# automatically generated file, don't edit



# Copyright 2011 David Cantrell, derived from data from libphonenumber
# http://code.google.com/p/libphonenumber/
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
package Number::Phone::StubCountry::GQ;
use base qw(Number::Phone::StubCountry);

use strict;
use warnings;
use utf8;
our $VERSION = 1.20200904144532;

my $formatters = [
                {
                  'format' => '$1 $2 $3',
                  'leading_digits' => '[235]',
                  'pattern' => '(\\d{3})(\\d{3})(\\d{3})'
                },
                {
                  'format' => '$1 $2',
                  'leading_digits' => '[89]',
                  'pattern' => '(\\d{3})(\\d{6})'
                }
              ];

my $validators = {
                'fixed_line' => '
          33[0-24-9]\\d[46]\\d{4}|
          3(?:
            33|
            5\\d
          )\\d[7-9]\\d{4}
        ',
                'geographic' => '
          33[0-24-9]\\d[46]\\d{4}|
          3(?:
            33|
            5\\d
          )\\d[7-9]\\d{4}
        ',
                'mobile' => '
          (?:
            222|
            55[015]
          )\\d{6}
        ',
                'pager' => '',
                'personal_number' => '',
                'specialrate' => '(90\\d[1-9]\\d{5})',
                'toll_free' => '80\\d[1-9]\\d{5}',
                'voip' => ''
              };
my %areanames = ();
$areanames{en}->{24033004} = "Bioko";
$areanames{en}->{24033006} = "Continental\ Region";
$areanames{en}->{24033014} = "Bioko";
$areanames{en}->{24033016} = "Continental\ Region";
$areanames{en}->{24033024} = "Bioko";
$areanames{en}->{24033026} = "Continental\ Region";
$areanames{en}->{24033034} = "Bioko";
$areanames{en}->{24033036} = "Continental\ Region";
$areanames{en}->{24033044} = "Bioko";
$areanames{en}->{24033046} = "Continental\ Region";
$areanames{en}->{24033054} = "Bioko";
$areanames{en}->{24033056} = "Continental\ Region";
$areanames{en}->{24033064} = "Bioko";
$areanames{en}->{24033066} = "Continental\ Region";
$areanames{en}->{24033074} = "Bioko";
$areanames{en}->{24033076} = "Continental\ Region";
$areanames{en}->{24033084} = "Bioko";
$areanames{en}->{24033086} = "Continental\ Region";
$areanames{en}->{24033094} = "Bioko";
$areanames{en}->{24033096} = "Continental\ Region";
$areanames{en}->{24033104} = "Bioko";
$areanames{en}->{24033106} = "Continental\ Region";
$areanames{en}->{24033114} = "Bioko";
$areanames{en}->{24033116} = "Continental\ Region";
$areanames{en}->{24033124} = "Bioko";
$areanames{en}->{24033126} = "Continental\ Region";
$areanames{en}->{24033134} = "Bioko";
$areanames{en}->{24033136} = "Continental\ Region";
$areanames{en}->{24033144} = "Bioko";
$areanames{en}->{24033146} = "Continental\ Region";
$areanames{en}->{24033154} = "Bioko";
$areanames{en}->{24033156} = "Continental\ Region";
$areanames{en}->{24033164} = "Bioko";
$areanames{en}->{24033166} = "Continental\ Region";
$areanames{en}->{24033174} = "Bioko";
$areanames{en}->{24033176} = "Continental\ Region";
$areanames{en}->{24033184} = "Bioko";
$areanames{en}->{24033186} = "Continental\ Region";
$areanames{en}->{24033194} = "Bioko";
$areanames{en}->{24033196} = "Continental\ Region";
$areanames{en}->{24033204} = "Bioko";
$areanames{en}->{24033206} = "Continental\ Region";
$areanames{en}->{24033214} = "Bioko";
$areanames{en}->{24033216} = "Continental\ Region";
$areanames{en}->{24033224} = "Bioko";
$areanames{en}->{24033226} = "Continental\ Region";
$areanames{en}->{24033234} = "Bioko";
$areanames{en}->{24033236} = "Continental\ Region";
$areanames{en}->{24033244} = "Bioko";
$areanames{en}->{24033246} = "Continental\ Region";
$areanames{en}->{24033254} = "Bioko";
$areanames{en}->{24033256} = "Continental\ Region";
$areanames{en}->{24033264} = "Bioko";
$areanames{en}->{24033266} = "Continental\ Region";
$areanames{en}->{24033274} = "Bioko";
$areanames{en}->{24033276} = "Continental\ Region";
$areanames{en}->{24033284} = "Bioko";
$areanames{en}->{24033286} = "Continental\ Region";
$areanames{en}->{24033294} = "Bioko";
$areanames{en}->{24033296} = "Continental\ Region";
$areanames{en}->{24033307} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24033308} = "Litoral\/Annobón";
$areanames{en}->{24033309} = "Bioko";
$areanames{en}->{24033317} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24033318} = "Litoral\/Annobón";
$areanames{en}->{24033319} = "Bioko";
$areanames{en}->{24033327} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24033328} = "Litoral\/Annobón";
$areanames{en}->{24033329} = "Bioko";
$areanames{en}->{24033337} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24033338} = "Litoral\/Annobón";
$areanames{en}->{24033339} = "Bioko";
$areanames{en}->{24033347} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24033348} = "Litoral\/Annobón";
$areanames{en}->{24033349} = "Bioko";
$areanames{en}->{24033357} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24033358} = "Litoral\/Annobón";
$areanames{en}->{24033359} = "Bioko";
$areanames{en}->{24033367} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24033368} = "Litoral\/Annobón";
$areanames{en}->{24033369} = "Bioko";
$areanames{en}->{24033377} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24033378} = "Litoral\/Annobón";
$areanames{en}->{24033379} = "Bioko";
$areanames{en}->{24033387} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24033388} = "Litoral\/Annobón";
$areanames{en}->{24033389} = "Bioko";
$areanames{en}->{24033397} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24033398} = "Litoral\/Annobón";
$areanames{en}->{24033399} = "Bioko";
$areanames{en}->{24033404} = "Bioko";
$areanames{en}->{24033406} = "Continental\ Region";
$areanames{en}->{24033414} = "Bioko";
$areanames{en}->{24033416} = "Continental\ Region";
$areanames{en}->{24033424} = "Bioko";
$areanames{en}->{24033426} = "Continental\ Region";
$areanames{en}->{24033434} = "Bioko";
$areanames{en}->{24033436} = "Continental\ Region";
$areanames{en}->{24033444} = "Bioko";
$areanames{en}->{24033446} = "Continental\ Region";
$areanames{en}->{24033454} = "Bioko";
$areanames{en}->{24033456} = "Continental\ Region";
$areanames{en}->{24033464} = "Bioko";
$areanames{en}->{24033466} = "Continental\ Region";
$areanames{en}->{24033474} = "Bioko";
$areanames{en}->{24033476} = "Continental\ Region";
$areanames{en}->{24033484} = "Bioko";
$areanames{en}->{24033486} = "Continental\ Region";
$areanames{en}->{24033494} = "Bioko";
$areanames{en}->{24033496} = "Continental\ Region";
$areanames{en}->{24033504} = "Bioko";
$areanames{en}->{24033506} = "Continental\ Region";
$areanames{en}->{24033514} = "Bioko";
$areanames{en}->{24033516} = "Continental\ Region";
$areanames{en}->{24033524} = "Bioko";
$areanames{en}->{24033526} = "Continental\ Region";
$areanames{en}->{24033534} = "Bioko";
$areanames{en}->{24033536} = "Continental\ Region";
$areanames{en}->{24033544} = "Bioko";
$areanames{en}->{24033546} = "Continental\ Region";
$areanames{en}->{24033554} = "Bioko";
$areanames{en}->{24033556} = "Continental\ Region";
$areanames{en}->{24033564} = "Bioko";
$areanames{en}->{24033566} = "Continental\ Region";
$areanames{en}->{24033574} = "Bioko";
$areanames{en}->{24033576} = "Continental\ Region";
$areanames{en}->{24033584} = "Bioko";
$areanames{en}->{24033586} = "Continental\ Region";
$areanames{en}->{24033594} = "Bioko";
$areanames{en}->{24033596} = "Continental\ Region";
$areanames{en}->{24033604} = "Bioko";
$areanames{en}->{24033606} = "Continental\ Region";
$areanames{en}->{24033614} = "Bioko";
$areanames{en}->{24033616} = "Continental\ Region";
$areanames{en}->{24033624} = "Bioko";
$areanames{en}->{24033626} = "Continental\ Region";
$areanames{en}->{24033634} = "Bioko";
$areanames{en}->{24033636} = "Continental\ Region";
$areanames{en}->{24033644} = "Bioko";
$areanames{en}->{24033646} = "Continental\ Region";
$areanames{en}->{24033654} = "Bioko";
$areanames{en}->{24033656} = "Continental\ Region";
$areanames{en}->{24033664} = "Bioko";
$areanames{en}->{24033666} = "Continental\ Region";
$areanames{en}->{24033674} = "Bioko";
$areanames{en}->{24033676} = "Continental\ Region";
$areanames{en}->{24033684} = "Bioko";
$areanames{en}->{24033686} = "Continental\ Region";
$areanames{en}->{24033694} = "Bioko";
$areanames{en}->{24033696} = "Continental\ Region";
$areanames{en}->{24033704} = "Bioko";
$areanames{en}->{24033706} = "Continental\ Region";
$areanames{en}->{24033714} = "Bioko";
$areanames{en}->{24033716} = "Continental\ Region";
$areanames{en}->{24033724} = "Bioko";
$areanames{en}->{24033726} = "Continental\ Region";
$areanames{en}->{24033734} = "Bioko";
$areanames{en}->{24033736} = "Continental\ Region";
$areanames{en}->{24033744} = "Bioko";
$areanames{en}->{24033746} = "Continental\ Region";
$areanames{en}->{24033754} = "Bioko";
$areanames{en}->{24033756} = "Continental\ Region";
$areanames{en}->{24033764} = "Bioko";
$areanames{en}->{24033766} = "Continental\ Region";
$areanames{en}->{24033774} = "Bioko";
$areanames{en}->{24033776} = "Continental\ Region";
$areanames{en}->{24033784} = "Bioko";
$areanames{en}->{24033786} = "Continental\ Region";
$areanames{en}->{24033794} = "Bioko";
$areanames{en}->{24033796} = "Continental\ Region";
$areanames{en}->{24033804} = "Bioko";
$areanames{en}->{24033806} = "Continental\ Region";
$areanames{en}->{24033814} = "Bioko";
$areanames{en}->{24033816} = "Continental\ Region";
$areanames{en}->{24033824} = "Bioko";
$areanames{en}->{24033826} = "Continental\ Region";
$areanames{en}->{24033834} = "Bioko";
$areanames{en}->{24033836} = "Continental\ Region";
$areanames{en}->{24033844} = "Bioko";
$areanames{en}->{24033846} = "Continental\ Region";
$areanames{en}->{24033854} = "Bioko";
$areanames{en}->{24033856} = "Continental\ Region";
$areanames{en}->{24033864} = "Bioko";
$areanames{en}->{24033866} = "Continental\ Region";
$areanames{en}->{24033874} = "Bioko";
$areanames{en}->{24033876} = "Continental\ Region";
$areanames{en}->{24033884} = "Bioko";
$areanames{en}->{24033886} = "Continental\ Region";
$areanames{en}->{24033894} = "Bioko";
$areanames{en}->{24033896} = "Continental\ Region";
$areanames{en}->{24033904} = "Bioko";
$areanames{en}->{24033906} = "Continental\ Region";
$areanames{en}->{24033914} = "Bioko";
$areanames{en}->{24033916} = "Continental\ Region";
$areanames{en}->{24033924} = "Bioko";
$areanames{en}->{24033926} = "Continental\ Region";
$areanames{en}->{24033934} = "Bioko";
$areanames{en}->{24033936} = "Continental\ Region";
$areanames{en}->{24033944} = "Bioko";
$areanames{en}->{24033946} = "Continental\ Region";
$areanames{en}->{24033954} = "Bioko";
$areanames{en}->{24033956} = "Continental\ Region";
$areanames{en}->{24033964} = "Bioko";
$areanames{en}->{24033966} = "Continental\ Region";
$areanames{en}->{24033974} = "Bioko";
$areanames{en}->{24033976} = "Continental\ Region";
$areanames{en}->{24033984} = "Bioko";
$areanames{en}->{24033986} = "Continental\ Region";
$areanames{en}->{24033994} = "Bioko";
$areanames{en}->{24033996} = "Continental\ Region";
$areanames{en}->{24035007} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035008} = "Litoral\/Annobón";
$areanames{en}->{24035009} = "Bioko";
$areanames{en}->{24035017} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035018} = "Litoral\/Annobón";
$areanames{en}->{24035019} = "Bioko";
$areanames{en}->{24035027} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035028} = "Litoral\/Annobón";
$areanames{en}->{24035029} = "Bioko";
$areanames{en}->{24035037} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035038} = "Litoral\/Annobón";
$areanames{en}->{24035039} = "Bioko";
$areanames{en}->{24035047} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035048} = "Litoral\/Annobón";
$areanames{en}->{24035049} = "Bioko";
$areanames{en}->{24035057} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035058} = "Litoral\/Annobón";
$areanames{en}->{24035059} = "Bioko";
$areanames{en}->{24035067} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035068} = "Litoral\/Annobón";
$areanames{en}->{24035069} = "Bioko";
$areanames{en}->{24035077} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035078} = "Litoral\/Annobón";
$areanames{en}->{24035079} = "Bioko";
$areanames{en}->{24035087} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035088} = "Litoral\/Annobón";
$areanames{en}->{24035089} = "Bioko";
$areanames{en}->{24035097} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035098} = "Litoral\/Annobón";
$areanames{en}->{24035099} = "Bioko";
$areanames{en}->{24035107} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035108} = "Litoral\/Annobón";
$areanames{en}->{24035109} = "Bioko";
$areanames{en}->{24035117} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035118} = "Litoral\/Annobón";
$areanames{en}->{24035119} = "Bioko";
$areanames{en}->{24035127} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035128} = "Litoral\/Annobón";
$areanames{en}->{24035129} = "Bioko";
$areanames{en}->{24035137} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035138} = "Litoral\/Annobón";
$areanames{en}->{24035139} = "Bioko";
$areanames{en}->{24035147} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035148} = "Litoral\/Annobón";
$areanames{en}->{24035149} = "Bioko";
$areanames{en}->{24035157} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035158} = "Litoral\/Annobón";
$areanames{en}->{24035159} = "Bioko";
$areanames{en}->{24035167} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035168} = "Litoral\/Annobón";
$areanames{en}->{24035169} = "Bioko";
$areanames{en}->{24035177} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035178} = "Litoral\/Annobón";
$areanames{en}->{24035179} = "Bioko";
$areanames{en}->{24035187} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035188} = "Litoral\/Annobón";
$areanames{en}->{24035189} = "Bioko";
$areanames{en}->{24035197} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035198} = "Litoral\/Annobón";
$areanames{en}->{24035199} = "Bioko";
$areanames{en}->{24035207} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035208} = "Litoral\/Annobón";
$areanames{en}->{24035209} = "Bioko";
$areanames{en}->{24035217} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035218} = "Litoral\/Annobón";
$areanames{en}->{24035219} = "Bioko";
$areanames{en}->{24035227} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035228} = "Litoral\/Annobón";
$areanames{en}->{24035229} = "Bioko";
$areanames{en}->{24035237} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035238} = "Litoral\/Annobón";
$areanames{en}->{24035239} = "Bioko";
$areanames{en}->{24035247} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035248} = "Litoral\/Annobón";
$areanames{en}->{24035249} = "Bioko";
$areanames{en}->{24035257} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035258} = "Litoral\/Annobón";
$areanames{en}->{24035259} = "Bioko";
$areanames{en}->{24035267} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035268} = "Litoral\/Annobón";
$areanames{en}->{24035269} = "Bioko";
$areanames{en}->{24035277} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035278} = "Litoral\/Annobón";
$areanames{en}->{24035279} = "Bioko";
$areanames{en}->{24035287} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035288} = "Litoral\/Annobón";
$areanames{en}->{24035289} = "Bioko";
$areanames{en}->{24035297} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035298} = "Litoral\/Annobón";
$areanames{en}->{24035299} = "Bioko";
$areanames{en}->{24035307} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035308} = "Litoral\/Annobón";
$areanames{en}->{24035309} = "Bioko";
$areanames{en}->{24035317} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035318} = "Litoral\/Annobón";
$areanames{en}->{24035319} = "Bioko";
$areanames{en}->{24035327} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035328} = "Litoral\/Annobón";
$areanames{en}->{24035329} = "Bioko";
$areanames{en}->{24035337} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035338} = "Litoral\/Annobón";
$areanames{en}->{24035339} = "Bioko";
$areanames{en}->{24035347} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035348} = "Litoral\/Annobón";
$areanames{en}->{24035349} = "Bioko";
$areanames{en}->{24035357} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035358} = "Litoral\/Annobón";
$areanames{en}->{24035359} = "Bioko";
$areanames{en}->{24035367} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035368} = "Litoral\/Annobón";
$areanames{en}->{24035369} = "Bioko";
$areanames{en}->{24035377} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035378} = "Litoral\/Annobón";
$areanames{en}->{24035379} = "Bioko";
$areanames{en}->{24035387} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035388} = "Litoral\/Annobón";
$areanames{en}->{24035389} = "Bioko";
$areanames{en}->{24035397} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035398} = "Litoral\/Annobón";
$areanames{en}->{24035399} = "Bioko";
$areanames{en}->{24035407} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035408} = "Litoral\/Annobón";
$areanames{en}->{24035409} = "Bioko";
$areanames{en}->{24035417} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035418} = "Litoral\/Annobón";
$areanames{en}->{24035419} = "Bioko";
$areanames{en}->{24035427} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035428} = "Litoral\/Annobón";
$areanames{en}->{24035429} = "Bioko";
$areanames{en}->{24035437} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035438} = "Litoral\/Annobón";
$areanames{en}->{24035439} = "Bioko";
$areanames{en}->{24035447} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035448} = "Litoral\/Annobón";
$areanames{en}->{24035449} = "Bioko";
$areanames{en}->{24035457} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035458} = "Litoral\/Annobón";
$areanames{en}->{24035459} = "Bioko";
$areanames{en}->{24035467} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035468} = "Litoral\/Annobón";
$areanames{en}->{24035469} = "Bioko";
$areanames{en}->{24035477} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035478} = "Litoral\/Annobón";
$areanames{en}->{24035479} = "Bioko";
$areanames{en}->{24035487} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035488} = "Litoral\/Annobón";
$areanames{en}->{24035489} = "Bioko";
$areanames{en}->{24035497} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035498} = "Litoral\/Annobón";
$areanames{en}->{24035499} = "Bioko";
$areanames{en}->{24035507} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035508} = "Litoral\/Annobón";
$areanames{en}->{24035509} = "Bioko";
$areanames{en}->{24035517} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035518} = "Litoral\/Annobón";
$areanames{en}->{24035519} = "Bioko";
$areanames{en}->{24035527} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035528} = "Litoral\/Annobón";
$areanames{en}->{24035529} = "Bioko";
$areanames{en}->{24035537} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035538} = "Litoral\/Annobón";
$areanames{en}->{24035539} = "Bioko";
$areanames{en}->{24035547} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035548} = "Litoral\/Annobón";
$areanames{en}->{24035549} = "Bioko";
$areanames{en}->{24035557} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035558} = "Litoral\/Annobón";
$areanames{en}->{24035559} = "Bioko";
$areanames{en}->{24035567} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035568} = "Litoral\/Annobón";
$areanames{en}->{24035569} = "Bioko";
$areanames{en}->{24035577} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035578} = "Litoral\/Annobón";
$areanames{en}->{24035579} = "Bioko";
$areanames{en}->{24035587} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035588} = "Litoral\/Annobón";
$areanames{en}->{24035589} = "Bioko";
$areanames{en}->{24035597} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035598} = "Litoral\/Annobón";
$areanames{en}->{24035599} = "Bioko";
$areanames{en}->{24035607} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035608} = "Litoral\/Annobón";
$areanames{en}->{24035609} = "Bioko";
$areanames{en}->{24035617} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035618} = "Litoral\/Annobón";
$areanames{en}->{24035619} = "Bioko";
$areanames{en}->{24035627} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035628} = "Litoral\/Annobón";
$areanames{en}->{24035629} = "Bioko";
$areanames{en}->{24035637} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035638} = "Litoral\/Annobón";
$areanames{en}->{24035639} = "Bioko";
$areanames{en}->{24035647} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035648} = "Litoral\/Annobón";
$areanames{en}->{24035649} = "Bioko";
$areanames{en}->{24035657} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035658} = "Litoral\/Annobón";
$areanames{en}->{24035659} = "Bioko";
$areanames{en}->{24035667} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035668} = "Litoral\/Annobón";
$areanames{en}->{24035669} = "Bioko";
$areanames{en}->{24035677} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035678} = "Litoral\/Annobón";
$areanames{en}->{24035679} = "Bioko";
$areanames{en}->{24035687} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035688} = "Litoral\/Annobón";
$areanames{en}->{24035689} = "Bioko";
$areanames{en}->{24035697} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035698} = "Litoral\/Annobón";
$areanames{en}->{24035699} = "Bioko";
$areanames{en}->{24035707} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035708} = "Litoral\/Annobón";
$areanames{en}->{24035709} = "Bioko";
$areanames{en}->{24035717} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035718} = "Litoral\/Annobón";
$areanames{en}->{24035719} = "Bioko";
$areanames{en}->{24035727} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035728} = "Litoral\/Annobón";
$areanames{en}->{24035729} = "Bioko";
$areanames{en}->{24035737} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035738} = "Litoral\/Annobón";
$areanames{en}->{24035739} = "Bioko";
$areanames{en}->{24035747} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035748} = "Litoral\/Annobón";
$areanames{en}->{24035749} = "Bioko";
$areanames{en}->{24035757} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035758} = "Litoral\/Annobón";
$areanames{en}->{24035759} = "Bioko";
$areanames{en}->{24035767} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035768} = "Litoral\/Annobón";
$areanames{en}->{24035769} = "Bioko";
$areanames{en}->{24035777} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035778} = "Litoral\/Annobón";
$areanames{en}->{24035779} = "Bioko";
$areanames{en}->{24035787} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035788} = "Litoral\/Annobón";
$areanames{en}->{24035789} = "Bioko";
$areanames{en}->{24035797} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035798} = "Litoral\/Annobón";
$areanames{en}->{24035799} = "Bioko";
$areanames{en}->{24035807} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035808} = "Litoral\/Annobón";
$areanames{en}->{24035809} = "Bioko";
$areanames{en}->{24035817} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035818} = "Litoral\/Annobón";
$areanames{en}->{24035819} = "Bioko";
$areanames{en}->{24035827} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035828} = "Litoral\/Annobón";
$areanames{en}->{24035829} = "Bioko";
$areanames{en}->{24035837} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035838} = "Litoral\/Annobón";
$areanames{en}->{24035839} = "Bioko";
$areanames{en}->{24035847} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035848} = "Litoral\/Annobón";
$areanames{en}->{24035849} = "Bioko";
$areanames{en}->{24035857} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035858} = "Litoral\/Annobón";
$areanames{en}->{24035859} = "Bioko";
$areanames{en}->{24035867} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035868} = "Litoral\/Annobón";
$areanames{en}->{24035869} = "Bioko";
$areanames{en}->{24035877} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035878} = "Litoral\/Annobón";
$areanames{en}->{24035879} = "Bioko";
$areanames{en}->{24035887} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035888} = "Litoral\/Annobón";
$areanames{en}->{24035889} = "Bioko";
$areanames{en}->{24035897} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035898} = "Litoral\/Annobón";
$areanames{en}->{24035899} = "Bioko";
$areanames{en}->{24035907} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035908} = "Litoral\/Annobón";
$areanames{en}->{24035909} = "Bioko";
$areanames{en}->{24035917} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035918} = "Litoral\/Annobón";
$areanames{en}->{24035919} = "Bioko";
$areanames{en}->{24035927} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035928} = "Litoral\/Annobón";
$areanames{en}->{24035929} = "Bioko";
$areanames{en}->{24035937} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035938} = "Litoral\/Annobón";
$areanames{en}->{24035939} = "Bioko";
$areanames{en}->{24035947} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035948} = "Litoral\/Annobón";
$areanames{en}->{24035949} = "Bioko";
$areanames{en}->{24035957} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035958} = "Litoral\/Annobón";
$areanames{en}->{24035959} = "Bioko";
$areanames{en}->{24035967} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035968} = "Litoral\/Annobón";
$areanames{en}->{24035969} = "Bioko";
$areanames{en}->{24035977} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035978} = "Litoral\/Annobón";
$areanames{en}->{24035979} = "Bioko";
$areanames{en}->{24035987} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035988} = "Litoral\/Annobón";
$areanames{en}->{24035989} = "Bioko";
$areanames{en}->{24035997} = "Centro\-Sur\/Kié\-Ntem\/Wele\-Nzás";
$areanames{en}->{24035998} = "Litoral\/Annobón";
$areanames{en}->{24035999} = "Bioko";

    sub new {
      my $class = shift;
      my $number = shift;
      $number =~ s/(^\+240|\D)//g;
      my $self = bless({ number => $number, formatters => $formatters, validators => $validators, areanames => \%areanames}, $class);
        return $self->is_valid() ? $self : undef;
    }
1;