# automatically generated file, don't edit



# Copyright 2011 David Cantrell, derived from data from libphonenumber
# http://code.google.com/p/libphonenumber/
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
package Number::Phone::StubCountry::AT;
use base qw(Number::Phone::StubCountry);

use strict;
use warnings;
use utf8;
our $VERSION = 1.20200904144526;

my $formatters = [
                {
                  'format' => '$1 $2',
                  'leading_digits' => '
            1(?:
              11|
              [2-9]
            )
          ',
                  'national_rule' => '0$1',
                  'pattern' => '(\\d)(\\d{3,12})'
                },
                {
                  'format' => '$1 $2',
                  'leading_digits' => '517',
                  'national_rule' => '0$1',
                  'pattern' => '(\\d{3})(\\d{2})'
                },
                {
                  'format' => '$1 $2',
                  'leading_digits' => '5[079]',
                  'national_rule' => '0$1',
                  'pattern' => '(\\d{2})(\\d{3,5})'
                },
                {
                  'format' => '$1',
                  'intl_format' => 'NA',
                  'leading_digits' => '1',
                  'pattern' => '(\\d{6})'
                },
                {
                  'format' => '$1 $2',
                  'leading_digits' => '
            (?:
              31|
              4
            )6|
            51|
            6(?:
              5[0-3579]|
              [6-9]
            )|
            7(?:
              20|
              32|
              8
            )|
            [89]
          ',
                  'national_rule' => '0$1',
                  'pattern' => '(\\d{3})(\\d{3,10})'
                },
                {
                  'format' => '$1 $2',
                  'leading_digits' => '
            [2-467]|
            5[2-6]
          ',
                  'national_rule' => '0$1',
                  'pattern' => '(\\d{4})(\\d{3,9})'
                },
                {
                  'format' => '$1 $2 $3',
                  'leading_digits' => '5',
                  'national_rule' => '0$1',
                  'pattern' => '(\\d{2})(\\d{3})(\\d{3,4})'
                },
                {
                  'format' => '$1 $2 $3',
                  'leading_digits' => '5',
                  'national_rule' => '0$1',
                  'pattern' => '(\\d{2})(\\d{4})(\\d{4,7})'
                }
              ];

my $validators = {
                'fixed_line' => '
          1(?:
            11\\d|
            [2-9]\\d{3,11}
          )|
          (?:
            316|
            463|
            (?:
              51|
              66|
              73
            )2
          )\\d{3,10}|
          (?:
            2(?:
              1[467]|
              2[13-8]|
              5[2357]|
              6[1-46-8]|
              7[1-8]|
              8[124-7]|
              9[1458]
            )|
            3(?:
              1[1-578]|
              3[23568]|
              4[5-7]|
              5[1378]|
              6[1-38]|
              8[3-68]
            )|
            4(?:
              2[1-8]|
              35|
              7[1368]|
              8[2457]
            )|
            5(?:
              2[1-8]|
              3[357]|
              4[147]|
              5[12578]|
              6[37]
            )|
            6(?:
              13|
              2[1-47]|
              4[135-8]|
              5[468]
            )|
            7(?:
              2[1-8]|
              35|
              4[13478]|
              5[68]|
              6[16-8]|
              7[1-6]|
              9[45]
            )
          )\\d{4,10}
        ',
                'geographic' => '
          1(?:
            11\\d|
            [2-9]\\d{3,11}
          )|
          (?:
            316|
            463|
            (?:
              51|
              66|
              73
            )2
          )\\d{3,10}|
          (?:
            2(?:
              1[467]|
              2[13-8]|
              5[2357]|
              6[1-46-8]|
              7[1-8]|
              8[124-7]|
              9[1458]
            )|
            3(?:
              1[1-578]|
              3[23568]|
              4[5-7]|
              5[1378]|
              6[1-38]|
              8[3-68]
            )|
            4(?:
              2[1-8]|
              35|
              7[1368]|
              8[2457]
            )|
            5(?:
              2[1-8]|
              3[357]|
              4[147]|
              5[12578]|
              6[37]
            )|
            6(?:
              13|
              2[1-47]|
              4[135-8]|
              5[468]
            )|
            7(?:
              2[1-8]|
              35|
              4[13478]|
              5[68]|
              6[16-8]|
              7[1-6]|
              9[45]
            )
          )\\d{4,10}
        ',
                'mobile' => '
          6(?:
            5[0-3579]|
            6[013-9]|
            [7-9]\\d
          )\\d{4,10}
        ',
                'pager' => '',
                'personal_number' => '',
                'specialrate' => '(
          8(?:
            10|
            2[018]
          )\\d{6,10}|
          828\\d{5}
        )|(
          9(?:
            0[01]|
            3[019]
          )\\d{6,10}
        )',
                'toll_free' => '800\\d{6,10}',
                'voip' => '
          5(?:
            0[1-9]|
            17|
            [79]\\d
          )\\d{2,10}|
          7[28]0\\d{6,10}
        '
              };
my %areanames = ();
$areanames{de}->{4312} = "Wien";
$areanames{de}->{4313} = "Wien";
$areanames{de}->{4314} = "Wien";
$areanames{de}->{4315} = "Wien";
$areanames{de}->{4316} = "Wien";
$areanames{de}->{4317} = "Wien";
$areanames{de}->{4318} = "Wien";
$areanames{de}->{4319} = "Wien";
$areanames{de}->{432142} = "Gattendorf";
$areanames{de}->{432143} = "Kittsee";
$areanames{de}->{432144} = "Deutsch\ Jahrndorf";
$areanames{de}->{432145} = "Prellenkirchen";
$areanames{de}->{432146} = "Nickelsdorf";
$areanames{de}->{432147} = "Zurndorf";
$areanames{de}->{432160} = "Jois";
$areanames{de}->{432162} = "Bruck\ an\ der\ Leitha";
$areanames{de}->{432163} = "Petronell\-Carnuntum";
$areanames{de}->{432164} = "Rohrau";
$areanames{de}->{432165} = "Hainburg\ a\.d\.\ Donau";
$areanames{de}->{432166} = "Parndorf";
$areanames{de}->{432167} = "Neusiedl\ am\ See";
$areanames{de}->{432168} = "Mannersdorf\ am\ Leithagebirge";
$areanames{de}->{432169} = "Trautmannsdorf\ an\ der\ Leitha";
$areanames{de}->{432172} = "Frauenkirchen";
$areanames{de}->{432173} = "Gols";
$areanames{de}->{432174} = "Wallern\ im\ Burgenland";
$areanames{de}->{432175} = "Apetlon";
$areanames{de}->{432176} = "Tadten";
$areanames{de}->{432177} = "Podersdorf\ am\ See";
$areanames{de}->{432212} = "Orth\ an\ der\ Donau";
$areanames{de}->{432213} = "Lassee";
$areanames{de}->{432214} = "Kopfstetten";
$areanames{de}->{432215} = "Probstdorf";
$areanames{de}->{432216} = "Leopoldsdorf\ im\ Marchfelde";
$areanames{de}->{432230} = "Schwadorf";
$areanames{de}->{432231} = "Purkersdorf";
$areanames{de}->{432232} = "Fischamend";
$areanames{de}->{432233} = "Preßbaum";
$areanames{de}->{432234} = "Gramatneusiedl";
$areanames{de}->{432235} = "Maria\-Lanzendorf";
$areanames{de}->{432236} = "Mödling";
$areanames{de}->{432237} = "Gaaden";
$areanames{de}->{432238} = "Kaltenleutgeben";
$areanames{de}->{432239} = "Breitenfurt\ bei\ Wien";
$areanames{de}->{432242} = "Sankt\ Andrä\-Wördern";
$areanames{de}->{432243} = "Klosterneuburg";
$areanames{de}->{432244} = "Langenzersdorf";
$areanames{de}->{432245} = "Wolkersdorf\ im\ Weinviertel";
$areanames{de}->{432246} = "Gerasdorf\ bei\ Wien";
$areanames{de}->{432247} = "Deutsch\-Wagram";
$areanames{de}->{432248} = "Markgrafneusiedl";
$areanames{de}->{432249} = "Groß\-Enzersdorf";
$areanames{de}->{432252} = "Baden";
$areanames{de}->{432253} = "Oberwaltersdorf";
$areanames{de}->{432254} = "Ebreichsdorf";
$areanames{de}->{432255} = "Deutsch\ Brodersdorf";
$areanames{de}->{432256} = "Leobersdorf";
$areanames{de}->{432257} = "Klausen\-Leopoldsdorf";
$areanames{de}->{432258} = "Alland";
$areanames{de}->{432259} = "Münchendorf";
$areanames{de}->{432262} = "Korneuburg";
$areanames{de}->{432263} = "Großrußbach";
$areanames{de}->{432264} = "Rückersdorf\,\ Harmannsdorf";
$areanames{de}->{432265} = "Hausleiten";
$areanames{de}->{432266} = "Stockerau";
$areanames{de}->{432267} = "Sierndorf";
$areanames{de}->{432268} = "Großmugl";
$areanames{de}->{432269} = "Niederfellabrunn";
$areanames{de}->{432271} = "Ried\ am\ Riederberg";
$areanames{de}->{432272} = "Tulln\ an\ der\ Donau";
$areanames{de}->{432273} = "Tulbing";
$areanames{de}->{432274} = "Sieghartskirchen";
$areanames{de}->{432275} = "Atzenbrugg";
$areanames{de}->{432276} = "Reidling";
$areanames{de}->{432277} = "Zwentendorf";
$areanames{de}->{432278} = "Absdorf";
$areanames{de}->{432279} = "Kirchberg\ am\ Wagram";
$areanames{de}->{432282} = "Gänserndorf";
$areanames{de}->{432283} = "Angern\ an\ der\ March";
$areanames{de}->{432284} = "Oberweiden";
$areanames{de}->{432285} = "Marchegg";
$areanames{de}->{432286} = "Obersiebenbrunn";
$areanames{de}->{432287} = "Strasshof\ an\ der\ Nordbahn";
$areanames{de}->{432288} = "Auersthal";
$areanames{de}->{432289} = "Matzen";
$areanames{de}->{432522} = "Laa\ an\ der\ Thaya";
$areanames{de}->{432523} = "Kirchstetten\,\ Neudorf\ bei\ Staatz";
$areanames{de}->{432524} = "Kautendorf";
$areanames{de}->{432525} = "Gnadendorf";
$areanames{de}->{432526} = "Stronsdorf";
$areanames{de}->{432527} = "Wulzeshofen";
$areanames{de}->{432532} = "Zistersdorf";
$areanames{de}->{432533} = "Neusiedl\ an\ der\ Zaya";
$areanames{de}->{432534} = "Niedersulz";
$areanames{de}->{432535} = "Hohenau\ an\ der\ March";
$areanames{de}->{432536} = "Drösing";
$areanames{de}->{432538} = "Velm\-Götzendorf";
$areanames{de}->{432552} = "Poysdorf";
$areanames{de}->{432554} = "Stützenhofen";
$areanames{de}->{432555} = "Herrnbaumgarten";
$areanames{de}->{432556} = "Großkrut";
$areanames{de}->{432557} = "Bernhardsthal";
$areanames{de}->{432572} = "Mistelbach";
$areanames{de}->{432573} = "Wilfersdorf";
$areanames{de}->{432574} = "Gaweinstal";
$areanames{de}->{432575} = "Ladendorf";
$areanames{de}->{432576} = "Ernstbrunn";
$areanames{de}->{432577} = "Asparn\ an\ der\ Zaya";
$areanames{de}->{432610} = "Horitschon";
$areanames{de}->{432611} = "Mannersdorf\ an\ der\ Rabnitz";
$areanames{de}->{432612} = "Oberpullendorf";
$areanames{de}->{432613} = "Deutschkreutz";
$areanames{de}->{432614} = "Kleinwarasdorf";
$areanames{de}->{432615} = "Lutzmannsburg";
$areanames{de}->{432616} = "Lockenhaus";
$areanames{de}->{432617} = "Draßmarkt";
$areanames{de}->{432618} = "Markt\ Sankt\ Martin";
$areanames{de}->{432619} = "Lackendorf";
$areanames{de}->{432620} = "Willendorf";
$areanames{de}->{432621} = "Sieggraben";
$areanames{de}->{432622} = "Wiener\ Neustadt";
$areanames{de}->{432623} = "Pottendorf";
$areanames{de}->{432624} = "Ebenfurth";
$areanames{de}->{432625} = "Bad\ Sauerbrunn";
$areanames{de}->{432626} = "Mattersburg";
$areanames{de}->{432627} = "Pitten";
$areanames{de}->{432628} = "Felixdorf";
$areanames{de}->{432629} = "Warth\,\ Niederösterreich";
$areanames{de}->{432630} = "Ternitz";
$areanames{de}->{432631} = "Pöttsching";
$areanames{de}->{432632} = "Pernitz";
$areanames{de}->{432633} = "Markt\ Piesting";
$areanames{de}->{432634} = "Gutenstein";
$areanames{de}->{432635} = "Neunkirchen";
$areanames{de}->{432636} = "Puchberg\ am\ Schneeberg";
$areanames{de}->{432637} = "Grünbach\ am\ Schneeberg";
$areanames{de}->{432638} = "Winzendorf\-Muthmannsdorf";
$areanames{de}->{432639} = "Bad\ Fischau";
$areanames{de}->{432641} = "Kirchberg\ am\ Wechsel";
$areanames{de}->{432642} = "Aspangberg\-Sankt\ Peter";
$areanames{de}->{432643} = "Lichtenegg";
$areanames{de}->{432644} = "Grimmenstein";
$areanames{de}->{432645} = "Wiesmath";
$areanames{de}->{432646} = "Kirchschlag\ in\ der\ Buckligen\ Welt";
$areanames{de}->{432647} = "Krumbach\,\ Niederösterreich";
$areanames{de}->{432648} = "Hochneukirchen";
$areanames{de}->{432649} = "Mönichkirchen";
$areanames{de}->{432662} = "Gloggnitz";
$areanames{de}->{432663} = "Schottwien";
$areanames{de}->{432664} = "Semmering";
$areanames{de}->{432665} = "Prein\ an\ der\ Rax";
$areanames{de}->{432666} = "Reichenau";
$areanames{de}->{432667} = "Schwarzau\ im\ Gebirge";
$areanames{de}->{432672} = "Berndorf";
$areanames{de}->{432673} = "Altenmarkt\ an\ der\ Triesting";
$areanames{de}->{432674} = "Weißenbach\ an\ der\ Triesting";
$areanames{de}->{432680} = "Sankt\ Margarethen\ im\ Burgenland";
$areanames{de}->{432682} = "Eisenstadt";
$areanames{de}->{432683} = "Purbach\ am\ Neusiedler\ See";
$areanames{de}->{432684} = "Schützen\ am\ Gebirge";
$areanames{de}->{432685} = "Rust";
$areanames{de}->{432686} = "Draßburg";
$areanames{de}->{432687} = "Siegendorf";
$areanames{de}->{432688} = "Steinbrunn";
$areanames{de}->{432689} = "Hornstein";
$areanames{de}->{432711} = "Dürnstein";
$areanames{de}->{432712} = "Aggsbach";
$areanames{de}->{432713} = "Spitz";
$areanames{de}->{432714} = "Rossatz";
$areanames{de}->{432715} = "Weißenkirchen\ in\ der\ Wachau";
$areanames{de}->{432716} = "Gföhl";
$areanames{de}->{432717} = "Unter\-Meisling";
$areanames{de}->{432718} = "Lichtenau\ im\ Waldviertel";
$areanames{de}->{432719} = "Droß";
$areanames{de}->{432722} = "Kirchberg\ an\ der\ Pielach";
$areanames{de}->{432723} = "Rabenstein\ an\ der\ Pielach";
$areanames{de}->{432724} = "Schwarzenbach\ an\ der\ Pielach";
$areanames{de}->{432725} = "Frankenfels";
$areanames{de}->{432726} = "Puchenstuben";
$areanames{de}->{432728} = "Wienerbruck";
$areanames{de}->{432731} = "Idolsberg";
$areanames{de}->{432732} = "Krems\ an\ der\ Donau";
$areanames{de}->{432733} = "Schönberg\ am\ Kamp";
$areanames{de}->{432734} = "Langenlois";
$areanames{de}->{432735} = "Hadersdorf\ am\ Kamp";
$areanames{de}->{432736} = "Paudorf";
$areanames{de}->{432738} = "Fels\ am\ Wagram";
$areanames{de}->{432739} = "Tiefenfucha";
$areanames{de}->{432741} = "Flinsbach";
$areanames{de}->{432742} = "Sankt\ Pölten";
$areanames{de}->{432743} = "Böheimkirchen";
$areanames{de}->{432744} = "Kasten\ bei\ Böheimkirchen";
$areanames{de}->{432745} = "Pyhra";
$areanames{de}->{432746} = "Wilhelmsburg";
$areanames{de}->{432747} = "Ober\-Grafendorf";
$areanames{de}->{432748} = "Kilb";
$areanames{de}->{432749} = "Prinzersdorf";
$areanames{de}->{432752} = "Melk";
$areanames{de}->{432753} = "Gansbach";
$areanames{de}->{432754} = "Loosdorf";
$areanames{de}->{432755} = "Mank";
$areanames{de}->{432756} = "Sankt\ Leonhard\ am\ Forst";
$areanames{de}->{432757} = "Pöchlarn";
$areanames{de}->{432758} = "Pöggstall";
$areanames{de}->{432762} = "Lilienfeld";
$areanames{de}->{432763} = "Sankt\ Veit\ an\ der\ Gölsen";
$areanames{de}->{432764} = "Hainfeld";
$areanames{de}->{432765} = "Kaumberg";
$areanames{de}->{432766} = "Kleinzell";
$areanames{de}->{432767} = "Hohenberg";
$areanames{de}->{432768} = "Sankt\ Aegyd\ am\ Neuwalde";
$areanames{de}->{432769} = "Türnitz";
$areanames{de}->{432772} = "Neulengbach";
$areanames{de}->{432773} = "Eichgraben";
$areanames{de}->{432774} = "Innermanzing";
$areanames{de}->{432782} = "Herzogenburg";
$areanames{de}->{432783} = "Traismauer";
$areanames{de}->{432784} = "Perschling";
$areanames{de}->{432786} = "Oberwölbling";
$areanames{de}->{432812} = "Groß\ Gerungs";
$areanames{de}->{432813} = "Arbesbach";
$areanames{de}->{432814} = "Langschlag";
$areanames{de}->{432815} = "Großschönau";
$areanames{de}->{432816} = "Karlstift";
$areanames{de}->{432822} = "Zwettl\-Niederösterreich";
$areanames{de}->{432823} = "Großglobnitz";
$areanames{de}->{432824} = "Allentsteig";
$areanames{de}->{432825} = "Göpfritz\ an\ der\ Wild";
$areanames{de}->{432826} = "Rastenfeld";
$areanames{de}->{432827} = "Schönbach";
$areanames{de}->{432828} = "Rappottenstein";
$areanames{de}->{432829} = "Schweiggers";
$areanames{de}->{432841} = "Vitis";
$areanames{de}->{432842} = "Waidhofen\ an\ der\ Thaya";
$areanames{de}->{432843} = "Dobersberg";
$areanames{de}->{432844} = "Karlstein\ an\ der\ Thaya";
$areanames{de}->{432845} = "Weikertschlag\ an\ der\ Thaya";
$areanames{de}->{432846} = "Raabs\ an\ der\ Thaya";
$areanames{de}->{432847} = "Groß\-Siegharts";
$areanames{de}->{432848} = "Pfaffenschlag\ bei\ Waidhofen";
$areanames{de}->{432849} = "Schwarzenau";
$areanames{de}->{432852} = "Gmünd";
$areanames{de}->{432853} = "Schrems";
$areanames{de}->{432854} = "Kirchberg\ am\ Walde";
$areanames{de}->{432855} = "Waldenstein";
$areanames{de}->{432856} = "Weitra";
$areanames{de}->{432857} = "Bad\ Großpertholz";
$areanames{de}->{432858} = "Moorbad\ Harbach";
$areanames{de}->{432859} = "Brand\-Nagelberg";
$areanames{de}->{432862} = "Heidenreichstein";
$areanames{de}->{432863} = "Eggern";
$areanames{de}->{432864} = "Kautzen";
$areanames{de}->{432865} = "Litschau";
$areanames{de}->{432872} = "Ottenschlag";
$areanames{de}->{432873} = "Kottes";
$areanames{de}->{432874} = "Martinsberg";
$areanames{de}->{432875} = "Grafenschlag";
$areanames{de}->{432876} = "Els";
$areanames{de}->{432877} = "Grainbrunn";
$areanames{de}->{432878} = "Traunstein";
$areanames{de}->{432912} = "Geras";
$areanames{de}->{432913} = "Hötzelsdorf";
$areanames{de}->{432914} = "Japons";
$areanames{de}->{432915} = "Drosendorf\-Zissersdorf";
$areanames{de}->{432916} = "Riegersburg\,\ Hardegg";
$areanames{de}->{432942} = "Retz";
$areanames{de}->{432943} = "Obritz";
$areanames{de}->{432944} = "Haugsdorf";
$areanames{de}->{432945} = "Zellerndorf";
$areanames{de}->{432946} = "Pulkau";
$areanames{de}->{432947} = "Theras";
$areanames{de}->{432948} = "Weitersfeld";
$areanames{de}->{432949} = "Niederfladnitz";
$areanames{de}->{432951} = "Guntersdorf";
$areanames{de}->{432952} = "Hollabrunn";
$areanames{de}->{432953} = "Nappersdorf";
$areanames{de}->{432954} = "Göllersdorf";
$areanames{de}->{432955} = "Großweikersdorf";
$areanames{de}->{432956} = "Ziersdorf";
$areanames{de}->{432957} = "Hohenwarth";
$areanames{de}->{432958} = "Maissau";
$areanames{de}->{432959} = "Sitzendorf\ an\ der\ Schmida";
$areanames{de}->{432982} = "Horn";
$areanames{de}->{432983} = "Sigmundsherberg";
$areanames{de}->{432984} = "Eggenburg";
$areanames{de}->{432985} = "Gars\ am\ Kamp";
$areanames{de}->{432986} = "Irnfritz";
$areanames{de}->{432987} = "Sankt\ Leonhard\ am\ Hornerwald";
$areanames{de}->{432988} = "Neupölla";
$areanames{de}->{432989} = "Brunn\ an\ der\ Wild";
$areanames{de}->{433112} = "Gleisdorf";
$areanames{de}->{433113} = "Pischelsdorf\ in\ der\ Steiermark";
$areanames{de}->{433114} = "Markt\ Hartmannsdorf";
$areanames{de}->{433115} = "Studenzen";
$areanames{de}->{433116} = "Kirchbach\ in\ Steiermark";
$areanames{de}->{433117} = "Eggersdorf\ bei\ Graz";
$areanames{de}->{433118} = "Sinabelkirchen";
$areanames{de}->{433119} = "Sankt\ Marein\ bei\ Graz";
$areanames{de}->{433123} = "Sankt\ Oswald\ bei\ Plankenwarth";
$areanames{de}->{433124} = "Gratkorn";
$areanames{de}->{433125} = "Übelbach";
$areanames{de}->{433126} = "Frohnleiten";
$areanames{de}->{433127} = "Peggau";
$areanames{de}->{433132} = "Kumberg";
$areanames{de}->{433133} = "Nestelbach";
$areanames{de}->{433134} = "Heiligenkreuz\ am\ Waasen";
$areanames{de}->{433135} = "Kalsdorf\ bei\ Graz";
$areanames{de}->{433136} = "Dobl";
$areanames{de}->{433137} = "Söding";
$areanames{de}->{433140} = "Sankt\ Martin\ am\ Wöllmißberg";
$areanames{de}->{433141} = "Hirschegg";
$areanames{de}->{433142} = "Voitsberg";
$areanames{de}->{433143} = "Krottendorf";
$areanames{de}->{433144} = "Köflach";
$areanames{de}->{433145} = "Edelschrott";
$areanames{de}->{433146} = "Modriach";
$areanames{de}->{433147} = "Salla";
$areanames{de}->{433148} = "Kainach\ bei\ Voitsberg";
$areanames{de}->{433149} = "Geistthal";
$areanames{de}->{433150} = "Paldau";
$areanames{de}->{433151} = "Gnas";
$areanames{de}->{433152} = "Feldbach";
$areanames{de}->{433153} = "Riegersburg";
$areanames{de}->{433155} = "Fehring";
$areanames{de}->{433157} = "Kapfenstein";
$areanames{de}->{433158} = "Sankt\ Anna\ am\ Aigen";
$areanames{de}->{433159} = "Bad\ Gleichenberg";
$areanames{de}->{43316} = "Graz";
$areanames{de}->{433170} = "Fischbach";
$areanames{de}->{433171} = "Gasen";
$areanames{de}->{433172} = "Weiz";
$areanames{de}->{433173} = "Ratten";
$areanames{de}->{433174} = "Birkfeld";
$areanames{de}->{433175} = "Anger";
$areanames{de}->{433176} = "Stubenberg";
$areanames{de}->{433177} = "Puch\ bei\ Weiz";
$areanames{de}->{433178} = "Sankt\ Ruprecht\ an\ der\ Raab";
$areanames{de}->{433179} = "Passail";
$areanames{de}->{433182} = "Wildon";
$areanames{de}->{433183} = "Sankt\ Georgen\ an\ der\ Stiefing";
$areanames{de}->{433184} = "Wolfsberg\ im\ Schwarzautal";
$areanames{de}->{433185} = "Preding";
$areanames{de}->{433322} = "Güssing";
$areanames{de}->{433323} = "Eberau";
$areanames{de}->{433324} = "Strem";
$areanames{de}->{433325} = "Heiligenkreuz\ im\ Lafnitztal";
$areanames{de}->{433326} = "Stegersbach";
$areanames{de}->{433327} = "Sankt\ Michael\ im\ Burgenland";
$areanames{de}->{433328} = "Kukmirn";
$areanames{de}->{433329} = "Jennersdorf";
$areanames{de}->{433331} = "Sankt\ Lorenzen\ am\ Wechsel";
$areanames{de}->{433332} = "Hartberg";
$areanames{de}->{433333} = "Sebersdorf";
$areanames{de}->{433334} = "Kaindorf";
$areanames{de}->{433335} = "Pöllau";
$areanames{de}->{433336} = "Waldbach";
$areanames{de}->{433337} = "Vorau";
$areanames{de}->{433338} = "Lafnitz";
$areanames{de}->{433339} = "Friedberg";
$areanames{de}->{433352} = "Oberwart";
$areanames{de}->{433353} = "Oberschützen";
$areanames{de}->{433354} = "Bernstein";
$areanames{de}->{433355} = "Stadtschlaining";
$areanames{de}->{433356} = "Markt\ Allhau";
$areanames{de}->{433357} = "Pinkafeld";
$areanames{de}->{433358} = "Litzelsdorf";
$areanames{de}->{433359} = "Loipersdorf\-Kitzladen";
$areanames{de}->{433362} = "Großpetersdorf";
$areanames{de}->{433363} = "Rechnitz";
$areanames{de}->{433364} = "Hannersdorf";
$areanames{de}->{433365} = "Deutsch\ Schützen\-Eisenberg";
$areanames{de}->{433366} = "Kohfidisch";
$areanames{de}->{433382} = "Fürstenfeld";
$areanames{de}->{433383} = "Burgau";
$areanames{de}->{433385} = "Ilz";
$areanames{de}->{433386} = "Großsteinbach";
$areanames{de}->{433387} = "Söchau";
$areanames{de}->{433452} = "Leibnitz";
$areanames{de}->{433453} = "Ehrenhausen";
$areanames{de}->{433454} = "Leutschach";
$areanames{de}->{433455} = "Arnfels";
$areanames{de}->{433456} = "Fresing";
$areanames{de}->{433457} = "Gleinstätten";
$areanames{de}->{433460} = "Soboth";
$areanames{de}->{433461} = "Trahütten";
$areanames{de}->{433462} = "Deutschlandsberg";
$areanames{de}->{433463} = "Stainz";
$areanames{de}->{433464} = "Groß\ Sankt\ Florian";
$areanames{de}->{433465} = "Pölfing\-Brunn";
$areanames{de}->{433466} = "Eibiswald";
$areanames{de}->{433467} = "Schwanberg";
$areanames{de}->{433468} = "Sankt\ Oswald\ ob\ Eibiswald";
$areanames{de}->{433469} = "Sankt\ Oswald\ im\ Freiland";
$areanames{de}->{433472} = "Mureck";
$areanames{de}->{433473} = "Straden";
$areanames{de}->{433474} = "Deutsch\ Goritz";
$areanames{de}->{433475} = "Hürth";
$areanames{de}->{433476} = "Bad\ Radkersburg";
$areanames{de}->{433477} = "Sankt\ Peter\ am\ Ottersbach";
$areanames{de}->{433512} = "Knittelfeld";
$areanames{de}->{433513} = "Bischoffeld";
$areanames{de}->{433514} = "Seckau";
$areanames{de}->{433515} = "Sankt\ Lorenzen\ bei\ Knittelfeld";
$areanames{de}->{433516} = "Kleinlobming";
$areanames{de}->{433532} = "Murau";
$areanames{de}->{433533} = "Turrach";
$areanames{de}->{433534} = "Stadl\ an\ der\ Mur";
$areanames{de}->{433535} = "Krakaudorf";
$areanames{de}->{433536} = "Sankt\ Peter\ am\ Kammersberg";
$areanames{de}->{433537} = "Sankt\ Georgen\ ob\ Murau";
$areanames{de}->{433571} = "Möderbrugg";
$areanames{de}->{433572} = "Judenburg";
$areanames{de}->{433573} = "Fohnsdorf";
$areanames{de}->{433574} = "Pusterwald";
$areanames{de}->{433575} = "Sankt\ Johann\ am\ Tauern";
$areanames{de}->{433576} = "Bretstein";
$areanames{de}->{433577} = "Zeltweg";
$areanames{de}->{433578} = "Obdach";
$areanames{de}->{433579} = "Pöls";
$areanames{de}->{433581} = "Oberwölz";
$areanames{de}->{433582} = "Scheifling";
$areanames{de}->{433583} = "Unzmarkt";
$areanames{de}->{433584} = "Neumarkt\ in\ Steiermark";
$areanames{de}->{433585} = "Sankt\ Lambrecht";
$areanames{de}->{433586} = "Mühlen";
$areanames{de}->{433587} = "Schönberg\-Lachtal";
$areanames{de}->{433588} = "Katsch\ an\ der\ Mur";
$areanames{de}->{433611} = "Johnsbach";
$areanames{de}->{433612} = "Liezen";
$areanames{de}->{433613} = "Admont";
$areanames{de}->{433614} = "Rottenmann";
$areanames{de}->{433615} = "Trieben";
$areanames{de}->{433616} = "Selzthal";
$areanames{de}->{433617} = "Gaishorn\ am\ See";
$areanames{de}->{433618} = "Hohentauern";
$areanames{de}->{433619} = "Oppenberg";
$areanames{de}->{433622} = "Bad\ Aussee";
$areanames{de}->{433623} = "Bad\ Mitterndorf";
$areanames{de}->{433624} = "Pichl\-Kainisch";
$areanames{de}->{433631} = "Unterlaussa";
$areanames{de}->{433632} = "Sankt\ Gallen";
$areanames{de}->{433633} = "Landl";
$areanames{de}->{433634} = "Hieflau";
$areanames{de}->{433635} = "Radmer";
$areanames{de}->{433636} = "Wildalpen";
$areanames{de}->{433637} = "Gams\ bei\ Hieflau";
$areanames{de}->{433638} = "Palfau";
$areanames{de}->{433680} = "Donnersbachwald";
$areanames{de}->{433682} = "Stainach";
$areanames{de}->{433683} = "Donnersbach";
$areanames{de}->{433684} = "Sankt\ Martin\ am\ Grimming";
$areanames{de}->{433685} = "Gröbming";
$areanames{de}->{433686} = "Haus";
$areanames{de}->{433687} = "Schladming";
$areanames{de}->{433688} = "Tauplitz";
$areanames{de}->{433689} = "Sankt\ Nikolai\ im\ Sölktal";
$areanames{de}->{433832} = "Kraubath\ an\ der\ Mur";
$areanames{de}->{433833} = "Traboch";
$areanames{de}->{433834} = "Wald\ am\ Schoberpaß";
$areanames{de}->{433842} = "Leoben";
$areanames{de}->{433843} = "Sankt\ Michael\ in\ Obersteiermark";
$areanames{de}->{433844} = "Kammern\ im\ Liesingtal";
$areanames{de}->{433845} = "Mautern\ in\ Steiermark";
$areanames{de}->{433846} = "Kalwang";
$areanames{de}->{433847} = "Trofaiach";
$areanames{de}->{433848} = "Eisenerz";
$areanames{de}->{433849} = "Vordernberg";
$areanames{de}->{433852} = "Mürzzuschlag";
$areanames{de}->{433853} = "Spital\ am\ Semmering";
$areanames{de}->{433854} = "Langenwang";
$areanames{de}->{433855} = "Krieglach";
$areanames{de}->{433856} = "Veitsch";
$areanames{de}->{433857} = "Neuberg\ an\ der\ Mürz";
$areanames{de}->{433858} = "Mitterdorf\ im\ Mürztal";
$areanames{de}->{433859} = "Mürzsteg";
$areanames{de}->{433861} = "Aflenz";
$areanames{de}->{433862} = "Bruck\ an\ der\ Mur";
$areanames{de}->{433863} = "Turnau";
$areanames{de}->{433864} = "Sankt\ Marein\ im\ Mürztal";
$areanames{de}->{433865} = "Kindberg";
$areanames{de}->{433866} = "Breitenau\ am\ Hochlantsch";
$areanames{de}->{433867} = "Pernegg\ an\ der\ Mur";
$areanames{de}->{433868} = "Tragöß";
$areanames{de}->{433869} = "Sankt\ Katharein\ an\ der\ Laming";
$areanames{de}->{433882} = "Mariazell";
$areanames{de}->{433883} = "Terz";
$areanames{de}->{433884} = "Wegscheid";
$areanames{de}->{433885} = "Greith";
$areanames{de}->{433886} = "Weichselboden";
$areanames{de}->{434212} = "Sankt\ Veit\ an\ der\ Glan";
$areanames{de}->{434213} = "Launsdorf";
$areanames{de}->{434214} = "Brückl";
$areanames{de}->{434215} = "Liebenfels";
$areanames{de}->{434220} = "Köttmannsdorf";
$areanames{de}->{434221} = "Gallizien";
$areanames{de}->{434223} = "Maria\ Saal";
$areanames{de}->{434224} = "Pischeldorf";
$areanames{de}->{434225} = "Grafenstein";
$areanames{de}->{434226} = "Sankt\ Margareten\ im\ Rosental";
$areanames{de}->{434227} = "Ferlach";
$areanames{de}->{434228} = "Feistritz\ im\ Rosental";
$areanames{de}->{434229} = "Krumpendorf\ am\ Wörther\ See";
$areanames{de}->{434230} = "Globasnitz";
$areanames{de}->{434231} = "Mittertrixen";
$areanames{de}->{434232} = "Völkermarkt";
$areanames{de}->{434233} = "Griffen";
$areanames{de}->{434234} = "Ruden";
$areanames{de}->{434235} = "Bleiburg";
$areanames{de}->{434236} = "Eberndorf";
$areanames{de}->{434237} = "Miklauzhof";
$areanames{de}->{434238} = "Eisenkappel\-Vellach";
$areanames{de}->{434239} = "Sankt\ Kanzian\ am\ Klopeiner\ See";
$areanames{de}->{434240} = "Bad\ Kleinkirchheim";
$areanames{de}->{434242} = "Villach";
$areanames{de}->{434243} = "Bodensdorf";
$areanames{de}->{434244} = "Bad\ Bleiberg";
$areanames{de}->{434245} = "Feistritz\ an\ der\ Drau";
$areanames{de}->{434246} = "Radenthein";
$areanames{de}->{434247} = "Afritz";
$areanames{de}->{434248} = "Treffen";
$areanames{de}->{434252} = "Wernberg";
$areanames{de}->{434253} = "Sankt\ Jakob\ im\ Rosental";
$areanames{de}->{434254} = "Faak\ am\ See";
$areanames{de}->{434255} = "Arnoldstein";
$areanames{de}->{434256} = "Nötsch\ im\ Gailtal";
$areanames{de}->{434257} = "Fürnitz";
$areanames{de}->{434258} = "Gummern";
$areanames{de}->{434262} = "Treibach";
$areanames{de}->{434263} = "Hüttenberg";
$areanames{de}->{434264} = "Klein\ Sankt\ Paul";
$areanames{de}->{434265} = "Weitensfeld\ im\ Gurktal";
$areanames{de}->{434266} = "Straßburg";
$areanames{de}->{434267} = "Metnitz";
$areanames{de}->{434268} = "Friesach";
$areanames{de}->{434269} = "Flattnitz";
$areanames{de}->{434271} = "Steuerberg";
$areanames{de}->{434272} = "Pörtschach\ am\ Wörther\ See";
$areanames{de}->{434273} = "Reifnitz";
$areanames{de}->{434274} = "Velden\ am\ Wörther\ See";
$areanames{de}->{434275} = "Ebene\ Reichenau";
$areanames{de}->{434276} = "Feldkirchen\ in\ Kärnten";
$areanames{de}->{434277} = "Glanegg";
$areanames{de}->{434278} = "Gnesau";
$areanames{de}->{434279} = "Sirnitz";
$areanames{de}->{434282} = "Hermagor";
$areanames{de}->{434283} = "Sankt\ Stefan\ im\ Gailtal";
$areanames{de}->{434284} = "Kirchbach";
$areanames{de}->{434285} = "Tröpolach";
$areanames{de}->{434286} = "Weißbriach";
$areanames{de}->{434350} = "Bad\ Sankt\ Leonhard\ im\ Lavanttal";
$areanames{de}->{434352} = "Wolfsberg";
$areanames{de}->{434353} = "Prebl";
$areanames{de}->{434354} = "Preitenegg";
$areanames{de}->{434355} = "Gemmersdorf";
$areanames{de}->{434356} = "Lavamünd";
$areanames{de}->{434357} = "Sankt\ Paul\ im\ Lavanttal";
$areanames{de}->{434358} = "Sankt\ Andrä";
$areanames{de}->{434359} = "Reichenfels";
$areanames{de}->{4346} = "Klagenfurt";
$areanames{de}->{434710} = "Oberdrauburg";
$areanames{de}->{434712} = "Greifenburg";
$areanames{de}->{434713} = "Techendorf";
$areanames{de}->{434714} = "Dellach\ im\ Drautal";
$areanames{de}->{434715} = "Kötschach\-Mauthen";
$areanames{de}->{434716} = "Lesachtal";
$areanames{de}->{434717} = "Steinfeld";
$areanames{de}->{434718} = "Dellach";
$areanames{de}->{434732} = "Gmünd\ in\ Kärnten";
$areanames{de}->{434733} = "Malta";
$areanames{de}->{434734} = "Rennweg";
$areanames{de}->{434735} = "Kremsbrücke";
$areanames{de}->{434736} = "Innerkrems";
$areanames{de}->{434761} = "Stockenboi";
$areanames{de}->{434762} = "Spittal\ an\ der\ Drau";
$areanames{de}->{434766} = "Millstatt";
$areanames{de}->{434767} = "Rothenthurn";
$areanames{de}->{434768} = "Kleblach\-Lind";
$areanames{de}->{434769} = "Möllbrücke";
$areanames{de}->{434782} = "Obervellach";
$areanames{de}->{434783} = "Reißeck";
$areanames{de}->{434784} = "Mallnitz";
$areanames{de}->{434785} = "Außerfragant";
$areanames{de}->{434822} = "Winklern";
$areanames{de}->{434823} = "Tresdorf\,\ Rangersdorf";
$areanames{de}->{434824} = "Heiligenblut";
$areanames{de}->{434825} = "Großkirchheim";
$areanames{de}->{434826} = "Mörtschach";
$areanames{de}->{434842} = "Sillian";
$areanames{de}->{434843} = "Außervillgraten";
$areanames{de}->{434846} = "Abfaltersbach";
$areanames{de}->{434847} = "Obertilliach";
$areanames{de}->{434848} = "Kartitsch";
$areanames{de}->{434852} = "Lienz";
$areanames{de}->{434853} = "Ainet";
$areanames{de}->{434855} = "Assling";
$areanames{de}->{434858} = "Nikolsdorf";
$areanames{de}->{434872} = "Huben";
$areanames{de}->{434873} = "Sankt\ Jakob\ in\ Defereggen";
$areanames{de}->{434874} = "Virgen";
$areanames{de}->{434875} = "Matrei\ in\ Osttirol";
$areanames{de}->{434876} = "Kals\ am\ Großglockner";
$areanames{de}->{434877} = "Prägraten\ am\ Großvenediger";
$areanames{de}->{434879} = "Sankt\ Veit\ in\ Defereggen";
$areanames{de}->{43512} = "Innsbruck";
$areanames{de}->{435212} = "Seefeld\ in\ Tirol";
$areanames{de}->{435213} = "Scharnitz";
$areanames{de}->{435214} = "Leutasch";
$areanames{de}->{435223} = "Hall\ in\ Tirol";
$areanames{de}->{435224} = "Wattens";
$areanames{de}->{435225} = "Fulpmes";
$areanames{de}->{435226} = "Neustift\ im\ Stubaital";
$areanames{de}->{435230} = "Sellrain";
$areanames{de}->{435232} = "Kematen\ in\ Tirol";
$areanames{de}->{435234} = "Axams";
$areanames{de}->{435236} = "Gries\ im\ Sellrain";
$areanames{de}->{435238} = "Zirl";
$areanames{de}->{435239} = "Kühtai";
$areanames{de}->{435242} = "Schwaz";
$areanames{de}->{435243} = "Maurach";
$areanames{de}->{435244} = "Jenbach";
$areanames{de}->{435245} = "Hinterriß";
$areanames{de}->{435246} = "Achenkirch";
$areanames{de}->{435248} = "Steinberg\ am\ Rofan";
$areanames{de}->{435252} = "Oetz";
$areanames{de}->{435253} = "Längenfeld";
$areanames{de}->{435254} = "Sölden";
$areanames{de}->{435255} = "Umhausen";
$areanames{de}->{435256} = "Untergurgl";
$areanames{de}->{435262} = "Telfs";
$areanames{de}->{435263} = "Silz";
$areanames{de}->{435264} = "Mieming";
$areanames{de}->{435265} = "Nassereith";
$areanames{de}->{435266} = "Ötztal\-Bahnhof";
$areanames{de}->{435272} = "Steinach\ am\ Brenner";
$areanames{de}->{435273} = "Matrei\ am\ Brenner";
$areanames{de}->{435274} = "Gries\ am\ Brenner";
$areanames{de}->{435275} = "Trins";
$areanames{de}->{435276} = "Gschnitz";
$areanames{de}->{435278} = "Navis";
$areanames{de}->{435279} = "Sankt\ Jodok\ am\ Brenner";
$areanames{de}->{435280} = "Hochfügen";
$areanames{de}->{435282} = "Zell\ am\ Ziller";
$areanames{de}->{435283} = "Kaltenbach";
$areanames{de}->{435284} = "Gerlos";
$areanames{de}->{435285} = "Mayrhofen";
$areanames{de}->{435286} = "Ginzling";
$areanames{de}->{435287} = "Tux";
$areanames{de}->{435288} = "Fügen";
$areanames{de}->{435289} = "Häusling";
$areanames{de}->{435331} = "Brandenberg";
$areanames{de}->{435332} = "Wörgl";
$areanames{de}->{435333} = "Söll";
$areanames{de}->{435334} = "Westendorf";
$areanames{de}->{435335} = "Hopfgarten\ im\ Brixental";
$areanames{de}->{435336} = "Alpbach";
$areanames{de}->{435337} = "Brixlegg";
$areanames{de}->{435338} = "Kundl";
$areanames{de}->{435339} = "Wildschönau";
$areanames{de}->{435352} = "Sankt\ Johann\ in\ Tirol";
$areanames{de}->{435353} = "Waidring";
$areanames{de}->{435354} = "Fieberbrunn";
$areanames{de}->{435355} = "Jochberg";
$areanames{de}->{435356} = "Kitzbühel";
$areanames{de}->{435357} = "Kirchberg\ in\ Tirol";
$areanames{de}->{435358} = "Ellmau";
$areanames{de}->{435359} = "Hochfilzen";
$areanames{de}->{435372} = "Kufstein";
$areanames{de}->{435373} = "Ebbs";
$areanames{de}->{435374} = "Walchsee";
$areanames{de}->{435375} = "Kössen";
$areanames{de}->{435376} = "Thiersee";
$areanames{de}->{435412} = "Imst";
$areanames{de}->{435413} = "Sankt\ Leonhard\ im\ Pitztal";
$areanames{de}->{435414} = "Wenns";
$areanames{de}->{435417} = "Roppen";
$areanames{de}->{435418} = "Schönwies";
$areanames{de}->{435441} = "See";
$areanames{de}->{435442} = "Landeck";
$areanames{de}->{435443} = "Galtür";
$areanames{de}->{435444} = "Ischgl";
$areanames{de}->{435445} = "Kappl";
$areanames{de}->{435446} = "Sankt\ Anton\ am\ Arlberg";
$areanames{de}->{435447} = "Flirsch";
$areanames{de}->{435448} = "Pettneu\ am\ Arlberg";
$areanames{de}->{435449} = "Fließ";
$areanames{de}->{435472} = "Prutz";
$areanames{de}->{435473} = "Nauders";
$areanames{de}->{435474} = "Pfunds";
$areanames{de}->{435475} = "Feichten";
$areanames{de}->{435476} = "Serfaus";
$areanames{de}->{435477} = "Tösens";
$areanames{de}->{435510} = "Damüls";
$areanames{de}->{435512} = "Egg";
$areanames{de}->{435513} = "Hittisau";
$areanames{de}->{435514} = "Bezau";
$areanames{de}->{435515} = "Au";
$areanames{de}->{435516} = "Doren";
$areanames{de}->{435517} = "Riezlern";
$areanames{de}->{435518} = "Mellau";
$areanames{de}->{435519} = "Schröcken";
$areanames{de}->{435522} = "Feldkirch";
$areanames{de}->{435523} = "Götzis";
$areanames{de}->{435524} = "Satteins";
$areanames{de}->{435525} = "Nenzing";
$areanames{de}->{435526} = "Laterns";
$areanames{de}->{435550} = "Thüringen";
$areanames{de}->{435552} = "Bludenz";
$areanames{de}->{435553} = "Raggal";
$areanames{de}->{435554} = "Sonntag";
$areanames{de}->{435556} = "Schruns";
$areanames{de}->{435557} = "Sankt\ Gallenkirch";
$areanames{de}->{435558} = "Gaschurn";
$areanames{de}->{435559} = "Brand";
$areanames{de}->{435572} = "Dornbirn";
$areanames{de}->{435573} = "Hörbranz";
$areanames{de}->{435574} = "Bregenz";
$areanames{de}->{435575} = "Langen\ bei\ Bregenz";
$areanames{de}->{435576} = "Hohenems";
$areanames{de}->{435577} = "Lustenau";
$areanames{de}->{435578} = "Höchst";
$areanames{de}->{435579} = "Alberschwende";
$areanames{de}->{435582} = "Klösterle";
$areanames{de}->{435583} = "Lech";
$areanames{de}->{435585} = "Dalaas";
$areanames{de}->{435632} = "Stanzach";
$areanames{de}->{435633} = "Hägerau";
$areanames{de}->{435634} = "Elbigenalp";
$areanames{de}->{435635} = "Elmen";
$areanames{de}->{435672} = "Reutte";
$areanames{de}->{435673} = "Ehrwald";
$areanames{de}->{435674} = "Bichlbach";
$areanames{de}->{435675} = "Tannheim";
$areanames{de}->{435676} = "Jungholz";
$areanames{de}->{435677} = "Vils";
$areanames{de}->{435678} = "Weißenbach\ am\ Lech";
$areanames{de}->{436131} = "Obertraun";
$areanames{de}->{436132} = "Bad\ Ischl";
$areanames{de}->{436133} = "Ebensee";
$areanames{de}->{436134} = "Hallstatt";
$areanames{de}->{436135} = "Bad\ Goisern";
$areanames{de}->{436136} = "Gosau";
$areanames{de}->{436137} = "Strobl";
$areanames{de}->{436138} = "Sankt\ Wolfgang\ im\ Salzkammergut";
$areanames{de}->{436212} = "Seekirchen\ am\ Wallersee";
$areanames{de}->{436213} = "Oberhofen\ am\ Irrsee";
$areanames{de}->{436214} = "Henndorf\ am\ Wallersee";
$areanames{de}->{436215} = "Straßwalchen";
$areanames{de}->{436216} = "Neumarkt\ am\ Wallersee";
$areanames{de}->{436217} = "Mattsee";
$areanames{de}->{436219} = "Obertrum\ am\ See";
$areanames{de}->{436221} = "Koppl";
$areanames{de}->{436223} = "Anthering";
$areanames{de}->{436224} = "Hintersee";
$areanames{de}->{436225} = "Eugendorf";
$areanames{de}->{436226} = "Fuschl\ am\ See";
$areanames{de}->{436227} = "Sankt\ Gilgen";
$areanames{de}->{436228} = "Faistenau";
$areanames{de}->{436229} = "Hof\ bei\ Salzburg";
$areanames{de}->{436232} = "Mondsee";
$areanames{de}->{436233} = "Oberwang";
$areanames{de}->{436234} = "Zell\ am\ Moos";
$areanames{de}->{436235} = "Thalgau";
$areanames{de}->{436240} = "Krispl";
$areanames{de}->{436241} = "Sankt\ Koloman";
$areanames{de}->{436242} = "Rußbach\ am\ Paß\ Gschütt";
$areanames{de}->{436243} = "Abtenau";
$areanames{de}->{436244} = "Golling\ an\ der\ Salzach";
$areanames{de}->{436245} = "Hallein";
$areanames{de}->{436246} = "Grödig";
$areanames{de}->{436247} = "Großgmain";
$areanames{de}->{436272} = "Oberndorf\ bei\ Salzburg";
$areanames{de}->{436274} = "Lamprechtshausen";
$areanames{de}->{436276} = "Nußdorf\ am\ Haunsberg";
$areanames{de}->{436277} = "Sankt\ Pantaleon";
$areanames{de}->{436278} = "Ostermiething";
$areanames{de}->{436412} = "Sankt\ Johann\ im\ Pongau";
$areanames{de}->{436413} = "Wagrain";
$areanames{de}->{436414} = "Großarl";
$areanames{de}->{436415} = "Schwarzach\ im\ Pongau";
$areanames{de}->{436416} = "Lend";
$areanames{de}->{436417} = "Hüttschlag";
$areanames{de}->{436418} = "Kleinarl";
$areanames{de}->{436432} = "Bad\ Hofgastein";
$areanames{de}->{436433} = "Dorfgastein";
$areanames{de}->{436434} = "Bad\ Gastein";
$areanames{de}->{436452} = "Radstadt";
$areanames{de}->{436453} = "Filzmoos";
$areanames{de}->{436454} = "Mandling";
$areanames{de}->{436455} = "Untertauern";
$areanames{de}->{436456} = "Obertauern";
$areanames{de}->{436457} = "Flachau";
$areanames{de}->{436458} = "Hüttau";
$areanames{de}->{436461} = "Dienten\ am\ Hochkönig";
$areanames{de}->{436462} = "Bischofshofen";
$areanames{de}->{436463} = "Annaberg\-Lungötz";
$areanames{de}->{436466} = "Werfenweng";
$areanames{de}->{436467} = "Mühlbach\ am\ Hochkönig";
$areanames{de}->{436468} = "Werfen";
$areanames{de}->{436470} = "Atzmannsdorf";
$areanames{de}->{436471} = "Tweng";
$areanames{de}->{436472} = "Mauterndorf";
$areanames{de}->{436473} = "Mariapfarr";
$areanames{de}->{436474} = "Tamsweg";
$areanames{de}->{436475} = "Ramingstein";
$areanames{de}->{436476} = "Sankt\ Margarethen\ im\ Lungau";
$areanames{de}->{436477} = "Sankt\ Michael\ im\ Lungau";
$areanames{de}->{436478} = "Zederhaus";
$areanames{de}->{436479} = "Muhr";
$areanames{de}->{436483} = "Göriach";
$areanames{de}->{436484} = "Lessach";
$areanames{de}->{436541} = "Saalbach";
$areanames{de}->{436542} = "Zell\ am\ See";
$areanames{de}->{436543} = "Taxenbach";
$areanames{de}->{436544} = "Rauris";
$areanames{de}->{436545} = "Bruck\ an\ der\ Großglocknerstraße";
$areanames{de}->{436546} = "Fusch\ an\ der\ Großglocknerstraße";
$areanames{de}->{436547} = "Kaprun";
$areanames{de}->{436548} = "Niedernsill";
$areanames{de}->{436549} = "Piesendorf";
$areanames{de}->{436562} = "Mittersill";
$areanames{de}->{436563} = "Uttendorf";
$areanames{de}->{436564} = "Krimml";
$areanames{de}->{436565} = "Neukirchen\ am\ Großvenediger";
$areanames{de}->{436566} = "Bramberg\ am\ Wildkogel";
$areanames{de}->{436582} = "Saalfelden\ am\ Steinernen\ Meer";
$areanames{de}->{436583} = "Leogang";
$areanames{de}->{436584} = "Maria\ Alm\ am\ Steinernen\ Meer";
$areanames{de}->{436588} = "Lofer";
$areanames{de}->{436589} = "Unken";
$areanames{de}->{43662} = "Salzburg";
$areanames{de}->{437211} = "Reichenau\ im\ Mühlkreis";
$areanames{de}->{437212} = "Zwettl\ an\ der\ Rodl";
$areanames{de}->{437213} = "Bad\ Leonfelden";
$areanames{de}->{437214} = "Reichenthal";
$areanames{de}->{437215} = "Hellmonsödt";
$areanames{de}->{437216} = "Helfenberg";
$areanames{de}->{437217} = "Sankt\ Veit\ im\ Mühlkreis";
$areanames{de}->{437218} = "Großtraberg";
$areanames{de}->{437219} = "Vorderweißenbach";
$areanames{de}->{437221} = "Hörsching";
$areanames{de}->{437223} = "Enns";
$areanames{de}->{437224} = "Sankt\ Florian";
$areanames{de}->{437225} = "Hargelsberg";
$areanames{de}->{437226} = "Wilhering";
$areanames{de}->{437227} = "Neuhofen\ an\ der\ Krems";
$areanames{de}->{437228} = "Kematen\ an\ der\ Krems";
$areanames{de}->{437229} = "Traun";
$areanames{de}->{437230} = "Altenberg\ bei\ Linz";
$areanames{de}->{437231} = "Herzogsdorf";
$areanames{de}->{437232} = "Sankt\ Martin\ im\ Mühlkreis";
$areanames{de}->{437233} = "Feldkirchen\ an\ der\ Donau";
$areanames{de}->{437234} = "Ottensheim";
$areanames{de}->{437235} = "Gallneukirchen";
$areanames{de}->{437236} = "Pregarten";
$areanames{de}->{437237} = "Sankt\ Georgen\ an\ der\ Gusen";
$areanames{de}->{437238} = "Mauthausen";
$areanames{de}->{437239} = "Lichtenberg";
$areanames{de}->{437240} = "Sipbachzell";
$areanames{de}->{437241} = "Steinerkirchen\ an\ der\ Traun";
$areanames{de}->{437242} = "Wels";
$areanames{de}->{437243} = "Marchtrenk";
$areanames{de}->{437244} = "Sattledt";
$areanames{de}->{437245} = "Lambach";
$areanames{de}->{437246} = "Gunskirchen";
$areanames{de}->{437247} = "Kematen\ am\ Innbach";
$areanames{de}->{437248} = "Grieskirchen";
$areanames{de}->{437249} = "Bad\ Schallerbach";
$areanames{de}->{437250} = "Maria\ Neustift";
$areanames{de}->{437251} = "Schiedlberg";
$areanames{de}->{437252} = "Steyr";
$areanames{de}->{437253} = "Wolfern";
$areanames{de}->{437254} = "Großraming";
$areanames{de}->{437255} = "Losenstein";
$areanames{de}->{437256} = "Ternberg";
$areanames{de}->{437257} = "Grünburg";
$areanames{de}->{437258} = "Bad\ Hall";
$areanames{de}->{437259} = "Sierning";
$areanames{de}->{437260} = "Waldhausen";
$areanames{de}->{437261} = "Schönau\ im\ Mühlkreis";
$areanames{de}->{437262} = "Perg";
$areanames{de}->{437263} = "Bad\ Zell";
$areanames{de}->{437264} = "Windhaag\ bei\ Perg";
$areanames{de}->{437265} = "Pabneukirchen";
$areanames{de}->{437266} = "Bad\ Kreuzen";
$areanames{de}->{437267} = "Mönchdorf";
$areanames{de}->{437268} = "Grein";
$areanames{de}->{437269} = "Baumgartenberg";
$areanames{de}->{437272} = "Eferding";
$areanames{de}->{437273} = "Aschach\ an\ der\ Donau";
$areanames{de}->{437274} = "Alkoven";
$areanames{de}->{437276} = "Peuerbach";
$areanames{de}->{437277} = "Waizenkirchen";
$areanames{de}->{437278} = "Neukirchen\ am\ Walde";
$areanames{de}->{437279} = "Haibach\ ob\ der\ Donau";
$areanames{de}->{437280} = "Schwarzenberg\ am\ Böhmerwald";
$areanames{de}->{437281} = "Aigen\ im\ Mühlkreis";
$areanames{de}->{437282} = "Neufelden";
$areanames{de}->{437283} = "Sarleinsbach";
$areanames{de}->{437284} = "Oberkappel";
$areanames{de}->{437285} = "Hofkirchen\ im\ Mühlkreis";
$areanames{de}->{437286} = "Lembach\ im\ Mühlkreis";
$areanames{de}->{437287} = "Peilstein\ im\ Mühlviertel";
$areanames{de}->{437288} = "Ulrichsberg";
$areanames{de}->{437289} = "Rohrbach\ in\ Oberösterreich";
$areanames{de}->{43732} = "Linz";
$areanames{de}->{437353} = "Gaflenz";
$areanames{de}->{437355} = "Weyer";
$areanames{de}->{437357} = "Kleinreifling";
$areanames{de}->{437412} = "Ybbs\ an\ der\ Donau";
$areanames{de}->{437413} = "Marbach\ an\ der\ Donau";
$areanames{de}->{437414} = "Weins\-Isperdorf";
$areanames{de}->{437415} = "Altenmarkt\,\ Yspertal";
$areanames{de}->{437416} = "Wieselburg";
$areanames{de}->{437432} = "Strengberg";
$areanames{de}->{437433} = "Wallsee";
$areanames{de}->{437434} = "Haag";
$areanames{de}->{437435} = "Sankt\ Valentin";
$areanames{de}->{437442} = "Waidhofen\ an\ der\ Ybbs";
$areanames{de}->{437443} = "Ybbsitz";
$areanames{de}->{437444} = "Opponitz";
$areanames{de}->{437445} = "Hollenstein\ an\ der\ Ybbs";
$areanames{de}->{437448} = "Kematen\ an\ der\ Ybbs";
$areanames{de}->{437471} = "Neustadtl\ an\ der\ Donau";
$areanames{de}->{437472} = "Amstetten";
$areanames{de}->{437473} = "Blindenmarkt";
$areanames{de}->{437474} = "Euratsfeld";
$areanames{de}->{437475} = "Hausmening\,\ Neuhofen\ an\ der\ Ybbs";
$areanames{de}->{437476} = "Aschbach\-Markt";
$areanames{de}->{437477} = "Sankt\ Peter\ in\ der\ Au";
$areanames{de}->{437478} = "Oed\-Oehling";
$areanames{de}->{437479} = "Ardagger";
$areanames{de}->{437480} = "Langau\,\ Gaming";
$areanames{de}->{437482} = "Scheibbs";
$areanames{de}->{437483} = "Oberndorf\ an\ der\ Melk";
$areanames{de}->{437484} = "Göstling\ an\ der\ Ybbs";
$areanames{de}->{437485} = "Gaming";
$areanames{de}->{437486} = "Lunz\ am\ See";
$areanames{de}->{437487} = "Gresten";
$areanames{de}->{437488} = "Steinakirchen\ am\ Forst";
$areanames{de}->{437489} = "Purgstall\ an\ der\ Erlauf";
$areanames{de}->{437562} = "Windischgarsten";
$areanames{de}->{437563} = "Spital\ am\ Pyhrn";
$areanames{de}->{437564} = "Hinterstoder";
$areanames{de}->{437565} = "Sankt\ Pankraz";
$areanames{de}->{437566} = "Rosenau\ am\ Hengstpaß";
$areanames{de}->{437582} = "Kirchdorf\ an\ der\ Krems";
$areanames{de}->{437583} = "Kremsmünster";
$areanames{de}->{437584} = "Molln";
$areanames{de}->{437585} = "Klaus\ an\ der\ Pyhrnbahn";
$areanames{de}->{437586} = "Pettenbach";
$areanames{de}->{437587} = "Wartberg\ an\ der\ Krems";
$areanames{de}->{437588} = "Ried\ im\ Traunkreis";
$areanames{de}->{437612} = "Gmunden";
$areanames{de}->{437613} = "Laakirchen";
$areanames{de}->{437614} = "Vorchdorf";
$areanames{de}->{437615} = "Scharnstein";
$areanames{de}->{437616} = "Grünau\ im\ Almtal";
$areanames{de}->{437617} = "Traunkirchen";
$areanames{de}->{437618} = "Neukirchen\,\ Altmünster";
$areanames{de}->{437619} = "Kirchham";
$areanames{de}->{437662} = "Seewalchen\ am\ Attersee";
$areanames{de}->{437663} = "Steinbach\ am\ Attersee";
$areanames{de}->{437664} = "Weyregg\ am\ Attersee";
$areanames{de}->{437665} = "Unterach\ am\ Attersee";
$areanames{de}->{437666} = "Attersee";
$areanames{de}->{437667} = "Sankt\ Georgen\ im\ Attergau";
$areanames{de}->{437672} = "Vöcklabruck";
$areanames{de}->{437673} = "Schwanenstadt";
$areanames{de}->{437674} = "Attnang\-Puchheim";
$areanames{de}->{437675} = "Ampflwang\ im\ Hausruckwald";
$areanames{de}->{437676} = "Ottnang\ am\ Hausruck";
$areanames{de}->{437682} = "Vöcklamarkt";
$areanames{de}->{437683} = "Frankenburg\ am\ Hausruck";
$areanames{de}->{437684} = "Frankenmarkt";
$areanames{de}->{437711} = "Suben";
$areanames{de}->{437712} = "Schärding";
$areanames{de}->{437713} = "Schardenberg";
$areanames{de}->{437714} = "Esternberg";
$areanames{de}->{437716} = "Münzkirchen";
$areanames{de}->{437717} = "Sankt\ Aegidi";
$areanames{de}->{437718} = "Waldkirchen\ am\ Wesen";
$areanames{de}->{437719} = "Taufkirchen\ an\ der\ Pram";
$areanames{de}->{437722} = "Braunau\ am\ Inn";
$areanames{de}->{437723} = "Altheim";
$areanames{de}->{437724} = "Mauerkirchen";
$areanames{de}->{437727} = "Ach";
$areanames{de}->{437728} = "Schwand\ im\ Innkreis";
$areanames{de}->{437729} = "Neukirchen\ an\ der\ Enknach";
$areanames{de}->{437732} = "Haag\ am\ Hausruck";
$areanames{de}->{437733} = "Neumarkt\ im\ Hausruckkreis";
$areanames{de}->{437734} = "Hofkirchen\ an\ der\ Trattnach";
$areanames{de}->{437735} = "Gaspoltshofen";
$areanames{de}->{437736} = "Pram";
$areanames{de}->{437742} = "Mattighofen";
$areanames{de}->{437743} = "Maria\ Schmolln";
$areanames{de}->{437744} = "Munderfing";
$areanames{de}->{437745} = "Lochen";
$areanames{de}->{437746} = "Friedburg";
$areanames{de}->{437747} = "Kirchberg\ bei\ Mattighofen";
$areanames{de}->{437748} = "Eggelsberg";
$areanames{de}->{437750} = "Andrichsfurt";
$areanames{de}->{437751} = "Sankt\ Martin\ im\ Innkreis";
$areanames{de}->{437752} = "Ried\ im\ Innkreis";
$areanames{de}->{437753} = "Eberschwang";
$areanames{de}->{437754} = "Waldzell";
$areanames{de}->{437755} = "Mettmach";
$areanames{de}->{437757} = "Gurten";
$areanames{de}->{437758} = "Obernberg\ am\ Inn";
$areanames{de}->{437759} = "Antiesenhofen";
$areanames{de}->{437762} = "Raab";
$areanames{de}->{437763} = "Kopfing\ im\ Innkreis";
$areanames{de}->{437764} = "Riedau";
$areanames{de}->{437765} = "Lambrechten";
$areanames{de}->{437766} = "Andorf";
$areanames{de}->{437767} = "Eggerding";
$areanames{de}->{437941} = "Neumarkt\ im\ Mühlkreis";
$areanames{de}->{437942} = "Freistadt";
$areanames{de}->{437943} = "Windhaag\ bei\ Freistadt";
$areanames{de}->{437944} = "Sandl";
$areanames{de}->{437945} = "Sankt\ Oswald\ bei\ Freistadt";
$areanames{de}->{437946} = "Gutau";
$areanames{de}->{437947} = "Kefermarkt";
$areanames{de}->{437948} = "Hirschbach\ im\ Mühlkreis";
$areanames{de}->{437949} = "Rainbach\ im\ Mühlkreis";
$areanames{de}->{437952} = "Weitersfelden";
$areanames{de}->{437953} = "Liebenau";
$areanames{de}->{437954} = "Sankt\ Georgen\ am\ Walde";
$areanames{de}->{437955} = "Königswiesen";
$areanames{de}->{437956} = "Unterweißenbach";
$areanames{en}->{4312} = "Vienna";
$areanames{en}->{4313} = "Vienna";
$areanames{en}->{4314} = "Vienna";
$areanames{en}->{4315} = "Vienna";
$areanames{en}->{4316} = "Vienna";
$areanames{en}->{4317} = "Vienna";
$areanames{en}->{4318} = "Vienna";
$areanames{en}->{4319} = "Vienna";
$areanames{en}->{432142} = "Gattendorf";
$areanames{en}->{432143} = "Kittsee";
$areanames{en}->{432144} = "Deutsch\ Jahrndorf";
$areanames{en}->{432145} = "Prellenkirchen";
$areanames{en}->{432146} = "Nickelsdorf";
$areanames{en}->{432147} = "Zurndorf";
$areanames{en}->{432160} = "Jois";
$areanames{en}->{432162} = "Bruck\ an\ der\ Leitha";
$areanames{en}->{432163} = "Petronell\-Carnuntum";
$areanames{en}->{432164} = "Rohrau";
$areanames{en}->{432165} = "Hainburg\ a\.d\.\ Donau";
$areanames{en}->{432166} = "Parndorf";
$areanames{en}->{432167} = "Neusiedl\ am\ See";
$areanames{en}->{432168} = "Mannersdorf\ am\ Leithagebirge";
$areanames{en}->{432169} = "Trautmannsdorf\ an\ der\ Leitha";
$areanames{en}->{432172} = "Frauenkirchen";
$areanames{en}->{432173} = "Gols";
$areanames{en}->{432174} = "Wallern\ im\ Burgenland";
$areanames{en}->{432175} = "Apetlon";
$areanames{en}->{432176} = "Tadten";
$areanames{en}->{432177} = "Podersdorf\ am\ See";
$areanames{en}->{432212} = "Orth\ an\ der\ Donau";
$areanames{en}->{432213} = "Lassee";
$areanames{en}->{432214} = "Kopfstetten";
$areanames{en}->{432215} = "Probstdorf";
$areanames{en}->{432216} = "Leopoldsdorf\ im\ Marchfelde";
$areanames{en}->{432230} = "Schwadorf";
$areanames{en}->{432231} = "Purkersdorf";
$areanames{en}->{432232} = "Fischamend";
$areanames{en}->{432233} = "Pressbaum";
$areanames{en}->{432234} = "Gramatneusiedl";
$areanames{en}->{432235} = "Maria\-Lanzendorf";
$areanames{en}->{432236} = "Mödling";
$areanames{en}->{432237} = "Gaaden";
$areanames{en}->{432238} = "Kaltenleutgeben";
$areanames{en}->{432239} = "Breitenfurt\ bei\ Wien";
$areanames{en}->{432242} = "St\.\ Andrä\-Wördern";
$areanames{en}->{432243} = "Klosterneuburg";
$areanames{en}->{432244} = "Langenzersdorf";
$areanames{en}->{432245} = "Wolkersdorf\ im\ Weinviertel";
$areanames{en}->{432246} = "Gerasdorf\ bei\ Wien";
$areanames{en}->{432247} = "Deutsch\-Wagram";
$areanames{en}->{432248} = "Markgrafneusiedl";
$areanames{en}->{432249} = "Gross\-Enzersdorf";
$areanames{en}->{432252} = "Baden";
$areanames{en}->{432253} = "Oberwaltersdorf";
$areanames{en}->{432254} = "Ebreichsdorf";
$areanames{en}->{432255} = "Deutsch\ Brodersdorf";
$areanames{en}->{432256} = "Leobersdorf";
$areanames{en}->{432257} = "Klausen\-Leopoldsdorf";
$areanames{en}->{432258} = "Alland";
$areanames{en}->{432259} = "Münchendorf";
$areanames{en}->{432262} = "Korneuburg";
$areanames{en}->{432263} = "Grossrussbach";
$areanames{en}->{432264} = "Rückersdorf\,\ Harmannsdorf";
$areanames{en}->{432265} = "Hausleiten";
$areanames{en}->{432266} = "Stockerau";
$areanames{en}->{432267} = "Sierndorf";
$areanames{en}->{432268} = "Grossmugl";
$areanames{en}->{432269} = "Niederfellabrunn";
$areanames{en}->{432271} = "Ried\ am\ Riederberg";
$areanames{en}->{432272} = "Tulln\ an\ der\ Donau";
$areanames{en}->{432273} = "Tulbing";
$areanames{en}->{432274} = "Sieghartskirchen";
$areanames{en}->{432275} = "Atzenbrugg";
$areanames{en}->{432276} = "Reidling";
$areanames{en}->{432277} = "Zwentendorf";
$areanames{en}->{432278} = "Absdorf";
$areanames{en}->{432279} = "Kirchberg\ am\ Wagram";
$areanames{en}->{432282} = "Gänserndorf";
$areanames{en}->{432283} = "Angern\ an\ der\ March";
$areanames{en}->{432284} = "Oberweiden";
$areanames{en}->{432285} = "Marchegg";
$areanames{en}->{432286} = "Obersiebenbrunn";
$areanames{en}->{432287} = "Strasshof\ an\ der\ Nordbahn";
$areanames{en}->{432288} = "Auersthal";
$areanames{en}->{432289} = "Matzen";
$areanames{en}->{432522} = "Laa\ an\ der\ Thaya";
$areanames{en}->{432523} = "Kirchstetten\,\ Neudorf\ bei\ Staatz";
$areanames{en}->{432524} = "Kautendorf";
$areanames{en}->{432525} = "Gnadendorf";
$areanames{en}->{432526} = "Stronsdorf";
$areanames{en}->{432527} = "Wulzeshofen";
$areanames{en}->{432532} = "Zistersdorf";
$areanames{en}->{432533} = "Neusiedl\ an\ der\ Zaya";
$areanames{en}->{432534} = "Niedersulz";
$areanames{en}->{432535} = "Hohenau\ an\ der\ March";
$areanames{en}->{432536} = "Drösing";
$areanames{en}->{432538} = "Velm\-Götzendorf";
$areanames{en}->{432552} = "Poysdorf";
$areanames{en}->{432554} = "Stützenhofen";
$areanames{en}->{432555} = "Herrnbaumgarten";
$areanames{en}->{432556} = "Grosskrut";
$areanames{en}->{432557} = "Bernhardsthal";
$areanames{en}->{432572} = "Mistelbach";
$areanames{en}->{432573} = "Wilfersdorf";
$areanames{en}->{432574} = "Gaweinstal";
$areanames{en}->{432575} = "Ladendorf";
$areanames{en}->{432576} = "Ernstbrunn";
$areanames{en}->{432577} = "Asparn\ an\ der\ Zaya";
$areanames{en}->{432610} = "Horitschon";
$areanames{en}->{432611} = "Mannersdorf\ an\ der\ Rabnitz";
$areanames{en}->{432612} = "Oberpullendorf";
$areanames{en}->{432613} = "Deutschkreutz";
$areanames{en}->{432614} = "Kleinwarasdorf";
$areanames{en}->{432615} = "Lutzmannsburg";
$areanames{en}->{432616} = "Lockenhaus";
$areanames{en}->{432617} = "Drassmarkt";
$areanames{en}->{432618} = "Markt\ St\.\ Martin";
$areanames{en}->{432619} = "Lackendorf";
$areanames{en}->{432620} = "Willendorf";
$areanames{en}->{432621} = "Sieggraben";
$areanames{en}->{432622} = "Wiener\ Neustadt";
$areanames{en}->{432623} = "Pottendorf";
$areanames{en}->{432624} = "Ebenfurth";
$areanames{en}->{432625} = "Bad\ Sauerbrunn";
$areanames{en}->{432626} = "Mattersburg";
$areanames{en}->{432627} = "Pitten";
$areanames{en}->{432628} = "Felixdorf";
$areanames{en}->{432629} = "Warth\,\ Lower\ Austria";
$areanames{en}->{432630} = "Ternitz";
$areanames{en}->{432631} = "Pöttsching";
$areanames{en}->{432632} = "Pernitz";
$areanames{en}->{432633} = "Markt\ Piesting";
$areanames{en}->{432634} = "Gutenstein";
$areanames{en}->{432635} = "Neunkirchen";
$areanames{en}->{432636} = "Puchberg\ am\ Schneeberg";
$areanames{en}->{432637} = "Grünbach\ am\ Schneeberg";
$areanames{en}->{432638} = "Winzendorf\-Muthmannsdorf";
$areanames{en}->{432639} = "Bad\ Fischau";
$areanames{en}->{432641} = "Kirchberg\ am\ Wechsel";
$areanames{en}->{432642} = "Aspangberg\-St\.\ Peter";
$areanames{en}->{432643} = "Lichtenegg";
$areanames{en}->{432644} = "Grimmenstein";
$areanames{en}->{432645} = "Wiesmath";
$areanames{en}->{432646} = "Kirchschlag\ in\ der\ Buckligen\ Welt";
$areanames{en}->{432647} = "Krumbach\,\ Lower\ Austria";
$areanames{en}->{432648} = "Hochneukirchen";
$areanames{en}->{432649} = "Mönichkirchen";
$areanames{en}->{432662} = "Gloggnitz";
$areanames{en}->{432663} = "Schottwien";
$areanames{en}->{432664} = "Semmering";
$areanames{en}->{432665} = "Prein\ an\ der\ Rax";
$areanames{en}->{432666} = "Reichenau";
$areanames{en}->{432667} = "Schwarzau\ im\ Gebirge";
$areanames{en}->{432672} = "Berndorf";
$areanames{en}->{432673} = "Altenmarkt\ an\ der\ Triesting";
$areanames{en}->{432674} = "Weissenbach\ an\ der\ Triesting";
$areanames{en}->{432680} = "St\.\ Margarethen\ im\ Burgenland";
$areanames{en}->{432682} = "Eisenstadt";
$areanames{en}->{432683} = "Purbach\ am\ Neusiedler\ See";
$areanames{en}->{432684} = "Schützen\ am\ Gebirge";
$areanames{en}->{432685} = "Rust";
$areanames{en}->{432686} = "Drassburg";
$areanames{en}->{432687} = "Siegendorf";
$areanames{en}->{432688} = "Steinbrunn";
$areanames{en}->{432689} = "Hornstein";
$areanames{en}->{432711} = "Dürnstein";
$areanames{en}->{432712} = "Aggsbach";
$areanames{en}->{432713} = "Spitz";
$areanames{en}->{432714} = "Rossatz";
$areanames{en}->{432715} = "Weissenkirchen\ in\ der\ Wachau";
$areanames{en}->{432716} = "Gföhl";
$areanames{en}->{432717} = "Unter\-Meisling";
$areanames{en}->{432718} = "Lichtenau\ im\ Waldviertel";
$areanames{en}->{432719} = "Dross";
$areanames{en}->{432722} = "Kirchberg\ an\ der\ Pielach";
$areanames{en}->{432723} = "Rabenstein\ an\ der\ Pielach";
$areanames{en}->{432724} = "Schwarzenbach\ an\ der\ Pielach";
$areanames{en}->{432725} = "Frankenfels";
$areanames{en}->{432726} = "Puchenstuben";
$areanames{en}->{432728} = "Wienerbruck";
$areanames{en}->{432731} = "Idolsberg";
$areanames{en}->{432732} = "Krems\ an\ der\ Donau";
$areanames{en}->{432733} = "Schönberg\ am\ Kamp";
$areanames{en}->{432734} = "Langenlois";
$areanames{en}->{432735} = "Hadersdorf\ am\ Kamp";
$areanames{en}->{432736} = "Paudorf";
$areanames{en}->{432738} = "Fels\ am\ Wagram";
$areanames{en}->{432739} = "Tiefenfucha";
$areanames{en}->{432741} = "Flinsbach";
$areanames{en}->{432742} = "St\.\ Pölten";
$areanames{en}->{432743} = "Böheimkirchen";
$areanames{en}->{432744} = "Kasten\ bei\ Böheimkirchen";
$areanames{en}->{432745} = "Pyhra";
$areanames{en}->{432746} = "Wilhelmsburg";
$areanames{en}->{432747} = "Ober\-Grafendorf";
$areanames{en}->{432748} = "Kilb";
$areanames{en}->{432749} = "Prinzersdorf";
$areanames{en}->{432752} = "Melk";
$areanames{en}->{432753} = "Gansbach";
$areanames{en}->{432754} = "Loosdorf";
$areanames{en}->{432755} = "Mank";
$areanames{en}->{432756} = "St\.\ Leonhard\ am\ Forst";
$areanames{en}->{432757} = "Pöchlarn";
$areanames{en}->{432758} = "Pöggstall";
$areanames{en}->{432762} = "Lilienfeld";
$areanames{en}->{432763} = "St\.\ Veit\ an\ der\ Gölsen";
$areanames{en}->{432764} = "Hainfeld";
$areanames{en}->{432765} = "Kaumberg";
$areanames{en}->{432766} = "Kleinzell";
$areanames{en}->{432767} = "Hohenberg";
$areanames{en}->{432768} = "St\.\ Aegyd\ am\ Neuwalde";
$areanames{en}->{432769} = "Türnitz";
$areanames{en}->{432772} = "Neulengbach";
$areanames{en}->{432773} = "Eichgraben";
$areanames{en}->{432774} = "Innermanzing";
$areanames{en}->{432782} = "Herzogenburg";
$areanames{en}->{432783} = "Traismauer";
$areanames{en}->{432784} = "Perschling";
$areanames{en}->{432786} = "Oberwölbling";
$areanames{en}->{432812} = "Gross\ Gerungs";
$areanames{en}->{432813} = "Arbesbach";
$areanames{en}->{432814} = "Langschlag";
$areanames{en}->{432815} = "Grossschönau";
$areanames{en}->{432816} = "Karlstift";
$areanames{en}->{432822} = "Zwettl\,\ Lower\ Austria";
$areanames{en}->{432823} = "Grossglobnitz";
$areanames{en}->{432824} = "Allentsteig";
$areanames{en}->{432825} = "Göpfritz\ an\ der\ Wild";
$areanames{en}->{432826} = "Rastenfeld";
$areanames{en}->{432827} = "Schönbach";
$areanames{en}->{432828} = "Rappottenstein";
$areanames{en}->{432829} = "Schweiggers";
$areanames{en}->{432841} = "Vitis";
$areanames{en}->{432842} = "Waidhofen\ an\ der\ Thaya";
$areanames{en}->{432843} = "Dobersberg";
$areanames{en}->{432844} = "Karlstein\ an\ der\ Thaya";
$areanames{en}->{432845} = "Weikertschlag\ an\ der\ Thaya";
$areanames{en}->{432846} = "Raabs\ an\ der\ Thaya";
$areanames{en}->{432847} = "Gross\-Siegharts";
$areanames{en}->{432848} = "Pfaffenschlag\ bei\ Waidhofen";
$areanames{en}->{432849} = "Schwarzenau";
$areanames{en}->{432852} = "Gmünd";
$areanames{en}->{432853} = "Schrems";
$areanames{en}->{432854} = "Kirchberg\ am\ Walde";
$areanames{en}->{432855} = "Waldenstein";
$areanames{en}->{432856} = "Weitra";
$areanames{en}->{432857} = "Bad\ Grosspertholz";
$areanames{en}->{432858} = "Moorbad\ Harbach";
$areanames{en}->{432859} = "Brand\-Nagelberg";
$areanames{en}->{432862} = "Heidenreichstein";
$areanames{en}->{432863} = "Eggern";
$areanames{en}->{432864} = "Kautzen";
$areanames{en}->{432865} = "Litschau";
$areanames{en}->{432872} = "Ottenschlag";
$areanames{en}->{432873} = "Kottes";
$areanames{en}->{432874} = "Martinsberg";
$areanames{en}->{432875} = "Grafenschlag";
$areanames{en}->{432876} = "Els";
$areanames{en}->{432877} = "Grainbrunn";
$areanames{en}->{432878} = "Traunstein";
$areanames{en}->{432912} = "Geras";
$areanames{en}->{432913} = "Hötzelsdorf";
$areanames{en}->{432914} = "Japons";
$areanames{en}->{432915} = "Drosendorf\-Zissersdorf";
$areanames{en}->{432916} = "Riegersburg\,\ Hardegg";
$areanames{en}->{432942} = "Retz";
$areanames{en}->{432943} = "Obritz";
$areanames{en}->{432944} = "Haugsdorf";
$areanames{en}->{432945} = "Zellerndorf";
$areanames{en}->{432946} = "Pulkau";
$areanames{en}->{432947} = "Theras";
$areanames{en}->{432948} = "Weitersfeld";
$areanames{en}->{432949} = "Niederfladnitz";
$areanames{en}->{432951} = "Guntersdorf";
$areanames{en}->{432952} = "Hollabrunn";
$areanames{en}->{432953} = "Nappersdorf";
$areanames{en}->{432954} = "Göllersdorf";
$areanames{en}->{432955} = "Grossweikersdorf";
$areanames{en}->{432956} = "Ziersdorf";
$areanames{en}->{432957} = "Hohenwarth";
$areanames{en}->{432958} = "Maissau";
$areanames{en}->{432959} = "Sitzendorf\ an\ der\ Schmida";
$areanames{en}->{432982} = "Horn";
$areanames{en}->{432983} = "Sigmundsherberg";
$areanames{en}->{432984} = "Eggenburg";
$areanames{en}->{432985} = "Gars\ am\ Kamp";
$areanames{en}->{432986} = "Irnfritz";
$areanames{en}->{432987} = "St\.\ Leonhard\ am\ Hornerwald";
$areanames{en}->{432988} = "Neupölla";
$areanames{en}->{432989} = "Brunn\ an\ der\ Wild";
$areanames{en}->{433112} = "Gleisdorf";
$areanames{en}->{433113} = "Pischelsdorf\ in\ der\ Steiermark";
$areanames{en}->{433114} = "Markt\ Hartmannsdorf";
$areanames{en}->{433115} = "Studenzen";
$areanames{en}->{433116} = "Kirchbach\ in\ Steiermark";
$areanames{en}->{433117} = "Eggersdorf\ bei\ Graz";
$areanames{en}->{433118} = "Sinabelkirchen";
$areanames{en}->{433119} = "St\.\ Marein\ bei\ Graz";
$areanames{en}->{433123} = "St\.\ Oswald\ bei\ Plankenwarth";
$areanames{en}->{433124} = "Gratkorn";
$areanames{en}->{433125} = "Übelbach";
$areanames{en}->{433126} = "Frohnleiten";
$areanames{en}->{433127} = "Peggau";
$areanames{en}->{433132} = "Kumberg";
$areanames{en}->{433133} = "Nestelbach";
$areanames{en}->{433134} = "Heiligenkreuz\ am\ Waasen";
$areanames{en}->{433135} = "Kalsdorf\ bei\ Graz";
$areanames{en}->{433136} = "Dobl";
$areanames{en}->{433137} = "Söding";
$areanames{en}->{433140} = "St\.\ Martin\ am\ Wöllmissberg";
$areanames{en}->{433141} = "Hirschegg";
$areanames{en}->{433142} = "Voitsberg";
$areanames{en}->{433143} = "Krottendorf";
$areanames{en}->{433144} = "Köflach";
$areanames{en}->{433145} = "Edelschrott";
$areanames{en}->{433146} = "Modriach";
$areanames{en}->{433147} = "Salla";
$areanames{en}->{433148} = "Kainach\ bei\ Voitsberg";
$areanames{en}->{433149} = "Geistthal";
$areanames{en}->{433150} = "Paldau";
$areanames{en}->{433151} = "Gnas";
$areanames{en}->{433152} = "Feldbach";
$areanames{en}->{433153} = "Riegersburg";
$areanames{en}->{433155} = "Fehring";
$areanames{en}->{433157} = "Kapfenstein";
$areanames{en}->{433158} = "St\.\ Anna\ am\ Aigen";
$areanames{en}->{433159} = "Bad\ Gleichenberg";
$areanames{en}->{43316} = "Graz";
$areanames{en}->{433170} = "Fischbach";
$areanames{en}->{433171} = "Gasen";
$areanames{en}->{433172} = "Weiz";
$areanames{en}->{433173} = "Ratten";
$areanames{en}->{433174} = "Birkfeld";
$areanames{en}->{433175} = "Anger";
$areanames{en}->{433176} = "Stubenberg";
$areanames{en}->{433177} = "Puch\ bei\ Weiz";
$areanames{en}->{433178} = "St\.\ Ruprecht\ an\ der\ Raab";
$areanames{en}->{433179} = "Passail";
$areanames{en}->{433182} = "Wildon";
$areanames{en}->{433183} = "St\.\ Georgen\ an\ der\ Stiefing";
$areanames{en}->{433184} = "Wolfsberg\ im\ Schwarzautal";
$areanames{en}->{433185} = "Preding";
$areanames{en}->{433322} = "Güssing";
$areanames{en}->{433323} = "Eberau";
$areanames{en}->{433324} = "Strem";
$areanames{en}->{433325} = "Heiligenkreuz\ im\ Lafnitztal";
$areanames{en}->{433326} = "Stegersbach";
$areanames{en}->{433327} = "St\.\ Michael\ im\ Burgenland";
$areanames{en}->{433328} = "Kukmirn";
$areanames{en}->{433329} = "Jennersdorf";
$areanames{en}->{433331} = "St\.\ Lorenzen\ am\ Wechsel";
$areanames{en}->{433332} = "Hartberg";
$areanames{en}->{433333} = "Sebersdorf";
$areanames{en}->{433334} = "Kaindorf";
$areanames{en}->{433335} = "Pöllau";
$areanames{en}->{433336} = "Waldbach";
$areanames{en}->{433337} = "Vorau";
$areanames{en}->{433338} = "Lafnitz";
$areanames{en}->{433339} = "Friedberg";
$areanames{en}->{433352} = "Oberwart";
$areanames{en}->{433353} = "Oberschützen";
$areanames{en}->{433354} = "Bernstein";
$areanames{en}->{433355} = "Stadtschlaining";
$areanames{en}->{433356} = "Markt\ Allhau";
$areanames{en}->{433357} = "Pinkafeld";
$areanames{en}->{433358} = "Litzelsdorf";
$areanames{en}->{433359} = "Loipersdorf\-Kitzladen";
$areanames{en}->{433362} = "Grosspetersdorf";
$areanames{en}->{433363} = "Rechnitz";
$areanames{en}->{433364} = "Hannersdorf";
$areanames{en}->{433365} = "Deutsch\ Schützen\-Eisenberg";
$areanames{en}->{433366} = "Kohfidisch";
$areanames{en}->{433382} = "Fürstenfeld";
$areanames{en}->{433383} = "Burgau";
$areanames{en}->{433385} = "Ilz";
$areanames{en}->{433386} = "Grosssteinbach";
$areanames{en}->{433387} = "Söchau";
$areanames{en}->{433452} = "Leibnitz";
$areanames{en}->{433453} = "Ehrenhausen";
$areanames{en}->{433454} = "Leutschach";
$areanames{en}->{433455} = "Arnfels";
$areanames{en}->{433456} = "Fresing";
$areanames{en}->{433457} = "Gleinstätten";
$areanames{en}->{433460} = "Soboth";
$areanames{en}->{433461} = "Trahütten";
$areanames{en}->{433462} = "Deutschlandsberg";
$areanames{en}->{433463} = "Stainz";
$areanames{en}->{433464} = "Gross\ St\.\ Florian";
$areanames{en}->{433465} = "Pölfing\-Brunn";
$areanames{en}->{433466} = "Eibiswald";
$areanames{en}->{433467} = "Schwanberg";
$areanames{en}->{433468} = "St\.\ Oswald\ ob\ Eibiswald";
$areanames{en}->{433469} = "St\.\ Oswald\ im\ Freiland";
$areanames{en}->{433472} = "Mureck";
$areanames{en}->{433473} = "Straden";
$areanames{en}->{433474} = "Deutsch\ Goritz";
$areanames{en}->{433475} = "Hürth";
$areanames{en}->{433476} = "Bad\ Radkersburg";
$areanames{en}->{433477} = "St\.\ Peter\ am\ Ottersbach";
$areanames{en}->{433512} = "Knittelfeld";
$areanames{en}->{433513} = "Bischoffeld";
$areanames{en}->{433514} = "Seckau";
$areanames{en}->{433515} = "St\.\ Lorenzen\ bei\ Knittelfeld";
$areanames{en}->{433516} = "Kleinlobming";
$areanames{en}->{433532} = "Murau";
$areanames{en}->{433533} = "Turrach";
$areanames{en}->{433534} = "Stadl\ an\ der\ Mur";
$areanames{en}->{433535} = "Krakaudorf";
$areanames{en}->{433536} = "St\.\ Peter\ am\ Kammersberg";
$areanames{en}->{433537} = "St\.\ Georgen\ ob\ Murau";
$areanames{en}->{433571} = "Möderbrugg";
$areanames{en}->{433572} = "Judenburg";
$areanames{en}->{433573} = "Fohnsdorf";
$areanames{en}->{433574} = "Pusterwald";
$areanames{en}->{433575} = "St\.\ Johann\ am\ Tauern";
$areanames{en}->{433576} = "Bretstein";
$areanames{en}->{433577} = "Zeltweg";
$areanames{en}->{433578} = "Obdach";
$areanames{en}->{433579} = "Pöls";
$areanames{en}->{433581} = "Oberwölz";
$areanames{en}->{433582} = "Scheifling";
$areanames{en}->{433583} = "Unzmarkt";
$areanames{en}->{433584} = "Neumarkt\ in\ Steiermark";
$areanames{en}->{433585} = "St\.\ Lambrecht";
$areanames{en}->{433586} = "Mühlen";
$areanames{en}->{433587} = "Schönberg\-Lachtal";
$areanames{en}->{433588} = "Katsch\ an\ der\ Mur";
$areanames{en}->{433611} = "Johnsbach";
$areanames{en}->{433612} = "Liezen";
$areanames{en}->{433613} = "Admont";
$areanames{en}->{433614} = "Rottenmann";
$areanames{en}->{433615} = "Trieben";
$areanames{en}->{433616} = "Selzthal";
$areanames{en}->{433617} = "Gaishorn\ am\ See";
$areanames{en}->{433618} = "Hohentauern";
$areanames{en}->{433619} = "Oppenberg";
$areanames{en}->{433622} = "Bad\ Aussee";
$areanames{en}->{433623} = "Bad\ Mitterndorf";
$areanames{en}->{433624} = "Pichl\-Kainisch";
$areanames{en}->{433631} = "Unterlaussa";
$areanames{en}->{433632} = "St\.\ Gallen";
$areanames{en}->{433633} = "Landl";
$areanames{en}->{433634} = "Hieflau";
$areanames{en}->{433635} = "Radmer";
$areanames{en}->{433636} = "Wildalpen";
$areanames{en}->{433637} = "Gams\ bei\ Hieflau";
$areanames{en}->{433638} = "Palfau";
$areanames{en}->{433680} = "Donnersbachwald";
$areanames{en}->{433682} = "Stainach";
$areanames{en}->{433683} = "Donnersbach";
$areanames{en}->{433684} = "St\.\ Martin\ am\ Grimming";
$areanames{en}->{433685} = "Gröbming";
$areanames{en}->{433686} = "Haus";
$areanames{en}->{433687} = "Schladming";
$areanames{en}->{433688} = "Tauplitz";
$areanames{en}->{433689} = "St\.\ Nikolai\ im\ Sölktal";
$areanames{en}->{433832} = "Kraubath\ an\ der\ Mur";
$areanames{en}->{433833} = "Traboch";
$areanames{en}->{433834} = "Wald\ am\ Schoberpass";
$areanames{en}->{433842} = "Leoben";
$areanames{en}->{433843} = "St\.\ Michael\ in\ Obersteiermark";
$areanames{en}->{433844} = "Kammern\ im\ Liesingtal";
$areanames{en}->{433845} = "Mautern\ in\ Steiermark";
$areanames{en}->{433846} = "Kalwang";
$areanames{en}->{433847} = "Trofaiach";
$areanames{en}->{433848} = "Eisenerz";
$areanames{en}->{433849} = "Vordernberg";
$areanames{en}->{433852} = "Mürzzuschlag";
$areanames{en}->{433853} = "Spital\ am\ Semmering";
$areanames{en}->{433854} = "Langenwang";
$areanames{en}->{433855} = "Krieglach";
$areanames{en}->{433856} = "Veitsch";
$areanames{en}->{433857} = "Neuberg\ an\ der\ Mürz";
$areanames{en}->{433858} = "Mitterdorf\ im\ Mürztal";
$areanames{en}->{433859} = "Mürzsteg";
$areanames{en}->{433861} = "Aflenz";
$areanames{en}->{433862} = "Bruck\ an\ der\ Mur";
$areanames{en}->{433863} = "Turnau";
$areanames{en}->{433864} = "St\.\ Marein\ im\ Mürztal";
$areanames{en}->{433865} = "Kindberg";
$areanames{en}->{433866} = "Breitenau\ am\ Hochlantsch";
$areanames{en}->{433867} = "Pernegg\ an\ der\ Mur";
$areanames{en}->{433868} = "Tragöss";
$areanames{en}->{433869} = "St\.\ Katharein\ an\ der\ Laming";
$areanames{en}->{433882} = "Mariazell";
$areanames{en}->{433883} = "Terz";
$areanames{en}->{433884} = "Wegscheid";
$areanames{en}->{433885} = "Greith";
$areanames{en}->{433886} = "Weichselboden";
$areanames{en}->{434212} = "St\.\ Veit\ an\ der\ Glan";
$areanames{en}->{434213} = "Launsdorf";
$areanames{en}->{434214} = "Brückl";
$areanames{en}->{434215} = "Liebenfels";
$areanames{en}->{434220} = "Köttmannsdorf";
$areanames{en}->{434221} = "Gallizien";
$areanames{en}->{434223} = "Maria\ Saal";
$areanames{en}->{434224} = "Pischeldorf";
$areanames{en}->{434225} = "Grafenstein";
$areanames{en}->{434226} = "St\.\ Margareten\ im\ Rosental";
$areanames{en}->{434227} = "Ferlach";
$areanames{en}->{434228} = "Feistritz\ im\ Rosental";
$areanames{en}->{434229} = "Krumpendorf\ am\ Wörther\ See";
$areanames{en}->{434230} = "Globasnitz";
$areanames{en}->{434231} = "Mittertrixen";
$areanames{en}->{434232} = "Völkermarkt";
$areanames{en}->{434233} = "Griffen";
$areanames{en}->{434234} = "Ruden";
$areanames{en}->{434235} = "Bleiburg";
$areanames{en}->{434236} = "Eberndorf";
$areanames{en}->{434237} = "Miklauzhof";
$areanames{en}->{434238} = "Eisenkappel\-Vellach";
$areanames{en}->{434239} = "St\.\ Kanzian\ am\ Klopeiner\ See";
$areanames{en}->{434240} = "Bad\ Kleinkirchheim";
$areanames{en}->{434242} = "Villach";
$areanames{en}->{434243} = "Bodensdorf";
$areanames{en}->{434244} = "Bad\ Bleiberg";
$areanames{en}->{434245} = "Feistritz\ an\ der\ Drau";
$areanames{en}->{434246} = "Radenthein";
$areanames{en}->{434247} = "Afritz";
$areanames{en}->{434248} = "Treffen";
$areanames{en}->{434252} = "Wernberg";
$areanames{en}->{434253} = "St\.\ Jakob\ im\ Rosental";
$areanames{en}->{434254} = "Faak\ am\ See";
$areanames{en}->{434255} = "Arnoldstein";
$areanames{en}->{434256} = "Nötsch\ im\ Gailtal";
$areanames{en}->{434257} = "Fürnitz";
$areanames{en}->{434258} = "Gummern";
$areanames{en}->{434262} = "Treibach";
$areanames{en}->{434263} = "Hüttenberg";
$areanames{en}->{434264} = "Klein\ St\.\ Paul";
$areanames{en}->{434265} = "Weitensfeld\ im\ Gurktal";
$areanames{en}->{434266} = "Strassburg";
$areanames{en}->{434267} = "Metnitz";
$areanames{en}->{434268} = "Friesach";
$areanames{en}->{434269} = "Flattnitz";
$areanames{en}->{434271} = "Steuerberg";
$areanames{en}->{434272} = "Pörtschach\ am\ Wörther\ See";
$areanames{en}->{434273} = "Reifnitz";
$areanames{en}->{434274} = "Velden\ am\ Wörther\ See";
$areanames{en}->{434275} = "Ebene\ Reichenau";
$areanames{en}->{434276} = "Feldkirchen\ in\ Kärnten";
$areanames{en}->{434277} = "Glanegg";
$areanames{en}->{434278} = "Gnesau";
$areanames{en}->{434279} = "Sirnitz";
$areanames{en}->{434282} = "Hermagor";
$areanames{en}->{434283} = "St\.\ Stefan\ im\ Gailtal";
$areanames{en}->{434284} = "Kirchbach";
$areanames{en}->{434285} = "Tröpolach";
$areanames{en}->{434286} = "Weissbriach";
$areanames{en}->{434350} = "Bad\ St\.\ Leonhard\ im\ Lavanttal";
$areanames{en}->{434352} = "Wolfsberg";
$areanames{en}->{434353} = "Prebl";
$areanames{en}->{434354} = "Preitenegg";
$areanames{en}->{434355} = "Gemmersdorf";
$areanames{en}->{434356} = "Lavamünd";
$areanames{en}->{434357} = "St\.\ Paul\ im\ Lavanttal";
$areanames{en}->{434358} = "St\.\ Andrä";
$areanames{en}->{434359} = "Reichenfels";
$areanames{en}->{4346} = "Klagenfurt";
$areanames{en}->{434710} = "Oberdrauburg";
$areanames{en}->{434712} = "Greifenburg";
$areanames{en}->{434713} = "Techendorf";
$areanames{en}->{434714} = "Dellach\ im\ Drautal";
$areanames{en}->{434715} = "Kötschach\-Mauthen";
$areanames{en}->{434716} = "Lesachtal";
$areanames{en}->{434717} = "Steinfeld";
$areanames{en}->{434718} = "Dellach";
$areanames{en}->{434732} = "Gmünd\ in\ Kärnten";
$areanames{en}->{434733} = "Malta";
$areanames{en}->{434734} = "Rennweg";
$areanames{en}->{434735} = "Kremsbrücke";
$areanames{en}->{434736} = "Innerkrems";
$areanames{en}->{434761} = "Stockenboi";
$areanames{en}->{434762} = "Spittal\ an\ der\ Drau";
$areanames{en}->{434766} = "Millstatt";
$areanames{en}->{434767} = "Rothenthurn";
$areanames{en}->{434768} = "Kleblach\-Lind";
$areanames{en}->{434769} = "Möllbrücke";
$areanames{en}->{434782} = "Obervellach";
$areanames{en}->{434783} = "Reisseck";
$areanames{en}->{434784} = "Mallnitz";
$areanames{en}->{434785} = "Ausserfragant";
$areanames{en}->{434822} = "Winklern";
$areanames{en}->{434823} = "Tresdorf\,\ Rangersdorf";
$areanames{en}->{434824} = "Heiligenblut";
$areanames{en}->{434825} = "Grosskirchheim";
$areanames{en}->{434826} = "Mörtschach";
$areanames{en}->{434842} = "Sillian";
$areanames{en}->{434843} = "Ausservillgraten";
$areanames{en}->{434846} = "Abfaltersbach";
$areanames{en}->{434847} = "Obertilliach";
$areanames{en}->{434848} = "Kartitsch";
$areanames{en}->{434852} = "Lienz";
$areanames{en}->{434853} = "Ainet";
$areanames{en}->{434855} = "Assling";
$areanames{en}->{434858} = "Nikolsdorf";
$areanames{en}->{434872} = "Huben";
$areanames{en}->{434873} = "St\.\ Jakob\ in\ Defereggen";
$areanames{en}->{434874} = "Virgen";
$areanames{en}->{434875} = "Matrei\ in\ Osttirol";
$areanames{en}->{434876} = "Kals\ am\ Grossglockner";
$areanames{en}->{434877} = "Prägraten\ am\ Grossvenediger";
$areanames{en}->{434879} = "St\.\ Veit\ in\ Defereggen";
$areanames{en}->{43512} = "Innsbruck";
$areanames{en}->{435212} = "Seefeld\ in\ Tirol";
$areanames{en}->{435213} = "Scharnitz";
$areanames{en}->{435214} = "Leutasch";
$areanames{en}->{435223} = "Hall\ in\ Tirol";
$areanames{en}->{435224} = "Wattens";
$areanames{en}->{435225} = "Fulpmes";
$areanames{en}->{435226} = "Neustift\ im\ Stubaital";
$areanames{en}->{435230} = "Sellrain";
$areanames{en}->{435232} = "Kematen\ in\ Tirol";
$areanames{en}->{435234} = "Axams";
$areanames{en}->{435236} = "Gries\ im\ Sellrain";
$areanames{en}->{435238} = "Zirl";
$areanames{en}->{435239} = "Kühtai";
$areanames{en}->{435242} = "Schwaz";
$areanames{en}->{435243} = "Maurach";
$areanames{en}->{435244} = "Jenbach";
$areanames{en}->{435245} = "Hinterriss";
$areanames{en}->{435246} = "Achenkirch";
$areanames{en}->{435248} = "Steinberg\ am\ Rofan";
$areanames{en}->{435252} = "Oetz";
$areanames{en}->{435253} = "Längenfeld";
$areanames{en}->{435254} = "Sölden";
$areanames{en}->{435255} = "Umhausen";
$areanames{en}->{435256} = "Untergurgl";
$areanames{en}->{435262} = "Telfs";
$areanames{en}->{435263} = "Silz";
$areanames{en}->{435264} = "Mieming";
$areanames{en}->{435265} = "Nassereith";
$areanames{en}->{435266} = "Ötztal\-Bahnhof";
$areanames{en}->{435272} = "Steinach\ am\ Brenner";
$areanames{en}->{435273} = "Matrei\ am\ Brenner";
$areanames{en}->{435274} = "Gries\ am\ Brenner";
$areanames{en}->{435275} = "Trins";
$areanames{en}->{435276} = "Gschnitz";
$areanames{en}->{435278} = "Navis";
$areanames{en}->{435279} = "St\.\ Jodok\ am\ Brenner";
$areanames{en}->{435280} = "Hochfügen";
$areanames{en}->{435282} = "Zell\ am\ Ziller";
$areanames{en}->{435283} = "Kaltenbach";
$areanames{en}->{435284} = "Gerlos";
$areanames{en}->{435285} = "Mayrhofen";
$areanames{en}->{435286} = "Ginzling";
$areanames{en}->{435287} = "Tux";
$areanames{en}->{435288} = "Fügen";
$areanames{en}->{435289} = "Häusling";
$areanames{en}->{435331} = "Brandenberg";
$areanames{en}->{435332} = "Wörgl";
$areanames{en}->{435333} = "Söll";
$areanames{en}->{435334} = "Westendorf";
$areanames{en}->{435335} = "Hopfgarten\ im\ Brixental";
$areanames{en}->{435336} = "Alpbach";
$areanames{en}->{435337} = "Brixlegg";
$areanames{en}->{435338} = "Kundl";
$areanames{en}->{435339} = "Wildschönau";
$areanames{en}->{435352} = "St\.\ Johann\ in\ Tirol";
$areanames{en}->{435353} = "Waidring";
$areanames{en}->{435354} = "Fieberbrunn";
$areanames{en}->{435355} = "Jochberg";
$areanames{en}->{435356} = "Kitzbühel";
$areanames{en}->{435357} = "Kirchberg\ in\ Tirol";
$areanames{en}->{435358} = "Ellmau";
$areanames{en}->{435359} = "Hochfilzen";
$areanames{en}->{435372} = "Kufstein";
$areanames{en}->{435373} = "Ebbs";
$areanames{en}->{435374} = "Walchsee";
$areanames{en}->{435375} = "Kössen";
$areanames{en}->{435376} = "Thiersee";
$areanames{en}->{435412} = "Imst";
$areanames{en}->{435413} = "St\.\ Leonhard\ im\ Pitztal";
$areanames{en}->{435414} = "Wenns";
$areanames{en}->{435417} = "Roppen";
$areanames{en}->{435418} = "Schönwies";
$areanames{en}->{435441} = "See";
$areanames{en}->{435442} = "Landeck";
$areanames{en}->{435443} = "Galtür";
$areanames{en}->{435444} = "Ischgl";
$areanames{en}->{435445} = "Kappl";
$areanames{en}->{435446} = "St\.\ Anton\ am\ Arlberg";
$areanames{en}->{435447} = "Flirsch";
$areanames{en}->{435448} = "Pettneu\ am\ Arlberg";
$areanames{en}->{435449} = "Fliess";
$areanames{en}->{435472} = "Prutz";
$areanames{en}->{435473} = "Nauders";
$areanames{en}->{435474} = "Pfunds";
$areanames{en}->{435475} = "Feichten";
$areanames{en}->{435476} = "Serfaus";
$areanames{en}->{435477} = "Tösens";
$areanames{en}->{435510} = "Damüls";
$areanames{en}->{435512} = "Egg";
$areanames{en}->{435513} = "Hittisau";
$areanames{en}->{435514} = "Bezau";
$areanames{en}->{435515} = "Au";
$areanames{en}->{435516} = "Doren";
$areanames{en}->{435517} = "Riezlern";
$areanames{en}->{435518} = "Mellau";
$areanames{en}->{435519} = "Schröcken";
$areanames{en}->{435522} = "Feldkirch";
$areanames{en}->{435523} = "Götzis";
$areanames{en}->{435524} = "Satteins";
$areanames{en}->{435525} = "Nenzing";
$areanames{en}->{435526} = "Laterns";
$areanames{en}->{435550} = "Thüringen";
$areanames{en}->{435552} = "Bludenz";
$areanames{en}->{435553} = "Raggal";
$areanames{en}->{435554} = "Sonntag";
$areanames{en}->{435556} = "Schruns";
$areanames{en}->{435557} = "St\.\ Gallenkirch";
$areanames{en}->{435558} = "Gaschurn";
$areanames{en}->{435559} = "Brand";
$areanames{en}->{435572} = "Dornbirn";
$areanames{en}->{435573} = "Hörbranz";
$areanames{en}->{435574} = "Bregenz";
$areanames{en}->{435575} = "Langen\ bei\ Bregenz";
$areanames{en}->{435576} = "Hohenems";
$areanames{en}->{435577} = "Lustenau";
$areanames{en}->{435578} = "Höchst";
$areanames{en}->{435579} = "Alberschwende";
$areanames{en}->{435582} = "Klösterle";
$areanames{en}->{435583} = "Lech";
$areanames{en}->{435585} = "Dalaas";
$areanames{en}->{435632} = "Stanzach";
$areanames{en}->{435633} = "Hägerau";
$areanames{en}->{435634} = "Elbigenalp";
$areanames{en}->{435635} = "Elmen";
$areanames{en}->{435672} = "Reutte";
$areanames{en}->{435673} = "Ehrwald";
$areanames{en}->{435674} = "Bichlbach";
$areanames{en}->{435675} = "Tannheim";
$areanames{en}->{435676} = "Jungholz";
$areanames{en}->{435677} = "Vils";
$areanames{en}->{435678} = "Weissenbach\ am\ Lech";
$areanames{en}->{436131} = "Obertraun";
$areanames{en}->{436132} = "Bad\ Ischl";
$areanames{en}->{436133} = "Ebensee";
$areanames{en}->{436134} = "Hallstatt";
$areanames{en}->{436135} = "Bad\ Goisern";
$areanames{en}->{436136} = "Gosau";
$areanames{en}->{436137} = "Strobl";
$areanames{en}->{436138} = "St\.\ Wolfgang\ im\ Salzkammergut";
$areanames{en}->{436212} = "Seekirchen\ am\ Wallersee";
$areanames{en}->{436213} = "Oberhofen\ am\ Irrsee";
$areanames{en}->{436214} = "Henndorf\ am\ Wallersee";
$areanames{en}->{436215} = "Strasswalchen";
$areanames{en}->{436216} = "Neumarkt\ am\ Wallersee";
$areanames{en}->{436217} = "Mattsee";
$areanames{en}->{436219} = "Obertrum\ am\ See";
$areanames{en}->{436221} = "Koppl";
$areanames{en}->{436223} = "Anthering";
$areanames{en}->{436224} = "Hintersee";
$areanames{en}->{436225} = "Eugendorf";
$areanames{en}->{436226} = "Fuschl\ am\ See";
$areanames{en}->{436227} = "St\.\ Gilgen";
$areanames{en}->{436228} = "Faistenau";
$areanames{en}->{436229} = "Hof\ bei\ Salzburg";
$areanames{en}->{436232} = "Mondsee";
$areanames{en}->{436233} = "Oberwang";
$areanames{en}->{436234} = "Zell\ am\ Moos";
$areanames{en}->{436235} = "Thalgau";
$areanames{en}->{436240} = "Krispl";
$areanames{en}->{436241} = "St\.\ Koloman";
$areanames{en}->{436242} = "Russbach\ am\ Pass\ Gschütt";
$areanames{en}->{436243} = "Abtenau";
$areanames{en}->{436244} = "Golling\ an\ der\ Salzach";
$areanames{en}->{436245} = "Hallein";
$areanames{en}->{436246} = "Grödig";
$areanames{en}->{436247} = "Grossgmain";
$areanames{en}->{436272} = "Oberndorf\ bei\ Salzburg";
$areanames{en}->{436274} = "Lamprechtshausen";
$areanames{en}->{436276} = "Nussdorf\ am\ Haunsberg";
$areanames{en}->{436277} = "St\.\ Pantaleon";
$areanames{en}->{436278} = "Ostermiething";
$areanames{en}->{436412} = "St\.\ Johann\ im\ Pongau";
$areanames{en}->{436413} = "Wagrain";
$areanames{en}->{436414} = "Grossarl";
$areanames{en}->{436415} = "Schwarzach\ im\ Pongau";
$areanames{en}->{436416} = "Lend";
$areanames{en}->{436417} = "Hüttschlag";
$areanames{en}->{436418} = "Kleinarl";
$areanames{en}->{436432} = "Bad\ Hofgastein";
$areanames{en}->{436433} = "Dorfgastein";
$areanames{en}->{436434} = "Bad\ Gastein";
$areanames{en}->{436452} = "Radstadt";
$areanames{en}->{436453} = "Filzmoos";
$areanames{en}->{436454} = "Mandling";
$areanames{en}->{436455} = "Untertauern";
$areanames{en}->{436456} = "Obertauern";
$areanames{en}->{436457} = "Flachau";
$areanames{en}->{436458} = "Hüttau";
$areanames{en}->{436461} = "Dienten\ am\ Hochkönig";
$areanames{en}->{436462} = "Bischofshofen";
$areanames{en}->{436463} = "Annaberg\-Lungötz";
$areanames{en}->{436466} = "Werfenweng";
$areanames{en}->{436467} = "Mühlbach\ am\ Hochkönig";
$areanames{en}->{436468} = "Werfen";
$areanames{en}->{436470} = "Atzmannsdorf";
$areanames{en}->{436471} = "Tweng";
$areanames{en}->{436472} = "Mauterndorf";
$areanames{en}->{436473} = "Mariapfarr";
$areanames{en}->{436474} = "Tamsweg";
$areanames{en}->{436475} = "Ramingstein";
$areanames{en}->{436476} = "St\.\ Margarethen\ im\ Lungau";
$areanames{en}->{436477} = "St\.\ Michael\ im\ Lungau";
$areanames{en}->{436478} = "Zederhaus";
$areanames{en}->{436479} = "Muhr";
$areanames{en}->{436483} = "Göriach";
$areanames{en}->{436484} = "Lessach";
$areanames{en}->{436541} = "Saalbach";
$areanames{en}->{436542} = "Zell\ am\ See";
$areanames{en}->{436543} = "Taxenbach";
$areanames{en}->{436544} = "Rauris";
$areanames{en}->{436545} = "Bruck\ an\ der\ Grossglocknerstrasse";
$areanames{en}->{436546} = "Fusch\ an\ der\ Grossglocknerstrasse";
$areanames{en}->{436547} = "Kaprun";
$areanames{en}->{436548} = "Niedernsill";
$areanames{en}->{436549} = "Piesendorf";
$areanames{en}->{436562} = "Mittersill";
$areanames{en}->{436563} = "Uttendorf";
$areanames{en}->{436564} = "Krimml";
$areanames{en}->{436565} = "Neukirchen\ am\ Grossvenediger";
$areanames{en}->{436566} = "Bramberg\ am\ Wildkogel";
$areanames{en}->{436582} = "Saalfelden\ am\ Steinernen\ Meer";
$areanames{en}->{436583} = "Leogang";
$areanames{en}->{436584} = "Maria\ Alm\ am\ Steinernen\ Meer";
$areanames{en}->{436588} = "Lofer";
$areanames{en}->{436589} = "Unken";
$areanames{en}->{43662} = "Salzburg";
$areanames{en}->{437211} = "Reichenau\ im\ Mühlkreis";
$areanames{en}->{437212} = "Zwettl\ an\ der\ Rodl";
$areanames{en}->{437213} = "Bad\ Leonfelden";
$areanames{en}->{437214} = "Reichenthal";
$areanames{en}->{437215} = "Hellmonsödt";
$areanames{en}->{437216} = "Helfenberg";
$areanames{en}->{437217} = "St\.\ Veit\ im\ Mühlkreis";
$areanames{en}->{437218} = "Grosstraberg";
$areanames{en}->{437219} = "Vorderweissenbach";
$areanames{en}->{437221} = "Hörsching";
$areanames{en}->{437223} = "Enns";
$areanames{en}->{437224} = "St\.\ Florian";
$areanames{en}->{437225} = "Hargelsberg";
$areanames{en}->{437226} = "Wilhering";
$areanames{en}->{437227} = "Neuhofen\ an\ der\ Krems";
$areanames{en}->{437228} = "Kematen\ an\ der\ Krems";
$areanames{en}->{437229} = "Traun";
$areanames{en}->{437230} = "Altenberg\ bei\ Linz";
$areanames{en}->{437231} = "Herzogsdorf";
$areanames{en}->{437232} = "St\.\ Martin\ im\ Mühlkreis";
$areanames{en}->{437233} = "Feldkirchen\ an\ der\ Donau";
$areanames{en}->{437234} = "Ottensheim";
$areanames{en}->{437235} = "Gallneukirchen";
$areanames{en}->{437236} = "Pregarten";
$areanames{en}->{437237} = "St\.\ Georgen\ an\ der\ Gusen";
$areanames{en}->{437238} = "Mauthausen";
$areanames{en}->{437239} = "Lichtenberg";
$areanames{en}->{437240} = "Sipbachzell";
$areanames{en}->{437241} = "Steinerkirchen\ an\ der\ Traun";
$areanames{en}->{437242} = "Wels";
$areanames{en}->{437243} = "Marchtrenk";
$areanames{en}->{437244} = "Sattledt";
$areanames{en}->{437245} = "Lambach";
$areanames{en}->{437246} = "Gunskirchen";
$areanames{en}->{437247} = "Kematen\ am\ Innbach";
$areanames{en}->{437248} = "Grieskirchen";
$areanames{en}->{437249} = "Bad\ Schallerbach";
$areanames{en}->{437250} = "Maria\ Neustift";
$areanames{en}->{437251} = "Schiedlberg";
$areanames{en}->{437252} = "Steyr";
$areanames{en}->{437253} = "Wolfern";
$areanames{en}->{437254} = "Grossraming";
$areanames{en}->{437255} = "Losenstein";
$areanames{en}->{437256} = "Ternberg";
$areanames{en}->{437257} = "Grünburg";
$areanames{en}->{437258} = "Bad\ Hall";
$areanames{en}->{437259} = "Sierning";
$areanames{en}->{437260} = "Waldhausen";
$areanames{en}->{437261} = "Schönau\ im\ Mühlkreis";
$areanames{en}->{437262} = "Perg";
$areanames{en}->{437263} = "Bad\ Zell";
$areanames{en}->{437264} = "Windhaag\ bei\ Perg";
$areanames{en}->{437265} = "Pabneukirchen";
$areanames{en}->{437266} = "Bad\ Kreuzen";
$areanames{en}->{437267} = "Mönchdorf";
$areanames{en}->{437268} = "Grein";
$areanames{en}->{437269} = "Baumgartenberg";
$areanames{en}->{437272} = "Eferding";
$areanames{en}->{437273} = "Aschach\ an\ der\ Donau";
$areanames{en}->{437274} = "Alkoven";
$areanames{en}->{437276} = "Peuerbach";
$areanames{en}->{437277} = "Waizenkirchen";
$areanames{en}->{437278} = "Neukirchen\ am\ Walde";
$areanames{en}->{437279} = "Haibach\ ob\ der\ Donau";
$areanames{en}->{437280} = "Schwarzenberg\ am\ Böhmerwald";
$areanames{en}->{437281} = "Aigen\ im\ Mühlkreis";
$areanames{en}->{437282} = "Neufelden";
$areanames{en}->{437283} = "Sarleinsbach";
$areanames{en}->{437284} = "Oberkappel";
$areanames{en}->{437285} = "Hofkirchen\ im\ Mühlkreis";
$areanames{en}->{437286} = "Lembach\ im\ Mühlkreis";
$areanames{en}->{437287} = "Peilstein\ im\ Mühlviertel";
$areanames{en}->{437288} = "Ulrichsberg";
$areanames{en}->{437289} = "Rohrbach\ in\ Oberösterreich";
$areanames{en}->{43732} = "Linz";
$areanames{en}->{437353} = "Gaflenz";
$areanames{en}->{437355} = "Weyer";
$areanames{en}->{437357} = "Kleinreifling";
$areanames{en}->{437412} = "Ybbs\ an\ der\ Donau";
$areanames{en}->{437413} = "Marbach\ an\ der\ Donau";
$areanames{en}->{437414} = "Weins\-Isperdorf";
$areanames{en}->{437415} = "Altenmarkt\,\ Yspertal";
$areanames{en}->{437416} = "Wieselburg";
$areanames{en}->{437432} = "Strengberg";
$areanames{en}->{437433} = "Wallsee";
$areanames{en}->{437434} = "Haag";
$areanames{en}->{437435} = "St\.\ Valentin";
$areanames{en}->{437442} = "Waidhofen\ an\ der\ Ybbs";
$areanames{en}->{437443} = "Ybbsitz";
$areanames{en}->{437444} = "Opponitz";
$areanames{en}->{437445} = "Hollenstein\ an\ der\ Ybbs";
$areanames{en}->{437448} = "Kematen\ an\ der\ Ybbs";
$areanames{en}->{437471} = "Neustadtl\ an\ der\ Donau";
$areanames{en}->{437472} = "Amstetten";
$areanames{en}->{437473} = "Blindenmarkt";
$areanames{en}->{437474} = "Euratsfeld";
$areanames{en}->{437475} = "Hausmening\,\ Neuhofen\ an\ der\ Ybbs";
$areanames{en}->{437476} = "Aschbach\-Markt";
$areanames{en}->{437477} = "St\.\ Peter\ in\ der\ Au";
$areanames{en}->{437478} = "Oed\-Oehling";
$areanames{en}->{437479} = "Ardagger";
$areanames{en}->{437480} = "Langau\,\ Gaming";
$areanames{en}->{437482} = "Scheibbs";
$areanames{en}->{437483} = "Oberndorf\ an\ der\ Melk";
$areanames{en}->{437484} = "Göstling\ an\ der\ Ybbs";
$areanames{en}->{437485} = "Gaming";
$areanames{en}->{437486} = "Lunz\ am\ See";
$areanames{en}->{437487} = "Gresten";
$areanames{en}->{437488} = "Steinakirchen\ am\ Forst";
$areanames{en}->{437489} = "Purgstall\ an\ der\ Erlauf";
$areanames{en}->{437562} = "Windischgarsten";
$areanames{en}->{437563} = "Spital\ am\ Pyhrn";
$areanames{en}->{437564} = "Hinterstoder";
$areanames{en}->{437565} = "St\.\ Pankraz";
$areanames{en}->{437566} = "Rosenau\ am\ Hengstpass";
$areanames{en}->{437582} = "Kirchdorf\ an\ der\ Krems";
$areanames{en}->{437583} = "Kremsmünster";
$areanames{en}->{437584} = "Molln";
$areanames{en}->{437585} = "Klaus\ an\ der\ Pyhrnbahn";
$areanames{en}->{437586} = "Pettenbach";
$areanames{en}->{437587} = "Wartberg\ an\ der\ Krems";
$areanames{en}->{437588} = "Ried\ im\ Traunkreis";
$areanames{en}->{437612} = "Gmunden";
$areanames{en}->{437613} = "Laakirchen";
$areanames{en}->{437614} = "Vorchdorf";
$areanames{en}->{437615} = "Scharnstein";
$areanames{en}->{437616} = "Grünau\ im\ Almtal";
$areanames{en}->{437617} = "Traunkirchen";
$areanames{en}->{437618} = "Neukirchen\,\ Altmünster";
$areanames{en}->{437619} = "Kirchham";
$areanames{en}->{437662} = "Seewalchen\ am\ Attersee";
$areanames{en}->{437663} = "Steinbach\ am\ Attersee";
$areanames{en}->{437664} = "Weyregg\ am\ Attersee";
$areanames{en}->{437665} = "Unterach\ am\ Attersee";
$areanames{en}->{437666} = "Attersee";
$areanames{en}->{437667} = "St\.\ Georgen\ im\ Attergau";
$areanames{en}->{437672} = "Vöcklabruck";
$areanames{en}->{437673} = "Schwanenstadt";
$areanames{en}->{437674} = "Attnang\-Puchheim";
$areanames{en}->{437675} = "Ampflwang\ im\ Hausruckwald";
$areanames{en}->{437676} = "Ottnang\ am\ Hausruck";
$areanames{en}->{437682} = "Vöcklamarkt";
$areanames{en}->{437683} = "Frankenburg\ am\ Hausruck";
$areanames{en}->{437684} = "Frankenmarkt";
$areanames{en}->{437711} = "Suben";
$areanames{en}->{437712} = "Schärding";
$areanames{en}->{437713} = "Schardenberg";
$areanames{en}->{437714} = "Esternberg";
$areanames{en}->{437716} = "Münzkirchen";
$areanames{en}->{437717} = "St\.\ Aegidi";
$areanames{en}->{437718} = "Waldkirchen\ am\ Wesen";
$areanames{en}->{437719} = "Taufkirchen\ an\ der\ Pram";
$areanames{en}->{437722} = "Braunau\ am\ Inn";
$areanames{en}->{437723} = "Altheim";
$areanames{en}->{437724} = "Mauerkirchen";
$areanames{en}->{437727} = "Ach";
$areanames{en}->{437728} = "Schwand\ im\ Innkreis";
$areanames{en}->{437729} = "Neukirchen\ an\ der\ Enknach";
$areanames{en}->{437732} = "Haag\ am\ Hausruck";
$areanames{en}->{437733} = "Neumarkt\ im\ Hausruckkreis";
$areanames{en}->{437734} = "Hofkirchen\ an\ der\ Trattnach";
$areanames{en}->{437735} = "Gaspoltshofen";
$areanames{en}->{437736} = "Pram";
$areanames{en}->{437742} = "Mattighofen";
$areanames{en}->{437743} = "Maria\ Schmolln";
$areanames{en}->{437744} = "Munderfing";
$areanames{en}->{437745} = "Lochen";
$areanames{en}->{437746} = "Friedburg";
$areanames{en}->{437747} = "Kirchberg\ bei\ Mattighofen";
$areanames{en}->{437748} = "Eggelsberg";
$areanames{en}->{437750} = "Andrichsfurt";
$areanames{en}->{437751} = "St\.\ Martin\ im\ Innkreis";
$areanames{en}->{437752} = "Ried\ im\ Innkreis";
$areanames{en}->{437753} = "Eberschwang";
$areanames{en}->{437754} = "Waldzell";
$areanames{en}->{437755} = "Mettmach";
$areanames{en}->{437757} = "Gurten";
$areanames{en}->{437758} = "Obernberg\ am\ Inn";
$areanames{en}->{437759} = "Antiesenhofen";
$areanames{en}->{437762} = "Raab";
$areanames{en}->{437763} = "Kopfing\ im\ Innkreis";
$areanames{en}->{437764} = "Riedau";
$areanames{en}->{437765} = "Lambrechten";
$areanames{en}->{437766} = "Andorf";
$areanames{en}->{437767} = "Eggerding";
$areanames{en}->{437941} = "Neumarkt\ im\ Mühlkreis";
$areanames{en}->{437942} = "Freistadt";
$areanames{en}->{437943} = "Windhaag\ bei\ Freistadt";
$areanames{en}->{437944} = "Sandl";
$areanames{en}->{437945} = "St\.\ Oswald\ bei\ Freistadt";
$areanames{en}->{437946} = "Gutau";
$areanames{en}->{437947} = "Kefermarkt";
$areanames{en}->{437948} = "Hirschbach\ im\ Mühlkreis";
$areanames{en}->{437949} = "Rainbach\ im\ Mühlkreis";
$areanames{en}->{437952} = "Weitersfelden";
$areanames{en}->{437953} = "Liebenau";
$areanames{en}->{437954} = "St\.\ Georgen\ am\ Walde";
$areanames{en}->{437955} = "Königswiesen";
$areanames{en}->{437956} = "Unterweissenbach";

    sub new {
      my $class = shift;
      my $number = shift;
      $number =~ s/(^\+43|\D)//g;
      my $self = bless({ number => $number, formatters => $formatters, validators => $validators, areanames => \%areanames}, $class);
      return $self if ($self->is_valid());
      $number =~ s/^(?:0)//;
      $self = bless({ number => $number, formatters => $formatters, validators => $validators, areanames => \%areanames}, $class);
      return $self->is_valid() ? $self : undef;
    }
1;