# automatically generated file, don't edit



# Copyright 2011 David Cantrell, derived from data from libphonenumber
# http://code.google.com/p/libphonenumber/
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
package Number::Phone::StubCountry::TG;
use base qw(Number::Phone::StubCountry);

use strict;
use warnings;
use utf8;
our $VERSION = 1.20200904144536;

my $formatters = [
                {
                  'format' => '$1 $2 $3 $4',
                  'leading_digits' => '[279]',
                  'pattern' => '(\\d{2})(\\d{2})(\\d{2})(\\d{2})'
                }
              ];

my $validators = {
                'fixed_line' => '
          2(?:
            2[2-7]|
            3[23]|
            4[45]|
            55|
            6[67]|
            77
          )\\d{5}
        ',
                'geographic' => '
          2(?:
            2[2-7]|
            3[23]|
            4[45]|
            55|
            6[67]|
            77
          )\\d{5}
        ',
                'mobile' => '
          (?:
            7[09]|
            9[0-36-9]
          )\\d{6}
        ',
                'pager' => '',
                'personal_number' => '',
                'specialrate' => '',
                'toll_free' => '',
                'voip' => ''
              };
my %areanames = ();
$areanames{en}->{22822} = "Lome";
$areanames{en}->{22823} = "Maritime\ region";
$areanames{en}->{22824} = "Plateaux\ region";
$areanames{en}->{22825} = "Central\ region";
$areanames{en}->{22826} = "Kara\ region";
$areanames{en}->{22827} = "Savannah\ region";
$areanames{es}->{22822} = "Lomé";
$areanames{es}->{22823} = "Región\ Marítima";
$areanames{es}->{22824} = "Región\ Plateaux";
$areanames{es}->{22825} = "Región\ Central";
$areanames{es}->{22826} = "Región\ de\ Kara";
$areanames{es}->{22827} = "Región\ de\ Savannah";
$areanames{fr}->{22822} = "Lomé";
$areanames{fr}->{22823} = "Région\ Maritime";
$areanames{fr}->{22824} = "Région\ des\ Plateaux";
$areanames{fr}->{22825} = "Région\ Centrale";
$areanames{fr}->{22826} = "Région\ de\ la\ Kara";
$areanames{fr}->{22827} = "Région\ des\ Savanes";

    sub new {
      my $class = shift;
      my $number = shift;
      $number =~ s/(^\+228|\D)//g;
      my $self = bless({ number => $number, formatters => $formatters, validators => $validators, areanames => \%areanames}, $class);
        return $self->is_valid() ? $self : undef;
    }
1;