# automatically generated file, don't edit



# Copyright 2011 David Cantrell, derived from data from libphonenumber
# http://code.google.com/p/libphonenumber/
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
package Number::Phone::StubCountry::AU;
use base qw(Number::Phone::StubCountry);

use strict;
use warnings;
use utf8;
our $VERSION = 1.20200904144526;

my $formatters = [
                {
                  'format' => '$1 $2',
                  'leading_digits' => '16',
                  'national_rule' => '0$1',
                  'pattern' => '(\\d{2})(\\d{3,4})'
                },
                {
                  'format' => '$1 $2 $3',
                  'intl_format' => 'NA',
                  'leading_digits' => '13',
                  'pattern' => '(\\d{2})(\\d{2})(\\d{2})'
                },
                {
                  'format' => '$1 $2',
                  'intl_format' => 'NA',
                  'leading_digits' => '19',
                  'pattern' => '(\\d{3})(\\d{3})'
                },
                {
                  'format' => '$1 $2',
                  'intl_format' => 'NA',
                  'leading_digits' => '1802',
                  'pattern' => '(\\d{3})(\\d{4})'
                },
                {
                  'format' => '$1 $2',
                  'intl_format' => 'NA',
                  'leading_digits' => '19',
                  'pattern' => '(\\d{4})(\\d{3,4})'
                },
                {
                  'format' => '$1 $2 $3',
                  'leading_digits' => '16',
                  'national_rule' => '0$1',
                  'pattern' => '(\\d{2})(\\d{3})(\\d{2,4})'
                },
                {
                  'format' => '$1 $2 $3',
                  'leading_digits' => '
            14|
            4
          ',
                  'national_rule' => '0$1',
                  'pattern' => '(\\d{3})(\\d{3})(\\d{3})'
                },
                {
                  'format' => '$1 $2 $3',
                  'leading_digits' => '[2378]',
                  'national_rule' => '(0$1)',
                  'pattern' => '(\\d)(\\d{4})(\\d{4})'
                },
                {
                  'format' => '$1 $2 $3',
                  'leading_digits' => '
            1(?:
              30|
              [89]
            )
          ',
                  'pattern' => '(\\d{4})(\\d{3})(\\d{3})'
                }
              ];

my $validators = {
                'fixed_line' => '
          8(?:
            51(?:
              0(?:
                0[03-9]|
                [12479]\\d|
                3[2-9]|
                5[0-8]|
                6[1-9]|
                8[0-7]
              )|
              1(?:
                [0235689]\\d|
                1[0-69]|
                4[0-589]|
                7[0-47-9]
              )|
              2(?:
                0[0-7]|
                3[2-4]|
                [4-6]\\d
              )
            )|
            91(?:
              [0-57-9]\\d|
              6[0135-9]
            )\\d
          )\\d{3}|
          (?:
            2(?:
              [0-26-9]\\d|
              3[0-8]|
              4[02-9]|
              5[0135-9]
            )|
            3(?:
              [0-3589]\\d|
              4[0-578]|
              6[1-9]|
              7[0-35-9]
            )|
            7(?:
              [013-57-9]\\d|
              2[0-8]
            )|
            8(?:
              6[0-8]|
              [78]\\d|
              9[02-9]
            )
          )\\d{6}
        ',
                'geographic' => '
          8(?:
            51(?:
              0(?:
                0[03-9]|
                [12479]\\d|
                3[2-9]|
                5[0-8]|
                6[1-9]|
                8[0-7]
              )|
              1(?:
                [0235689]\\d|
                1[0-69]|
                4[0-589]|
                7[0-47-9]
              )|
              2(?:
                0[0-7]|
                3[2-4]|
                [4-6]\\d
              )
            )|
            91(?:
              [0-57-9]\\d|
              6[0135-9]
            )\\d
          )\\d{3}|
          (?:
            2(?:
              [0-26-9]\\d|
              3[0-8]|
              4[02-9]|
              5[0135-9]
            )|
            3(?:
              [0-3589]\\d|
              4[0-578]|
              6[1-9]|
              7[0-35-9]
            )|
            7(?:
              [013-57-9]\\d|
              2[0-8]
            )|
            8(?:
              6[0-8]|
              [78]\\d|
              9[02-9]
            )
          )\\d{6}
        ',
                'mobile' => '
          4(?:
            83[0-38]|
            93[0-4]
          )\\d{5}|
          4(?:
            [0-3]\\d|
            4[047-9]|
            5[0-25-9]|
            6[06-9]|
            7[02-9]|
            8[0-24-9]|
            9[0-27-9]
          )\\d{6}
        ',
                'pager' => '163\\d{2,6}',
                'personal_number' => '',
                'specialrate' => '(
          13(?:
            00\\d{3}|
            45[0-4]
          )\\d{3}|
          13\\d{4}
        )|(190[0-26]\\d{6})',
                'toll_free' => '
          180(?:
            0\\d{3}|
            2
          )\\d{3}
        ',
                'voip' => '
          14(?:
            5(?:
              1[0458]|
              [23][458]
            )|
            71\\d
          )\\d{4}
        '
              };
my %areanames = ();
$areanames{en}->{61238000} = "Bowral";
$areanames{en}->{61238001} = "Barrallier";
$areanames{en}->{61238002} = "Bevendale";
$areanames{en}->{61238003} = "Binda";
$areanames{en}->{61238004} = "Bowral";
$areanames{en}->{61238005} = "Braidwood";
$areanames{en}->{61238006} = "Breadalbane";
$areanames{en}->{61238007} = "Bundanoon";
$areanames{en}->{61238008} = "Bungonia";
$areanames{en}->{61238009} = "Crookwell";
$areanames{en}->{61238010} = "Golspie";
$areanames{en}->{61238011} = "Goulburn";
$areanames{en}->{61238012} = "Gundillion";
$areanames{en}->{61238013} = "Gunning";
$areanames{en}->{61238014} = "Lost\ River";
$areanames{en}->{61238015} = "Marulan";
$areanames{en}->{61238016} = "Nerriga";
$areanames{en}->{61238017} = "Paddys\ River";
$areanames{en}->{61238018} = "Reidsdale";
$areanames{en}->{61238019} = "Robertson";
$areanames{en}->{61238020} = "Rugby";
$areanames{en}->{61238021} = "Tarago";
$areanames{en}->{61238022} = "Taralga";
$areanames{en}->{61238023} = "Tuena";
$areanames{en}->{61238024} = "Wombeyan\ Caves";
$areanames{en}->{61238025} = "Woodhouselee";
$areanames{en}->{61238026} = "Yerrinbool";
$areanames{en}->{61238027} = "Bowral";
$areanames{en}->{61238028} = "Bowral";
$areanames{en}->{61238029} = "Bowral";
$areanames{en}->{61238030} = "Barrallier";
$areanames{en}->{61238031} = "Bevendale";
$areanames{en}->{61238032} = "Binda";
$areanames{en}->{61238033} = "Bowral";
$areanames{en}->{61238034} = "Braidwood";
$areanames{en}->{61238035} = "Breadalbane";
$areanames{en}->{61238036} = "Bundanoon";
$areanames{en}->{61238037} = "Bungonia";
$areanames{en}->{61238038} = "Crookwell";
$areanames{en}->{61238039} = "Golspie";
$areanames{en}->{61238040} = "Goulburn";
$areanames{en}->{61238041} = "Gundillion";
$areanames{en}->{61238042} = "Gunning";
$areanames{en}->{61238043} = "Lost\ River";
$areanames{en}->{61238044} = "Marulan";
$areanames{en}->{61238045} = "Nerriga";
$areanames{en}->{61238046} = "Paddys\ River";
$areanames{en}->{61238047} = "Reidsdale";
$areanames{en}->{61238048} = "Robertson";
$areanames{en}->{61238049} = "Rugby";
$areanames{en}->{61238050} = "Tarago";
$areanames{en}->{61238051} = "Taralga";
$areanames{en}->{61238052} = "Tuena";
$areanames{en}->{61238053} = "Wombeyan\ Caves";
$areanames{en}->{61238054} = "Woodhouselee";
$areanames{en}->{61238055} = "Yerrinbool";
$areanames{en}->{61238056} = "Barrallier";
$areanames{en}->{61238057} = "Bevendale";
$areanames{en}->{61238058} = "Binda";
$areanames{en}->{61238059} = "Bowral";
$areanames{en}->{61238060} = "Braidwood";
$areanames{en}->{61238061} = "Breadalbane";
$areanames{en}->{61238062} = "Bundanoon";
$areanames{en}->{61238063} = "Bungonia";
$areanames{en}->{61238064} = "Crookwell";
$areanames{en}->{61238065} = "Golspie";
$areanames{en}->{61238066} = "Goulburn";
$areanames{en}->{61238067} = "Gundillion";
$areanames{en}->{61238068} = "Gunning";
$areanames{en}->{61238069} = "Lost\ River";
$areanames{en}->{61238070} = "Marulan";
$areanames{en}->{61238071} = "Nerriga";
$areanames{en}->{61238072} = "Paddys\ River";
$areanames{en}->{61238073} = "Reidsdale";
$areanames{en}->{61238074} = "Robertson";
$areanames{en}->{61238075} = "Rugby";
$areanames{en}->{61238076} = "Tarago";
$areanames{en}->{61238077} = "Taralga";
$areanames{en}->{61238078} = "Tuena";
$areanames{en}->{61238079} = "Wombeyan\ Caves";
$areanames{en}->{61238080} = "Woodhouselee";
$areanames{en}->{61238081} = "Yerrinbool";
$areanames{en}->{61238082} = "Bowral";
$areanames{en}->{61238083} = "Bowral";
$areanames{en}->{61238084} = "Bowral";
$areanames{en}->{61238085} = "Barrallier";
$areanames{en}->{61238086} = "Bevendale";
$areanames{en}->{61238087} = "Binda";
$areanames{en}->{61238088} = "Bowral";
$areanames{en}->{61238089} = "Braidwood";
$areanames{en}->{61238090} = "Breadalbane";
$areanames{en}->{61238091} = "Bundanoon";
$areanames{en}->{61238092} = "Bungonia";
$areanames{en}->{61238093} = "Crookwell";
$areanames{en}->{61238094} = "Golspie";
$areanames{en}->{61238095} = "Goulburn";
$areanames{en}->{61238096} = "Gundillion";
$areanames{en}->{61238097} = "Gunning";
$areanames{en}->{61238098} = "Lost\ River";
$areanames{en}->{61238099} = "Marulan";
$areanames{en}->{61238100} = "Nerriga";
$areanames{en}->{61238101} = "Paddys\ River";
$areanames{en}->{61238102} = "Reidsdale";
$areanames{en}->{61238103} = "Robertson";
$areanames{en}->{61238104} = "Rugby";
$areanames{en}->{61238105} = "Tarago";
$areanames{en}->{61238106} = "Taralga";
$areanames{en}->{61238107} = "Tuena";
$areanames{en}->{61238108} = "Barrallier";
$areanames{en}->{61238109} = "Bevendale";
$areanames{en}->{61238110} = "Binda";
$areanames{en}->{61238111} = "Bowral";
$areanames{en}->{61238112} = "Braidwood";
$areanames{en}->{61238113} = "Breadalbane";
$areanames{en}->{61238114} = "Bundanoon";
$areanames{en}->{61238115} = "Bungonia";
$areanames{en}->{61238116} = "Crookwell";
$areanames{en}->{61238117} = "Golspie";
$areanames{en}->{61238118} = "Goulburn";
$areanames{en}->{61238119} = "Gundillion";
$areanames{en}->{61238120} = "Gunning";
$areanames{en}->{61238121} = "Lost\ River";
$areanames{en}->{61238122} = "Marulan";
$areanames{en}->{61238123} = "Nerriga";
$areanames{en}->{61238124} = "Paddys\ River";
$areanames{en}->{61238125} = "Reidsdale";
$areanames{en}->{61238126} = "Robertson";
$areanames{en}->{61238127} = "Rugby";
$areanames{en}->{61238128} = "Tarago";
$areanames{en}->{61238129} = "Taralga";
$areanames{en}->{61238130} = "Tuena";
$areanames{en}->{61238131} = "Wombeyan\ Caves";
$areanames{en}->{61238132} = "Woodhouselee";
$areanames{en}->{61238133} = "Yerrinbool";
$areanames{en}->{61238134} = "Wombeyan\ Caves";
$areanames{en}->{61238135} = "Woodhouselee";
$areanames{en}->{61238136} = "Yerrinbool";
$areanames{en}->{61238137} = "Barrallier";
$areanames{en}->{61238138} = "Bevendale";
$areanames{en}->{61238139} = "Binda";
$areanames{en}->{61238140} = "Bowral";
$areanames{en}->{61238141} = "Braidwood";
$areanames{en}->{61238142} = "Breadalbane";
$areanames{en}->{61238143} = "Bundanoon";
$areanames{en}->{61238144} = "Bungonia";
$areanames{en}->{61238145} = "Crookwell";
$areanames{en}->{61238146} = "Golspie";
$areanames{en}->{61238147} = "Goulburn";
$areanames{en}->{61238148} = "Gundillion";
$areanames{en}->{61238149} = "Gunning";
$areanames{en}->{61238150} = "Lost\ River";
$areanames{en}->{61238151} = "Marulan";
$areanames{en}->{61238152} = "Nerriga";
$areanames{en}->{61238153} = "Paddys\ River";
$areanames{en}->{61238154} = "Reidsdale";
$areanames{en}->{61238155} = "Robertson";
$areanames{en}->{61238156} = "Rugby";
$areanames{en}->{61238157} = "Tarago";
$areanames{en}->{61238158} = "Taralga";
$areanames{en}->{61238159} = "Tuena";
$areanames{en}->{61238160} = "Wombeyan\ Caves";
$areanames{en}->{61238161} = "Woodhouselee";
$areanames{en}->{61238162} = "Yerrinbool";
$areanames{en}->{61238163} = "Barrallier";
$areanames{en}->{61238164} = "Bevendale";
$areanames{en}->{61238165} = "Binda";
$areanames{en}->{61238166} = "Bowral";
$areanames{en}->{61238167} = "Braidwood";
$areanames{en}->{61238168} = "Breadalbane";
$areanames{en}->{61238169} = "Bundanoon";
$areanames{en}->{61238170} = "Bungonia";
$areanames{en}->{61238171} = "Crookwell";
$areanames{en}->{61238172} = "Golspie";
$areanames{en}->{61238173} = "Goulburn";
$areanames{en}->{61238174} = "Gundillion";
$areanames{en}->{61238175} = "Gunning";
$areanames{en}->{61238176} = "Lost\ River";
$areanames{en}->{61238177} = "Marulan";
$areanames{en}->{61238178} = "Nerriga";
$areanames{en}->{61238179} = "Paddys\ River";
$areanames{en}->{61238180} = "Reidsdale";
$areanames{en}->{61238181} = "Robertson";
$areanames{en}->{61238182} = "Rugby";
$areanames{en}->{61238183} = "Tarago";
$areanames{en}->{61238184} = "Taralga";
$areanames{en}->{61238185} = "Tuena";
$areanames{en}->{61238186} = "Wombeyan\ Caves";
$areanames{en}->{61238187} = "Woodhouselee";
$areanames{en}->{61238188} = "Yerrinbool";
$areanames{en}->{61238189} = "Bowral";
$areanames{en}->{61238190} = "Barrallier";
$areanames{en}->{61238191} = "Bevendale";
$areanames{en}->{61238192} = "Binda";
$areanames{en}->{61238193} = "Bowral";
$areanames{en}->{61238194} = "Braidwood";
$areanames{en}->{61238195} = "Breadalbane";
$areanames{en}->{61238196} = "Bundanoon";
$areanames{en}->{61238197} = "Bungonia";
$areanames{en}->{61238198} = "Crookwell";
$areanames{en}->{61238199} = "Golspie";
$areanames{en}->{61238200} = "Goulburn";
$areanames{en}->{61238201} = "Gundillion";
$areanames{en}->{61238202} = "Gunning";
$areanames{en}->{61238203} = "Lost\ River";
$areanames{en}->{61238204} = "Marulan";
$areanames{en}->{61238205} = "Nerriga";
$areanames{en}->{61238206} = "Paddys\ River";
$areanames{en}->{61238207} = "Reidsdale";
$areanames{en}->{61238208} = "Robertson";
$areanames{en}->{61238209} = "Rugby";
$areanames{en}->{61238210} = "Tarago";
$areanames{en}->{61238211} = "Taralga";
$areanames{en}->{61238212} = "Tuena";
$areanames{en}->{61238213} = "Wombeyan\ Caves";
$areanames{en}->{61238214} = "Woodhouselee";
$areanames{en}->{61238215} = "Yerrinbool";
$areanames{en}->{61240000} = "Bandon\ Grove";
$areanames{en}->{61240001} = "Branxton";
$areanames{en}->{61240002} = "Bulahdelah";
$areanames{en}->{61240003} = "Cessnock";
$areanames{en}->{61240004} = "Clarence\ Town";
$areanames{en}->{61240005} = "Dungog";
$areanames{en}->{61240006} = "East\ Gresford";
$areanames{en}->{61240007} = "Eccleston";
$areanames{en}->{61240008} = "Karuah";
$areanames{en}->{61240009} = "Laguna";
$areanames{en}->{61240010} = "Newcastle";
$areanames{en}->{61240011} = "Bandon\ Grove";
$areanames{en}->{61240012} = "Branxton";
$areanames{en}->{61240013} = "Bulahdelah";
$areanames{en}->{61240014} = "Cessnock";
$areanames{en}->{61240015} = "Clarence\ Town";
$areanames{en}->{61240016} = "Dungog";
$areanames{en}->{61240017} = "East\ Gresford";
$areanames{en}->{61240018} = "Eccleston";
$areanames{en}->{61240019} = "Karuah";
$areanames{en}->{61240020} = "Laguna";
$areanames{en}->{61240021} = "Maitland";
$areanames{en}->{61240022} = "Mulbring";
$areanames{en}->{61240023} = "Nelson\ Bay";
$areanames{en}->{61240024} = "Newcastle";
$areanames{en}->{61240025} = "Raymond\ Terrace";
$areanames{en}->{61240026} = "Stroud";
$areanames{en}->{61240027} = "Swansea";
$areanames{en}->{61240028} = "Tea\ Gardens";
$areanames{en}->{61240029} = "Wards\ River";
$areanames{en}->{61240030} = "Wootton";
$areanames{en}->{61240031} = "Bandon\ Grove";
$areanames{en}->{61240032} = "Branxton";
$areanames{en}->{61240033} = "Bulahdelah";
$areanames{en}->{61240034} = "Cessnock";
$areanames{en}->{61240035} = "Clarence\ Town";
$areanames{en}->{61240036} = "Dungog";
$areanames{en}->{61240037} = "East\ Gresford";
$areanames{en}->{61240038} = "Eccleston";
$areanames{en}->{61240039} = "Karuah";
$areanames{en}->{61240040} = "Laguna";
$areanames{en}->{61240041} = "Maitland";
$areanames{en}->{61240042} = "Mulbring";
$areanames{en}->{61240043} = "Nelson\ Bay";
$areanames{en}->{61240044} = "Raymond\ Terrace";
$areanames{en}->{61240045} = "Maitland";
$areanames{en}->{61240046} = "Newcastle";
$areanames{en}->{61240047} = "Raymond\ Terrace";
$areanames{en}->{61240048} = "Stroud";
$areanames{en}->{61240049} = "Swansea";
$areanames{en}->{61240050} = "Tea\ Gardens";
$areanames{en}->{61240051} = "Wards\ River";
$areanames{en}->{61240052} = "Wootton";
$areanames{en}->{61240053} = "Bandon\ Grove";
$areanames{en}->{61240054} = "Branxton";
$areanames{en}->{61240055} = "Bulahdelah";
$areanames{en}->{61240056} = "Cessnock";
$areanames{en}->{61240057} = "Clarence\ Town";
$areanames{en}->{61240058} = "Dungog";
$areanames{en}->{61240059} = "East\ Gresford";
$areanames{en}->{61240060} = "Eccleston";
$areanames{en}->{61240061} = "Karuah";
$areanames{en}->{61240062} = "Laguna";
$areanames{en}->{61240063} = "Maitland";
$areanames{en}->{61240064} = "Mulbring";
$areanames{en}->{61240065} = "Nelson\ Bay";
$areanames{en}->{61240066} = "Raymond\ Terrace";
$areanames{en}->{61240067} = "Stroud";
$areanames{en}->{61240068} = "Swansea";
$areanames{en}->{61240069} = "Tea\ Gardens";
$areanames{en}->{61240070} = "Wards\ River";
$areanames{en}->{61240071} = "Wootton";
$areanames{en}->{61240072} = "Bandon\ Grove";
$areanames{en}->{61240073} = "Branxton";
$areanames{en}->{61240074} = "Bulahdelah";
$areanames{en}->{61240075} = "Cessnock";
$areanames{en}->{61240076} = "Clarence\ Town";
$areanames{en}->{61240077} = "Dungog";
$areanames{en}->{61240078} = "East\ Gresford";
$areanames{en}->{61240079} = "Eccleston";
$areanames{en}->{61240080} = "Karuah";
$areanames{en}->{61240081} = "Laguna";
$areanames{en}->{61240082} = "Maitland";
$areanames{en}->{61240083} = "Mulbring";
$areanames{en}->{61240084} = "Nelson\ Bay";
$areanames{en}->{61240085} = "Raymond\ Terrace";
$areanames{en}->{61240086} = "Stroud";
$areanames{en}->{61240087} = "Swansea";
$areanames{en}->{61240088} = "Tea\ Gardens";
$areanames{en}->{61240089} = "Wards\ River";
$areanames{en}->{61240090} = "Wootton";
$areanames{en}->{61240091} = "Newcastle";
$areanames{en}->{61240092} = "Branxton";
$areanames{en}->{61240093} = "Bulahdelah";
$areanames{en}->{61240094} = "Cessnock";
$areanames{en}->{61240095} = "Clarence\ Town";
$areanames{en}->{61240096} = "Dungog";
$areanames{en}->{61240097} = "East\ Gresford";
$areanames{en}->{61240098} = "Eccleston";
$areanames{en}->{61240099} = "Karuah";
$areanames{en}->{61240100} = "Laguna";
$areanames{en}->{61240101} = "Maitland";
$areanames{en}->{61240102} = "Mulbring";
$areanames{en}->{61240103} = "Nelson\ Bay";
$areanames{en}->{61240104} = "Raymond\ Terrace";
$areanames{en}->{61240105} = "Stroud";
$areanames{en}->{61240106} = "Swansea";
$areanames{en}->{61240107} = "Tea\ Gardens";
$areanames{en}->{61240108} = "Wards\ River";
$areanames{en}->{61240109} = "Wootton";
$areanames{en}->{61240110} = "Bandon\ Grove";
$areanames{en}->{61240111} = "Bandon\ Grove";
$areanames{en}->{61240112} = "Branxton";
$areanames{en}->{61240113} = "Bulahdelah";
$areanames{en}->{61240114} = "Cessnock";
$areanames{en}->{61240115} = "Clarence\ Town";
$areanames{en}->{61240116} = "Dungog";
$areanames{en}->{61240117} = "East\ Gresford";
$areanames{en}->{61240118} = "Eccleston";
$areanames{en}->{61240119} = "Karuah";
$areanames{en}->{61240120} = "Laguna";
$areanames{en}->{61240121} = "Maitland";
$areanames{en}->{61240122} = "Mulbring";
$areanames{en}->{61240123} = "Nelson\ Bay";
$areanames{en}->{61240124} = "Newcastle";
$areanames{en}->{61240125} = "Raymond\ Terrace";
$areanames{en}->{61240126} = "Stroud";
$areanames{en}->{61240127} = "Swansea";
$areanames{en}->{61240128} = "Tea\ Gardens";
$areanames{en}->{61240129} = "Wards\ River";
$areanames{en}->{61240130} = "Wootton";
$areanames{en}->{61240131} = "Newcastle";
$areanames{en}->{61240132} = "Newcastle";
$areanames{en}->{61240133} = "Newcastle";
$areanames{en}->{61240134} = "Newcastle";
$areanames{en}->{61240135} = "Cessnock";
$areanames{en}->{61240136} = "Maitland";
$areanames{en}->{61240137} = "Nelson\ Bay";
$areanames{en}->{61240138} = "Raymond\ Terrace";
$areanames{en}->{61240139} = "Bandon\ Grove";
$areanames{en}->{6124014} = "Newcastle";
$areanames{en}->{6124015} = "Maitland";
$areanames{en}->{6124016} = "Newcastle";
$areanames{en}->{6124017} = "Newcastle";
$areanames{en}->{61240180} = "Bulahdelah";
$areanames{en}->{61240181} = "Cessnock";
$areanames{en}->{61240182} = "Clarence\ Town";
$areanames{en}->{61240183} = "Dungog";
$areanames{en}->{61240184} = "East\ Gresford";
$areanames{en}->{61240185} = "Karuah";
$areanames{en}->{61240186} = "Laguna";
$areanames{en}->{61240187} = "Maitland";
$areanames{en}->{61240188} = "Mulbring";
$areanames{en}->{61240189} = "Nelson\ Bay";
$areanames{en}->{61240190} = "Raymond\ Terrace";
$areanames{en}->{61240191} = "Stroud";
$areanames{en}->{61240192} = "Swansea";
$areanames{en}->{61240193} = "Tea\ Gardens";
$areanames{en}->{61240194} = "Wootton";
$areanames{en}->{61240195} = "Wards\ River";
$areanames{en}->{61240196} = "Bandon\ Grove";
$areanames{en}->{61240197} = "Branxton";
$areanames{en}->{61240198} = "Eccleston";
$areanames{en}->{61240199} = "Cessnock";
$areanames{en}->{61240200} = "Cessnock";
$areanames{en}->{61240201} = "Maitland";
$areanames{en}->{61240202} = "Maitland";
$areanames{en}->{61240203} = "East\ Gresford";
$areanames{en}->{61240204} = "East\ Gresford";
$areanames{en}->{61240205} = "Nelson\ Bay";
$areanames{en}->{61240206} = "Nelson\ Bay";
$areanames{en}->{61240207} = "Raymond\ Terrace";
$areanames{en}->{61240208} = "Raymond\ Terrace";
$areanames{en}->{61240209} = "Mulbring";
$areanames{en}->{61240210} = "Nelson\ Bay";
$areanames{en}->{61240211} = "Newcastle";
$areanames{en}->{61240212} = "Raymond\ Terrace";
$areanames{en}->{61240213} = "Eccleston";
$areanames{en}->{61240214} = "Swansea";
$areanames{en}->{61240215} = "Tea\ Gardens";
$areanames{en}->{61240216} = "Branxton";
$areanames{en}->{61240217} = "Wootton";
$areanames{en}->{61240218} = "Bulahdelah";
$areanames{en}->{61240219} = "Bulahdelah";
$areanames{en}->{61240220} = "Cessnock";
$areanames{en}->{61240221} = "Cessnock";
$areanames{en}->{61240222} = "Clarence\ Town";
$areanames{en}->{61240223} = "Dungog";
$areanames{en}->{61240224} = "East\ Gresford";
$areanames{en}->{61240225} = "Karuah";
$areanames{en}->{61240226} = "Laguna";
$areanames{en}->{61240227} = "Maitland";
$areanames{en}->{61240228} = "Newcastle";
$areanames{en}->{61240229} = "Newcastle";
$areanames{en}->{6124023} = "Newcastle";
$areanames{en}->{61240240} = "Branxton";
$areanames{en}->{61240241} = "Cessnock";
$areanames{en}->{61240242} = "Nelson\ Bay";
$areanames{en}->{61240243} = "Raymond\ Terrace";
$areanames{en}->{61240244} = "Swansea";
$areanames{en}->{61240245} = "Stroud";
$areanames{en}->{61240246} = "Stroud";
$areanames{en}->{61240247} = "Wards\ River";
$areanames{en}->{61240248} = "Wards\ River";
$areanames{en}->{61240249} = "Branxton";
$areanames{en}->{61240250} = "Branxton";
$areanames{en}->{61240251} = "Bulahdelah";
$areanames{en}->{61240252} = "Bulahdelah";
$areanames{en}->{61240253} = "Cessnock";
$areanames{en}->{61240254} = "Cessnock";
$areanames{en}->{61240255} = "Clarence\ Town";
$areanames{en}->{61240256} = "Clarence\ Town";
$areanames{en}->{61240257} = "Dungog";
$areanames{en}->{61240258} = "Dungog";
$areanames{en}->{61240259} = "Karuah";
$areanames{en}->{61240260} = "Karuah";
$areanames{en}->{61240261} = "Laguna";
$areanames{en}->{61240262} = "Laguna";
$areanames{en}->{61240263} = "Maitland";
$areanames{en}->{61240264} = "Maitland";
$areanames{en}->{61240265} = "Mulbring";
$areanames{en}->{61240266} = "Mulbring";
$areanames{en}->{61240267} = "Newcastle";
$areanames{en}->{61240268} = "Newcastle";
$areanames{en}->{61240269} = "Swansea";
$areanames{en}->{61240270} = "Swansea";
$areanames{en}->{61240271} = "Tea\ Gardens";
$areanames{en}->{61240272} = "Tea\ Gardens";
$areanames{en}->{61240273} = "Wootton";
$areanames{en}->{61240274} = "Wootton";
$areanames{en}->{61240275} = "Newcastle";
$areanames{en}->{61240276} = "Bandon\ Grove";
$areanames{en}->{61240277} = "Bandon\ Grove";
$areanames{en}->{61240278} = "Eccleston";
$areanames{en}->{61240279} = "Eccleston";
$areanames{en}->{6124028} = "Newcastle";
$areanames{en}->{6124029} = "Newcastle";
$areanames{en}->{6124030} = "Maitland";
$areanames{en}->{6124031} = "Newcastle";
$areanames{en}->{6124032} = "Newcastle";
$areanames{en}->{6124033} = "Newcastle";
$areanames{en}->{61240330} = "Maitland";
$areanames{en}->{61240331} = "Maitland";
$areanames{en}->{61240332} = "Nelson\ Bay";
$areanames{en}->{61240333} = "Nelson\ Bay";
$areanames{en}->{6124034} = "Newcastle";
$areanames{en}->{61240350} = "Nelson\ Bay";
$areanames{en}->{61240351} = "Nelson\ Bay";
$areanames{en}->{61240352} = "Nelson\ Bay";
$areanames{en}->{61240353} = "Newcastle";
$areanames{en}->{61240354} = "Newcastle";
$areanames{en}->{61240355} = "Newcastle";
$areanames{en}->{61240356} = "Newcastle";
$areanames{en}->{61240357} = "Newcastle";
$areanames{en}->{61240358} = "Maitland";
$areanames{en}->{61240359} = "Maitland";
$areanames{en}->{61240360} = "Eccleston";
$areanames{en}->{61240361} = "Newcastle";
$areanames{en}->{61240362} = "Newcastle";
$areanames{en}->{61240363} = "Newcastle";
$areanames{en}->{61240364} = "Clarence\ Town";
$areanames{en}->{61240365} = "Maitland";
$areanames{en}->{61240366} = "Karuah";
$areanames{en}->{61240367} = "Wards\ River";
$areanames{en}->{61240368} = "Wootton";
$areanames{en}->{61240369} = "Karuah";
$areanames{en}->{6124037} = "Newcastle";
$areanames{en}->{61240380} = "Laguna";
$areanames{en}->{61240381} = "Newcastle";
$areanames{en}->{61240382} = "Mulbring";
$areanames{en}->{61240383} = "Branxton";
$areanames{en}->{61240384} = "Bulahdelah";
$areanames{en}->{61240385} = "Laguna";
$areanames{en}->{61240386} = "Raymond\ Terrace";
$areanames{en}->{61240387} = "Dungog";
$areanames{en}->{61240388} = "Eccleston";
$areanames{en}->{61240389} = "Maitland";
$areanames{en}->{61240390} = "Mulbring";
$areanames{en}->{61240391} = "Tea\ Gardens";
$areanames{en}->{61240392} = "East\ Gresford";
$areanames{en}->{61240393} = "Nelson\ Bay";
$areanames{en}->{61240394} = "Stroud";
$areanames{en}->{61240395} = "Bandon\ Grove";
$areanames{en}->{61240396} = "Swansea";
$areanames{en}->{61240397} = "Cessnock";
$areanames{en}->{61240398} = "Newcastle";
$areanames{en}->{61240399} = "Nelson\ Bay";
$areanames{en}->{61240400} = "Newcastle";
$areanames{en}->{61240401} = "Newcastle";
$areanames{en}->{61240402} = "Clarence\ Town";
$areanames{en}->{61240403} = "Maitland";
$areanames{en}->{61240404} = "Nelson\ Bay";
$areanames{en}->{61240405} = "Newcastle";
$areanames{en}->{61240406} = "Swansea";
$areanames{en}->{61240407} = "Swansea";
$areanames{en}->{61240408} = "Maitland";
$areanames{en}->{61240409} = "Newcastle";
$areanames{en}->{6124041} = "Newcastle";
$areanames{en}->{61240420} = "Newcastle";
$areanames{en}->{61240421} = "Newcastle";
$areanames{en}->{61240422} = "Karuah";
$areanames{en}->{61240423} = "Wards\ River";
$areanames{en}->{61240424} = "Wootton";
$areanames{en}->{61240425} = "East\ Gresford";
$areanames{en}->{61240426} = "Mulbring";
$areanames{en}->{61240427} = "Branxton";
$areanames{en}->{61240428} = "Bulahdelah";
$areanames{en}->{61240429} = "Raymond\ Terrace";
$areanames{en}->{61240430} = "Stroud";
$areanames{en}->{61240431} = "Laguna";
$areanames{en}->{61240432} = "Raymond\ Terrace";
$areanames{en}->{61240433} = "Dungog";
$areanames{en}->{61240434} = "Eccleston";
$areanames{en}->{61240435} = "Tea\ Gardens";
$areanames{en}->{61240436} = "East\ Gresford";
$areanames{en}->{61240437} = "Nelson\ Bay";
$areanames{en}->{61240438} = "Stroud";
$areanames{en}->{61240439} = "Swansea";
$areanames{en}->{6124044} = "Newcastle";
$areanames{en}->{61240446} = "Bandon\ Grove";
$areanames{en}->{61240447} = "Swansea";
$areanames{en}->{61240448} = "Cessnock";
$areanames{en}->{61240449} = "Tea\ Gardens";
$areanames{en}->{61240450} = "Wards\ River";
$areanames{en}->{61240451} = "Dungog";
$areanames{en}->{61240452} = "Clarence\ Town";
$areanames{en}->{61240453} = "Eccleston";
$areanames{en}->{61240454} = "Tea\ Gardens";
$areanames{en}->{61240455} = "Karuah";
$areanames{en}->{61240456} = "Wards\ River";
$areanames{en}->{61240457} = "Wootton";
$areanames{en}->{61240458} = "Mulbring";
$areanames{en}->{61240459} = "Wootton";
$areanames{en}->{61240460} = "Newcastle";
$areanames{en}->{61240461} = "Branxton";
$areanames{en}->{61240462} = "Bulahdelah";
$areanames{en}->{61240463} = "Laguna";
$areanames{en}->{61240464} = "Stroud";
$areanames{en}->{61240465} = "Bandon\ Grove";
$areanames{en}->{61240466} = "Swansea";
$areanames{en}->{61240467} = "Newcastle";
$areanames{en}->{61240468} = "Maitland";
$areanames{en}->{61240469} = "Maitland";
$areanames{en}->{6124047} = "Newcastle";
$areanames{en}->{6124048} = "Newcastle";
$areanames{en}->{6124049} = "Newcastle";
$areanames{en}->{61240500} = "Newcastle";
$areanames{en}->{61240501} = "Newcastle";
$areanames{en}->{61240502} = "Newcastle";
$areanames{en}->{61240503} = "Newcastle";
$areanames{en}->{61240504} = "Bandon\ Grove";
$areanames{en}->{61240505} = "Cessnock";
$areanames{en}->{61240506} = "Cessnock";
$areanames{en}->{61240507} = "Maitland";
$areanames{en}->{61240508} = "Maitland";
$areanames{en}->{61240509} = "Maitland";
$areanames{en}->{61240510} = "Branxton";
$areanames{en}->{61240511} = "Bulahdelah";
$areanames{en}->{61240512} = "Cessnock";
$areanames{en}->{61240513} = "Clarence\ Town";
$areanames{en}->{61240514} = "Dungog";
$areanames{en}->{61240515} = "East\ Gresford";
$areanames{en}->{61240516} = "Eccleston";
$areanames{en}->{61240517} = "Karuah";
$areanames{en}->{61240518} = "Laguna";
$areanames{en}->{61240519} = "Maitland";
$areanames{en}->{61240520} = "Nelson\ Bay";
$areanames{en}->{61240521} = "Nelson\ Bay";
$areanames{en}->{61240522} = "Nelson\ Bay";
$areanames{en}->{61240523} = "Nelson\ Bay";
$areanames{en}->{61240524} = "Nelson\ Bay";
$areanames{en}->{61240525} = "Branxton";
$areanames{en}->{61240526} = "Bulahdelah";
$areanames{en}->{61240527} = "Eccleston";
$areanames{en}->{61240528} = "Maitland";
$areanames{en}->{61240529} = "Maitland";
$areanames{en}->{6124053} = "Newcastle";
$areanames{en}->{61240540} = "Mulbring";
$areanames{en}->{61240541} = "Nelson\ Bay";
$areanames{en}->{61240542} = "Newcastle";
$areanames{en}->{61240543} = "Raymond\ Terrace";
$areanames{en}->{61240544} = "Stroud";
$areanames{en}->{61240545} = "Swansea";
$areanames{en}->{61240546} = "Tea\ Gardens";
$areanames{en}->{61240547} = "Wards\ River";
$areanames{en}->{61240548} = "Wootton";
$areanames{en}->{61240549} = "Newcastle";
$areanames{en}->{6124055} = "Newcastle";
$areanames{en}->{6124056} = "Newcastle";
$areanames{en}->{6124057} = "Maitland";
$areanames{en}->{61240580} = "Maitland";
$areanames{en}->{61240581} = "Newcastle";
$areanames{en}->{61240582} = "Newcastle";
$areanames{en}->{61240583} = "Newcastle";
$areanames{en}->{61240584} = "Newcastle";
$areanames{en}->{61240585} = "Newcastle";
$areanames{en}->{61240586} = "Bandon\ Grove";
$areanames{en}->{61240587} = "Branxton";
$areanames{en}->{61240588} = "Bulahdelah";
$areanames{en}->{61240589} = "Cessnock";
$areanames{en}->{61240590} = "Clarence\ Town";
$areanames{en}->{61240591} = "Dungog";
$areanames{en}->{61240592} = "East\ Gresford";
$areanames{en}->{61240593} = "Eccleston";
$areanames{en}->{61240594} = "Karuah";
$areanames{en}->{61240595} = "Laguna";
$areanames{en}->{61240596} = "Maitland";
$areanames{en}->{61240597} = "Mulbring";
$areanames{en}->{61240598} = "Nelson\ Bay";
$areanames{en}->{61240599} = "Newcastle";
$areanames{en}->{61240600} = "Raymond\ Terrace";
$areanames{en}->{61240601} = "Stroud";
$areanames{en}->{61240602} = "Swansea";
$areanames{en}->{61240603} = "Tea\ Gardens";
$areanames{en}->{61240604} = "Wards\ River";
$areanames{en}->{61240605} = "Wootton";
$areanames{en}->{61240606} = "Bandon\ Grove";
$areanames{en}->{61240607} = "Branxton";
$areanames{en}->{61240608} = "Bulahdelah";
$areanames{en}->{61240609} = "Cessnock";
$areanames{en}->{61240610} = "Clarence\ Town";
$areanames{en}->{61240611} = "Tea\ Gardens";
$areanames{en}->{61240612} = "Dungog";
$areanames{en}->{61240613} = "East\ Gresford";
$areanames{en}->{61240614} = "Eccleston";
$areanames{en}->{61240615} = "Karuah";
$areanames{en}->{61240616} = "Laguna";
$areanames{en}->{61240617} = "Maitland";
$areanames{en}->{61240618} = "Mulbring";
$areanames{en}->{61240619} = "Nelson\ Bay";
$areanames{en}->{61240620} = "Newcastle";
$areanames{en}->{61240621} = "Raymond\ Terrace";
$areanames{en}->{61240622} = "Stroud";
$areanames{en}->{61240623} = "Swansea";
$areanames{en}->{61240624} = "Tea\ Gardens";
$areanames{en}->{61240625} = "Wards\ River";
$areanames{en}->{61240626} = "Wootton";
$areanames{en}->{61240627} = "Newcastle";
$areanames{en}->{61240628} = "Newcastle";
$areanames{en}->{61240629} = "Newcastle";
$areanames{en}->{6124063} = "Newcastle";
$areanames{en}->{61240636} = "Maitland";
$areanames{en}->{61240637} = "Maitland";
$areanames{en}->{61240638} = "Maitland";
$areanames{en}->{61240639} = "Maitland";
$areanames{en}->{6124064} = "Newcastle";
$areanames{en}->{61240650} = "Nelson\ Bay";
$areanames{en}->{61240651} = "Nelson\ Bay";
$areanames{en}->{61240652} = "Bandon\ Grove";
$areanames{en}->{61240653} = "Branxton";
$areanames{en}->{61240654} = "Bulahdelah";
$areanames{en}->{61240655} = "Cessnock";
$areanames{en}->{61240656} = "Clarence\ Town";
$areanames{en}->{61240657} = "Dungog";
$areanames{en}->{61240658} = "East\ Gresford";
$areanames{en}->{61240659} = "Eccleston";
$areanames{en}->{61240660} = "Karuah";
$areanames{en}->{61240661} = "Laguna";
$areanames{en}->{61240662} = "Maitland";
$areanames{en}->{61240663} = "Mulbring";
$areanames{en}->{61240664} = "Nelson\ Bay";
$areanames{en}->{61240665} = "Newcastle";
$areanames{en}->{61240666} = "Raymond\ Terrace";
$areanames{en}->{61240667} = "Stroud";
$areanames{en}->{61240668} = "Swansea";
$areanames{en}->{61240669} = "Tea\ Gardens";
$areanames{en}->{6124067} = "Newcastle";
$areanames{en}->{61240670} = "Wards\ River";
$areanames{en}->{61240671} = "Wootton";
$areanames{en}->{61240680} = "Maitland";
$areanames{en}->{61240681} = "Maitland";
$areanames{en}->{61240682} = "Clarence\ Town";
$areanames{en}->{61240683} = "Clarence\ Town";
$areanames{en}->{61240684} = "Clarence\ Town";
$areanames{en}->{61240685} = "Cessnock";
$areanames{en}->{61240686} = "Cessnock";
$areanames{en}->{61240687} = "Cessnock";
$areanames{en}->{61240688} = "Cessnock";
$areanames{en}->{61240689} = "Cessnock";
$areanames{en}->{61240692} = "Bandon\ Grove";
$areanames{en}->{61240693} = "Branxton";
$areanames{en}->{61240694} = "Bulahdelah";
$areanames{en}->{61240695} = "Cessnock";
$areanames{en}->{61240696} = "Clarence\ Town";
$areanames{en}->{61240697} = "Dungog";
$areanames{en}->{61240698} = "East\ Gresford";
$areanames{en}->{61240699} = "Eccleston";
$areanames{en}->{61240700} = "Karuah";
$areanames{en}->{61240701} = "Laguna";
$areanames{en}->{61240702} = "Maitland";
$areanames{en}->{61240703} = "Mulbring";
$areanames{en}->{61240704} = "Nelson\ Bay";
$areanames{en}->{61240705} = "Newcastle";
$areanames{en}->{61240706} = "Raymond\ Terrace";
$areanames{en}->{61240707} = "Stroud";
$areanames{en}->{61240708} = "Swansea";
$areanames{en}->{61240709} = "Tea\ Gardens";
$areanames{en}->{61240710} = "Wards\ River";
$areanames{en}->{61240711} = "Wootton";
$areanames{en}->{61240712} = "Bandon\ Grove";
$areanames{en}->{61240713} = "Branxton";
$areanames{en}->{61240714} = "Bulahdelah";
$areanames{en}->{61240715} = "Cessnock";
$areanames{en}->{61240716} = "Clarence\ Town";
$areanames{en}->{61240717} = "Dungog";
$areanames{en}->{61240718} = "East\ Gresford";
$areanames{en}->{61240719} = "Eccleston";
$areanames{en}->{61240720} = "Karuah";
$areanames{en}->{61240721} = "Laguna";
$areanames{en}->{61240722} = "Maitland";
$areanames{en}->{61240723} = "Mulbring";
$areanames{en}->{61240724} = "Nelson\ Bay";
$areanames{en}->{61240725} = "Newcastle";
$areanames{en}->{61240726} = "Raymond\ Terrace";
$areanames{en}->{61240727} = "Stroud";
$areanames{en}->{61240728} = "Swansea";
$areanames{en}->{61240729} = "Tea\ Gardens";
$areanames{en}->{61240730} = "Wards\ River";
$areanames{en}->{61240731} = "Wootton";
$areanames{en}->{61240732} = "Bandon\ Grove";
$areanames{en}->{61240733} = "Branxton";
$areanames{en}->{61240734} = "Bulahdelah";
$areanames{en}->{61240735} = "Cessnock";
$areanames{en}->{61240736} = "Clarence\ Town";
$areanames{en}->{61240737} = "Dungog";
$areanames{en}->{61240738} = "East\ Gresford";
$areanames{en}->{61240739} = "Eccleston";
$areanames{en}->{61240740} = "Karuah";
$areanames{en}->{61240741} = "Laguna";
$areanames{en}->{61240742} = "Maitland";
$areanames{en}->{61240743} = "Mulbring";
$areanames{en}->{61240744} = "Nelson\ Bay";
$areanames{en}->{61240745} = "Newcastle";
$areanames{en}->{61240746} = "Raymond\ Terrace";
$areanames{en}->{61240747} = "Stroud";
$areanames{en}->{61240748} = "Swansea";
$areanames{en}->{61240749} = "Tea\ Gardens";
$areanames{en}->{61240750} = "Wards\ River";
$areanames{en}->{61240751} = "Wootton";
$areanames{en}->{61240752} = "Newcastle";
$areanames{en}->{61240753} = "Bandon\ Grove";
$areanames{en}->{61240754} = "Branxton";
$areanames{en}->{61240755} = "Bulahdelah";
$areanames{en}->{61240756} = "Cessnock";
$areanames{en}->{61240757} = "Clarence\ Town";
$areanames{en}->{61240758} = "Dungog";
$areanames{en}->{61240759} = "East\ Gresford";
$areanames{en}->{61240760} = "Eccleston";
$areanames{en}->{61240761} = "Karuah";
$areanames{en}->{61240762} = "Laguna";
$areanames{en}->{61240763} = "Maitland";
$areanames{en}->{61240764} = "Mulbring";
$areanames{en}->{61240765} = "Nelson\ Bay";
$areanames{en}->{61240766} = "Newcastle";
$areanames{en}->{61240767} = "Raymond\ Terrace";
$areanames{en}->{61240768} = "Stroud";
$areanames{en}->{61240769} = "Swansea";
$areanames{en}->{61240770} = "Tea\ Gardens";
$areanames{en}->{61240771} = "Wards\ River";
$areanames{en}->{61240772} = "Wootton";
$areanames{en}->{6124088} = "Newcastle";
$areanames{en}->{6124089} = "Newcastle";
$areanames{en}->{61240896} = "Raymond\ Terrace";
$areanames{en}->{61240897} = "Raymond\ Terrace";
$areanames{en}->{61240898} = "Raymond\ Terrace";
$areanames{en}->{6124099} = "Newcastle";
$areanames{en}->{6124200} = "Wollongong";
$areanames{en}->{6124201} = "Wollongong";
$areanames{en}->{61242020} = "Helensburgh";
$areanames{en}->{61242021} = "Helensburgh";
$areanames{en}->{61242022} = "Helensburgh";
$areanames{en}->{61242023} = "Kiama";
$areanames{en}->{61242024} = "Kiama";
$areanames{en}->{61242025} = "Kiama";
$areanames{en}->{61242026} = "Wollongong";
$areanames{en}->{61242027} = "Helensburgh";
$areanames{en}->{61242028} = "Kiama";
$areanames{en}->{61242029} = "Wollongong";
$areanames{en}->{6124203} = "Kiama";
$areanames{en}->{61242030} = "Helensburgh";
$areanames{en}->{61242032} = "Wollongong";
$areanames{en}->{61242035} = "Wollongong";
$areanames{en}->{61242036} = "Helensburgh";
$areanames{en}->{61242040} = "Helensburgh";
$areanames{en}->{61242041} = "Wollongong";
$areanames{en}->{61242042} = "Wollongong";
$areanames{en}->{61242043} = "Helensburgh";
$areanames{en}->{61242044} = "Helensburgh";
$areanames{en}->{61242045} = "Kiama";
$areanames{en}->{61242046} = "Kiama";
$areanames{en}->{61242047} = "Kiama";
$areanames{en}->{61242048} = "Wollongong";
$areanames{en}->{61242049} = "Wollongong";
$areanames{en}->{6124205} = "Kiama";
$areanames{en}->{6124206} = "Wollongong";
$areanames{en}->{61242070} = "Wollongong";
$areanames{en}->{61242071} = "Wollongong";
$areanames{en}->{61242072} = "Wollongong";
$areanames{en}->{61242073} = "Wollongong";
$areanames{en}->{61242074} = "Kiama";
$areanames{en}->{61242075} = "Helensburgh";
$areanames{en}->{61242076} = "Helensburgh";
$areanames{en}->{61242077} = "Kiama";
$areanames{en}->{61242078} = "Helensburgh";
$areanames{en}->{61242079} = "Wollongong";
$areanames{en}->{61242080} = "Wollongong";
$areanames{en}->{61242081} = "Wollongong";
$areanames{en}->{61242082} = "Wollongong";
$areanames{en}->{61242083} = "Wollongong";
$areanames{en}->{61242084} = "Helensburgh";
$areanames{en}->{61242085} = "Kiama";
$areanames{en}->{61242086} = "Kiama";
$areanames{en}->{61242087} = "Wollongong";
$areanames{en}->{61242088} = "Helensburgh";
$areanames{en}->{61242089} = "Kiama";
$areanames{en}->{6124209} = "Wollongong";
$areanames{en}->{61242091} = "Helensburgh";
$areanames{en}->{61242092} = "Kiama";
$areanames{en}->{61242097} = "Helensburgh";
$areanames{en}->{61242098} = "Kiama";
$areanames{en}->{61242100} = "Kiama";
$areanames{en}->{61242101} = "Helensburgh";
$areanames{en}->{61242102} = "Kiama";
$areanames{en}->{61242103} = "Wollongong";
$areanames{en}->{61242104} = "Helensburgh";
$areanames{en}->{61242105} = "Kiama";
$areanames{en}->{61242106} = "Wollongong";
$areanames{en}->{61242107} = "Wollongong";
$areanames{en}->{61242108} = "Wollongong";
$areanames{en}->{61242109} = "Wollongong";
$areanames{en}->{6124211} = "Wollongong";
$areanames{en}->{61242111} = "Kiama";
$areanames{en}->{61242112} = "Kiama";
$areanames{en}->{61242113} = "Kiama";
$areanames{en}->{6124212} = "Wollongong";
$areanames{en}->{6124213} = "Wollongong";
$areanames{en}->{6124214} = "Wollongong";
$areanames{en}->{61242145} = "Helensburgh";
$areanames{en}->{61242146} = "Kiama";
$areanames{en}->{61242148} = "Helensburgh";
$areanames{en}->{61242149} = "Kiama";
$areanames{en}->{61242150} = "Wollongong";
$areanames{en}->{612422} = "Wollongong";
$areanames{en}->{6124230} = "Kiama";
$areanames{en}->{6124231} = "Wollongong";
$areanames{en}->{6124232} = "Kiama";
$areanames{en}->{6124233} = "Kiama";
$areanames{en}->{6124234} = "Kiama";
$areanames{en}->{6124235} = "Kiama";
$areanames{en}->{6124236} = "Kiama";
$areanames{en}->{6124237} = "Kiama";
$areanames{en}->{6124238} = "Wollongong";
$areanames{en}->{61242380} = "Helensburgh";
$areanames{en}->{61242381} = "Kiama";
$areanames{en}->{61242389} = "Kiama";
$areanames{en}->{6124240} = "Wollongong";
$areanames{en}->{6124242} = "Wollongong";
$areanames{en}->{6124243} = "Wollongong";
$areanames{en}->{61242432} = "Helensburgh";
$areanames{en}->{6124244} = "Wollongong";
$areanames{en}->{6124245} = "Wollongong";
$areanames{en}->{6124246} = "Wollongong";
$areanames{en}->{6124247} = "Wollongong";
$areanames{en}->{61242490} = "Wollongong";
$areanames{en}->{61242491} = "Wollongong";
$areanames{en}->{61242492} = "Wollongong";
$areanames{en}->{61242493} = "Wollongong";
$areanames{en}->{61242494} = "Wollongong";
$areanames{en}->{612425} = "Wollongong";
$areanames{en}->{61242550} = "Helensburgh";
$areanames{en}->{6124256} = "Kiama";
$areanames{en}->{6124257} = "Kiama";
$areanames{en}->{6124260} = "Wollongong";
$areanames{en}->{6124261} = "Wollongong";
$areanames{en}->{6124262} = "Wollongong";
$areanames{en}->{61242630} = "Wollongong";
$areanames{en}->{61242631} = "Wollongong";
$areanames{en}->{61242632} = "Helensburgh";
$areanames{en}->{61242633} = "Kiama";
$areanames{en}->{61242634} = "Wollongong";
$areanames{en}->{61242635} = "Helensburgh";
$areanames{en}->{61242636} = "Kiama";
$areanames{en}->{61242637} = "Wollongong";
$areanames{en}->{61242638} = "Helensburgh";
$areanames{en}->{61242639} = "Kiama";
$areanames{en}->{61242640} = "Kiama";
$areanames{en}->{61242641} = "Wollongong";
$areanames{en}->{61242651} = "Wollongong";
$areanames{en}->{6124267} = "Wollongong";
$areanames{en}->{6124268} = "Wollongong";
$areanames{en}->{6124271} = "Wollongong";
$areanames{en}->{6124272} = "Wollongong";
$areanames{en}->{6124273} = "Wollongong";
$areanames{en}->{6124274} = "Wollongong";
$areanames{en}->{6124275} = "Wollongong";
$areanames{en}->{6124276} = "Wollongong";
$areanames{en}->{61242770} = "Kiama";
$areanames{en}->{61242771} = "Wollongong";
$areanames{en}->{6124283} = "Wollongong";
$areanames{en}->{6124284} = "Wollongong";
$areanames{en}->{6124285} = "Wollongong";
$areanames{en}->{6124286} = "Wollongong";
$areanames{en}->{6124287} = "Wollongong";
$areanames{en}->{6124288} = "Wollongong";
$areanames{en}->{6124289} = "Wollongong";
$areanames{en}->{6124291} = "Helensburgh";
$areanames{en}->{6124292} = "Helensburgh";
$areanames{en}->{61242930} = "Helensburgh";
$areanames{en}->{61242931} = "Kiama";
$areanames{en}->{6124294} = "Helensburgh";
$areanames{en}->{6124295} = "Wollongong";
$areanames{en}->{6124296} = "Wollongong";
$areanames{en}->{6124297} = "Wollongong";
$areanames{en}->{6124298} = "Wollongong";
$areanames{en}->{6124299} = "Helensburgh";
$areanames{en}->{6124300} = "Gosford";
$areanames{en}->{6124301} = "Gosford";
$areanames{en}->{6124302} = "Gosford";
$areanames{en}->{61243030} = "Gosford";
$areanames{en}->{61243031} = "Gosford";
$areanames{en}->{61243032} = "Gosford";
$areanames{en}->{61243033} = "Mangrove\ Mountain";
$areanames{en}->{61243034} = "Mangrove\ Mountain";
$areanames{en}->{61243035} = "Mangrove\ Mountain";
$areanames{en}->{61243036} = "Wyong";
$areanames{en}->{61243037} = "Wyong";
$areanames{en}->{61243038} = "Wyong";
$areanames{en}->{61243039} = "Gosford";
$areanames{en}->{6124304} = "Gosford";
$areanames{en}->{6124305} = "Wyong";
$areanames{en}->{61243060} = "Gosford";
$areanames{en}->{61243061} = "Mangrove\ Mountain";
$areanames{en}->{61243062} = "Wyong";
$areanames{en}->{61243063} = "Gosford";
$areanames{en}->{61243064} = "Gosford";
$areanames{en}->{61243065} = "Mangrove\ Mountain";
$areanames{en}->{61243066} = "Wyong";
$areanames{en}->{61243067} = "Gosford";
$areanames{en}->{61243068} = "Mangrove\ Mountain";
$areanames{en}->{61243069} = "Wyong";
$areanames{en}->{61243070} = "Mangrove\ Mountain";
$areanames{en}->{61243071} = "Wyong";
$areanames{en}->{61243072} = "Mangrove\ Mountain";
$areanames{en}->{61243073} = "Mangrove\ Mountain";
$areanames{en}->{61243074} = "Wyong";
$areanames{en}->{61243075} = "Gosford";
$areanames{en}->{61243076} = "Mangrove\ Mountain";
$areanames{en}->{61243077} = "Wyong";
$areanames{en}->{61243078} = "Gosford";
$areanames{en}->{61243079} = "Gosford";
$areanames{en}->{61243080} = "Mangrove\ Mountain";
$areanames{en}->{61243081} = "Wyong";
$areanames{en}->{61243082} = "Gosford";
$areanames{en}->{61243083} = "Wyong";
$areanames{en}->{61243084} = "Wyong";
$areanames{en}->{61243085} = "Wyong";
$areanames{en}->{61243086} = "Gosford";
$areanames{en}->{61243087} = "Gosford";
$areanames{en}->{61243088} = "Gosford";
$areanames{en}->{61243089} = "Gosford";
$areanames{en}->{6124309} = "Gosford";
$areanames{en}->{6124310} = "Wyong";
$areanames{en}->{6124311} = "Gosford";
$areanames{en}->{61243110} = "Wyong";
$areanames{en}->{61243111} = "Wyong";
$areanames{en}->{61243118} = "Mangrove\ Mountain";
$areanames{en}->{61243120} = "Gosford";
$areanames{en}->{61243121} = "Wyong";
$areanames{en}->{61243122} = "Mangrove\ Mountain";
$areanames{en}->{61243123} = "Mangrove\ Mountain";
$areanames{en}->{61243124} = "Wyong";
$areanames{en}->{61243125} = "Gosford";
$areanames{en}->{61243126} = "Gosford";
$areanames{en}->{61243127} = "Gosford";
$areanames{en}->{61243128} = "Gosford";
$areanames{en}->{61243129} = "Mangrove\ Mountain";
$areanames{en}->{6124313} = "Gosford";
$areanames{en}->{61243130} = "Wyong";
$areanames{en}->{61243137} = "Mangrove\ Mountain";
$areanames{en}->{61243138} = "Wyong";
$areanames{en}->{6124314} = "Gosford";
$areanames{en}->{61243145} = "Wyong";
$areanames{en}->{61243147} = "Mangrove\ Mountain";
$areanames{en}->{61243148} = "Wyong";
$areanames{en}->{61243150} = "Gosford";
$areanames{en}->{61243151} = "Gosford";
$areanames{en}->{61243152} = "Gosford";
$areanames{en}->{61243153} = "Gosford";
$areanames{en}->{61243154} = "Wyong";
$areanames{en}->{61243155} = "Wyong";
$areanames{en}->{61243156} = "Wyong";
$areanames{en}->{61243157} = "Gosford";
$areanames{en}->{61243158} = "Mangrove\ Mountain";
$areanames{en}->{61243159} = "Wyong";
$areanames{en}->{61243160} = "Gosford";
$areanames{en}->{61243161} = "Mangrove\ Mountain";
$areanames{en}->{61243162} = "Wyong";
$areanames{en}->{61243163} = "Gosford";
$areanames{en}->{61243164} = "Mangrove\ Mountain";
$areanames{en}->{61243165} = "Wyong";
$areanames{en}->{61243166} = "Gosford";
$areanames{en}->{61243167} = "Mangrove\ Mountain";
$areanames{en}->{61243168} = "Wyong";
$areanames{en}->{61243169} = "Gosford";
$areanames{en}->{61243170} = "Mangrove\ Mountain";
$areanames{en}->{61243171} = "Wyong";
$areanames{en}->{612432} = "Gosford";
$areanames{en}->{61243262} = "Wyong";
$areanames{en}->{61243263} = "Wyong";
$areanames{en}->{61243264} = "Wyong";
$areanames{en}->{6124330} = "Wyong";
$areanames{en}->{6124331} = "Gosford";
$areanames{en}->{6124332} = "Gosford";
$areanames{en}->{6124333} = "Gosford";
$areanames{en}->{6124334} = "Gosford";
$areanames{en}->{6124335} = "Gosford";
$areanames{en}->{61243350} = "Mangrove\ Mountain";
$areanames{en}->{61243351} = "Wyong";
$areanames{en}->{6124336} = "Gosford";
$areanames{en}->{6124337} = "Gosford";
$areanames{en}->{61243380} = "Wyong";
$areanames{en}->{61243381} = "Mangrove\ Mountain";
$areanames{en}->{61243382} = "Mangrove\ Mountain";
$areanames{en}->{6124339} = "Gosford";
$areanames{en}->{6124340} = "Gosford";
$areanames{en}->{6124341} = "Gosford";
$areanames{en}->{6124342} = "Gosford";
$areanames{en}->{6124343} = "Gosford";
$areanames{en}->{6124344} = "Gosford";
$areanames{en}->{6124345} = "Gosford";
$areanames{en}->{61243460} = "Wyong";
$areanames{en}->{61243461} = "Gosford";
$areanames{en}->{61243462} = "Gosford";
$areanames{en}->{61243463} = "Wyong";
$areanames{en}->{61243464} = "Gosford";
$areanames{en}->{61243465} = "Gosford";
$areanames{en}->{61243466} = "Gosford";
$areanames{en}->{61243474} = "Gosford";
$areanames{en}->{6124348} = "Gosford";
$areanames{en}->{6124349} = "Gosford";
$areanames{en}->{612435} = "Wyong";
$areanames{en}->{612436} = "Gosford";
$areanames{en}->{6124366} = "Wyong";
$areanames{en}->{612437} = "Gosford";
$areanames{en}->{6124371} = "Mangrove\ Mountain";
$areanames{en}->{6124373} = "Mangrove\ Mountain";
$areanames{en}->{6124374} = "Mangrove\ Mountain";
$areanames{en}->{6124376} = "Mangrove\ Mountain";
$areanames{en}->{61243800} = "Gosford";
$areanames{en}->{61243808} = "Gosford";
$areanames{en}->{61243809} = "Gosford";
$areanames{en}->{6124381} = "Gosford";
$areanames{en}->{6124382} = "Gosford";
$areanames{en}->{6124384} = "Gosford";
$areanames{en}->{6124385} = "Gosford";
$areanames{en}->{6124388} = "Gosford";
$areanames{en}->{6124389} = "Gosford";
$areanames{en}->{6124390} = "Wyong";
$areanames{en}->{61243910} = "Wyong";
$areanames{en}->{6124392} = "Wyong";
$areanames{en}->{6124393} = "Wyong";
$areanames{en}->{6124394} = "Wyong";
$areanames{en}->{6124396} = "Wyong";
$areanames{en}->{6124397} = "Wyong";
$areanames{en}->{6124399} = "Wyong";
$areanames{en}->{61244000} = "Batemans\ Bay";
$areanames{en}->{61244001} = "Batemans\ Bay";
$areanames{en}->{61244002} = "Batemans\ Bay";
$areanames{en}->{61244003} = "Bawley\ Point";
$areanames{en}->{61244004} = "Bawley\ Point";
$areanames{en}->{61244005} = "Bawley\ Point";
$areanames{en}->{61244006} = "Berry";
$areanames{en}->{61244007} = "Berry";
$areanames{en}->{61244008} = "Berry";
$areanames{en}->{61244009} = "Batemans\ Bay";
$areanames{en}->{61244010} = "Huskisson";
$areanames{en}->{61244011} = "Huskisson";
$areanames{en}->{61244012} = "Huskisson";
$areanames{en}->{61244013} = "Jilliga";
$areanames{en}->{61244014} = "Jilliga";
$areanames{en}->{61244015} = "Jilliga";
$areanames{en}->{61244016} = "Milton\-ulladulla";
$areanames{en}->{61244017} = "Milton\-ulladulla";
$areanames{en}->{61244018} = "Milton\-ulladulla";
$areanames{en}->{61244019} = "Jilliga";
$areanames{en}->{61244020} = "Moruya";
$areanames{en}->{61244021} = "Moruya";
$areanames{en}->{61244022} = "Moruya";
$areanames{en}->{61244023} = "Narooma";
$areanames{en}->{61244024} = "Narooma";
$areanames{en}->{61244025} = "Narooma";
$areanames{en}->{61244026} = "Nowra";
$areanames{en}->{61244027} = "Nowra";
$areanames{en}->{61244028} = "Nowra";
$areanames{en}->{61244029} = "Nowra";
$areanames{en}->{61244030} = "Nowra";
$areanames{en}->{61244031} = "Batemans\ Bay";
$areanames{en}->{61244032} = "Jilliga";
$areanames{en}->{61244033} = "Moruya";
$areanames{en}->{61244034} = "Narooma";
$areanames{en}->{61244035} = "Bawley\ Point";
$areanames{en}->{61244036} = "Berry";
$areanames{en}->{61244037} = "Huskisson";
$areanames{en}->{61244038} = "Milton\-ulladulla";
$areanames{en}->{61244039} = "Nowra";
$areanames{en}->{61244040} = "Moruya";
$areanames{en}->{61244041} = "Narooma";
$areanames{en}->{61244042} = "Bawley\ Point";
$areanames{en}->{61244043} = "Berry";
$areanames{en}->{61244044} = "Huskisson";
$areanames{en}->{61244045} = "Milton\-ulladulla";
$areanames{en}->{61244046} = "Nowra";
$areanames{en}->{61244047} = "Batemans\ Bay";
$areanames{en}->{61244048} = "Jilliga";
$areanames{en}->{61244049} = "Moruya";
$areanames{en}->{61244050} = "Narooma";
$areanames{en}->{61244051} = "Bawley\ Point";
$areanames{en}->{61244052} = "Berry";
$areanames{en}->{61244053} = "Huskisson";
$areanames{en}->{61244054} = "Milton\-ulladulla";
$areanames{en}->{61244055} = "Nowra";
$areanames{en}->{61244056} = "Batemans\ Bay";
$areanames{en}->{61244057} = "Jilliga";
$areanames{en}->{61244058} = "Moruya";
$areanames{en}->{61244059} = "Narooma";
$areanames{en}->{61244060} = "Bawley\ Point";
$areanames{en}->{61244061} = "Berry";
$areanames{en}->{61244062} = "Huskisson";
$areanames{en}->{61244063} = "Milton\-ulladulla";
$areanames{en}->{61244064} = "Batemans\ Bay";
$areanames{en}->{61244065} = "Jilliga";
$areanames{en}->{61244066} = "Moruya";
$areanames{en}->{61244067} = "Narooma";
$areanames{en}->{61244068} = "Bawley\ Point";
$areanames{en}->{61244069} = "Berry";
$areanames{en}->{61244070} = "Batemans\ Bay";
$areanames{en}->{61244071} = "Jilliga";
$areanames{en}->{61244072} = "Moruya";
$areanames{en}->{61244073} = "Narooma";
$areanames{en}->{61244074} = "Bawley\ Point";
$areanames{en}->{61244075} = "Berry";
$areanames{en}->{61244076} = "Huskisson";
$areanames{en}->{61244077} = "Milton\-ulladulla";
$areanames{en}->{61244078} = "Nowra";
$areanames{en}->{61244079} = "Huskisson";
$areanames{en}->{61244080} = "Milton\-ulladulla";
$areanames{en}->{61244081} = "Nowra";
$areanames{en}->{61244082} = "Batemans\ Bay";
$areanames{en}->{61244083} = "Nowra";
$areanames{en}->{61244084} = "Moruya";
$areanames{en}->{61244085} = "Narooma";
$areanames{en}->{61244086} = "Batemans\ Bay";
$areanames{en}->{61244087} = "Berry";
$areanames{en}->{61244088} = "Huskisson";
$areanames{en}->{61244089} = "Milton\-ulladulla";
$areanames{en}->{61244090} = "Nowra";
$areanames{en}->{61244091} = "Nowra";
$areanames{en}->{61244092} = "Nowra";
$areanames{en}->{61244093} = "Nowra";
$areanames{en}->{61244094} = "Batemans\ Bay";
$areanames{en}->{61244095} = "Milton\-ulladulla";
$areanames{en}->{61244096} = "Narooma";
$areanames{en}->{61244097} = "Nowra";
$areanames{en}->{61244098} = "Huskisson";
$areanames{en}->{61244099} = "Jilliga";
$areanames{en}->{61244100} = "Moruya";
$areanames{en}->{61244101} = "Berry";
$areanames{en}->{61244102} = "Jilliga";
$areanames{en}->{61244103} = "Milton\-ulladulla";
$areanames{en}->{61244104} = "Moruya";
$areanames{en}->{61244105} = "Narooma";
$areanames{en}->{61244106} = "Moruya";
$areanames{en}->{61244107} = "Batemans\ Bay";
$areanames{en}->{61244108} = "Narooma";
$areanames{en}->{61244109} = "Narooma";
$areanames{en}->{61244110} = "Bawley\ Point";
$areanames{en}->{61244111} = "Nowra";
$areanames{en}->{61244112} = "Huskisson";
$areanames{en}->{61244113} = "Berry";
$areanames{en}->{61244114} = "Jilliga";
$areanames{en}->{61244115} = "Milton\-ulladulla";
$areanames{en}->{61244116} = "Moruya";
$areanames{en}->{61244117} = "Bawley\ Point";
$areanames{en}->{61244118} = "Batemans\ Bay";
$areanames{en}->{61244119} = "Berry";
$areanames{en}->{61244120} = "Huskisson";
$areanames{en}->{61244121} = "Narooma";
$areanames{en}->{61244122} = "Jilliga";
$areanames{en}->{61244123} = "Batemans\ Bay";
$areanames{en}->{61244124} = "Moruya";
$areanames{en}->{61244125} = "Huskisson";
$areanames{en}->{61244126} = "Berry";
$areanames{en}->{61244127} = "Milton\-ulladulla";
$areanames{en}->{61244128} = "Bawley\ Point";
$areanames{en}->{61244129} = "Milton\-ulladulla";
$areanames{en}->{61244130} = "Nowra";
$areanames{en}->{61244131} = "Nowra";
$areanames{en}->{61244132} = "Nowra";
$areanames{en}->{61244133} = "Batemans\ Bay";
$areanames{en}->{61244134} = "Bawley\ Point";
$areanames{en}->{61244135} = "Berry";
$areanames{en}->{61244136} = "Huskisson";
$areanames{en}->{61244137} = "Jilliga";
$areanames{en}->{61244138} = "Milton\-ulladulla";
$areanames{en}->{61244139} = "Moruya";
$areanames{en}->{61244140} = "Narooma";
$areanames{en}->{61244141} = "Nowra";
$areanames{en}->{61244142} = "Batemans\ Bay";
$areanames{en}->{61244143} = "Bawley\ Point";
$areanames{en}->{61244144} = "Berry";
$areanames{en}->{61244145} = "Huskisson";
$areanames{en}->{61244146} = "Jilliga";
$areanames{en}->{61244147} = "Milton\-ulladulla";
$areanames{en}->{61244148} = "Moruya";
$areanames{en}->{61244149} = "Narooma";
$areanames{en}->{61244150} = "Nowra";
$areanames{en}->{61244151} = "Batemans\ Bay";
$areanames{en}->{61244152} = "Bawley\ Point";
$areanames{en}->{61244153} = "Berry";
$areanames{en}->{61244154} = "Huskisson";
$areanames{en}->{61244155} = "Jilliga";
$areanames{en}->{61244156} = "Milton\-ulladulla";
$areanames{en}->{61244157} = "Moruya";
$areanames{en}->{61244158} = "Narooma";
$areanames{en}->{61244159} = "Nowra";
$areanames{en}->{61244160} = "Batemans\ Bay";
$areanames{en}->{61244161} = "Bawley\ Point";
$areanames{en}->{61244162} = "Berry";
$areanames{en}->{61244163} = "Huskisson";
$areanames{en}->{61244164} = "Jilliga";
$areanames{en}->{61244165} = "Milton\-ulladulla";
$areanames{en}->{61244166} = "Moruya";
$areanames{en}->{61244167} = "Narooma";
$areanames{en}->{61244168} = "Nowra";
$areanames{en}->{61244169} = "Batemans\ Bay";
$areanames{en}->{61244170} = "Bawley\ Point";
$areanames{en}->{61244171} = "Berry";
$areanames{en}->{61244172} = "Huskisson";
$areanames{en}->{61244173} = "Jilliga";
$areanames{en}->{61244174} = "Milton\-ulladulla";
$areanames{en}->{61244175} = "Moruya";
$areanames{en}->{61244176} = "Narooma";
$areanames{en}->{61244177} = "Nowra";
$areanames{en}->{61244178} = "Batemans\ Bay";
$areanames{en}->{61244179} = "Bawley\ Point";
$areanames{en}->{61244180} = "Berry";
$areanames{en}->{61244181} = "Huskisson";
$areanames{en}->{61244182} = "Jilliga";
$areanames{en}->{61244183} = "Milton\-ulladulla";
$areanames{en}->{61244184} = "Moruya";
$areanames{en}->{61244185} = "Narooma";
$areanames{en}->{61244186} = "Nowra";
$areanames{en}->{61244187} = "Batemans\ Bay";
$areanames{en}->{61244188} = "Bawley\ Point";
$areanames{en}->{61244189} = "Berry";
$areanames{en}->{61244190} = "Huskisson";
$areanames{en}->{61244191} = "Jilliga";
$areanames{en}->{61244192} = "Milton\-ulladulla";
$areanames{en}->{61244193} = "Moruya";
$areanames{en}->{61244194} = "Narooma";
$areanames{en}->{61244195} = "Nowra";
$areanames{en}->{61244196} = "Batemans\ Bay";
$areanames{en}->{61244197} = "Bawley\ Point";
$areanames{en}->{61244198} = "Berry";
$areanames{en}->{61244199} = "Huskisson";
$areanames{en}->{61244200} = "Jilliga";
$areanames{en}->{61244201} = "Milton\-ulladulla";
$areanames{en}->{61244202} = "Moruya";
$areanames{en}->{61244203} = "Narooma";
$areanames{en}->{61244204} = "Nowra";
$areanames{en}->{6124421} = "Nowra";
$areanames{en}->{6124422} = "Nowra";
$areanames{en}->{6124423} = "Nowra";
$areanames{en}->{6124424} = "Nowra";
$areanames{en}->{61244250} = "Batemans\ Bay";
$areanames{en}->{61244251} = "Berry";
$areanames{en}->{61244252} = "Huskisson";
$areanames{en}->{61244253} = "Milton\-ulladulla";
$areanames{en}->{61244254} = "Moruya";
$areanames{en}->{61244255} = "Moruya";
$areanames{en}->{61244256} = "Narooma";
$areanames{en}->{61244257} = "Narooma";
$areanames{en}->{61244258} = "Milton\-ulladulla";
$areanames{en}->{61244259} = "Milton\-ulladulla";
$areanames{en}->{6124426} = "Nowra";
$areanames{en}->{61244270} = "Jilliga";
$areanames{en}->{61244271} = "Jilliga";
$areanames{en}->{61244272} = "Nowra";
$areanames{en}->{61244273} = "Nowra";
$areanames{en}->{61244274} = "Nowra";
$areanames{en}->{61244275} = "Bawley\ Point";
$areanames{en}->{61244276} = "Bawley\ Point";
$areanames{en}->{61244277} = "Bawley\ Point";
$areanames{en}->{61244278} = "Jilliga";
$areanames{en}->{6124428} = "Nowra";
$areanames{en}->{61244280} = "Huskisson";
$areanames{en}->{61244281} = "Huskisson";
$areanames{en}->{61244282} = "Huskisson";
$areanames{en}->{61244283} = "Huskisson";
$areanames{en}->{61244290} = "Bawley\ Point";
$areanames{en}->{61244291} = "Nowra";
$areanames{en}->{61244292} = "Nowra";
$areanames{en}->{61244293} = "Nowra";
$areanames{en}->{61244294} = "Nowra";
$areanames{en}->{61244295} = "Nowra";
$areanames{en}->{61244296} = "Berry";
$areanames{en}->{61244297} = "Huskisson";
$areanames{en}->{61244298} = "Milton\-ulladulla";
$areanames{en}->{61244299} = "Milton\-ulladulla";
$areanames{en}->{6124441} = "Huskisson";
$areanames{en}->{6124442} = "Huskisson";
$areanames{en}->{6124443} = "Huskisson";
$areanames{en}->{61244440} = "Nowra";
$areanames{en}->{61244441} = "Nowra";
$areanames{en}->{61244442} = "Nowra";
$areanames{en}->{61244443} = "Nowra";
$areanames{en}->{61244444} = "Berry";
$areanames{en}->{61244445} = "Berry";
$areanames{en}->{61244446} = "Huskisson";
$areanames{en}->{61244447} = "Huskisson";
$areanames{en}->{61244448} = "Milton\-ulladulla";
$areanames{en}->{61244449} = "Milton\-ulladulla";
$areanames{en}->{6124445} = "Nowra";
$areanames{en}->{61244452} = "Batemans\ Bay";
$areanames{en}->{61244455} = "Batemans\ Bay";
$areanames{en}->{61244456} = "Batemans\ Bay";
$areanames{en}->{61244459} = "Milton\-ulladulla";
$areanames{en}->{6124446} = "Nowra";
$areanames{en}->{6124447} = "Nowra";
$areanames{en}->{6124448} = "Nowra";
$areanames{en}->{6124454} = "Milton\-ulladulla";
$areanames{en}->{6124455} = "Milton\-ulladulla";
$areanames{en}->{6124456} = "Milton\-ulladulla";
$areanames{en}->{6124457} = "Bawley\ Point";
$areanames{en}->{61244581} = "Nowra";
$areanames{en}->{6124464} = "Berry";
$areanames{en}->{6124465} = "Berry";
$areanames{en}->{6124471} = "Moruya";
$areanames{en}->{6124472} = "Batemans\ Bay";
$areanames{en}->{6124473} = "Narooma";
$areanames{en}->{61244730} = "Batemans\ Bay";
$areanames{en}->{6124474} = "Moruya";
$areanames{en}->{61244750} = "Moruya";
$areanames{en}->{61244751} = "Batemans\ Bay";
$areanames{en}->{61244752} = "Batemans\ Bay";
$areanames{en}->{61244753} = "Batemans\ Bay";
$areanames{en}->{61244754} = "Moruya";
$areanames{en}->{61244755} = "Narooma";
$areanames{en}->{61244756} = "Moruya";
$areanames{en}->{61244757} = "Narooma";
$areanames{en}->{61244758} = "Jilliga";
$areanames{en}->{61244759} = "Moruya";
$areanames{en}->{6124476} = "Narooma";
$areanames{en}->{6124477} = "Jilliga";
$areanames{en}->{6124478} = "Batemans\ Bay";
$areanames{en}->{61244790} = "Batemans\ Bay";
$areanames{en}->{61244791} = "Jilliga";
$areanames{en}->{61244792} = "Moruya";
$areanames{en}->{61244793} = "Batemans\ Bay";
$areanames{en}->{61244794} = "Batemans\ Bay";
$areanames{en}->{61244795} = "Moruya";
$areanames{en}->{61244796} = "Moruya";
$areanames{en}->{61244797} = "Narooma";
$areanames{en}->{61244798} = "Narooma";
$areanames{en}->{61244799} = "Narooma";
$areanames{en}->{61244800} = "Narooma";
$areanames{en}->{61244801} = "Bawley\ Point";
$areanames{en}->{61244802} = "Berry";
$areanames{en}->{61244803} = "Huskisson";
$areanames{en}->{61244804} = "Milton\-ulladulla";
$areanames{en}->{61244805} = "Nowra";
$areanames{en}->{61244806} = "Nowra";
$areanames{en}->{61244807} = "Nowra";
$areanames{en}->{61244808} = "Bawley\ Point";
$areanames{en}->{61244809} = "Bawley\ Point";
$areanames{en}->{6124481} = "Nowra";
$areanames{en}->{61244881} = "Nowra";
$areanames{en}->{61244884} = "Nowra";
$areanames{en}->{61244999} = "Berry";
$areanames{en}->{61245000} = "Colo\ Heights";
$areanames{en}->{61245001} = "Colo\ Heights";
$areanames{en}->{61245002} = "Colo\ Heights";
$areanames{en}->{61245003} = "Kurrajong\ Heights";
$areanames{en}->{61245004} = "Kurrajong\ Heights";
$areanames{en}->{61245005} = "Kurrajong\ Heights";
$areanames{en}->{61245006} = "St\ Albans";
$areanames{en}->{61245007} = "St\ Albans";
$areanames{en}->{61245008} = "St\ Albans";
$areanames{en}->{61245009} = "Colo\ Heights";
$areanames{en}->{61245010} = "Windsor";
$areanames{en}->{61245011} = "Windsor";
$areanames{en}->{61245012} = "Windsor";
$areanames{en}->{61245013} = "Wisemans\ Ferry";
$areanames{en}->{61245014} = "Wisemans\ Ferry";
$areanames{en}->{61245015} = "Wisemans\ Ferry";
$areanames{en}->{61245016} = "Kurrajong\ Heights";
$areanames{en}->{61245017} = "St\ Albans";
$areanames{en}->{61245018} = "Windsor";
$areanames{en}->{61245019} = "Wisemans\ Ferry";
$areanames{en}->{61245020} = "Colo\ Heights";
$areanames{en}->{61245021} = "Kurrajong\ Heights";
$areanames{en}->{61245022} = "St\ Albans";
$areanames{en}->{61245023} = "Windsor";
$areanames{en}->{61245024} = "Wisemans\ Ferry";
$areanames{en}->{61245025} = "Colo\ Heights";
$areanames{en}->{61245026} = "Kurrajong\ Heights";
$areanames{en}->{61245027} = "St\ Albans";
$areanames{en}->{61245028} = "Windsor";
$areanames{en}->{61245029} = "Wisemans\ Ferry";
$areanames{en}->{61245030} = "Colo\ Heights";
$areanames{en}->{61245031} = "Kurrajong\ Heights";
$areanames{en}->{61245032} = "St\ Albans";
$areanames{en}->{61245033} = "Wisemans\ Ferry";
$areanames{en}->{61245034} = "Colo\ Heights";
$areanames{en}->{61245035} = "Kurrajong\ Heights";
$areanames{en}->{61245036} = "St\ Albans";
$areanames{en}->{61245037} = "Windsor";
$areanames{en}->{61245038} = "Wisemans\ Ferry";
$areanames{en}->{61245039} = "Wisemans\ Ferry";
$areanames{en}->{61245040} = "Colo\ Heights";
$areanames{en}->{61245041} = "Kurrajong\ Heights";
$areanames{en}->{61245042} = "St\ Albans";
$areanames{en}->{61245043} = "Wisemans\ Ferry";
$areanames{en}->{61245044} = "Colo\ Heights";
$areanames{en}->{61245045} = "Kurrajong\ Heights";
$areanames{en}->{61245046} = "St\ Albans";
$areanames{en}->{61245047} = "Windsor";
$areanames{en}->{61245048} = "Windsor";
$areanames{en}->{61245049} = "Windsor";
$areanames{en}->{6124505} = "Windsor";
$areanames{en}->{61245056} = "Colo\ Heights";
$areanames{en}->{61245057} = "St\ Albans";
$areanames{en}->{61245058} = "Kurrajong\ Heights";
$areanames{en}->{61245059} = "Wisemans\ Ferry";
$areanames{en}->{61245060} = "Windsor";
$areanames{en}->{61245061} = "Wisemans\ Ferry";
$areanames{en}->{61245062} = "Windsor";
$areanames{en}->{61245063} = "Colo\ Heights";
$areanames{en}->{61245064} = "St\ Albans";
$areanames{en}->{61245065} = "Kurrajong\ Heights";
$areanames{en}->{61245066} = "Wisemans\ Ferry";
$areanames{en}->{61245067} = "Colo\ Heights";
$areanames{en}->{61245068} = "St\ Albans";
$areanames{en}->{61245069} = "Colo\ Heights";
$areanames{en}->{61245070} = "Kurrajong\ Heights";
$areanames{en}->{61245071} = "Kurrajong\ Heights";
$areanames{en}->{61245072} = "Wisemans\ Ferry";
$areanames{en}->{61245073} = "St\ Albans";
$areanames{en}->{61245074} = "Windsor";
$areanames{en}->{61245075} = "Wisemans\ Ferry";
$areanames{en}->{61245076} = "Colo\ Heights";
$areanames{en}->{61245077} = "Kurrajong\ Heights";
$areanames{en}->{61245078} = "St\ Albans";
$areanames{en}->{61245079} = "Windsor";
$areanames{en}->{61245080} = "Wisemans\ Ferry";
$areanames{en}->{61245081} = "Colo\ Heights";
$areanames{en}->{61245082} = "Kurrajong\ Heights";
$areanames{en}->{61245083} = "St\ Albans";
$areanames{en}->{61245084} = "Windsor";
$areanames{en}->{61245085} = "Wisemans\ Ferry";
$areanames{en}->{61245086} = "Windsor";
$areanames{en}->{61245087} = "Windsor";
$areanames{en}->{61245088} = "Colo\ Heights";
$areanames{en}->{61245089} = "Kurrajong\ Heights";
$areanames{en}->{61245090} = "St\ Albans";
$areanames{en}->{61245091} = "Colo\ Heights";
$areanames{en}->{61245092} = "Kurrajong\ Heights";
$areanames{en}->{61245093} = "St\ Albans";
$areanames{en}->{61245094} = "Windsor";
$areanames{en}->{61245095} = "Wisemans\ Ferry";
$areanames{en}->{61245096} = "Windsor";
$areanames{en}->{61245097} = "Wisemans\ Ferry";
$areanames{en}->{61245098} = "Colo\ Heights";
$areanames{en}->{61245099} = "Kurrajong\ Heights";
$areanames{en}->{61245100} = "St\ Albans";
$areanames{en}->{61245101} = "Windsor";
$areanames{en}->{61245102} = "Wisemans\ Ferry";
$areanames{en}->{61245103} = "Colo\ Heights";
$areanames{en}->{61245104} = "Kurrajong\ Heights";
$areanames{en}->{61245105} = "St\ Albans";
$areanames{en}->{61245106} = "Windsor";
$areanames{en}->{61245107} = "Wisemans\ Ferry";
$areanames{en}->{61245108} = "Colo\ Heights";
$areanames{en}->{61245109} = "Kurrajong\ Heights";
$areanames{en}->{61245110} = "St\ Albans";
$areanames{en}->{61245111} = "Windsor";
$areanames{en}->{61245112} = "Wisemans\ Ferry";
$areanames{en}->{6124545} = "Windsor";
$areanames{en}->{61245460} = "Windsor";
$areanames{en}->{6124555} = "Windsor";
$areanames{en}->{6124556} = "Windsor";
$areanames{en}->{6124557} = "Windsor";
$areanames{en}->{61245582} = "Windsor";
$areanames{en}->{6124560} = "Windsor";
$areanames{en}->{61245600} = "Wisemans\ Ferry";
$areanames{en}->{61245607} = "Kurrajong\ Heights";
$areanames{en}->{61245608} = "Colo\ Heights";
$areanames{en}->{61245609} = "St\ Albans";
$areanames{en}->{61245610} = "Windsor";
$areanames{en}->{61245611} = "Windsor";
$areanames{en}->{61245612} = "Windsor";
$areanames{en}->{61245613} = "Windsor";
$areanames{en}->{61245614} = "Colo\ Heights";
$areanames{en}->{61245615} = "Colo\ Heights";
$areanames{en}->{61245616} = "Kurrajong\ Heights";
$areanames{en}->{61245617} = "Kurrajong\ Heights";
$areanames{en}->{61245618} = "Wisemans\ Ferry";
$areanames{en}->{61245619} = "Wisemans\ Ferry";
$areanames{en}->{6124565} = "Colo\ Heights";
$areanames{en}->{6124566} = "Wisemans\ Ferry";
$areanames{en}->{6124567} = "Kurrajong\ Heights";
$areanames{en}->{6124568} = "St\ Albans";
$areanames{en}->{612457} = "Windsor";
$areanames{en}->{6124580} = "Windsor";
$areanames{en}->{6124581} = "Wisemans\ Ferry";
$areanames{en}->{6124582} = "Windsor";
$areanames{en}->{6124583} = "Windsor";
$areanames{en}->{61245840} = "St\ Albans";
$areanames{en}->{61245841} = "St\ Albans";
$areanames{en}->{6124587} = "Windsor";
$areanames{en}->{6124588} = "Windsor";
$areanames{en}->{61245890} = "Colo\ Heights";
$areanames{en}->{61245891} = "Kurrajong\ Heights";
$areanames{en}->{61245892} = "St\ Albans";
$areanames{en}->{61245893} = "Windsor";
$areanames{en}->{61245894} = "Wisemans\ Ferry";
$areanames{en}->{61245899} = "Windsor";
$areanames{en}->{61246000} = "Camden";
$areanames{en}->{61246001} = "Camden";
$areanames{en}->{61246002} = "Camden";
$areanames{en}->{61246003} = "Campbelltown";
$areanames{en}->{61246004} = "Campbelltown";
$areanames{en}->{61246005} = "Campbelltown";
$areanames{en}->{61246006} = "Picton";
$areanames{en}->{61246007} = "Picton";
$areanames{en}->{61246008} = "Picton";
$areanames{en}->{61246009} = "Campbelltown";
$areanames{en}->{61246010} = "Camden";
$areanames{en}->{61246011} = "Campbelltown";
$areanames{en}->{61246012} = "Picton";
$areanames{en}->{61246013} = "Camden";
$areanames{en}->{61246014} = "Campbelltown";
$areanames{en}->{61246015} = "Picton";
$areanames{en}->{61246016} = "Camden";
$areanames{en}->{61246017} = "Picton";
$areanames{en}->{61246018} = "Camden";
$areanames{en}->{61246019} = "Picton";
$areanames{en}->{61246020} = "Campbelltown";
$areanames{en}->{61246021} = "Camden";
$areanames{en}->{61246022} = "Campbelltown";
$areanames{en}->{61246023} = "Picton";
$areanames{en}->{61246024} = "Camden";
$areanames{en}->{61246025} = "Campbelltown";
$areanames{en}->{61246026} = "Camden";
$areanames{en}->{61246027} = "Picton";
$areanames{en}->{61246028} = "Camden";
$areanames{en}->{61246029} = "Campbelltown";
$areanames{en}->{61246030} = "Picton";
$areanames{en}->{61246031} = "Camden";
$areanames{en}->{61246032} = "Picton";
$areanames{en}->{61246033} = "Camden";
$areanames{en}->{61246034} = "Camden";
$areanames{en}->{61246035} = "Campbelltown";
$areanames{en}->{61246036} = "Campbelltown";
$areanames{en}->{61246037} = "Campbelltown";
$areanames{en}->{61246038} = "Camden";
$areanames{en}->{61246039} = "Campbelltown";
$areanames{en}->{61246040} = "Camden";
$areanames{en}->{61246041} = "Picton";
$areanames{en}->{61246042} = "Campbelltown";
$areanames{en}->{61246043} = "Campbelltown";
$areanames{en}->{61246044} = "Picton";
$areanames{en}->{61246045} = "Campbelltown";
$areanames{en}->{61246046} = "Camden";
$areanames{en}->{61246047} = "Picton";
$areanames{en}->{61246048} = "Campbelltown";
$areanames{en}->{61246049} = "Campbelltown";
$areanames{en}->{6124605} = "Campbelltown";
$areanames{en}->{6124606} = "Campbelltown";
$areanames{en}->{61246070} = "Picton";
$areanames{en}->{61246071} = "Picton";
$areanames{en}->{61246072} = "Campbelltown";
$areanames{en}->{61246073} = "Campbelltown";
$areanames{en}->{61246074} = "Camden";
$areanames{en}->{61246075} = "Campbelltown";
$areanames{en}->{61246076} = "Picton";
$areanames{en}->{61246077} = "Campbelltown";
$areanames{en}->{61246078} = "Camden";
$areanames{en}->{61246079} = "Campbelltown";
$areanames{en}->{6124608} = "Campbelltown";
$areanames{en}->{6124609} = "Campbelltown";
$areanames{en}->{6124610} = "Campbelltown";
$areanames{en}->{61246103} = "Picton";
$areanames{en}->{61246104} = "Camden";
$areanames{en}->{61246106} = "Picton";
$areanames{en}->{61246110} = "Campbelltown";
$areanames{en}->{61246111} = "Camden";
$areanames{en}->{61246112} = "Campbelltown";
$areanames{en}->{61246113} = "Camden";
$areanames{en}->{61246114} = "Campbelltown";
$areanames{en}->{61246115} = "Picton";
$areanames{en}->{61246116} = "Picton";
$areanames{en}->{61246117} = "Camden";
$areanames{en}->{61246118} = "Campbelltown";
$areanames{en}->{61246119} = "Picton";
$areanames{en}->{61246120} = "Camden";
$areanames{en}->{61246121} = "Campbelltown";
$areanames{en}->{61246122} = "Picton";
$areanames{en}->{61246123} = "Camden";
$areanames{en}->{61246124} = "Campbelltown";
$areanames{en}->{61246125} = "Picton";
$areanames{en}->{612462} = "Campbelltown";
$areanames{en}->{61246232} = "Camden";
$areanames{en}->{61246234} = "Picton";
$areanames{en}->{61246236} = "Camden";
$areanames{en}->{61246237} = "Camden";
$areanames{en}->{6124630} = "Campbelltown";
$areanames{en}->{6124631} = "Campbelltown";
$areanames{en}->{6124632} = "Campbelltown";
$areanames{en}->{6124633} = "Campbelltown";
$areanames{en}->{6124634} = "Campbelltown";
$areanames{en}->{6124635} = "Camden";
$areanames{en}->{6124636} = "Campbelltown";
$areanames{en}->{61246370} = "Campbelltown";
$areanames{en}->{61246371} = "Campbelltown";
$areanames{en}->{61246372} = "Campbelltown";
$areanames{en}->{61246373} = "Campbelltown";
$areanames{en}->{61246374} = "Campbelltown";
$areanames{en}->{61246375} = "Campbelltown";
$areanames{en}->{61246376} = "Campbelltown";
$areanames{en}->{61246377} = "Campbelltown";
$areanames{en}->{6124638} = "Campbelltown";
$areanames{en}->{6124640} = "Campbelltown";
$areanames{en}->{61246400} = "Picton";
$areanames{en}->{61246409} = "Camden";
$areanames{en}->{61246410} = "Picton";
$areanames{en}->{61246411} = "Campbelltown";
$areanames{en}->{61246412} = "Picton";
$areanames{en}->{61246413} = "Picton";
$areanames{en}->{61246414} = "Picton";
$areanames{en}->{6124645} = "Campbelltown";
$areanames{en}->{6124646} = "Campbelltown";
$areanames{en}->{6124647} = "Campbelltown";
$areanames{en}->{6124648} = "Campbelltown";
$areanames{en}->{6124649} = "Campbelltown";
$areanames{en}->{6124651} = "Camden";
$areanames{en}->{6124652} = "Camden";
$areanames{en}->{6124653} = "Camden";
$areanames{en}->{6124654} = "Camden";
$areanames{en}->{6124655} = "Camden";
$areanames{en}->{6124656} = "Campbelltown";
$areanames{en}->{6124657} = "Camden";
$areanames{en}->{6124658} = "Camden";
$areanames{en}->{6124659} = "Camden";
$areanames{en}->{61246600} = "Camden";
$areanames{en}->{61246611} = "Camden";
$areanames{en}->{61246660} = "Campbelltown";
$areanames{en}->{61246661} = "Campbelltown";
$areanames{en}->{61246662} = "Campbelltown";
$areanames{en}->{61246663} = "Campbelltown";
$areanames{en}->{61246664} = "Campbelltown";
$areanames{en}->{61246665} = "Campbelltown";
$areanames{en}->{61246666} = "Campbelltown";
$areanames{en}->{61246667} = "Camden";
$areanames{en}->{6124677} = "Picton";
$areanames{en}->{6124678} = "Picton";
$areanames{en}->{6124680} = "Picton";
$areanames{en}->{6124681} = "Picton";
$areanames{en}->{6124683} = "Picton";
$areanames{en}->{6124684} = "Picton";
$areanames{en}->{61247000} = "Katoomba";
$areanames{en}->{61247001} = "Katoomba";
$areanames{en}->{61247002} = "Katoomba";
$areanames{en}->{61247003} = "Lawson";
$areanames{en}->{61247004} = "Lawson";
$areanames{en}->{61247005} = "Lawson";
$areanames{en}->{61247006} = "Mount\ Wilson";
$areanames{en}->{61247007} = "Mount\ Wilson";
$areanames{en}->{61247008} = "Mount\ Wilson";
$areanames{en}->{61247009} = "Katoomba";
$areanames{en}->{61247010} = "Mulgoa";
$areanames{en}->{61247011} = "Mulgoa";
$areanames{en}->{61247012} = "Mulgoa";
$areanames{en}->{61247013} = "Penrith";
$areanames{en}->{61247014} = "Penrith";
$areanames{en}->{61247015} = "Penrith";
$areanames{en}->{61247016} = "Lawson";
$areanames{en}->{61247017} = "Mount\ Wilson";
$areanames{en}->{61247018} = "Mulgoa";
$areanames{en}->{61247019} = "Penrith";
$areanames{en}->{6124702} = "Penrith";
$areanames{en}->{61247030} = "Katoomba";
$areanames{en}->{61247031} = "Lawson";
$areanames{en}->{61247032} = "Mount\ Wilson";
$areanames{en}->{61247033} = "Mulgoa";
$areanames{en}->{61247034} = "Penrith";
$areanames{en}->{61247035} = "Katoomba";
$areanames{en}->{61247036} = "Lawson";
$areanames{en}->{61247037} = "Mount\ Wilson";
$areanames{en}->{61247038} = "Mulgoa";
$areanames{en}->{61247039} = "Penrith";
$areanames{en}->{61247040} = "Katoomba";
$areanames{en}->{61247041} = "Lawson";
$areanames{en}->{61247042} = "Mount\ Wilson";
$areanames{en}->{61247043} = "Mulgoa";
$areanames{en}->{61247044} = "Katoomba";
$areanames{en}->{61247045} = "Lawson";
$areanames{en}->{61247046} = "Mount\ Wilson";
$areanames{en}->{61247047} = "Mulgoa";
$areanames{en}->{61247048} = "Penrith";
$areanames{en}->{61247049} = "Penrith";
$areanames{en}->{61247050} = "Lawson";
$areanames{en}->{61247051} = "Mount\ Wilson";
$areanames{en}->{61247052} = "Mulgoa";
$areanames{en}->{61247053} = "Katoomba";
$areanames{en}->{61247054} = "Lawson";
$areanames{en}->{61247055} = "Mount\ Wilson";
$areanames{en}->{61247056} = "Mulgoa";
$areanames{en}->{61247057} = "Penrith";
$areanames{en}->{61247058} = "Katoomba";
$areanames{en}->{61247059} = "Lawson";
$areanames{en}->{61247060} = "Penrith";
$areanames{en}->{61247061} = "Mulgoa";
$areanames{en}->{61247062} = "Penrith";
$areanames{en}->{61247063} = "Katoomba";
$areanames{en}->{61247064} = "Lawson";
$areanames{en}->{61247065} = "Mulgoa";
$areanames{en}->{61247066} = "Katoomba";
$areanames{en}->{61247067} = "Lawson";
$areanames{en}->{61247068} = "Penrith";
$areanames{en}->{61247069} = "Penrith";
$areanames{en}->{6124707} = "Penrith";
$areanames{en}->{6124708} = "Penrith";
$areanames{en}->{61247084} = "Mulgoa";
$areanames{en}->{61247085} = "Lawson";
$areanames{en}->{61247086} = "Mount\ Wilson";
$areanames{en}->{61247087} = "Katoomba";
$areanames{en}->{61247090} = "Penrith";
$areanames{en}->{61247091} = "Mulgoa";
$areanames{en}->{61247092} = "Lawson";
$areanames{en}->{61247093} = "Mount\ Wilson";
$areanames{en}->{61247094} = "Katoomba";
$areanames{en}->{61247095} = "Mount\ Wilson";
$areanames{en}->{61247096} = "Penrith";
$areanames{en}->{61247097} = "Penrith";
$areanames{en}->{61247098} = "Penrith";
$areanames{en}->{61247099} = "Katoomba";
$areanames{en}->{61247100} = "Lawson";
$areanames{en}->{61247101} = "Mount\ Wilson";
$areanames{en}->{61247102} = "Mulgoa";
$areanames{en}->{61247103} = "Penrith";
$areanames{en}->{61247104} = "Katoomba";
$areanames{en}->{61247105} = "Lawson";
$areanames{en}->{61247106} = "Mount\ Wilson";
$areanames{en}->{61247107} = "Mulgoa";
$areanames{en}->{61247108} = "Penrith";
$areanames{en}->{61247109} = "Katoomba";
$areanames{en}->{61247110} = "Lawson";
$areanames{en}->{61247111} = "Mount\ Wilson";
$areanames{en}->{61247112} = "Mulgoa";
$areanames{en}->{61247113} = "Penrith";
$areanames{en}->{61247114} = "Penrith";
$areanames{en}->{61247115} = "Penrith";
$areanames{en}->{61247116} = "Penrith";
$areanames{en}->{61247117} = "Katoomba";
$areanames{en}->{61247118} = "Lawson";
$areanames{en}->{61247119} = "Katoomba";
$areanames{en}->{61247120} = "Lawson";
$areanames{en}->{61247121} = "Mount\ Wilson";
$areanames{en}->{61247122} = "Mulgoa";
$areanames{en}->{61247123} = "Penrith";
$areanames{en}->{61247124} = "Mount\ Wilson";
$areanames{en}->{61247125} = "Mulgoa";
$areanames{en}->{61247126} = "Penrith";
$areanames{en}->{61247127} = "Katoomba";
$areanames{en}->{61247128} = "Lawson";
$areanames{en}->{61247129} = "Mount\ Wilson";
$areanames{en}->{61247130} = "Mulgoa";
$areanames{en}->{61247131} = "Penrith";
$areanames{en}->{61247132} = "Katoomba";
$areanames{en}->{61247133} = "Lawson";
$areanames{en}->{61247134} = "Mount\ Wilson";
$areanames{en}->{61247135} = "Mulgoa";
$areanames{en}->{61247136} = "Penrith";
$areanames{en}->{61247137} = "Katoomba";
$areanames{en}->{61247138} = "Lawson";
$areanames{en}->{61247139} = "Mount\ Wilson";
$areanames{en}->{61247140} = "Mulgoa";
$areanames{en}->{61247141} = "Penrith";
$areanames{en}->{612472} = "Penrith";
$areanames{en}->{6124720} = "Mulgoa";
$areanames{en}->{612473} = "Penrith";
$areanames{en}->{6124740} = "Penrith";
$areanames{en}->{6124741} = "Mulgoa";
$areanames{en}->{61247420} = "Katoomba";
$areanames{en}->{61247421} = "Lawson";
$areanames{en}->{61247422} = "Mulgoa";
$areanames{en}->{61247423} = "Penrith";
$areanames{en}->{61247424} = "Penrith";
$areanames{en}->{61247425} = "Penrith";
$areanames{en}->{61247426} = "Penrith";
$areanames{en}->{61247427} = "Katoomba";
$areanames{en}->{61247428} = "Katoomba";
$areanames{en}->{61247429} = "Katoomba";
$areanames{en}->{6124743} = "Penrith";
$areanames{en}->{6124744} = "Penrith";
$areanames{en}->{61247444} = "Mulgoa";
$areanames{en}->{6124747} = "Penrith";
$areanames{en}->{61247480} = "Penrith";
$areanames{en}->{61247489} = "Penrith";
$areanames{en}->{6124749} = "Penrith";
$areanames{en}->{6124750} = "Lawson";
$areanames{en}->{6124751} = "Penrith";
$areanames{en}->{6124752} = "Penrith";
$areanames{en}->{61247530} = "Lawson";
$areanames{en}->{61247531} = "Lawson";
$areanames{en}->{61247532} = "Lawson";
$areanames{en}->{61247533} = "Lawson";
$areanames{en}->{61247534} = "Lawson";
$areanames{en}->{61247535} = "Penrith";
$areanames{en}->{61247536} = "Penrith";
$areanames{en}->{61247537} = "Penrith";
$areanames{en}->{61247538} = "Penrith";
$areanames{en}->{61247539} = "Penrith";
$areanames{en}->{6124754} = "Penrith";
$areanames{en}->{6124755} = "Penrith";
$areanames{en}->{6124756} = "Mount\ Wilson";
$areanames{en}->{6124757} = "Lawson";
$areanames{en}->{6124758} = "Lawson";
$areanames{en}->{6124759} = "Lawson";
$areanames{en}->{61247600} = "Penrith";
$areanames{en}->{61247601} = "Penrith";
$areanames{en}->{61247602} = "Penrith";
$areanames{en}->{61247603} = "Penrith";
$areanames{en}->{61247604} = "Lawson";
$areanames{en}->{61247605} = "Lawson";
$areanames{en}->{61247608} = "Katoomba";
$areanames{en}->{61247609} = "Katoomba";
$areanames{en}->{6124761} = "Penrith";
$areanames{en}->{6124773} = "Mulgoa";
$areanames{en}->{6124774} = "Mulgoa";
$areanames{en}->{6124775} = "Mulgoa";
$areanames{en}->{6124776} = "Penrith";
$areanames{en}->{6124777} = "Penrith";
$areanames{en}->{61247780} = "Katoomba";
$areanames{en}->{61247781} = "Lawson";
$areanames{en}->{61247782} = "Mount\ Wilson";
$areanames{en}->{6124780} = "Katoomba";
$areanames{en}->{61247803} = "Lawson";
$areanames{en}->{61247804} = "Lawson";
$areanames{en}->{61247809} = "Mount\ Wilson";
$areanames{en}->{6124781} = "Katoomba";
$areanames{en}->{6124782} = "Katoomba";
$areanames{en}->{61247830} = "Katoomba";
$areanames{en}->{61247831} = "Mulgoa";
$areanames{en}->{61247832} = "Mulgoa";
$areanames{en}->{61247833} = "Mount\ Wilson";
$areanames{en}->{61247834} = "Mount\ Wilson";
$areanames{en}->{61247835} = "Mulgoa";
$areanames{en}->{61247836} = "Mulgoa";
$areanames{en}->{61247837} = "Penrith";
$areanames{en}->{6124784} = "Katoomba";
$areanames{en}->{6124785} = "Katoomba";
$areanames{en}->{6124786} = "Penrith";
$areanames{en}->{6124787} = "Katoomba";
$areanames{en}->{6124788} = "Katoomba";
$areanames{en}->{6124789} = "Penrith";
$areanames{en}->{61247999} = "Penrith";
$areanames{en}->{61248000} = "Barrallier";
$areanames{en}->{61248001} = "Barrallier";
$areanames{en}->{61248002} = "Barrallier";
$areanames{en}->{61248003} = "Bevendale";
$areanames{en}->{61248004} = "Bevendale";
$areanames{en}->{61248005} = "Bevendale";
$areanames{en}->{61248006} = "Binda";
$areanames{en}->{61248007} = "Binda";
$areanames{en}->{61248008} = "Binda";
$areanames{en}->{61248009} = "Bowral";
$areanames{en}->{61248010} = "Bowral";
$areanames{en}->{61248011} = "Bowral";
$areanames{en}->{61248012} = "Bowral";
$areanames{en}->{61248013} = "Braidwood";
$areanames{en}->{61248014} = "Braidwood";
$areanames{en}->{61248015} = "Braidwood";
$areanames{en}->{61248016} = "Breadalbane";
$areanames{en}->{61248017} = "Breadalbane";
$areanames{en}->{61248018} = "Breadalbane";
$areanames{en}->{61248019} = "Barrallier";
$areanames{en}->{61248020} = "Bundanoon";
$areanames{en}->{61248021} = "Bundanoon";
$areanames{en}->{61248022} = "Bundanoon";
$areanames{en}->{61248023} = "Bungonia";
$areanames{en}->{61248024} = "Bungonia";
$areanames{en}->{61248025} = "Bungonia";
$areanames{en}->{61248026} = "Crookwell";
$areanames{en}->{61248027} = "Crookwell";
$areanames{en}->{61248028} = "Crookwell";
$areanames{en}->{61248029} = "Bowral";
$areanames{en}->{61248030} = "Golspie";
$areanames{en}->{61248031} = "Golspie";
$areanames{en}->{61248032} = "Golspie";
$areanames{en}->{61248033} = "Goulburn";
$areanames{en}->{61248034} = "Goulburn";
$areanames{en}->{61248035} = "Goulburn";
$areanames{en}->{61248036} = "Gundillion";
$areanames{en}->{61248037} = "Gundillion";
$areanames{en}->{61248038} = "Gundillion";
$areanames{en}->{61248039} = "Goulburn";
$areanames{en}->{61248040} = "Gunning";
$areanames{en}->{61248041} = "Gunning";
$areanames{en}->{61248042} = "Gunning";
$areanames{en}->{61248043} = "Lost\ River";
$areanames{en}->{61248044} = "Lost\ River";
$areanames{en}->{61248045} = "Lost\ River";
$areanames{en}->{61248046} = "Marulan";
$areanames{en}->{61248047} = "Marulan";
$areanames{en}->{61248048} = "Marulan";
$areanames{en}->{61248049} = "Bundanoon";
$areanames{en}->{61248050} = "Nerriga";
$areanames{en}->{61248051} = "Nerriga";
$areanames{en}->{61248052} = "Nerriga";
$areanames{en}->{61248053} = "Paddys\ River";
$areanames{en}->{61248054} = "Paddys\ River";
$areanames{en}->{61248055} = "Paddys\ River";
$areanames{en}->{61248056} = "Reidsdale";
$areanames{en}->{61248057} = "Reidsdale";
$areanames{en}->{61248058} = "Reidsdale";
$areanames{en}->{61248059} = "Paddys\ River";
$areanames{en}->{61248060} = "Robertson";
$areanames{en}->{61248061} = "Robertson";
$areanames{en}->{61248062} = "Robertson";
$areanames{en}->{61248063} = "Rugby";
$areanames{en}->{61248064} = "Rugby";
$areanames{en}->{61248065} = "Rugby";
$areanames{en}->{61248066} = "Tarago";
$areanames{en}->{61248067} = "Tarago";
$areanames{en}->{61248068} = "Tarago";
$areanames{en}->{61248069} = "Robertson";
$areanames{en}->{61248070} = "Taralga";
$areanames{en}->{61248071} = "Taralga";
$areanames{en}->{61248072} = "Taralga";
$areanames{en}->{61248073} = "Tuena";
$areanames{en}->{61248074} = "Tuena";
$areanames{en}->{61248075} = "Tuena";
$areanames{en}->{61248076} = "Wombeyan\ Caves";
$areanames{en}->{61248077} = "Wombeyan\ Caves";
$areanames{en}->{61248078} = "Wombeyan\ Caves";
$areanames{en}->{61248079} = "Yerrinbool";
$areanames{en}->{6124808} = "Goulburn";
$areanames{en}->{61248090} = "Woodhouselee";
$areanames{en}->{61248091} = "Woodhouselee";
$areanames{en}->{61248092} = "Woodhouselee";
$areanames{en}->{61248093} = "Yerrinbool";
$areanames{en}->{61248094} = "Yerrinbool";
$areanames{en}->{61248095} = "Yerrinbool";
$areanames{en}->{61248096} = "Binda";
$areanames{en}->{61248097} = "Crookwell";
$areanames{en}->{61248098} = "Lost\ River";
$areanames{en}->{61248099} = "Rugby";
$areanames{en}->{61248100} = "Goulburn";
$areanames{en}->{61248107} = "Gundillion";
$areanames{en}->{61248108} = "Lost\ River";
$areanames{en}->{61248109} = "Nerriga";
$areanames{en}->{61248110} = "Barrallier";
$areanames{en}->{61248111} = "Bowral";
$areanames{en}->{61248112} = "Bundanoon";
$areanames{en}->{61248113} = "Paddys\ River";
$areanames{en}->{61248114} = "Robertson";
$areanames{en}->{61248115} = "Yerrinbool";
$areanames{en}->{61248116} = "Binda";
$areanames{en}->{61248117} = "Crookwell";
$areanames{en}->{61248118} = "Lost\ River";
$areanames{en}->{61248119} = "Rugby";
$areanames{en}->{61248120} = "Tuena";
$areanames{en}->{61248121} = "Bevendale";
$areanames{en}->{61248122} = "Braidwood";
$areanames{en}->{61248123} = "Breadalbane";
$areanames{en}->{61248124} = "Bungonia";
$areanames{en}->{61248125} = "Goulburn";
$areanames{en}->{61248126} = "Gundillion";
$areanames{en}->{61248127} = "Gunning";
$areanames{en}->{61248128} = "Nerriga";
$areanames{en}->{61248129} = "Reidsdale";
$areanames{en}->{61248130} = "Tarago";
$areanames{en}->{61248131} = "Woodhouselee";
$areanames{en}->{61248132} = "Golspie";
$areanames{en}->{61248133} = "Marulan";
$areanames{en}->{61248134} = "Taralga";
$areanames{en}->{61248135} = "Wombeyan\ Caves";
$areanames{en}->{61248136} = "Barrallier";
$areanames{en}->{61248137} = "Bowral";
$areanames{en}->{61248138} = "Bundanoon";
$areanames{en}->{61248139} = "Paddys\ River";
$areanames{en}->{61248140} = "Robertson";
$areanames{en}->{61248141} = "Yerrinbool";
$areanames{en}->{61248142} = "Binda";
$areanames{en}->{61248143} = "Crookwell";
$areanames{en}->{61248144} = "Lost\ River";
$areanames{en}->{61248145} = "Rugby";
$areanames{en}->{61248146} = "Tuena";
$areanames{en}->{61248147} = "Bevendale";
$areanames{en}->{61248148} = "Braidwood";
$areanames{en}->{61248149} = "Breadalbane";
$areanames{en}->{61248150} = "Tuena";
$areanames{en}->{61248151} = "Bevendale";
$areanames{en}->{61248152} = "Braidwood";
$areanames{en}->{61248153} = "Breadalbane";
$areanames{en}->{61248154} = "Bungonia";
$areanames{en}->{61248155} = "Goulburn";
$areanames{en}->{61248156} = "Gundillion";
$areanames{en}->{61248157} = "Gunning";
$areanames{en}->{61248158} = "Nerriga";
$areanames{en}->{61248159} = "Reidsdale";
$areanames{en}->{61248160} = "Bungonia";
$areanames{en}->{61248161} = "Goulburn";
$areanames{en}->{61248162} = "Gundillion";
$areanames{en}->{61248163} = "Gunning";
$areanames{en}->{61248164} = "Nerriga";
$areanames{en}->{61248165} = "Reidsdale";
$areanames{en}->{61248166} = "Tarago";
$areanames{en}->{61248167} = "Woodhouselee";
$areanames{en}->{61248168} = "Golspie";
$areanames{en}->{61248169} = "Marulan";
$areanames{en}->{61248170} = "Taralga";
$areanames{en}->{61248171} = "Wombeyan\ Caves";
$areanames{en}->{61248172} = "Barrallier";
$areanames{en}->{61248173} = "Bowral";
$areanames{en}->{61248174} = "Bundanoon";
$areanames{en}->{61248175} = "Paddys\ River";
$areanames{en}->{61248176} = "Robertson";
$areanames{en}->{61248177} = "Yerrinbool";
$areanames{en}->{61248178} = "Binda";
$areanames{en}->{61248179} = "Crookwell";
$areanames{en}->{61248180} = "Tarago";
$areanames{en}->{61248181} = "Woodhouselee";
$areanames{en}->{61248182} = "Golspie";
$areanames{en}->{61248183} = "Marulan";
$areanames{en}->{61248184} = "Taralga";
$areanames{en}->{61248185} = "Wombeyan\ Caves";
$areanames{en}->{61248186} = "Lost\ River";
$areanames{en}->{61248187} = "Rugby";
$areanames{en}->{61248188} = "Tuena";
$areanames{en}->{61248189} = "Bevendale";
$areanames{en}->{61248190} = "Braidwood";
$areanames{en}->{61248191} = "Breadalbane";
$areanames{en}->{61248192} = "Bungonia";
$areanames{en}->{61248193} = "Goulburn";
$areanames{en}->{61248194} = "Gundillion";
$areanames{en}->{61248195} = "Gunning";
$areanames{en}->{61248196} = "Nerriga";
$areanames{en}->{61248197} = "Reidsdale";
$areanames{en}->{61248198} = "Tarago";
$areanames{en}->{61248199} = "Woodhouselee";
$areanames{en}->{612482} = "Goulburn";
$areanames{en}->{6124820} = "Marulan";
$areanames{en}->{61248201} = "Golspie";
$areanames{en}->{61248202} = "Taralga";
$areanames{en}->{61248204} = "Wombeyan\ Caves";
$areanames{en}->{61248233} = "Crookwell";
$areanames{en}->{61248250} = "Bevendale";
$areanames{en}->{61248251} = "Bungonia";
$areanames{en}->{61248252} = "Bungonia";
$areanames{en}->{61248257} = "Gunning";
$areanames{en}->{61248258} = "Nerriga";
$areanames{en}->{61248259} = "Woodhouselee";
$areanames{en}->{61248263} = "Woodhouselee";
$areanames{en}->{61248264} = "Breadalbane";
$areanames{en}->{61248265} = "Bungonia";
$areanames{en}->{61248266} = "Tarago";
$areanames{en}->{61248267} = "Gunning";
$areanames{en}->{61248268} = "Bevendale";
$areanames{en}->{61248274} = "Bungonia";
$areanames{en}->{61248275} = "Woodhouselee";
$areanames{en}->{61248276} = "Gunning";
$areanames{en}->{61248277} = "Breadalbane";
$areanames{en}->{61248278} = "Tarago";
$areanames{en}->{61248279} = "Braidwood";
$areanames{en}->{61248281} = "Gundillion";
$areanames{en}->{61248282} = "Reidsdale";
$areanames{en}->{61248283} = "Nerriga";
$areanames{en}->{6124830} = "Crookwell";
$areanames{en}->{61248302} = "Binda";
$areanames{en}->{61248303} = "Tuena";
$areanames{en}->{61248304} = "Lost\ River";
$areanames{en}->{61248305} = "Rugby";
$areanames{en}->{61248310} = "Golspie";
$areanames{en}->{61248311} = "Marulan";
$areanames{en}->{61248312} = "Taralga";
$areanames{en}->{61248313} = "Wombeyan\ Caves";
$areanames{en}->{61248314} = "Barrallier";
$areanames{en}->{61248315} = "Bundanoon";
$areanames{en}->{61248316} = "Paddys\ River";
$areanames{en}->{61248317} = "Robertson";
$areanames{en}->{61248318} = "Yerrinbool";
$areanames{en}->{61248319} = "Binda";
$areanames{en}->{6124832} = "Crookwell";
$areanames{en}->{61248330} = "Crookwell";
$areanames{en}->{61248331} = "Lost\ River";
$areanames{en}->{61248332} = "Rugby";
$areanames{en}->{61248333} = "Tuena";
$areanames{en}->{61248334} = "Bevendale";
$areanames{en}->{61248335} = "Braidwood";
$areanames{en}->{61248336} = "Breadalbane";
$areanames{en}->{61248337} = "Bungonia";
$areanames{en}->{61248338} = "Gundillion";
$areanames{en}->{61248339} = "Gunning";
$areanames{en}->{6124834} = "Tuena";
$areanames{en}->{6124835} = "Binda";
$areanames{en}->{61248357} = "Rugby";
$areanames{en}->{61248358} = "Rugby";
$areanames{en}->{61248359} = "Rugby";
$areanames{en}->{6124836} = "Lost\ River";
$areanames{en}->{6124837} = "Crookwell";
$areanames{en}->{61248380} = "Nerriga";
$areanames{en}->{61248381} = "Reidsdale";
$areanames{en}->{61248382} = "Tarago";
$areanames{en}->{61248383} = "Woodhouselee";
$areanames{en}->{61248384} = "Golspie";
$areanames{en}->{61248385} = "Marulan";
$areanames{en}->{61248386} = "Taralga";
$areanames{en}->{61248387} = "Wombeyan\ Caves";
$areanames{en}->{61248388} = "Barrallier";
$areanames{en}->{61248389} = "Bowral";
$areanames{en}->{61248390} = "Bundanoon";
$areanames{en}->{61248391} = "Paddys\ River";
$areanames{en}->{61248392} = "Robertson";
$areanames{en}->{61248393} = "Yerrinbool";
$areanames{en}->{61248394} = "Binda";
$areanames{en}->{61248395} = "Crookwell";
$areanames{en}->{61248396} = "Lost\ River";
$areanames{en}->{61248397} = "Rugby";
$areanames{en}->{61248398} = "Tuena";
$areanames{en}->{61248399} = "Bevendale";
$areanames{en}->{6124840} = "Taralga";
$areanames{en}->{6124841} = "Marulan";
$areanames{en}->{6124842} = "Braidwood";
$areanames{en}->{6124843} = "Golspie";
$areanames{en}->{61248432} = "Woodhouselee";
$areanames{en}->{61248435} = "Wombeyan\ Caves";
$areanames{en}->{61248440} = "Breadalbane";
$areanames{en}->{61248441} = "Woodhouselee";
$areanames{en}->{61248442} = "Breadalbane";
$areanames{en}->{61248443} = "Woodhouselee";
$areanames{en}->{61248444} = "Bungonia";
$areanames{en}->{61248445} = "Bungonia";
$areanames{en}->{61248446} = "Breadalbane";
$areanames{en}->{61248447} = "Bungonia";
$areanames{en}->{61248448} = "Breadalbane";
$areanames{en}->{61248449} = "Breadalbane";
$areanames{en}->{6124845} = "Gunning";
$areanames{en}->{61248450} = "Bevendale";
$areanames{en}->{61248455} = "Bevendale";
$areanames{en}->{61248459} = "Nerriga";
$areanames{en}->{6124846} = "Reidsdale";
$areanames{en}->{6124847} = "Gundillion";
$areanames{en}->{6124848} = "Bungonia";
$areanames{en}->{61248480} = "Breadalbane";
$areanames{en}->{61248481} = "Woodhouselee";
$areanames{en}->{61248482} = "Woodhouselee";
$areanames{en}->{61248483} = "Woodhouselee";
$areanames{en}->{6124849} = "Tarago";
$areanames{en}->{61248500} = "Braidwood";
$areanames{en}->{61248501} = "Breadalbane";
$areanames{en}->{61248502} = "Bungonia";
$areanames{en}->{61248503} = "Goulburn";
$areanames{en}->{61248504} = "Gundillion";
$areanames{en}->{61248505} = "Gunning";
$areanames{en}->{61248506} = "Nerriga";
$areanames{en}->{61248507} = "Reidsdale";
$areanames{en}->{61248508} = "Tarago";
$areanames{en}->{61248509} = "Woodhouselee";
$areanames{en}->{61248510} = "Golspie";
$areanames{en}->{61248511} = "Marulan";
$areanames{en}->{61248512} = "Taralga";
$areanames{en}->{61248513} = "Wombeyan\ Caves";
$areanames{en}->{61248514} = "Bowral";
$areanames{en}->{61248515} = "Bowral";
$areanames{en}->{61248516} = "Bundanoon";
$areanames{en}->{61248517} = "Bungonia";
$areanames{en}->{61248518} = "Robertson";
$areanames{en}->{61248519} = "Yerrinbool";
$areanames{en}->{61248526} = "Braidwood";
$areanames{en}->{61248527} = "Breadalbane";
$areanames{en}->{61248528} = "Gundillion";
$areanames{en}->{61248529} = "Goulburn";
$areanames{en}->{61248530} = "Gundillion";
$areanames{en}->{61248531} = "Gunning";
$areanames{en}->{61248532} = "Goulburn";
$areanames{en}->{61248533} = "Goulburn";
$areanames{en}->{61248534} = "Goulburn";
$areanames{en}->{61248535} = "Goulburn";
$areanames{en}->{61248536} = "Goulburn";
$areanames{en}->{61248537} = "Marulan";
$areanames{en}->{61248538} = "Bowral";
$areanames{en}->{61248539} = "Bowral";
$areanames{en}->{61248540} = "Bowral";
$areanames{en}->{61248541} = "Yerrinbool";
$areanames{en}->{61248542} = "Goulburn";
$areanames{en}->{61248543} = "Goulburn";
$areanames{en}->{61248544} = "Bowral";
$areanames{en}->{61248545} = "Binda";
$areanames{en}->{61248546} = "Binda";
$areanames{en}->{61248547} = "Golspie";
$areanames{en}->{61248548} = "Golspie";
$areanames{en}->{61248549} = "Wombeyan\ Caves";
$areanames{en}->{61248550} = "Goulburn";
$areanames{en}->{61248551} = "Goulburn";
$areanames{en}->{61248552} = "Bowral";
$areanames{en}->{61248553} = "Bowral";
$areanames{en}->{61248554} = "Bundanoon";
$areanames{en}->{61248555} = "Bundanoon";
$areanames{en}->{61248556} = "Paddys\ River";
$areanames{en}->{61248557} = "Paddys\ River";
$areanames{en}->{61248558} = "Robertson";
$areanames{en}->{61248559} = "Robertson";
$areanames{en}->{61248560} = "Yerrinbool";
$areanames{en}->{61248561} = "Yerrinbool";
$areanames{en}->{61248562} = "Bevendale";
$areanames{en}->{61248563} = "Bevendale";
$areanames{en}->{61248564} = "Braidwood";
$areanames{en}->{61248565} = "Braidwood";
$areanames{en}->{61248566} = "Breadalbane";
$areanames{en}->{61248567} = "Breadalbane";
$areanames{en}->{61248568} = "Goulburn";
$areanames{en}->{61248569} = "Goulburn";
$areanames{en}->{61248570} = "Gunning";
$areanames{en}->{61248571} = "Gunning";
$areanames{en}->{61248572} = "Reidsdale";
$areanames{en}->{61248573} = "Reidsdale";
$areanames{en}->{61248574} = "Bowral";
$areanames{en}->{61248575} = "Goulburn";
$areanames{en}->{61248576} = "Goulburn";
$areanames{en}->{61248577} = "Goulburn";
$areanames{en}->{61248578} = "Wombeyan\ Caves";
$areanames{en}->{61248579} = "Wombeyan\ Caves";
$areanames{en}->{61248580} = "Bowral";
$areanames{en}->{61248581} = "Bowral";
$areanames{en}->{61248582} = "Tarago";
$areanames{en}->{61248583} = "Tarago";
$areanames{en}->{61248584} = "Woodhouselee";
$areanames{en}->{61248585} = "Woodhouselee";
$areanames{en}->{61248586} = "Marulan";
$areanames{en}->{61248587} = "Marulan";
$areanames{en}->{61248588} = "Taralga";
$areanames{en}->{61248589} = "Taralga";
$areanames{en}->{61248590} = "Barrallier";
$areanames{en}->{61248591} = "Barrallier";
$areanames{en}->{61248592} = "Crookwell";
$areanames{en}->{61248593} = "Crookwell";
$areanames{en}->{61248594} = "Lost\ River";
$areanames{en}->{61248595} = "Lost\ River";
$areanames{en}->{61248596} = "Rugby";
$areanames{en}->{61248597} = "Rugby";
$areanames{en}->{61248598} = "Tuena";
$areanames{en}->{61248599} = "Tuena";
$areanames{en}->{61248600} = "Bowral";
$areanames{en}->{61248601} = "Bowral";
$areanames{en}->{61248602} = "Bowral";
$areanames{en}->{61248603} = "Bowral";
$areanames{en}->{61248604} = "Bowral";
$areanames{en}->{61248605} = "Bundanoon";
$areanames{en}->{61248606} = "Paddys\ River";
$areanames{en}->{61248607} = "Robertson";
$areanames{en}->{61248608} = "Yerrinbool";
$areanames{en}->{61248609} = "Barrallier";
$areanames{en}->{6124861} = "Bowral";
$areanames{en}->{6124862} = "Bowral";
$areanames{en}->{61248630} = "Bungonia";
$areanames{en}->{61248631} = "Bungonia";
$areanames{en}->{61248632} = "Nerriga";
$areanames{en}->{61248633} = "Nerriga";
$areanames{en}->{61248634} = "Bevendale";
$areanames{en}->{61248635} = "Bowral";
$areanames{en}->{61248636} = "Crookwell";
$areanames{en}->{61248637} = "Lost\ River";
$areanames{en}->{61248638} = "Bungonia";
$areanames{en}->{61248639} = "Goulburn";
$areanames{en}->{61248640} = "Goulburn";
$areanames{en}->{61248641} = "Barrallier";
$areanames{en}->{61248642} = "Tarago";
$areanames{en}->{61248643} = "Binda";
$areanames{en}->{61248644} = "Marulan";
$areanames{en}->{61248645} = "Woodhouselee";
$areanames{en}->{61248646} = "Bundanoon";
$areanames{en}->{61248647} = "Breadalbane";
$areanames{en}->{61248648} = "Golspie";
$areanames{en}->{61248649} = "Binda";
$areanames{en}->{61248651} = "Goulburn";
$areanames{en}->{61248652} = "Wombeyan\ Caves";
$areanames{en}->{61248653} = "Nerriga";
$areanames{en}->{61248654} = "Tuena";
$areanames{en}->{61248655} = "Rugby";
$areanames{en}->{61248656} = "Robertson";
$areanames{en}->{61248657} = "Braidwood";
$areanames{en}->{61248658} = "Reidsdale";
$areanames{en}->{61248661} = "Paddys\ River";
$areanames{en}->{61248662} = "Yerrinbool";
$areanames{en}->{61248663} = "Taralga";
$areanames{en}->{61248664} = "Gundillion";
$areanames{en}->{61248665} = "Gunning";
$areanames{en}->{61248666} = "Bevendale";
$areanames{en}->{61248667} = "Bowral";
$areanames{en}->{61248668} = "Crookwell";
$areanames{en}->{61248671} = "Lost\ River";
$areanames{en}->{61248672} = "Bungonia";
$areanames{en}->{61248673} = "Barrallier";
$areanames{en}->{61248674} = "Tarago";
$areanames{en}->{61248675} = "Binda";
$areanames{en}->{61248676} = "Marulan";
$areanames{en}->{61248677} = "Woodhouselee";
$areanames{en}->{61248678} = "Bundanoon";
$areanames{en}->{61248679} = "Binda";
$areanames{en}->{6124868} = "Bowral";
$areanames{en}->{6124869} = "Bowral";
$areanames{en}->{61248700} = "Barrallier";
$areanames{en}->{61248701} = "Bowral";
$areanames{en}->{61248702} = "Bundanoon";
$areanames{en}->{61248703} = "Paddys\ River";
$areanames{en}->{61248704} = "Robertson";
$areanames{en}->{61248705} = "Yerrinbool";
$areanames{en}->{61248706} = "Binda";
$areanames{en}->{61248707} = "Crookwell";
$areanames{en}->{61248708} = "Lost\ River";
$areanames{en}->{61248709} = "Rugby";
$areanames{en}->{6124871} = "Bowral";
$areanames{en}->{6124872} = "Bowral";
$areanames{en}->{61248730} = "Tuena";
$areanames{en}->{61248731} = "Bevendale";
$areanames{en}->{61248732} = "Braidwood";
$areanames{en}->{61248733} = "Breadalbane";
$areanames{en}->{61248734} = "Bungonia";
$areanames{en}->{61248735} = "Goulburn";
$areanames{en}->{61248736} = "Gundillion";
$areanames{en}->{61248737} = "Gunning";
$areanames{en}->{61248738} = "Nerriga";
$areanames{en}->{61248739} = "Reidsdale";
$areanames{en}->{61248740} = "Tarago";
$areanames{en}->{61248741} = "Woodhouselee";
$areanames{en}->{61248742} = "Golspie";
$areanames{en}->{61248743} = "Marulan";
$areanames{en}->{61248744} = "Taralga";
$areanames{en}->{61248745} = "Wombeyan\ Caves";
$areanames{en}->{61248746} = "Breadalbane";
$areanames{en}->{61248747} = "Golspie";
$areanames{en}->{61248748} = "Goulburn";
$areanames{en}->{61248751} = "Wombeyan\ Caves";
$areanames{en}->{61248752} = "Nerriga";
$areanames{en}->{61248753} = "Tuena";
$areanames{en}->{61248754} = "Rugby";
$areanames{en}->{61248755} = "Robertson";
$areanames{en}->{61248756} = "Braidwood";
$areanames{en}->{61248757} = "Reidsdale";
$areanames{en}->{61248758} = "Paddys\ River";
$areanames{en}->{61248761} = "Yerrinbool";
$areanames{en}->{61248762} = "Taralga";
$areanames{en}->{61248763} = "Gundillion";
$areanames{en}->{61248764} = "Gunning";
$areanames{en}->{61248765} = "Robertson";
$areanames{en}->{61248766} = "Barrallier";
$areanames{en}->{61248767} = "Braidwood";
$areanames{en}->{61248768} = "Reidsdale";
$areanames{en}->{61248769} = "Tarago";
$areanames{en}->{6124877} = "Bowral";
$areanames{en}->{6124878} = "Bowral";
$areanames{en}->{61248790} = "Gundillion";
$areanames{en}->{61248791} = "Gundillion";
$areanames{en}->{61248792} = "Paddys\ River";
$areanames{en}->{61248793} = "Yerrinbool";
$areanames{en}->{61248794} = "Bundanoon";
$areanames{en}->{61248795} = "Binda";
$areanames{en}->{61248796} = "Marulan";
$areanames{en}->{61248797} = "Taralga";
$areanames{en}->{61248798} = "Golspie";
$areanames{en}->{61248799} = "Bowral";
$areanames{en}->{61248801} = "Bowral";
$areanames{en}->{61248802} = "Gundillion";
$areanames{en}->{61248803} = "Crookwell";
$areanames{en}->{61248804} = "Lost\ River";
$areanames{en}->{61248805} = "Wombeyan\ Caves";
$areanames{en}->{61248806} = "Nerriga";
$areanames{en}->{61248807} = "Tuena";
$areanames{en}->{61248808} = "Rugby";
$areanames{en}->{61248809} = "Braidwood";
$areanames{en}->{6124883} = "Bundanoon";
$areanames{en}->{61248839} = "Yerrinbool";
$areanames{en}->{6124884} = "Bundanoon";
$areanames{en}->{61248840} = "Paddys\ River";
$areanames{en}->{61248841} = "Paddys\ River";
$areanames{en}->{61248842} = "Paddys\ River";
$areanames{en}->{61248843} = "Paddys\ River";
$areanames{en}->{6124885} = "Robertson";
$areanames{en}->{6124886} = "Robertson";
$areanames{en}->{6124887} = "Robertson";
$areanames{en}->{6124888} = "Robertson";
$areanames{en}->{61248889} = "Barrallier";
$areanames{en}->{6124889} = "Yerrinbool";
$areanames{en}->{61248900} = "Tuena";
$areanames{en}->{61248901} = "Goulburn";
$areanames{en}->{61248997} = "Bowral";
$areanames{en}->{61248998} = "Goulburn";
$areanames{en}->{61248999} = "Goulburn";
$areanames{en}->{612490} = "Newcastle";
$areanames{en}->{6124901} = "Nelson\ Bay";
$areanames{en}->{61249051} = "Maitland";
$areanames{en}->{61249052} = "Maitland";
$areanames{en}->{61249053} = "Maitland";
$areanames{en}->{61249054} = "Nelson\ Bay";
$areanames{en}->{61249055} = "Nelson\ Bay";
$areanames{en}->{61249056} = "Nelson\ Bay";
$areanames{en}->{61249057} = "Bandon\ Grove";
$areanames{en}->{61249058} = "Branxton";
$areanames{en}->{61249059} = "Bulahdelah";
$areanames{en}->{61249090} = "East\ Gresford";
$areanames{en}->{61249091} = "East\ Gresford";
$areanames{en}->{61249092} = "East\ Gresford";
$areanames{en}->{61249093} = "Maitland";
$areanames{en}->{61249094} = "Maitland";
$areanames{en}->{61249095} = "Branxton";
$areanames{en}->{61249096} = "Branxton";
$areanames{en}->{61249097} = "Cessnock";
$areanames{en}->{61249098} = "Cessnock";
$areanames{en}->{61249099} = "Mulbring";
$areanames{en}->{6124910} = "Newcastle";
$areanames{en}->{6124911} = "Newcastle";
$areanames{en}->{61249120} = "Cessnock";
$areanames{en}->{61249121} = "Clarence\ Town";
$areanames{en}->{61249122} = "Dungog";
$areanames{en}->{61249123} = "East\ Gresford";
$areanames{en}->{61249124} = "Eccleston";
$areanames{en}->{61249125} = "Karuah";
$areanames{en}->{61249126} = "Laguna";
$areanames{en}->{61249127} = "Mulbring";
$areanames{en}->{61249128} = "Nelson\ Bay";
$areanames{en}->{61249129} = "Raymond\ Terrace";
$areanames{en}->{61249130} = "Stroud";
$areanames{en}->{61249131} = "Swansea";
$areanames{en}->{61249132} = "Tea\ Gardens";
$areanames{en}->{61249133} = "Wards\ River";
$areanames{en}->{61249134} = "Wootton";
$areanames{en}->{61249135} = "Newcastle";
$areanames{en}->{61249136} = "Newcastle";
$areanames{en}->{61249137} = "Newcastle";
$areanames{en}->{61249138} = "Newcastle";
$areanames{en}->{61249139} = "Newcastle";
$areanames{en}->{6124914} = "Newcastle";
$areanames{en}->{61249149} = "Maitland";
$areanames{en}->{6124915} = "Newcastle";
$areanames{en}->{61249160} = "Nelson\ Bay";
$areanames{en}->{61249161} = "Nelson\ Bay";
$areanames{en}->{61249162} = "Nelson\ Bay";
$areanames{en}->{61249163} = "Nelson\ Bay";
$areanames{en}->{61249164} = "Nelson\ Bay";
$areanames{en}->{61249165} = "Karuah";
$areanames{en}->{61249166} = "Karuah";
$areanames{en}->{61249167} = "Bulahdelah";
$areanames{en}->{61249168} = "Bulahdelah";
$areanames{en}->{61249169} = "Wootton";
$areanames{en}->{61249170} = "Newcastle";
$areanames{en}->{61249171} = "Mulbring";
$areanames{en}->{61249172} = "Nelson\ Bay";
$areanames{en}->{61249173} = "Newcastle";
$areanames{en}->{61249174} = "Raymond\ Terrace";
$areanames{en}->{61249175} = "Stroud";
$areanames{en}->{61249176} = "Swansea";
$areanames{en}->{61249177} = "Tea\ Gardens";
$areanames{en}->{61249178} = "Wards\ River";
$areanames{en}->{61249179} = "Wootton";
$areanames{en}->{6124918} = "Newcastle";
$areanames{en}->{6124919} = "Nelson\ Bay";
$areanames{en}->{61249197} = "Tea\ Gardens";
$areanames{en}->{61249198} = "Tea\ Gardens";
$areanames{en}->{61249199} = "Tea\ Gardens";
$areanames{en}->{612492} = "Newcastle";
$areanames{en}->{612493} = "Maitland";
$areanames{en}->{61249315} = "Eccleston";
$areanames{en}->{61249317} = "Eccleston";
$areanames{en}->{6124935} = "Newcastle";
$areanames{en}->{61249380} = "Mulbring";
$areanames{en}->{61249381} = "Branxton";
$areanames{en}->{61249382} = "Branxton";
$areanames{en}->{61249383} = "Branxton";
$areanames{en}->{61249384} = "East\ Gresford";
$areanames{en}->{61249385} = "East\ Gresford";
$areanames{en}->{61249386} = "Branxton";
$areanames{en}->{61249387} = "Branxton";
$areanames{en}->{61249388} = "East\ Gresford";
$areanames{en}->{61249389} = "East\ Gresford";
$areanames{en}->{61249390} = "Branxton";
$areanames{en}->{61249396} = "Laguna";
$areanames{en}->{61249397} = "Mulbring";
$areanames{en}->{61249398} = "East\ Gresford";
$areanames{en}->{61249399} = "Eccleston";
$areanames{en}->{612494} = "Newcastle";
$areanames{en}->{612495} = "Newcastle";
$areanames{en}->{612496} = "Newcastle";
$areanames{en}->{612497} = "Swansea";
$areanames{en}->{6124974} = "Newcastle";
$areanames{en}->{6124978} = "Newcastle";
$areanames{en}->{6124979} = "Newcastle";
$areanames{en}->{61249800} = "Raymond\ Terrace";
$areanames{en}->{61249801} = "Swansea";
$areanames{en}->{61249802} = "Swansea";
$areanames{en}->{61249803} = "Raymond\ Terrace";
$areanames{en}->{61249804} = "Nelson\ Bay";
$areanames{en}->{61249805} = "Nelson\ Bay";
$areanames{en}->{61249806} = "Nelson\ Bay";
$areanames{en}->{61249807} = "Raymond\ Terrace";
$areanames{en}->{61249808} = "Bulahdelah";
$areanames{en}->{61249809} = "Swansea";
$areanames{en}->{6124981} = "Nelson\ Bay";
$areanames{en}->{6124982} = "Nelson\ Bay";
$areanames{en}->{6124983} = "Raymond\ Terrace";
$areanames{en}->{6124984} = "Nelson\ Bay";
$areanames{en}->{6124985} = "Newcastle";
$areanames{en}->{6124986} = "Swansea";
$areanames{en}->{6124987} = "Raymond\ Terrace";
$areanames{en}->{61249870} = "Karuah";
$areanames{en}->{61249879} = "Bulahdelah";
$areanames{en}->{6124988} = "Raymond\ Terrace";
$areanames{en}->{6124989} = "Newcastle";
$areanames{en}->{6124990} = "Cessnock";
$areanames{en}->{6124991} = "Cessnock";
$areanames{en}->{6124992} = "Dungog";
$areanames{en}->{6124993} = "Cessnock";
$areanames{en}->{6124994} = "Stroud";
$areanames{en}->{61249946} = "Wards\ River";
$areanames{en}->{61249947} = "Wards\ River";
$areanames{en}->{61249948} = "Wards\ River";
$areanames{en}->{6124995} = "Bandon\ Grove";
$areanames{en}->{61249956} = "Dungog";
$areanames{en}->{61249957} = "Dungog";
$areanames{en}->{6124996} = "Clarence\ Town";
$areanames{en}->{61249970} = "Tea\ Gardens";
$areanames{en}->{61249971} = "Tea\ Gardens";
$areanames{en}->{61249972} = "Tea\ Gardens";
$areanames{en}->{61249973} = "Karuah";
$areanames{en}->{61249974} = "Bulahdelah";
$areanames{en}->{61249975} = "Karuah";
$areanames{en}->{61249976} = "Bulahdelah";
$areanames{en}->{61249977} = "Wootton";
$areanames{en}->{61249978} = "Wootton";
$areanames{en}->{61249979} = "Tea\ Gardens";
$areanames{en}->{6124998} = "Cessnock";
$areanames{en}->{61249988} = "Laguna";
$areanames{en}->{61249989} = "Laguna";
$areanames{en}->{61249990} = "Clarence\ Town";
$areanames{en}->{61249991} = "Dungog";
$areanames{en}->{61249992} = "Dungog";
$areanames{en}->{61249993} = "Bandon\ Grove";
$areanames{en}->{61249994} = "Wards\ River";
$areanames{en}->{61249995} = "Stroud";
$areanames{en}->{61249996} = "Maitland";
$areanames{en}->{61249997} = "Wootton";
$areanames{en}->{61249998} = "Karuah";
$areanames{en}->{61249999} = "Tea\ Gardens";
$areanames{en}->{61250000} = "Albury";
$areanames{en}->{61250001} = "Albury";
$areanames{en}->{61250002} = "Balldale";
$areanames{en}->{61250003} = "Barnawartha";
$areanames{en}->{61250004} = "Coppabella";
$areanames{en}->{61250005} = "Corowa";
$areanames{en}->{61250006} = "Corryong";
$areanames{en}->{61250007} = "Cudgewa";
$areanames{en}->{61250008} = "Culcairn";
$areanames{en}->{61250009} = "Dartmouth";
$areanames{en}->{61250010} = "Eskdale";
$areanames{en}->{61250011} = "Gerogery";
$areanames{en}->{61250012} = "Holbrook";
$areanames{en}->{61250013} = "Howlong";
$areanames{en}->{61250014} = "Koetong";
$areanames{en}->{61250015} = "Leicester\ Park";
$areanames{en}->{61250016} = "Little\ Billabong";
$areanames{en}->{61250017} = "Nariel";
$areanames{en}->{61250018} = "Oaklands";
$areanames{en}->{61250019} = "Ournie";
$areanames{en}->{61250020} = "Rand";
$areanames{en}->{61250021} = "Rennie";
$areanames{en}->{61250022} = "Talgarno";
$areanames{en}->{61250023} = "Tallangatta";
$areanames{en}->{61250024} = "Tallangatta\ Valley";
$areanames{en}->{61250025} = "Talmalmo";
$areanames{en}->{61250026} = "Walla\ Walla";
$areanames{en}->{61250027} = "Walwa";
$areanames{en}->{61250028} = "Yackandandah";
$areanames{en}->{61250029} = "Albury";
$areanames{en}->{61250030} = "Balldale";
$areanames{en}->{61250031} = "Barnawartha";
$areanames{en}->{61250032} = "Coppabella";
$areanames{en}->{61250033} = "Corowa";
$areanames{en}->{61250034} = "Corryong";
$areanames{en}->{61250035} = "Cudgewa";
$areanames{en}->{61250036} = "Culcairn";
$areanames{en}->{61250037} = "Dartmouth";
$areanames{en}->{61250038} = "Eskdale";
$areanames{en}->{61250039} = "Gerogery";
$areanames{en}->{61250040} = "Holbrook";
$areanames{en}->{61250041} = "Howlong";
$areanames{en}->{61250042} = "Koetong";
$areanames{en}->{61250043} = "Leicester\ Park";
$areanames{en}->{61250044} = "Little\ Billabong";
$areanames{en}->{61250045} = "Nariel";
$areanames{en}->{61250046} = "Oaklands";
$areanames{en}->{61250047} = "Ournie";
$areanames{en}->{61250048} = "Rand";
$areanames{en}->{61250049} = "Rennie";
$areanames{en}->{61250050} = "Talgarno";
$areanames{en}->{61250051} = "Tallangatta";
$areanames{en}->{61250052} = "Tallangatta\ Valley";
$areanames{en}->{61250053} = "Talmalmo";
$areanames{en}->{61250054} = "Walla\ Walla";
$areanames{en}->{61250055} = "Walwa";
$areanames{en}->{61250056} = "Yackandandah";
$areanames{en}->{61250057} = "Albury";
$areanames{en}->{61250058} = "Balldale";
$areanames{en}->{61250059} = "Barnawartha";
$areanames{en}->{61250060} = "Coppabella";
$areanames{en}->{61250061} = "Corowa";
$areanames{en}->{61250062} = "Corryong";
$areanames{en}->{61250063} = "Cudgewa";
$areanames{en}->{61250064} = "Culcairn";
$areanames{en}->{61250065} = "Dartmouth";
$areanames{en}->{61250066} = "Eskdale";
$areanames{en}->{61250067} = "Gerogery";
$areanames{en}->{61250068} = "Holbrook";
$areanames{en}->{61250069} = "Howlong";
$areanames{en}->{61250070} = "Koetong";
$areanames{en}->{61250071} = "Leicester\ Park";
$areanames{en}->{61250072} = "Little\ Billabong";
$areanames{en}->{61250073} = "Nariel";
$areanames{en}->{61250074} = "Oaklands";
$areanames{en}->{61250075} = "Ournie";
$areanames{en}->{61250076} = "Rand";
$areanames{en}->{61250077} = "Rennie";
$areanames{en}->{61250078} = "Talgarno";
$areanames{en}->{61250079} = "Tallangatta";
$areanames{en}->{61250080} = "Tallangatta\ Valley";
$areanames{en}->{61250081} = "Talmalmo";
$areanames{en}->{61250082} = "Walla\ Walla";
$areanames{en}->{61250083} = "Walwa";
$areanames{en}->{61250084} = "Yackandandah";
$areanames{en}->{61250085} = "Albury";
$areanames{en}->{61250086} = "Albury";
$areanames{en}->{61250087} = "Albury";
$areanames{en}->{61250088} = "Albury";
$areanames{en}->{61250089} = "Albury";
$areanames{en}->{61250106} = "Balldale";
$areanames{en}->{61250107} = "Barnawartha";
$areanames{en}->{61250108} = "Coppabella";
$areanames{en}->{61250109} = "Corowa";
$areanames{en}->{61250110} = "Corryong";
$areanames{en}->{61250111} = "Cudgewa";
$areanames{en}->{61250112} = "Culcairn";
$areanames{en}->{61250113} = "Albury";
$areanames{en}->{61250114} = "Balldale";
$areanames{en}->{61250115} = "Barnawartha";
$areanames{en}->{61250116} = "Coppabella";
$areanames{en}->{61250117} = "Corowa";
$areanames{en}->{61250118} = "Corryong";
$areanames{en}->{61250119} = "Cudgewa";
$areanames{en}->{61250120} = "Culcairn";
$areanames{en}->{61250121} = "Dartmouth";
$areanames{en}->{61250122} = "Eskdale";
$areanames{en}->{61250123} = "Gerogery";
$areanames{en}->{61250124} = "Holbrook";
$areanames{en}->{61250125} = "Howlong";
$areanames{en}->{61250126} = "Koetong";
$areanames{en}->{61250127} = "Leicester\ Park";
$areanames{en}->{61250128} = "Little\ Billabong";
$areanames{en}->{61250129} = "Nariel";
$areanames{en}->{61250130} = "Oaklands";
$areanames{en}->{61250131} = "Ournie";
$areanames{en}->{61250132} = "Rand";
$areanames{en}->{61250133} = "Rennie";
$areanames{en}->{61250134} = "Talgarno";
$areanames{en}->{61250135} = "Tallangatta";
$areanames{en}->{61250136} = "Tallangatta\ Valley";
$areanames{en}->{61250137} = "Talmalmo";
$areanames{en}->{61250138} = "Walla\ Walla";
$areanames{en}->{61250139} = "Walwa";
$areanames{en}->{61250140} = "Yackandandah";
$areanames{en}->{61250141} = "Dartmouth";
$areanames{en}->{61250142} = "Eskdale";
$areanames{en}->{61250143} = "Gerogery";
$areanames{en}->{61250144} = "Holbrook";
$areanames{en}->{61250145} = "Howlong";
$areanames{en}->{61250146} = "Koetong";
$areanames{en}->{61250147} = "Leicester\ Park";
$areanames{en}->{61250148} = "Little\ Billabong";
$areanames{en}->{61250149} = "Nariel";
$areanames{en}->{61250150} = "Oaklands";
$areanames{en}->{61250151} = "Ournie";
$areanames{en}->{61250152} = "Rand";
$areanames{en}->{61250153} = "Rennie";
$areanames{en}->{61250154} = "Talgarno";
$areanames{en}->{61250155} = "Tallangatta";
$areanames{en}->{61250156} = "Tallangatta\ Valley";
$areanames{en}->{61250157} = "Talmalmo";
$areanames{en}->{61250158} = "Walla\ Walla";
$areanames{en}->{61250159} = "Walwa";
$areanames{en}->{61250160} = "Yackandandah";
$areanames{en}->{61250161} = "Albury";
$areanames{en}->{61250162} = "Balldale";
$areanames{en}->{61250163} = "Barnawartha";
$areanames{en}->{61250164} = "Coppabella";
$areanames{en}->{61250165} = "Corowa";
$areanames{en}->{61250166} = "Corryong";
$areanames{en}->{61250167} = "Cudgewa";
$areanames{en}->{61250168} = "Culcairn";
$areanames{en}->{61250169} = "Dartmouth";
$areanames{en}->{61250170} = "Eskdale";
$areanames{en}->{61250171} = "Gerogery";
$areanames{en}->{61250172} = "Holbrook";
$areanames{en}->{61250173} = "Howlong";
$areanames{en}->{61250174} = "Koetong";
$areanames{en}->{61250175} = "Leicester\ Park";
$areanames{en}->{61250176} = "Little\ Billabong";
$areanames{en}->{61250177} = "Nariel";
$areanames{en}->{61250178} = "Oaklands";
$areanames{en}->{61250179} = "Ournie";
$areanames{en}->{61250180} = "Rand";
$areanames{en}->{61250181} = "Rennie";
$areanames{en}->{61250182} = "Talgarno";
$areanames{en}->{61250183} = "Tallangatta";
$areanames{en}->{61250184} = "Tallangatta\ Valley";
$areanames{en}->{61250185} = "Talmalmo";
$areanames{en}->{61250186} = "Walla\ Walla";
$areanames{en}->{61250187} = "Walwa";
$areanames{en}->{61250188} = "Yackandandah";
$areanames{en}->{61250189} = "Albury";
$areanames{en}->{61250190} = "Balldale";
$areanames{en}->{61250191} = "Barnawartha";
$areanames{en}->{61250192} = "Coppabella";
$areanames{en}->{61250193} = "Corowa";
$areanames{en}->{61250194} = "Corryong";
$areanames{en}->{61250195} = "Cudgewa";
$areanames{en}->{61250196} = "Culcairn";
$areanames{en}->{61250197} = "Dartmouth";
$areanames{en}->{61250198} = "Eskdale";
$areanames{en}->{61250199} = "Gerogery";
$areanames{en}->{61250200} = "Holbrook";
$areanames{en}->{61250201} = "Howlong";
$areanames{en}->{61250202} = "Koetong";
$areanames{en}->{61250203} = "Leicester\ Park";
$areanames{en}->{61250204} = "Little\ Billabong";
$areanames{en}->{61250205} = "Nariel";
$areanames{en}->{61250206} = "Oaklands";
$areanames{en}->{61250207} = "Ournie";
$areanames{en}->{61250208} = "Rand";
$areanames{en}->{61250209} = "Rennie";
$areanames{en}->{61250210} = "Talgarno";
$areanames{en}->{61250211} = "Tallangatta";
$areanames{en}->{61250212} = "Tallangatta\ Valley";
$areanames{en}->{61250213} = "Talmalmo";
$areanames{en}->{61250214} = "Walla\ Walla";
$areanames{en}->{61250215} = "Walwa";
$areanames{en}->{61250216} = "Yackandandah";
$areanames{en}->{61250217} = "Albury";
$areanames{en}->{61250218} = "Balldale";
$areanames{en}->{61250219} = "Barnawartha";
$areanames{en}->{61250220} = "Coppabella";
$areanames{en}->{61250221} = "Corowa";
$areanames{en}->{61250222} = "Corryong";
$areanames{en}->{61250223} = "Cudgewa";
$areanames{en}->{61250224} = "Culcairn";
$areanames{en}->{61250225} = "Dartmouth";
$areanames{en}->{61250226} = "Eskdale";
$areanames{en}->{61250227} = "Gerogery";
$areanames{en}->{61250228} = "Holbrook";
$areanames{en}->{61250229} = "Howlong";
$areanames{en}->{61250230} = "Koetong";
$areanames{en}->{61250231} = "Leicester\ Park";
$areanames{en}->{61250232} = "Little\ Billabong";
$areanames{en}->{61250233} = "Nariel";
$areanames{en}->{61250234} = "Oaklands";
$areanames{en}->{61250235} = "Ournie";
$areanames{en}->{61250236} = "Rand";
$areanames{en}->{61250237} = "Rennie";
$areanames{en}->{61250238} = "Talgarno";
$areanames{en}->{61250239} = "Tallangatta";
$areanames{en}->{61250240} = "Tallangatta\ Valley";
$areanames{en}->{61250241} = "Talmalmo";
$areanames{en}->{61250242} = "Walla\ Walla";
$areanames{en}->{61250243} = "Walwa";
$areanames{en}->{61250244} = "Yackandandah";
$areanames{en}->{612510} = "Canberra";
$areanames{en}->{61251010} = "Anembo";
$areanames{en}->{61251011} = "Binalong";
$areanames{en}->{61251012} = "Bungendore";
$areanames{en}->{61251013} = "Burrinjuck";
$areanames{en}->{61251015} = "Captains\ Flat";
$areanames{en}->{61251016} = "Cavan";
$areanames{en}->{61251017} = "Gearys\ Gap";
$areanames{en}->{61251018} = "Gundaroo";
$areanames{en}->{61251019} = "Michelago";
$areanames{en}->{61251020} = "Rye\ Park";
$areanames{en}->{61251021} = "The\ Mullion";
$areanames{en}->{61251022} = "Uriarra\ Forest";
$areanames{en}->{61251023} = "Yass";
$areanames{en}->{61251024} = "Anembo";
$areanames{en}->{61251025} = "Binalong";
$areanames{en}->{61251026} = "Bungendore";
$areanames{en}->{61251027} = "Burrinjuck";
$areanames{en}->{61251029} = "Captains\ Flat";
$areanames{en}->{61251070} = "Cavan";
$areanames{en}->{61251071} = "Gearys\ Gap";
$areanames{en}->{61251072} = "Gundaroo";
$areanames{en}->{61251073} = "Michelago";
$areanames{en}->{61251074} = "Rye\ Park";
$areanames{en}->{61251075} = "The\ Mullion";
$areanames{en}->{61251076} = "Uriarra\ Forest";
$areanames{en}->{61251077} = "Yass";
$areanames{en}->{61251078} = "Anembo";
$areanames{en}->{61251079} = "Binalong";
$areanames{en}->{6125110} = "Canberra";
$areanames{en}->{61251100} = "Bungendore";
$areanames{en}->{61251101} = "Burrinjuck";
$areanames{en}->{6125111} = "Canberra";
$areanames{en}->{61251120} = "Canberra";
$areanames{en}->{61251121} = "Canberra";
$areanames{en}->{61251122} = "Canberra";
$areanames{en}->{61251123} = "Captains\ Flat";
$areanames{en}->{61251124} = "Cavan";
$areanames{en}->{61251125} = "Gearys\ Gap";
$areanames{en}->{61251126} = "Anembo";
$areanames{en}->{61251127} = "Binalong";
$areanames{en}->{61251128} = "Bungendore";
$areanames{en}->{61251129} = "Burrinjuck";
$areanames{en}->{61251130} = "Canberra";
$areanames{en}->{61251131} = "Captains\ Flat";
$areanames{en}->{61251132} = "Cavan";
$areanames{en}->{61251133} = "Gearys\ Gap";
$areanames{en}->{61251134} = "Gundaroo";
$areanames{en}->{61251135} = "Michelago";
$areanames{en}->{61251136} = "Rye\ Park";
$areanames{en}->{61251137} = "The\ Mullion";
$areanames{en}->{61251138} = "Uriarra\ Forest";
$areanames{en}->{61251139} = "Yass";
$areanames{en}->{6125114} = "Canberra";
$areanames{en}->{6125115} = "Canberra";
$areanames{en}->{61251160} = "Canberra";
$areanames{en}->{61251161} = "Canberra";
$areanames{en}->{61251162} = "Canberra";
$areanames{en}->{61251163} = "Canberra";
$areanames{en}->{61251164} = "Canberra";
$areanames{en}->{61251165} = "Bungendore";
$areanames{en}->{61251166} = "Bungendore";
$areanames{en}->{61251167} = "Gundaroo";
$areanames{en}->{61251168} = "Michelago";
$areanames{en}->{61251169} = "Rye\ Park";
$areanames{en}->{61251170} = "The\ Mullion";
$areanames{en}->{61251171} = "Uriarra\ Forest";
$areanames{en}->{61251172} = "Yass";
$areanames{en}->{61251173} = "Canberra";
$areanames{en}->{61251174} = "Canberra";
$areanames{en}->{61251175} = "Anembo";
$areanames{en}->{61251176} = "Binalong";
$areanames{en}->{61251177} = "Bungendore";
$areanames{en}->{61251178} = "Burrinjuck";
$areanames{en}->{61251179} = "Canberra";
$areanames{en}->{61251180} = "Captains\ Flat";
$areanames{en}->{61251181} = "Cavan";
$areanames{en}->{61251182} = "Gearys\ Gap";
$areanames{en}->{61251183} = "Gundaroo";
$areanames{en}->{61251184} = "Michelago";
$areanames{en}->{61251185} = "Rye\ Park";
$areanames{en}->{61251186} = "The\ Mullion";
$areanames{en}->{61251187} = "Uriarra\ Forest";
$areanames{en}->{61251188} = "Yass";
$areanames{en}->{61251189} = "Anembo";
$areanames{en}->{61251190} = "Binalong";
$areanames{en}->{61251191} = "Bungendore";
$areanames{en}->{61251192} = "Burrinjuck";
$areanames{en}->{61251193} = "Canberra";
$areanames{en}->{61251194} = "Captains\ Flat";
$areanames{en}->{61251195} = "Cavan";
$areanames{en}->{61251196} = "Gearys\ Gap";
$areanames{en}->{61251197} = "Gundaroo";
$areanames{en}->{61251198} = "Michelago";
$areanames{en}->{61251199} = "Rye\ Park";
$areanames{en}->{61251200} = "The\ Mullion";
$areanames{en}->{61251201} = "Uriarra\ Forest";
$areanames{en}->{61251202} = "Yass";
$areanames{en}->{61251203} = "Anembo";
$areanames{en}->{61251204} = "Binalong";
$areanames{en}->{61251205} = "Bungendore";
$areanames{en}->{61251206} = "Burrinjuck";
$areanames{en}->{61251207} = "Canberra";
$areanames{en}->{61251208} = "Captains\ Flat";
$areanames{en}->{61251209} = "Cavan";
$areanames{en}->{61251210} = "Gearys\ Gap";
$areanames{en}->{61251211} = "Gundaroo";
$areanames{en}->{61251212} = "Michelago";
$areanames{en}->{61251213} = "Rye\ Park";
$areanames{en}->{61251214} = "The\ Mullion";
$areanames{en}->{61251215} = "Uriarra\ Forest";
$areanames{en}->{61251216} = "Yass";
$areanames{en}->{61251217} = "Anembo";
$areanames{en}->{61251218} = "Binalong";
$areanames{en}->{61251219} = "Bungendore";
$areanames{en}->{6125122} = "Canberra";
$areanames{en}->{6125123} = "Canberra";
$areanames{en}->{6125124} = "Canberra";
$areanames{en}->{6125125} = "Canberra";
$areanames{en}->{6125126} = "Canberra";
$areanames{en}->{6125127} = "Canberra";
$areanames{en}->{61251280} = "Burrinjuck";
$areanames{en}->{61251281} = "Canberra";
$areanames{en}->{61251282} = "Captains\ Flat";
$areanames{en}->{61251283} = "Cavan";
$areanames{en}->{61251284} = "Gearys\ Gap";
$areanames{en}->{61251285} = "Gundaroo";
$areanames{en}->{61251286} = "Michelago";
$areanames{en}->{61251287} = "Rye\ Park";
$areanames{en}->{61251288} = "The\ Mullion";
$areanames{en}->{61251289} = "Uriarra\ Forest";
$areanames{en}->{61251290} = "Yass";
$areanames{en}->{61251291} = "Canberra";
$areanames{en}->{612530000} = "Leadville";
$areanames{en}->{612530001} = "Leadville";
$areanames{en}->{612530002} = "Leadville";
$areanames{en}->{612530003} = "Leadville";
$areanames{en}->{612530004} = "Leadville\/Baldry\/Bathurst\/Birriwa";
$areanames{en}->{612530005} = "Leadville\/Baldry\/Bathurst\/Birriwa";
$areanames{en}->{612530006} = "Leadville";
$areanames{en}->{612530007} = "Baldry";
$areanames{en}->{612530008} = "Bathurst";
$areanames{en}->{612530009} = "Birriwa";
$areanames{en}->{612530010} = "Lue";
$areanames{en}->{612530011} = "Lue";
$areanames{en}->{612530012} = "Lue";
$areanames{en}->{612530013} = "Lue";
$areanames{en}->{612530014} = "Lue\/Blayney\/Boorowa\/Bribbaree";
$areanames{en}->{612530015} = "Lue\/Blayney\/Boorowa\/Bribbaree";
$areanames{en}->{612530016} = "Lue";
$areanames{en}->{612530017} = "Blayney";
$areanames{en}->{612530018} = "Boorowa";
$areanames{en}->{612530019} = "Bribbaree";
$areanames{en}->{61253002} = "Mudgee";
$areanames{en}->{612530029} = "Burraga";
$areanames{en}->{612530030} = "Twelve\ Mile";
$areanames{en}->{612530031} = "Twelve\ Mile";
$areanames{en}->{612530032} = "Twelve\ Mile";
$areanames{en}->{612530033} = "Twelve\ Mile";
$areanames{en}->{612530034} = "Twelve\ Mile\/Bylong\/Canowindra\/Bathurst";
$areanames{en}->{612530035} = "Twelve\ Mile\/Bylong\/Canowindra\/Bathurst";
$areanames{en}->{612530036} = "Twelve\ Mile";
$areanames{en}->{612530037} = "Bylong";
$areanames{en}->{612530038} = "Canowindra";
$areanames{en}->{612530039} = "Bathurst";
$areanames{en}->{61253004} = "Windeyer";
$areanames{en}->{612530048} = "Caragabal";
$areanames{en}->{612530049} = "Cassilis";
$areanames{en}->{61253005} = "Wollar";
$areanames{en}->{612530055} = "Lithgow";
$areanames{en}->{612530056} = "Orange";
$areanames{en}->{612530059} = "Coolah";
$areanames{en}->{61253006} = "Baldry";
$areanames{en}->{612530068} = "Cowra";
$areanames{en}->{612530069} = "Cudal";
$areanames{en}->{61253007} = "Blayney";
$areanames{en}->{612530078} = "Cumnock";
$areanames{en}->{612530079} = "Dunedoo";
$areanames{en}->{612530080} = "Cudal";
$areanames{en}->{612530081} = "Cudal";
$areanames{en}->{612530082} = "Cudal";
$areanames{en}->{612530083} = "Cudal";
$areanames{en}->{612530084} = "Cudal\/Euchareena\/Frogmore\/Galong";
$areanames{en}->{612530085} = "Cudal\/Euchareena\/Frogmore\/Galong";
$areanames{en}->{612530086} = "Cudal";
$areanames{en}->{612530087} = "Euchareena";
$areanames{en}->{612530088} = "Frogmore";
$areanames{en}->{612530089} = "Galong";
$areanames{en}->{612530090} = "Cumnock";
$areanames{en}->{612530091} = "Cumnock";
$areanames{en}->{612530092} = "Cumnock";
$areanames{en}->{612530093} = "Cumnock";
$areanames{en}->{612530094} = "Cumnock\/Gingkin\/Glen\ Davis\/Gooloogong";
$areanames{en}->{612530095} = "Cumnock\/Gingkin\/Glen\ Davis\/Gooloogong";
$areanames{en}->{612530096} = "Cumnock";
$areanames{en}->{612530097} = "Gingkin";
$areanames{en}->{612530098} = "Glen\ Davis";
$areanames{en}->{612530099} = "Gooloogong";
$areanames{en}->{612530100} = "Euchareena";
$areanames{en}->{612530101} = "Euchareena";
$areanames{en}->{612530102} = "Euchareena";
$areanames{en}->{612530103} = "Euchareena";
$areanames{en}->{612530104} = "Euchareena\/Greenethorpe\/Grenfell\/Gulgong";
$areanames{en}->{612530105} = "Euchareena\/Greenethorpe\/Grenfell\/Gulgong";
$areanames{en}->{612530106} = "Euchareena";
$areanames{en}->{612530107} = "Greenethorpe";
$areanames{en}->{612530108} = "Grenfell";
$areanames{en}->{612530109} = "Gulgong";
$areanames{en}->{612530110} = "Lyndhurst";
$areanames{en}->{612530111} = "Lyndhurst";
$areanames{en}->{612530112} = "Lyndhurst";
$areanames{en}->{612530113} = "Lyndhurst";
$areanames{en}->{612530114} = "Lyndhurst\/Hampton\/Harden\/Hill\ End";
$areanames{en}->{612530115} = "Lyndhurst\/Hampton\/Harden\/Hill\ End";
$areanames{en}->{612530116} = "Lyndhurst";
$areanames{en}->{612530117} = "Hampton";
$areanames{en}->{612530118} = "Harden";
$areanames{en}->{612530119} = "Hill\ End";
$areanames{en}->{612530120} = "Manildra";
$areanames{en}->{612530121} = "Manildra";
$areanames{en}->{612530122} = "Manildra";
$areanames{en}->{612530123} = "Manildra";
$areanames{en}->{612530124} = "Manildra\/Kandos\/Killongbutta\/Koorawatha";
$areanames{en}->{612530125} = "Manildra\/Kandos\/Killongbutta\/Koorawatha";
$areanames{en}->{612530126} = "Manildra";
$areanames{en}->{612530127} = "Kandos";
$areanames{en}->{612530128} = "Killongbutta";
$areanames{en}->{612530129} = "Koorawatha";
$areanames{en}->{61253013} = "Millthorpe";
$areanames{en}->{612530138} = "Laheys\ Creek";
$areanames{en}->{612530139} = "Leadville";
$areanames{en}->{612530140} = "Molong";
$areanames{en}->{612530141} = "Molong";
$areanames{en}->{612530142} = "Molong";
$areanames{en}->{612530143} = "Molong";
$areanames{en}->{612530144} = "Molong\/Limekilns\/Lithgow\/Lue";
$areanames{en}->{612530145} = "Molong\/Limekilns\/Lithgow\/Lue";
$areanames{en}->{612530146} = "Molong";
$areanames{en}->{612530147} = "Limekilns";
$areanames{en}->{612530148} = "Lithgow";
$areanames{en}->{612530149} = "Lue";
$areanames{en}->{612530150} = "Neville";
$areanames{en}->{612530151} = "Neville";
$areanames{en}->{612530152} = "Neville";
$areanames{en}->{612530153} = "Neville";
$areanames{en}->{612530154} = "Neville\/Lyndhurst\/Maimuru\/Manildra";
$areanames{en}->{612530155} = "Neville\/Lyndhurst\/Maimuru\/Manildra";
$areanames{en}->{612530156} = "Neville";
$areanames{en}->{612530157} = "Lyndhurst";
$areanames{en}->{612530158} = "Maimuru";
$areanames{en}->{612530159} = "Manildra";
$areanames{en}->{612530160} = "Orange";
$areanames{en}->{612530161} = "Orange";
$areanames{en}->{612530162} = "Orange";
$areanames{en}->{612530163} = "Orange";
$areanames{en}->{612530164} = "Orange";
$areanames{en}->{612530165} = "Orange\/Meadow\ Flat\/Merriganowry\/Millthorpe";
$areanames{en}->{612530166} = "Orange\/Meadow\ Flat\/Merriganowry\/Millthorpe";
$areanames{en}->{612530167} = "Meadow\ Flat";
$areanames{en}->{612530168} = "Merriganowry";
$areanames{en}->{612530169} = "Millthorpe";
$areanames{en}->{612530170} = "Bylong";
$areanames{en}->{612530171} = "Bylong";
$areanames{en}->{612530172} = "Bylong";
$areanames{en}->{612530173} = "Bylong";
$areanames{en}->{612530174} = "Bylong\/Milvale\/Molong\/Monteagle";
$areanames{en}->{612530175} = "Bylong\/Milvale\/Molong\/Monteagle";
$areanames{en}->{612530176} = "Bylong";
$areanames{en}->{612530177} = "Milvale";
$areanames{en}->{612530178} = "Molong";
$areanames{en}->{612530179} = "Monteagle";
$areanames{en}->{612530180} = "Glen\ Davis";
$areanames{en}->{612530181} = "Glen\ Davis";
$areanames{en}->{612530182} = "Glen\ Davis";
$areanames{en}->{612530183} = "Glen\ Davis";
$areanames{en}->{612530184} = "Glen\ Davis\/Mudgee\/Murringo\/Neville";
$areanames{en}->{612530185} = "Glen\ Davis\/Mudgee\/Murringo\/Neville";
$areanames{en}->{612530186} = "Glen\ Davis";
$areanames{en}->{612530187} = "Mudgee";
$areanames{en}->{612530188} = "Murringo";
$areanames{en}->{612530189} = "Neville";
$areanames{en}->{61253019} = "Kandos";
$areanames{en}->{612530198} = "Oberon";
$areanames{en}->{612530199} = "Ooma";
$areanames{en}->{612530200} = "Running\ Stream";
$areanames{en}->{612530201} = "Running\ Stream";
$areanames{en}->{612530202} = "Running\ Stream";
$areanames{en}->{612530203} = "Running\ Stream";
$areanames{en}->{612530204} = "Running\ Stream\/Orange\/Portland\/Quandialla";
$areanames{en}->{612530205} = "Running\ Stream\/Orange\/Portland\/Quandialla";
$areanames{en}->{612530206} = "Running\ Stream";
$areanames{en}->{612530207} = "Orange";
$areanames{en}->{612530208} = "Portland";
$areanames{en}->{612530209} = "Quandialla";
$areanames{en}->{61253021} = "Boorowa";
$areanames{en}->{612530218} = "Reids\ Flat";
$areanames{en}->{612530219} = "Rockley";
$areanames{en}->{612530220} = "Bribbaree";
$areanames{en}->{612530221} = "Bribbaree";
$areanames{en}->{612530222} = "Bribbaree";
$areanames{en}->{612530223} = "Bribbaree";
$areanames{en}->{612530224} = "Bribbaree\/Running\ Stream\/Twelve\ Mile\/Tyagong";
$areanames{en}->{612530225} = "Bribbaree\/Running\ Stream\/Twelve\ Mile\/Tyagong";
$areanames{en}->{612530226} = "Bribbaree";
$areanames{en}->{612530227} = "Running\ Stream";
$areanames{en}->{612530228} = "Twelve\ Mile";
$areanames{en}->{612530229} = "Tyagong";
$areanames{en}->{612530230} = "Frogmore";
$areanames{en}->{612530231} = "Frogmore";
$areanames{en}->{612530232} = "Frogmore";
$areanames{en}->{612530233} = "Frogmore";
$areanames{en}->{612530234} = "Frogmore\/Windeyer\/Wollar\/Woodstock";
$areanames{en}->{612530235} = "Frogmore\/Windeyer\/Wollar\/Woodstock";
$areanames{en}->{612530236} = "Frogmore";
$areanames{en}->{612530237} = "Windeyer";
$areanames{en}->{612530238} = "Wollar";
$areanames{en}->{612530239} = "Woodstock";
$areanames{en}->{612530240} = "Galong";
$areanames{en}->{612530241} = "Galong";
$areanames{en}->{612530242} = "Galong";
$areanames{en}->{612530243} = "Galong";
$areanames{en}->{612530244} = "Galong\/Yetholme\/Young\/Baldry";
$areanames{en}->{612530245} = "Galong\/Yetholme\/Young\/Baldry";
$areanames{en}->{612530246} = "Galong";
$areanames{en}->{612530247} = "Yetholme";
$areanames{en}->{612530248} = "Young";
$areanames{en}->{612530249} = "Baldry";
$areanames{en}->{612530250} = "Harden";
$areanames{en}->{612530251} = "Harden";
$areanames{en}->{612530252} = "Harden";
$areanames{en}->{612530253} = "Harden";
$areanames{en}->{612530254} = "Harden\/Bathurst\/Birriwa\/Blayney";
$areanames{en}->{612530255} = "Harden\/Bathurst\/Birriwa\/Blayney";
$areanames{en}->{612530256} = "Harden";
$areanames{en}->{612530257} = "Bathurst";
$areanames{en}->{612530258} = "Birriwa";
$areanames{en}->{612530259} = "Blayney";
$areanames{en}->{612530260} = "Maimuru";
$areanames{en}->{612530261} = "Maimuru";
$areanames{en}->{612530262} = "Maimuru";
$areanames{en}->{612530263} = "Maimuru";
$areanames{en}->{612530264} = "Maimuru\/Boorowa\/Bribbaree\/Burraga";
$areanames{en}->{612530265} = "Maimuru\/Boorowa\/Bribbaree\/Burraga";
$areanames{en}->{612530266} = "Maimuru";
$areanames{en}->{612530267} = "Boorowa";
$areanames{en}->{612530268} = "Bribbaree";
$areanames{en}->{612530269} = "Burraga";
$areanames{en}->{612530270} = "Milvale";
$areanames{en}->{612530271} = "Milvale";
$areanames{en}->{612530272} = "Milvale";
$areanames{en}->{612530273} = "Milvale";
$areanames{en}->{612530274} = "Milvale\/Bylong\/Canowindra\/Caragabal";
$areanames{en}->{612530275} = "Milvale\/Bylong\/Canowindra\/Caragabal";
$areanames{en}->{612530276} = "Milvale";
$areanames{en}->{612530277} = "Bylong";
$areanames{en}->{612530278} = "Canowindra";
$areanames{en}->{612530279} = "Caragabal";
$areanames{en}->{61253028} = "Monteagle";
$areanames{en}->{612530287} = "Cassilis";
$areanames{en}->{612530288} = "Coolah";
$areanames{en}->{612530289} = "Cowra";
$areanames{en}->{612530290} = "Murringo";
$areanames{en}->{612530291} = "Murringo";
$areanames{en}->{612530292} = "Murringo";
$areanames{en}->{612530293} = "Murringo";
$areanames{en}->{612530294} = "Murringo\/Cudal\/Cumnock\/Dunedoo";
$areanames{en}->{612530295} = "Murringo\/Cudal\/Cumnock\/Dunedoo";
$areanames{en}->{612530296} = "Murringo";
$areanames{en}->{612530297} = "Cudal";
$areanames{en}->{612530298} = "Cumnock";
$areanames{en}->{612530299} = "Dunedoo";
$areanames{en}->{61253030} = "Young";
$areanames{en}->{612530308} = "Euchareena";
$areanames{en}->{612530309} = "Frogmore";
$areanames{en}->{61253031} = "Bathurst";
$areanames{en}->{61253032} = "Gooloogong";
$areanames{en}->{61253033} = "Gooloogong";
$areanames{en}->{61253034} = "Greenethorpe";
$areanames{en}->{61253035} = "Greenethorpe";
$areanames{en}->{61253036} = "Grenfell";
$areanames{en}->{61253037} = "Grenfell";
$areanames{en}->{61253038} = "Koorawatha";
$areanames{en}->{61253039} = "Koorawatha";
$areanames{en}->{61253040} = "Bathurst";
$areanames{en}->{61253041} = "Burraga";
$areanames{en}->{61253042} = "Gingkin";
$areanames{en}->{61253043} = "Hill\ End";
$areanames{en}->{61253044} = "Killongbutta";
$areanames{en}->{61253045} = "Limekilns";
$areanames{en}->{61253046} = "Oberon";
$areanames{en}->{61253047} = "Rockley";
$areanames{en}->{61253048} = "Yetholme";
$areanames{en}->{61253049} = "Canowindra";
$areanames{en}->{61253050} = "Caragabal";
$areanames{en}->{61253051} = "Gooloogong";
$areanames{en}->{61253052} = "Greenethorpe";
$areanames{en}->{61253053} = "Grenfell";
$areanames{en}->{61253054} = "Koorawatha";
$areanames{en}->{61253055} = "Merriganowry";
$areanames{en}->{61253056} = "Ooma";
$areanames{en}->{61253057} = "Quandialla";
$areanames{en}->{61253058} = "Reids\ Flat";
$areanames{en}->{61253059} = "Tyagong";
$areanames{en}->{61253060} = "Woodstock";
$areanames{en}->{61253061} = "Hampton";
$areanames{en}->{61253062} = "Lithgow";
$areanames{en}->{61253063} = "Meadow\ Flat";
$areanames{en}->{61253064} = "Portland";
$areanames{en}->{61253065} = "Birriwa";
$areanames{en}->{61253066} = "Cassilis";
$areanames{en}->{61253067} = "Coolah";
$areanames{en}->{61253068} = "Dunedoo";
$areanames{en}->{61253069} = "Gulgong";
$areanames{en}->{61253070} = "Laheys\ Creek";
$areanames{en}->{61253071} = "Leadville";
$areanames{en}->{61253072} = "Lue";
$areanames{en}->{61253073} = "Mudgee";
$areanames{en}->{61253074} = "Twelve\ Mile";
$areanames{en}->{61253075} = "Windeyer";
$areanames{en}->{61253076} = "Wollar";
$areanames{en}->{61253077} = "Baldry";
$areanames{en}->{61253078} = "Blayney";
$areanames{en}->{61253079} = "Cudal";
$areanames{en}->{61253080} = "Cumnock";
$areanames{en}->{61253081} = "Euchareena";
$areanames{en}->{61253082} = "Lyndhurst";
$areanames{en}->{61253083} = "Manildra";
$areanames{en}->{61253084} = "Millthorpe";
$areanames{en}->{61253085} = "Molong";
$areanames{en}->{61253086} = "Neville";
$areanames{en}->{61253087} = "Bylong";
$areanames{en}->{61253088} = "Glen\ Davis";
$areanames{en}->{61253089} = "Kandos";
$areanames{en}->{61253090} = "Running\ Stream";
$areanames{en}->{61253091} = "Boorowa";
$areanames{en}->{61253092} = "Bribbaree";
$areanames{en}->{61253093} = "Frogmore";
$areanames{en}->{61253094} = "Galong";
$areanames{en}->{61253095} = "Harden";
$areanames{en}->{61253096} = "Maimuru";
$areanames{en}->{61253097} = "Milvale";
$areanames{en}->{61253098} = "Monteagle";
$areanames{en}->{61253099} = "Murringo";
$areanames{en}->{6125310} = "Orange";
$areanames{en}->{61253100} = "Young";
$areanames{en}->{61253107} = "Millthorpe";
$areanames{en}->{61253108} = "Millthorpe";
$areanames{en}->{61253109} = "Lyndhurst";
$areanames{en}->{61253110} = "Lyndhurst";
$areanames{en}->{61253111} = "Orange";
$areanames{en}->{61253112} = "Orange";
$areanames{en}->{61253113} = "Woodstock";
$areanames{en}->{61253114} = "Woodstock";
$areanames{en}->{61253115} = "Canowindra";
$areanames{en}->{61253116} = "Canowindra";
$areanames{en}->{61253117} = "Caragabal";
$areanames{en}->{61253118} = "Caragabal";
$areanames{en}->{61253119} = "Merriganowry";
$areanames{en}->{61253120} = "Merriganowry";
$areanames{en}->{61253121} = "Ooma";
$areanames{en}->{61253122} = "Ooma";
$areanames{en}->{61253123} = "Quandialla";
$areanames{en}->{61253124} = "Quandialla";
$areanames{en}->{61253125} = "Reids\ Flat";
$areanames{en}->{61253126} = "Reids\ Flat";
$areanames{en}->{61253127} = "Tyagong";
$areanames{en}->{61253128} = "Tyagong";
$areanames{en}->{61253129} = "Cassilis";
$areanames{en}->{61253130} = "Cassilis";
$areanames{en}->{61253131} = "Coolah";
$areanames{en}->{61253132} = "Coolah";
$areanames{en}->{61253133} = "Gulgong";
$areanames{en}->{61253134} = "Gulgong";
$areanames{en}->{61253135} = "Laheys\ Creek";
$areanames{en}->{61253136} = "Laheys\ Creek";
$areanames{en}->{61253137} = "Leadville";
$areanames{en}->{61253138} = "Leadville";
$areanames{en}->{61253139} = "Lue";
$areanames{en}->{61253140} = "Lue";
$areanames{en}->{61253141} = "Twelve\ Mile";
$areanames{en}->{61253142} = "Twelve\ Mile";
$areanames{en}->{61253143} = "Windeyer";
$areanames{en}->{61253144} = "Windeyer";
$areanames{en}->{61253145} = "Wollar";
$areanames{en}->{61253146} = "Wollar";
$areanames{en}->{61253147} = "Glen\ Davis";
$areanames{en}->{61253148} = "Glen\ Davis";
$areanames{en}->{61253149} = "Running\ Stream";
$areanames{en}->{61253150} = "Running\ Stream";
$areanames{en}->{61253151} = "Boorowa";
$areanames{en}->{61253152} = "Boorowa";
$areanames{en}->{61253153} = "Bribbaree";
$areanames{en}->{61253154} = "Bribbaree";
$areanames{en}->{61253155} = "Milvale";
$areanames{en}->{61253156} = "Milvale";
$areanames{en}->{61253157} = "Murringo";
$areanames{en}->{61253158} = "Murringo";
$areanames{en}->{61253159} = "Baldry";
$areanames{en}->{61253160} = "Baldry";
$areanames{en}->{61253161} = "Cumnock";
$areanames{en}->{61253162} = "Cumnock";
$areanames{en}->{61253163} = "Euchareena";
$areanames{en}->{61253164} = "Euchareena";
$areanames{en}->{61253165} = "Manildra";
$areanames{en}->{61253166} = "Manildra";
$areanames{en}->{61253167} = "Molong";
$areanames{en}->{61253168} = "Molong";
$areanames{en}->{61253169} = "Neville";
$areanames{en}->{61253170} = "Neville";
$areanames{en}->{61253171} = "Orange";
$areanames{en}->{61253172} = "Bathurst";
$areanames{en}->{61253173} = "Orange";
$areanames{en}->{61253174} = "Lithgow";
$areanames{en}->{61253175} = "Cowra";
$areanames{en}->{61253176} = "Bathurst";
$areanames{en}->{61253177} = "Orange";
$areanames{en}->{61253178} = "Orange";
$areanames{en}->{61253179} = "Lithgow";
$areanames{en}->{61253180} = "Portland";
$areanames{en}->{61253181} = "Orange";
$areanames{en}->{61253182} = "Bathurst";
$areanames{en}->{61253183} = "Bathurst";
$areanames{en}->{61253184} = "Young";
$areanames{en}->{61253185} = "Portland";
$areanames{en}->{61253186} = "Portland";
$areanames{en}->{61253187} = "Portland";
$areanames{en}->{61253188} = "Blayney";
$areanames{en}->{61253189} = "Blayney";
$areanames{en}->{61253190} = "Orange";
$areanames{en}->{61253191} = "Merriganowry";
$areanames{en}->{61253192} = "Portland";
$areanames{en}->{61253193} = "Quandialla";
$areanames{en}->{61253194} = "Reids\ Flat";
$areanames{en}->{61253195} = "Woodstock";
$areanames{en}->{61253196} = "Killongbutta";
$areanames{en}->{61253197} = "Cowra";
$areanames{en}->{61253198} = "Mudgee";
$areanames{en}->{61253199} = "Millthorpe";
$areanames{en}->{61253200} = "Birriwa";
$areanames{en}->{61253201} = "Boorowa";
$areanames{en}->{61253202} = "Bribbaree";
$areanames{en}->{61253203} = "Burraga";
$areanames{en}->{61253204} = "Coolah";
$areanames{en}->{61253205} = "Cudal";
$areanames{en}->{61253206} = "Cumnock";
$areanames{en}->{61253207} = "Euchareena";
$areanames{en}->{61253208} = "Galong";
$areanames{en}->{61253209} = "Gingkin";
$areanames{en}->{61253210} = "Glen\ Davis";
$areanames{en}->{61253211} = "Gulgong";
$areanames{en}->{61253212} = "Harden";
$areanames{en}->{61253213} = "Hill\ End";
$areanames{en}->{61253214} = "Kandos";
$areanames{en}->{61253215} = "Killongbutta";
$areanames{en}->{61253216} = "Laheys\ Creek";
$areanames{en}->{61253217} = "Leadville";
$areanames{en}->{61253218} = "Limekilns";
$areanames{en}->{61253219} = "Lue";
$areanames{en}->{61253220} = "Maimuru";
$areanames{en}->{61253221} = "Bathurst";
$areanames{en}->{61253222} = "Lithgow";
$areanames{en}->{61253223} = "Orange";
$areanames{en}->{61253224} = "Bathurst";
$areanames{en}->{61253225} = "Bathurst";
$areanames{en}->{61253226} = "Bathurst";
$areanames{en}->{61253227} = "Young";
$areanames{en}->{61253228} = "Young";
$areanames{en}->{61253229} = "Young";
$areanames{en}->{61253230} = "Manildra";
$areanames{en}->{61253231} = "Millthorpe";
$areanames{en}->{61253232} = "Milvale";
$areanames{en}->{61253233} = "Molong";
$areanames{en}->{61253234} = "Monteagle";
$areanames{en}->{61253235} = "Murringo";
$areanames{en}->{61253236} = "Neville";
$areanames{en}->{61253237} = "Oberon";
$areanames{en}->{61253238} = "Rockley";
$areanames{en}->{61253239} = "Windeyer";
$areanames{en}->{61253240} = "Wollar";
$areanames{en}->{61253241} = "Yetholme";
$areanames{en}->{61253242} = "Mudgee";
$areanames{en}->{612532430} = "Galong";
$areanames{en}->{612532431} = "Gingkin";
$areanames{en}->{612532432} = "Glen\ Davis";
$areanames{en}->{612532433} = "Gooloogong";
$areanames{en}->{612532434} = "Greenethorpe";
$areanames{en}->{612532435} = "Grenfell";
$areanames{en}->{612532436} = "Gulgong";
$areanames{en}->{612532437} = "Hampton";
$areanames{en}->{612532438} = "Harden";
$areanames{en}->{612532439} = "Hill\ End";
$areanames{en}->{612532440} = "Kandos";
$areanames{en}->{612532441} = "Killongbutta";
$areanames{en}->{612532442} = "Koorawatha";
$areanames{en}->{612532443} = "Laheys\ Creek";
$areanames{en}->{612532444} = "Leadville";
$areanames{en}->{612532445} = "Limekilns";
$areanames{en}->{612532446} = "Lithgow";
$areanames{en}->{612532447} = "Lue";
$areanames{en}->{612532448} = "Lyndhurst";
$areanames{en}->{612532449} = "Maimuru";
$areanames{en}->{612532450} = "Manildra";
$areanames{en}->{612532451} = "Meadow\ Flat";
$areanames{en}->{612532452} = "Merriganowry";
$areanames{en}->{612532453} = "Millthorpe";
$areanames{en}->{612532454} = "Milvale";
$areanames{en}->{612532455} = "Molong";
$areanames{en}->{612532456} = "Monteagle";
$areanames{en}->{612532457} = "Mudgee";
$areanames{en}->{612532458} = "Murringo";
$areanames{en}->{612532459} = "Neville";
$areanames{en}->{612532460} = "Oberon";
$areanames{en}->{612532461} = "Ooma";
$areanames{en}->{612532462} = "Orange";
$areanames{en}->{612532463} = "Portland";
$areanames{en}->{612532464} = "Quandialla";
$areanames{en}->{612532465} = "Reids\ Flat";
$areanames{en}->{612532466} = "Rockley";
$areanames{en}->{612532467} = "Running\ Stream";
$areanames{en}->{612532468} = "Twelve\ Mile";
$areanames{en}->{612532469} = "Tyagong";
$areanames{en}->{612532470} = "Windeyer";
$areanames{en}->{612532471} = "Wollar";
$areanames{en}->{612532472} = "Woodstock";
$areanames{en}->{612532473} = "Yetholme";
$areanames{en}->{612532474} = "Young";
$areanames{en}->{612532475} = "Baldry";
$areanames{en}->{612532476} = "Bathurst";
$areanames{en}->{612532477} = "Birriwa";
$areanames{en}->{612532478} = "Blayney";
$areanames{en}->{612532479} = "Boorowa";
$areanames{en}->{61253248} = "Bathurst";
$areanames{en}->{61253249} = "Grenfell";
$areanames{en}->{61253250} = "Cudal";
$areanames{en}->{612532510} = "Bribbaree";
$areanames{en}->{612532511} = "Burraga";
$areanames{en}->{612532512} = "Bylong";
$areanames{en}->{612532513} = "Canowindra";
$areanames{en}->{612532514} = "Caragabal";
$areanames{en}->{612532515} = "Cassilis";
$areanames{en}->{612532516} = "Coolah";
$areanames{en}->{612532517} = "Cowra";
$areanames{en}->{612532518} = "Cudal";
$areanames{en}->{612532519} = "Cumnock";
$areanames{en}->{612532520} = "Dunedoo";
$areanames{en}->{612532521} = "Euchareena";
$areanames{en}->{612532522} = "Frogmore";
$areanames{en}->{612532523} = "Galong";
$areanames{en}->{612532524} = "Gingkin";
$areanames{en}->{612532525} = "Glen\ Davis";
$areanames{en}->{612532526} = "Gooloogong";
$areanames{en}->{612532527} = "Greenethorpe";
$areanames{en}->{612532528} = "Grenfell";
$areanames{en}->{612532529} = "Gulgong";
$areanames{en}->{612532530} = "Hampton";
$areanames{en}->{612532531} = "Harden";
$areanames{en}->{612532532} = "Hill\ End";
$areanames{en}->{612532533} = "Kandos";
$areanames{en}->{612532534} = "Killongbutta";
$areanames{en}->{612532535} = "Koorawatha";
$areanames{en}->{612532536} = "Laheys\ Creek";
$areanames{en}->{612532537} = "Leadville";
$areanames{en}->{612532538} = "Limekilns";
$areanames{en}->{612532539} = "Lithgow";
$areanames{en}->{612532540} = "Lue";
$areanames{en}->{612532541} = "Lyndhurst";
$areanames{en}->{612532542} = "Maimuru";
$areanames{en}->{612532543} = "Manildra";
$areanames{en}->{612532544} = "Meadow\ Flat";
$areanames{en}->{612532545} = "Merriganowry";
$areanames{en}->{612532546} = "Millthorpe";
$areanames{en}->{612532547} = "Milvale";
$areanames{en}->{612532548} = "Molong";
$areanames{en}->{612532549} = "Monteagle";
$areanames{en}->{61253255} = "Molong";
$areanames{en}->{61253256} = "Molong";
$areanames{en}->{61253257} = "Molong";
$areanames{en}->{612532580} = "Mudgee";
$areanames{en}->{612532581} = "Murringo";
$areanames{en}->{612532582} = "Neville";
$areanames{en}->{612532583} = "Oberon";
$areanames{en}->{612532584} = "Ooma";
$areanames{en}->{612532585} = "Orange";
$areanames{en}->{612532586} = "Portland";
$areanames{en}->{612532587} = "Quandialla";
$areanames{en}->{612532588} = "Reids\ Flat";
$areanames{en}->{612532589} = "Rockley";
$areanames{en}->{61253259} = "Bathurst";
$areanames{en}->{612532600} = "Running\ Stream";
$areanames{en}->{612532601} = "Twelve\ Mile";
$areanames{en}->{612532602} = "Tyagong";
$areanames{en}->{612532603} = "Windeyer";
$areanames{en}->{612532604} = "Wollar";
$areanames{en}->{612532605} = "Woodstock";
$areanames{en}->{612532606} = "Yetholme";
$areanames{en}->{612532607} = "Young";
$areanames{en}->{612532608} = "Baldry";
$areanames{en}->{612532609} = "Bathurst";
$areanames{en}->{61253261} = "Bathurst";
$areanames{en}->{61253262} = "Bathurst";
$areanames{en}->{61253263} = "Bathurst";
$areanames{en}->{61253264} = "Bathurst";
$areanames{en}->{61253265} = "Orange";
$areanames{en}->{612532660} = "Birriwa";
$areanames{en}->{612532661} = "Baldry";
$areanames{en}->{612532662} = "Bathurst";
$areanames{en}->{612532663} = "Birriwa";
$areanames{en}->{612532664} = "Blayney";
$areanames{en}->{612532665} = "Boorowa";
$areanames{en}->{612532666} = "Bribbaree";
$areanames{en}->{612532667} = "Burraga";
$areanames{en}->{612532668} = "Bylong";
$areanames{en}->{612532669} = "Canowindra";
$areanames{en}->{612532670} = "Caragabal";
$areanames{en}->{612532671} = "Cassilis";
$areanames{en}->{612532672} = "Coolah";
$areanames{en}->{612532673} = "Cowra";
$areanames{en}->{612532674} = "Cudal";
$areanames{en}->{612532675} = "Cumnock";
$areanames{en}->{612532676} = "Dunedoo";
$areanames{en}->{612532677} = "Euchareena";
$areanames{en}->{612532678} = "Frogmore";
$areanames{en}->{612532679} = "Galong";
$areanames{en}->{612532680} = "Gingkin";
$areanames{en}->{612532681} = "Glen\ Davis";
$areanames{en}->{612532682} = "Gooloogong";
$areanames{en}->{612532683} = "Greenethorpe";
$areanames{en}->{612532684} = "Grenfell";
$areanames{en}->{612532685} = "Gulgong";
$areanames{en}->{612532686} = "Hampton";
$areanames{en}->{612532687} = "Harden";
$areanames{en}->{612532688} = "Hill\ End";
$areanames{en}->{612532689} = "Kandos";
$areanames{en}->{612532690} = "Killongbutta";
$areanames{en}->{612532691} = "Koorawatha";
$areanames{en}->{612532692} = "Laheys\ Creek";
$areanames{en}->{612532693} = "Leadville";
$areanames{en}->{612532694} = "Limekilns";
$areanames{en}->{612532695} = "Lithgow";
$areanames{en}->{612532696} = "Lue";
$areanames{en}->{612532697} = "Lyndhurst";
$areanames{en}->{612532698} = "Maimuru";
$areanames{en}->{612532699} = "Manildra";
$areanames{en}->{612532700} = "Meadow\ Flat";
$areanames{en}->{612532701} = "Merriganowry";
$areanames{en}->{612532702} = "Millthorpe";
$areanames{en}->{612532703} = "Milvale";
$areanames{en}->{612532704} = "Molong";
$areanames{en}->{612532705} = "Monteagle";
$areanames{en}->{612532706} = "Mudgee";
$areanames{en}->{612532707} = "Murringo";
$areanames{en}->{612532708} = "Neville";
$areanames{en}->{612532709} = "Oberon";
$areanames{en}->{612532710} = "Ooma";
$areanames{en}->{612532711} = "Orange";
$areanames{en}->{612532712} = "Portland";
$areanames{en}->{612532713} = "Quandialla";
$areanames{en}->{612532714} = "Reids\ Flat";
$areanames{en}->{612532715} = "Rockley";
$areanames{en}->{612532716} = "Running\ Stream";
$areanames{en}->{612532717} = "Twelve\ Mile";
$areanames{en}->{612532718} = "Tyagong";
$areanames{en}->{612532719} = "Windeyer";
$areanames{en}->{612532720} = "Wollar";
$areanames{en}->{612532721} = "Woodstock";
$areanames{en}->{612532722} = "Yetholme";
$areanames{en}->{612532723} = "Young";
$areanames{en}->{612532724} = "Blayney";
$areanames{en}->{612532725} = "Boorowa";
$areanames{en}->{612532726} = "Bribbaree";
$areanames{en}->{612532727} = "Burraga";
$areanames{en}->{612532728} = "Bylong";
$areanames{en}->{612532729} = "Canowindra";
$areanames{en}->{61253273} = "Orange";
$areanames{en}->{61253274} = "Lithgow";
$areanames{en}->{61253275} = "Lithgow";
$areanames{en}->{61253276} = "Cowra";
$areanames{en}->{61253277} = "Young";
$areanames{en}->{61253278} = "Blayney";
$areanames{en}->{61253279} = "Gulgong";
$areanames{en}->{61253280} = "Molong";
$areanames{en}->{61253281} = "Kandos";
$areanames{en}->{612532820} = "Caragabal";
$areanames{en}->{612532821} = "Cassilis";
$areanames{en}->{612532822} = "Coolah";
$areanames{en}->{612532823} = "Cowra";
$areanames{en}->{612532824} = "Cudal";
$areanames{en}->{612532825} = "Cumnock";
$areanames{en}->{612532826} = "Dunedoo";
$areanames{en}->{612532827} = "Euchareena";
$areanames{en}->{612532828} = "Frogmore";
$areanames{en}->{612532829} = "Galong";
$areanames{en}->{612532830} = "Gingkin";
$areanames{en}->{612532831} = "Glen\ Davis";
$areanames{en}->{612532832} = "Gooloogong";
$areanames{en}->{612532833} = "Greenethorpe";
$areanames{en}->{612532834} = "Grenfell";
$areanames{en}->{612532835} = "Gulgong";
$areanames{en}->{612532836} = "Hampton";
$areanames{en}->{612532837} = "Harden";
$areanames{en}->{612532838} = "Hill\ End";
$areanames{en}->{612532839} = "Kandos";
$areanames{en}->{612532840} = "Killongbutta";
$areanames{en}->{612532841} = "Koorawatha";
$areanames{en}->{612532842} = "Laheys\ Creek";
$areanames{en}->{612532843} = "Leadville";
$areanames{en}->{612532844} = "Limekilns";
$areanames{en}->{612532845} = "Lithgow";
$areanames{en}->{612532846} = "Lue";
$areanames{en}->{612532847} = "Lyndhurst";
$areanames{en}->{612532848} = "Maimuru";
$areanames{en}->{612532849} = "Manildra";
$areanames{en}->{612532850} = "Meadow\ Flat";
$areanames{en}->{612532851} = "Merriganowry";
$areanames{en}->{612532852} = "Millthorpe";
$areanames{en}->{612532853} = "Milvale";
$areanames{en}->{612532854} = "Molong";
$areanames{en}->{612532855} = "Monteagle";
$areanames{en}->{612532856} = "Mudgee";
$areanames{en}->{612532857} = "Murringo";
$areanames{en}->{612532858} = "Neville";
$areanames{en}->{612532859} = "Oberon";
$areanames{en}->{612532860} = "Ooma";
$areanames{en}->{612532861} = "Orange";
$areanames{en}->{612532862} = "Portland";
$areanames{en}->{612532863} = "Quandialla";
$areanames{en}->{612532864} = "Reids\ Flat";
$areanames{en}->{612532865} = "Rockley";
$areanames{en}->{612532866} = "Running\ Stream";
$areanames{en}->{612532867} = "Twelve\ Mile";
$areanames{en}->{612532868} = "Tyagong";
$areanames{en}->{612532869} = "Windeyer";
$areanames{en}->{612532870} = "Wollar";
$areanames{en}->{612532871} = "Woodstock";
$areanames{en}->{612532872} = "Yetholme";
$areanames{en}->{612532873} = "Young";
$areanames{en}->{612532874} = "Baldry";
$areanames{en}->{612532875} = "Bathurst";
$areanames{en}->{612532876} = "Birriwa";
$areanames{en}->{612532877} = "Blayney";
$areanames{en}->{612532878} = "Boorowa";
$areanames{en}->{612532879} = "Bribbaree";
$areanames{en}->{612532880} = "Burraga";
$areanames{en}->{612532881} = "Bylong";
$areanames{en}->{612532882} = "Canowindra";
$areanames{en}->{612532883} = "Caragabal";
$areanames{en}->{612532884} = "Cassilis";
$areanames{en}->{612532885} = "Coolah";
$areanames{en}->{612532886} = "Cowra";
$areanames{en}->{612532887} = "Cudal";
$areanames{en}->{612532888} = "Cumnock";
$areanames{en}->{612532889} = "Dunedoo";
$areanames{en}->{612532890} = "Euchareena";
$areanames{en}->{612532891} = "Frogmore";
$areanames{en}->{612532892} = "Galong";
$areanames{en}->{612532893} = "Gingkin";
$areanames{en}->{612532894} = "Glen\ Davis";
$areanames{en}->{612532895} = "Gooloogong";
$areanames{en}->{612532896} = "Greenethorpe";
$areanames{en}->{612532897} = "Grenfell";
$areanames{en}->{612532898} = "Gulgong";
$areanames{en}->{612532899} = "Hampton";
$areanames{en}->{612532900} = "Harden";
$areanames{en}->{612532901} = "Hill\ End";
$areanames{en}->{612532902} = "Kandos";
$areanames{en}->{612532903} = "Killongbutta";
$areanames{en}->{612532904} = "Koorawatha";
$areanames{en}->{612532905} = "Laheys\ Creek";
$areanames{en}->{612532906} = "Leadville";
$areanames{en}->{612532907} = "Limekilns";
$areanames{en}->{612532908} = "Lithgow";
$areanames{en}->{612532909} = "Lue";
$areanames{en}->{612532910} = "Lyndhurst";
$areanames{en}->{612532911} = "Maimuru";
$areanames{en}->{612532912} = "Manildra";
$areanames{en}->{612532913} = "Meadow\ Flat";
$areanames{en}->{612532914} = "Merriganowry";
$areanames{en}->{612532915} = "Millthorpe";
$areanames{en}->{612532916} = "Milvale";
$areanames{en}->{612532917} = "Molong";
$areanames{en}->{612532918} = "Monteagle";
$areanames{en}->{612532919} = "Mudgee";
$areanames{en}->{612532920} = "Murringo";
$areanames{en}->{612532921} = "Neville";
$areanames{en}->{612532922} = "Oberon";
$areanames{en}->{612532923} = "Ooma";
$areanames{en}->{612532924} = "Orange";
$areanames{en}->{612532925} = "Portland";
$areanames{en}->{612532926} = "Quandialla";
$areanames{en}->{612532927} = "Reids\ Flat";
$areanames{en}->{612532928} = "Rockley";
$areanames{en}->{612532929} = "Running\ Stream";
$areanames{en}->{612532930} = "Twelve\ Mile";
$areanames{en}->{612532931} = "Tyagong";
$areanames{en}->{612532932} = "Windeyer";
$areanames{en}->{612532933} = "Wollar";
$areanames{en}->{612532934} = "Woodstock";
$areanames{en}->{612532935} = "Yetholme";
$areanames{en}->{612532936} = "Young";
$areanames{en}->{612532937} = "Baldry";
$areanames{en}->{612532938} = "Bathurst";
$areanames{en}->{612532939} = "Birriwa";
$areanames{en}->{612532940} = "Blayney";
$areanames{en}->{612532941} = "Boorowa";
$areanames{en}->{612532942} = "Bribbaree";
$areanames{en}->{612532943} = "Burraga";
$areanames{en}->{612532944} = "Bylong";
$areanames{en}->{612532945} = "Canowindra";
$areanames{en}->{612532946} = "Caragabal";
$areanames{en}->{612532947} = "Cassilis";
$areanames{en}->{612532948} = "Coolah";
$areanames{en}->{612532949} = "Cowra";
$areanames{en}->{612532950} = "Cudal";
$areanames{en}->{612532951} = "Cumnock";
$areanames{en}->{612532952} = "Dunedoo";
$areanames{en}->{612532953} = "Euchareena";
$areanames{en}->{612532954} = "Frogmore";
$areanames{en}->{612532955} = "Galong";
$areanames{en}->{612532956} = "Gingkin";
$areanames{en}->{612532957} = "Glen\ Davis";
$areanames{en}->{612532958} = "Gooloogong";
$areanames{en}->{612532959} = "Greenethorpe";
$areanames{en}->{612532960} = "Grenfell";
$areanames{en}->{612532961} = "Gulgong";
$areanames{en}->{612532962} = "Hampton";
$areanames{en}->{612532963} = "Harden";
$areanames{en}->{612532964} = "Hill\ End";
$areanames{en}->{612532965} = "Kandos";
$areanames{en}->{612532966} = "Killongbutta";
$areanames{en}->{612532967} = "Koorawatha";
$areanames{en}->{612532968} = "Laheys\ Creek";
$areanames{en}->{612532969} = "Leadville";
$areanames{en}->{612532970} = "Limekilns";
$areanames{en}->{612532971} = "Lithgow";
$areanames{en}->{612532972} = "Lue";
$areanames{en}->{612532973} = "Lyndhurst";
$areanames{en}->{612532974} = "Maimuru";
$areanames{en}->{612532975} = "Manildra";
$areanames{en}->{612532976} = "Meadow\ Flat";
$areanames{en}->{612532977} = "Merriganowry";
$areanames{en}->{612532978} = "Millthorpe";
$areanames{en}->{612532979} = "Milvale";
$areanames{en}->{612532980} = "Molong";
$areanames{en}->{612532981} = "Monteagle";
$areanames{en}->{612532982} = "Mudgee";
$areanames{en}->{612532983} = "Murringo";
$areanames{en}->{612532984} = "Neville";
$areanames{en}->{612532985} = "Oberon";
$areanames{en}->{612532986} = "Ooma";
$areanames{en}->{612532987} = "Orange";
$areanames{en}->{612532988} = "Portland";
$areanames{en}->{612532989} = "Quandialla";
$areanames{en}->{612532990} = "Reids\ Flat";
$areanames{en}->{612532991} = "Rockley";
$areanames{en}->{612532992} = "Running\ Stream";
$areanames{en}->{612532993} = "Twelve\ Mile";
$areanames{en}->{612532994} = "Tyagong";
$areanames{en}->{612532995} = "Windeyer";
$areanames{en}->{612532996} = "Wollar";
$areanames{en}->{612532997} = "Woodstock";
$areanames{en}->{612532998} = "Yetholme";
$areanames{en}->{612532999} = "Young";
$areanames{en}->{612533000} = "Baldry";
$areanames{en}->{612533001} = "Bathurst";
$areanames{en}->{612533002} = "Birriwa";
$areanames{en}->{612533003} = "Blayney";
$areanames{en}->{612533004} = "Boorowa";
$areanames{en}->{612533005} = "Bribbaree";
$areanames{en}->{612533006} = "Burraga";
$areanames{en}->{612533007} = "Bylong";
$areanames{en}->{612533008} = "Canowindra";
$areanames{en}->{612533009} = "Caragabal";
$areanames{en}->{612533010} = "Cassilis";
$areanames{en}->{612533011} = "Coolah";
$areanames{en}->{612533012} = "Cowra";
$areanames{en}->{612533013} = "Cudal";
$areanames{en}->{612533014} = "Cumnock";
$areanames{en}->{612533015} = "Dunedoo";
$areanames{en}->{612533016} = "Euchareena";
$areanames{en}->{612533017} = "Frogmore";
$areanames{en}->{612533018} = "Galong";
$areanames{en}->{612533019} = "Gingkin";
$areanames{en}->{612533020} = "Glen\ Davis";
$areanames{en}->{612533021} = "Gooloogong";
$areanames{en}->{612533022} = "Greenethorpe";
$areanames{en}->{612533023} = "Grenfell";
$areanames{en}->{612533024} = "Gulgong";
$areanames{en}->{612533025} = "Hampton";
$areanames{en}->{612533026} = "Harden";
$areanames{en}->{612533027} = "Hill\ End";
$areanames{en}->{612533028} = "Kandos";
$areanames{en}->{612533029} = "Killongbutta";
$areanames{en}->{612533030} = "Koorawatha";
$areanames{en}->{612533031} = "Laheys\ Creek";
$areanames{en}->{612533032} = "Leadville";
$areanames{en}->{612533033} = "Limekilns";
$areanames{en}->{612533034} = "Lithgow";
$areanames{en}->{612533035} = "Lue";
$areanames{en}->{612533036} = "Lyndhurst";
$areanames{en}->{612533037} = "Maimuru";
$areanames{en}->{612533038} = "Manildra";
$areanames{en}->{612533039} = "Meadow\ Flat";
$areanames{en}->{612533040} = "Merriganowry";
$areanames{en}->{612533041} = "Millthorpe";
$areanames{en}->{612533042} = "Milvale";
$areanames{en}->{612533043} = "Molong";
$areanames{en}->{612533044} = "Monteagle";
$areanames{en}->{612533045} = "Mudgee";
$areanames{en}->{612533046} = "Murringo";
$areanames{en}->{612533047} = "Neville";
$areanames{en}->{612533048} = "Oberon";
$areanames{en}->{612533049} = "Ooma";
$areanames{en}->{612533050} = "Orange";
$areanames{en}->{612533051} = "Portland";
$areanames{en}->{612533052} = "Quandialla";
$areanames{en}->{612533053} = "Reids\ Flat";
$areanames{en}->{612533054} = "Rockley";
$areanames{en}->{612533055} = "Running\ Stream";
$areanames{en}->{612533056} = "Twelve\ Mile";
$areanames{en}->{612533057} = "Tyagong";
$areanames{en}->{612533058} = "Windeyer";
$areanames{en}->{612533059} = "Wollar";
$areanames{en}->{612533060} = "Woodstock";
$areanames{en}->{612533061} = "Yetholme";
$areanames{en}->{612533062} = "Young";
$areanames{en}->{61253307} = "Canowindra";
$areanames{en}->{61253308} = "Harden";
$areanames{en}->{61253309} = "Baldry";
$areanames{en}->{61253320} = "Canowindra";
$areanames{en}->{61253330} = "Dunedoo";
$areanames{en}->{61253331} = "Dunedoo";
$areanames{en}->{61253332} = "Dunedoo";
$areanames{en}->{61253333} = "Orange";
$areanames{en}->{61253334} = "Gulgong";
$areanames{en}->{61253335} = "Bathurst";
$areanames{en}->{61253336} = "Mudgee";
$areanames{en}->{61253337} = "Mudgee";
$areanames{en}->{61253338} = "Mudgee";
$areanames{en}->{61253339} = "Hill\ End";
$areanames{en}->{61253349} = "Hampton";
$areanames{en}->{6125335} = "Orange";
$areanames{en}->{61253350} = "Hampton";
$areanames{en}->{61253351} = "Hampton";
$areanames{en}->{61253355} = "Mudgee";
$areanames{en}->{61253369} = "Running\ Stream";
$areanames{en}->{61253380} = "Young";
$areanames{en}->{61253381} = "Lyndhurst";
$areanames{en}->{6125353} = "Orange";
$areanames{en}->{6125354} = "Lithgow";
$areanames{en}->{61253550} = "Bathurst";
$areanames{en}->{61253551} = "Cowra";
$areanames{en}->{61253552} = "Mudgee";
$areanames{en}->{61253553} = "Blayney";
$areanames{en}->{61253554} = "Young";
$areanames{en}->{61253555} = "Harden";
$areanames{en}->{61253556} = "Rockley";
$areanames{en}->{61253557} = "Rockley";
$areanames{en}->{61253558} = "Portland";
$areanames{en}->{61253559} = "Portland";
$areanames{en}->{61253560} = "Meadow\ Flat";
$areanames{en}->{61253561} = "Meadow\ Flat";
$areanames{en}->{61253562} = "Dunedoo";
$areanames{en}->{61253563} = "Dunedoo";
$areanames{en}->{61253564} = "Kandos";
$areanames{en}->{61253565} = "Kandos";
$areanames{en}->{61253566} = "Bylong";
$areanames{en}->{61253567} = "Bylong";
$areanames{en}->{61253568} = "Frogmore";
$areanames{en}->{61253569} = "Frogmore";
$areanames{en}->{61253570} = "Galong";
$areanames{en}->{61253571} = "Galong";
$areanames{en}->{61253572} = "Maimuru";
$areanames{en}->{61253573} = "Maimuru";
$areanames{en}->{61253574} = "Burraga";
$areanames{en}->{61253575} = "Burraga";
$areanames{en}->{61253576} = "Gingkin";
$areanames{en}->{61253577} = "Gingkin";
$areanames{en}->{61253578} = "Mudgee";
$areanames{en}->{61253579} = "Orange";
$areanames{en}->{61255000} = "Kempsey";
$areanames{en}->{61255001} = "Singleton";
$areanames{en}->{61255002} = "Macksville";
$areanames{en}->{61255003} = "Smithtown";
$areanames{en}->{61255004} = "Stuarts\ Point";
$areanames{en}->{61255005} = "Taylors\ Arm";
$areanames{en}->{61255006} = "Toorooka";
$areanames{en}->{61255007} = "Lord\ Howe\ Island";
$areanames{en}->{61255008} = "Baerami";
$areanames{en}->{61255009} = "Bunnan";
$areanames{en}->{61255010} = "Castle\ Rock";
$areanames{en}->{61255011} = "Denman";
$areanames{en}->{61255012} = "Ellerston";
$areanames{en}->{61255013} = "Hunter\ Springs";
$areanames{en}->{61255014} = "Idaville";
$areanames{en}->{61255015} = "Comboyne";
$areanames{en}->{61255016} = "Merriwa";
$areanames{en}->{61255017} = "Moonan\ Flat";
$areanames{en}->{61255018} = "Murrurundi";
$areanames{en}->{61255019} = "Muswellbrook";
$areanames{en}->{61255020} = "Scone";
$areanames{en}->{61255021} = "Widden\ Valley";
$areanames{en}->{61255022} = "Broke";
$areanames{en}->{61255023} = "Glendonbrook";
$areanames{en}->{61255024} = "Howes\ Valley";
$areanames{en}->{61255025} = "Jerrys\ Plains";
$areanames{en}->{61255026} = "Mount\ Olive";
$areanames{en}->{61255027} = "Putty";
$areanames{en}->{61255028} = "Ravensworth";
$areanames{en}->{61255029} = "Coopernook";
$areanames{en}->{61255030} = "Forster";
$areanames{en}->{61255031} = "Gloucester";
$areanames{en}->{61255032} = "Krambach";
$areanames{en}->{61255033} = "Mount\ George";
$areanames{en}->{61255034} = "Pacific\ Palms";
$areanames{en}->{61255035} = "Rawdon\ Vale";
$areanames{en}->{61255036} = "Rookhurst";
$areanames{en}->{61255037} = "Taree";
$areanames{en}->{61255038} = "Byabarra";
$areanames{en}->{61255039} = "Ellenborough";
$areanames{en}->{61255040} = "Port\ Macquarie";
$areanames{en}->{61255041} = "Telegraph\ Point";
$areanames{en}->{61255042} = "Muswellbrook";
$areanames{en}->{61255043} = "Scone";
$areanames{en}->{61255044} = "Singleton";
$areanames{en}->{61255045} = "Port\ Macquarie";
$areanames{en}->{61255046} = "Taree";
$areanames{en}->{61255047} = "Kempsey";
$areanames{en}->{61255048} = "Macksville";
$areanames{en}->{61255049} = "Smithtown";
$areanames{en}->{61255050} = "Stuarts\ Point";
$areanames{en}->{61255051} = "Bowraville";
$areanames{en}->{61255052} = "Comara";
$areanames{en}->{61255053} = "Lord\ Howe\ Island";
$areanames{en}->{61255054} = "Kempsey";
$areanames{en}->{61255055} = "Macksville";
$areanames{en}->{61255056} = "Smithtown";
$areanames{en}->{61255057} = "Stuarts\ Point";
$areanames{en}->{61255058} = "Taylors\ Arm";
$areanames{en}->{61255059} = "Toorooka";
$areanames{en}->{61255060} = "Comboyne";
$areanames{en}->{61255061} = "Coopernook";
$areanames{en}->{61255062} = "Forster";
$areanames{en}->{61255063} = "Gloucester";
$areanames{en}->{61255064} = "Muswellbrook";
$areanames{en}->{61255065} = "Krambach";
$areanames{en}->{61255066} = "Mount\ George";
$areanames{en}->{61255067} = "Broke";
$areanames{en}->{61255068} = "Pacific\ Palms";
$areanames{en}->{61255069} = "Rawdon\ Vale";
$areanames{en}->{61255070} = "Rookhurst";
$areanames{en}->{61255071} = "Taree";
$areanames{en}->{61255072} = "Byabarra";
$areanames{en}->{61255073} = "Ellenborough";
$areanames{en}->{61255074} = "Singleton";
$areanames{en}->{61255075} = "Comboyne";
$areanames{en}->{61255076} = "Coopernook";
$areanames{en}->{61255077} = "Forster";
$areanames{en}->{61255078} = "Gloucester";
$areanames{en}->{61255079} = "Port\ Macquarie";
$areanames{en}->{61255080} = "Telegraph\ Point";
$areanames{en}->{61255081} = "Pacific\ Palms";
$areanames{en}->{61255082} = "Port\ Macquarie";
$areanames{en}->{61255083} = "Port\ Macquarie";
$areanames{en}->{61255084} = "Taree";
$areanames{en}->{61255085} = "Taree";
$areanames{en}->{61255086} = "Baerami";
$areanames{en}->{61255087} = "Port\ Macquarie";
$areanames{en}->{61255088} = "Telegraph\ Point";
$areanames{en}->{61255089} = "Kempsey";
$areanames{en}->{61255090} = "Kempsey";
$areanames{en}->{61255091} = "Macksville";
$areanames{en}->{61255092} = "Macksville";
$areanames{en}->{61255093} = "Smithtown";
$areanames{en}->{61255094} = "Smithtown";
$areanames{en}->{61255095} = "Comboyne";
$areanames{en}->{61255096} = "Comboyne";
$areanames{en}->{61255097} = "Coopernook";
$areanames{en}->{61255098} = "Coopernook";
$areanames{en}->{61255099} = "Forster";
$areanames{en}->{61255100} = "Forster";
$areanames{en}->{61255101} = "Krambach";
$areanames{en}->{61255102} = "Krambach";
$areanames{en}->{61255103} = "Krambach";
$areanames{en}->{61255104} = "Krambach";
$areanames{en}->{61255105} = "Pacific\ Palms";
$areanames{en}->{61255106} = "Pacific\ Palms";
$areanames{en}->{61255107} = "Rookhurst";
$areanames{en}->{61255108} = "Rookhurst";
$areanames{en}->{61255109} = "Taree";
$areanames{en}->{61255110} = "Taree";
$areanames{en}->{61255111} = "Byabarra";
$areanames{en}->{61255112} = "Byabarra";
$areanames{en}->{61255113} = "Port\ Macquarie";
$areanames{en}->{61255114} = "Port\ Macquarie";
$areanames{en}->{61255115} = "Telegraph\ Point";
$areanames{en}->{61255116} = "Telegraph\ Point";
$areanames{en}->{61255117} = "Stuarts\ Point";
$areanames{en}->{61255118} = "Stuarts\ Point";
$areanames{en}->{61255119} = "Bunnan";
$areanames{en}->{61255120} = "Bunnan";
$areanames{en}->{61255121} = "Castle\ Rock";
$areanames{en}->{61255122} = "Castle\ Rock";
$areanames{en}->{61255123} = "Denman";
$areanames{en}->{61255124} = "Denman";
$areanames{en}->{61255125} = "Idaville";
$areanames{en}->{61255126} = "Idaville";
$areanames{en}->{61255127} = "Merriwa";
$areanames{en}->{61255128} = "Merriwa";
$areanames{en}->{61255129} = "Murrurundi";
$areanames{en}->{61255130} = "Murrurundi";
$areanames{en}->{61255131} = "Muswellbrook";
$areanames{en}->{61255132} = "Muswellbrook";
$areanames{en}->{61255133} = "Scone";
$areanames{en}->{61255134} = "Scone";
$areanames{en}->{61255135} = "Forster";
$areanames{en}->{61255136} = "Port\ Macquarie";
$areanames{en}->{61255137} = "Broke";
$areanames{en}->{61255138} = "Broke";
$areanames{en}->{61255139} = "Forster";
$areanames{en}->{61255140} = "Port\ Macquarie";
$areanames{en}->{61255141} = "Port\ Macquarie";
$areanames{en}->{61255142} = "Forster";
$areanames{en}->{61255143} = "Lord\ Howe\ Island";
$areanames{en}->{61255144} = "Macksville";
$areanames{en}->{61255145} = "Port\ Macquarie";
$areanames{en}->{61255146} = "Rookhurst";
$areanames{en}->{61255147} = "Forster";
$areanames{en}->{61255148} = "Glendonbrook";
$areanames{en}->{61255149} = "Port\ Macquarie";
$areanames{en}->{61255150} = "Port\ Macquarie";
$areanames{en}->{61255151} = "Mount\ Olive";
$areanames{en}->{61255152} = "Mount\ George";
$areanames{en}->{61255153} = "Putty";
$areanames{en}->{61255154} = "Smithtown";
$areanames{en}->{61255155} = "Pacific\ Palms";
$areanames{en}->{61255156} = "Widden\ Valley";
$areanames{en}->{61255157} = "Merriwa";
$areanames{en}->{61255158} = "Rookhurst";
$areanames{en}->{61255159} = "Bowraville";
$areanames{en}->{61255160} = "Broke";
$areanames{en}->{61255161} = "Singleton";
$areanames{en}->{61255162} = "Denman";
$areanames{en}->{61255163} = "Comara";
$areanames{en}->{61255164} = "Moonan\ Flat";
$areanames{en}->{61255165} = "Castle\ Rock";
$areanames{en}->{61255166} = "Macksville";
$areanames{en}->{61255167} = "Byabarra";
$areanames{en}->{61255168} = "Scone";
$areanames{en}->{61255169} = "Bunnan";
$areanames{en}->{61255170} = "Byabarra";
$areanames{en}->{61255171} = "Muswellbrook";
$areanames{en}->{61255172} = "Idaville";
$areanames{en}->{61255173} = "Coopernook";
$areanames{en}->{61255174} = "Broke";
$areanames{en}->{61255175} = "Ellerston";
$areanames{en}->{61255176} = "Krambach";
$areanames{en}->{61255177} = "Hunter\ Springs";
$areanames{en}->{61255178} = "Howes\ Valley";
$areanames{en}->{61255179} = "Castle\ Rock";
$areanames{en}->{61255180} = "Comara";
$areanames{en}->{61255181} = "Gloucester";
$areanames{en}->{61255182} = "Bunnan";
$areanames{en}->{61255183} = "Baerami";
$areanames{en}->{61255184} = "Ravensworth";
$areanames{en}->{61255185} = "Telegraph\ Point";
$areanames{en}->{61255186} = "Taree";
$areanames{en}->{61255187} = "Jerrys\ Plains";
$areanames{en}->{61255188} = "Comboyne";
$areanames{en}->{61255189} = "Comboyne";
$areanames{en}->{61255190} = "Coopernook";
$areanames{en}->{61255191} = "Taylors\ Arm";
$areanames{en}->{61255192} = "Bowraville";
$areanames{en}->{61255193} = "Stuarts\ Point";
$areanames{en}->{61255194} = "Toorooka";
$areanames{en}->{61255195} = "Murrurundi";
$areanames{en}->{61255196} = "Kempsey";
$areanames{en}->{61255197} = "Ellenborough";
$areanames{en}->{61255198} = "Port\ Macquarie";
$areanames{en}->{61255199} = "Denman";
$areanames{en}->{61255200} = "Ellenborough";
$areanames{en}->{61255201} = "Rawdon\ Vale";
$areanames{en}->{61255202} = "Forster";
$areanames{en}->{61255203} = "Glendonbrook";
$areanames{en}->{61255204} = "Mount\ Olive";
$areanames{en}->{61255205} = "Mount\ George";
$areanames{en}->{61255206} = "Putty";
$areanames{en}->{61255207} = "Smithtown";
$areanames{en}->{61255208} = "Pacific\ Palms";
$areanames{en}->{61255209} = "Ellerston";
$areanames{en}->{61255210} = "Forster";
$areanames{en}->{61255211} = "Widden\ Valley";
$areanames{en}->{61255212} = "Merriwa";
$areanames{en}->{61255213} = "Lord\ Howe\ Island";
$areanames{en}->{61255214} = "Singleton";
$areanames{en}->{61255215} = "Denman";
$areanames{en}->{61255216} = "Comara";
$areanames{en}->{61255217} = "Moonan\ Flat";
$areanames{en}->{61255218} = "Castle\ Rock";
$areanames{en}->{61255219} = "Glendonbrook";
$areanames{en}->{61255220} = "Gloucester";
$areanames{en}->{61255221} = "Macksville";
$areanames{en}->{61255222} = "Byabarra";
$areanames{en}->{61255223} = "Scone";
$areanames{en}->{61255224} = "Muswellbrook";
$areanames{en}->{61255225} = "Idaville";
$areanames{en}->{61255226} = "Coopernook";
$areanames{en}->{61255227} = "Broke";
$areanames{en}->{61255228} = "Ellerston";
$areanames{en}->{61255229} = "Howes\ Valley";
$areanames{en}->{61255230} = "Hunter\ Springs";
$areanames{en}->{61255231} = "Krambach";
$areanames{en}->{61255232} = "Hunter\ Springs";
$areanames{en}->{61255233} = "Howes\ Valley";
$areanames{en}->{61255234} = "Gloucester";
$areanames{en}->{61255235} = "Bunnan";
$areanames{en}->{61255236} = "Baerami";
$areanames{en}->{61255237} = "Ravensworth";
$areanames{en}->{61255238} = "Telegraph\ Point";
$areanames{en}->{61255239} = "Idaville";
$areanames{en}->{61255240} = "Port\ Macquarie";
$areanames{en}->{61255241} = "Port\ Macquarie";
$areanames{en}->{61255242} = "Port\ Macquarie";
$areanames{en}->{61255243} = "Comara";
$areanames{en}->{61255244} = "Comara";
$areanames{en}->{61255245} = "Ellenborough";
$areanames{en}->{61255246} = "Ellenborough";
$areanames{en}->{61255247} = "Port\ Macquarie";
$areanames{en}->{61255248} = "Rawdon\ Vale";
$areanames{en}->{61255249} = "Rawdon\ Vale";
$areanames{en}->{6125525} = "Port\ Macquarie";
$areanames{en}->{61255256} = "Taree";
$areanames{en}->{61255257} = "Jerrys\ Plains";
$areanames{en}->{61255258} = "Comboyne";
$areanames{en}->{61255259} = "Jerrys\ Plains";
$areanames{en}->{6125526} = "Port\ Macquarie";
$areanames{en}->{61255270} = "Kempsey";
$areanames{en}->{61255271} = "Taylors\ Arm";
$areanames{en}->{61255272} = "Bowraville";
$areanames{en}->{61255273} = "Stuarts\ Point";
$areanames{en}->{61255274} = "Toorooka";
$areanames{en}->{61255275} = "Murrurundi";
$areanames{en}->{61255276} = "Kempsey";
$areanames{en}->{61255277} = "Ellenborough";
$areanames{en}->{61255278} = "Port\ Macquarie";
$areanames{en}->{61255279} = "Krambach";
$areanames{en}->{61255280} = "Lord\ Howe\ Island";
$areanames{en}->{61255281} = "Rawdon\ Vale";
$areanames{en}->{61255282} = "Singleton";
$areanames{en}->{61255283} = "Rookhurst";
$areanames{en}->{61255284} = "Krambach";
$areanames{en}->{61255285} = "Forster";
$areanames{en}->{61255286} = "Hunter\ Springs";
$areanames{en}->{61255287} = "Howes\ Valley";
$areanames{en}->{61255288} = "Gloucester";
$areanames{en}->{61255289} = "Macksville";
$areanames{en}->{61255290} = "Merriwa";
$areanames{en}->{61255291} = "Glendonbrook";
$areanames{en}->{61255292} = "Mount\ Olive";
$areanames{en}->{61255293} = "Bunnan";
$areanames{en}->{61255294} = "Mount\ George";
$areanames{en}->{61255295} = "Baerami";
$areanames{en}->{61255296} = "Ravensworth";
$areanames{en}->{61255297} = "Putty";
$areanames{en}->{61255298} = "Smithtown";
$areanames{en}->{61255299} = "Moonan\ Flat";
$areanames{en}->{61255300} = "Mount\ George";
$areanames{en}->{61255301} = "Telegraph\ Point";
$areanames{en}->{61255302} = "Pacific\ Palms";
$areanames{en}->{61255303} = "Widden\ Valley";
$areanames{en}->{61255304} = "Merriwa";
$areanames{en}->{61255305} = "Jerrys\ Plains";
$areanames{en}->{61255306} = "Comboyne";
$areanames{en}->{61255307} = "Lord\ Howe\ Island";
$areanames{en}->{61255308} = "Denman";
$areanames{en}->{61255309} = "Mount\ Olive";
$areanames{en}->{61255310} = "Murrurundi";
$areanames{en}->{61255311} = "Comara";
$areanames{en}->{61255312} = "Taylors\ Arm";
$areanames{en}->{61255313} = "Moonan\ Flat";
$areanames{en}->{61255314} = "Bowraville";
$areanames{en}->{61255315} = "Castle\ Rock";
$areanames{en}->{61255316} = "Macksville";
$areanames{en}->{61255317} = "Byabarra";
$areanames{en}->{61255318} = "Stuarts\ Point";
$areanames{en}->{61255319} = "Muswellbrook";
$areanames{en}->{61255320} = "Pacific\ Palms";
$areanames{en}->{61255321} = "Toorooka";
$areanames{en}->{61255322} = "Murrurundi";
$areanames{en}->{61255323} = "Idaville";
$areanames{en}->{61255324} = "Kempsey";
$areanames{en}->{61255325} = "Ellenborough";
$areanames{en}->{61255326} = "Coopernook";
$areanames{en}->{61255327} = "Broke";
$areanames{en}->{61255328} = "Ellerston";
$areanames{en}->{61255329} = "Port\ Macquarie";
$areanames{en}->{61255330} = "Putty";
$areanames{en}->{61255331} = "Rawdon\ Vale";
$areanames{en}->{61255332} = "Ravensworth";
$areanames{en}->{61255333} = "Rawdon\ Vale";
$areanames{en}->{61255334} = "Rookhurst";
$areanames{en}->{61255335} = "Scone";
$areanames{en}->{61255336} = "Singleton";
$areanames{en}->{61255337} = "Smithtown";
$areanames{en}->{61255338} = "Stuarts\ Point";
$areanames{en}->{61255339} = "Taree";
$areanames{en}->{61255340} = "Ellenborough";
$areanames{en}->{61255341} = "Port\ Macquarie";
$areanames{en}->{61255342} = "Port\ Macquarie";
$areanames{en}->{61255343} = "Port\ Macquarie";
$areanames{en}->{61255344} = "Taylors\ Arm";
$areanames{en}->{61255345} = "Telegraph\ Point";
$areanames{en}->{61255346} = "Toorooka";
$areanames{en}->{61255347} = "Widden\ Valley";
$areanames{en}->{61255348} = "Baerami";
$areanames{en}->{61255349} = "Bowraville";
$areanames{en}->{61255350} = "Broke";
$areanames{en}->{61255351} = "Bunnan";
$areanames{en}->{61255352} = "Byabarra";
$areanames{en}->{61255353} = "Castle\ Rock";
$areanames{en}->{61255354} = "Comara";
$areanames{en}->{61255355} = "Comboyne";
$areanames{en}->{61255356} = "Coopernook";
$areanames{en}->{61255357} = "Denman";
$areanames{en}->{61255358} = "Ellenborough";
$areanames{en}->{61255359} = "Ellerston";
$areanames{en}->{61255360} = "Forster";
$areanames{en}->{61255361} = "Glendonbrook";
$areanames{en}->{61255362} = "Gloucester";
$areanames{en}->{61255363} = "Howes\ Valley";
$areanames{en}->{61255364} = "Hunter\ Springs";
$areanames{en}->{61255365} = "Idaville";
$areanames{en}->{61255366} = "Jerrys\ Plains";
$areanames{en}->{61255367} = "Kempsey";
$areanames{en}->{61255368} = "Krambach";
$areanames{en}->{61255369} = "Lord\ Howe\ Island";
$areanames{en}->{61255370} = "Macksville";
$areanames{en}->{61255371} = "Merriwa";
$areanames{en}->{61255372} = "Moonan\ Flat";
$areanames{en}->{61255373} = "Mount\ George";
$areanames{en}->{61255374} = "Mount\ Olive";
$areanames{en}->{61255375} = "Murrurundi";
$areanames{en}->{61255376} = "Muswellbrook";
$areanames{en}->{61255377} = "Pacific\ Palms";
$areanames{en}->{61255378} = "Port\ Macquarie";
$areanames{en}->{61255379} = "Putty";
$areanames{en}->{61255380} = "Ravensworth";
$areanames{en}->{61255381} = "Rawdon\ Vale";
$areanames{en}->{61255382} = "Rookhurst";
$areanames{en}->{61255383} = "Scone";
$areanames{en}->{61255384} = "Singleton";
$areanames{en}->{61255385} = "Smithtown";
$areanames{en}->{61255386} = "Stuarts\ Point";
$areanames{en}->{61255387} = "Taree";
$areanames{en}->{61255388} = "Taylors\ Arm";
$areanames{en}->{61255389} = "Telegraph\ Point";
$areanames{en}->{61255390} = "Toorooka";
$areanames{en}->{61255391} = "Widden\ Valley";
$areanames{en}->{61255392} = "Baerami";
$areanames{en}->{61255393} = "Bowraville";
$areanames{en}->{61255394} = "Broke";
$areanames{en}->{61255395} = "Bunnan";
$areanames{en}->{61255396} = "Byabarra";
$areanames{en}->{61255397} = "Castle\ Rock";
$areanames{en}->{61255398} = "Comara";
$areanames{en}->{61255399} = "Comboyne";
$areanames{en}->{61255400} = "Coopernook";
$areanames{en}->{61255401} = "Denman";
$areanames{en}->{61255402} = "Ellenborough";
$areanames{en}->{61255403} = "Ellerston";
$areanames{en}->{61255404} = "Forster";
$areanames{en}->{61255405} = "Glendonbrook";
$areanames{en}->{61255406} = "Gloucester";
$areanames{en}->{61255407} = "Howes\ Valley";
$areanames{en}->{61255408} = "Hunter\ Springs";
$areanames{en}->{61255409} = "Idaville";
$areanames{en}->{61255410} = "Jerrys\ Plains";
$areanames{en}->{61255411} = "Kempsey";
$areanames{en}->{61255412} = "Krambach";
$areanames{en}->{61255413} = "Lord\ Howe\ Island";
$areanames{en}->{61255414} = "Macksville";
$areanames{en}->{61255415} = "Merriwa";
$areanames{en}->{61255416} = "Moonan\ Flat";
$areanames{en}->{61255417} = "Mount\ George";
$areanames{en}->{61255418} = "Mount\ Olive";
$areanames{en}->{61255419} = "Murrurundi";
$areanames{en}->{61255420} = "Muswellbrook";
$areanames{en}->{61255421} = "Pacific\ Palms";
$areanames{en}->{61255422} = "Port\ Macquarie";
$areanames{en}->{61255423} = "Putty";
$areanames{en}->{61255424} = "Ravensworth";
$areanames{en}->{61255425} = "Rawdon\ Vale";
$areanames{en}->{61255426} = "Rookhurst";
$areanames{en}->{61255427} = "Scone";
$areanames{en}->{61255428} = "Singleton";
$areanames{en}->{61255429} = "Smithtown";
$areanames{en}->{61255430} = "Stuarts\ Point";
$areanames{en}->{61255431} = "Taree";
$areanames{en}->{61255432} = "Taylors\ Arm";
$areanames{en}->{61255433} = "Telegraph\ Point";
$areanames{en}->{61255434} = "Toorooka";
$areanames{en}->{61255435} = "Widden\ Valley";
$areanames{en}->{61255436} = "Forster";
$areanames{en}->{61255437} = "Forster";
$areanames{en}->{61255438} = "Port\ Macquarie";
$areanames{en}->{61255439} = "Port\ Macquarie";
$areanames{en}->{61255440} = "Taree";
$areanames{en}->{61255441} = "Taree";
$areanames{en}->{61255442} = "Muswellbrook";
$areanames{en}->{61255443} = "Gloucester";
$areanames{en}->{61255444} = "Gloucester";
$areanames{en}->{61255445} = "Gloucester";
$areanames{en}->{61255446} = "Telegraph\ Point";
$areanames{en}->{61255447} = "Telegraph\ Point";
$areanames{en}->{61255448} = "Telegraph\ Point";
$areanames{en}->{61255449} = "Baerami";
$areanames{en}->{61255455} = "Bowraville";
$areanames{en}->{61255456} = "Broke";
$areanames{en}->{61255457} = "Bunnan";
$areanames{en}->{61255458} = "Byabarra";
$areanames{en}->{61255459} = "Castle\ Rock";
$areanames{en}->{61255460} = "Comara";
$areanames{en}->{61255461} = "Comboyne";
$areanames{en}->{61255462} = "Coopernook";
$areanames{en}->{61255463} = "Denman";
$areanames{en}->{61255464} = "Ellenborough";
$areanames{en}->{61255465} = "Ellerston";
$areanames{en}->{61255466} = "Forster";
$areanames{en}->{61255467} = "Glendonbrook";
$areanames{en}->{61255468} = "Gloucester";
$areanames{en}->{61255469} = "Howes\ Valley";
$areanames{en}->{61255470} = "Hunter\ Springs";
$areanames{en}->{61255471} = "Idaville";
$areanames{en}->{61255472} = "Jerrys\ Plains";
$areanames{en}->{61255473} = "Kempsey";
$areanames{en}->{61255474} = "Krambach";
$areanames{en}->{61255475} = "Lord\ Howe\ Island";
$areanames{en}->{61255476} = "Port\ Macquarie";
$areanames{en}->{61255477} = "Port\ Macquarie";
$areanames{en}->{61255478} = "Port\ Macquarie";
$areanames{en}->{61255479} = "Port\ Macquarie";
$areanames{en}->{61255480} = "Baerami";
$areanames{en}->{61255481} = "Bowraville";
$areanames{en}->{61255482} = "Broke";
$areanames{en}->{61255483} = "Bunnan";
$areanames{en}->{61255484} = "Byabarra";
$areanames{en}->{61255485} = "Castle\ Rock";
$areanames{en}->{61255486} = "Comara";
$areanames{en}->{61255487} = "Comboyne";
$areanames{en}->{61255488} = "Coopernook";
$areanames{en}->{61255489} = "Denman";
$areanames{en}->{61255490} = "Ellenborough";
$areanames{en}->{61255491} = "Ellerston";
$areanames{en}->{61255492} = "Forster";
$areanames{en}->{61255493} = "Glendonbrook";
$areanames{en}->{61255494} = "Gloucester";
$areanames{en}->{61255495} = "Howes\ Valley";
$areanames{en}->{61255496} = "Hunter\ Springs";
$areanames{en}->{61255497} = "Idaville";
$areanames{en}->{61255498} = "Jerrys\ Plains";
$areanames{en}->{61255499} = "Kempsey";
$areanames{en}->{61255510} = "Denman";
$areanames{en}->{61255511} = "Ellerston";
$areanames{en}->{61255512} = "Idaville";
$areanames{en}->{61255513} = "Merriwa";
$areanames{en}->{61255514} = "Moonan\ Flat";
$areanames{en}->{61255515} = "Murrurundi";
$areanames{en}->{61255516} = "Muswellbrook";
$areanames{en}->{61255517} = "Scone";
$areanames{en}->{61255518} = "Widden\ Valley";
$areanames{en}->{61255519} = "Baerami";
$areanames{en}->{61255520} = "Castle\ Rock";
$areanames{en}->{61255521} = "Bunnan";
$areanames{en}->{61255522} = "Hunter\ Springs";
$areanames{en}->{61255523} = "Putty";
$areanames{en}->{61255524} = "Mount\ Olive";
$areanames{en}->{61255525} = "Glendonbrook";
$areanames{en}->{61255526} = "Howes\ Valley";
$areanames{en}->{61255527} = "Broke";
$areanames{en}->{61255528} = "Jerrys\ Plains";
$areanames{en}->{61255529} = "Ravensworth";
$areanames{en}->{61255530} = "Singleton";
$areanames{en}->{61255531} = "Mount\ George";
$areanames{en}->{61255532} = "Mount\ George";
$areanames{en}->{61255533} = "Comara";
$areanames{en}->{61255534} = "Comara";
$areanames{en}->{61255535} = "Baerami";
$areanames{en}->{61255536} = "Baerami";
$areanames{en}->{61255537} = "Ellerston";
$areanames{en}->{61255538} = "Ellerston";
$areanames{en}->{61255539} = "Hunter\ Springs";
$areanames{en}->{61255540} = "Hunter\ Springs";
$areanames{en}->{61255541} = "Moonan\ Flat";
$areanames{en}->{61255542} = "Moonan\ Flat";
$areanames{en}->{61255543} = "Widden\ Valley";
$areanames{en}->{61255544} = "Widden\ Valley";
$areanames{en}->{61255545} = "Bowraville";
$areanames{en}->{61255546} = "Bowraville";
$areanames{en}->{61255547} = "Taylors\ Arm";
$areanames{en}->{61255548} = "Taylors\ Arm";
$areanames{en}->{61255549} = "Toorooka";
$areanames{en}->{61255550} = "Toorooka";
$areanames{en}->{61255551} = "Gloucester";
$areanames{en}->{61255552} = "Gloucester";
$areanames{en}->{61255553} = "Glendonbrook";
$areanames{en}->{61255554} = "Glendonbrook";
$areanames{en}->{61255555} = "Port\ Macquarie";
$areanames{en}->{61255556} = "Port\ Macquarie";
$areanames{en}->{61255557} = "Taree";
$areanames{en}->{61255558} = "Forster";
$areanames{en}->{61255559} = "Krambach";
$areanames{en}->{61255560} = "Forster";
$areanames{en}->{61255561} = "Forster";
$areanames{en}->{61255562} = "Forster";
$areanames{en}->{61255563} = "Forster";
$areanames{en}->{61255564} = "Forster";
$areanames{en}->{61255565} = "Gloucester";
$areanames{en}->{61255566} = "Gloucester";
$areanames{en}->{61255567} = "Gloucester";
$areanames{en}->{61255568} = "Lord\ Howe\ Island";
$areanames{en}->{61255569} = "Macksville";
$areanames{en}->{61255570} = "Merriwa";
$areanames{en}->{61255571} = "Moonan\ Flat";
$areanames{en}->{61255572} = "Mount\ George";
$areanames{en}->{61255573} = "Mount\ Olive";
$areanames{en}->{61255574} = "Murrurundi";
$areanames{en}->{61255575} = "Muswellbrook";
$areanames{en}->{61255576} = "Pacific\ Palms";
$areanames{en}->{61255577} = "Port\ Macquarie";
$areanames{en}->{61255578} = "Putty";
$areanames{en}->{61255579} = "Ravensworth";
$areanames{en}->{61255580} = "Rawdon\ Vale";
$areanames{en}->{61255581} = "Rookhurst";
$areanames{en}->{61255582} = "Scone";
$areanames{en}->{61255583} = "Singleton";
$areanames{en}->{61255584} = "Smithtown";
$areanames{en}->{61255585} = "Stuarts\ Point";
$areanames{en}->{61255586} = "Taree";
$areanames{en}->{61255587} = "Taylors\ Arm";
$areanames{en}->{61255588} = "Telegraph\ Point";
$areanames{en}->{61255589} = "Toorooka";
$areanames{en}->{61255590} = "Widden\ Valley";
$areanames{en}->{61255591} = "Taree";
$areanames{en}->{61255592} = "Taree";
$areanames{en}->{61255593} = "Taree";
$areanames{en}->{61255594} = "Kempsey";
$areanames{en}->{61255595} = "Kempsey";
$areanames{en}->{61255596} = "Kempsey";
$areanames{en}->{61255597} = "Macksville";
$areanames{en}->{61255598} = "Merriwa";
$areanames{en}->{61255599} = "Moonan\ Flat";
$areanames{en}->{61255600} = "Mount\ George";
$areanames{en}->{61255601} = "Mount\ Olive";
$areanames{en}->{61255602} = "Murrurundi";
$areanames{en}->{61255603} = "Muswellbrook";
$areanames{en}->{61255604} = "Pacific\ Palms";
$areanames{en}->{61255605} = "Port\ Macquarie";
$areanames{en}->{61255606} = "Putty";
$areanames{en}->{61255607} = "Ravensworth";
$areanames{en}->{61255608} = "Rawdon\ Vale";
$areanames{en}->{61255609} = "Rookhurst";
$areanames{en}->{61255610} = "Scone";
$areanames{en}->{61255611} = "Singleton";
$areanames{en}->{61255612} = "Smithtown";
$areanames{en}->{61255613} = "Stuarts\ Point";
$areanames{en}->{61255614} = "Taree";
$areanames{en}->{61255615} = "Taylors\ Arm";
$areanames{en}->{61255616} = "Telegraph\ Point";
$areanames{en}->{61255617} = "Toorooka";
$areanames{en}->{61255618} = "Widden\ Valley";
$areanames{en}->{61255619} = "Baerami";
$areanames{en}->{61255620} = "Bowraville";
$areanames{en}->{61255621} = "Broke";
$areanames{en}->{61255622} = "Bunnan";
$areanames{en}->{61255623} = "Byabarra";
$areanames{en}->{61255624} = "Castle\ Rock";
$areanames{en}->{61255625} = "Comara";
$areanames{en}->{61255626} = "Comboyne";
$areanames{en}->{61255627} = "Coopernook";
$areanames{en}->{61255628} = "Denman";
$areanames{en}->{61255629} = "Ellenborough";
$areanames{en}->{61255630} = "Ellerston";
$areanames{en}->{61255631} = "Forster";
$areanames{en}->{61255632} = "Glendonbrook";
$areanames{en}->{61255633} = "Gloucester";
$areanames{en}->{61255634} = "Howes\ Valley";
$areanames{en}->{61255635} = "Hunter\ Springs";
$areanames{en}->{61255636} = "Idaville";
$areanames{en}->{61255637} = "Jerrys\ Plains";
$areanames{en}->{61255638} = "Kempsey";
$areanames{en}->{61255639} = "Krambach";
$areanames{en}->{61255640} = "Lord\ Howe\ Island";
$areanames{en}->{61255641} = "Macksville";
$areanames{en}->{61255642} = "Merriwa";
$areanames{en}->{61255643} = "Moonan\ Flat";
$areanames{en}->{61255644} = "Mount\ George";
$areanames{en}->{61255645} = "Mount\ Olive";
$areanames{en}->{61255646} = "Murrurundi";
$areanames{en}->{61255647} = "Muswellbrook";
$areanames{en}->{61255648} = "Pacific\ Palms";
$areanames{en}->{61255649} = "Port\ Macquarie";
$areanames{en}->{61255650} = "Putty";
$areanames{en}->{61255651} = "Ravensworth";
$areanames{en}->{61255652} = "Rawdon\ Vale";
$areanames{en}->{61255653} = "Rookhurst";
$areanames{en}->{61255654} = "Scone";
$areanames{en}->{61255655} = "Singleton";
$areanames{en}->{61255656} = "Smithtown";
$areanames{en}->{61255657} = "Stuarts\ Point";
$areanames{en}->{61255658} = "Taree";
$areanames{en}->{61255659} = "Taylors\ Arm";
$areanames{en}->{61255660} = "Telegraph\ Point";
$areanames{en}->{61255661} = "Toorooka";
$areanames{en}->{61255662} = "Widden\ Valley";
$areanames{en}->{61255663} = "Baerami";
$areanames{en}->{61255664} = "Bowraville";
$areanames{en}->{61255665} = "Broke";
$areanames{en}->{61255666} = "Bunnan";
$areanames{en}->{61255667} = "Byabarra";
$areanames{en}->{61255668} = "Castle\ Rock";
$areanames{en}->{61255669} = "Comara";
$areanames{en}->{61255670} = "Comboyne";
$areanames{en}->{61255671} = "Coopernook";
$areanames{en}->{61255672} = "Denman";
$areanames{en}->{61255673} = "Ellenborough";
$areanames{en}->{61255674} = "Ellerston";
$areanames{en}->{61255675} = "Forster";
$areanames{en}->{61255676} = "Glendonbrook";
$areanames{en}->{61255677} = "Gloucester";
$areanames{en}->{61255678} = "Howes\ Valley";
$areanames{en}->{61255679} = "Hunter\ Springs";
$areanames{en}->{61255680} = "Idaville";
$areanames{en}->{61255681} = "Jerrys\ Plains";
$areanames{en}->{61255682} = "Kempsey";
$areanames{en}->{61255683} = "Krambach";
$areanames{en}->{61255684} = "Lord\ Howe\ Island";
$areanames{en}->{61255685} = "Macksville";
$areanames{en}->{61255686} = "Merriwa";
$areanames{en}->{61255687} = "Moonan\ Flat";
$areanames{en}->{61255688} = "Mount\ George";
$areanames{en}->{61255689} = "Mount\ Olive";
$areanames{en}->{61255690} = "Murrurundi";
$areanames{en}->{61255691} = "Muswellbrook";
$areanames{en}->{61255692} = "Pacific\ Palms";
$areanames{en}->{61255693} = "Port\ Macquarie";
$areanames{en}->{61255694} = "Putty";
$areanames{en}->{61255695} = "Ravensworth";
$areanames{en}->{61255696} = "Rawdon\ Vale";
$areanames{en}->{61255697} = "Rookhurst";
$areanames{en}->{61255698} = "Scone";
$areanames{en}->{61255699} = "Singleton";
$areanames{en}->{61255700} = "Smithtown";
$areanames{en}->{61255701} = "Stuarts\ Point";
$areanames{en}->{61255702} = "Taree";
$areanames{en}->{61255703} = "Taylors\ Arm";
$areanames{en}->{61255704} = "Telegraph\ Point";
$areanames{en}->{61255705} = "Toorooka";
$areanames{en}->{61255706} = "Widden\ Valley";
$areanames{en}->{61255707} = "Baerami";
$areanames{en}->{61255708} = "Bowraville";
$areanames{en}->{61255709} = "Broke";
$areanames{en}->{61255710} = "Bunnan";
$areanames{en}->{61255711} = "Byabarra";
$areanames{en}->{61255712} = "Castle\ Rock";
$areanames{en}->{61255713} = "Comara";
$areanames{en}->{61255714} = "Comboyne";
$areanames{en}->{61255715} = "Coopernook";
$areanames{en}->{61255716} = "Denman";
$areanames{en}->{61255717} = "Ellenborough";
$areanames{en}->{61255718} = "Ellerston";
$areanames{en}->{61255719} = "Forster";
$areanames{en}->{61255720} = "Glendonbrook";
$areanames{en}->{61255721} = "Gloucester";
$areanames{en}->{61255722} = "Howes\ Valley";
$areanames{en}->{61255723} = "Hunter\ Springs";
$areanames{en}->{61255724} = "Idaville";
$areanames{en}->{61255725} = "Jerrys\ Plains";
$areanames{en}->{61255726} = "Kempsey";
$areanames{en}->{61255727} = "Krambach";
$areanames{en}->{61255728} = "Lord\ Howe\ Island";
$areanames{en}->{61255729} = "Macksville";
$areanames{en}->{61255730} = "Merriwa";
$areanames{en}->{61255731} = "Moonan\ Flat";
$areanames{en}->{61255732} = "Mount\ George";
$areanames{en}->{61255733} = "Mount\ Olive";
$areanames{en}->{61255734} = "Murrurundi";
$areanames{en}->{61255735} = "Muswellbrook";
$areanames{en}->{61255736} = "Pacific\ Palms";
$areanames{en}->{61255737} = "Port\ Macquarie";
$areanames{en}->{61255738} = "Putty";
$areanames{en}->{61255739} = "Ravensworth";
$areanames{en}->{61255740} = "Rawdon\ Vale";
$areanames{en}->{61255741} = "Rookhurst";
$areanames{en}->{61255742} = "Scone";
$areanames{en}->{61255743} = "Singleton";
$areanames{en}->{61255744} = "Smithtown";
$areanames{en}->{61255745} = "Stuarts\ Point";
$areanames{en}->{61255746} = "Taree";
$areanames{en}->{61255747} = "Taylors\ Arm";
$areanames{en}->{61255748} = "Telegraph\ Point";
$areanames{en}->{61255749} = "Toorooka";
$areanames{en}->{61255750} = "Widden\ Valley";
$areanames{en}->{6125590} = "Port\ Macquarie";
$areanames{en}->{61255910} = "Kempsey";
$areanames{en}->{61255911} = "Macksville";
$areanames{en}->{61255912} = "Smithtown";
$areanames{en}->{61255913} = "Muswellbrook";
$areanames{en}->{61255914} = "Scone";
$areanames{en}->{61255915} = "Singleton";
$areanames{en}->{61255916} = "Coopernook";
$areanames{en}->{61255917} = "Forster";
$areanames{en}->{61255918} = "Taree";
$areanames{en}->{61255919} = "Macksville";
$areanames{en}->{61255921} = "Ravensworth";
$areanames{en}->{61255922} = "Ravensworth";
$areanames{en}->{61255923} = "Mount\ Olive";
$areanames{en}->{61255924} = "Mount\ Olive";
$areanames{en}->{61255925} = "Jerrys\ Plains";
$areanames{en}->{61255926} = "Jerrys\ Plains";
$areanames{en}->{61255927} = "Singleton";
$areanames{en}->{61255928} = "Singleton";
$areanames{en}->{61255930} = "Taree";
$areanames{en}->{61255931} = "Taree";
$areanames{en}->{61255932} = "Howes\ Valley";
$areanames{en}->{61255933} = "Howes\ Valley";
$areanames{en}->{61255934} = "Putty";
$areanames{en}->{61255935} = "Putty";
$areanames{en}->{61255936} = "Lord\ Howe\ Island";
$areanames{en}->{61255937} = "Lord\ Howe\ Island";
$areanames{en}->{61255938} = "Ravensworth";
$areanames{en}->{61255939} = "Ravensworth";
$areanames{en}->{61255941} = "Taree";
$areanames{en}->{61255942} = "Taree";
$areanames{en}->{61255943} = "Taree";
$areanames{en}->{61255944} = "Baerami";
$areanames{en}->{61255945} = "Muswellbrook";
$areanames{en}->{61255946} = "Taree";
$areanames{en}->{61255947} = "Taree";
$areanames{en}->{61255948} = "Taree";
$areanames{en}->{61255949} = "Taree";
$areanames{en}->{61256000} = "Tabulam";
$areanames{en}->{61256001} = "Whiporie";
$areanames{en}->{61256002} = "Bellingen";
$areanames{en}->{61256003} = "Dorrigo";
$areanames{en}->{61256004} = "Hernani";
$areanames{en}->{61256005} = "Thora";
$areanames{en}->{61256006} = "Tyringham";
$areanames{en}->{61256007} = "Ulong";
$areanames{en}->{61256008} = "Copmanhurst";
$areanames{en}->{61256009} = "Coutts\ Crossing";
$areanames{en}->{61256010} = "Glenreagh";
$areanames{en}->{61256011} = "Lawrence";
$areanames{en}->{61256012} = "Maclean";
$areanames{en}->{61256013} = "Wooli";
$areanames{en}->{61256014} = "Ettrick";
$areanames{en}->{61256015} = "Kyogle";
$areanames{en}->{61256016} = "Urbenville";
$areanames{en}->{61256017} = "Wiangaree";
$areanames{en}->{61256018} = "Woodenbong";
$areanames{en}->{61256019} = "Ballina";
$areanames{en}->{61256020} = "Nimbin";
$areanames{en}->{61256021} = "Woodburn";
$areanames{en}->{61256022} = "Murwillumbah";
$areanames{en}->{61256023} = "Tyalgum";
$areanames{en}->{61256024} = "Bonalbo";
$areanames{en}->{61256025} = "Casino";
$areanames{en}->{61256026} = "Dyraaba";
$areanames{en}->{61256027} = "Leeville";
$areanames{en}->{61256028} = "Mallanganee";
$areanames{en}->{61256029} = "Rappville";
$areanames{en}->{61256030} = "Tabulam";
$areanames{en}->{61256031} = "Whiporie";
$areanames{en}->{61256032} = "Bellingen";
$areanames{en}->{61256033} = "Coffs\ Harbour";
$areanames{en}->{61256034} = "Dorrigo";
$areanames{en}->{61256035} = "Hernani";
$areanames{en}->{61256036} = "Thora";
$areanames{en}->{61256037} = "Tyringham";
$areanames{en}->{61256038} = "Ulong";
$areanames{en}->{61256039} = "Copmanhurst";
$areanames{en}->{61256040} = "Coutts\ Crossing";
$areanames{en}->{61256041} = "Glenreagh";
$areanames{en}->{61256042} = "Grafton";
$areanames{en}->{61256043} = "Lawrence";
$areanames{en}->{61256044} = "Maclean";
$areanames{en}->{61256045} = "Wooli";
$areanames{en}->{61256046} = "Ettrick";
$areanames{en}->{61256047} = "Kyogle";
$areanames{en}->{61256048} = "Urbenville";
$areanames{en}->{61256049} = "Wiangaree";
$areanames{en}->{61256050} = "Woodenbong";
$areanames{en}->{61256051} = "Ballina";
$areanames{en}->{61256052} = "Lismore";
$areanames{en}->{61256053} = "Mullumbimby";
$areanames{en}->{61256054} = "Nimbin";
$areanames{en}->{61256055} = "Woodburn";
$areanames{en}->{61256056} = "Murwillumbah";
$areanames{en}->{61256057} = "Tyalgum";
$areanames{en}->{61256058} = "Lismore";
$areanames{en}->{61256059} = "Bonalbo";
$areanames{en}->{6125606} = "Coffs\ Harbour";
$areanames{en}->{61256070} = "Casino";
$areanames{en}->{61256071} = "Casino";
$areanames{en}->{61256072} = "Rappville";
$areanames{en}->{61256073} = "Mallanganee";
$areanames{en}->{61256074} = "Ettrick";
$areanames{en}->{61256075} = "Tabulam";
$areanames{en}->{61256076} = "Dorrigo";
$areanames{en}->{61256077} = "Bellingen";
$areanames{en}->{61256078} = "Coffs\ Harbour";
$areanames{en}->{61256079} = "Dorrigo";
$areanames{en}->{61256080} = "Hernani";
$areanames{en}->{61256081} = "Thora";
$areanames{en}->{61256082} = "Tyringham";
$areanames{en}->{61256083} = "Ulong";
$areanames{en}->{61256084} = "Woodenbong";
$areanames{en}->{61256085} = "Kyogle";
$areanames{en}->{61256086} = "Copmanhurst";
$areanames{en}->{61256087} = "Grafton";
$areanames{en}->{61256088} = "Lawrence";
$areanames{en}->{61256089} = "Maclean";
$areanames{en}->{61256090} = "Wooli";
$areanames{en}->{61256091} = "Hernani";
$areanames{en}->{61256092} = "Leeville";
$areanames{en}->{61256093} = "Nimbin";
$areanames{en}->{61256094} = "Tabulam";
$areanames{en}->{61256095} = "Woodenbong";
$areanames{en}->{61256096} = "Ballina";
$areanames{en}->{61256097} = "Lismore";
$areanames{en}->{61256098} = "Mullumbimby";
$areanames{en}->{61256099} = "Nimbin";
$areanames{en}->{61256100} = "Woodburn";
$areanames{en}->{61256101} = "Murwillumbah";
$areanames{en}->{61256102} = "Tyalgum";
$areanames{en}->{61256103} = "Murwillumbah";
$areanames{en}->{61256104} = "Murwillumbah";
$areanames{en}->{61256105} = "Grafton";
$areanames{en}->{61256106} = "Lismore";
$areanames{en}->{61256107} = "Ettrick";
$areanames{en}->{61256108} = "Ettrick";
$areanames{en}->{61256109} = "Lismore";
$areanames{en}->{61256110} = "Casino";
$areanames{en}->{61256111} = "Bellingen";
$areanames{en}->{61256112} = "Grafton";
$areanames{en}->{61256113} = "Maclean";
$areanames{en}->{61256114} = "Kyogle";
$areanames{en}->{61256115} = "Ballina";
$areanames{en}->{61256116} = "Lismore";
$areanames{en}->{61256117} = "Mullumbimby";
$areanames{en}->{61256118} = "Woodburn";
$areanames{en}->{61256119} = "Murwillumbah";
$areanames{en}->{6125612} = "Coffs\ Harbour";
$areanames{en}->{61256130} = "Ballina";
$areanames{en}->{61256131} = "Lismore";
$areanames{en}->{61256132} = "Woodburn";
$areanames{en}->{61256133} = "Woodburn";
$areanames{en}->{61256134} = "Dyraaba";
$areanames{en}->{61256135} = "Dyraaba";
$areanames{en}->{61256136} = "Murwillumbah";
$areanames{en}->{61256137} = "Murwillumbah";
$areanames{en}->{61256138} = "Lawrence";
$areanames{en}->{61256139} = "Lawrence";
$areanames{en}->{61256140} = "Leeville";
$areanames{en}->{61256141} = "Leeville";
$areanames{en}->{61256142} = "Urbenville";
$areanames{en}->{61256143} = "Urbenville";
$areanames{en}->{61256144} = "Nimbin";
$areanames{en}->{61256145} = "Nimbin";
$areanames{en}->{61256146} = "Tyalgum";
$areanames{en}->{61256147} = "Tyalgum";
$areanames{en}->{61256148} = "Mullumbimby";
$areanames{en}->{61256149} = "Mullumbimby";
$areanames{en}->{61256150} = "Lismore";
$areanames{en}->{61256151} = "Lismore";
$areanames{en}->{61256152} = "Ballina";
$areanames{en}->{61256153} = "Ballina";
$areanames{en}->{61256154} = "Wiangaree";
$areanames{en}->{61256155} = "Wiangaree";
$areanames{en}->{61256156} = "Kyogle";
$areanames{en}->{61256157} = "Kyogle";
$areanames{en}->{61256158} = "Coffs\ Harbour";
$areanames{en}->{61256159} = "Coffs\ Harbour";
$areanames{en}->{61256160} = "Coffs\ Harbour";
$areanames{en}->{61256161} = "Coffs\ Harbour";
$areanames{en}->{61256162} = "Woodenbong";
$areanames{en}->{61256163} = "Woodenbong";
$areanames{en}->{61256164} = "Lismore";
$areanames{en}->{61256165} = "Lismore";
$areanames{en}->{61256166} = "Casino";
$areanames{en}->{61256167} = "Casino";
$areanames{en}->{61256168} = "Coffs\ Harbour";
$areanames{en}->{61256169} = "Grafton";
$areanames{en}->{61256170} = "Mallanganee";
$areanames{en}->{61256171} = "Mallanganee";
$areanames{en}->{61256172} = "Whiporie";
$areanames{en}->{61256173} = "Whiporie";
$areanames{en}->{61256174} = "Bellingen";
$areanames{en}->{61256175} = "Bellingen";
$areanames{en}->{61256176} = "Coffs\ Harbour";
$areanames{en}->{61256177} = "Coffs\ Harbour";
$areanames{en}->{61256178} = "Dorrigo";
$areanames{en}->{61256179} = "Dorrigo";
$areanames{en}->{61256180} = "Thora";
$areanames{en}->{61256181} = "Thora";
$areanames{en}->{61256182} = "Tyringham";
$areanames{en}->{61256183} = "Tyringham";
$areanames{en}->{61256184} = "Coutts\ Crossing";
$areanames{en}->{61256185} = "Coutts\ Crossing";
$areanames{en}->{61256186} = "Glenreagh";
$areanames{en}->{61256187} = "Glenreagh";
$areanames{en}->{61256188} = "Grafton";
$areanames{en}->{61256189} = "Grafton";
$areanames{en}->{61256190} = "Maclean";
$areanames{en}->{61256191} = "Maclean";
$areanames{en}->{61256192} = "Coffs\ Harbour";
$areanames{en}->{61256193} = "Ulong";
$areanames{en}->{61256194} = "Ulong";
$areanames{en}->{61256195} = "Copmanhurst";
$areanames{en}->{61256196} = "Copmanhurst";
$areanames{en}->{61256197} = "Wooli";
$areanames{en}->{61256198} = "Wooli";
$areanames{en}->{61256199} = "Grafton";
$areanames{en}->{6125620} = "Casino";
$areanames{en}->{61256205} = "Lismore";
$areanames{en}->{61256206} = "Coffs\ Harbour";
$areanames{en}->{61256207} = "Bonalbo";
$areanames{en}->{61256208} = "Lawrence";
$areanames{en}->{61256210} = "Dyraaba";
$areanames{en}->{61256211} = "Grafton";
$areanames{en}->{61256212} = "Leeville";
$areanames{en}->{61256213} = "Coutts\ Crossing";
$areanames{en}->{61256214} = "Mallanganee";
$areanames{en}->{61256215} = "Maclean";
$areanames{en}->{61256216} = "Tyalgum";
$areanames{en}->{61256217} = "Copmanhurst";
$areanames{en}->{61256218} = "Coffs\ Harbour";
$areanames{en}->{61256219} = "Leeville";
$areanames{en}->{61256220} = "Mallanganee";
$areanames{en}->{61256221} = "Lismore";
$areanames{en}->{61256222} = "Wooli";
$areanames{en}->{61256223} = "Casino";
$areanames{en}->{61256224} = "Grafton";
$areanames{en}->{61256225} = "Tyringham";
$areanames{en}->{61256226} = "Ballina";
$areanames{en}->{61256227} = "Ulong";
$areanames{en}->{61256228} = "Coffs\ Harbour";
$areanames{en}->{61256229} = "Coffs\ Harbour";
$areanames{en}->{61256230} = "Rappville";
$areanames{en}->{61256231} = "Coffs\ Harbour";
$areanames{en}->{61256232} = "Nimbin";
$areanames{en}->{61256233} = "Kyogle";
$areanames{en}->{61256234} = "Bellingen";
$areanames{en}->{61256235} = "Glenreagh";
$areanames{en}->{61256236} = "Woodburn";
$areanames{en}->{61256237} = "Urbenville";
$areanames{en}->{61256238} = "Woodenbong";
$areanames{en}->{61256239} = "Tabulam";
$areanames{en}->{61256240} = "Whiporie";
$areanames{en}->{61256241} = "Dorrigo";
$areanames{en}->{61256242} = "Whiporie";
$areanames{en}->{61256243} = "Rappville";
$areanames{en}->{61256244} = "Tabulam";
$areanames{en}->{61256245} = "Mullumbimby";
$areanames{en}->{61256246} = "Wiangaree";
$areanames{en}->{61256247} = "Lismore";
$areanames{en}->{61256248} = "Dyraaba";
$areanames{en}->{61256249} = "Bellingen";
$areanames{en}->{61256250} = "Coffs\ Harbour";
$areanames{en}->{61256251} = "Hernani";
$areanames{en}->{61256252} = "Murwillumbah";
$areanames{en}->{61256253} = "Thora";
$areanames{en}->{61256254} = "Ettrick";
$areanames{en}->{61256255} = "Bonalbo";
$areanames{en}->{61256256} = "Lawrence";
$areanames{en}->{61256257} = "Leeville";
$areanames{en}->{61256258} = "Coutts\ Crossing";
$areanames{en}->{61256259} = "Dorrigo";
$areanames{en}->{61256260} = "Hernani";
$areanames{en}->{61256261} = "Mallanganee";
$areanames{en}->{61256262} = "Maclean";
$areanames{en}->{61256263} = "Tyalgum";
$areanames{en}->{61256264} = "Copmanhurst";
$areanames{en}->{61256265} = "Coffs\ Harbour";
$areanames{en}->{61256266} = "Wooli";
$areanames{en}->{61256267} = "Casino";
$areanames{en}->{61256268} = "Grafton";
$areanames{en}->{61256269} = "Thora";
$areanames{en}->{61256270} = "Tyringham";
$areanames{en}->{61256271} = "Tyringham";
$areanames{en}->{61256272} = "Ballina";
$areanames{en}->{61256273} = "Ulong";
$areanames{en}->{61256274} = "Nimbin";
$areanames{en}->{61256275} = "Kyogle";
$areanames{en}->{61256276} = "Bellingen";
$areanames{en}->{61256277} = "Glenreagh";
$areanames{en}->{61256278} = "Woodburn";
$areanames{en}->{61256279} = "Ulong";
$areanames{en}->{61256280} = "Copmanhurst";
$areanames{en}->{61256281} = "Urbenville";
$areanames{en}->{61256282} = "Woodenbong";
$areanames{en}->{61256283} = "Dorrigo";
$areanames{en}->{61256284} = "Whiporie";
$areanames{en}->{61256285} = "Rappville";
$areanames{en}->{61256286} = "Tabulam";
$areanames{en}->{61256287} = "Mullumbimby";
$areanames{en}->{61256288} = "Wiangaree";
$areanames{en}->{61256289} = "Coutts\ Crossing";
$areanames{en}->{61256290} = "Glenreagh";
$areanames{en}->{61256291} = "Lismore";
$areanames{en}->{61256292} = "Dyraaba";
$areanames{en}->{61256293} = "Hernani";
$areanames{en}->{61256294} = "Murwillumbah";
$areanames{en}->{61256295} = "Thora";
$areanames{en}->{61256296} = "Ettrick";
$areanames{en}->{61256297} = "Mullumbimby";
$areanames{en}->{61256298} = "Maclean";
$areanames{en}->{61256299} = "Grafton";
$areanames{en}->{61256300} = "Lawrence";
$areanames{en}->{61256301} = "Ballina";
$areanames{en}->{61256302} = "Wooli";
$areanames{en}->{61256303} = "Glenreagh";
$areanames{en}->{61256304} = "Whiporie";
$areanames{en}->{61256305} = "Tyringham";
$areanames{en}->{61256306} = "Ulong";
$areanames{en}->{61256307} = "Bonalbo";
$areanames{en}->{61256308} = "Tyalgum";
$areanames{en}->{61256309} = "Maclean";
$areanames{en}->{61256310} = "Wooli";
$areanames{en}->{61256311} = "Murwillumbah";
$areanames{en}->{61256312} = "Wiangaree";
$areanames{en}->{61256313} = "Woodburn";
$areanames{en}->{61256314} = "Lawrence";
$areanames{en}->{61256315} = "Coutts\ Crossing";
$areanames{en}->{61256316} = "Thora";
$areanames{en}->{61256317} = "Urbenville";
$areanames{en}->{61256318} = "Ballina";
$areanames{en}->{61256319} = "Ettrick";
$areanames{en}->{61256320} = "Kyogle";
$areanames{en}->{61256321} = "Lismore";
$areanames{en}->{61256322} = "Bellingen";
$areanames{en}->{61256323} = "Grafton";
$areanames{en}->{61256324} = "Coffs\ Harbour";
$areanames{en}->{61256325} = "Lismore";
$areanames{en}->{61256326} = "Urbenville";
$areanames{en}->{61256327} = "Wiangaree";
$areanames{en}->{61256328} = "Woodenbong";
$areanames{en}->{61256329} = "Ballina";
$areanames{en}->{61256330} = "Lismore";
$areanames{en}->{61256331} = "Mullumbimby";
$areanames{en}->{61256332} = "Nimbin";
$areanames{en}->{61256333} = "Woodburn";
$areanames{en}->{61256334} = "Murwillumbah";
$areanames{en}->{61256335} = "Tyalgum";
$areanames{en}->{61256336} = "Coffs\ Harbour";
$areanames{en}->{61256337} = "Dyraaba";
$areanames{en}->{61256338} = "Mallanganee";
$areanames{en}->{61256339} = "Coffs\ Harbour";
$areanames{en}->{61256340} = "Grafton";
$areanames{en}->{61256341} = "Grafton";
$areanames{en}->{61256342} = "Maclean";
$areanames{en}->{61256343} = "Maclean";
$areanames{en}->{61256344} = "Coffs\ Harbour";
$areanames{en}->{61256345} = "Grafton";
$areanames{en}->{61256346} = "Grafton";
$areanames{en}->{61256347} = "Grafton";
$areanames{en}->{61256348} = "Ballina";
$areanames{en}->{61256349} = "Bellingen";
$areanames{en}->{61256350} = "Bonalbo";
$areanames{en}->{61256351} = "Casino";
$areanames{en}->{61256352} = "Coffs\ Harbour";
$areanames{en}->{61256353} = "Copmanhurst";
$areanames{en}->{61256354} = "Coutts\ Crossing";
$areanames{en}->{61256355} = "Dorrigo";
$areanames{en}->{61256356} = "Dyraaba";
$areanames{en}->{61256357} = "Ettrick";
$areanames{en}->{61256358} = "Glenreagh";
$areanames{en}->{61256359} = "Grafton";
$areanames{en}->{61256360} = "Hernani";
$areanames{en}->{61256361} = "Kyogle";
$areanames{en}->{61256362} = "Lawrence";
$areanames{en}->{61256363} = "Leeville";
$areanames{en}->{61256364} = "Lismore";
$areanames{en}->{61256365} = "Maclean";
$areanames{en}->{61256366} = "Mallanganee";
$areanames{en}->{61256367} = "Mullumbimby";
$areanames{en}->{61256368} = "Murwillumbah";
$areanames{en}->{61256369} = "Nimbin";
$areanames{en}->{61256370} = "Rappville";
$areanames{en}->{61256371} = "Tabulam";
$areanames{en}->{61256372} = "Thora";
$areanames{en}->{61256373} = "Tyalgum";
$areanames{en}->{61256374} = "Tyringham";
$areanames{en}->{61256375} = "Ulong";
$areanames{en}->{61256376} = "Urbenville";
$areanames{en}->{61256377} = "Whiporie";
$areanames{en}->{61256378} = "Wiangaree";
$areanames{en}->{61256379} = "Woodburn";
$areanames{en}->{61256380} = "Woodenbong";
$areanames{en}->{61256381} = "Wooli";
$areanames{en}->{61256382} = "Ballina";
$areanames{en}->{61256383} = "Bellingen";
$areanames{en}->{61256384} = "Bonalbo";
$areanames{en}->{61256385} = "Casino";
$areanames{en}->{61256386} = "Coffs\ Harbour";
$areanames{en}->{61256387} = "Copmanhurst";
$areanames{en}->{61256388} = "Coutts\ Crossing";
$areanames{en}->{61256389} = "Dorrigo";
$areanames{en}->{61256390} = "Dyraaba";
$areanames{en}->{61256391} = "Ettrick";
$areanames{en}->{61256392} = "Glenreagh";
$areanames{en}->{61256393} = "Grafton";
$areanames{en}->{61256394} = "Hernani";
$areanames{en}->{61256395} = "Kyogle";
$areanames{en}->{61256396} = "Lawrence";
$areanames{en}->{61256397} = "Leeville";
$areanames{en}->{61256398} = "Lismore";
$areanames{en}->{61256399} = "Maclean";
$areanames{en}->{61256400} = "Mallanganee";
$areanames{en}->{61256401} = "Mullumbimby";
$areanames{en}->{61256402} = "Murwillumbah";
$areanames{en}->{61256403} = "Nimbin";
$areanames{en}->{61256404} = "Rappville";
$areanames{en}->{61256405} = "Tabulam";
$areanames{en}->{61256406} = "Thora";
$areanames{en}->{61256407} = "Tyalgum";
$areanames{en}->{61256408} = "Tyringham";
$areanames{en}->{61256409} = "Ulong";
$areanames{en}->{61256410} = "Urbenville";
$areanames{en}->{61256411} = "Whiporie";
$areanames{en}->{61256412} = "Wiangaree";
$areanames{en}->{61256413} = "Woodburn";
$areanames{en}->{61256414} = "Woodenbong";
$areanames{en}->{61256415} = "Wooli";
$areanames{en}->{61256416} = "Bellingen";
$areanames{en}->{61256417} = "Bellingen";
$areanames{en}->{61256418} = "Bellingen";
$areanames{en}->{61256419} = "Bellingen";
$areanames{en}->{61256420} = "Ballina";
$areanames{en}->{61256421} = "Bellingen";
$areanames{en}->{61256422} = "Bonalbo";
$areanames{en}->{61256423} = "Casino";
$areanames{en}->{61256424} = "Coffs\ Harbour";
$areanames{en}->{61256425} = "Copmanhurst";
$areanames{en}->{61256426} = "Coutts\ Crossing";
$areanames{en}->{61256427} = "Dorrigo";
$areanames{en}->{61256428} = "Dyraaba";
$areanames{en}->{61256429} = "Ettrick";
$areanames{en}->{61256430} = "Glenreagh";
$areanames{en}->{61256431} = "Grafton";
$areanames{en}->{61256432} = "Hernani";
$areanames{en}->{61256433} = "Kyogle";
$areanames{en}->{61256434} = "Lawrence";
$areanames{en}->{61256435} = "Leeville";
$areanames{en}->{61256436} = "Lismore";
$areanames{en}->{61256437} = "Maclean";
$areanames{en}->{61256438} = "Mallanganee";
$areanames{en}->{61256439} = "Mullumbimby";
$areanames{en}->{61256440} = "Murwillumbah";
$areanames{en}->{61256441} = "Nimbin";
$areanames{en}->{61256442} = "Rappville";
$areanames{en}->{61256443} = "Tabulam";
$areanames{en}->{61256444} = "Thora";
$areanames{en}->{61256445} = "Tyalgum";
$areanames{en}->{61256446} = "Tyringham";
$areanames{en}->{61256447} = "Ulong";
$areanames{en}->{61256448} = "Urbenville";
$areanames{en}->{61256449} = "Whiporie";
$areanames{en}->{6125645} = "Coffs\ Harbour";
$areanames{en}->{61256450} = "Grafton";
$areanames{en}->{61256457} = "Lismore";
$areanames{en}->{61256458} = "Lismore";
$areanames{en}->{61256459} = "Grafton";
$areanames{en}->{61256460} = "Wiangaree";
$areanames{en}->{61256461} = "Ballina";
$areanames{en}->{61256462} = "Ballina";
$areanames{en}->{61256463} = "Coffs\ Harbour";
$areanames{en}->{61256464} = "Coffs\ Harbour";
$areanames{en}->{61256465} = "Coffs\ Harbour";
$areanames{en}->{61256466} = "Coffs\ Harbour";
$areanames{en}->{61256467} = "Coffs\ Harbour";
$areanames{en}->{61256468} = "Woodburn";
$areanames{en}->{61256469} = "Woodenbong";
$areanames{en}->{61256470} = "Wooli";
$areanames{en}->{61256471} = "Mullumbimby";
$areanames{en}->{61256472} = "Mullumbimby";
$areanames{en}->{61256473} = "Mullumbimby";
$areanames{en}->{61256474} = "Ballina";
$areanames{en}->{61256475} = "Ballina";
$areanames{en}->{61256476} = "Ballina";
$areanames{en}->{61256477} = "Bellingen";
$areanames{en}->{61256478} = "Ballina";
$areanames{en}->{61256479} = "Bellingen";
$areanames{en}->{61256480} = "Bonalbo";
$areanames{en}->{61256481} = "Casino";
$areanames{en}->{61256482} = "Coffs\ Harbour";
$areanames{en}->{61256483} = "Copmanhurst";
$areanames{en}->{61256484} = "Coutts\ Crossing";
$areanames{en}->{61256485} = "Ballina";
$areanames{en}->{61256486} = "Bellingen";
$areanames{en}->{61256487} = "Bonalbo";
$areanames{en}->{61256488} = "Casino";
$areanames{en}->{61256489} = "Coffs\ Harbour";
$areanames{en}->{61256490} = "Copmanhurst";
$areanames{en}->{61256491} = "Coutts\ Crossing";
$areanames{en}->{61256492} = "Dorrigo";
$areanames{en}->{61256493} = "Dyraaba";
$areanames{en}->{61256494} = "Ettrick";
$areanames{en}->{61256495} = "Glenreagh";
$areanames{en}->{61256496} = "Grafton";
$areanames{en}->{61256497} = "Hernani";
$areanames{en}->{61256498} = "Kyogle";
$areanames{en}->{61256499} = "Lawrence";
$areanames{en}->{61256500} = "Leeville";
$areanames{en}->{61256501} = "Lismore";
$areanames{en}->{61256502} = "Maclean";
$areanames{en}->{61256503} = "Mallanganee";
$areanames{en}->{61256504} = "Mullumbimby";
$areanames{en}->{61256505} = "Murwillumbah";
$areanames{en}->{61256506} = "Nimbin";
$areanames{en}->{61256507} = "Rappville";
$areanames{en}->{61256508} = "Tabulam";
$areanames{en}->{61256509} = "Thora";
$areanames{en}->{61256510} = "Tyalgum";
$areanames{en}->{61256511} = "Tyringham";
$areanames{en}->{61256512} = "Ulong";
$areanames{en}->{61256513} = "Urbenville";
$areanames{en}->{61256514} = "Whiporie";
$areanames{en}->{61256515} = "Wiangaree";
$areanames{en}->{61256516} = "Woodburn";
$areanames{en}->{61256517} = "Woodenbong";
$areanames{en}->{61256518} = "Wooli";
$areanames{en}->{61256519} = "Dorrigo";
$areanames{en}->{61256520} = "Dyraaba";
$areanames{en}->{61256521} = "Ettrick";
$areanames{en}->{61256522} = "Glenreagh";
$areanames{en}->{61256523} = "Grafton";
$areanames{en}->{61256524} = "Hernani";
$areanames{en}->{61256525} = "Kyogle";
$areanames{en}->{61256526} = "Lawrence";
$areanames{en}->{61256527} = "Leeville";
$areanames{en}->{61256528} = "Lismore";
$areanames{en}->{61256529} = "Maclean";
$areanames{en}->{61256530} = "Mallanganee";
$areanames{en}->{61256531} = "Mullumbimby";
$areanames{en}->{61256532} = "Murwillumbah";
$areanames{en}->{61256533} = "Nimbin";
$areanames{en}->{61256534} = "Rappville";
$areanames{en}->{61256535} = "Tabulam";
$areanames{en}->{61256536} = "Thora";
$areanames{en}->{61256537} = "Tyalgum";
$areanames{en}->{61256538} = "Tyringham";
$areanames{en}->{61256539} = "Ulong";
$areanames{en}->{61256540} = "Urbenville";
$areanames{en}->{61256541} = "Whiporie";
$areanames{en}->{61256542} = "Wiangaree";
$areanames{en}->{61256543} = "Woodburn";
$areanames{en}->{61256544} = "Woodenbong";
$areanames{en}->{61256545} = "Wooli";
$areanames{en}->{61256546} = "Ballina";
$areanames{en}->{61256547} = "Bellingen";
$areanames{en}->{61256548} = "Bonalbo";
$areanames{en}->{61256549} = "Casino";
$areanames{en}->{61256550} = "Coffs\ Harbour";
$areanames{en}->{61256551} = "Copmanhurst";
$areanames{en}->{61256552} = "Coutts\ Crossing";
$areanames{en}->{61256553} = "Dorrigo";
$areanames{en}->{61256554} = "Dyraaba";
$areanames{en}->{61256555} = "Ettrick";
$areanames{en}->{61256556} = "Glenreagh";
$areanames{en}->{61256557} = "Grafton";
$areanames{en}->{61256558} = "Hernani";
$areanames{en}->{61256559} = "Kyogle";
$areanames{en}->{61256560} = "Lawrence";
$areanames{en}->{61256561} = "Leeville";
$areanames{en}->{61256562} = "Lismore";
$areanames{en}->{61256563} = "Maclean";
$areanames{en}->{61256564} = "Mallanganee";
$areanames{en}->{61256565} = "Mullumbimby";
$areanames{en}->{61256566} = "Murwillumbah";
$areanames{en}->{61256567} = "Nimbin";
$areanames{en}->{61256568} = "Rappville";
$areanames{en}->{61256569} = "Tabulam";
$areanames{en}->{61256570} = "Thora";
$areanames{en}->{61256571} = "Tyalgum";
$areanames{en}->{61256572} = "Tyringham";
$areanames{en}->{61256573} = "Ulong";
$areanames{en}->{61256574} = "Urbenville";
$areanames{en}->{61256575} = "Whiporie";
$areanames{en}->{61256576} = "Wiangaree";
$areanames{en}->{61256577} = "Woodburn";
$areanames{en}->{61256578} = "Woodenbong";
$areanames{en}->{61256579} = "Wooli";
$areanames{en}->{61256580} = "Ballina";
$areanames{en}->{61256581} = "Bellingen";
$areanames{en}->{61256582} = "Bonalbo";
$areanames{en}->{61256583} = "Casino";
$areanames{en}->{61256584} = "Coffs\ Harbour";
$areanames{en}->{61256585} = "Copmanhurst";
$areanames{en}->{61256586} = "Coutts\ Crossing";
$areanames{en}->{61256587} = "Dorrigo";
$areanames{en}->{61256588} = "Dyraaba";
$areanames{en}->{61256589} = "Ettrick";
$areanames{en}->{61256590} = "Glenreagh";
$areanames{en}->{61256591} = "Grafton";
$areanames{en}->{61256592} = "Hernani";
$areanames{en}->{61256593} = "Kyogle";
$areanames{en}->{61256594} = "Lawrence";
$areanames{en}->{61256595} = "Leeville";
$areanames{en}->{61256596} = "Lismore";
$areanames{en}->{61256597} = "Maclean";
$areanames{en}->{61256598} = "Mallanganee";
$areanames{en}->{61256599} = "Mullumbimby";
$areanames{en}->{61256600} = "Murwillumbah";
$areanames{en}->{61256601} = "Nimbin";
$areanames{en}->{61256602} = "Rappville";
$areanames{en}->{61256603} = "Tabulam";
$areanames{en}->{61256604} = "Thora";
$areanames{en}->{61256605} = "Tyalgum";
$areanames{en}->{61256606} = "Tyringham";
$areanames{en}->{61256607} = "Ulong";
$areanames{en}->{61256608} = "Urbenville";
$areanames{en}->{61256609} = "Whiporie";
$areanames{en}->{61256610} = "Wiangaree";
$areanames{en}->{61256611} = "Woodburn";
$areanames{en}->{61256612} = "Woodenbong";
$areanames{en}->{61256613} = "Wooli";
$areanames{en}->{61256614} = "Ballina";
$areanames{en}->{61256615} = "Bellingen";
$areanames{en}->{61256616} = "Bonalbo";
$areanames{en}->{61256617} = "Casino";
$areanames{en}->{61256618} = "Coffs\ Harbour";
$areanames{en}->{61256619} = "Copmanhurst";
$areanames{en}->{61256620} = "Coutts\ Crossing";
$areanames{en}->{61256621} = "Dorrigo";
$areanames{en}->{61256622} = "Dyraaba";
$areanames{en}->{61256623} = "Ettrick";
$areanames{en}->{61256624} = "Glenreagh";
$areanames{en}->{61256625} = "Grafton";
$areanames{en}->{61256626} = "Hernani";
$areanames{en}->{61256627} = "Kyogle";
$areanames{en}->{61256628} = "Lawrence";
$areanames{en}->{61256629} = "Leeville";
$areanames{en}->{61256630} = "Lismore";
$areanames{en}->{61256631} = "Maclean";
$areanames{en}->{61256632} = "Mallanganee";
$areanames{en}->{61256633} = "Mullumbimby";
$areanames{en}->{61256634} = "Murwillumbah";
$areanames{en}->{61256635} = "Nimbin";
$areanames{en}->{61256636} = "Rappville";
$areanames{en}->{61256637} = "Tabulam";
$areanames{en}->{61256638} = "Thora";
$areanames{en}->{61256639} = "Tyalgum";
$areanames{en}->{61256640} = "Tyringham";
$areanames{en}->{61256641} = "Ulong";
$areanames{en}->{61256642} = "Urbenville";
$areanames{en}->{61256643} = "Whiporie";
$areanames{en}->{61256644} = "Wiangaree";
$areanames{en}->{61256645} = "Woodburn";
$areanames{en}->{61256646} = "Woodenbong";
$areanames{en}->{61256647} = "Wooli";
$areanames{en}->{61256648} = "Murwillumbah";
$areanames{en}->{61256660} = "Ballina";
$areanames{en}->{61256661} = "Ballina";
$areanames{en}->{61256662} = "Ballina";
$areanames{en}->{61256663} = "Ballina";
$areanames{en}->{61256664} = "Ballina";
$areanames{en}->{61256665} = "Coffs\ Harbour";
$areanames{en}->{61256666} = "Coffs\ Harbour";
$areanames{en}->{61256667} = "Coffs\ Harbour";
$areanames{en}->{61256668} = "Lismore";
$areanames{en}->{61256981} = "Lismore";
$areanames{en}->{61256982} = "Lismore";
$areanames{en}->{61256983} = "Lismore";
$areanames{en}->{61256984} = "Lismore";
$areanames{en}->{61256985} = "Coffs\ Harbour";
$areanames{en}->{61256986} = "Coffs\ Harbour";
$areanames{en}->{61256987} = "Glenreagh";
$areanames{en}->{61256988} = "Glenreagh";
$areanames{en}->{61256989} = "Glenreagh";
$areanames{en}->{61256990} = "Mullumbimby";
$areanames{en}->{61256991} = "Bonalbo";
$areanames{en}->{61256992} = "Bonalbo";
$areanames{en}->{61256993} = "Rappville";
$areanames{en}->{61256994} = "Rappville";
$areanames{en}->{61256995} = "Tabulam";
$areanames{en}->{61256996} = "Tabulam";
$areanames{en}->{61256997} = "Hernani";
$areanames{en}->{61256998} = "Hernani";
$areanames{en}->{61256999} = "Lismore";
$areanames{en}->{61257000} = "Bohena";
$areanames{en}->{612570001} = "Aberfoyle";
$areanames{en}->{612570007} = "Armidale";
$areanames{en}->{61257001} = "Burren\ Junction";
$areanames{en}->{612570011} = "Baan\ Baa";
$areanames{en}->{612570019} = "Banoon";
$areanames{en}->{61257002} = "Cuttabri";
$areanames{en}->{612570021} = "Cuttabri\/Barraba\/Cuttabri\/Cuttabri\/Cuttabri\/Cuttabri\/Barwick";
$areanames{en}->{612570022} = "Cuttabri\/Barraba\/Cuttabri\/Cuttabri\/Cuttabri\/Cuttabri\/Barwick";
$areanames{en}->{612570024} = "Barraba";
$areanames{en}->{612570029} = "Barwick";
$areanames{en}->{61257003} = "Narrabri";
$areanames{en}->{612570034} = "Bellata";
$areanames{en}->{612570040} = "Pilliga";
$areanames{en}->{612570041} = "Pilliga\/Ben\ Lomond\/Pilliga\/Pilliga\/Tamworth\/Pilliga\/Bendemeer";
$areanames{en}->{612570042} = "Pilliga\/Ben\ Lomond\/Pilliga\/Pilliga\/Tamworth\/Pilliga\/Bendemeer";
$areanames{en}->{612570043} = "Pilliga";
$areanames{en}->{612570044} = "Ben\ Lomond";
$areanames{en}->{612570045} = "Pilliga";
$areanames{en}->{612570046} = "Pilliga";
$areanames{en}->{612570047} = "Tamworth";
$areanames{en}->{612570048} = "Pilliga";
$areanames{en}->{612570049} = "Bendemeer";
$areanames{en}->{61257005} = "Rowena";
$areanames{en}->{612570051} = "Rowena\/Armidale\/Rowena\/Bingara";
$areanames{en}->{612570052} = "Rowena\/Armidale\/Rowena\/Bingara";
$areanames{en}->{612570057} = "Armidale";
$areanames{en}->{612570059} = "Bingara";
$areanames{en}->{61257006} = "Spring\ Plains";
$areanames{en}->{612570061} = "Spring\ Plains\/Boggabri\/Spring\ Plains\/Spring\ Plains\/Spring\ Plains\/Spring\ Plains\/Bohena";
$areanames{en}->{612570062} = "Spring\ Plains\/Boggabri\/Spring\ Plains\/Spring\ Plains\/Spring\ Plains\/Spring\ Plains\/Bohena";
$areanames{en}->{612570064} = "Boggabri";
$areanames{en}->{612570069} = "Bohena";
$areanames{en}->{61257007} = "Wee\ Waa";
$areanames{en}->{612570074} = "Boomi";
$areanames{en}->{612570077} = "Boorolong";
$areanames{en}->{61257008} = "Yarrie\ Lake";
$areanames{en}->{612570081} = "Breeza";
$areanames{en}->{612570087} = "Bundarra";
$areanames{en}->{61257009} = "Bendemeer";
$areanames{en}->{612570095} = "Bundella";
$areanames{en}->{612570098} = "Bunnor";
$areanames{en}->{612570099} = "Burren\ Junction";
$areanames{en}->{61257010} = "Currabubula";
$areanames{en}->{612570105} = "Careunga";
$areanames{en}->{612570108} = "Caroda";
$areanames{en}->{612570109} = "Collarenebri";
$areanames{en}->{61257011} = "Limbri";
$areanames{en}->{612570115} = "Coolatai";
$areanames{en}->{612570118} = "Copeton\ Dam";
$areanames{en}->{612570119} = "Craigleigh";
$areanames{en}->{61257012} = "Nundle";
$areanames{en}->{612570124} = "Nundle\/Croppa\ Creek\/Curlewis";
$areanames{en}->{612570125} = "Nundle\/Croppa\ Creek\/Curlewis";
$areanames{en}->{612570128} = "Croppa\ Creek";
$areanames{en}->{612570129} = "Curlewis";
$areanames{en}->{61257013} = "Ogunbil";
$areanames{en}->{612570135} = "Currabubula";
$areanames{en}->{612570138} = "Cuttabri";
$areanames{en}->{612570139} = "Deepwater";
$areanames{en}->{612570140} = "Somerton";
$areanames{en}->{612570141} = "Somerton";
$areanames{en}->{612570142} = "Somerton";
$areanames{en}->{612570143} = "Somerton";
$areanames{en}->{612570144} = "Somerton\/Delungra\/Drake";
$areanames{en}->{612570145} = "Somerton\/Delungra\/Drake";
$areanames{en}->{612570146} = "Somerton\/Delungra\/Drake";
$areanames{en}->{612570147} = "Somerton";
$areanames{en}->{612570148} = "Delungra";
$areanames{en}->{612570149} = "Drake";
$areanames{en}->{61257015} = "Tamworth";
$areanames{en}->{612570157} = "Ebor";
$areanames{en}->{612570158} = "Elcombe";
$areanames{en}->{612570159} = "Emmaville";
$areanames{en}->{61257016} = "Aberfoyle";
$areanames{en}->{61257017} = "Armidale";
$areanames{en}->{61257018} = "Boorolong";
$areanames{en}->{61257019} = "Ebor";
$areanames{en}->{61257020} = "Guyra";
$areanames{en}->{61257021} = "Ingleba";
$areanames{en}->{61257022} = "Kingstown";
$areanames{en}->{61257023} = "Marple";
$areanames{en}->{61257024} = "Moona\ Plains";
$areanames{en}->{61257025} = "Nowendoc";
$areanames{en}->{61257026} = "Oban";
$areanames{en}->{61257027} = "Tenterden";
$areanames{en}->{61257028} = "Uralla";
$areanames{en}->{61257029} = "Walcha";
$areanames{en}->{61257030} = "Walcha\ Road";
$areanames{en}->{61257031} = "Wollomombi";
$areanames{en}->{61257032} = "Yarrowitch";
$areanames{en}->{61257033} = "Banoon";
$areanames{en}->{61257034} = "Barraba";
$areanames{en}->{61257035} = "Caroda";
$areanames{en}->{61257036} = "Halls\ Creek";
$areanames{en}->{61257037} = "Manilla";
$areanames{en}->{61257038} = "Plumthorpe";
$areanames{en}->{61257039} = "Upper\ Horton";
$areanames{en}->{61257040} = "Barwick";
$areanames{en}->{61257041} = "Ben\ Lomond";
$areanames{en}->{61257042} = "Deepwater";
$areanames{en}->{61257043} = "Drake";
$areanames{en}->{61257044} = "Emmaville";
$areanames{en}->{61257045} = "Glen\ Elgin";
$areanames{en}->{61257046} = "Glen\ Innes";
$areanames{en}->{61257047} = "Glencoe";
$areanames{en}->{61257048} = "Pinkett";
$areanames{en}->{61257049} = "Rocky\ Creek";
$areanames{en}->{61257050} = "Sandy\ Flat";
$areanames{en}->{61257051} = "Tenterfield";
$areanames{en}->{61257052} = "Wellingrove";
$areanames{en}->{61257053} = "Boggabri";
$areanames{en}->{61257054} = "Breeza";
$areanames{en}->{61257055} = "Bundella";
$areanames{en}->{61257056} = "Curlewis";
$areanames{en}->{61257057} = "Goolhi";
$areanames{en}->{61257058} = "Gunnedah";
$areanames{en}->{61257059} = "Kelvin";
$areanames{en}->{61257060} = "Mullaley";
$areanames{en}->{61257061} = "Pine\ Ridge";
$areanames{en}->{61257062} = "Quirindi";
$areanames{en}->{61257063} = "Tambar\ Springs";
$areanames{en}->{61257064} = "Willow\ Tree";
$areanames{en}->{61257065} = "Bingara";
$areanames{en}->{61257066} = "Bundarra";
$areanames{en}->{61257067} = "Coolatai";
$areanames{en}->{61257068} = "Copeton\ Dam";
$areanames{en}->{61257069} = "Craigleigh";
$areanames{en}->{61257070} = "Delungra";
$areanames{en}->{61257071} = "Elcombe";
$areanames{en}->{61257072} = "Frazers\ Creek";
$areanames{en}->{61257073} = "Graman";
$areanames{en}->{61257074} = "Gunyerwarildi";
$areanames{en}->{61257075} = "Inverell";
$areanames{en}->{61257076} = "Nullamanna";
$areanames{en}->{61257077} = "Oakey\ Creek";
$areanames{en}->{61257078} = "Tingha";
$areanames{en}->{61257079} = "Warialda";
$areanames{en}->{61257080} = "Boomi";
$areanames{en}->{61257081} = "Bunnor";
$areanames{en}->{61257082} = "Careunga";
$areanames{en}->{61257083} = "Collarenebri";
$areanames{en}->{61257084} = "Croppa\ Creek";
$areanames{en}->{61257085} = "Garah";
$areanames{en}->{61257086} = "Gundabloui";
$areanames{en}->{61257087} = "Gurley";
$areanames{en}->{61257088} = "Mirriadool";
$areanames{en}->{61257089} = "Moree";
$areanames{en}->{61257090} = "Mungindi";
$areanames{en}->{61257091} = "Pallamallawa";
$areanames{en}->{61257092} = "Weemelah";
$areanames{en}->{61257093} = "Wenna";
$areanames{en}->{61257094} = "Baan\ Baa";
$areanames{en}->{61257095} = "Bellata";
$areanames{en}->{61257096} = "Bohena";
$areanames{en}->{61257097} = "Burren\ Junction";
$areanames{en}->{61257098} = "Cuttabri";
$areanames{en}->{61257099} = "Narrabri";
$areanames{en}->{61257100} = "Pilliga";
$areanames{en}->{61257101} = "Rowena";
$areanames{en}->{61257102} = "Spring\ Plains";
$areanames{en}->{61257103} = "Wee\ Waa";
$areanames{en}->{61257104} = "Yarrie\ Lake";
$areanames{en}->{61257105} = "Bendemeer";
$areanames{en}->{61257106} = "Currabubula";
$areanames{en}->{61257107} = "Limbri";
$areanames{en}->{61257108} = "Nundle";
$areanames{en}->{61257109} = "Ogunbil";
$areanames{en}->{61257110} = "Somerton";
$areanames{en}->{61257111} = "Tamworth";
$areanames{en}->{61257112} = "Bundarra";
$areanames{en}->{612571125} = "Frazers\ Creek";
$areanames{en}->{612571128} = "Garah";
$areanames{en}->{612571129} = "Glen\ Elgin";
$areanames{en}->{61257113} = "Armidale";
$areanames{en}->{61257114} = "Armidale";
$areanames{en}->{61257115} = "Armidale";
$areanames{en}->{61257116} = "Ogunbil";
$areanames{en}->{61257117} = "Ogunbil";
$areanames{en}->{61257118} = "Limbri";
$areanames{en}->{61257119} = "Limbri";
$areanames{en}->{6125712} = "Tamworth";
$areanames{en}->{61257127} = "Nundle";
$areanames{en}->{61257128} = "Nundle";
$areanames{en}->{61257130} = "Armidale";
$areanames{en}->{61257131} = "Uralla";
$areanames{en}->{61257132} = "Gunnedah";
$areanames{en}->{61257133} = "Inverell";
$areanames{en}->{61257134} = "Moree";
$areanames{en}->{61257135} = "Tamworth";
$areanames{en}->{61257136} = "Armidale";
$areanames{en}->{61257137} = "Armidale";
$areanames{en}->{61257138} = "Guyra";
$areanames{en}->{61257139} = "Guyra";
$areanames{en}->{61257140} = "Uralla";
$areanames{en}->{61257141} = "Uralla";
$areanames{en}->{61257142} = "Barwick";
$areanames{en}->{61257143} = "Barwick";
$areanames{en}->{61257144} = "Ben\ Lomond";
$areanames{en}->{61257145} = "Ben\ Lomond";
$areanames{en}->{61257146} = "Bendemeer";
$areanames{en}->{61257147} = "Bendemeer";
$areanames{en}->{61257148} = "Emmaville";
$areanames{en}->{61257149} = "Emmaville";
$areanames{en}->{61257150} = "Glen\ Innes";
$areanames{en}->{61257151} = "Glen\ Innes";
$areanames{en}->{61257152} = "Glencoe";
$areanames{en}->{61257153} = "Glencoe";
$areanames{en}->{61257154} = "Breeza";
$areanames{en}->{61257155} = "Breeza";
$areanames{en}->{61257156} = "Gunnedah";
$areanames{en}->{61257157} = "Gunnedah";
$areanames{en}->{61257158} = "Kelvin";
$areanames{en}->{61257159} = "Kelvin";
$areanames{en}->{61257160} = "Quirindi";
$areanames{en}->{61257161} = "Quirindi";
$areanames{en}->{61257162} = "Willow\ Tree";
$areanames{en}->{61257163} = "Willow\ Tree";
$areanames{en}->{61257164} = "Currabubula";
$areanames{en}->{61257165} = "Currabubula";
$areanames{en}->{61257166} = "Croppa\ Creek";
$areanames{en}->{61257167} = "Croppa\ Creek";
$areanames{en}->{61257168} = "Gurley";
$areanames{en}->{61257169} = "Gurley";
$areanames{en}->{61257170} = "Moree";
$areanames{en}->{61257171} = "Moree";
$areanames{en}->{61257172} = "Yarrie\ Lake";
$areanames{en}->{61257173} = "Yarrie\ Lake";
$areanames{en}->{61257174} = "Wee\ Waa";
$areanames{en}->{61257175} = "Wee\ Waa";
$areanames{en}->{61257176} = "Narrabri";
$areanames{en}->{61257177} = "Narrabri";
$areanames{en}->{61257178} = "Bohena";
$areanames{en}->{61257179} = "Bohena";
$areanames{en}->{61257180} = "Bellata";
$areanames{en}->{61257181} = "Bellata";
$areanames{en}->{61257182} = "Somerton";
$areanames{en}->{61257183} = "Somerton";
$areanames{en}->{61257184} = "Careunga";
$areanames{en}->{61257185} = "Careunga";
$areanames{en}->{61257186} = "Deepwater";
$areanames{en}->{61257187} = "Deepwater";
$areanames{en}->{61257188} = "Moree";
$areanames{en}->{61257189} = "Narrabri";
$areanames{en}->{61257190} = "Tamworth";
$areanames{en}->{61257191} = "Tamworth";
$areanames{en}->{61257192} = "Bundarra";
$areanames{en}->{61257193} = "Bundarra";
$areanames{en}->{61257194} = "Bingara";
$areanames{en}->{61257195} = "Bingara";
$areanames{en}->{61257196} = "Coolatai";
$areanames{en}->{61257197} = "Coolatai";
$areanames{en}->{61257198} = "Copeton\ Dam";
$areanames{en}->{61257199} = "Copeton\ Dam";
$areanames{en}->{61257200} = "Craigleigh";
$areanames{en}->{61257201} = "Craigleigh";
$areanames{en}->{61257202} = "Delungra";
$areanames{en}->{61257203} = "Delungra";
$areanames{en}->{61257204} = "Elcombe";
$areanames{en}->{61257205} = "Elcombe";
$areanames{en}->{61257206} = "Frazers\ Creek";
$areanames{en}->{61257207} = "Frazers\ Creek";
$areanames{en}->{61257208} = "Graman";
$areanames{en}->{61257209} = "Graman";
$areanames{en}->{61257210} = "Gunyerwarildi";
$areanames{en}->{61257211} = "Gunyerwarildi";
$areanames{en}->{61257212} = "Inverell";
$areanames{en}->{61257213} = "Inverell";
$areanames{en}->{61257214} = "Nullamanna";
$areanames{en}->{61257215} = "Nullamanna";
$areanames{en}->{61257216} = "Oakey\ Creek";
$areanames{en}->{61257217} = "Oakey\ Creek";
$areanames{en}->{61257218} = "Tingha";
$areanames{en}->{61257219} = "Tingha";
$areanames{en}->{61257220} = "Warialda";
$areanames{en}->{61257221} = "Warialda";
$areanames{en}->{61257222} = "Ingleba";
$areanames{en}->{61257223} = "Ingleba";
$areanames{en}->{61257224} = "Moona\ Plains";
$areanames{en}->{61257225} = "Moona\ Plains";
$areanames{en}->{61257226} = "Walcha";
$areanames{en}->{61257227} = "Walcha";
$areanames{en}->{61257228} = "Walcha\ Road";
$areanames{en}->{61257229} = "Walcha\ Road";
$areanames{en}->{61257230} = "Banoon";
$areanames{en}->{61257231} = "Banoon";
$areanames{en}->{61257232} = "Barraba";
$areanames{en}->{61257233} = "Barraba";
$areanames{en}->{61257234} = "Caroda";
$areanames{en}->{61257235} = "Caroda";
$areanames{en}->{61257236} = "Halls\ Creek";
$areanames{en}->{61257237} = "Halls\ Creek";
$areanames{en}->{61257238} = "Manilla";
$areanames{en}->{61257239} = "Manilla";
$areanames{en}->{61257240} = "Plumthorpe";
$areanames{en}->{61257241} = "Plumthorpe";
$areanames{en}->{61257242} = "Upper\ Horton";
$areanames{en}->{61257243} = "Upper\ Horton";
$areanames{en}->{61257244} = "Boomi";
$areanames{en}->{61257245} = "Boomi";
$areanames{en}->{61257246} = "Bunnor";
$areanames{en}->{61257247} = "Bunnor";
$areanames{en}->{61257248} = "Garah";
$areanames{en}->{61257249} = "Garah";
$areanames{en}->{61257250} = "Mirriadool";
$areanames{en}->{61257251} = "Mirriadool";
$areanames{en}->{61257252} = "Pallamallawa";
$areanames{en}->{61257253} = "Pallamallawa";
$areanames{en}->{61257254} = "Baan\ Baa";
$areanames{en}->{61257255} = "Baan\ Baa";
$areanames{en}->{61257256} = "Burren\ Junction";
$areanames{en}->{61257257} = "Burren\ Junction";
$areanames{en}->{61257258} = "Cuttabri";
$areanames{en}->{61257259} = "Cuttabri";
$areanames{en}->{61257260} = "Rowena";
$areanames{en}->{61257261} = "Rowena";
$areanames{en}->{61257262} = "Spring\ Plains";
$areanames{en}->{61257263} = "Spring\ Plains";
$areanames{en}->{61257264} = "Boggabri";
$areanames{en}->{61257265} = "Boggabri";
$areanames{en}->{61257266} = "Bundella";
$areanames{en}->{61257267} = "Bundella";
$areanames{en}->{61257268} = "Curlewis";
$areanames{en}->{61257269} = "Curlewis";
$areanames{en}->{61257270} = "Goolhi";
$areanames{en}->{61257271} = "Goolhi";
$areanames{en}->{61257272} = "Mullaley";
$areanames{en}->{61257273} = "Mullaley";
$areanames{en}->{61257274} = "Pine\ Ridge";
$areanames{en}->{61257275} = "Pine\ Ridge";
$areanames{en}->{61257276} = "Tambar\ Springs";
$areanames{en}->{61257277} = "Tambar\ Springs";
$areanames{en}->{61257278} = "Aberfoyle";
$areanames{en}->{61257279} = "Aberfoyle";
$areanames{en}->{61257280} = "Boorolong";
$areanames{en}->{61257281} = "Boorolong";
$areanames{en}->{61257282} = "Ebor";
$areanames{en}->{61257283} = "Ebor";
$areanames{en}->{61257284} = "Tenterden";
$areanames{en}->{61257285} = "Tenterden";
$areanames{en}->{61257286} = "Kingstown";
$areanames{en}->{61257287} = "Kingstown";
$areanames{en}->{61257288} = "Marple";
$areanames{en}->{61257289} = "Marple";
$areanames{en}->{61257290} = "Oban";
$areanames{en}->{61257291} = "Oban";
$areanames{en}->{61257292} = "Wollomombi";
$areanames{en}->{61257293} = "Wollomombi";
$areanames{en}->{61257294} = "Drake";
$areanames{en}->{61257295} = "Drake";
$areanames{en}->{61257296} = "Glen\ Elgin";
$areanames{en}->{61257297} = "Glen\ Elgin";
$areanames{en}->{61257298} = "Pinkett";
$areanames{en}->{61257299} = "Pinkett";
$areanames{en}->{61257300} = "Sandy\ Flat";
$areanames{en}->{61257301} = "Sandy\ Flat";
$areanames{en}->{61257302} = "Tenterfield";
$areanames{en}->{61257303} = "Tenterfield";
$areanames{en}->{61257304} = "Wellingrove";
$areanames{en}->{61257305} = "Wellingrove";
$areanames{en}->{61257306} = "Collarenebri";
$areanames{en}->{61257307} = "Collarenebri";
$areanames{en}->{61257308} = "Gundabloui";
$areanames{en}->{61257309} = "Gundabloui";
$areanames{en}->{61257310} = "Mungindi";
$areanames{en}->{61257311} = "Mungindi";
$areanames{en}->{61257312} = "Nowendoc";
$areanames{en}->{61257313} = "Nowendoc";
$areanames{en}->{61257314} = "Weemelah";
$areanames{en}->{61257315} = "Weemelah";
$areanames{en}->{61257316} = "Wenna";
$areanames{en}->{61257317} = "Wenna";
$areanames{en}->{61257318} = "Tamworth";
$areanames{en}->{61257319} = "Tamworth";
$areanames{en}->{61257320} = "Tamworth";
$areanames{en}->{61257321} = "Inverell";
$areanames{en}->{61257322} = "Armidale";
$areanames{en}->{61257323} = "Tamworth";
$areanames{en}->{61257324} = "Armidale";
$areanames{en}->{61257325} = "Tamworth";
$areanames{en}->{61257326} = "Inverell";
$areanames{en}->{61257327} = "Armidale";
$areanames{en}->{61257328} = "Tamworth";
$areanames{en}->{61257329} = "Wollomombi";
$areanames{en}->{61257330} = "Guyra";
$areanames{en}->{61257331} = "Glen\ Innes";
$areanames{en}->{61257332} = "Moree";
$areanames{en}->{61257333} = "Narrabri";
$areanames{en}->{61257334} = "Tamworth";
$areanames{en}->{61257335} = "Armidale";
$areanames{en}->{61257336} = "Glen\ Elgin";
$areanames{en}->{61257337} = "Gunnedah";
$areanames{en}->{61257338} = "Narrabri";
$areanames{en}->{612573390} = "Glen\ Innes";
$areanames{en}->{612573391} = "Glencoe";
$areanames{en}->{612573392} = "Goolhi";
$areanames{en}->{612573393} = "Graman";
$areanames{en}->{612573394} = "Gundabloui";
$areanames{en}->{612573395} = "Gunnedah";
$areanames{en}->{612573396} = "Gunyerwarildi";
$areanames{en}->{612573397} = "Gurley";
$areanames{en}->{612573398} = "Guyra";
$areanames{en}->{612573399} = "Halls\ Creek";
$areanames{en}->{612573400} = "Ingleba";
$areanames{en}->{612573401} = "Inverell";
$areanames{en}->{612573402} = "Kelvin";
$areanames{en}->{612573403} = "Kingstown";
$areanames{en}->{612573404} = "Limbri";
$areanames{en}->{612573405} = "Manilla";
$areanames{en}->{612573406} = "Marple";
$areanames{en}->{612573407} = "Mirriadool";
$areanames{en}->{612573408} = "Moona\ Plains";
$areanames{en}->{612573409} = "Moree";
$areanames{en}->{612573410} = "Mullaley";
$areanames{en}->{612573411} = "Mungindi";
$areanames{en}->{612573412} = "Narrabri";
$areanames{en}->{612573413} = "Nowendoc";
$areanames{en}->{612573414} = "Nullamanna";
$areanames{en}->{612573415} = "Nundle";
$areanames{en}->{612573416} = "Oakey\ Creek";
$areanames{en}->{612573417} = "Oban";
$areanames{en}->{612573418} = "Ogunbil";
$areanames{en}->{612573419} = "Pallamallawa";
$areanames{en}->{612573420} = "Pilliga";
$areanames{en}->{612573421} = "Pine\ Ridge";
$areanames{en}->{612573422} = "Pinkett";
$areanames{en}->{612573423} = "Plumthorpe";
$areanames{en}->{612573424} = "Quirindi";
$areanames{en}->{612573425} = "Rocky\ Creek";
$areanames{en}->{612573426} = "Rowena";
$areanames{en}->{612573427} = "Sandy\ Flat";
$areanames{en}->{612573428} = "Somerton";
$areanames{en}->{612573429} = "Spring\ Plains";
$areanames{en}->{612573430} = "Tambar\ Springs";
$areanames{en}->{612573431} = "Tamworth";
$areanames{en}->{612573432} = "Tenterden";
$areanames{en}->{612573433} = "Tenterfield";
$areanames{en}->{612573434} = "Tingha";
$areanames{en}->{612573435} = "Upper\ Horton";
$areanames{en}->{612573436} = "Uralla";
$areanames{en}->{612573437} = "Walcha";
$areanames{en}->{612573438} = "Walcha\ Road";
$areanames{en}->{612573439} = "Warialda";
$areanames{en}->{612573440} = "Wee\ Waa";
$areanames{en}->{612573441} = "Weemelah";
$areanames{en}->{612573442} = "Wellingrove";
$areanames{en}->{612573443} = "Wenna";
$areanames{en}->{612573444} = "Willow\ Tree";
$areanames{en}->{612573445} = "Wollomombi";
$areanames{en}->{612573446} = "Yarrie\ Lake";
$areanames{en}->{612573447} = "Yarrowitch";
$areanames{en}->{612573448} = "Aberfoyle";
$areanames{en}->{612573449} = "Armidale";
$areanames{en}->{61257345} = "Inverell";
$areanames{en}->{61257346} = "Barraba";
$areanames{en}->{61257347} = "Barwick";
$areanames{en}->{61257348} = "Bellata";
$areanames{en}->{61257349} = "Ben\ Lomond";
$areanames{en}->{61257350} = "Bendemeer";
$areanames{en}->{61257351} = "Bingara";
$areanames{en}->{61257352} = "Boggabri";
$areanames{en}->{61257353} = "Bohena";
$areanames{en}->{61257354} = "Boorolong";
$areanames{en}->{61257355} = "Breeza";
$areanames{en}->{61257356} = "Bundarra";
$areanames{en}->{61257357} = "Bundella";
$areanames{en}->{61257358} = "Burren\ Junction";
$areanames{en}->{61257359} = "Coolatai";
$areanames{en}->{61257360} = "Craigleigh";
$areanames{en}->{61257361} = "Currabubula";
$areanames{en}->{61257362} = "Cuttabri";
$areanames{en}->{61257363} = "Deepwater";
$areanames{en}->{61257364} = "Delungra";
$areanames{en}->{61257365} = "Ebor";
$areanames{en}->{61257366} = "Elcombe";
$areanames{en}->{61257367} = "Emmaville";
$areanames{en}->{61257368} = "Frazers\ Creek";
$areanames{en}->{61257369} = "Glen\ Elgin";
$areanames{en}->{61257370} = "Glencoe";
$areanames{en}->{61257371} = "Goolhi";
$areanames{en}->{61257372} = "Graman";
$areanames{en}->{61257373} = "Gunyerwarildi";
$areanames{en}->{61257374} = "Guyra";
$areanames{en}->{61257375} = "Halls\ Creek";
$areanames{en}->{61257376} = "Ingleba";
$areanames{en}->{61257377} = "Kelvin";
$areanames{en}->{61257378} = "Limbri";
$areanames{en}->{61257379} = "Manilla";
$areanames{en}->{61257380} = "Marple";
$areanames{en}->{61257381} = "Moona\ Plains";
$areanames{en}->{61257382} = "Mullaley";
$areanames{en}->{61257383} = "Nowendoc";
$areanames{en}->{61257384} = "Nullamanna";
$areanames{en}->{61257385} = "Nundle";
$areanames{en}->{61257386} = "Oakey\ Creek";
$areanames{en}->{61257387} = "Ogunbil";
$areanames{en}->{61257388} = "Pilliga";
$areanames{en}->{61257389} = "Pine\ Ridge";
$areanames{en}->{61257390} = "Pinkett";
$areanames{en}->{61257391} = "Plumthorpe";
$areanames{en}->{61257392} = "Rowena";
$areanames{en}->{61257393} = "Sandy\ Flat";
$areanames{en}->{61257394} = "Somerton";
$areanames{en}->{61257395} = "Spring\ Plains";
$areanames{en}->{61257396} = "Tambar\ Springs";
$areanames{en}->{61257397} = "Tenterden";
$areanames{en}->{61257398} = "Upper\ Horton";
$areanames{en}->{61257399} = "Uralla";
$areanames{en}->{61257400} = "Walcha\ Road";
$areanames{en}->{61257401} = "Wellingrove";
$areanames{en}->{61257402} = "Willow\ Tree";
$areanames{en}->{61257403} = "Wollomombi";
$areanames{en}->{61257404} = "Yarrie\ Lake";
$areanames{en}->{61257405} = "Yarrowitch";
$areanames{en}->{61257406} = "Quirindi";
$areanames{en}->{61257407} = "Aberfoyle";
$areanames{en}->{61257408} = "Moree";
$areanames{en}->{612574090} = "Baan\ Baa";
$areanames{en}->{612574091} = "Banoon";
$areanames{en}->{612574092} = "Barraba";
$areanames{en}->{612574093} = "Barwick";
$areanames{en}->{612574094} = "Bellata";
$areanames{en}->{612574095} = "Ben\ Lomond";
$areanames{en}->{612574096} = "Bendemeer";
$areanames{en}->{612574097} = "Bingara";
$areanames{en}->{612574098} = "Boggabri";
$areanames{en}->{612574099} = "Bohena";
$areanames{en}->{612574100} = "Boomi";
$areanames{en}->{612574101} = "Boorolong";
$areanames{en}->{612574102} = "Breeza";
$areanames{en}->{612574103} = "Bundarra";
$areanames{en}->{612574104} = "Bundella";
$areanames{en}->{612574105} = "Bunnor";
$areanames{en}->{612574106} = "Burren\ Junction";
$areanames{en}->{612574107} = "Careunga";
$areanames{en}->{612574108} = "Caroda";
$areanames{en}->{612574109} = "Collarenebri";
$areanames{en}->{612574110} = "Coolatai";
$areanames{en}->{612574111} = "Copeton\ Dam";
$areanames{en}->{612574112} = "Craigleigh";
$areanames{en}->{612574113} = "Croppa\ Creek";
$areanames{en}->{612574114} = "Curlewis";
$areanames{en}->{612574115} = "Currabubula";
$areanames{en}->{612574116} = "Cuttabri";
$areanames{en}->{612574117} = "Deepwater";
$areanames{en}->{612574118} = "Delungra";
$areanames{en}->{612574119} = "Drake";
$areanames{en}->{612574120} = "Ebor";
$areanames{en}->{612574121} = "Elcombe";
$areanames{en}->{612574122} = "Emmaville";
$areanames{en}->{612574123} = "Frazers\ Creek";
$areanames{en}->{612574124} = "Garah";
$areanames{en}->{612574125} = "Glen\ Elgin";
$areanames{en}->{612574126} = "Glen\ Innes";
$areanames{en}->{612574127} = "Glencoe";
$areanames{en}->{612574128} = "Goolhi";
$areanames{en}->{612574129} = "Graman";
$areanames{en}->{612574130} = "Gundabloui";
$areanames{en}->{612574131} = "Gunnedah";
$areanames{en}->{612574132} = "Gunyerwarildi";
$areanames{en}->{612574133} = "Gurley";
$areanames{en}->{612574134} = "Guyra";
$areanames{en}->{612574135} = "Halls\ Creek";
$areanames{en}->{612574136} = "Ingleba";
$areanames{en}->{612574137} = "Inverell";
$areanames{en}->{612574138} = "Kelvin";
$areanames{en}->{612574139} = "Kingstown";
$areanames{en}->{612574140} = "Limbri";
$areanames{en}->{612574141} = "Manilla";
$areanames{en}->{612574142} = "Marple";
$areanames{en}->{612574143} = "Mirriadool";
$areanames{en}->{612574144} = "Moona\ Plains";
$areanames{en}->{612574145} = "Moree";
$areanames{en}->{612574146} = "Mullaley";
$areanames{en}->{612574147} = "Mungindi";
$areanames{en}->{612574148} = "Narrabri";
$areanames{en}->{612574149} = "Nowendoc";
$areanames{en}->{612574150} = "Nullamanna";
$areanames{en}->{612574151} = "Nundle";
$areanames{en}->{612574152} = "Oakey\ Creek";
$areanames{en}->{612574153} = "Oban";
$areanames{en}->{612574154} = "Ogunbil";
$areanames{en}->{612574155} = "Pallamallawa";
$areanames{en}->{612574156} = "Pilliga";
$areanames{en}->{612574157} = "Pine\ Ridge";
$areanames{en}->{612574158} = "Pinkett";
$areanames{en}->{612574159} = "Plumthorpe";
$areanames{en}->{612574160} = "Quirindi";
$areanames{en}->{612574161} = "Rocky\ Creek";
$areanames{en}->{612574162} = "Rowena";
$areanames{en}->{612574163} = "Sandy\ Flat";
$areanames{en}->{612574164} = "Somerton";
$areanames{en}->{612574165} = "Spring\ Plains";
$areanames{en}->{612574166} = "Tambar\ Springs";
$areanames{en}->{612574167} = "Tamworth";
$areanames{en}->{612574168} = "Tenterden";
$areanames{en}->{612574169} = "Tenterfield";
$areanames{en}->{612574170} = "Tingha";
$areanames{en}->{612574171} = "Upper\ Horton";
$areanames{en}->{612574172} = "Uralla";
$areanames{en}->{612574173} = "Walcha";
$areanames{en}->{612574174} = "Walcha\ Road";
$areanames{en}->{612574175} = "Warialda";
$areanames{en}->{612574176} = "Wee\ Waa";
$areanames{en}->{612574177} = "Weemelah";
$areanames{en}->{612574178} = "Wellingrove";
$areanames{en}->{612574179} = "Wenna";
$areanames{en}->{612574180} = "Willow\ Tree";
$areanames{en}->{612574181} = "Wollomombi";
$areanames{en}->{612574182} = "Yarrie\ Lake";
$areanames{en}->{612574183} = "Yarrowitch";
$areanames{en}->{612574184} = "Aberfoyle";
$areanames{en}->{612574185} = "Armidale";
$areanames{en}->{612574186} = "Baan\ Baa";
$areanames{en}->{612574187} = "Banoon";
$areanames{en}->{612574188} = "Barraba";
$areanames{en}->{612574189} = "Barwick";
$areanames{en}->{61257419} = "Inverell";
$areanames{en}->{612574200} = "Bellata";
$areanames{en}->{612574201} = "Ben\ Lomond";
$areanames{en}->{612574202} = "Bendemeer";
$areanames{en}->{612574203} = "Bingara";
$areanames{en}->{612574204} = "Boggabri";
$areanames{en}->{612574205} = "Bohena";
$areanames{en}->{612574206} = "Boomi";
$areanames{en}->{612574207} = "Boorolong";
$areanames{en}->{612574208} = "Breeza";
$areanames{en}->{612574209} = "Bundarra";
$areanames{en}->{612574210} = "Bundella";
$areanames{en}->{612574211} = "Bunnor";
$areanames{en}->{612574212} = "Burren\ Junction";
$areanames{en}->{612574213} = "Careunga";
$areanames{en}->{612574214} = "Caroda";
$areanames{en}->{612574215} = "Collarenebri";
$areanames{en}->{612574216} = "Coolatai";
$areanames{en}->{612574217} = "Copeton\ Dam";
$areanames{en}->{612574218} = "Craigleigh";
$areanames{en}->{612574219} = "Croppa\ Creek";
$areanames{en}->{612574220} = "Curlewis";
$areanames{en}->{612574221} = "Currabubula";
$areanames{en}->{612574222} = "Cuttabri";
$areanames{en}->{612574223} = "Deepwater";
$areanames{en}->{612574224} = "Delungra";
$areanames{en}->{612574225} = "Drake";
$areanames{en}->{612574226} = "Ebor";
$areanames{en}->{612574227} = "Elcombe";
$areanames{en}->{612574228} = "Emmaville";
$areanames{en}->{612574229} = "Frazers\ Creek";
$areanames{en}->{612574230} = "Garah";
$areanames{en}->{612574231} = "Glen\ Elgin";
$areanames{en}->{612574232} = "Glen\ Innes";
$areanames{en}->{612574233} = "Glencoe";
$areanames{en}->{612574234} = "Goolhi";
$areanames{en}->{612574235} = "Graman";
$areanames{en}->{612574236} = "Gundabloui";
$areanames{en}->{612574237} = "Gunnedah";
$areanames{en}->{612574238} = "Gunyerwarildi";
$areanames{en}->{612574239} = "Gurley";
$areanames{en}->{612574240} = "Guyra";
$areanames{en}->{612574241} = "Halls\ Creek";
$areanames{en}->{612574242} = "Ingleba";
$areanames{en}->{612574243} = "Inverell";
$areanames{en}->{612574244} = "Kelvin";
$areanames{en}->{612574245} = "Kingstown";
$areanames{en}->{612574246} = "Limbri";
$areanames{en}->{612574247} = "Manilla";
$areanames{en}->{612574248} = "Marple";
$areanames{en}->{612574249} = "Mirriadool";
$areanames{en}->{612574250} = "Moona\ Plains";
$areanames{en}->{612574251} = "Moree";
$areanames{en}->{612574252} = "Mullaley";
$areanames{en}->{612574253} = "Mungindi";
$areanames{en}->{612574254} = "Narrabri";
$areanames{en}->{612574255} = "Nowendoc";
$areanames{en}->{612574256} = "Nullamanna";
$areanames{en}->{612574257} = "Nundle";
$areanames{en}->{612574258} = "Oakey\ Creek";
$areanames{en}->{612574259} = "Oban";
$areanames{en}->{612574260} = "Ogunbil";
$areanames{en}->{612574261} = "Pallamallawa";
$areanames{en}->{612574262} = "Pilliga";
$areanames{en}->{612574263} = "Pine\ Ridge";
$areanames{en}->{612574264} = "Pinkett";
$areanames{en}->{612574265} = "Plumthorpe";
$areanames{en}->{612574266} = "Quirindi";
$areanames{en}->{612574267} = "Rocky\ Creek";
$areanames{en}->{612574268} = "Rowena";
$areanames{en}->{612574269} = "Sandy\ Flat";
$areanames{en}->{612574270} = "Somerton";
$areanames{en}->{612574271} = "Spring\ Plains";
$areanames{en}->{612574272} = "Tambar\ Springs";
$areanames{en}->{612574273} = "Tamworth";
$areanames{en}->{612574274} = "Tenterden";
$areanames{en}->{612574275} = "Tenterfield";
$areanames{en}->{612574276} = "Tingha";
$areanames{en}->{612574277} = "Upper\ Horton";
$areanames{en}->{612574278} = "Uralla";
$areanames{en}->{612574279} = "Walcha";
$areanames{en}->{612574280} = "Walcha\ Road";
$areanames{en}->{612574281} = "Warialda";
$areanames{en}->{612574282} = "Wee\ Waa";
$areanames{en}->{612574283} = "Weemelah";
$areanames{en}->{612574284} = "Wellingrove";
$areanames{en}->{612574285} = "Wenna";
$areanames{en}->{612574286} = "Willow\ Tree";
$areanames{en}->{612574287} = "Wollomombi";
$areanames{en}->{612574288} = "Yarrie\ Lake";
$areanames{en}->{612574289} = "Yarrowitch";
$areanames{en}->{61257429} = "Nundle";
$areanames{en}->{61257430} = "Armidale";
$areanames{en}->{61257431} = "Armidale";
$areanames{en}->{61257432} = "Tamworth";
$areanames{en}->{61257433} = "Tenterfield";
$areanames{en}->{61257434} = "Quirindi";
$areanames{en}->{61257435} = "Gunnedah";
$areanames{en}->{61257436} = "Gunnedah";
$areanames{en}->{61257437} = "Gunnedah";
$areanames{en}->{612574380} = "Aberfoyle";
$areanames{en}->{612574381} = "Armidale";
$areanames{en}->{612574382} = "Baan\ Baa";
$areanames{en}->{612574383} = "Banoon";
$areanames{en}->{612574384} = "Barraba";
$areanames{en}->{612574385} = "Barwick";
$areanames{en}->{612574386} = "Aberfoyle";
$areanames{en}->{612574387} = "Armidale";
$areanames{en}->{612574388} = "Baan\ Baa";
$areanames{en}->{612574389} = "Banoon";
$areanames{en}->{612574390} = "Barraba";
$areanames{en}->{612574391} = "Barwick";
$areanames{en}->{612574392} = "Bellata";
$areanames{en}->{612574393} = "Ben\ Lomond";
$areanames{en}->{612574394} = "Bendemeer";
$areanames{en}->{612574395} = "Bingara";
$areanames{en}->{612574396} = "Boggabri";
$areanames{en}->{612574397} = "Bohena";
$areanames{en}->{612574398} = "Boomi";
$areanames{en}->{612574399} = "Boorolong";
$areanames{en}->{612574400} = "Breeza";
$areanames{en}->{612574401} = "Bundarra";
$areanames{en}->{612574402} = "Bundella";
$areanames{en}->{612574403} = "Bunnor";
$areanames{en}->{612574404} = "Burren\ Junction";
$areanames{en}->{612574405} = "Careunga";
$areanames{en}->{612574406} = "Caroda";
$areanames{en}->{612574407} = "Collarenebri";
$areanames{en}->{612574408} = "Coolatai";
$areanames{en}->{612574409} = "Copeton\ Dam";
$areanames{en}->{612574410} = "Craigleigh";
$areanames{en}->{612574411} = "Croppa\ Creek";
$areanames{en}->{612574412} = "Curlewis";
$areanames{en}->{612574413} = "Currabubula";
$areanames{en}->{612574414} = "Cuttabri";
$areanames{en}->{612574415} = "Deepwater";
$areanames{en}->{612574416} = "Delungra";
$areanames{en}->{612574417} = "Drake";
$areanames{en}->{612574418} = "Ebor";
$areanames{en}->{612574419} = "Elcombe";
$areanames{en}->{612574420} = "Emmaville";
$areanames{en}->{612574421} = "Frazers\ Creek";
$areanames{en}->{612574422} = "Garah";
$areanames{en}->{612574423} = "Glen\ Elgin";
$areanames{en}->{612574424} = "Glen\ Innes";
$areanames{en}->{612574425} = "Glencoe";
$areanames{en}->{612574426} = "Goolhi";
$areanames{en}->{612574427} = "Graman";
$areanames{en}->{612574428} = "Gundabloui";
$areanames{en}->{612574429} = "Gunnedah";
$areanames{en}->{612574430} = "Gunyerwarildi";
$areanames{en}->{612574431} = "Gurley";
$areanames{en}->{612574432} = "Guyra";
$areanames{en}->{612574433} = "Halls\ Creek";
$areanames{en}->{612574434} = "Ingleba";
$areanames{en}->{612574435} = "Inverell";
$areanames{en}->{612574436} = "Kelvin";
$areanames{en}->{612574437} = "Kingstown";
$areanames{en}->{612574438} = "Limbri";
$areanames{en}->{612574439} = "Manilla";
$areanames{en}->{612574440} = "Marple";
$areanames{en}->{612574441} = "Mirriadool";
$areanames{en}->{612574442} = "Moona\ Plains";
$areanames{en}->{612574443} = "Moree";
$areanames{en}->{612574444} = "Mullaley";
$areanames{en}->{612574445} = "Mungindi";
$areanames{en}->{612574446} = "Narrabri";
$areanames{en}->{612574447} = "Nowendoc";
$areanames{en}->{612574448} = "Nullamanna";
$areanames{en}->{612574449} = "Nundle";
$areanames{en}->{612574450} = "Oakey\ Creek";
$areanames{en}->{612574451} = "Oban";
$areanames{en}->{612574452} = "Ogunbil";
$areanames{en}->{612574453} = "Pallamallawa";
$areanames{en}->{612574454} = "Pilliga";
$areanames{en}->{612574455} = "Pine\ Ridge";
$areanames{en}->{612574456} = "Pinkett";
$areanames{en}->{612574457} = "Plumthorpe";
$areanames{en}->{612574458} = "Quirindi";
$areanames{en}->{612574459} = "Rocky\ Creek";
$areanames{en}->{612574460} = "Rowena";
$areanames{en}->{612574461} = "Sandy\ Flat";
$areanames{en}->{612574462} = "Somerton";
$areanames{en}->{612574463} = "Spring\ Plains";
$areanames{en}->{612574464} = "Tambar\ Springs";
$areanames{en}->{612574465} = "Tamworth";
$areanames{en}->{612574466} = "Tenterden";
$areanames{en}->{612574467} = "Tenterfield";
$areanames{en}->{612574468} = "Tingha";
$areanames{en}->{612574469} = "Upper\ Horton";
$areanames{en}->{612574470} = "Uralla";
$areanames{en}->{612574471} = "Walcha";
$areanames{en}->{612574472} = "Walcha\ Road";
$areanames{en}->{612574473} = "Warialda";
$areanames{en}->{612574474} = "Wee\ Waa";
$areanames{en}->{612574475} = "Weemelah";
$areanames{en}->{612574476} = "Wellingrove";
$areanames{en}->{612574477} = "Wenna";
$areanames{en}->{612574478} = "Willow\ Tree";
$areanames{en}->{612574479} = "Wollomombi";
$areanames{en}->{612574480} = "Yarrie\ Lake";
$areanames{en}->{612574481} = "Yarrowitch";
$areanames{en}->{612574482} = "Bellata";
$areanames{en}->{612574483} = "Ben\ Lomond";
$areanames{en}->{612574484} = "Bendemeer";
$areanames{en}->{612574485} = "Bingara";
$areanames{en}->{612574486} = "Boggabri";
$areanames{en}->{612574487} = "Bohena";
$areanames{en}->{612574488} = "Boomi";
$areanames{en}->{612574489} = "Boorolong";
$areanames{en}->{61257449} = "Barraba";
$areanames{en}->{61257450} = "Armidale";
$areanames{en}->{61257451} = "Armidale";
$areanames{en}->{61257452} = "Armidale";
$areanames{en}->{61257453} = "Frazers\ Creek";
$areanames{en}->{61257454} = "Frazers\ Creek";
$areanames{en}->{61257455} = "Frazers\ Creek";
$areanames{en}->{61257456} = "Quirindi";
$areanames{en}->{612574570} = "Breeza";
$areanames{en}->{612574571} = "Bundarra";
$areanames{en}->{612574572} = "Bundella";
$areanames{en}->{612574573} = "Bunnor";
$areanames{en}->{612574574} = "Burren\ Junction";
$areanames{en}->{612574575} = "Careunga";
$areanames{en}->{612574576} = "Caroda";
$areanames{en}->{612574577} = "Collarenebri";
$areanames{en}->{612574578} = "Coolatai";
$areanames{en}->{612574579} = "Copeton\ Dam";
$areanames{en}->{612574580} = "Craigleigh";
$areanames{en}->{612574581} = "Croppa\ Creek";
$areanames{en}->{612574582} = "Curlewis";
$areanames{en}->{612574583} = "Currabubula";
$areanames{en}->{612574584} = "Cuttabri";
$areanames{en}->{612574585} = "Deepwater";
$areanames{en}->{612574586} = "Delungra";
$areanames{en}->{612574587} = "Drake";
$areanames{en}->{612574588} = "Ebor";
$areanames{en}->{612574589} = "Elcombe";
$areanames{en}->{612574590} = "Emmaville";
$areanames{en}->{612574591} = "Frazers\ Creek";
$areanames{en}->{612574592} = "Garah";
$areanames{en}->{612574593} = "Glen\ Elgin";
$areanames{en}->{612574594} = "Glen\ Innes";
$areanames{en}->{612574595} = "Glencoe";
$areanames{en}->{612574596} = "Goolhi";
$areanames{en}->{612574597} = "Graman";
$areanames{en}->{612574598} = "Gundabloui";
$areanames{en}->{612574599} = "Gunnedah";
$areanames{en}->{612574600} = "Gunyerwarildi";
$areanames{en}->{612574601} = "Gurley";
$areanames{en}->{612574602} = "Guyra";
$areanames{en}->{612574603} = "Halls\ Creek";
$areanames{en}->{612574604} = "Ingleba";
$areanames{en}->{612574605} = "Inverell";
$areanames{en}->{612574606} = "Kelvin";
$areanames{en}->{612574607} = "Kingstown";
$areanames{en}->{612574608} = "Limbri";
$areanames{en}->{612574609} = "Manilla";
$areanames{en}->{612574610} = "Marple";
$areanames{en}->{612574611} = "Mirriadool";
$areanames{en}->{612574612} = "Moona\ Plains";
$areanames{en}->{612574613} = "Moree";
$areanames{en}->{612574614} = "Mullaley";
$areanames{en}->{612574615} = "Mungindi";
$areanames{en}->{612574616} = "Narrabri";
$areanames{en}->{612574617} = "Nowendoc";
$areanames{en}->{612574618} = "Nullamanna";
$areanames{en}->{612574619} = "Nundle";
$areanames{en}->{612574620} = "Oakey\ Creek";
$areanames{en}->{612574621} = "Oban";
$areanames{en}->{612574622} = "Ogunbil";
$areanames{en}->{612574623} = "Pallamallawa";
$areanames{en}->{612574624} = "Pilliga";
$areanames{en}->{612574625} = "Pine\ Ridge";
$areanames{en}->{612574626} = "Pinkett";
$areanames{en}->{612574627} = "Plumthorpe";
$areanames{en}->{612574628} = "Quirindi";
$areanames{en}->{612574629} = "Rocky\ Creek";
$areanames{en}->{612574630} = "Rowena";
$areanames{en}->{612574631} = "Sandy\ Flat";
$areanames{en}->{612574632} = "Somerton";
$areanames{en}->{612574633} = "Spring\ Plains";
$areanames{en}->{612574634} = "Tambar\ Springs";
$areanames{en}->{612574635} = "Tamworth";
$areanames{en}->{612574636} = "Tenterden";
$areanames{en}->{612574637} = "Tenterfield";
$areanames{en}->{612574638} = "Tingha";
$areanames{en}->{612574639} = "Upper\ Horton";
$areanames{en}->{612574640} = "Uralla";
$areanames{en}->{612574641} = "Walcha";
$areanames{en}->{612574642} = "Walcha\ Road";
$areanames{en}->{612574643} = "Warialda";
$areanames{en}->{612574644} = "Wee\ Waa";
$areanames{en}->{612574645} = "Weemelah";
$areanames{en}->{612574646} = "Wellingrove";
$areanames{en}->{612574647} = "Wenna";
$areanames{en}->{612574648} = "Willow\ Tree";
$areanames{en}->{612574649} = "Wollomombi";
$areanames{en}->{612574650} = "Yarrie\ Lake";
$areanames{en}->{612574651} = "Yarrowitch";
$areanames{en}->{612574652} = "Aberfoyle";
$areanames{en}->{612574653} = "Armidale";
$areanames{en}->{612574654} = "Baan\ Baa";
$areanames{en}->{612574655} = "Banoon";
$areanames{en}->{612574656} = "Barraba";
$areanames{en}->{612574657} = "Barwick";
$areanames{en}->{612574658} = "Bellata";
$areanames{en}->{612574659} = "Ben\ Lomond";
$areanames{en}->{612574660} = "Bendemeer";
$areanames{en}->{612574661} = "Bingara";
$areanames{en}->{612574662} = "Boggabri";
$areanames{en}->{612574663} = "Bohena";
$areanames{en}->{612574664} = "Boomi";
$areanames{en}->{612574665} = "Boorolong";
$areanames{en}->{612574666} = "Breeza";
$areanames{en}->{612574667} = "Bundarra";
$areanames{en}->{612574668} = "Bundella";
$areanames{en}->{612574669} = "Bunnor";
$areanames{en}->{612574670} = "Burren\ Junction";
$areanames{en}->{612574671} = "Careunga";
$areanames{en}->{612574672} = "Caroda";
$areanames{en}->{612574673} = "Collarenebri";
$areanames{en}->{612574674} = "Coolatai";
$areanames{en}->{612574675} = "Copeton\ Dam";
$areanames{en}->{612574676} = "Craigleigh";
$areanames{en}->{612574677} = "Croppa\ Creek";
$areanames{en}->{612574678} = "Curlewis";
$areanames{en}->{612574679} = "Currabubula";
$areanames{en}->{612574680} = "Cuttabri";
$areanames{en}->{612574681} = "Deepwater";
$areanames{en}->{612574682} = "Delungra";
$areanames{en}->{612574683} = "Drake";
$areanames{en}->{612574684} = "Ebor";
$areanames{en}->{612574685} = "Elcombe";
$areanames{en}->{612574686} = "Emmaville";
$areanames{en}->{612574687} = "Frazers\ Creek";
$areanames{en}->{612574688} = "Garah";
$areanames{en}->{612574689} = "Glen\ Elgin";
$areanames{en}->{612574690} = "Glen\ Innes";
$areanames{en}->{612574691} = "Glencoe";
$areanames{en}->{612574692} = "Goolhi";
$areanames{en}->{612574693} = "Graman";
$areanames{en}->{612574694} = "Gundabloui";
$areanames{en}->{612574695} = "Gunnedah";
$areanames{en}->{612574696} = "Gunyerwarildi";
$areanames{en}->{612574697} = "Gurley";
$areanames{en}->{612574698} = "Guyra";
$areanames{en}->{612574699} = "Halls\ Creek";
$areanames{en}->{612574700} = "Ingleba";
$areanames{en}->{612574701} = "Inverell";
$areanames{en}->{612574702} = "Kelvin";
$areanames{en}->{612574703} = "Kingstown";
$areanames{en}->{612574704} = "Limbri";
$areanames{en}->{612574705} = "Manilla";
$areanames{en}->{612574706} = "Marple";
$areanames{en}->{612574707} = "Mirriadool";
$areanames{en}->{612574708} = "Moona\ Plains";
$areanames{en}->{612574709} = "Moree";
$areanames{en}->{612574710} = "Mullaley";
$areanames{en}->{612574711} = "Mungindi";
$areanames{en}->{612574712} = "Narrabri";
$areanames{en}->{612574713} = "Nowendoc";
$areanames{en}->{612574714} = "Nullamanna";
$areanames{en}->{612574715} = "Nundle";
$areanames{en}->{612574716} = "Oakey\ Creek";
$areanames{en}->{612574717} = "Oban";
$areanames{en}->{612574718} = "Ogunbil";
$areanames{en}->{612574719} = "Pallamallawa";
$areanames{en}->{612574720} = "Pilliga";
$areanames{en}->{612574721} = "Pine\ Ridge";
$areanames{en}->{612574722} = "Pinkett";
$areanames{en}->{612574723} = "Plumthorpe";
$areanames{en}->{612574724} = "Quirindi";
$areanames{en}->{612574725} = "Rocky\ Creek";
$areanames{en}->{612574726} = "Rowena";
$areanames{en}->{612574727} = "Sandy\ Flat";
$areanames{en}->{612574728} = "Somerton";
$areanames{en}->{612574729} = "Spring\ Plains";
$areanames{en}->{612574730} = "Tambar\ Springs";
$areanames{en}->{612574731} = "Tamworth";
$areanames{en}->{612574732} = "Tenterden";
$areanames{en}->{612574733} = "Tenterfield";
$areanames{en}->{612574734} = "Tingha";
$areanames{en}->{612574735} = "Upper\ Horton";
$areanames{en}->{612574736} = "Uralla";
$areanames{en}->{612574737} = "Walcha";
$areanames{en}->{612574738} = "Walcha\ Road";
$areanames{en}->{612574739} = "Warialda";
$areanames{en}->{612574740} = "Wee\ Waa";
$areanames{en}->{612574741} = "Weemelah";
$areanames{en}->{612574742} = "Wellingrove";
$areanames{en}->{612574743} = "Wenna";
$areanames{en}->{612574744} = "Willow\ Tree";
$areanames{en}->{612574745} = "Wollomombi";
$areanames{en}->{612574746} = "Yarrie\ Lake";
$areanames{en}->{612574747} = "Yarrowitch";
$areanames{en}->{612574748} = "Aberfoyle";
$areanames{en}->{612574749} = "Armidale";
$areanames{en}->{612574750} = "Baan\ Baa";
$areanames{en}->{612574751} = "Banoon";
$areanames{en}->{612574752} = "Barraba";
$areanames{en}->{612574753} = "Barwick";
$areanames{en}->{612574754} = "Bellata";
$areanames{en}->{612574755} = "Ben\ Lomond";
$areanames{en}->{612574756} = "Bendemeer";
$areanames{en}->{612574757} = "Bingara";
$areanames{en}->{612574758} = "Boggabri";
$areanames{en}->{612574759} = "Bohena";
$areanames{en}->{612574760} = "Boomi";
$areanames{en}->{612574761} = "Boorolong";
$areanames{en}->{612574762} = "Breeza";
$areanames{en}->{612574763} = "Bundarra";
$areanames{en}->{612574764} = "Bundella";
$areanames{en}->{612574765} = "Bunnor";
$areanames{en}->{612574766} = "Burren\ Junction";
$areanames{en}->{612574767} = "Careunga";
$areanames{en}->{612574768} = "Caroda";
$areanames{en}->{612574769} = "Collarenebri";
$areanames{en}->{612574770} = "Coolatai";
$areanames{en}->{612574771} = "Copeton\ Dam";
$areanames{en}->{612574772} = "Craigleigh";
$areanames{en}->{612574773} = "Croppa\ Creek";
$areanames{en}->{612574774} = "Curlewis";
$areanames{en}->{612574775} = "Currabubula";
$areanames{en}->{612574776} = "Cuttabri";
$areanames{en}->{612574777} = "Deepwater";
$areanames{en}->{612574778} = "Delungra";
$areanames{en}->{612574779} = "Drake";
$areanames{en}->{612574780} = "Ebor";
$areanames{en}->{612574781} = "Elcombe";
$areanames{en}->{612574782} = "Emmaville";
$areanames{en}->{612574783} = "Frazers\ Creek";
$areanames{en}->{612574784} = "Garah";
$areanames{en}->{612574785} = "Glen\ Elgin";
$areanames{en}->{612574786} = "Glen\ Innes";
$areanames{en}->{612574787} = "Glencoe";
$areanames{en}->{612574788} = "Goolhi";
$areanames{en}->{612574789} = "Graman";
$areanames{en}->{612574790} = "Gundabloui";
$areanames{en}->{612574791} = "Gunnedah";
$areanames{en}->{612574792} = "Gunyerwarildi";
$areanames{en}->{612574793} = "Gurley";
$areanames{en}->{612574794} = "Guyra";
$areanames{en}->{612574795} = "Halls\ Creek";
$areanames{en}->{612574796} = "Ingleba";
$areanames{en}->{612574797} = "Inverell";
$areanames{en}->{612574798} = "Kelvin";
$areanames{en}->{612574799} = "Kingstown";
$areanames{en}->{612574800} = "Limbri";
$areanames{en}->{612574801} = "Manilla";
$areanames{en}->{612574802} = "Marple";
$areanames{en}->{612574803} = "Mirriadool";
$areanames{en}->{612574804} = "Moona\ Plains";
$areanames{en}->{612574805} = "Moree";
$areanames{en}->{612574806} = "Mullaley";
$areanames{en}->{612574807} = "Mungindi";
$areanames{en}->{612574808} = "Narrabri";
$areanames{en}->{612574809} = "Nowendoc";
$areanames{en}->{612574810} = "Nullamanna";
$areanames{en}->{612574811} = "Nundle";
$areanames{en}->{612574812} = "Oakey\ Creek";
$areanames{en}->{612574813} = "Oban";
$areanames{en}->{612574814} = "Ogunbil";
$areanames{en}->{612574815} = "Pallamallawa";
$areanames{en}->{612574816} = "Pilliga";
$areanames{en}->{612574817} = "Pine\ Ridge";
$areanames{en}->{612574818} = "Pinkett";
$areanames{en}->{612574819} = "Plumthorpe";
$areanames{en}->{612574820} = "Quirindi";
$areanames{en}->{612574821} = "Rocky\ Creek";
$areanames{en}->{612574822} = "Rowena";
$areanames{en}->{612574823} = "Sandy\ Flat";
$areanames{en}->{612574824} = "Somerton";
$areanames{en}->{612574825} = "Spring\ Plains";
$areanames{en}->{612574826} = "Tambar\ Springs";
$areanames{en}->{612574827} = "Tamworth";
$areanames{en}->{612574828} = "Tenterden";
$areanames{en}->{612574829} = "Tenterfield";
$areanames{en}->{612574830} = "Tingha";
$areanames{en}->{612574831} = "Upper\ Horton";
$areanames{en}->{612574832} = "Uralla";
$areanames{en}->{612574833} = "Walcha";
$areanames{en}->{612574834} = "Walcha\ Road";
$areanames{en}->{612574835} = "Warialda";
$areanames{en}->{612574836} = "Wee\ Waa";
$areanames{en}->{612574837} = "Weemelah";
$areanames{en}->{612574838} = "Wellingrove";
$areanames{en}->{612574839} = "Wenna";
$areanames{en}->{612574840} = "Willow\ Tree";
$areanames{en}->{612574841} = "Wollomombi";
$areanames{en}->{612574842} = "Yarrie\ Lake";
$areanames{en}->{612574843} = "Yarrowitch";
$areanames{en}->{612574844} = "Aberfoyle";
$areanames{en}->{612574845} = "Armidale";
$areanames{en}->{612574846} = "Baan\ Baa";
$areanames{en}->{612574847} = "Banoon";
$areanames{en}->{612574848} = "Barraba";
$areanames{en}->{612574849} = "Barwick";
$areanames{en}->{612574900} = "Bellata";
$areanames{en}->{612574901} = "Ben\ Lomond";
$areanames{en}->{612574902} = "Bendemeer";
$areanames{en}->{612574903} = "Bingara";
$areanames{en}->{612574904} = "Boggabri";
$areanames{en}->{612574905} = "Bohena";
$areanames{en}->{612574906} = "Boomi";
$areanames{en}->{612574907} = "Boorolong";
$areanames{en}->{612574908} = "Breeza";
$areanames{en}->{612574909} = "Bundarra";
$areanames{en}->{612574910} = "Bundella";
$areanames{en}->{612574911} = "Bunnor";
$areanames{en}->{612574912} = "Burren\ Junction";
$areanames{en}->{612574913} = "Careunga";
$areanames{en}->{612574914} = "Caroda";
$areanames{en}->{612574915} = "Collarenebri";
$areanames{en}->{612574916} = "Coolatai";
$areanames{en}->{612574917} = "Copeton\ Dam";
$areanames{en}->{612574918} = "Craigleigh";
$areanames{en}->{612574919} = "Croppa\ Creek";
$areanames{en}->{612574920} = "Curlewis";
$areanames{en}->{612574921} = "Currabubula";
$areanames{en}->{612574922} = "Cuttabri";
$areanames{en}->{612574923} = "Deepwater";
$areanames{en}->{612574924} = "Delungra";
$areanames{en}->{612574925} = "Drake";
$areanames{en}->{612574926} = "Ebor";
$areanames{en}->{612574927} = "Elcombe";
$areanames{en}->{612574928} = "Emmaville";
$areanames{en}->{612574929} = "Frazers\ Creek";
$areanames{en}->{612574930} = "Garah";
$areanames{en}->{612574931} = "Glen\ Elgin";
$areanames{en}->{612574932} = "Glen\ Innes";
$areanames{en}->{612574933} = "Glencoe";
$areanames{en}->{612574934} = "Goolhi";
$areanames{en}->{612574935} = "Graman";
$areanames{en}->{612574936} = "Gundabloui";
$areanames{en}->{612574937} = "Gunnedah";
$areanames{en}->{612574938} = "Gunyerwarildi";
$areanames{en}->{612574939} = "Gurley";
$areanames{en}->{612574940} = "Guyra";
$areanames{en}->{612574941} = "Halls\ Creek";
$areanames{en}->{612574942} = "Ingleba";
$areanames{en}->{612574943} = "Inverell";
$areanames{en}->{612574944} = "Kelvin";
$areanames{en}->{612574945} = "Kingstown";
$areanames{en}->{612574946} = "Limbri";
$areanames{en}->{612574947} = "Manilla";
$areanames{en}->{612574948} = "Marple";
$areanames{en}->{612574949} = "Mirriadool";
$areanames{en}->{612574950} = "Moona\ Plains";
$areanames{en}->{612574951} = "Moree";
$areanames{en}->{612574952} = "Mullaley";
$areanames{en}->{612574953} = "Mungindi";
$areanames{en}->{612574954} = "Narrabri";
$areanames{en}->{612574955} = "Nowendoc";
$areanames{en}->{612574956} = "Nullamanna";
$areanames{en}->{612574957} = "Nundle";
$areanames{en}->{612574958} = "Oakey\ Creek";
$areanames{en}->{612574959} = "Oban";
$areanames{en}->{612574960} = "Ogunbil";
$areanames{en}->{612574961} = "Pallamallawa";
$areanames{en}->{612574962} = "Pilliga";
$areanames{en}->{612574963} = "Pine\ Ridge";
$areanames{en}->{612574964} = "Pinkett";
$areanames{en}->{612574965} = "Plumthorpe";
$areanames{en}->{612574966} = "Quirindi";
$areanames{en}->{612574967} = "Rocky\ Creek";
$areanames{en}->{612574968} = "Rowena";
$areanames{en}->{612574969} = "Sandy\ Flat";
$areanames{en}->{612574970} = "Somerton";
$areanames{en}->{612574971} = "Spring\ Plains";
$areanames{en}->{612574972} = "Tambar\ Springs";
$areanames{en}->{612574973} = "Tamworth";
$areanames{en}->{612574974} = "Tenterden";
$areanames{en}->{612574975} = "Tenterfield";
$areanames{en}->{612574976} = "Tingha";
$areanames{en}->{612574977} = "Upper\ Horton";
$areanames{en}->{612574978} = "Uralla";
$areanames{en}->{612574979} = "Walcha";
$areanames{en}->{612574980} = "Walcha\ Road";
$areanames{en}->{612574981} = "Warialda";
$areanames{en}->{612574982} = "Wee\ Waa";
$areanames{en}->{612574983} = "Weemelah";
$areanames{en}->{612574984} = "Wellingrove";
$areanames{en}->{612574985} = "Wenna";
$areanames{en}->{612574986} = "Willow\ Tree";
$areanames{en}->{612574987} = "Wollomombi";
$areanames{en}->{612574988} = "Yarrie\ Lake";
$areanames{en}->{612574989} = "Yarrowitch";
$areanames{en}->{61257499} = "Wee\ Waa";
$areanames{en}->{61257509} = "Boomi";
$areanames{en}->{61257520} = "Caroda";
$areanames{en}->{61257539} = "Glen\ Innes";
$areanames{en}->{61257550} = "Gurley";
$areanames{en}->{61257569} = "Tenterfield";
$areanames{en}->{61257580} = "Warialda";
$areanames{en}->{61257748} = "Tamworth";
$areanames{en}->{61257749} = "Tamworth";
$areanames{en}->{61257750} = "Wollomombi";
$areanames{en}->{61257751} = "Aberfoyle";
$areanames{en}->{61257752} = "Ingleba";
$areanames{en}->{61257753} = "Kingstown";
$areanames{en}->{61257754} = "Yarrowitch";
$areanames{en}->{61257755} = "Tenterden";
$areanames{en}->{61257756} = "Marple";
$areanames{en}->{61257757} = "Nowendoc";
$areanames{en}->{61257758} = "Armidale";
$areanames{en}->{61257759} = "Armidale";
$areanames{en}->{6125776} = "Tamworth";
$areanames{en}->{61257760} = "Armidale";
$areanames{en}->{61257762} = "Armidale";
$areanames{en}->{61257763} = "Armidale";
$areanames{en}->{61257764} = "Armidale";
$areanames{en}->{61257770} = "Tamworth";
$areanames{en}->{61257771} = "Tamworth";
$areanames{en}->{61257772} = "Tamworth";
$areanames{en}->{61257773} = "Armidale";
$areanames{en}->{61257774} = "Armidale";
$areanames{en}->{61257775} = "Narrabri";
$areanames{en}->{61257776} = "Manilla";
$areanames{en}->{61257777} = "Armidale";
$areanames{en}->{61257778} = "Quirindi";
$areanames{en}->{61257779} = "Tamworth";
$areanames{en}->{61257793} = "Tamworth";
$areanames{en}->{61257944} = "Baan\ Baa";
$areanames{en}->{61257945} = "Baan\ Baa";
$areanames{en}->{61257946} = "Boggabri";
$areanames{en}->{61257947} = "Tamworth";
$areanames{en}->{61257948} = "Tamworth";
$areanames{en}->{61257949} = "Moree";
$areanames{en}->{61257950} = "Mungindi";
$areanames{en}->{61257951} = "Armidale";
$areanames{en}->{61257952} = "Ingleba";
$areanames{en}->{61257953} = "Ingleba";
$areanames{en}->{61257954} = "Ingleba";
$areanames{en}->{61258000} = "Neilrex";
$areanames{en}->{61258001} = "Purlewaugh";
$areanames{en}->{61258002} = "Rocky\ Glen";
$areanames{en}->{61258003} = "Tooraweenah";
$areanames{en}->{61258004} = "Trangie";
$areanames{en}->{61258005} = "Tyrie";
$areanames{en}->{61258006} = "Warren";
$areanames{en}->{61258007} = "Weetaliba";
$areanames{en}->{61258008} = "Wyanga";
$areanames{en}->{61258009} = "Yarragrin";
$areanames{en}->{61258010} = "Bedgerebong";
$areanames{en}->{61258011} = "Eugowra";
$areanames{en}->{61258012} = "Forbes";
$areanames{en}->{61258013} = "Weelong";
$areanames{en}->{61258014} = "Wirrinya";
$areanames{en}->{61258015} = "Berkley\ Downs";
$areanames{en}->{61258016} = "Bonnay";
$areanames{en}->{61258017} = "Boorooma";
$areanames{en}->{61258018} = "Borah\ Tank";
$areanames{en}->{61258019} = "Cumborah";
$areanames{en}->{61258020} = "Goodooga";
$areanames{en}->{61258021} = "Grawin";
$areanames{en}->{61258022} = "Lightning\ Ridge";
$areanames{en}->{61258023} = "Walgett";
$areanames{en}->{61258024} = "Colane";
$areanames{en}->{61258025} = "Coolabah";
$areanames{en}->{61258026} = "Girilambone";
$areanames{en}->{61258027} = "Hermidale";
$areanames{en}->{61258028} = "Mount\ Foster";
$areanames{en}->{61258029} = "Mullengudgery";
$areanames{en}->{61258030} = "Nyngan";
$areanames{en}->{61258031} = "Widgeland";
$areanames{en}->{61258032} = "Alectown";
$areanames{en}->{61258033} = "Bindogundra";
$areanames{en}->{61258034} = "Bogan\ Gate";
$areanames{en}->{61258035} = "Bruie\ Plains";
$areanames{en}->{61258036} = "Mandagery";
$areanames{en}->{61258037} = "Mungery";
$areanames{en}->{61258038} = "Parkes";
$areanames{en}->{61258039} = "Peak\ Hill";
$areanames{en}->{61258040} = "Yarrabandai";
$areanames{en}->{61258041} = "Gollan";
$areanames{en}->{61258042} = "Stuart\ Town";
$areanames{en}->{61258043} = "Wellington";
$areanames{en}->{61258044} = "Yeoval";
$areanames{en}->{61258045} = "Dubbo";
$areanames{en}->{61258046} = "Dubbo";
$areanames{en}->{61258047} = "Dubbo";
$areanames{en}->{61258048} = "Gilgandra";
$areanames{en}->{61258049} = "Parkes";
$areanames{en}->{6125805} = "Dubbo";
$areanames{en}->{61258060} = "Dubbo";
$areanames{en}->{61258061} = "Airlands";
$areanames{en}->{61258062} = "Airlands";
$areanames{en}->{61258063} = "Balladoran";
$areanames{en}->{61258064} = "Balladoran";
$areanames{en}->{61258065} = "Coonabarabran";
$areanames{en}->{61258066} = "Coonabarabran";
$areanames{en}->{61258067} = "Dubbo";
$areanames{en}->{61258068} = "Dubbo";
$areanames{en}->{61258069} = "Geurie";
$areanames{en}->{61258070} = "Geurie";
$areanames{en}->{61258071} = "Wellington";
$areanames{en}->{61258072} = "Wellington";
$areanames{en}->{61258073} = "Goorianawa";
$areanames{en}->{61258074} = "Goorianawa";
$areanames{en}->{61258075} = "Narromine";
$areanames{en}->{61258076} = "Narromine";
$areanames{en}->{61258077} = "Rocky\ Glen";
$areanames{en}->{61258078} = "Rocky\ Glen";
$areanames{en}->{61258079} = "Tooraweenah";
$areanames{en}->{61258080} = "Tooraweenah";
$areanames{en}->{61258081} = "Trangie";
$areanames{en}->{61258082} = "Trangie";
$areanames{en}->{61258083} = "Warrumbungle";
$areanames{en}->{61258084} = "Warrumbungle";
$areanames{en}->{61258085} = "Naradhan";
$areanames{en}->{61258086} = "Naradhan";
$areanames{en}->{61258087} = "Walgett";
$areanames{en}->{61258088} = "Walgett";
$areanames{en}->{61258089} = "Parkes";
$areanames{en}->{61258090} = "Parkes";
$areanames{en}->{61258091} = "Nyngan";
$areanames{en}->{61258092} = "Nyngan";
$areanames{en}->{61258093} = "Bindogundra";
$areanames{en}->{61258094} = "Bindogundra";
$areanames{en}->{61258095} = "Peak\ Hill";
$areanames{en}->{61258096} = "Peak\ Hill";
$areanames{en}->{61258097} = "Dubbo";
$areanames{en}->{61258098} = "Dubbo";
$areanames{en}->{61258099} = "Dubbo";
$areanames{en}->{61258100} = "Dandaloo";
$areanames{en}->{61258101} = "Dandaloo";
$areanames{en}->{61258102} = "Collie";
$areanames{en}->{61258103} = "Collie";
$areanames{en}->{61258104} = "Wyanga";
$areanames{en}->{61258105} = "Wyanga";
$areanames{en}->{61258106} = "Yarragrin";
$areanames{en}->{61258107} = "Yarragrin";
$areanames{en}->{61258108} = "Ballimore";
$areanames{en}->{61258109} = "Ballimore";
$areanames{en}->{61258110} = "Baradine";
$areanames{en}->{61258111} = "Baradine";
$areanames{en}->{61258112} = "Binnaway";
$areanames{en}->{61258113} = "Binnaway";
$areanames{en}->{61258114} = "Curban";
$areanames{en}->{61258115} = "Curban";
$areanames{en}->{61258116} = "Farrendale";
$areanames{en}->{61258117} = "Farrendale";
$areanames{en}->{61258118} = "Gilgandra";
$areanames{en}->{61258119} = "Gilgandra";
$areanames{en}->{61258120} = "Gwabegar";
$areanames{en}->{61258121} = "Gwabegar";
$areanames{en}->{61258122} = "Colane";
$areanames{en}->{61258123} = "Colane";
$areanames{en}->{61258124} = "Girilambone";
$areanames{en}->{61258125} = "Girilambone";
$areanames{en}->{61258126} = "Coalbaggie";
$areanames{en}->{61258127} = "Coalbaggie";
$areanames{en}->{61258128} = "Hermidale";
$areanames{en}->{61258129} = "Hermidale";
$areanames{en}->{61258130} = "Mullengudgery";
$areanames{en}->{61258131} = "Mullengudgery";
$areanames{en}->{61258132} = "Neilrex";
$areanames{en}->{61258133} = "Neilrex";
$areanames{en}->{61258134} = "Bonnay";
$areanames{en}->{61258135} = "Bonnay";
$areanames{en}->{61258136} = "Cumborah";
$areanames{en}->{61258137} = "Cumborah";
$areanames{en}->{61258138} = "Grawin";
$areanames{en}->{61258139} = "Grawin";
$areanames{en}->{61258140} = "Purlewaugh";
$areanames{en}->{61258141} = "Purlewaugh";
$areanames{en}->{61258142} = "Weetaliba";
$areanames{en}->{61258143} = "Weetaliba";
$areanames{en}->{61258144} = "Barrier";
$areanames{en}->{61258145} = "Barrier";
$areanames{en}->{61258146} = "Warrington";
$areanames{en}->{61258147} = "Warrington";
$areanames{en}->{61258148} = "Forbes";
$areanames{en}->{61258149} = "Forbes";
$areanames{en}->{61258150} = "Double\ Peaks";
$areanames{en}->{61258151} = "Double\ Peaks";
$areanames{en}->{61258152} = "Fairholme";
$areanames{en}->{61258153} = "Fairholme";
$areanames{en}->{61258154} = "Coonamble";
$areanames{en}->{61258155} = "Coonamble";
$areanames{en}->{61258156} = "Wirrinya";
$areanames{en}->{61258157} = "Wirrinya";
$areanames{en}->{61258158} = "Dubbo";
$areanames{en}->{61258159} = "Barrier";
$areanames{en}->{61258160} = "Alectown";
$areanames{en}->{61258161} = "Alectown";
$areanames{en}->{61258162} = "Mandagery";
$areanames{en}->{61258163} = "Mandagery";
$areanames{en}->{61258164} = "Cuttaburra";
$areanames{en}->{61258165} = "Dubbo";
$areanames{en}->{61258166} = "Dubbo";
$areanames{en}->{61258167} = "Parkes";
$areanames{en}->{61258168} = "Airlands";
$areanames{en}->{61258169} = "Dubbo";
$areanames{en}->{61258170} = "Yeoval";
$areanames{en}->{61258171} = "Yeoval";
$areanames{en}->{61258172} = "Mungery";
$areanames{en}->{61258173} = "Mungery";
$areanames{en}->{61258174} = "Bogan\ Gate";
$areanames{en}->{61258175} = "Bogan\ Gate";
$areanames{en}->{61258176} = "Yarrabandai";
$areanames{en}->{61258177} = "Yarrabandai";
$areanames{en}->{61258178} = "Widgeland";
$areanames{en}->{61258179} = "Widgeland";
$areanames{en}->{61258180} = "Weelong";
$areanames{en}->{61258181} = "Weelong";
$areanames{en}->{61258182} = "Kiacatoo";
$areanames{en}->{61258183} = "Kiacatoo";
$areanames{en}->{61258184} = "Dubbo";
$areanames{en}->{61258185} = "Dubbo";
$areanames{en}->{61258186} = "Eugowra";
$areanames{en}->{61258187} = "Eugowra";
$areanames{en}->{61258188} = "Cuttaburra";
$areanames{en}->{61258189} = "Cuttaburra";
$areanames{en}->{61258190} = "Bedgerebong";
$areanames{en}->{61258191} = "Bedgerebong";
$areanames{en}->{61258192} = "Warren";
$areanames{en}->{61258193} = "Warren";
$areanames{en}->{61258194} = "Lightning\ Ridge";
$areanames{en}->{61258195} = "Lightning\ Ridge";
$areanames{en}->{61258196} = "Goodooga";
$areanames{en}->{61258197} = "Goodooga";
$areanames{en}->{61258198} = "Borah\ Tank";
$areanames{en}->{61258199} = "Borah\ Tank";
$areanames{en}->{61258200} = "Dubbo";
$areanames{en}->{61258201} = "Dubbo";
$areanames{en}->{61258202} = "Mount\ Foster";
$areanames{en}->{61258203} = "Mount\ Foster";
$areanames{en}->{61258204} = "Barrier";
$areanames{en}->{61258205} = "Bourke";
$areanames{en}->{61258206} = "Mendooran";
$areanames{en}->{61258207} = "Mendooran";
$areanames{en}->{61258208} = "Mount\ Herring";
$areanames{en}->{61258209} = "Mount\ Herring";
$areanames{en}->{61258210} = "Bruie\ Plains";
$areanames{en}->{61258211} = "Bruie\ Plains";
$areanames{en}->{61258212} = "Gollan";
$areanames{en}->{61258213} = "Gollan";
$areanames{en}->{61258214} = "Banar";
$areanames{en}->{61258215} = "Banar";
$areanames{en}->{61258216} = "Condobolin";
$areanames{en}->{61258217} = "Condobolin";
$areanames{en}->{61258218} = "Coonamble";
$areanames{en}->{61258219} = "Narran";
$areanames{en}->{61258220} = "Trundle";
$areanames{en}->{61258221} = "Trundle";
$areanames{en}->{61258222} = "Tullamore";
$areanames{en}->{61258223} = "Tullamore";
$areanames{en}->{61258224} = "Gilgooma";
$areanames{en}->{61258225} = "Gilgooma";
$areanames{en}->{61258226} = "Gulargambone";
$areanames{en}->{61258227} = "Gulargambone";
$areanames{en}->{61258228} = "Magometon";
$areanames{en}->{61258229} = "Magometon";
$areanames{en}->{61258230} = "Quambone";
$areanames{en}->{61258231} = "Quambone";
$areanames{en}->{61258232} = "Teridgerie";
$areanames{en}->{61258233} = "Teridgerie";
$areanames{en}->{61258234} = "Dubbo";
$areanames{en}->{61258235} = "Condobolin";
$areanames{en}->{61258236} = "Coonamble";
$areanames{en}->{61258237} = "Coonabarabran";
$areanames{en}->{61258238} = "Gilgandra";
$areanames{en}->{61258239} = "Narromine";
$areanames{en}->{61258240} = "Forbes";
$areanames{en}->{61258241} = "Lightning\ Ridge";
$areanames{en}->{61258242} = "Walgett";
$areanames{en}->{61258243} = "Wellington";
$areanames{en}->{612582440} = "Airlands";
$areanames{en}->{612582441} = "Albert";
$areanames{en}->{612582442} = "Alectown";
$areanames{en}->{612582443} = "Balladoran";
$areanames{en}->{612582444} = "Ballimore";
$areanames{en}->{612582445} = "Banar";
$areanames{en}->{612582446} = "Baradine";
$areanames{en}->{612582447} = "Barrier";
$areanames{en}->{612582448} = "Barrinford";
$areanames{en}->{612582449} = "Bedgerebong";
$areanames{en}->{612582450} = "Berkley\ Downs";
$areanames{en}->{612582451} = "Bindogundra";
$areanames{en}->{612582452} = "Binnaway";
$areanames{en}->{612582453} = "Bobadah";
$areanames{en}->{612582454} = "Bogan\ Gate";
$areanames{en}->{612582455} = "Bonnay";
$areanames{en}->{612582456} = "Boona\ Mountain";
$areanames{en}->{612582457} = "Boorooma";
$areanames{en}->{612582458} = "Borah\ Tank";
$areanames{en}->{612582459} = "Bourke";
$areanames{en}->{612582460} = "Brewarrina";
$areanames{en}->{612582461} = "Bruie\ Plains";
$areanames{en}->{612582462} = "Buckinguy";
$areanames{en}->{612582463} = "Carinda";
$areanames{en}->{612582464} = "Coalbaggie";
$areanames{en}->{612582465} = "Cobar";
$areanames{en}->{612582466} = "Colane";
$areanames{en}->{612582467} = "Collie";
$areanames{en}->{612582468} = "Condobolin";
$areanames{en}->{612582469} = "Coolabah";
$areanames{en}->{612582470} = "Coonabarabran";
$areanames{en}->{612582471} = "Coonamble";
$areanames{en}->{612582472} = "Cumborah";
$areanames{en}->{612582473} = "Curban";
$areanames{en}->{612582474} = "Cuttaburra";
$areanames{en}->{612582475} = "Dandaloo";
$areanames{en}->{612582476} = "Double\ Peaks";
$areanames{en}->{612582477} = "Dubbo";
$areanames{en}->{612582478} = "Eugowra";
$areanames{en}->{612582479} = "Fairholme";
$areanames{en}->{612582480} = "Farrendale";
$areanames{en}->{612582481} = "Forbes";
$areanames{en}->{612582482} = "Geurie";
$areanames{en}->{612582483} = "Gilgandra";
$areanames{en}->{612582484} = "Gilgooma";
$areanames{en}->{612582485} = "Ginghet";
$areanames{en}->{612582486} = "Girilambone";
$areanames{en}->{612582487} = "Gollan";
$areanames{en}->{612582488} = "Goodooga";
$areanames{en}->{612582489} = "Goorianawa";
$areanames{en}->{612582490} = "Grawin";
$areanames{en}->{612582491} = "Gulargambone";
$areanames{en}->{612582492} = "Gwabegar";
$areanames{en}->{612582493} = "Hermidale";
$areanames{en}->{612582494} = "Kiacatoo";
$areanames{en}->{612582495} = "Lake\ Cargelligo";
$areanames{en}->{612582496} = "Lightning\ Ridge";
$areanames{en}->{612582497} = "Magometon";
$areanames{en}->{612582498} = "Mandagery";
$areanames{en}->{612582499} = "Mendooran";
$areanames{en}->{612582500} = "Mount\ Foster";
$areanames{en}->{612582501} = "Mount\ Herring";
$areanames{en}->{612582502} = "Mullengudgery";
$areanames{en}->{612582503} = "Mungery";
$areanames{en}->{612582504} = "Myamley";
$areanames{en}->{612582505} = "Naradhan";
$areanames{en}->{612582506} = "Narran";
$areanames{en}->{612582507} = "Narromine";
$areanames{en}->{612582508} = "Neilrex";
$areanames{en}->{612582509} = "Nyngan";
$areanames{en}->{612582510} = "Parkes";
$areanames{en}->{612582511} = "Peak\ Hill";
$areanames{en}->{612582512} = "Purlewaugh";
$areanames{en}->{612582513} = "Quambone";
$areanames{en}->{612582514} = "Rocky\ Glen";
$areanames{en}->{612582515} = "Stuart\ Town";
$areanames{en}->{612582516} = "Teridgerie";
$areanames{en}->{612582517} = "Tooraweenah";
$areanames{en}->{612582518} = "Tottenham";
$areanames{en}->{612582519} = "Trangie";
$areanames{en}->{612582520} = "Trundle";
$areanames{en}->{612582521} = "Tullamore";
$areanames{en}->{612582522} = "Tyrie";
$areanames{en}->{612582523} = "Walgett";
$areanames{en}->{612582524} = "Warren";
$areanames{en}->{612582525} = "Warrington";
$areanames{en}->{612582526} = "Warrumbungle";
$areanames{en}->{612582527} = "Weelong";
$areanames{en}->{612582528} = "Weetaliba";
$areanames{en}->{612582529} = "Wellington";
$areanames{en}->{612582530} = "Widgeland";
$areanames{en}->{612582531} = "Wirrinya";
$areanames{en}->{612582532} = "Wyanga";
$areanames{en}->{612582533} = "Yarrabandai";
$areanames{en}->{612582534} = "Yarragrin";
$areanames{en}->{612582535} = "Yeoval";
$areanames{en}->{612582536} = "Airlands";
$areanames{en}->{612582537} = "Albert";
$areanames{en}->{612582538} = "Alectown";
$areanames{en}->{612582539} = "Balladoran";
$areanames{en}->{61258254} = "Balladoran";
$areanames{en}->{61258255} = "Ballimore";
$areanames{en}->{61258256} = "Banar";
$areanames{en}->{61258257} = "Baradine";
$areanames{en}->{61258258} = "Bedgerebong";
$areanames{en}->{61258259} = "Bindogundra";
$areanames{en}->{61258260} = "Binnaway";
$areanames{en}->{61258261} = "Bobadah";
$areanames{en}->{61258262} = "Bogan\ Gate";
$areanames{en}->{61258263} = "Bonnay";
$areanames{en}->{61258264} = "Boorooma";
$areanames{en}->{61258265} = "Bruie\ Plains";
$areanames{en}->{61258266} = "Coalbaggie";
$areanames{en}->{61258267} = "Collie";
$areanames{en}->{61258268} = "Coolabah";
$areanames{en}->{61258269} = "Cumborah";
$areanames{en}->{61258270} = "Dandaloo";
$areanames{en}->{61258271} = "Double\ Peaks";
$areanames{en}->{61258272} = "Eugowra";
$areanames{en}->{61258273} = "Fairholme";
$areanames{en}->{61258274} = "Geurie";
$areanames{en}->{61258275} = "Gilgandra";
$areanames{en}->{61258276} = "Girilambone";
$areanames{en}->{61258277} = "Gollan";
$areanames{en}->{61258278} = "Goodooga";
$areanames{en}->{61258279} = "Grawin";
$areanames{en}->{61258280} = "Gwabegar";
$areanames{en}->{61258281} = "Hermidale";
$areanames{en}->{61258282} = "Kiacatoo";
$areanames{en}->{61258283} = "Lake\ Cargelligo";
$areanames{en}->{61258284} = "Lightning\ Ridge";
$areanames{en}->{61258285} = "Mendooran";
$areanames{en}->{61258286} = "Mount\ Foster";
$areanames{en}->{61258287} = "Mount\ Herring";
$areanames{en}->{61258288} = "Mullengudgery";
$areanames{en}->{61258289} = "Myamley";
$areanames{en}->{61258290} = "Narromine";
$areanames{en}->{61258291} = "Neilrex";
$areanames{en}->{61258292} = "Nyngan";
$areanames{en}->{61258293} = "Parkes";
$areanames{en}->{61258294} = "Peak\ Hill";
$areanames{en}->{61258295} = "Purlewaugh";
$areanames{en}->{61258296} = "Stuart\ Town";
$areanames{en}->{61258297} = "Tooraweenah";
$areanames{en}->{61258298} = "Tottenham";
$areanames{en}->{61258299} = "Trangie";
$areanames{en}->{61258300} = "Trundle";
$areanames{en}->{61258301} = "Tullamore";
$areanames{en}->{61258302} = "Tyrie";
$areanames{en}->{61258303} = "Walgett";
$areanames{en}->{61258304} = "Weelong";
$areanames{en}->{61258305} = "Wellington";
$areanames{en}->{61258306} = "Widgeland";
$areanames{en}->{61258307} = "Wirrinya";
$areanames{en}->{61258308} = "Wyanga";
$areanames{en}->{61258309} = "Yeoval";
$areanames{en}->{61258310} = "Goorianawa";
$areanames{en}->{61258311} = "Albert";
$areanames{en}->{61258312} = "Alectown";
$areanames{en}->{612583130} = "Ballimore";
$areanames{en}->{612583131} = "Banar";
$areanames{en}->{612583132} = "Baradine";
$areanames{en}->{612583133} = "Barrier";
$areanames{en}->{612583134} = "Barrinford";
$areanames{en}->{612583135} = "Bedgerebong";
$areanames{en}->{612583136} = "Berkley\ Downs";
$areanames{en}->{612583137} = "Bindogundra";
$areanames{en}->{612583138} = "Binnaway";
$areanames{en}->{612583139} = "Bobadah";
$areanames{en}->{612583140} = "Bogan\ Gate";
$areanames{en}->{612583141} = "Bonnay";
$areanames{en}->{612583142} = "Boona\ Mountain";
$areanames{en}->{612583143} = "Boorooma";
$areanames{en}->{612583144} = "Borah\ Tank";
$areanames{en}->{612583145} = "Bourke";
$areanames{en}->{612583146} = "Brewarrina";
$areanames{en}->{612583147} = "Bruie\ Plains";
$areanames{en}->{612583148} = "Buckinguy";
$areanames{en}->{612583149} = "Carinda";
$areanames{en}->{612583150} = "Coalbaggie";
$areanames{en}->{612583151} = "Cobar";
$areanames{en}->{612583152} = "Colane";
$areanames{en}->{612583153} = "Collie";
$areanames{en}->{612583154} = "Condobolin";
$areanames{en}->{612583155} = "Coolabah";
$areanames{en}->{612583156} = "Coonabarabran";
$areanames{en}->{612583157} = "Coonamble";
$areanames{en}->{612583158} = "Cumborah";
$areanames{en}->{612583159} = "Curban";
$areanames{en}->{612583160} = "Cuttaburra";
$areanames{en}->{612583161} = "Dandaloo";
$areanames{en}->{612583162} = "Double\ Peaks";
$areanames{en}->{612583163} = "Dubbo";
$areanames{en}->{612583164} = "Eugowra";
$areanames{en}->{612583165} = "Fairholme";
$areanames{en}->{612583166} = "Farrendale";
$areanames{en}->{612583167} = "Forbes";
$areanames{en}->{612583168} = "Geurie";
$areanames{en}->{612583169} = "Gilgandra";
$areanames{en}->{612583170} = "Gilgooma";
$areanames{en}->{612583171} = "Ginghet";
$areanames{en}->{612583172} = "Girilambone";
$areanames{en}->{612583173} = "Gollan";
$areanames{en}->{612583174} = "Goodooga";
$areanames{en}->{612583175} = "Goorianawa";
$areanames{en}->{612583176} = "Grawin";
$areanames{en}->{612583177} = "Gulargambone";
$areanames{en}->{612583178} = "Gwabegar";
$areanames{en}->{612583179} = "Hermidale";
$areanames{en}->{612583180} = "Kiacatoo";
$areanames{en}->{612583181} = "Lake\ Cargelligo";
$areanames{en}->{612583182} = "Lightning\ Ridge";
$areanames{en}->{612583183} = "Magometon";
$areanames{en}->{612583184} = "Mandagery";
$areanames{en}->{612583185} = "Mendooran";
$areanames{en}->{612583186} = "Mount\ Foster";
$areanames{en}->{612583187} = "Mount\ Herring";
$areanames{en}->{612583188} = "Mullengudgery";
$areanames{en}->{612583189} = "Mungery";
$areanames{en}->{612583190} = "Myamley";
$areanames{en}->{612583191} = "Naradhan";
$areanames{en}->{612583192} = "Narran";
$areanames{en}->{612583193} = "Narromine";
$areanames{en}->{612583194} = "Neilrex";
$areanames{en}->{612583195} = "Nyngan";
$areanames{en}->{612583196} = "Parkes";
$areanames{en}->{612583197} = "Peak\ Hill";
$areanames{en}->{612583198} = "Purlewaugh";
$areanames{en}->{612583199} = "Quambone";
$areanames{en}->{612583200} = "Rocky\ Glen";
$areanames{en}->{612583201} = "Stuart\ Town";
$areanames{en}->{612583202} = "Teridgerie";
$areanames{en}->{612583203} = "Tooraweenah";
$areanames{en}->{612583204} = "Tottenham";
$areanames{en}->{612583205} = "Trangie";
$areanames{en}->{612583206} = "Trundle";
$areanames{en}->{612583207} = "Tullamore";
$areanames{en}->{612583208} = "Tyrie";
$areanames{en}->{612583209} = "Walgett";
$areanames{en}->{612583210} = "Warren";
$areanames{en}->{612583211} = "Warrington";
$areanames{en}->{612583212} = "Warrumbungle";
$areanames{en}->{612583213} = "Weelong";
$areanames{en}->{612583214} = "Weetaliba";
$areanames{en}->{612583215} = "Wellington";
$areanames{en}->{612583216} = "Widgeland";
$areanames{en}->{612583217} = "Wirrinya";
$areanames{en}->{612583218} = "Wyanga";
$areanames{en}->{612583219} = "Yarrabandai";
$areanames{en}->{612583220} = "Yarragrin";
$areanames{en}->{612583221} = "Yeoval";
$areanames{en}->{612583222} = "Airlands";
$areanames{en}->{612583223} = "Albert";
$areanames{en}->{612583224} = "Alectown";
$areanames{en}->{612583225} = "Balladoran";
$areanames{en}->{612583226} = "Ballimore";
$areanames{en}->{612583227} = "Banar";
$areanames{en}->{612583228} = "Baradine";
$areanames{en}->{612583229} = "Barrier";
$areanames{en}->{612583230} = "Barrinford";
$areanames{en}->{612583231} = "Bedgerebong";
$areanames{en}->{612583232} = "Berkley\ Downs";
$areanames{en}->{612583233} = "Bindogundra";
$areanames{en}->{612583234} = "Binnaway";
$areanames{en}->{612583235} = "Bobadah";
$areanames{en}->{612583236} = "Bogan\ Gate";
$areanames{en}->{612583237} = "Bonnay";
$areanames{en}->{612583238} = "Boona\ Mountain";
$areanames{en}->{612583239} = "Boorooma";
$areanames{en}->{612583240} = "Borah\ Tank";
$areanames{en}->{612583241} = "Bourke";
$areanames{en}->{612583242} = "Brewarrina";
$areanames{en}->{612583243} = "Bruie\ Plains";
$areanames{en}->{612583244} = "Buckinguy";
$areanames{en}->{612583245} = "Carinda";
$areanames{en}->{612583246} = "Coalbaggie";
$areanames{en}->{612583247} = "Cobar";
$areanames{en}->{612583248} = "Colane";
$areanames{en}->{612583249} = "Collie";
$areanames{en}->{612583250} = "Condobolin";
$areanames{en}->{612583251} = "Coolabah";
$areanames{en}->{612583252} = "Coonabarabran";
$areanames{en}->{612583253} = "Coonamble";
$areanames{en}->{612583254} = "Cumborah";
$areanames{en}->{612583255} = "Curban";
$areanames{en}->{612583256} = "Cuttaburra";
$areanames{en}->{612583257} = "Dandaloo";
$areanames{en}->{612583258} = "Double\ Peaks";
$areanames{en}->{612583259} = "Dubbo";
$areanames{en}->{612583260} = "Eugowra";
$areanames{en}->{612583261} = "Fairholme";
$areanames{en}->{612583262} = "Farrendale";
$areanames{en}->{612583263} = "Forbes";
$areanames{en}->{612583264} = "Geurie";
$areanames{en}->{612583265} = "Gilgandra";
$areanames{en}->{612583266} = "Gilgooma";
$areanames{en}->{612583267} = "Ginghet";
$areanames{en}->{612583268} = "Girilambone";
$areanames{en}->{612583269} = "Gollan";
$areanames{en}->{612583270} = "Goodooga";
$areanames{en}->{612583271} = "Goorianawa";
$areanames{en}->{612583272} = "Grawin";
$areanames{en}->{612583273} = "Gulargambone";
$areanames{en}->{612583274} = "Gwabegar";
$areanames{en}->{612583275} = "Hermidale";
$areanames{en}->{612583276} = "Kiacatoo";
$areanames{en}->{612583277} = "Lake\ Cargelligo";
$areanames{en}->{612583278} = "Lightning\ Ridge";
$areanames{en}->{612583279} = "Magometon";
$areanames{en}->{612583280} = "Mandagery";
$areanames{en}->{612583281} = "Mendooran";
$areanames{en}->{612583282} = "Mount\ Foster";
$areanames{en}->{612583283} = "Mount\ Herring";
$areanames{en}->{612583284} = "Mullengudgery";
$areanames{en}->{612583285} = "Mungery";
$areanames{en}->{612583286} = "Myamley";
$areanames{en}->{612583287} = "Naradhan";
$areanames{en}->{612583288} = "Narran";
$areanames{en}->{612583289} = "Narromine";
$areanames{en}->{612583290} = "Neilrex";
$areanames{en}->{612583291} = "Nyngan";
$areanames{en}->{612583292} = "Parkes";
$areanames{en}->{612583293} = "Peak\ Hill";
$areanames{en}->{612583294} = "Purlewaugh";
$areanames{en}->{612583295} = "Quambone";
$areanames{en}->{612583296} = "Rocky\ Glen";
$areanames{en}->{612583297} = "Stuart\ Town";
$areanames{en}->{612583298} = "Teridgerie";
$areanames{en}->{612583299} = "Tooraweenah";
$areanames{en}->{612583300} = "Tottenham";
$areanames{en}->{612583301} = "Trangie";
$areanames{en}->{612583302} = "Trundle";
$areanames{en}->{612583303} = "Tullamore";
$areanames{en}->{612583304} = "Tyrie";
$areanames{en}->{612583305} = "Walgett";
$areanames{en}->{612583306} = "Warren";
$areanames{en}->{612583307} = "Warrington";
$areanames{en}->{612583308} = "Warrumbungle";
$areanames{en}->{612583309} = "Weelong";
$areanames{en}->{612583310} = "Weetaliba";
$areanames{en}->{612583311} = "Wellington";
$areanames{en}->{612583312} = "Widgeland";
$areanames{en}->{612583313} = "Wirrinya";
$areanames{en}->{612583314} = "Wyanga";
$areanames{en}->{612583315} = "Yarrabandai";
$areanames{en}->{612583316} = "Yarragrin";
$areanames{en}->{612583317} = "Yeoval";
$areanames{en}->{612583318} = "Airlands";
$areanames{en}->{612583319} = "Albert";
$areanames{en}->{61258332} = "Bourke";
$areanames{en}->{61258333} = "Dubbo";
$areanames{en}->{61258334} = "Wellington";
$areanames{en}->{61258335} = "Nyngan";
$areanames{en}->{61258336} = "Cobar";
$areanames{en}->{61258337} = "Gilgandra";
$areanames{en}->{61258338} = "Coalbaggie";
$areanames{en}->{612583390} = "Alectown";
$areanames{en}->{612583391} = "Balladoran";
$areanames{en}->{612583392} = "Ballimore";
$areanames{en}->{612583393} = "Banar";
$areanames{en}->{612583394} = "Baradine";
$areanames{en}->{612583395} = "Barrier";
$areanames{en}->{612583396} = "Barrinford";
$areanames{en}->{612583397} = "Bedgerebong";
$areanames{en}->{612583398} = "Berkley\ Downs";
$areanames{en}->{612583399} = "Bindogundra";
$areanames{en}->{612583400} = "Binnaway";
$areanames{en}->{612583401} = "Bobadah";
$areanames{en}->{612583402} = "Bogan\ Gate";
$areanames{en}->{612583403} = "Bonnay";
$areanames{en}->{612583404} = "Boona\ Mountain";
$areanames{en}->{612583405} = "Boorooma";
$areanames{en}->{612583406} = "Borah\ Tank";
$areanames{en}->{612583407} = "Bourke";
$areanames{en}->{612583408} = "Brewarrina";
$areanames{en}->{612583409} = "Bruie\ Plains";
$areanames{en}->{612583410} = "Buckinguy";
$areanames{en}->{612583411} = "Carinda";
$areanames{en}->{612583412} = "Coalbaggie";
$areanames{en}->{612583413} = "Cobar";
$areanames{en}->{612583414} = "Colane";
$areanames{en}->{612583415} = "Collie";
$areanames{en}->{612583416} = "Condobolin";
$areanames{en}->{612583417} = "Coolabah";
$areanames{en}->{612583418} = "Coonabarabran";
$areanames{en}->{612583419} = "Coonamble";
$areanames{en}->{612583420} = "Cumborah";
$areanames{en}->{612583421} = "Curban";
$areanames{en}->{612583422} = "Cuttaburra";
$areanames{en}->{612583423} = "Dandaloo";
$areanames{en}->{612583424} = "Airlands";
$areanames{en}->{612583425} = "Albert";
$areanames{en}->{612583426} = "Alectown";
$areanames{en}->{612583427} = "Balladoran";
$areanames{en}->{612583428} = "Ballimore";
$areanames{en}->{612583429} = "Banar";
$areanames{en}->{612583430} = "Baradine";
$areanames{en}->{612583431} = "Barrier";
$areanames{en}->{612583432} = "Barrinford";
$areanames{en}->{612583433} = "Bedgerebong";
$areanames{en}->{612583434} = "Berkley\ Downs";
$areanames{en}->{612583435} = "Bindogundra";
$areanames{en}->{612583436} = "Binnaway";
$areanames{en}->{612583437} = "Bobadah";
$areanames{en}->{612583438} = "Bogan\ Gate";
$areanames{en}->{612583439} = "Bonnay";
$areanames{en}->{612583440} = "Boona\ Mountain";
$areanames{en}->{612583441} = "Boorooma";
$areanames{en}->{612583442} = "Borah\ Tank";
$areanames{en}->{612583443} = "Bourke";
$areanames{en}->{612583444} = "Brewarrina";
$areanames{en}->{612583445} = "Bruie\ Plains";
$areanames{en}->{612583446} = "Buckinguy";
$areanames{en}->{612583447} = "Carinda";
$areanames{en}->{612583448} = "Coalbaggie";
$areanames{en}->{612583449} = "Cobar";
$areanames{en}->{61258345} = "Barrier";
$areanames{en}->{61258346} = "Condobolin";
$areanames{en}->{61258347} = "Bourke";
$areanames{en}->{61258348} = "Airlands";
$areanames{en}->{61258349} = "Brewarrina";
$areanames{en}->{612583500} = "Colane";
$areanames{en}->{612583501} = "Collie";
$areanames{en}->{612583502} = "Condobolin";
$areanames{en}->{612583503} = "Coolabah";
$areanames{en}->{612583504} = "Coonabarabran";
$areanames{en}->{612583505} = "Coonamble";
$areanames{en}->{612583506} = "Cumborah";
$areanames{en}->{612583507} = "Curban";
$areanames{en}->{612583508} = "Cuttaburra";
$areanames{en}->{612583509} = "Dandaloo";
$areanames{en}->{612583510} = "Double\ Peaks";
$areanames{en}->{612583511} = "Dubbo";
$areanames{en}->{612583512} = "Eugowra";
$areanames{en}->{612583513} = "Fairholme";
$areanames{en}->{612583514} = "Farrendale";
$areanames{en}->{612583515} = "Forbes";
$areanames{en}->{612583516} = "Geurie";
$areanames{en}->{612583517} = "Gilgandra";
$areanames{en}->{612583518} = "Gilgooma";
$areanames{en}->{612583519} = "Ginghet";
$areanames{en}->{612583520} = "Girilambone";
$areanames{en}->{612583521} = "Gollan";
$areanames{en}->{612583522} = "Goodooga";
$areanames{en}->{612583523} = "Goorianawa";
$areanames{en}->{612583524} = "Grawin";
$areanames{en}->{612583525} = "Gulargambone";
$areanames{en}->{612583526} = "Gwabegar";
$areanames{en}->{612583527} = "Hermidale";
$areanames{en}->{612583528} = "Kiacatoo";
$areanames{en}->{612583529} = "Lake\ Cargelligo";
$areanames{en}->{612583530} = "Lightning\ Ridge";
$areanames{en}->{612583531} = "Magometon";
$areanames{en}->{612583532} = "Mandagery";
$areanames{en}->{612583533} = "Mendooran";
$areanames{en}->{612583534} = "Mount\ Foster";
$areanames{en}->{612583535} = "Mount\ Herring";
$areanames{en}->{612583536} = "Mullengudgery";
$areanames{en}->{612583537} = "Mungery";
$areanames{en}->{612583538} = "Myamley";
$areanames{en}->{612583539} = "Naradhan";
$areanames{en}->{612583540} = "Narran";
$areanames{en}->{612583541} = "Narromine";
$areanames{en}->{612583542} = "Neilrex";
$areanames{en}->{612583543} = "Nyngan";
$areanames{en}->{612583544} = "Parkes";
$areanames{en}->{612583545} = "Peak\ Hill";
$areanames{en}->{612583546} = "Purlewaugh";
$areanames{en}->{612583547} = "Quambone";
$areanames{en}->{612583548} = "Rocky\ Glen";
$areanames{en}->{612583549} = "Stuart\ Town";
$areanames{en}->{612583550} = "Teridgerie";
$areanames{en}->{612583551} = "Tooraweenah";
$areanames{en}->{612583552} = "Tottenham";
$areanames{en}->{612583553} = "Trangie";
$areanames{en}->{612583554} = "Trundle";
$areanames{en}->{612583555} = "Tullamore";
$areanames{en}->{612583556} = "Tyrie";
$areanames{en}->{612583557} = "Walgett";
$areanames{en}->{612583558} = "Warren";
$areanames{en}->{612583559} = "Warrington";
$areanames{en}->{612583560} = "Warrumbungle";
$areanames{en}->{612583561} = "Weelong";
$areanames{en}->{612583562} = "Weetaliba";
$areanames{en}->{612583563} = "Wellington";
$areanames{en}->{612583564} = "Widgeland";
$areanames{en}->{612583565} = "Wirrinya";
$areanames{en}->{612583566} = "Wyanga";
$areanames{en}->{612583567} = "Yarrabandai";
$areanames{en}->{612583568} = "Yarragrin";
$areanames{en}->{612583569} = "Yeoval";
$areanames{en}->{61258357} = "Bindogundra";
$areanames{en}->{61258358} = "Bindogundra";
$areanames{en}->{61258359} = "Bindogundra";
$areanames{en}->{612583600} = "Double\ Peaks";
$areanames{en}->{612583601} = "Dubbo";
$areanames{en}->{612583602} = "Eugowra";
$areanames{en}->{612583603} = "Fairholme";
$areanames{en}->{612583604} = "Farrendale";
$areanames{en}->{612583605} = "Forbes";
$areanames{en}->{612583606} = "Geurie";
$areanames{en}->{612583607} = "Gilgandra";
$areanames{en}->{612583608} = "Gilgooma";
$areanames{en}->{612583609} = "Ginghet";
$areanames{en}->{612583610} = "Girilambone";
$areanames{en}->{612583611} = "Gollan";
$areanames{en}->{612583612} = "Goodooga";
$areanames{en}->{612583613} = "Goorianawa";
$areanames{en}->{612583614} = "Grawin";
$areanames{en}->{612583615} = "Gulargambone";
$areanames{en}->{612583616} = "Gwabegar";
$areanames{en}->{612583617} = "Hermidale";
$areanames{en}->{612583618} = "Kiacatoo";
$areanames{en}->{612583619} = "Lake\ Cargelligo";
$areanames{en}->{612583620} = "Lightning\ Ridge";
$areanames{en}->{612583621} = "Magometon";
$areanames{en}->{612583622} = "Mandagery";
$areanames{en}->{612583623} = "Mendooran";
$areanames{en}->{612583624} = "Mount\ Foster";
$areanames{en}->{612583625} = "Mount\ Herring";
$areanames{en}->{612583626} = "Mullengudgery";
$areanames{en}->{612583627} = "Mungery";
$areanames{en}->{612583628} = "Myamley";
$areanames{en}->{612583629} = "Naradhan";
$areanames{en}->{612583630} = "Narran";
$areanames{en}->{612583631} = "Narromine";
$areanames{en}->{612583632} = "Neilrex";
$areanames{en}->{612583633} = "Nyngan";
$areanames{en}->{612583634} = "Parkes";
$areanames{en}->{612583635} = "Peak\ Hill";
$areanames{en}->{612583636} = "Purlewaugh";
$areanames{en}->{612583637} = "Quambone";
$areanames{en}->{612583638} = "Rocky\ Glen";
$areanames{en}->{612583639} = "Stuart\ Town";
$areanames{en}->{612583640} = "Teridgerie";
$areanames{en}->{612583641} = "Tooraweenah";
$areanames{en}->{612583642} = "Tottenham";
$areanames{en}->{612583643} = "Trangie";
$areanames{en}->{612583644} = "Trundle";
$areanames{en}->{612583645} = "Tullamore";
$areanames{en}->{612583646} = "Tyrie";
$areanames{en}->{612583647} = "Walgett";
$areanames{en}->{612583648} = "Warren";
$areanames{en}->{612583649} = "Warrington";
$areanames{en}->{612583650} = "Warrumbungle";
$areanames{en}->{612583651} = "Weelong";
$areanames{en}->{612583652} = "Weetaliba";
$areanames{en}->{612583653} = "Wellington";
$areanames{en}->{612583654} = "Widgeland";
$areanames{en}->{612583655} = "Wirrinya";
$areanames{en}->{612583656} = "Wyanga";
$areanames{en}->{612583657} = "Yarrabandai";
$areanames{en}->{612583658} = "Yarragrin";
$areanames{en}->{612583659} = "Yeoval";
$areanames{en}->{612583660} = "Airlands";
$areanames{en}->{612583661} = "Albert";
$areanames{en}->{612583662} = "Alectown";
$areanames{en}->{612583663} = "Balladoran";
$areanames{en}->{612583664} = "Ballimore";
$areanames{en}->{612583665} = "Banar";
$areanames{en}->{612583666} = "Baradine";
$areanames{en}->{612583667} = "Barrier";
$areanames{en}->{612583668} = "Barrinford";
$areanames{en}->{612583669} = "Bedgerebong";
$areanames{en}->{612583670} = "Berkley\ Downs";
$areanames{en}->{612583671} = "Bindogundra";
$areanames{en}->{612583672} = "Binnaway";
$areanames{en}->{612583673} = "Bobadah";
$areanames{en}->{612583674} = "Bogan\ Gate";
$areanames{en}->{612583675} = "Bonnay";
$areanames{en}->{612583676} = "Boona\ Mountain";
$areanames{en}->{612583677} = "Boorooma";
$areanames{en}->{612583678} = "Borah\ Tank";
$areanames{en}->{612583679} = "Bourke";
$areanames{en}->{612583680} = "Brewarrina";
$areanames{en}->{612583681} = "Bruie\ Plains";
$areanames{en}->{612583682} = "Buckinguy";
$areanames{en}->{612583683} = "Carinda";
$areanames{en}->{612583684} = "Coalbaggie";
$areanames{en}->{612583685} = "Cobar";
$areanames{en}->{612583686} = "Colane";
$areanames{en}->{612583687} = "Collie";
$areanames{en}->{612583688} = "Condobolin";
$areanames{en}->{612583689} = "Coolabah";
$areanames{en}->{612583690} = "Coonabarabran";
$areanames{en}->{612583691} = "Coonamble";
$areanames{en}->{612583692} = "Cumborah";
$areanames{en}->{612583693} = "Curban";
$areanames{en}->{612583694} = "Cuttaburra";
$areanames{en}->{612583695} = "Dandaloo";
$areanames{en}->{612583696} = "Double\ Peaks";
$areanames{en}->{612583697} = "Dubbo";
$areanames{en}->{612583698} = "Eugowra";
$areanames{en}->{612583699} = "Fairholme";
$areanames{en}->{612583700} = "Farrendale";
$areanames{en}->{612583701} = "Forbes";
$areanames{en}->{612583702} = "Geurie";
$areanames{en}->{612583703} = "Gilgandra";
$areanames{en}->{612583704} = "Gilgooma";
$areanames{en}->{612583705} = "Ginghet";
$areanames{en}->{612583706} = "Girilambone";
$areanames{en}->{612583707} = "Gollan";
$areanames{en}->{612583708} = "Goodooga";
$areanames{en}->{612583709} = "Goorianawa";
$areanames{en}->{612583710} = "Grawin";
$areanames{en}->{612583711} = "Gulargambone";
$areanames{en}->{612583712} = "Gwabegar";
$areanames{en}->{612583713} = "Hermidale";
$areanames{en}->{612583714} = "Kiacatoo";
$areanames{en}->{612583715} = "Lake\ Cargelligo";
$areanames{en}->{612583716} = "Lightning\ Ridge";
$areanames{en}->{612583717} = "Magometon";
$areanames{en}->{612583718} = "Mandagery";
$areanames{en}->{612583719} = "Mendooran";
$areanames{en}->{612583720} = "Mount\ Foster";
$areanames{en}->{612583721} = "Mount\ Herring";
$areanames{en}->{612583722} = "Mullengudgery";
$areanames{en}->{612583723} = "Mungery";
$areanames{en}->{612583724} = "Myamley";
$areanames{en}->{612583725} = "Naradhan";
$areanames{en}->{612583726} = "Narran";
$areanames{en}->{612583727} = "Narromine";
$areanames{en}->{612583728} = "Neilrex";
$areanames{en}->{612583729} = "Nyngan";
$areanames{en}->{612583730} = "Parkes";
$areanames{en}->{612583731} = "Peak\ Hill";
$areanames{en}->{612583732} = "Purlewaugh";
$areanames{en}->{612583733} = "Quambone";
$areanames{en}->{612583734} = "Rocky\ Glen";
$areanames{en}->{612583735} = "Stuart\ Town";
$areanames{en}->{612583736} = "Teridgerie";
$areanames{en}->{612583737} = "Tooraweenah";
$areanames{en}->{612583738} = "Tottenham";
$areanames{en}->{612583739} = "Trangie";
$areanames{en}->{612583740} = "Trundle";
$areanames{en}->{612583741} = "Tullamore";
$areanames{en}->{612583742} = "Tyrie";
$areanames{en}->{612583743} = "Walgett";
$areanames{en}->{612583744} = "Warren";
$areanames{en}->{612583745} = "Warrington";
$areanames{en}->{612583746} = "Warrumbungle";
$areanames{en}->{612583747} = "Weelong";
$areanames{en}->{612583748} = "Weetaliba";
$areanames{en}->{612583749} = "Wellington";
$areanames{en}->{612583750} = "Widgeland";
$areanames{en}->{612583751} = "Wirrinya";
$areanames{en}->{612583752} = "Wyanga";
$areanames{en}->{612583753} = "Yarrabandai";
$areanames{en}->{612583754} = "Yarragrin";
$areanames{en}->{612583755} = "Yeoval";
$areanames{en}->{612583756} = "Airlands";
$areanames{en}->{612583757} = "Albert";
$areanames{en}->{612583758} = "Alectown";
$areanames{en}->{612583759} = "Balladoran";
$areanames{en}->{612583760} = "Ballimore";
$areanames{en}->{612583761} = "Banar";
$areanames{en}->{612583762} = "Baradine";
$areanames{en}->{612583763} = "Barrier";
$areanames{en}->{612583764} = "Barrinford";
$areanames{en}->{612583765} = "Bedgerebong";
$areanames{en}->{612583766} = "Berkley\ Downs";
$areanames{en}->{612583767} = "Bindogundra";
$areanames{en}->{612583768} = "Binnaway";
$areanames{en}->{612583769} = "Bobadah";
$areanames{en}->{612583770} = "Bogan\ Gate";
$areanames{en}->{612583771} = "Bonnay";
$areanames{en}->{612583772} = "Boona\ Mountain";
$areanames{en}->{612583773} = "Boorooma";
$areanames{en}->{612583774} = "Borah\ Tank";
$areanames{en}->{612583775} = "Bourke";
$areanames{en}->{612583776} = "Brewarrina";
$areanames{en}->{612583777} = "Bruie\ Plains";
$areanames{en}->{612583778} = "Buckinguy";
$areanames{en}->{612583779} = "Carinda";
$areanames{en}->{612583780} = "Coalbaggie";
$areanames{en}->{612583781} = "Cobar";
$areanames{en}->{612583782} = "Colane";
$areanames{en}->{612583783} = "Collie";
$areanames{en}->{612583784} = "Condobolin";
$areanames{en}->{612583785} = "Coolabah";
$areanames{en}->{612583786} = "Coonabarabran";
$areanames{en}->{612583787} = "Coonamble";
$areanames{en}->{612583788} = "Cumborah";
$areanames{en}->{612583789} = "Curban";
$areanames{en}->{612583790} = "Cuttaburra";
$areanames{en}->{612583791} = "Dandaloo";
$areanames{en}->{612583792} = "Double\ Peaks";
$areanames{en}->{612583793} = "Dubbo";
$areanames{en}->{612583794} = "Eugowra";
$areanames{en}->{612583795} = "Fairholme";
$areanames{en}->{612583796} = "Farrendale";
$areanames{en}->{612583797} = "Forbes";
$areanames{en}->{612583798} = "Geurie";
$areanames{en}->{612583799} = "Gilgandra";
$areanames{en}->{612583800} = "Gilgooma";
$areanames{en}->{612583801} = "Ginghet";
$areanames{en}->{612583802} = "Girilambone";
$areanames{en}->{612583803} = "Gollan";
$areanames{en}->{612583804} = "Goodooga";
$areanames{en}->{612583805} = "Goorianawa";
$areanames{en}->{612583806} = "Grawin";
$areanames{en}->{612583807} = "Gulargambone";
$areanames{en}->{612583808} = "Gwabegar";
$areanames{en}->{612583809} = "Hermidale";
$areanames{en}->{612583810} = "Kiacatoo";
$areanames{en}->{612583811} = "Lake\ Cargelligo";
$areanames{en}->{612583812} = "Lightning\ Ridge";
$areanames{en}->{612583813} = "Magometon";
$areanames{en}->{612583814} = "Mandagery";
$areanames{en}->{612583815} = "Mendooran";
$areanames{en}->{612583816} = "Mount\ Foster";
$areanames{en}->{612583817} = "Mount\ Herring";
$areanames{en}->{612583818} = "Mullengudgery";
$areanames{en}->{612583819} = "Mungery";
$areanames{en}->{612583820} = "Myamley";
$areanames{en}->{612583821} = "Naradhan";
$areanames{en}->{612583822} = "Narran";
$areanames{en}->{612583823} = "Narromine";
$areanames{en}->{612583824} = "Neilrex";
$areanames{en}->{612583825} = "Nyngan";
$areanames{en}->{612583826} = "Parkes";
$areanames{en}->{612583827} = "Peak\ Hill";
$areanames{en}->{612583828} = "Purlewaugh";
$areanames{en}->{612583829} = "Quambone";
$areanames{en}->{612583830} = "Rocky\ Glen";
$areanames{en}->{612583831} = "Stuart\ Town";
$areanames{en}->{612583832} = "Teridgerie";
$areanames{en}->{612583833} = "Tooraweenah";
$areanames{en}->{612583834} = "Tottenham";
$areanames{en}->{612583835} = "Trangie";
$areanames{en}->{612583836} = "Trundle";
$areanames{en}->{612583837} = "Tullamore";
$areanames{en}->{612583838} = "Tyrie";
$areanames{en}->{612583839} = "Walgett";
$areanames{en}->{612583840} = "Warren";
$areanames{en}->{612583841} = "Warrington";
$areanames{en}->{612583842} = "Warrumbungle";
$areanames{en}->{612583843} = "Weelong";
$areanames{en}->{612583844} = "Weetaliba";
$areanames{en}->{612583845} = "Wellington";
$areanames{en}->{612583846} = "Widgeland";
$areanames{en}->{612583847} = "Wirrinya";
$areanames{en}->{612583848} = "Wyanga";
$areanames{en}->{612583849} = "Yarrabandai";
$areanames{en}->{612583850} = "Yarragrin";
$areanames{en}->{612583851} = "Yeoval";
$areanames{en}->{612583852} = "Airlands";
$areanames{en}->{612583853} = "Albert";
$areanames{en}->{612583854} = "Alectown";
$areanames{en}->{612583855} = "Balladoran";
$areanames{en}->{612583856} = "Ballimore";
$areanames{en}->{612583857} = "Banar";
$areanames{en}->{612583858} = "Baradine";
$areanames{en}->{612583859} = "Barrier";
$areanames{en}->{61258386} = "Dubbo";
$areanames{en}->{612583870} = "Barrinford";
$areanames{en}->{612583871} = "Bedgerebong";
$areanames{en}->{612583872} = "Berkley\ Downs";
$areanames{en}->{612583873} = "Bindogundra";
$areanames{en}->{612583874} = "Binnaway";
$areanames{en}->{612583875} = "Bobadah";
$areanames{en}->{612583876} = "Bogan\ Gate";
$areanames{en}->{612583877} = "Bonnay";
$areanames{en}->{612583878} = "Boona\ Mountain";
$areanames{en}->{612583879} = "Boorooma";
$areanames{en}->{612583880} = "Borah\ Tank";
$areanames{en}->{612583881} = "Bourke";
$areanames{en}->{612583882} = "Brewarrina";
$areanames{en}->{612583883} = "Bruie\ Plains";
$areanames{en}->{612583884} = "Buckinguy";
$areanames{en}->{612583885} = "Carinda";
$areanames{en}->{612583886} = "Coalbaggie";
$areanames{en}->{612583887} = "Cobar";
$areanames{en}->{612583888} = "Colane";
$areanames{en}->{612583889} = "Collie";
$areanames{en}->{612583890} = "Condobolin";
$areanames{en}->{612583891} = "Coolabah";
$areanames{en}->{612583892} = "Coonabarabran";
$areanames{en}->{612583893} = "Coonamble";
$areanames{en}->{612583894} = "Cumborah";
$areanames{en}->{612583895} = "Curban";
$areanames{en}->{612583896} = "Cuttaburra";
$areanames{en}->{612583897} = "Dandaloo";
$areanames{en}->{612583898} = "Double\ Peaks";
$areanames{en}->{612583899} = "Dubbo";
$areanames{en}->{612583900} = "Eugowra";
$areanames{en}->{612583901} = "Fairholme";
$areanames{en}->{612583902} = "Farrendale";
$areanames{en}->{612583903} = "Forbes";
$areanames{en}->{612583904} = "Geurie";
$areanames{en}->{612583905} = "Gilgandra";
$areanames{en}->{612583906} = "Gilgooma";
$areanames{en}->{612583907} = "Ginghet";
$areanames{en}->{612583908} = "Girilambone";
$areanames{en}->{612583909} = "Gollan";
$areanames{en}->{612583910} = "Goodooga";
$areanames{en}->{612583911} = "Goorianawa";
$areanames{en}->{612583912} = "Grawin";
$areanames{en}->{612583913} = "Gulargambone";
$areanames{en}->{612583914} = "Gwabegar";
$areanames{en}->{612583915} = "Hermidale";
$areanames{en}->{612583916} = "Kiacatoo";
$areanames{en}->{612583917} = "Lake\ Cargelligo";
$areanames{en}->{612583918} = "Lightning\ Ridge";
$areanames{en}->{612583919} = "Magometon";
$areanames{en}->{612583920} = "Mandagery";
$areanames{en}->{612583921} = "Mendooran";
$areanames{en}->{612583922} = "Mount\ Foster";
$areanames{en}->{612583923} = "Mount\ Herring";
$areanames{en}->{612583924} = "Mullengudgery";
$areanames{en}->{612583925} = "Mungery";
$areanames{en}->{612583926} = "Myamley";
$areanames{en}->{612583927} = "Naradhan";
$areanames{en}->{612583928} = "Narran";
$areanames{en}->{612583929} = "Narromine";
$areanames{en}->{612583930} = "Neilrex";
$areanames{en}->{612583931} = "Nyngan";
$areanames{en}->{612583932} = "Parkes";
$areanames{en}->{612583933} = "Peak\ Hill";
$areanames{en}->{612583934} = "Purlewaugh";
$areanames{en}->{612583935} = "Quambone";
$areanames{en}->{612583936} = "Rocky\ Glen";
$areanames{en}->{612583937} = "Stuart\ Town";
$areanames{en}->{612583938} = "Teridgerie";
$areanames{en}->{612583939} = "Tooraweenah";
$areanames{en}->{612583940} = "Tottenham";
$areanames{en}->{612583941} = "Trangie";
$areanames{en}->{612583942} = "Trundle";
$areanames{en}->{612583943} = "Tullamore";
$areanames{en}->{612583944} = "Tyrie";
$areanames{en}->{612583945} = "Walgett";
$areanames{en}->{612583946} = "Warren";
$areanames{en}->{612583947} = "Warrington";
$areanames{en}->{612583948} = "Warrumbungle";
$areanames{en}->{612583949} = "Weelong";
$areanames{en}->{612583950} = "Weetaliba";
$areanames{en}->{612583951} = "Wellington";
$areanames{en}->{612583952} = "Widgeland";
$areanames{en}->{612583953} = "Wirrinya";
$areanames{en}->{612583954} = "Wyanga";
$areanames{en}->{612583955} = "Yarrabandai";
$areanames{en}->{612583956} = "Yarragrin";
$areanames{en}->{612583957} = "Yeoval";
$areanames{en}->{61258399} = "Boona\ Mountain";
$areanames{en}->{61258410} = "Buckinguy";
$areanames{en}->{61258429} = "Farrendale";
$areanames{en}->{61258440} = "Ginghet";
$areanames{en}->{61258459} = "Rocky\ Glen";
$areanames{en}->{61258470} = "Warrington";
$areanames{en}->{61258520} = "Lightning\ Ridge";
$areanames{en}->{61258521} = "Dubbo";
$areanames{en}->{61258522} = "Lightning\ Ridge";
$areanames{en}->{61258523} = "Coonamble";
$areanames{en}->{61258524} = "Dubbo";
$areanames{en}->{61258525} = "Dubbo";
$areanames{en}->{61258526} = "Dubbo";
$areanames{en}->{61258527} = "Forbes";
$areanames{en}->{61258528} = "Forbes";
$areanames{en}->{61258529} = "Forbes";
$areanames{en}->{61258530} = "Dubbo";
$areanames{en}->{61258535} = "Mount\ Herring";
$areanames{en}->{61258536} = "Barrinford";
$areanames{en}->{61258576} = "Dubbo";
$areanames{en}->{61258577} = "Dubbo";
$areanames{en}->{61258578} = "Dubbo";
$areanames{en}->{61258579} = "Walgett";
$areanames{en}->{6125858} = "Dubbo";
$areanames{en}->{61258586} = "Parkes";
$areanames{en}->{61258587} = "Parkes";
$areanames{en}->{61258588} = "Parkes";
$areanames{en}->{61258589} = "Condobolin";
$areanames{en}->{61258810} = "Warren";
$areanames{en}->{61258811} = "Warren";
$areanames{en}->{61258812} = "Warren";
$areanames{en}->{61258813} = "Balladoran";
$areanames{en}->{61258814} = "Baradine";
$areanames{en}->{61258815} = "Gwabegar";
$areanames{en}->{61258816} = "Coonabarabran";
$areanames{en}->{61258817} = "Coonabarabran";
$areanames{en}->{61258818} = "Coonabarabran";
$areanames{en}->{61258819} = "Trangie";
$areanames{en}->{61259000} = "Talbingo";
$areanames{en}->{61259001} = "Tooma";
$areanames{en}->{61259002} = "Tumbarumba";
$areanames{en}->{61259003} = "Tumorrama";
$areanames{en}->{61259004} = "Tumut";
$areanames{en}->{61259005} = "Wallendbeen";
$areanames{en}->{61259006} = "Yaven\ Creek";
$areanames{en}->{61259007} = "Barellan";
$areanames{en}->{61259008} = "Black\ Stump";
$areanames{en}->{61259009} = "Bunda";
$areanames{en}->{61259010} = "Darlington\ Point";
$areanames{en}->{61259011} = "Goolgowi";
$areanames{en}->{61259012} = "Griffith";
$areanames{en}->{61259013} = "Gunbar";
$areanames{en}->{61259014} = "Hillston";
$areanames{en}->{61259015} = "Melbergen";
$areanames{en}->{61259016} = "Merriwagga";
$areanames{en}->{61259017} = "Rankins\ Springs";
$areanames{en}->{61259018} = "Wallanthery";
$areanames{en}->{61259019} = "Warrawidgee";
$areanames{en}->{61259020} = "Wee\ Elwah";
$areanames{en}->{61259021} = "Yenda";
$areanames{en}->{61259022} = "Bambilla";
$areanames{en}->{61259023} = "Booroorban";
$areanames{en}->{61259024} = "Carrathool";
$areanames{en}->{61259025} = "Hay";
$areanames{en}->{61259026} = "Ivanhoe";
$areanames{en}->{61259027} = "Lachlan";
$areanames{en}->{61259028} = "Maude";
$areanames{en}->{61259029} = "Bundure";
$areanames{en}->{61259030} = "Coleambally";
$areanames{en}->{61259031} = "Egansford";
$areanames{en}->{61259032} = "Gala\ Vale";
$areanames{en}->{61259033} = "Grong\ Grong";
$areanames{en}->{61259034} = "Landervale";
$areanames{en}->{61259035} = "Leeton";
$areanames{en}->{61259036} = "Morundah";
$areanames{en}->{61259037} = "Narrandera";
$areanames{en}->{61259038} = "Sandigo";
$areanames{en}->{61259039} = "Stanbridge";
$areanames{en}->{61259040} = "Ardlethan";
$areanames{en}->{61259041} = "Ariah\ Park";
$areanames{en}->{61259042} = "Barmedman";
$areanames{en}->{61259043} = "Barmedman\ East";
$areanames{en}->{61259044} = "Narraburra";
$areanames{en}->{61259045} = "Springdale";
$areanames{en}->{61259046} = "Temora";
$areanames{en}->{61259047} = "Bidgeemia";
$areanames{en}->{61259048} = "Boree\ Creek";
$areanames{en}->{61259049} = "Coolamon";
$areanames{en}->{61259050} = "Cowabbie";
$areanames{en}->{61259051} = "Currawarna";
$areanames{en}->{61259052} = "Galore";
$areanames{en}->{61259053} = "Ganmain";
$areanames{en}->{61259054} = "Henty";
$areanames{en}->{61259055} = "Humula";
$areanames{en}->{61259056} = "Junee";
$areanames{en}->{61259057} = "Junee\ Reefs";
$areanames{en}->{61259058} = "Kyeamba";
$areanames{en}->{61259059} = "Lockhart";
$areanames{en}->{61259060} = "Mangoplah";
$areanames{en}->{61259061} = "Milbrulong";
$areanames{en}->{61259062} = "Rannock";
$areanames{en}->{61259063} = "Tarcutta";
$areanames{en}->{61259064} = "The\ Rock";
$areanames{en}->{61259065} = "Urana";
$areanames{en}->{61259066} = "Wantabadgery";
$areanames{en}->{61259067} = "Winchendon\ Vale";
$areanames{en}->{61259068} = "Alleena";
$areanames{en}->{61259069} = "Burcher";
$areanames{en}->{61259070} = "Kikoira";
$areanames{en}->{61259071} = "Marsden";
$areanames{en}->{61259072} = "Tallimba";
$areanames{en}->{61259073} = "Tullibigeal";
$areanames{en}->{61259074} = "Ungarie";
$areanames{en}->{61259075} = "Warralonga";
$areanames{en}->{61259076} = "Weethalle";
$areanames{en}->{61259077} = "West\ Wyalong";
$areanames{en}->{61259078} = "Coolamon";
$areanames{en}->{61259079} = "Coolamon";
$areanames{en}->{6125908} = "Wagga\ Wagga";
$areanames{en}->{61259085} = "Barmedman";
$areanames{en}->{61259086} = "Barmedman";
$areanames{en}->{61259089} = "Henty";
$areanames{en}->{61259090} = "Gundagai";
$areanames{en}->{61259091} = "Griffith";
$areanames{en}->{61259092} = "Narrandera";
$areanames{en}->{61259093} = "Leeton";
$areanames{en}->{61259094} = "West\ Wyalong";
$areanames{en}->{61259095} = "West\ Wyalong";
$areanames{en}->{61259096} = "Sandigo";
$areanames{en}->{61259097} = "Sandigo";
$areanames{en}->{61259098} = "Burra";
$areanames{en}->{61259099} = "Burra";
$areanames{en}->{61259100} = "Coolac";
$areanames{en}->{61259101} = "Coolac";
$areanames{en}->{61259102} = "Cootamundra";
$areanames{en}->{61259103} = "Cootamundra";
$areanames{en}->{61259104} = "Gundagai";
$areanames{en}->{61259105} = "Gundagai";
$areanames{en}->{61259106} = "Mannus";
$areanames{en}->{61259107} = "Mannus";
$areanames{en}->{61259108} = "Nangus";
$areanames{en}->{61259109} = "Nangus";
$areanames{en}->{61259110} = "Tumut";
$areanames{en}->{61259111} = "Tumut";
$areanames{en}->{61259112} = "Yaven\ Creek";
$areanames{en}->{61259113} = "Yaven\ Creek";
$areanames{en}->{61259114} = "Rankins\ Springs";
$areanames{en}->{61259115} = "Rankins\ Springs";
$areanames{en}->{61259116} = "Narrandera";
$areanames{en}->{61259117} = "Narrandera";
$areanames{en}->{61259118} = "Cowabbie";
$areanames{en}->{61259119} = "Cowabbie";
$areanames{en}->{61259120} = "Currawarna";
$areanames{en}->{61259121} = "Currawarna";
$areanames{en}->{61259122} = "Galore";
$areanames{en}->{61259123} = "Galore";
$areanames{en}->{61259124} = "Humula";
$areanames{en}->{61259125} = "Humula";
$areanames{en}->{61259126} = "Junee";
$areanames{en}->{61259127} = "Junee";
$areanames{en}->{61259128} = "Kyeamba";
$areanames{en}->{61259129} = "Kyeamba";
$areanames{en}->{61259130} = "Lockhart";
$areanames{en}->{61259131} = "Lockhart";
$areanames{en}->{61259132} = "Mangoplah";
$areanames{en}->{61259133} = "Mangoplah";
$areanames{en}->{61259134} = "Milbrulong";
$areanames{en}->{61259135} = "Milbrulong";
$areanames{en}->{61259136} = "Tarcutta";
$areanames{en}->{61259137} = "Tarcutta";
$areanames{en}->{61259138} = "The\ Rock";
$areanames{en}->{61259139} = "The\ Rock";
$areanames{en}->{61259140} = "Wagga\ Wagga";
$areanames{en}->{61259141} = "Wagga\ Wagga";
$areanames{en}->{61259142} = "Wantabadgery";
$areanames{en}->{61259143} = "Wantabadgery";
$areanames{en}->{61259144} = "Alleena";
$areanames{en}->{61259145} = "Alleena";
$areanames{en}->{61259146} = "Burcher";
$areanames{en}->{61259147} = "Burcher";
$areanames{en}->{61259148} = "Marsden";
$areanames{en}->{61259149} = "Marsden";
$areanames{en}->{61259150} = "Tallimba";
$areanames{en}->{61259151} = "Tallimba";
$areanames{en}->{61259152} = "Ungarie";
$areanames{en}->{61259153} = "Ungarie";
$areanames{en}->{61259154} = "Warralonga";
$areanames{en}->{61259155} = "Warralonga";
$areanames{en}->{61259156} = "Morundah";
$areanames{en}->{61259157} = "Morundah";
$areanames{en}->{61259158} = "Leeton";
$areanames{en}->{61259159} = "Leeton";
$areanames{en}->{61259160} = "Egansford";
$areanames{en}->{61259161} = "Egansford";
$areanames{en}->{61259162} = "Burra";
$areanames{en}->{61259163} = "Burra";
$areanames{en}->{61259164} = "Adelong";
$areanames{en}->{61259165} = "Adelong";
$areanames{en}->{61259166} = "Batlow";
$areanames{en}->{61259167} = "Batlow";
$areanames{en}->{61259168} = "Bethungra";
$areanames{en}->{61259169} = "Bethungra";
$areanames{en}->{61259170} = "Carabost";
$areanames{en}->{61259171} = "Carabost";
$areanames{en}->{61259172} = "Stockinbingal";
$areanames{en}->{61259173} = "Stockinbingal";
$areanames{en}->{61259174} = "Talbingo";
$areanames{en}->{61259175} = "Talbingo";
$areanames{en}->{61259176} = "Tooma";
$areanames{en}->{61259177} = "Tooma";
$areanames{en}->{61259178} = "Tumbarumba";
$areanames{en}->{61259179} = "Tumbarumba";
$areanames{en}->{61259180} = "Tumorrama";
$areanames{en}->{61259181} = "Tumorrama";
$areanames{en}->{61259182} = "Wallendbeen";
$areanames{en}->{61259183} = "Wallendbeen";
$areanames{en}->{61259184} = "Wee\ Elwah";
$areanames{en}->{61259185} = "Wee\ Elwah";
$areanames{en}->{61259186} = "Yenda";
$areanames{en}->{61259187} = "Yenda";
$areanames{en}->{61259188} = "Barellan";
$areanames{en}->{61259189} = "Barellan";
$areanames{en}->{61259190} = "Black\ Stump";
$areanames{en}->{61259191} = "Black\ Stump";
$areanames{en}->{61259192} = "Hillston";
$areanames{en}->{61259193} = "Hillston";
$areanames{en}->{61259194} = "Wallanthery";
$areanames{en}->{61259195} = "Wallanthery";
$areanames{en}->{61259196} = "Carrathool";
$areanames{en}->{61259197} = "Carrathool";
$areanames{en}->{61259198} = "Bundure";
$areanames{en}->{61259199} = "Bundure";
$areanames{en}->{61259200} = "Coleambally";
$areanames{en}->{61259201} = "Coleambally";
$areanames{en}->{61259202} = "Gala\ Vale";
$areanames{en}->{61259203} = "Gala\ Vale";
$areanames{en}->{61259204} = "Grong\ Grong";
$areanames{en}->{61259205} = "Grong\ Grong";
$areanames{en}->{61259206} = "Stanbridge";
$areanames{en}->{61259207} = "Stanbridge";
$areanames{en}->{61259208} = "Ardlethan";
$areanames{en}->{61259209} = "Ardlethan";
$areanames{en}->{61259210} = "Barmedman\ East";
$areanames{en}->{61259211} = "Barmedman\ East";
$areanames{en}->{61259212} = "Narraburra";
$areanames{en}->{61259213} = "Narraburra";
$areanames{en}->{61259214} = "Springdale";
$areanames{en}->{61259215} = "Springdale";
$areanames{en}->{61259216} = "Bidgeemia";
$areanames{en}->{61259217} = "Bidgeemia";
$areanames{en}->{61259218} = "Boree\ Creek";
$areanames{en}->{61259219} = "Boree\ Creek";
$areanames{en}->{61259220} = "Ganmain";
$areanames{en}->{61259221} = "Ganmain";
$areanames{en}->{61259222} = "Henty";
$areanames{en}->{61259223} = "Henty";
$areanames{en}->{61259224} = "Junee\ Reefs";
$areanames{en}->{61259225} = "Junee\ Reefs";
$areanames{en}->{61259226} = "Rannock";
$areanames{en}->{61259227} = "Rannock";
$areanames{en}->{61259228} = "Urana";
$areanames{en}->{61259229} = "Urana";
$areanames{en}->{61259230} = "Winchendon\ Vale";
$areanames{en}->{61259231} = "Winchendon\ Vale";
$areanames{en}->{61259232} = "Kikoira";
$areanames{en}->{61259233} = "Kikoira";
$areanames{en}->{61259234} = "Tullibigeal";
$areanames{en}->{61259235} = "Tullibigeal";
$areanames{en}->{61259236} = "Weethalle";
$areanames{en}->{61259237} = "Weethalle";
$areanames{en}->{61259238} = "Bambilla";
$areanames{en}->{61259239} = "Bambilla";
$areanames{en}->{61259240} = "Gundagai";
$areanames{en}->{61259241} = "Griffith";
$areanames{en}->{61259242} = "Griffith";
$areanames{en}->{61259243} = "Wagga\ Wagga";
$areanames{en}->{61259244} = "Wagga\ Wagga";
$areanames{en}->{61259245} = "Wagga\ Wagga";
$areanames{en}->{61259246} = "Tumut";
$areanames{en}->{61259247} = "Narrandera";
$areanames{en}->{61259248} = "Leeton";
$areanames{en}->{61259249} = "Griffith";
$areanames{en}->{61259250} = "Griffith";
$areanames{en}->{61259251} = "Cootamundra";
$areanames{en}->{61259252} = "Cootamundra";
$areanames{en}->{61259253} = "Hay";
$areanames{en}->{61259254} = "Griffith";
$areanames{en}->{61259255} = "Wagga\ Wagga";
$areanames{en}->{61259256} = "Junee";
$areanames{en}->{61259257} = "Wagga\ Wagga";
$areanames{en}->{61259258} = "West\ Wyalong";
$areanames{en}->{61259259} = "Adelong";
$areanames{en}->{61259260} = "Cootamundra";
$areanames{en}->{61259261} = "Mangoplah";
$areanames{en}->{61259262} = "Wagga\ Wagga";
$areanames{en}->{61259263} = "Tumut";
$areanames{en}->{61259264} = "Leeton";
$areanames{en}->{61259265} = "Temora";
$areanames{en}->{61259266} = "The\ Rock";
$areanames{en}->{612592670} = "Adelong";
$areanames{en}->{612592671} = "Alleena";
$areanames{en}->{612592672} = "Ardlethan";
$areanames{en}->{612592673} = "Ariah\ Park";
$areanames{en}->{612592674} = "Bambilla";
$areanames{en}->{612592675} = "Barellan";
$areanames{en}->{612592676} = "Barmedman";
$areanames{en}->{612592677} = "Barmedman\ East";
$areanames{en}->{612592678} = "Batlow";
$areanames{en}->{612592679} = "Bethungra";
$areanames{en}->{612592680} = "Bidgeemia";
$areanames{en}->{612592681} = "Black\ Stump";
$areanames{en}->{612592682} = "Booroorban";
$areanames{en}->{612592683} = "Boree\ Creek";
$areanames{en}->{612592684} = "Bunda";
$areanames{en}->{612592685} = "Bundure";
$areanames{en}->{612592686} = "Burcher";
$areanames{en}->{612592687} = "Burra";
$areanames{en}->{612592688} = "Carabost";
$areanames{en}->{612592689} = "Carrathool";
$areanames{en}->{612592690} = "Coleambally";
$areanames{en}->{612592691} = "Coolac";
$areanames{en}->{612592692} = "Coolamon";
$areanames{en}->{612592693} = "Cootamundra";
$areanames{en}->{612592694} = "Cowabbie";
$areanames{en}->{612592695} = "Currawarna";
$areanames{en}->{612592696} = "Darlington\ Point";
$areanames{en}->{612592697} = "Egansford";
$areanames{en}->{612592698} = "Gala\ Vale";
$areanames{en}->{612592699} = "Galore";
$areanames{en}->{612592700} = "Ganmain";
$areanames{en}->{612592701} = "Goolgowi";
$areanames{en}->{612592702} = "Griffith";
$areanames{en}->{612592703} = "Grong\ Grong";
$areanames{en}->{612592704} = "Gunbar";
$areanames{en}->{612592705} = "Gundagai";
$areanames{en}->{612592706} = "Hay";
$areanames{en}->{612592707} = "Henty";
$areanames{en}->{612592708} = "Hillston";
$areanames{en}->{612592709} = "Humula";
$areanames{en}->{612592710} = "Ivanhoe";
$areanames{en}->{612592711} = "Junee";
$areanames{en}->{612592712} = "Junee\ Reefs";
$areanames{en}->{612592713} = "Kikoira";
$areanames{en}->{612592714} = "Kyeamba";
$areanames{en}->{612592715} = "Lachlan";
$areanames{en}->{612592716} = "Landervale";
$areanames{en}->{612592717} = "Leeton";
$areanames{en}->{612592718} = "Lockhart";
$areanames{en}->{612592719} = "Mangoplah";
$areanames{en}->{612592720} = "Mannus";
$areanames{en}->{612592721} = "Marsden";
$areanames{en}->{612592722} = "Maude";
$areanames{en}->{612592723} = "Melbergen";
$areanames{en}->{612592724} = "Merriwagga";
$areanames{en}->{612592725} = "Milbrulong";
$areanames{en}->{612592726} = "Morundah";
$areanames{en}->{612592727} = "Nangus";
$areanames{en}->{612592728} = "Narraburra";
$areanames{en}->{612592729} = "Narrandera";
$areanames{en}->{612592730} = "Rankins\ Springs";
$areanames{en}->{612592731} = "Rannock";
$areanames{en}->{612592732} = "Sandigo";
$areanames{en}->{612592733} = "Springdale";
$areanames{en}->{612592734} = "Stanbridge";
$areanames{en}->{612592735} = "Stockinbingal";
$areanames{en}->{612592736} = "Talbingo";
$areanames{en}->{612592737} = "Tallimba";
$areanames{en}->{612592738} = "Tarcutta";
$areanames{en}->{612592739} = "Temora";
$areanames{en}->{612592740} = "The\ Rock";
$areanames{en}->{612592741} = "Tooma";
$areanames{en}->{612592742} = "Tullibigeal";
$areanames{en}->{612592743} = "Tumbarumba";
$areanames{en}->{612592744} = "Tumorrama";
$areanames{en}->{612592745} = "Tumut";
$areanames{en}->{612592746} = "Ungarie";
$areanames{en}->{612592747} = "Urana";
$areanames{en}->{612592748} = "Wagga\ Wagga";
$areanames{en}->{612592749} = "Wallanthery";
$areanames{en}->{612592750} = "Wallendbeen";
$areanames{en}->{612592751} = "Wantabadgery";
$areanames{en}->{612592752} = "Warralonga";
$areanames{en}->{612592753} = "Warrawidgee";
$areanames{en}->{612592754} = "Wee\ Elwah";
$areanames{en}->{612592755} = "Weethalle";
$areanames{en}->{612592756} = "West\ Wyalong";
$areanames{en}->{612592757} = "Winchendon\ Vale";
$areanames{en}->{612592758} = "Yaven\ Creek";
$areanames{en}->{612592759} = "Yenda";
$areanames{en}->{61259276} = "Yenda";
$areanames{en}->{61259277} = "Bambilla";
$areanames{en}->{61259278} = "Barellan";
$areanames{en}->{61259279} = "Barmedman";
$areanames{en}->{61259280} = "Barmedman\ East";
$areanames{en}->{61259281} = "Bidgeemia";
$areanames{en}->{61259282} = "Black\ Stump";
$areanames{en}->{61259283} = "Boree\ Creek";
$areanames{en}->{61259284} = "Bunda";
$areanames{en}->{61259285} = "Bundure";
$areanames{en}->{61259286} = "Burcher";
$areanames{en}->{61259287} = "Burra";
$areanames{en}->{61259288} = "Carrathool";
$areanames{en}->{61259289} = "Coolac";
$areanames{en}->{61259290} = "Coolamon";
$areanames{en}->{61259291} = "Cowabbie";
$areanames{en}->{61259292} = "Currawarna";
$areanames{en}->{61259293} = "Darlington\ Point";
$areanames{en}->{61259294} = "Egansford";
$areanames{en}->{61259295} = "Gala\ Vale";
$areanames{en}->{61259296} = "Ganmain";
$areanames{en}->{61259297} = "Goolgowi";
$areanames{en}->{61259298} = "Grong\ Grong";
$areanames{en}->{61259299} = "Gunbar";
$areanames{en}->{61259300} = "Hay";
$areanames{en}->{61259301} = "Humula";
$areanames{en}->{61259302} = "Junee";
$areanames{en}->{61259303} = "Junee\ Reefs";
$areanames{en}->{61259304} = "Kikoira";
$areanames{en}->{61259305} = "Kyeamba";
$areanames{en}->{61259306} = "Landervale";
$areanames{en}->{61259307} = "Lockhart";
$areanames{en}->{61259308} = "Mangoplah";
$areanames{en}->{61259309} = "Mannus";
$areanames{en}->{61259310} = "Marsden";
$areanames{en}->{61259311} = "Maude";
$areanames{en}->{61259312} = "Melbergen";
$areanames{en}->{61259313} = "Merriwagga";
$areanames{en}->{61259314} = "Milbrulong";
$areanames{en}->{61259315} = "Morundah";
$areanames{en}->{61259316} = "Nangus";
$areanames{en}->{61259317} = "Narraburra";
$areanames{en}->{61259318} = "Rankins\ Springs";
$areanames{en}->{61259319} = "Rannock";
$areanames{en}->{61259320} = "Tarcutta";
$areanames{en}->{61259321} = "Wantabadgery";
$areanames{en}->{61259322} = "Wantabadgery";
$areanames{en}->{61259323} = "Boree\ Creek";
$areanames{en}->{61259324} = "Milbrulong";
$areanames{en}->{61259325} = "Humula";
$areanames{en}->{61259326} = "Rannock";
$areanames{en}->{61259327} = "Cowabbie";
$areanames{en}->{61259328} = "Junee\ Reefs";
$areanames{en}->{61259329} = "Galore";
$areanames{en}->{6125933} = "Wagga\ Wagga";
$areanames{en}->{61259340} = "Ariah\ Park";
$areanames{en}->{61259341} = "Sandigo";
$areanames{en}->{61259342} = "Springdale";
$areanames{en}->{61259343} = "Stanbridge";
$areanames{en}->{61259344} = "Stockinbingal";
$areanames{en}->{61259345} = "Talbingo";
$areanames{en}->{61259346} = "Tallimba";
$areanames{en}->{61259347} = "Tarcutta";
$areanames{en}->{61259348} = "The\ Rock";
$areanames{en}->{61259349} = "Tumbarumba";
$areanames{en}->{61259350} = "Tumorrama";
$areanames{en}->{61259351} = "Tumut";
$areanames{en}->{61259352} = "Ungarie";
$areanames{en}->{61259353} = "Wallanthery";
$areanames{en}->{61259354} = "Wallendbeen";
$areanames{en}->{61259355} = "Wantabadgery";
$areanames{en}->{61259356} = "Warralonga";
$areanames{en}->{61259357} = "Warrawidgee";
$areanames{en}->{61259358} = "Wee\ Elwah";
$areanames{en}->{61259359} = "West\ Wyalong";
$areanames{en}->{61259360} = "Winchendon\ Vale";
$areanames{en}->{61259361} = "Yaven\ Creek";
$areanames{en}->{61259362} = "Yenda";
$areanames{en}->{61259363} = "Adelong";
$areanames{en}->{61259364} = "Narrandera";
$areanames{en}->{61259365} = "Coleambally";
$areanames{en}->{612593660} = "Adelong";
$areanames{en}->{612593661} = "Alleena";
$areanames{en}->{612593662} = "Ardlethan";
$areanames{en}->{612593663} = "Ariah\ Park";
$areanames{en}->{612593664} = "Bambilla";
$areanames{en}->{612593665} = "Barellan";
$areanames{en}->{612593666} = "Barmedman";
$areanames{en}->{612593667} = "Barmedman\ East";
$areanames{en}->{612593668} = "Batlow";
$areanames{en}->{612593669} = "Bethungra";
$areanames{en}->{612593670} = "Bidgeemia";
$areanames{en}->{612593671} = "Black\ Stump";
$areanames{en}->{612593672} = "Booroorban";
$areanames{en}->{612593673} = "Boree\ Creek";
$areanames{en}->{612593674} = "Bunda";
$areanames{en}->{612593675} = "Bundure";
$areanames{en}->{612593676} = "Burcher";
$areanames{en}->{612593677} = "Burra";
$areanames{en}->{612593678} = "Carabost";
$areanames{en}->{612593679} = "Carrathool";
$areanames{en}->{612593680} = "Coleambally";
$areanames{en}->{612593681} = "Coolac";
$areanames{en}->{612593682} = "Coolamon";
$areanames{en}->{612593683} = "Cootamundra";
$areanames{en}->{612593684} = "Cowabbie";
$areanames{en}->{612593685} = "Currawarna";
$areanames{en}->{612593686} = "Darlington\ Point";
$areanames{en}->{612593687} = "Egansford";
$areanames{en}->{612593688} = "Gala\ Vale";
$areanames{en}->{612593689} = "Galore";
$areanames{en}->{612593690} = "Ganmain";
$areanames{en}->{612593691} = "Goolgowi";
$areanames{en}->{612593692} = "Griffith";
$areanames{en}->{612593693} = "Grong\ Grong";
$areanames{en}->{612593694} = "Gunbar";
$areanames{en}->{612593695} = "Gundagai";
$areanames{en}->{612593696} = "Hay";
$areanames{en}->{612593697} = "Henty";
$areanames{en}->{612593698} = "Hillston";
$areanames{en}->{612593699} = "Humula";
$areanames{en}->{612593700} = "Ivanhoe";
$areanames{en}->{612593701} = "Junee";
$areanames{en}->{612593702} = "Junee\ Reefs";
$areanames{en}->{612593703} = "Kikoira";
$areanames{en}->{612593704} = "Kyeamba";
$areanames{en}->{612593705} = "Lachlan";
$areanames{en}->{612593706} = "Landervale";
$areanames{en}->{612593707} = "Leeton";
$areanames{en}->{612593708} = "Lockhart";
$areanames{en}->{612593709} = "Mangoplah";
$areanames{en}->{612593710} = "Mannus";
$areanames{en}->{612593711} = "Marsden";
$areanames{en}->{612593712} = "Maude";
$areanames{en}->{612593713} = "Melbergen";
$areanames{en}->{612593714} = "Merriwagga";
$areanames{en}->{612593715} = "Milbrulong";
$areanames{en}->{612593716} = "Morundah";
$areanames{en}->{612593717} = "Nangus";
$areanames{en}->{612593718} = "Narraburra";
$areanames{en}->{612593719} = "Narrandera";
$areanames{en}->{612593720} = "Rankins\ Springs";
$areanames{en}->{612593721} = "Rannock";
$areanames{en}->{612593722} = "Sandigo";
$areanames{en}->{612593723} = "Springdale";
$areanames{en}->{612593724} = "Stanbridge";
$areanames{en}->{612593725} = "Stockinbingal";
$areanames{en}->{612593726} = "Talbingo";
$areanames{en}->{612593727} = "Tallimba";
$areanames{en}->{612593728} = "Tarcutta";
$areanames{en}->{612593729} = "Temora";
$areanames{en}->{612593730} = "The\ Rock";
$areanames{en}->{612593731} = "Tooma";
$areanames{en}->{612593732} = "Tullibigeal";
$areanames{en}->{612593733} = "Tumbarumba";
$areanames{en}->{612593734} = "Tumorrama";
$areanames{en}->{612593735} = "Tumut";
$areanames{en}->{612593736} = "Ungarie";
$areanames{en}->{612593737} = "Urana";
$areanames{en}->{612593738} = "Wagga\ Wagga";
$areanames{en}->{612593739} = "Wallanthery";
$areanames{en}->{612593740} = "Wallendbeen";
$areanames{en}->{612593741} = "Wantabadgery";
$areanames{en}->{612593742} = "Warralonga";
$areanames{en}->{612593743} = "Warrawidgee";
$areanames{en}->{612593744} = "Wee\ Elwah";
$areanames{en}->{612593745} = "Weethalle";
$areanames{en}->{612593746} = "West\ Wyalong";
$areanames{en}->{612593747} = "Winchendon\ Vale";
$areanames{en}->{612593748} = "Yaven\ Creek";
$areanames{en}->{612593749} = "Yenda";
$areanames{en}->{612593750} = "Adelong";
$areanames{en}->{612593751} = "Alleena";
$areanames{en}->{612593752} = "Ardlethan";
$areanames{en}->{612593753} = "Ariah\ Park";
$areanames{en}->{612593754} = "Bambilla";
$areanames{en}->{612593755} = "Barellan";
$areanames{en}->{612593756} = "Barmedman";
$areanames{en}->{612593757} = "Barmedman\ East";
$areanames{en}->{612593758} = "Batlow";
$areanames{en}->{612593759} = "Bethungra";
$areanames{en}->{612593760} = "Bidgeemia";
$areanames{en}->{612593761} = "Black\ Stump";
$areanames{en}->{612593762} = "Booroorban";
$areanames{en}->{612593763} = "Boree\ Creek";
$areanames{en}->{612593764} = "Bunda";
$areanames{en}->{612593765} = "Bundure";
$areanames{en}->{612593766} = "Burcher";
$areanames{en}->{612593767} = "Burra";
$areanames{en}->{612593768} = "Carabost";
$areanames{en}->{612593769} = "Carrathool";
$areanames{en}->{612593770} = "Coleambally";
$areanames{en}->{612593771} = "Coolac";
$areanames{en}->{612593772} = "Coolamon";
$areanames{en}->{612593773} = "Cootamundra";
$areanames{en}->{612593774} = "Cowabbie";
$areanames{en}->{612593775} = "Currawarna";
$areanames{en}->{612593776} = "Darlington\ Point";
$areanames{en}->{612593777} = "Egansford";
$areanames{en}->{612593778} = "Gala\ Vale";
$areanames{en}->{612593779} = "Galore";
$areanames{en}->{612593780} = "Ganmain";
$areanames{en}->{612593781} = "Goolgowi";
$areanames{en}->{612593782} = "Griffith";
$areanames{en}->{612593783} = "Grong\ Grong";
$areanames{en}->{612593784} = "Gunbar";
$areanames{en}->{612593785} = "Gundagai";
$areanames{en}->{612593786} = "Hay";
$areanames{en}->{612593787} = "Henty";
$areanames{en}->{612593788} = "Hillston";
$areanames{en}->{612593789} = "Humula";
$areanames{en}->{612593790} = "Ivanhoe";
$areanames{en}->{612593791} = "Junee";
$areanames{en}->{612593792} = "Junee\ Reefs";
$areanames{en}->{612593793} = "Kikoira";
$areanames{en}->{612593794} = "Kyeamba";
$areanames{en}->{612593795} = "Lachlan";
$areanames{en}->{612593796} = "Landervale";
$areanames{en}->{612593797} = "Leeton";
$areanames{en}->{612593798} = "Lockhart";
$areanames{en}->{612593799} = "Mangoplah";
$areanames{en}->{612593800} = "Mannus";
$areanames{en}->{612593801} = "Marsden";
$areanames{en}->{612593802} = "Maude";
$areanames{en}->{612593803} = "Melbergen";
$areanames{en}->{612593804} = "Merriwagga";
$areanames{en}->{612593805} = "Milbrulong";
$areanames{en}->{612593806} = "Morundah";
$areanames{en}->{612593807} = "Nangus";
$areanames{en}->{612593808} = "Narraburra";
$areanames{en}->{612593809} = "Narrandera";
$areanames{en}->{612593810} = "Rankins\ Springs";
$areanames{en}->{612593811} = "Rannock";
$areanames{en}->{612593812} = "Sandigo";
$areanames{en}->{612593813} = "Springdale";
$areanames{en}->{612593814} = "Stanbridge";
$areanames{en}->{612593815} = "Stockinbingal";
$areanames{en}->{612593816} = "Talbingo";
$areanames{en}->{612593817} = "Tallimba";
$areanames{en}->{612593818} = "Tarcutta";
$areanames{en}->{612593819} = "Temora";
$areanames{en}->{612593820} = "The\ Rock";
$areanames{en}->{612593821} = "Tooma";
$areanames{en}->{612593822} = "Tullibigeal";
$areanames{en}->{612593823} = "Tumbarumba";
$areanames{en}->{612593824} = "Tumorrama";
$areanames{en}->{612593825} = "Tumut";
$areanames{en}->{612593826} = "Ungarie";
$areanames{en}->{612593827} = "Urana";
$areanames{en}->{612593828} = "Wagga\ Wagga";
$areanames{en}->{612593829} = "Wallanthery";
$areanames{en}->{612593830} = "Wallendbeen";
$areanames{en}->{612593831} = "Wantabadgery";
$areanames{en}->{612593832} = "Warralonga";
$areanames{en}->{612593833} = "Warrawidgee";
$areanames{en}->{612593834} = "Wee\ Elwah";
$areanames{en}->{612593835} = "Weethalle";
$areanames{en}->{612593836} = "West\ Wyalong";
$areanames{en}->{612593837} = "Winchendon\ Vale";
$areanames{en}->{612593838} = "Yaven\ Creek";
$areanames{en}->{612593839} = "Yenda";
$areanames{en}->{61259384} = "Coolac";
$areanames{en}->{61259385} = "Narrandera";
$areanames{en}->{61259386} = "Wallendbeen";
$areanames{en}->{612593870} = "Adelong";
$areanames{en}->{612593871} = "Alleena";
$areanames{en}->{612593872} = "Ardlethan";
$areanames{en}->{612593873} = "Ariah\ Park";
$areanames{en}->{612593874} = "Bambilla";
$areanames{en}->{612593875} = "Barellan";
$areanames{en}->{612593876} = "Barmedman";
$areanames{en}->{612593877} = "Barmedman\ East";
$areanames{en}->{612593878} = "Batlow";
$areanames{en}->{612593879} = "Bethungra";
$areanames{en}->{612593880} = "Bidgeemia";
$areanames{en}->{612593881} = "Black\ Stump";
$areanames{en}->{612593882} = "Booroorban";
$areanames{en}->{612593883} = "Boree\ Creek";
$areanames{en}->{612593884} = "Bunda";
$areanames{en}->{612593885} = "Bundure";
$areanames{en}->{612593886} = "Burcher";
$areanames{en}->{612593887} = "Burra";
$areanames{en}->{612593888} = "Carabost";
$areanames{en}->{612593889} = "Carrathool";
$areanames{en}->{612593890} = "Coleambally";
$areanames{en}->{612593891} = "Coolac";
$areanames{en}->{612593892} = "Coolamon";
$areanames{en}->{612593893} = "Cootamundra";
$areanames{en}->{612593894} = "Cowabbie";
$areanames{en}->{612593895} = "Currawarna";
$areanames{en}->{612593896} = "Darlington\ Point";
$areanames{en}->{612593897} = "Egansford";
$areanames{en}->{612593898} = "Gala\ Vale";
$areanames{en}->{612593899} = "Galore";
$areanames{en}->{612593900} = "Ganmain";
$areanames{en}->{612593901} = "Goolgowi";
$areanames{en}->{612593902} = "Griffith";
$areanames{en}->{612593903} = "Grong\ Grong";
$areanames{en}->{612593904} = "Gunbar";
$areanames{en}->{612593905} = "Gundagai";
$areanames{en}->{612593906} = "Hay";
$areanames{en}->{612593907} = "Henty";
$areanames{en}->{612593908} = "Hillston";
$areanames{en}->{612593909} = "Humula";
$areanames{en}->{612593910} = "Ivanhoe";
$areanames{en}->{612593911} = "Junee";
$areanames{en}->{612593912} = "Junee\ Reefs";
$areanames{en}->{612593913} = "Kikoira";
$areanames{en}->{612593914} = "Kyeamba";
$areanames{en}->{612593915} = "Lachlan";
$areanames{en}->{612593916} = "Landervale";
$areanames{en}->{612593917} = "Leeton";
$areanames{en}->{612593918} = "Lockhart";
$areanames{en}->{612593919} = "Mangoplah";
$areanames{en}->{612593920} = "Mannus";
$areanames{en}->{612593921} = "Marsden";
$areanames{en}->{612593922} = "Maude";
$areanames{en}->{612593923} = "Melbergen";
$areanames{en}->{612593924} = "Merriwagga";
$areanames{en}->{612593925} = "Milbrulong";
$areanames{en}->{612593926} = "Morundah";
$areanames{en}->{612593927} = "Nangus";
$areanames{en}->{612593928} = "Narraburra";
$areanames{en}->{612593929} = "Narrandera";
$areanames{en}->{612593930} = "Rankins\ Springs";
$areanames{en}->{612593931} = "Rannock";
$areanames{en}->{612593932} = "Sandigo";
$areanames{en}->{612593933} = "Springdale";
$areanames{en}->{612593934} = "Stanbridge";
$areanames{en}->{612593935} = "Stockinbingal";
$areanames{en}->{612593936} = "Talbingo";
$areanames{en}->{612593937} = "Tallimba";
$areanames{en}->{612593938} = "Tarcutta";
$areanames{en}->{612593939} = "Temora";
$areanames{en}->{612593940} = "Adelong";
$areanames{en}->{612593941} = "Alleena";
$areanames{en}->{612593942} = "Ardlethan";
$areanames{en}->{612593943} = "Ariah\ Park";
$areanames{en}->{612593944} = "Bambilla";
$areanames{en}->{612593945} = "Barellan";
$areanames{en}->{612593946} = "Barmedman";
$areanames{en}->{612593947} = "Barmedman\ East";
$areanames{en}->{612593948} = "Batlow";
$areanames{en}->{612593949} = "Bethungra";
$areanames{en}->{612593950} = "Bidgeemia";
$areanames{en}->{612593951} = "Black\ Stump";
$areanames{en}->{612593952} = "Booroorban";
$areanames{en}->{612593953} = "Boree\ Creek";
$areanames{en}->{612593954} = "Bunda";
$areanames{en}->{612593955} = "Bundure";
$areanames{en}->{612593956} = "Burcher";
$areanames{en}->{612593957} = "Burra";
$areanames{en}->{612593958} = "Carabost";
$areanames{en}->{612593959} = "Carrathool";
$areanames{en}->{612593960} = "Coleambally";
$areanames{en}->{612593961} = "Coolac";
$areanames{en}->{612593962} = "Coolamon";
$areanames{en}->{612593963} = "Cootamundra";
$areanames{en}->{612593964} = "Cowabbie";
$areanames{en}->{612593965} = "Currawarna";
$areanames{en}->{612593966} = "Darlington\ Point";
$areanames{en}->{612593967} = "Egansford";
$areanames{en}->{612593968} = "Gala\ Vale";
$areanames{en}->{612593969} = "Galore";
$areanames{en}->{612593970} = "Ganmain";
$areanames{en}->{612593971} = "Goolgowi";
$areanames{en}->{612593972} = "Griffith";
$areanames{en}->{612593973} = "Grong\ Grong";
$areanames{en}->{612593974} = "Gunbar";
$areanames{en}->{612593975} = "Gundagai";
$areanames{en}->{612593976} = "Hay";
$areanames{en}->{612593977} = "Henty";
$areanames{en}->{612593978} = "Hillston";
$areanames{en}->{612593979} = "Humula";
$areanames{en}->{612593980} = "Ivanhoe";
$areanames{en}->{612593981} = "Junee";
$areanames{en}->{612593982} = "Junee\ Reefs";
$areanames{en}->{612593983} = "Kikoira";
$areanames{en}->{612593984} = "Kyeamba";
$areanames{en}->{612593985} = "Lachlan";
$areanames{en}->{612593986} = "Landervale";
$areanames{en}->{612593987} = "Leeton";
$areanames{en}->{612593988} = "Lockhart";
$areanames{en}->{612593989} = "Mangoplah";
$areanames{en}->{612593990} = "Mannus";
$areanames{en}->{612593991} = "Marsden";
$areanames{en}->{612593992} = "Maude";
$areanames{en}->{612593993} = "Melbergen";
$areanames{en}->{612593994} = "Merriwagga";
$areanames{en}->{612593995} = "Milbrulong";
$areanames{en}->{612593996} = "Morundah";
$areanames{en}->{612593997} = "Nangus";
$areanames{en}->{612593998} = "Narraburra";
$areanames{en}->{612593999} = "Narrandera";
$areanames{en}->{612594000} = "Rankins\ Springs";
$areanames{en}->{612594001} = "Rannock";
$areanames{en}->{612594002} = "Sandigo";
$areanames{en}->{612594003} = "Springdale";
$areanames{en}->{612594004} = "Stanbridge";
$areanames{en}->{612594005} = "Stockinbingal";
$areanames{en}->{612594006} = "Talbingo";
$areanames{en}->{612594007} = "Tallimba";
$areanames{en}->{612594008} = "Tarcutta";
$areanames{en}->{612594009} = "Temora";
$areanames{en}->{612594010} = "The\ Rock";
$areanames{en}->{612594011} = "Tooma";
$areanames{en}->{612594012} = "Tullibigeal";
$areanames{en}->{612594013} = "Tumbarumba";
$areanames{en}->{612594014} = "Tumorrama";
$areanames{en}->{612594015} = "Tumut";
$areanames{en}->{612594016} = "Ungarie";
$areanames{en}->{612594017} = "Urana";
$areanames{en}->{612594018} = "Wagga\ Wagga";
$areanames{en}->{612594019} = "Wallanthery";
$areanames{en}->{612594020} = "Wallendbeen";
$areanames{en}->{612594021} = "Wantabadgery";
$areanames{en}->{612594022} = "Warralonga";
$areanames{en}->{612594023} = "Warrawidgee";
$areanames{en}->{612594024} = "Wee\ Elwah";
$areanames{en}->{612594025} = "Weethalle";
$areanames{en}->{612594026} = "West\ Wyalong";
$areanames{en}->{612594027} = "Winchendon\ Vale";
$areanames{en}->{612594028} = "Yaven\ Creek";
$areanames{en}->{612594029} = "Yenda";
$areanames{en}->{61259403} = "Batlow";
$areanames{en}->{61259404} = "Batlow";
$areanames{en}->{61259405} = "Batlow";
$areanames{en}->{612594060} = "The\ Rock";
$areanames{en}->{612594061} = "Tooma";
$areanames{en}->{612594062} = "Tullibigeal";
$areanames{en}->{612594063} = "Tumbarumba";
$areanames{en}->{612594064} = "Tumorrama";
$areanames{en}->{612594065} = "Tumut";
$areanames{en}->{612594066} = "Ungarie";
$areanames{en}->{612594067} = "Urana";
$areanames{en}->{612594068} = "Wagga\ Wagga";
$areanames{en}->{612594069} = "Wallanthery";
$areanames{en}->{612594070} = "Wallendbeen";
$areanames{en}->{612594071} = "Wantabadgery";
$areanames{en}->{612594072} = "Warralonga";
$areanames{en}->{612594073} = "Warrawidgee";
$areanames{en}->{612594074} = "Wee\ Elwah";
$areanames{en}->{612594075} = "Weethalle";
$areanames{en}->{612594076} = "West\ Wyalong";
$areanames{en}->{612594077} = "Winchendon\ Vale";
$areanames{en}->{612594078} = "Yaven\ Creek";
$areanames{en}->{612594079} = "Yenda";
$areanames{en}->{612594080} = "Adelong";
$areanames{en}->{612594081} = "Alleena";
$areanames{en}->{612594082} = "Ardlethan";
$areanames{en}->{612594083} = "Ariah\ Park";
$areanames{en}->{612594084} = "Bambilla";
$areanames{en}->{612594085} = "Barellan";
$areanames{en}->{612594086} = "Barmedman";
$areanames{en}->{612594087} = "Barmedman\ East";
$areanames{en}->{612594088} = "Batlow";
$areanames{en}->{612594089} = "Bethungra";
$areanames{en}->{612594090} = "Bidgeemia";
$areanames{en}->{612594091} = "Black\ Stump";
$areanames{en}->{612594092} = "Booroorban";
$areanames{en}->{612594093} = "Boree\ Creek";
$areanames{en}->{612594094} = "Bunda";
$areanames{en}->{612594095} = "Bundure";
$areanames{en}->{612594096} = "Burcher";
$areanames{en}->{612594097} = "Burra";
$areanames{en}->{612594098} = "Carabost";
$areanames{en}->{612594099} = "Carrathool";
$areanames{en}->{612594100} = "Coleambally";
$areanames{en}->{612594101} = "Coolac";
$areanames{en}->{612594102} = "Coolamon";
$areanames{en}->{612594103} = "Cootamundra";
$areanames{en}->{612594104} = "Cowabbie";
$areanames{en}->{612594105} = "Currawarna";
$areanames{en}->{612594106} = "Darlington\ Point";
$areanames{en}->{612594107} = "Egansford";
$areanames{en}->{612594108} = "Gala\ Vale";
$areanames{en}->{612594109} = "Galore";
$areanames{en}->{612594110} = "Ganmain";
$areanames{en}->{612594111} = "Goolgowi";
$areanames{en}->{612594112} = "Griffith";
$areanames{en}->{612594113} = "Grong\ Grong";
$areanames{en}->{612594114} = "Gunbar";
$areanames{en}->{612594115} = "Gundagai";
$areanames{en}->{612594116} = "Hay";
$areanames{en}->{612594117} = "Henty";
$areanames{en}->{612594118} = "Hillston";
$areanames{en}->{612594119} = "Humula";
$areanames{en}->{612594120} = "Ivanhoe";
$areanames{en}->{612594121} = "Junee";
$areanames{en}->{612594122} = "Junee\ Reefs";
$areanames{en}->{612594123} = "Kikoira";
$areanames{en}->{612594124} = "Kyeamba";
$areanames{en}->{612594125} = "Lachlan";
$areanames{en}->{612594126} = "Landervale";
$areanames{en}->{612594127} = "Leeton";
$areanames{en}->{612594128} = "Lockhart";
$areanames{en}->{612594129} = "Mangoplah";
$areanames{en}->{612594130} = "Mannus";
$areanames{en}->{612594131} = "Marsden";
$areanames{en}->{612594132} = "Maude";
$areanames{en}->{612594133} = "Melbergen";
$areanames{en}->{612594134} = "Merriwagga";
$areanames{en}->{612594135} = "Milbrulong";
$areanames{en}->{612594136} = "Morundah";
$areanames{en}->{612594137} = "Nangus";
$areanames{en}->{612594138} = "Narraburra";
$areanames{en}->{612594139} = "Narrandera";
$areanames{en}->{612594140} = "Rankins\ Springs";
$areanames{en}->{612594141} = "Rannock";
$areanames{en}->{612594142} = "Sandigo";
$areanames{en}->{612594143} = "Springdale";
$areanames{en}->{612594144} = "Stanbridge";
$areanames{en}->{612594145} = "Stockinbingal";
$areanames{en}->{612594146} = "Talbingo";
$areanames{en}->{612594147} = "Tallimba";
$areanames{en}->{612594148} = "Tarcutta";
$areanames{en}->{612594149} = "Temora";
$areanames{en}->{612594150} = "The\ Rock";
$areanames{en}->{612594151} = "Tooma";
$areanames{en}->{612594152} = "Tullibigeal";
$areanames{en}->{612594153} = "Tumbarumba";
$areanames{en}->{612594154} = "Tumorrama";
$areanames{en}->{612594155} = "Tumut";
$areanames{en}->{612594156} = "Ungarie";
$areanames{en}->{612594157} = "Urana";
$areanames{en}->{612594158} = "Wagga\ Wagga";
$areanames{en}->{612594159} = "Wallanthery";
$areanames{en}->{612594160} = "Wallendbeen";
$areanames{en}->{612594161} = "Wantabadgery";
$areanames{en}->{612594162} = "Warralonga";
$areanames{en}->{612594163} = "Warrawidgee";
$areanames{en}->{612594164} = "Wee\ Elwah";
$areanames{en}->{612594165} = "Weethalle";
$areanames{en}->{612594166} = "West\ Wyalong";
$areanames{en}->{612594167} = "Winchendon\ Vale";
$areanames{en}->{612594168} = "Yaven\ Creek";
$areanames{en}->{612594169} = "Yenda";
$areanames{en}->{612594170} = "Adelong";
$areanames{en}->{612594171} = "Alleena";
$areanames{en}->{612594172} = "Ardlethan";
$areanames{en}->{612594173} = "Ariah\ Park";
$areanames{en}->{612594174} = "Bambilla";
$areanames{en}->{612594175} = "Barellan";
$areanames{en}->{612594176} = "Barmedman";
$areanames{en}->{612594177} = "Barmedman\ East";
$areanames{en}->{612594178} = "Batlow";
$areanames{en}->{612594179} = "Bethungra";
$areanames{en}->{612594180} = "Bidgeemia";
$areanames{en}->{612594181} = "Black\ Stump";
$areanames{en}->{612594182} = "Booroorban";
$areanames{en}->{612594183} = "Boree\ Creek";
$areanames{en}->{612594184} = "Bunda";
$areanames{en}->{612594185} = "Bundure";
$areanames{en}->{612594186} = "Burcher";
$areanames{en}->{612594187} = "Burra";
$areanames{en}->{612594188} = "Carabost";
$areanames{en}->{612594189} = "Carrathool";
$areanames{en}->{612594190} = "Coleambally";
$areanames{en}->{612594191} = "Coolac";
$areanames{en}->{612594192} = "Coolamon";
$areanames{en}->{612594193} = "Cootamundra";
$areanames{en}->{612594194} = "Cowabbie";
$areanames{en}->{612594195} = "Currawarna";
$areanames{en}->{612594196} = "Darlington\ Point";
$areanames{en}->{612594197} = "Egansford";
$areanames{en}->{612594198} = "Gala\ Vale";
$areanames{en}->{612594199} = "Galore";
$areanames{en}->{6125942} = "Wagga\ Wagga";
$areanames{en}->{612594200} = "Ganmain";
$areanames{en}->{612594201} = "Goolgowi";
$areanames{en}->{612594202} = "Griffith";
$areanames{en}->{612594203} = "Grong\ Grong";
$areanames{en}->{612594204} = "Gunbar";
$areanames{en}->{612594205} = "Gundagai";
$areanames{en}->{612594206} = "Hay";
$areanames{en}->{612594207} = "Henty";
$areanames{en}->{612594208} = "Hillston";
$areanames{en}->{612594209} = "Humula";
$areanames{en}->{612594210} = "Ivanhoe";
$areanames{en}->{612594211} = "Junee";
$areanames{en}->{612594212} = "Junee\ Reefs";
$areanames{en}->{612594213} = "Kikoira";
$areanames{en}->{612594214} = "Kyeamba";
$areanames{en}->{612594215} = "Lachlan";
$areanames{en}->{612594216} = "Landervale";
$areanames{en}->{612594217} = "Leeton";
$areanames{en}->{612594218} = "Lockhart";
$areanames{en}->{612594219} = "Mangoplah";
$areanames{en}->{612594220} = "Mannus";
$areanames{en}->{612594221} = "Marsden";
$areanames{en}->{612594222} = "Maude";
$areanames{en}->{612594223} = "Melbergen";
$areanames{en}->{612594224} = "Merriwagga";
$areanames{en}->{612594225} = "Milbrulong";
$areanames{en}->{612594226} = "Morundah";
$areanames{en}->{612594227} = "Nangus";
$areanames{en}->{612594228} = "Narraburra";
$areanames{en}->{612594229} = "Narrandera";
$areanames{en}->{612594300} = "Rankins\ Springs";
$areanames{en}->{612594301} = "Rannock";
$areanames{en}->{612594302} = "Sandigo";
$areanames{en}->{612594303} = "Springdale";
$areanames{en}->{612594304} = "Stanbridge";
$areanames{en}->{612594305} = "Stockinbingal";
$areanames{en}->{612594306} = "Talbingo";
$areanames{en}->{612594307} = "Tallimba";
$areanames{en}->{612594308} = "Tarcutta";
$areanames{en}->{612594309} = "Temora";
$areanames{en}->{61259431} = "Wagga\ Wagga";
$areanames{en}->{61259432} = "Wagga\ Wagga";
$areanames{en}->{61259433} = "Wagga\ Wagga";
$areanames{en}->{61259434} = "Wagga\ Wagga";
$areanames{en}->{612594350} = "The\ Rock";
$areanames{en}->{612594351} = "Tooma";
$areanames{en}->{612594352} = "Tullibigeal";
$areanames{en}->{612594353} = "Tumbarumba";
$areanames{en}->{612594354} = "Tumorrama";
$areanames{en}->{612594355} = "Tumut";
$areanames{en}->{612594356} = "Ungarie";
$areanames{en}->{612594357} = "Urana";
$areanames{en}->{612594358} = "Wagga\ Wagga";
$areanames{en}->{612594359} = "Wallanthery";
$areanames{en}->{612594360} = "Wallendbeen";
$areanames{en}->{612594361} = "Wantabadgery";
$areanames{en}->{612594362} = "Warralonga";
$areanames{en}->{612594363} = "Warrawidgee";
$areanames{en}->{612594364} = "Wee\ Elwah";
$areanames{en}->{612594365} = "Weethalle";
$areanames{en}->{612594366} = "West\ Wyalong";
$areanames{en}->{612594367} = "Winchendon\ Vale";
$areanames{en}->{612594368} = "Yaven\ Creek";
$areanames{en}->{612594369} = "Yenda";
$areanames{en}->{612594370} = "Adelong";
$areanames{en}->{612594371} = "Alleena";
$areanames{en}->{612594372} = "Ardlethan";
$areanames{en}->{612594373} = "Ariah\ Park";
$areanames{en}->{612594374} = "Bambilla";
$areanames{en}->{612594375} = "Barellan";
$areanames{en}->{612594376} = "Barmedman";
$areanames{en}->{612594377} = "Barmedman\ East";
$areanames{en}->{612594378} = "Batlow";
$areanames{en}->{612594379} = "Bethungra";
$areanames{en}->{612594380} = "Bidgeemia";
$areanames{en}->{612594381} = "Black\ Stump";
$areanames{en}->{612594382} = "Booroorban";
$areanames{en}->{612594383} = "Boree\ Creek";
$areanames{en}->{612594384} = "Bunda";
$areanames{en}->{612594385} = "Bundure";
$areanames{en}->{612594386} = "Burcher";
$areanames{en}->{612594387} = "Burra";
$areanames{en}->{612594388} = "Carabost";
$areanames{en}->{612594389} = "Carrathool";
$areanames{en}->{612594390} = "Coleambally";
$areanames{en}->{612594391} = "Coolac";
$areanames{en}->{612594392} = "Coolamon";
$areanames{en}->{612594393} = "Cootamundra";
$areanames{en}->{612594394} = "Cowabbie";
$areanames{en}->{612594395} = "Currawarna";
$areanames{en}->{612594396} = "Darlington\ Point";
$areanames{en}->{612594397} = "Egansford";
$areanames{en}->{612594398} = "Gala\ Vale";
$areanames{en}->{612594399} = "Galore";
$areanames{en}->{612594400} = "Ganmain";
$areanames{en}->{612594401} = "Goolgowi";
$areanames{en}->{612594402} = "Griffith";
$areanames{en}->{612594403} = "Grong\ Grong";
$areanames{en}->{612594404} = "Gunbar";
$areanames{en}->{612594405} = "Gundagai";
$areanames{en}->{612594406} = "Hay";
$areanames{en}->{612594407} = "Henty";
$areanames{en}->{612594408} = "Hillston";
$areanames{en}->{612594409} = "Humula";
$areanames{en}->{612594410} = "Ivanhoe";
$areanames{en}->{612594411} = "Junee";
$areanames{en}->{612594412} = "Junee\ Reefs";
$areanames{en}->{612594413} = "Kikoira";
$areanames{en}->{612594414} = "Kyeamba";
$areanames{en}->{612594415} = "Lachlan";
$areanames{en}->{612594416} = "Landervale";
$areanames{en}->{612594417} = "Leeton";
$areanames{en}->{612594418} = "Lockhart";
$areanames{en}->{612594419} = "Mangoplah";
$areanames{en}->{612594420} = "Mannus";
$areanames{en}->{612594421} = "Marsden";
$areanames{en}->{612594422} = "Maude";
$areanames{en}->{612594423} = "Melbergen";
$areanames{en}->{612594424} = "Merriwagga";
$areanames{en}->{612594425} = "Milbrulong";
$areanames{en}->{612594426} = "Morundah";
$areanames{en}->{612594427} = "Nangus";
$areanames{en}->{612594428} = "Narraburra";
$areanames{en}->{612594429} = "Narrandera";
$areanames{en}->{612594430} = "Rankins\ Springs";
$areanames{en}->{612594431} = "Rannock";
$areanames{en}->{612594432} = "Sandigo";
$areanames{en}->{612594433} = "Springdale";
$areanames{en}->{612594434} = "Stanbridge";
$areanames{en}->{612594435} = "Stockinbingal";
$areanames{en}->{612594436} = "Talbingo";
$areanames{en}->{612594437} = "Tallimba";
$areanames{en}->{612594438} = "Tarcutta";
$areanames{en}->{612594439} = "Temora";
$areanames{en}->{612594440} = "The\ Rock";
$areanames{en}->{612594441} = "Tooma";
$areanames{en}->{612594442} = "Tullibigeal";
$areanames{en}->{612594443} = "Tumbarumba";
$areanames{en}->{612594444} = "Tumorrama";
$areanames{en}->{612594445} = "Tumut";
$areanames{en}->{612594446} = "Ungarie";
$areanames{en}->{612594447} = "Urana";
$areanames{en}->{612594448} = "Wagga\ Wagga";
$areanames{en}->{612594449} = "Wallanthery";
$areanames{en}->{612594450} = "Wallendbeen";
$areanames{en}->{612594451} = "Wantabadgery";
$areanames{en}->{612594452} = "Warralonga";
$areanames{en}->{612594453} = "Warrawidgee";
$areanames{en}->{612594454} = "Wee\ Elwah";
$areanames{en}->{612594455} = "Weethalle";
$areanames{en}->{612594456} = "West\ Wyalong";
$areanames{en}->{612594457} = "Winchendon\ Vale";
$areanames{en}->{612594458} = "Yaven\ Creek";
$areanames{en}->{612594459} = "Yenda";
$areanames{en}->{61259446} = "Hay";
$areanames{en}->{61259447} = "Wagga\ Wagga";
$areanames{en}->{61259448} = "Leeton";
$areanames{en}->{61259449} = "Leeton";
$areanames{en}->{61259459} = "Booroorban";
$areanames{en}->{61259470} = "Galore";
$areanames{en}->{61259489} = "Tullibigeal";
$areanames{en}->{61259500} = "Lachlan";
$areanames{en}->{6125959} = "Wagga\ Wagga";
$areanames{en}->{61259600} = "Ariah\ Park";
$areanames{en}->{61259601} = "Ariah\ Park";
$areanames{en}->{61259602} = "Landervale";
$areanames{en}->{61259603} = "Landervale";
$areanames{en}->{61259604} = "Temora";
$areanames{en}->{61259605} = "Temora";
$areanames{en}->{61259606} = "Bunda";
$areanames{en}->{61259607} = "Bunda";
$areanames{en}->{61259608} = "Darlington\ Point";
$areanames{en}->{61259609} = "Darlington\ Point";
$areanames{en}->{61259610} = "Goolgowi";
$areanames{en}->{61259611} = "Goolgowi";
$areanames{en}->{61259612} = "Griffith";
$areanames{en}->{61259613} = "Griffith";
$areanames{en}->{61259614} = "Melbergen";
$areanames{en}->{61259615} = "Melbergen";
$areanames{en}->{61259616} = "Merriwagga";
$areanames{en}->{61259617} = "Merriwagga";
$areanames{en}->{61259618} = "Warrawidgee";
$areanames{en}->{61259619} = "Warrawidgee";
$areanames{en}->{61259620} = "Booroorban";
$areanames{en}->{61259621} = "Booroorban";
$areanames{en}->{61259622} = "Hay";
$areanames{en}->{61259623} = "Hay";
$areanames{en}->{61259624} = "Gunbar";
$areanames{en}->{61259625} = "Gunbar";
$areanames{en}->{61259626} = "Ivanhoe";
$areanames{en}->{61259627} = "Ivanhoe";
$areanames{en}->{61259628} = "Lachlan";
$areanames{en}->{61259629} = "Lachlan";
$areanames{en}->{61259630} = "Maude";
$areanames{en}->{61259631} = "Maude";
$areanames{en}->{61259632} = "Wagga\ Wagga";
$areanames{en}->{61259633} = "Coolamon";
$areanames{en}->{61259700} = "Tullibigeal";
$areanames{en}->{61259701} = "Tallimba";
$areanames{en}->{61259702} = "Alleena";
$areanames{en}->{61259703} = "Kikoira";
$areanames{en}->{61259704} = "Warralonga";
$areanames{en}->{61259705} = "Marsden";
$areanames{en}->{61259706} = "West\ Wyalong";
$areanames{en}->{61259707} = "West\ Wyalong";
$areanames{en}->{61259708} = "West\ Wyalong";
$areanames{en}->{61259709} = "Burcher";
$areanames{en}->{61259710} = "Wagga\ Wagga";
$areanames{en}->{61259711} = "Wagga\ Wagga";
$areanames{en}->{61259712} = "Wagga\ Wagga";
$areanames{en}->{61259713} = "Wagga\ Wagga";
$areanames{en}->{61259714} = "Wagga\ Wagga";
$areanames{en}->{61259716} = "Hillston";
$areanames{en}->{61259717} = "Barellan";
$areanames{en}->{61259718} = "Barellan";
$areanames{en}->{61259719} = "Tumorrama";
$areanames{en}->{61259761} = "Wagga\ Wagga";
$areanames{en}->{61259762} = "Alleena";
$areanames{en}->{61259763} = "Barmedman";
$areanames{en}->{61259990} = "Wagga\ Wagga";
$areanames{en}->{61259995} = "Griffith";
$areanames{en}->{61259996} = "Wagga\ Wagga";
$areanames{en}->{61259997} = "Wagga\ Wagga";
$areanames{en}->{61259998} = "Wagga\ Wagga";
$areanames{en}->{61259999} = "Griffith";
$areanames{en}->{61260000} = "Albury";
$areanames{en}->{61260001} = "Albury";
$areanames{en}->{61260002} = "Albury";
$areanames{en}->{61260003} = "Balldale";
$areanames{en}->{61260004} = "Balldale";
$areanames{en}->{61260005} = "Balldale";
$areanames{en}->{61260006} = "Barnawartha";
$areanames{en}->{61260007} = "Barnawartha";
$areanames{en}->{61260008} = "Barnawartha";
$areanames{en}->{61260009} = "Albury";
$areanames{en}->{61260010} = "Coppabella";
$areanames{en}->{61260011} = "Coppabella";
$areanames{en}->{61260012} = "Coppabella";
$areanames{en}->{61260013} = "Corowa";
$areanames{en}->{61260014} = "Corowa";
$areanames{en}->{61260015} = "Corowa";
$areanames{en}->{61260016} = "Corryong";
$areanames{en}->{61260017} = "Corryong";
$areanames{en}->{61260018} = "Corryong";
$areanames{en}->{61260019} = "Balldale";
$areanames{en}->{61260020} = "Cudgewa";
$areanames{en}->{61260021} = "Cudgewa";
$areanames{en}->{61260022} = "Cudgewa";
$areanames{en}->{61260023} = "Culcairn";
$areanames{en}->{61260024} = "Culcairn";
$areanames{en}->{61260025} = "Culcairn";
$areanames{en}->{61260026} = "Dartmouth";
$areanames{en}->{61260027} = "Dartmouth";
$areanames{en}->{61260028} = "Dartmouth";
$areanames{en}->{61260029} = "Barnawartha";
$areanames{en}->{61260030} = "Gerogery";
$areanames{en}->{61260031} = "Gerogery";
$areanames{en}->{61260032} = "Gerogery";
$areanames{en}->{61260033} = "Holbrook";
$areanames{en}->{61260034} = "Holbrook";
$areanames{en}->{61260035} = "Holbrook";
$areanames{en}->{61260036} = "Howlong";
$areanames{en}->{61260037} = "Howlong";
$areanames{en}->{61260038} = "Howlong";
$areanames{en}->{61260039} = "Coppabella";
$areanames{en}->{61260040} = "Koetong";
$areanames{en}->{61260041} = "Koetong";
$areanames{en}->{61260042} = "Koetong";
$areanames{en}->{61260043} = "Leicester\ Park";
$areanames{en}->{61260044} = "Leicester\ Park";
$areanames{en}->{61260045} = "Leicester\ Park";
$areanames{en}->{61260046} = "Little\ Billabong";
$areanames{en}->{61260047} = "Little\ Billabong";
$areanames{en}->{61260048} = "Little\ Billabong";
$areanames{en}->{61260049} = "Corowa";
$areanames{en}->{61260050} = "Nariel";
$areanames{en}->{61260051} = "Nariel";
$areanames{en}->{61260052} = "Nariel";
$areanames{en}->{61260053} = "Oaklands";
$areanames{en}->{61260054} = "Oaklands";
$areanames{en}->{61260055} = "Oaklands";
$areanames{en}->{61260056} = "Ournie";
$areanames{en}->{61260057} = "Ournie";
$areanames{en}->{61260058} = "Ournie";
$areanames{en}->{61260059} = "Culcairn";
$areanames{en}->{61260060} = "Rand";
$areanames{en}->{61260061} = "Rand";
$areanames{en}->{61260062} = "Rand";
$areanames{en}->{61260063} = "Rennie";
$areanames{en}->{61260064} = "Rennie";
$areanames{en}->{61260065} = "Rennie";
$areanames{en}->{61260066} = "Talgarno";
$areanames{en}->{61260067} = "Talgarno";
$areanames{en}->{61260068} = "Talgarno";
$areanames{en}->{61260069} = "Gerogery";
$areanames{en}->{61260070} = "Tallangatta";
$areanames{en}->{61260071} = "Tallangatta";
$areanames{en}->{61260072} = "Tallangatta";
$areanames{en}->{61260073} = "Tallangatta\ Valley";
$areanames{en}->{61260074} = "Tallangatta\ Valley";
$areanames{en}->{61260075} = "Tallangatta\ Valley";
$areanames{en}->{61260076} = "Talmalmo";
$areanames{en}->{61260077} = "Talmalmo";
$areanames{en}->{61260078} = "Talmalmo";
$areanames{en}->{61260079} = "Holbrook";
$areanames{en}->{61260080} = "Walla\ Walla";
$areanames{en}->{61260081} = "Walla\ Walla";
$areanames{en}->{61260082} = "Walla\ Walla";
$areanames{en}->{61260083} = "Walwa";
$areanames{en}->{61260084} = "Walwa";
$areanames{en}->{61260085} = "Walwa";
$areanames{en}->{61260086} = "Yackandandah";
$areanames{en}->{61260087} = "Yackandandah";
$areanames{en}->{61260088} = "Yackandandah";
$areanames{en}->{61260089} = "Howlong";
$areanames{en}->{61260090} = "Albury";
$areanames{en}->{61260091} = "Albury";
$areanames{en}->{61260092} = "Balldale";
$areanames{en}->{61260093} = "Barnawartha";
$areanames{en}->{61260094} = "Coppabella";
$areanames{en}->{61260095} = "Yackandandah";
$areanames{en}->{61260096} = "Corowa";
$areanames{en}->{61260097} = "Culcairn";
$areanames{en}->{61260098} = "Gerogery";
$areanames{en}->{61260099} = "Holbrook";
$areanames{en}->{61260100} = "Howlong";
$areanames{en}->{61260101} = "Leicester\ Park";
$areanames{en}->{61260102} = "Little\ Billabong";
$areanames{en}->{61260103} = "Oaklands";
$areanames{en}->{61260104} = "Ournie";
$areanames{en}->{61260105} = "Rand";
$areanames{en}->{61260106} = "Rennie";
$areanames{en}->{61260107} = "Talgarno";
$areanames{en}->{61260108} = "Talmalmo";
$areanames{en}->{61260109} = "Walla\ Walla";
$areanames{en}->{61260110} = "Walwa";
$areanames{en}->{61260111} = "Yackandandah";
$areanames{en}->{61260112} = "Corryong";
$areanames{en}->{61260113} = "Cudgewa";
$areanames{en}->{61260114} = "Dartmouth";
$areanames{en}->{61260115} = "Eskdale";
$areanames{en}->{61260116} = "Koetong";
$areanames{en}->{61260117} = "Nariel";
$areanames{en}->{61260118} = "Tallangatta";
$areanames{en}->{61260119} = "Tallangatta\ Valley";
$areanames{en}->{61260120} = "Leicester\ Park";
$areanames{en}->{61260121} = "Little\ Billabong";
$areanames{en}->{61260122} = "Oaklands";
$areanames{en}->{61260123} = "Ournie";
$areanames{en}->{61260124} = "Rand";
$areanames{en}->{61260125} = "Rennie";
$areanames{en}->{61260126} = "Talgarno";
$areanames{en}->{61260127} = "Talmalmo";
$areanames{en}->{61260128} = "Walla\ Walla";
$areanames{en}->{61260129} = "Walwa";
$areanames{en}->{61260130} = "Yackandandah";
$areanames{en}->{61260131} = "Corryong";
$areanames{en}->{61260132} = "Cudgewa";
$areanames{en}->{61260133} = "Dartmouth";
$areanames{en}->{61260134} = "Eskdale";
$areanames{en}->{61260135} = "Koetong";
$areanames{en}->{61260136} = "Nariel";
$areanames{en}->{61260137} = "Tallangatta";
$areanames{en}->{61260138} = "Tallangatta\ Valley";
$areanames{en}->{61260139} = "Albury";
$areanames{en}->{61260140} = "Balldale";
$areanames{en}->{61260141} = "Barnawartha";
$areanames{en}->{61260142} = "Coppabella";
$areanames{en}->{61260143} = "Corowa";
$areanames{en}->{61260144} = "Culcairn";
$areanames{en}->{61260145} = "Gerogery";
$areanames{en}->{61260146} = "Holbrook";
$areanames{en}->{61260147} = "Howlong";
$areanames{en}->{61260148} = "Leicester\ Park";
$areanames{en}->{61260149} = "Little\ Billabong";
$areanames{en}->{61260150} = "Oaklands";
$areanames{en}->{61260151} = "Ournie";
$areanames{en}->{61260152} = "Rand";
$areanames{en}->{61260153} = "Rennie";
$areanames{en}->{61260154} = "Talgarno";
$areanames{en}->{61260155} = "Talmalmo";
$areanames{en}->{61260156} = "Walla\ Walla";
$areanames{en}->{61260157} = "Walwa";
$areanames{en}->{61260158} = "Yackandandah";
$areanames{en}->{61260159} = "Corryong";
$areanames{en}->{61260160} = "Cudgewa";
$areanames{en}->{61260161} = "Dartmouth";
$areanames{en}->{61260162} = "Eskdale";
$areanames{en}->{61260163} = "Koetong";
$areanames{en}->{61260164} = "Nariel";
$areanames{en}->{61260165} = "Tallangatta";
$areanames{en}->{61260166} = "Tallangatta\ Valley";
$areanames{en}->{61260167} = "Balldale";
$areanames{en}->{61260168} = "Barnawartha";
$areanames{en}->{61260169} = "Coppabella";
$areanames{en}->{61260170} = "Corowa";
$areanames{en}->{61260171} = "Culcairn";
$areanames{en}->{61260172} = "Gerogery";
$areanames{en}->{61260173} = "Holbrook";
$areanames{en}->{61260174} = "Howlong";
$areanames{en}->{61260175} = "Leicester\ Park";
$areanames{en}->{61260176} = "Little\ Billabong";
$areanames{en}->{61260177} = "Oaklands";
$areanames{en}->{61260178} = "Ournie";
$areanames{en}->{61260179} = "Rand";
$areanames{en}->{61260180} = "Rennie";
$areanames{en}->{61260181} = "Talgarno";
$areanames{en}->{61260182} = "Talmalmo";
$areanames{en}->{61260183} = "Walla\ Walla";
$areanames{en}->{61260184} = "Walwa";
$areanames{en}->{61260185} = "Corryong";
$areanames{en}->{61260186} = "Cudgewa";
$areanames{en}->{61260187} = "Dartmouth";
$areanames{en}->{61260188} = "Eskdale";
$areanames{en}->{61260189} = "Koetong";
$areanames{en}->{61260190} = "Nariel";
$areanames{en}->{61260191} = "Tallangatta";
$areanames{en}->{61260192} = "Tallangatta\ Valley";
$areanames{en}->{61260193} = "Balldale";
$areanames{en}->{61260194} = "Barnawartha";
$areanames{en}->{61260195} = "Coppabella";
$areanames{en}->{61260196} = "Corowa";
$areanames{en}->{61260197} = "Culcairn";
$areanames{en}->{61260198} = "Gerogery";
$areanames{en}->{61260199} = "Holbrook";
$areanames{en}->{6126020} = "Talgarno";
$areanames{en}->{61260206} = "Albury";
$areanames{en}->{61260207} = "Albury";
$areanames{en}->{61260208} = "Albury";
$areanames{en}->{61260209} = "Albury";
$areanames{en}->{6126021} = "Albury";
$areanames{en}->{6126022} = "Albury";
$areanames{en}->{6126023} = "Albury";
$areanames{en}->{6126024} = "Albury";
$areanames{en}->{6126025} = "Albury";
$areanames{en}->{61260260} = "Gerogery";
$areanames{en}->{61260261} = "Albury";
$areanames{en}->{61260262} = "Albury";
$areanames{en}->{61260263} = "Albury";
$areanames{en}->{61260264} = "Albury";
$areanames{en}->{61260265} = "Howlong";
$areanames{en}->{61260266} = "Howlong";
$areanames{en}->{61260267} = "Barnawartha";
$areanames{en}->{61260268} = "Howlong";
$areanames{en}->{61260269} = "Barnawartha";
$areanames{en}->{6126027} = "Yackandandah";
$areanames{en}->{6126028} = "Yackandandah";
$areanames{en}->{61260290} = "Rand";
$areanames{en}->{61260291} = "Walla\ Walla";
$areanames{en}->{61260292} = "Walla\ Walla";
$areanames{en}->{61260293} = "Walla\ Walla";
$areanames{en}->{61260294} = "Walla\ Walla";
$areanames{en}->{61260295} = "Rand";
$areanames{en}->{61260296} = "Culcairn";
$areanames{en}->{61260297} = "Culcairn";
$areanames{en}->{61260298} = "Culcairn";
$areanames{en}->{61260299} = "Rand";
$areanames{en}->{61260300} = "Rennie";
$areanames{en}->{61260301} = "Holbrook";
$areanames{en}->{61260302} = "Coppabella";
$areanames{en}->{61260303} = "Little\ Billabong";
$areanames{en}->{61260304} = "Corowa";
$areanames{en}->{61260305} = "Corowa";
$areanames{en}->{61260306} = "Corowa";
$areanames{en}->{61260307} = "Balldale";
$areanames{en}->{61260308} = "Leicester\ Park";
$areanames{en}->{61260309} = "Oaklands";
$areanames{en}->{61260310} = "Howlong";
$areanames{en}->{61260311} = "Leicester\ Park";
$areanames{en}->{61260312} = "Little\ Billabong";
$areanames{en}->{61260313} = "Oaklands";
$areanames{en}->{61260314} = "Ournie";
$areanames{en}->{61260315} = "Rand";
$areanames{en}->{61260316} = "Rennie";
$areanames{en}->{61260317} = "Talgarno";
$areanames{en}->{61260318} = "Talmalmo";
$areanames{en}->{61260319} = "Walla\ Walla";
$areanames{en}->{6126032} = "Rennie";
$areanames{en}->{61260327} = "Corowa";
$areanames{en}->{61260328} = "Corowa";
$areanames{en}->{61260329} = "Corowa";
$areanames{en}->{6126033} = "Corowa";
$areanames{en}->{61260340} = "Walwa";
$areanames{en}->{61260341} = "Yackandandah";
$areanames{en}->{61260342} = "Corryong";
$areanames{en}->{61260343} = "Cudgewa";
$areanames{en}->{61260344} = "Dartmouth";
$areanames{en}->{61260345} = "Eskdale";
$areanames{en}->{61260346} = "Koetong";
$areanames{en}->{61260347} = "Nariel";
$areanames{en}->{61260348} = "Tallangatta";
$areanames{en}->{61260349} = "Tallangatta\ Valley";
$areanames{en}->{61260350} = "Balldale";
$areanames{en}->{61260351} = "Balldale";
$areanames{en}->{61260352} = "Corowa";
$areanames{en}->{61260353} = "Corowa";
$areanames{en}->{61260354} = "Oaklands";
$areanames{en}->{61260355} = "Oaklands";
$areanames{en}->{61260356} = "Leicester\ Park";
$areanames{en}->{61260357} = "Corowa";
$areanames{en}->{61260358} = "Balldale";
$areanames{en}->{61260359} = "Rennie";
$areanames{en}->{6126036} = "Holbrook";
$areanames{en}->{61260367} = "Little\ Billabong";
$areanames{en}->{61260368} = "Coppabella";
$areanames{en}->{61260369} = "Coppabella";
$areanames{en}->{6126037} = "Walwa";
$areanames{en}->{61260372} = "Talmalmo";
$areanames{en}->{61260373} = "Talmalmo";
$areanames{en}->{61260374} = "Ournie";
$areanames{en}->{61260375} = "Ournie";
$areanames{en}->{61260380} = "Albury";
$areanames{en}->{61260381} = "Balldale";
$areanames{en}->{61260382} = "Barnawartha";
$areanames{en}->{61260383} = "Coppabella";
$areanames{en}->{61260384} = "Corowa";
$areanames{en}->{61260385} = "Culcairn";
$areanames{en}->{61260386} = "Gerogery";
$areanames{en}->{61260387} = "Holbrook";
$areanames{en}->{61260388} = "Howlong";
$areanames{en}->{61260389} = "Leicester\ Park";
$areanames{en}->{61260390} = "Little\ Billabong";
$areanames{en}->{61260391} = "Oaklands";
$areanames{en}->{61260392} = "Ournie";
$areanames{en}->{61260393} = "Rand";
$areanames{en}->{61260394} = "Rennie";
$areanames{en}->{61260395} = "Talgarno";
$areanames{en}->{61260396} = "Talmalmo";
$areanames{en}->{61260397} = "Walla\ Walla";
$areanames{en}->{61260398} = "Walwa";
$areanames{en}->{61260399} = "Yackandandah";
$areanames{en}->{6126040} = "Albury";
$areanames{en}->{6126041} = "Albury";
$areanames{en}->{61260420} = "Albury";
$areanames{en}->{61260421} = "Albury";
$areanames{en}->{61260422} = "Albury";
$areanames{en}->{61260423} = "Albury";
$areanames{en}->{61260424} = "Albury";
$areanames{en}->{61260425} = "Balldale";
$areanames{en}->{61260426} = "Balldale";
$areanames{en}->{61260427} = "Balldale";
$areanames{en}->{61260428} = "Barnawartha";
$areanames{en}->{61260429} = "Barnawartha";
$areanames{en}->{6126043} = "Albury";
$areanames{en}->{61260440} = "Coppabella";
$areanames{en}->{61260441} = "Coppabella";
$areanames{en}->{61260442} = "Corowa";
$areanames{en}->{61260443} = "Corowa";
$areanames{en}->{61260444} = "Corowa";
$areanames{en}->{61260445} = "Corowa";
$areanames{en}->{61260446} = "Culcairn";
$areanames{en}->{61260447} = "Culcairn";
$areanames{en}->{61260448} = "Culcairn";
$areanames{en}->{61260449} = "Walla\ Walla";
$areanames{en}->{61260450} = "Corryong";
$areanames{en}->{61260451} = "Cudgewa";
$areanames{en}->{61260452} = "Dartmouth";
$areanames{en}->{61260453} = "Eskdale";
$areanames{en}->{61260454} = "Koetong";
$areanames{en}->{61260455} = "Nariel";
$areanames{en}->{61260456} = "Tallangatta";
$areanames{en}->{61260457} = "Tallangatta\ Valley";
$areanames{en}->{61260458} = "Albury";
$areanames{en}->{61260459} = "Albury";
$areanames{en}->{61260460} = "Albury";
$areanames{en}->{61260461} = "Balldale";
$areanames{en}->{61260462} = "Barnawartha";
$areanames{en}->{61260463} = "Yackandandah";
$areanames{en}->{61260464} = "Yackandandah";
$areanames{en}->{61260465} = "Yackandandah";
$areanames{en}->{61260468} = "Howlong";
$areanames{en}->{61260469} = "Albury";
$areanames{en}->{6126047} = "Albury";
$areanames{en}->{6126048} = "Albury";
$areanames{en}->{6126049} = "Albury";
$areanames{en}->{61260500} = "Ournie";
$areanames{en}->{61260501} = "Barnawartha";
$areanames{en}->{61260502} = "Culcairn";
$areanames{en}->{61260503} = "Gerogery";
$areanames{en}->{61260504} = "Howlong";
$areanames{en}->{61260505} = "Rand";
$areanames{en}->{61260506} = "Talgarno";
$areanames{en}->{61260507} = "Walla\ Walla";
$areanames{en}->{61260508} = "Walwa";
$areanames{en}->{61260509} = "Yackandandah";
$areanames{en}->{6126051} = "Albury";
$areanames{en}->{61260520} = "Gerogery";
$areanames{en}->{61260521} = "Gerogery";
$areanames{en}->{61260522} = "Holbrook";
$areanames{en}->{61260523} = "Holbrook";
$areanames{en}->{61260524} = "Howlong";
$areanames{en}->{61260525} = "Howlong";
$areanames{en}->{61260526} = "Rand";
$areanames{en}->{61260527} = "Rand";
$areanames{en}->{61260528} = "Talgarno";
$areanames{en}->{61260529} = "Talgarno";
$areanames{en}->{61260530} = "Corryong";
$areanames{en}->{61260536} = "Tallangatta";
$areanames{en}->{61260539} = "Oaklands";
$areanames{en}->{61260540} = "Albury";
$areanames{en}->{61260541} = "Albury";
$areanames{en}->{61260542} = "Albury";
$areanames{en}->{61260548} = "Tallangatta";
$areanames{en}->{61260549} = "Tallangatta";
$areanames{en}->{6126055} = "Albury";
$areanames{en}->{6126056} = "Albury";
$areanames{en}->{6126057} = "Albury";
$areanames{en}->{6126058} = "Albury";
$areanames{en}->{61260589} = "Talmalmo";
$areanames{en}->{6126059} = "Albury";
$areanames{en}->{6126060} = "Albury";
$areanames{en}->{61260610} = "Albury";
$areanames{en}->{61260611} = "Albury";
$areanames{en}->{61260612} = "Albury";
$areanames{en}->{61260613} = "Albury";
$areanames{en}->{61260614} = "Albury";
$areanames{en}->{61260615} = "Corowa";
$areanames{en}->{61260616} = "Corryong";
$areanames{en}->{61260617} = "Corryong";
$areanames{en}->{61260618} = "Cudgewa";
$areanames{en}->{61260619} = "Cudgewa";
$areanames{en}->{61260620} = "Nariel";
$areanames{en}->{61260621} = "Nariel";
$areanames{en}->{61260622} = "Albury";
$areanames{en}->{61260623} = "Albury";
$areanames{en}->{61260624} = "Ournie";
$areanames{en}->{61260625} = "Ournie";
$areanames{en}->{61260626} = "Rand";
$areanames{en}->{61260627} = "Rand";
$areanames{en}->{61260628} = "Rennie";
$areanames{en}->{61260629} = "Rennie";
$areanames{en}->{61260630} = "Talmalmo";
$areanames{en}->{61260631} = "Talmalmo";
$areanames{en}->{61260632} = "Walwa";
$areanames{en}->{61260633} = "Walwa";
$areanames{en}->{61260634} = "Koetong";
$areanames{en}->{61260635} = "Koetong";
$areanames{en}->{61260636} = "Dartmouth";
$areanames{en}->{61260637} = "Dartmouth";
$areanames{en}->{61260638} = "Eskdale";
$areanames{en}->{61260639} = "Eskdale";
$areanames{en}->{61260641} = "Albury";
$areanames{en}->{61260642} = "Albury";
$areanames{en}->{61260643} = "Dartmouth";
$areanames{en}->{61260644} = "Dartmouth";
$areanames{en}->{61260645} = "Balldale";
$areanames{en}->{61260646} = "Corowa";
$areanames{en}->{61260647} = "Howlong";
$areanames{en}->{61260648} = "Rand";
$areanames{en}->{61260649} = "Ournie";
$areanames{en}->{61260650} = "Gerogery";
$areanames{en}->{61260651} = "Little\ Billabong";
$areanames{en}->{61260652} = "Barnawartha";
$areanames{en}->{61260653} = "Barnawartha";
$areanames{en}->{61260654} = "Culcairn";
$areanames{en}->{61260655} = "Culcairn";
$areanames{en}->{61260656} = "Howlong";
$areanames{en}->{61260657} = "Howlong";
$areanames{en}->{61260658} = "Leicester\ Park";
$areanames{en}->{61260659} = "Gerogery";
$areanames{en}->{61260660} = "Albury";
$areanames{en}->{61260661} = "Oaklands";
$areanames{en}->{61260662} = "Barnawartha";
$areanames{en}->{61260663} = "Rennie";
$areanames{en}->{61260664} = "Ournie";
$areanames{en}->{61260665} = "Culcairn";
$areanames{en}->{61260666} = "Holbrook";
$areanames{en}->{61260667} = "Gerogery";
$areanames{en}->{61260668} = "Coppabella";
$areanames{en}->{61260669} = "Albury";
$areanames{en}->{61260670} = "Albury";
$areanames{en}->{61260671} = "Walla\ Walla";
$areanames{en}->{61260672} = "Albury";
$areanames{en}->{61260673} = "Walwa";
$areanames{en}->{61260674} = "Yackandandah";
$areanames{en}->{61260675} = "Balldale";
$areanames{en}->{61260676} = "Leicester\ Park";
$areanames{en}->{61260677} = "Talgarno";
$areanames{en}->{61260678} = "Talmalmo";
$areanames{en}->{61260679} = "Albury";
$areanames{en}->{61260681} = "Eskdale";
$areanames{en}->{61260682} = "Dartmouth";
$areanames{en}->{61260683} = "Cudgewa";
$areanames{en}->{61260684} = "Tallangatta";
$areanames{en}->{61260685} = "Nariel";
$areanames{en}->{61260686} = "Corryong";
$areanames{en}->{61260687} = "Koetong";
$areanames{en}->{61260688} = "Tallangatta\ Valley";
$areanames{en}->{61260689} = "Albury";
$areanames{en}->{61260691} = "Corowa";
$areanames{en}->{61260692} = "Howlong";
$areanames{en}->{61260693} = "Rand";
$areanames{en}->{61260694} = "Oaklands";
$areanames{en}->{61260695} = "Barnawartha";
$areanames{en}->{61260696} = "Rennie";
$areanames{en}->{61260697} = "Ournie";
$areanames{en}->{61260698} = "Culcairn";
$areanames{en}->{61260699} = "Albury";
$areanames{en}->{61260700} = "Corryong";
$areanames{en}->{61260701} = "Koetong";
$areanames{en}->{61260702} = "Eskdale";
$areanames{en}->{61260703} = "Tallangatta";
$areanames{en}->{61260704} = "Tallangatta\ Valley";
$areanames{en}->{61260705} = "Dartmouth";
$areanames{en}->{61260706} = "Corryong";
$areanames{en}->{61260707} = "Cudgewa";
$areanames{en}->{61260708} = "Nariel";
$areanames{en}->{61260709} = "Corryong";
$areanames{en}->{6126071} = "Tallangatta";
$areanames{en}->{61260710} = "Tallangatta\ Valley";
$areanames{en}->{61260719} = "Tallangatta\ Valley";
$areanames{en}->{61260720} = "Eskdale";
$areanames{en}->{61260721} = "Eskdale";
$areanames{en}->{61260722} = "Eskdale";
$areanames{en}->{61260723} = "Eskdale";
$areanames{en}->{61260724} = "Dartmouth";
$areanames{en}->{61260725} = "Tallangatta";
$areanames{en}->{61260726} = "Tallangatta";
$areanames{en}->{61260727} = "Koetong";
$areanames{en}->{61260728} = "Koetong";
$areanames{en}->{61260729} = "Tallangatta";
$areanames{en}->{61260730} = "Yackandandah";
$areanames{en}->{61260731} = "Yackandandah";
$areanames{en}->{61260732} = "Walla\ Walla";
$areanames{en}->{61260733} = "Walla\ Walla";
$areanames{en}->{61260734} = "Barnawartha";
$areanames{en}->{61260735} = "Barnawartha";
$areanames{en}->{61260736} = "Corowa";
$areanames{en}->{61260737} = "Corowa";
$areanames{en}->{61260738} = "Culcairn";
$areanames{en}->{61260739} = "Culcairn";
$areanames{en}->{61260740} = "Gerogery";
$areanames{en}->{61260741} = "Gerogery";
$areanames{en}->{61260742} = "Holbrook";
$areanames{en}->{61260743} = "Holbrook";
$areanames{en}->{61260744} = "Howlong";
$areanames{en}->{61260745} = "Howlong";
$areanames{en}->{61260746} = "Little\ Billabong";
$areanames{en}->{61260747} = "Little\ Billabong";
$areanames{en}->{61260748} = "Talgarno";
$areanames{en}->{61260749} = "Talgarno";
$areanames{en}->{61260750} = "Albury";
$areanames{en}->{61260751} = "Balldale";
$areanames{en}->{61260752} = "Balldale";
$areanames{en}->{61260753} = "Coppabella";
$areanames{en}->{61260754} = "Coppabella";
$areanames{en}->{61260755} = "Leicester\ Park";
$areanames{en}->{61260756} = "Leicester\ Park";
$areanames{en}->{61260757} = "Oaklands";
$areanames{en}->{61260758} = "Oaklands";
$areanames{en}->{61260759} = "Albury";
$areanames{en}->{6126076} = "Corryong";
$areanames{en}->{61260760} = "Nariel";
$areanames{en}->{61260765} = "Nariel";
$areanames{en}->{61260766} = "Nariel";
$areanames{en}->{61260769} = "Nariel";
$areanames{en}->{61260770} = "Nariel";
$areanames{en}->{61260771} = "Nariel";
$areanames{en}->{61260772} = "Nariel";
$areanames{en}->{61260773} = "Nariel";
$areanames{en}->{61260774} = "Cudgewa";
$areanames{en}->{61260775} = "Cudgewa";
$areanames{en}->{61260776} = "Cudgewa";
$areanames{en}->{61260777} = "Cudgewa";
$areanames{en}->{61260778} = "Corryong";
$areanames{en}->{61260779} = "Corryong";
$areanames{en}->{61260780} = "Albury";
$areanames{en}->{61260781} = "Balldale";
$areanames{en}->{61260782} = "Barnawartha";
$areanames{en}->{61260783} = "Coppabella";
$areanames{en}->{61260784} = "Corowa";
$areanames{en}->{61260785} = "Culcairn";
$areanames{en}->{61260786} = "Gerogery";
$areanames{en}->{61260787} = "Holbrook";
$areanames{en}->{61260788} = "Howlong";
$areanames{en}->{61260789} = "Leicester\ Park";
$areanames{en}->{61260790} = "Little\ Billabong";
$areanames{en}->{61260791} = "Oaklands";
$areanames{en}->{61260792} = "Ournie";
$areanames{en}->{61260793} = "Rand";
$areanames{en}->{61260794} = "Rennie";
$areanames{en}->{61260795} = "Talgarno";
$areanames{en}->{61260796} = "Talmalmo";
$areanames{en}->{61260797} = "Walla\ Walla";
$areanames{en}->{61260798} = "Walwa";
$areanames{en}->{61260799} = "Yackandandah";
$areanames{en}->{61260800} = "Corryong";
$areanames{en}->{61260801} = "Cudgewa";
$areanames{en}->{61260802} = "Dartmouth";
$areanames{en}->{61260803} = "Eskdale";
$areanames{en}->{61260804} = "Koetong";
$areanames{en}->{61260805} = "Nariel";
$areanames{en}->{61260806} = "Tallangatta";
$areanames{en}->{61260807} = "Tallangatta\ Valley";
$areanames{en}->{61260808} = "Albury";
$areanames{en}->{61260809} = "Albury";
$areanames{en}->{61260810} = "Albury";
$areanames{en}->{61260811} = "Tallangatta\ Valley";
$areanames{en}->{61260812} = "Tallangatta\ Valley";
$areanames{en}->{61260813} = "Holbrook";
$areanames{en}->{61260814} = "Gerogery";
$areanames{en}->{61260815} = "Coppabella";
$areanames{en}->{61260816} = "Walla\ Walla";
$areanames{en}->{61260817} = "Albury";
$areanames{en}->{61260818} = "Walwa";
$areanames{en}->{61260819} = "Albury";
$areanames{en}->{61260821} = "Yackandandah";
$areanames{en}->{61260822} = "Little\ Billabong";
$areanames{en}->{61260823} = "Leicester\ Park";
$areanames{en}->{61260824} = "Talgarno";
$areanames{en}->{61260825} = "Talmalmo";
$areanames{en}->{61260826} = "Eskdale";
$areanames{en}->{61260827} = "Dartmouth";
$areanames{en}->{61260828} = "Cudgewa";
$areanames{en}->{61260829} = "Albury";
$areanames{en}->{61260831} = "Tallangatta";
$areanames{en}->{61260832} = "Nariel";
$areanames{en}->{61260833} = "Corryong";
$areanames{en}->{61260834} = "Koetong";
$areanames{en}->{61260835} = "Tallangatta\ Valley";
$areanames{en}->{61260836} = "Eskdale";
$areanames{en}->{61260837} = "Dartmouth";
$areanames{en}->{61260838} = "Cudgewa";
$areanames{en}->{61260841} = "Tallangatta";
$areanames{en}->{61260842} = "Nariel";
$areanames{en}->{61260843} = "Corryong";
$areanames{en}->{61260844} = "Koetong";
$areanames{en}->{61260845} = "Tallangatta\ Valley";
$areanames{en}->{61260846} = "Balldale";
$areanames{en}->{61260847} = "Corowa";
$areanames{en}->{61260848} = "Howlong";
$areanames{en}->{61260851} = "Walwa";
$areanames{en}->{61260852} = "Barnawartha";
$areanames{en}->{61260853} = "Yackandandah";
$areanames{en}->{61260854} = "Coppabella";
$areanames{en}->{61260855} = "Rennie";
$areanames{en}->{61260856} = "Walla\ Walla";
$areanames{en}->{61260857} = "Ournie";
$areanames{en}->{61260858} = "Rand";
$areanames{en}->{61260861} = "Culcairn";
$areanames{en}->{61260862} = "Little\ Billabong";
$areanames{en}->{61260863} = "Leicester\ Park";
$areanames{en}->{61260864} = "Holbrook";
$areanames{en}->{61260865} = "Talgarno";
$areanames{en}->{61260866} = "Gerogery";
$areanames{en}->{61260867} = "Talmalmo";
$areanames{en}->{61260868} = "Oaklands";
$areanames{en}->{61260869} = "Dartmouth";
$areanames{en}->{6126087} = "Albury";
$areanames{en}->{61260882} = "Coppabella";
$areanames{en}->{61260883} = "Holbrook";
$areanames{en}->{61260884} = "Walwa";
$areanames{en}->{61260885} = "Barnawartha";
$areanames{en}->{61260886} = "Albury";
$areanames{en}->{61260887} = "Walla\ Walla";
$areanames{en}->{61260888} = "Rennie";
$areanames{en}->{61260889} = "Balldale";
$areanames{en}->{61260890} = "Gerogery";
$areanames{en}->{61260891} = "Little\ Billabong";
$areanames{en}->{61260892} = "Culcairn";
$areanames{en}->{61260893} = "Talmalmo";
$areanames{en}->{61260894} = "Rand";
$areanames{en}->{61260895} = "Oaklands";
$areanames{en}->{61260896} = "Leicester\ Park";
$areanames{en}->{61260897} = "Talgarno";
$areanames{en}->{61260898} = "Corowa";
$areanames{en}->{61260899} = "Yackandandah";
$areanames{en}->{61260900} = "Howlong";
$areanames{en}->{61260910} = "Ournie";
$areanames{en}->{61260920} = "Albury";
$areanames{en}->{61260921} = "Albury";
$areanames{en}->{61260922} = "Albury";
$areanames{en}->{61260923} = "Albury";
$areanames{en}->{61260924} = "Albury";
$areanames{en}->{61260925} = "Albury";
$areanames{en}->{61260926} = "Albury";
$areanames{en}->{61261} = "Canberra";
$areanames{en}->{61261040} = "Anembo";
$areanames{en}->{61261041} = "Anembo";
$areanames{en}->{61261042} = "Anembo";
$areanames{en}->{61261043} = "Binalong";
$areanames{en}->{61261044} = "Binalong";
$areanames{en}->{61261045} = "Binalong";
$areanames{en}->{61261046} = "Bungendore";
$areanames{en}->{61261047} = "Bungendore";
$areanames{en}->{61261048} = "Bungendore";
$areanames{en}->{61261050} = "Burrinjuck";
$areanames{en}->{61261051} = "Burrinjuck";
$areanames{en}->{61261052} = "Burrinjuck";
$areanames{en}->{61261053} = "Captains\ Flat";
$areanames{en}->{61261054} = "Captains\ Flat";
$areanames{en}->{61261055} = "Captains\ Flat";
$areanames{en}->{61261056} = "Cavan";
$areanames{en}->{61261057} = "Cavan";
$areanames{en}->{61261058} = "Cavan";
$areanames{en}->{61261059} = "Anembo";
$areanames{en}->{61261060} = "Gearys\ Gap";
$areanames{en}->{61261061} = "Gearys\ Gap";
$areanames{en}->{61261062} = "Gearys\ Gap";
$areanames{en}->{61261063} = "Gundaroo";
$areanames{en}->{61261064} = "Gundaroo";
$areanames{en}->{61261065} = "Gundaroo";
$areanames{en}->{61261066} = "Michelago";
$areanames{en}->{61261067} = "Michelago";
$areanames{en}->{61261068} = "Michelago";
$areanames{en}->{61261069} = "Binalong";
$areanames{en}->{61261070} = "Rye\ Park";
$areanames{en}->{61261071} = "Rye\ Park";
$areanames{en}->{61261072} = "Rye\ Park";
$areanames{en}->{61261073} = "The\ Mullion";
$areanames{en}->{61261074} = "The\ Mullion";
$areanames{en}->{61261075} = "The\ Mullion";
$areanames{en}->{61261076} = "Uriarra\ Forest";
$areanames{en}->{61261077} = "Uriarra\ Forest";
$areanames{en}->{61261078} = "Uriarra\ Forest";
$areanames{en}->{61261079} = "Rye\ Park";
$areanames{en}->{61261080} = "Yass";
$areanames{en}->{61261081} = "Yass";
$areanames{en}->{61261082} = "Yass";
$areanames{en}->{61261085} = "The\ Mullion";
$areanames{en}->{61261086} = "Uriarra\ Forest";
$areanames{en}->{61261087} = "Yass";
$areanames{en}->{61261088} = "Anembo";
$areanames{en}->{61261089} = "Binalong";
$areanames{en}->{61261110} = "Bungendore";
$areanames{en}->{61261113} = "Bungendore";
$areanames{en}->{61261114} = "Burrinjuck";
$areanames{en}->{61261115} = "Captains\ Flat";
$areanames{en}->{61261116} = "Cavan";
$areanames{en}->{61261117} = "Gearys\ Gap";
$areanames{en}->{61261118} = "Gundaroo";
$areanames{en}->{61261119} = "Michelago";
$areanames{en}->{61261140} = "Burrinjuck";
$areanames{en}->{61261146} = "Captains\ Flat";
$areanames{en}->{61261147} = "Cavan";
$areanames{en}->{61261148} = "Gearys\ Gap";
$areanames{en}->{61261149} = "Gundaroo";
$areanames{en}->{61261150} = "Michelago";
$areanames{en}->{61261151} = "Rye\ Park";
$areanames{en}->{61261152} = "The\ Mullion";
$areanames{en}->{61261153} = "Uriarra\ Forest";
$areanames{en}->{61261154} = "Yass";
$areanames{en}->{61261155} = "Anembo";
$areanames{en}->{61261156} = "Binalong";
$areanames{en}->{61261157} = "The\ Mullion";
$areanames{en}->{61261158} = "Uriarra\ Forest";
$areanames{en}->{61261159} = "Yass";
$areanames{en}->{61261160} = "Bungendore";
$areanames{en}->{61261161} = "Burrinjuck";
$areanames{en}->{61261162} = "Captains\ Flat";
$areanames{en}->{61261163} = "Cavan";
$areanames{en}->{61261164} = "Gearys\ Gap";
$areanames{en}->{61261165} = "Gundaroo";
$areanames{en}->{61261166} = "Michelago";
$areanames{en}->{61261167} = "Rye\ Park";
$areanames{en}->{61261169} = "Anembo";
$areanames{en}->{61261170} = "Binalong";
$areanames{en}->{61261171} = "Bungendore";
$areanames{en}->{61261172} = "Burrinjuck";
$areanames{en}->{61261173} = "Captains\ Flat";
$areanames{en}->{61261174} = "Cavan";
$areanames{en}->{61261175} = "Gearys\ Gap";
$areanames{en}->{61261176} = "Gundaroo";
$areanames{en}->{61261177} = "Michelago";
$areanames{en}->{61261178} = "Rye\ Park";
$areanames{en}->{61261179} = "The\ Mullion";
$areanames{en}->{61261180} = "Binalong";
$areanames{en}->{61261181} = "Binalong";
$areanames{en}->{61261182} = "Burrinjuck";
$areanames{en}->{61261183} = "Cavan";
$areanames{en}->{61261184} = "Rye\ Park";
$areanames{en}->{61261185} = "The\ Mullion";
$areanames{en}->{61261186} = "Yass";
$areanames{en}->{61261187} = "Yass";
$areanames{en}->{61261188} = "The\ Mullion";
$areanames{en}->{61261189} = "Uriarra\ Forest";
$areanames{en}->{61261190} = "Anembo";
$areanames{en}->{61261191} = "Captains\ Flat";
$areanames{en}->{61261192} = "Captains\ Flat";
$areanames{en}->{61261193} = "Gearys\ Gap";
$areanames{en}->{61261194} = "Gearys\ Gap";
$areanames{en}->{61261195} = "Gundaroo";
$areanames{en}->{61261196} = "Gundaroo";
$areanames{en}->{61261197} = "Bungendore";
$areanames{en}->{61261198} = "Yass";
$areanames{en}->{61261199} = "Rye\ Park";
$areanames{en}->{61261302} = "Uriarra\ Forest";
$areanames{en}->{61261303} = "Yass";
$areanames{en}->{61261304} = "Anembo";
$areanames{en}->{61261305} = "Binalong";
$areanames{en}->{61261306} = "Bungendore";
$areanames{en}->{61261307} = "Burrinjuck";
$areanames{en}->{61261308} = "Captains\ Flat";
$areanames{en}->{61261309} = "Cavan";
$areanames{en}->{61261340} = "Gearys\ Gap";
$areanames{en}->{61261341} = "Gundaroo";
$areanames{en}->{61261342} = "Michelago";
$areanames{en}->{61261343} = "The\ Mullion";
$areanames{en}->{61261344} = "Uriarra\ Forest";
$areanames{en}->{61261345} = "Yass";
$areanames{en}->{61261347} = "Anembo";
$areanames{en}->{61261348} = "Binalong";
$areanames{en}->{61261349} = "Bungendore";
$areanames{en}->{61261360} = "Burrinjuck";
$areanames{en}->{61261362} = "Captains\ Flat";
$areanames{en}->{61261363} = "Cavan";
$areanames{en}->{61261364} = "Gearys\ Gap";
$areanames{en}->{61261365} = "Gundaroo";
$areanames{en}->{61261366} = "Michelago";
$areanames{en}->{61261367} = "Rye\ Park";
$areanames{en}->{61261368} = "The\ Mullion";
$areanames{en}->{61261369} = "Uriarra\ Forest";
$areanames{en}->{61261370} = "Yass";
$areanames{en}->{61261371} = "Yass";
$areanames{en}->{61261372} = "Anembo";
$areanames{en}->{61261373} = "Binalong";
$areanames{en}->{61261374} = "Bungendore";
$areanames{en}->{61261375} = "Burrinjuck";
$areanames{en}->{61261376} = "Captains\ Flat";
$areanames{en}->{61261377} = "Cavan";
$areanames{en}->{61261378} = "Gearys\ Gap";
$areanames{en}->{61261379} = "Gundaroo";
$areanames{en}->{61261380} = "Michelago";
$areanames{en}->{61261381} = "Rye\ Park";
$areanames{en}->{61261382} = "The\ Mullion";
$areanames{en}->{61261383} = "Uriarra\ Forest";
$areanames{en}->{61261384} = "Yass";
$areanames{en}->{61261385} = "Bungendore";
$areanames{en}->{61261386} = "Yass";
$areanames{en}->{61261387} = "Anembo";
$areanames{en}->{61261388} = "Binalong";
$areanames{en}->{61261389} = "Bungendore";
$areanames{en}->{61261390} = "Burrinjuck";
$areanames{en}->{61261392} = "Captains\ Flat";
$areanames{en}->{61261393} = "Cavan";
$areanames{en}->{61261394} = "Gearys\ Gap";
$areanames{en}->{61261395} = "Gundaroo";
$areanames{en}->{61261396} = "Michelago";
$areanames{en}->{61261397} = "Rye\ Park";
$areanames{en}->{61261398} = "The\ Mullion";
$areanames{en}->{61261399} = "Uriarra\ Forest";
$areanames{en}->{61261400} = "Yass";
$areanames{en}->{61261409} = "Anembo";
$areanames{en}->{61261410} = "Binalong";
$areanames{en}->{61261451} = "Michelago";
$areanames{en}->{61261453} = "Yass";
$areanames{en}->{61261454} = "Captains\ Flat";
$areanames{en}->{61261455} = "Cavan";
$areanames{en}->{61261456} = "Binalong";
$areanames{en}->{61261457} = "Gundaroo";
$areanames{en}->{61261458} = "Gearys\ Gap";
$areanames{en}->{61261459} = "Bungendore";
$areanames{en}->{61261480} = "Burrinjuck";
$areanames{en}->{61261481} = "The\ Mullion";
$areanames{en}->{61261482} = "Uriarra\ Forest";
$areanames{en}->{61261483} = "Anembo";
$areanames{en}->{61261484} = "Bungendore";
$areanames{en}->{61261485} = "Rye\ Park";
$areanames{en}->{61261486} = "Burrinjuck";
$areanames{en}->{61261487} = "Michelago";
$areanames{en}->{61261488} = "Yass";
$areanames{en}->{61261490} = "Captains\ Flat";
$areanames{en}->{61261491} = "Captains\ Flat";
$areanames{en}->{61261492} = "Cavan";
$areanames{en}->{61261493} = "Cavan";
$areanames{en}->{61261494} = "Binalong";
$areanames{en}->{61261495} = "Gundaroo";
$areanames{en}->{61261496} = "Gearys\ Gap";
$areanames{en}->{61261497} = "The\ Mullion";
$areanames{en}->{61261498} = "Uriarra\ Forest";
$areanames{en}->{61261499} = "Gearys\ Gap";
$areanames{en}->{61261500} = "Gundaroo";
$areanames{en}->{61261501} = "Anembo";
$areanames{en}->{61261502} = "Bungendore";
$areanames{en}->{61261503} = "Rye\ Park";
$areanames{en}->{61261504} = "Burrinjuck";
$areanames{en}->{61261526} = "Yass";
$areanames{en}->{61261527} = "Yass";
$areanames{en}->{61261537} = "The\ Mullion";
$areanames{en}->{61261538} = "Bungendore";
$areanames{en}->{61261539} = "Michelago";
$areanames{en}->{61261570} = "Anembo";
$areanames{en}->{61261571} = "Binalong";
$areanames{en}->{61261572} = "Yass";
$areanames{en}->{61261573} = "Bungendore";
$areanames{en}->{61261574} = "Burrinjuck";
$areanames{en}->{61261576} = "Captains\ Flat";
$areanames{en}->{61261577} = "Cavan";
$areanames{en}->{61261578} = "Uriarra\ Forest";
$areanames{en}->{61261579} = "The\ Mullion";
$areanames{en}->{61261580} = "Michelago";
$areanames{en}->{61261581} = "Gundaroo";
$areanames{en}->{61261582} = "Gundaroo";
$areanames{en}->{61261583} = "Cavan";
$areanames{en}->{61261584} = "Binalong";
$areanames{en}->{61261585} = "Uriarra\ Forest";
$areanames{en}->{61261586} = "Captains\ Flat";
$areanames{en}->{61261587} = "Anembo";
$areanames{en}->{61261588} = "Burrinjuck";
$areanames{en}->{61261589} = "Rye\ Park";
$areanames{en}->{61261590} = "The\ Mullion";
$areanames{en}->{61261591} = "Gearys\ Gap";
$areanames{en}->{61261592} = "Rye\ Park";
$areanames{en}->{61261599} = "Uriarra\ Forest";
$areanames{en}->{61261640} = "Anembo";
$areanames{en}->{61261641} = "Binalong";
$areanames{en}->{61261642} = "Bungendore";
$areanames{en}->{61261643} = "Burrinjuck";
$areanames{en}->{61261644} = "Captains\ Flat";
$areanames{en}->{61261645} = "Cavan";
$areanames{en}->{61261646} = "Gearys\ Gap";
$areanames{en}->{61261647} = "Gundaroo";
$areanames{en}->{61261648} = "Michelago";
$areanames{en}->{61261649} = "Rye\ Park";
$areanames{en}->{61261680} = "Burrinjuck";
$areanames{en}->{61261681} = "Binalong";
$areanames{en}->{61261682} = "Bungendore";
$areanames{en}->{61261683} = "Cavan";
$areanames{en}->{61261684} = "Captains\ Flat";
$areanames{en}->{61261685} = "Gearys\ Gap";
$areanames{en}->{61261686} = "Gundaroo";
$areanames{en}->{61261687} = "Michelago";
$areanames{en}->{61261688} = "The\ Mullion";
$areanames{en}->{61261689} = "Anembo";
$areanames{en}->{61261690} = "Rye\ Park";
$areanames{en}->{61261691} = "Yass";
$areanames{en}->{61261692} = "Uriarra\ Forest";
$areanames{en}->{61261698} = "Bungendore";
$areanames{en}->{61261699} = "Bungendore";
$areanames{en}->{61261790} = "Yass";
$areanames{en}->{61261791} = "Michelago";
$areanames{en}->{61261792} = "Gundaroo";
$areanames{en}->{61261881} = "Captains\ Flat";
$areanames{en}->{61261946} = "Rye\ Park";
$areanames{en}->{61261947} = "Gearys\ Gap";
$areanames{en}->{61261948} = "Gundaroo";
$areanames{en}->{61262} = "Canberra";
$areanames{en}->{61262201} = "Yass";
$areanames{en}->{61262202} = "Yass";
$areanames{en}->{61262203} = "Binalong";
$areanames{en}->{61262204} = "Burrinjuck";
$areanames{en}->{61262205} = "Cavan";
$areanames{en}->{61262206} = "Rye\ Park";
$areanames{en}->{61262207} = "The\ Mullion";
$areanames{en}->{6126226} = "Yass";
$areanames{en}->{61262268} = "The\ Mullion";
$areanames{en}->{61262270} = "The\ Mullion";
$areanames{en}->{61262271} = "Yass";
$areanames{en}->{61262272} = "Rye\ Park";
$areanames{en}->{61262273} = "Rye\ Park";
$areanames{en}->{61262274} = "Binalong";
$areanames{en}->{61262275} = "The\ Mullion";
$areanames{en}->{61262276} = "Binalong";
$areanames{en}->{61262277} = "Binalong";
$areanames{en}->{61262278} = "Burrinjuck";
$areanames{en}->{61262279} = "Cavan";
$areanames{en}->{61262308} = "Anembo";
$areanames{en}->{61262331} = "Bungendore";
$areanames{en}->{61262332} = "Gearys\ Gap";
$areanames{en}->{61262333} = "Gundaroo";
$areanames{en}->{61262334} = "Uriarra\ Forest";
$areanames{en}->{61262335} = "Michelago";
$areanames{en}->{61262336} = "Captains\ Flat";
$areanames{en}->{61262337} = "Anembo";
$areanames{en}->{6126235} = "Michelago";
$areanames{en}->{61262360} = "Uriarra\ Forest";
$areanames{en}->{61262361} = "Uriarra\ Forest";
$areanames{en}->{61262362} = "Uriarra\ Forest";
$areanames{en}->{61262363} = "Captains\ Flat";
$areanames{en}->{61262364} = "Captains\ Flat";
$areanames{en}->{61262365} = "Uriarra\ Forest";
$areanames{en}->{61262366} = "Captains\ Flat";
$areanames{en}->{61262367} = "Captains\ Flat";
$areanames{en}->{61262368} = "Gundaroo";
$areanames{en}->{61262369} = "Gearys\ Gap";
$areanames{en}->{6126237} = "Michelago";
$areanames{en}->{6126238} = "Bungendore";
$areanames{en}->{61263000} = "Bathurst";
$areanames{en}->{61263001} = "Burraga";
$areanames{en}->{61263002} = "Gingkin";
$areanames{en}->{61263003} = "Hill\ End";
$areanames{en}->{61263004} = "Killongbutta";
$areanames{en}->{61263005} = "Limekilns";
$areanames{en}->{61263006} = "Oberon";
$areanames{en}->{61263007} = "Rockley";
$areanames{en}->{61263008} = "Yetholme";
$areanames{en}->{61263009} = "Canowindra";
$areanames{en}->{61263010} = "Baldry";
$areanames{en}->{61263011} = "Baldry";
$areanames{en}->{61263012} = "Baldry";
$areanames{en}->{61263013} = "Bathurst";
$areanames{en}->{61263014} = "Bathurst";
$areanames{en}->{61263015} = "Bathurst";
$areanames{en}->{61263016} = "Birriwa";
$areanames{en}->{61263017} = "Birriwa";
$areanames{en}->{61263018} = "Birriwa";
$areanames{en}->{61263019} = "Bathurst";
$areanames{en}->{61263020} = "Blayney";
$areanames{en}->{61263021} = "Blayney";
$areanames{en}->{61263022} = "Blayney";
$areanames{en}->{61263023} = "Boorowa";
$areanames{en}->{61263024} = "Boorowa";
$areanames{en}->{61263025} = "Boorowa";
$areanames{en}->{61263026} = "Bribbaree";
$areanames{en}->{61263027} = "Bribbaree";
$areanames{en}->{61263028} = "Bribbaree";
$areanames{en}->{61263029} = "Burraga";
$areanames{en}->{61263030} = "Burraga";
$areanames{en}->{61263031} = "Burraga";
$areanames{en}->{61263032} = "Burraga";
$areanames{en}->{61263033} = "Bylong";
$areanames{en}->{61263034} = "Bylong";
$areanames{en}->{61263035} = "Bylong";
$areanames{en}->{61263036} = "Canowindra";
$areanames{en}->{61263037} = "Canowindra";
$areanames{en}->{61263038} = "Canowindra";
$areanames{en}->{612630390} = "Gingkin";
$areanames{en}->{612630391} = "Gingkin";
$areanames{en}->{612630392} = "Gingkin";
$areanames{en}->{612630393} = "Gingkin";
$areanames{en}->{612630394} = "Burraga";
$areanames{en}->{612630395} = "Burraga";
$areanames{en}->{612630396} = "Gingkin";
$areanames{en}->{612630397} = "Burraga";
$areanames{en}->{612630398} = "Burraga";
$areanames{en}->{612630399} = "Burraga";
$areanames{en}->{61263040} = "Caragabal";
$areanames{en}->{61263041} = "Caragabal";
$areanames{en}->{61263042} = "Caragabal";
$areanames{en}->{61263043} = "Cassilis";
$areanames{en}->{61263044} = "Cassilis";
$areanames{en}->{61263045} = "Cassilis";
$areanames{en}->{61263046} = "Coolah";
$areanames{en}->{61263047} = "Coolah";
$areanames{en}->{61263048} = "Coolah";
$areanames{en}->{612630490} = "Hill\ End";
$areanames{en}->{612630491} = "Hill\ End";
$areanames{en}->{612630492} = "Hill\ End";
$areanames{en}->{612630493} = "Hill\ End";
$areanames{en}->{612630494} = "Burraga";
$areanames{en}->{612630495} = "Burraga";
$areanames{en}->{612630496} = "Hill\ End";
$areanames{en}->{612630497} = "Burraga";
$areanames{en}->{612630498} = "Burraga";
$areanames{en}->{612630499} = "Burraga";
$areanames{en}->{61263050} = "Windeyer";
$areanames{en}->{61263051} = "Windeyer";
$areanames{en}->{61263052} = "Windeyer";
$areanames{en}->{61263053} = "Windeyer";
$areanames{en}->{61263054} = "Blayney";
$areanames{en}->{61263055} = "Blayney";
$areanames{en}->{61263056} = "Bathurst";
$areanames{en}->{61263057} = "Cowra";
$areanames{en}->{61263058} = "Cowra";
$areanames{en}->{61263059} = "Cowra";
$areanames{en}->{61263060} = "Cudal";
$areanames{en}->{61263061} = "Cudal";
$areanames{en}->{61263062} = "Cudal";
$areanames{en}->{61263063} = "Cumnock";
$areanames{en}->{61263064} = "Cumnock";
$areanames{en}->{61263065} = "Cumnock";
$areanames{en}->{61263066} = "Dunedoo";
$areanames{en}->{61263067} = "Dunedoo";
$areanames{en}->{61263068} = "Dunedoo";
$areanames{en}->{612630690} = "Killongbutta";
$areanames{en}->{612630691} = "Killongbutta";
$areanames{en}->{612630692} = "Killongbutta";
$areanames{en}->{612630693} = "Killongbutta";
$areanames{en}->{612630694} = "Burraga";
$areanames{en}->{612630695} = "Burraga";
$areanames{en}->{612630696} = "Killongbutta";
$areanames{en}->{612630697} = "Burraga";
$areanames{en}->{612630698} = "Burraga";
$areanames{en}->{612630699} = "Burraga";
$areanames{en}->{61263070} = "Euchareena";
$areanames{en}->{61263071} = "Euchareena";
$areanames{en}->{61263072} = "Euchareena";
$areanames{en}->{61263073} = "Frogmore";
$areanames{en}->{61263074} = "Frogmore";
$areanames{en}->{61263075} = "Frogmore";
$areanames{en}->{61263076} = "Galong";
$areanames{en}->{61263077} = "Galong";
$areanames{en}->{61263078} = "Galong";
$areanames{en}->{612630790} = "Limekilns";
$areanames{en}->{612630791} = "Limekilns";
$areanames{en}->{612630792} = "Limekilns";
$areanames{en}->{612630793} = "Limekilns";
$areanames{en}->{612630794} = "Burraga";
$areanames{en}->{612630795} = "Burraga";
$areanames{en}->{612630796} = "Limekilns";
$areanames{en}->{612630797} = "Burraga";
$areanames{en}->{612630798} = "Burraga";
$areanames{en}->{612630799} = "Burraga";
$areanames{en}->{61263080} = "Gingkin";
$areanames{en}->{61263081} = "Gingkin";
$areanames{en}->{61263082} = "Gingkin";
$areanames{en}->{61263083} = "Glen\ Davis";
$areanames{en}->{61263084} = "Glen\ Davis";
$areanames{en}->{61263085} = "Glen\ Davis";
$areanames{en}->{61263086} = "Gooloogong";
$areanames{en}->{61263087} = "Gooloogong";
$areanames{en}->{61263088} = "Gooloogong";
$areanames{en}->{612630890} = "Oberon";
$areanames{en}->{612630891} = "Oberon";
$areanames{en}->{612630892} = "Oberon";
$areanames{en}->{612630893} = "Oberon";
$areanames{en}->{612630894} = "Burraga";
$areanames{en}->{612630895} = "Burraga";
$areanames{en}->{612630896} = "Oberon";
$areanames{en}->{612630897} = "Burraga";
$areanames{en}->{612630898} = "Burraga";
$areanames{en}->{612630899} = "Burraga";
$areanames{en}->{61263090} = "Greenethorpe";
$areanames{en}->{61263091} = "Greenethorpe";
$areanames{en}->{61263092} = "Greenethorpe";
$areanames{en}->{61263093} = "Grenfell";
$areanames{en}->{61263094} = "Grenfell";
$areanames{en}->{61263095} = "Grenfell";
$areanames{en}->{61263096} = "Gulgong";
$areanames{en}->{61263097} = "Gulgong";
$areanames{en}->{61263098} = "Gulgong";
$areanames{en}->{612630990} = "Rockley";
$areanames{en}->{612630991} = "Rockley";
$areanames{en}->{612630992} = "Rockley";
$areanames{en}->{612630993} = "Rockley";
$areanames{en}->{612630994} = "Burraga";
$areanames{en}->{612630995} = "Burraga";
$areanames{en}->{612630996} = "Rockley";
$areanames{en}->{612630997} = "Burraga";
$areanames{en}->{612630998} = "Burraga";
$areanames{en}->{612630999} = "Burraga";
$areanames{en}->{61263100} = "Hampton";
$areanames{en}->{61263101} = "Hampton";
$areanames{en}->{61263102} = "Hampton";
$areanames{en}->{61263103} = "Harden";
$areanames{en}->{61263104} = "Harden";
$areanames{en}->{61263105} = "Harden";
$areanames{en}->{61263106} = "Hill\ End";
$areanames{en}->{61263107} = "Hill\ End";
$areanames{en}->{61263108} = "Hill\ End";
$areanames{en}->{61263109} = "Orange";
$areanames{en}->{61263110} = "Orange";
$areanames{en}->{61263111} = "Orange";
$areanames{en}->{61263112} = "Orange";
$areanames{en}->{61263113} = "Kandos";
$areanames{en}->{61263114} = "Kandos";
$areanames{en}->{61263115} = "Kandos";
$areanames{en}->{61263116} = "Killongbutta";
$areanames{en}->{61263117} = "Killongbutta";
$areanames{en}->{61263118} = "Killongbutta";
$areanames{en}->{61263119} = "Yetholme";
$areanames{en}->{61263120} = "Koorawatha";
$areanames{en}->{61263121} = "Koorawatha";
$areanames{en}->{61263122} = "Koorawatha";
$areanames{en}->{61263123} = "Laheys\ Creek";
$areanames{en}->{61263124} = "Laheys\ Creek";
$areanames{en}->{61263125} = "Laheys\ Creek";
$areanames{en}->{61263126} = "Leadville";
$areanames{en}->{61263127} = "Leadville";
$areanames{en}->{61263128} = "Leadville";
$areanames{en}->{61263129} = "Canowindra";
$areanames{en}->{61263130} = "Limekilns";
$areanames{en}->{61263131} = "Limekilns";
$areanames{en}->{61263132} = "Limekilns";
$areanames{en}->{61263133} = "Lithgow";
$areanames{en}->{61263134} = "Lithgow";
$areanames{en}->{61263135} = "Lithgow";
$areanames{en}->{61263136} = "Lue";
$areanames{en}->{61263137} = "Lue";
$areanames{en}->{61263138} = "Lue";
$areanames{en}->{61263139} = "Caragabal";
$areanames{en}->{612631394} = "Canowindra";
$areanames{en}->{612631397} = "Canowindra";
$areanames{en}->{612631398} = "Canowindra";
$areanames{en}->{612631399} = "Canowindra";
$areanames{en}->{61263140} = "Lyndhurst";
$areanames{en}->{61263141} = "Lyndhurst";
$areanames{en}->{61263142} = "Lyndhurst";
$areanames{en}->{61263143} = "Maimuru";
$areanames{en}->{61263144} = "Maimuru";
$areanames{en}->{61263145} = "Maimuru";
$areanames{en}->{61263146} = "Manildra";
$areanames{en}->{61263147} = "Manildra";
$areanames{en}->{61263148} = "Manildra";
$areanames{en}->{61263149} = "Cowra";
$areanames{en}->{61263150} = "Meadow\ Flat";
$areanames{en}->{61263151} = "Meadow\ Flat";
$areanames{en}->{61263152} = "Meadow\ Flat";
$areanames{en}->{61263153} = "Merriganowry";
$areanames{en}->{61263154} = "Merriganowry";
$areanames{en}->{61263155} = "Merriganowry";
$areanames{en}->{61263156} = "Millthorpe";
$areanames{en}->{61263157} = "Millthorpe";
$areanames{en}->{61263158} = "Millthorpe";
$areanames{en}->{61263159} = "Gooloogong";
$areanames{en}->{612631594} = "Canowindra";
$areanames{en}->{612631597} = "Canowindra";
$areanames{en}->{612631598} = "Canowindra";
$areanames{en}->{612631599} = "Canowindra";
$areanames{en}->{61263160} = "Milvale";
$areanames{en}->{61263161} = "Milvale";
$areanames{en}->{61263162} = "Milvale";
$areanames{en}->{61263163} = "Molong";
$areanames{en}->{61263164} = "Molong";
$areanames{en}->{61263165} = "Molong";
$areanames{en}->{61263166} = "Monteagle";
$areanames{en}->{61263167} = "Monteagle";
$areanames{en}->{61263168} = "Monteagle";
$areanames{en}->{61263169} = "Greenethorpe";
$areanames{en}->{612631694} = "Canowindra";
$areanames{en}->{612631697} = "Canowindra";
$areanames{en}->{612631698} = "Canowindra";
$areanames{en}->{612631699} = "Canowindra";
$areanames{en}->{61263170} = "Mudgee";
$areanames{en}->{61263171} = "Mudgee";
$areanames{en}->{61263172} = "Mudgee";
$areanames{en}->{61263173} = "Murringo";
$areanames{en}->{61263174} = "Murringo";
$areanames{en}->{61263175} = "Murringo";
$areanames{en}->{61263176} = "Neville";
$areanames{en}->{61263177} = "Neville";
$areanames{en}->{61263178} = "Neville";
$areanames{en}->{61263179} = "Grenfell";
$areanames{en}->{612631794} = "Canowindra";
$areanames{en}->{612631797} = "Canowindra";
$areanames{en}->{612631798} = "Canowindra";
$areanames{en}->{612631799} = "Canowindra";
$areanames{en}->{61263180} = "Oberon";
$areanames{en}->{61263181} = "Oberon";
$areanames{en}->{61263182} = "Oberon";
$areanames{en}->{61263183} = "Ooma";
$areanames{en}->{61263184} = "Ooma";
$areanames{en}->{61263185} = "Ooma";
$areanames{en}->{61263186} = "Orange";
$areanames{en}->{61263187} = "Orange";
$areanames{en}->{61263188} = "Orange";
$areanames{en}->{61263189} = "Koorawatha";
$areanames{en}->{612631894} = "Canowindra";
$areanames{en}->{612631897} = "Canowindra";
$areanames{en}->{612631898} = "Canowindra";
$areanames{en}->{612631899} = "Canowindra";
$areanames{en}->{61263190} = "Portland";
$areanames{en}->{61263191} = "Portland";
$areanames{en}->{61263192} = "Portland";
$areanames{en}->{61263193} = "Quandialla";
$areanames{en}->{61263194} = "Quandialla";
$areanames{en}->{61263195} = "Quandialla";
$areanames{en}->{61263196} = "Reids\ Flat";
$areanames{en}->{61263197} = "Reids\ Flat";
$areanames{en}->{61263198} = "Reids\ Flat";
$areanames{en}->{61263199} = "Merriganowry";
$areanames{en}->{612631994} = "Canowindra";
$areanames{en}->{612631997} = "Canowindra";
$areanames{en}->{612631998} = "Canowindra";
$areanames{en}->{612631999} = "Canowindra";
$areanames{en}->{61263200} = "Ooma";
$areanames{en}->{61263201} = "Rockley";
$areanames{en}->{61263202} = "Rockley";
$areanames{en}->{61263203} = "Rockley";
$areanames{en}->{61263204} = "Running\ Stream";
$areanames{en}->{61263205} = "Running\ Stream";
$areanames{en}->{61263206} = "Running\ Stream";
$areanames{en}->{61263207} = "Twelve\ Mile";
$areanames{en}->{61263208} = "Twelve\ Mile";
$areanames{en}->{61263209} = "Twelve\ Mile";
$areanames{en}->{61263210} = "Tyagong";
$areanames{en}->{61263211} = "Tyagong";
$areanames{en}->{61263212} = "Tyagong";
$areanames{en}->{61263213} = "Windeyer";
$areanames{en}->{61263214} = "Windeyer";
$areanames{en}->{61263215} = "Windeyer";
$areanames{en}->{61263216} = "Wollar";
$areanames{en}->{61263217} = "Wollar";
$areanames{en}->{61263218} = "Wollar";
$areanames{en}->{61263219} = "Quandialla";
$areanames{en}->{61263220} = "Woodstock";
$areanames{en}->{61263221} = "Woodstock";
$areanames{en}->{61263222} = "Woodstock";
$areanames{en}->{61263223} = "Yetholme";
$areanames{en}->{61263224} = "Yetholme";
$areanames{en}->{61263225} = "Yetholme";
$areanames{en}->{61263226} = "Young";
$areanames{en}->{61263227} = "Young";
$areanames{en}->{61263228} = "Young";
$areanames{en}->{61263229} = "Reids\ Flat";
$areanames{en}->{6126323} = "Bathurst";
$areanames{en}->{61263240} = "Bathurst";
$areanames{en}->{61263241} = "Bathurst";
$areanames{en}->{61263242} = "Orange";
$areanames{en}->{61263243} = "Caragabal";
$areanames{en}->{61263244} = "Cowra";
$areanames{en}->{61263245} = "Bathurst";
$areanames{en}->{61263246} = "Bathurst";
$areanames{en}->{61263247} = "Gooloogong";
$areanames{en}->{61263248} = "Greenethorpe";
$areanames{en}->{61263249} = "Grenfell";
$areanames{en}->{61263250} = "Orange";
$areanames{en}->{61263251} = "Bathurst";
$areanames{en}->{61263252} = "Burraga";
$areanames{en}->{61263253} = "Gingkin";
$areanames{en}->{61263254} = "Hill\ End";
$areanames{en}->{61263255} = "Killongbutta";
$areanames{en}->{61263256} = "Limekilns";
$areanames{en}->{61263257} = "Oberon";
$areanames{en}->{61263258} = "Rockley";
$areanames{en}->{61263259} = "Yetholme";
$areanames{en}->{61263260} = "Canowindra";
$areanames{en}->{61263261} = "Caragabal";
$areanames{en}->{61263262} = "Cowra";
$areanames{en}->{61263263} = "Gooloogong";
$areanames{en}->{61263264} = "Greenethorpe";
$areanames{en}->{61263265} = "Grenfell";
$areanames{en}->{61263266} = "Koorawatha";
$areanames{en}->{61263267} = "Merriganowry";
$areanames{en}->{61263268} = "Ooma";
$areanames{en}->{61263269} = "Quandialla";
$areanames{en}->{61263270} = "Reids\ Flat";
$areanames{en}->{61263271} = "Tyagong";
$areanames{en}->{61263272} = "Woodstock";
$areanames{en}->{61263273} = "Hampton";
$areanames{en}->{61263274} = "Lithgow";
$areanames{en}->{61263275} = "Meadow\ Flat";
$areanames{en}->{61263276} = "Portland";
$areanames{en}->{61263277} = "Birriwa";
$areanames{en}->{61263278} = "Cassilis";
$areanames{en}->{61263279} = "Coolah";
$areanames{en}->{61263280} = "Killongbutta";
$areanames{en}->{61263281} = "Killongbutta";
$areanames{en}->{61263282} = "Oberon";
$areanames{en}->{61263283} = "Oberon";
$areanames{en}->{61263284} = "Yetholme";
$areanames{en}->{61263285} = "Yetholme";
$areanames{en}->{61263286} = "Cowra";
$areanames{en}->{61263287} = "Cowra";
$areanames{en}->{61263288} = "Bathurst";
$areanames{en}->{61263289} = "Bathurst";
$areanames{en}->{61263290} = "Limekilns";
$areanames{en}->{61263291} = "Limekilns";
$areanames{en}->{61263292} = "Limekilns";
$areanames{en}->{61263293} = "Killongbutta";
$areanames{en}->{61263294} = "Yetholme";
$areanames{en}->{61263295} = "Yetholme";
$areanames{en}->{61263296} = "Rockley";
$areanames{en}->{61263297} = "Rockley";
$areanames{en}->{61263298} = "Oberon";
$areanames{en}->{61263299} = "Burraga";
$areanames{en}->{612633} = "Bathurst";
$areanames{en}->{61263350} = "Hill\ End";
$areanames{en}->{61263351} = "Hill\ End";
$areanames{en}->{61263352} = "Limekilns";
$areanames{en}->{61263353} = "Limekilns";
$areanames{en}->{61263354} = "Hill\ End";
$areanames{en}->{61263355} = "Gingkin";
$areanames{en}->{61263356} = "Gingkin";
$areanames{en}->{61263357} = "Gingkin";
$areanames{en}->{61263358} = "Burraga";
$areanames{en}->{61263359} = "Gingkin";
$areanames{en}->{6126336} = "Oberon";
$areanames{en}->{61263370} = "Burraga";
$areanames{en}->{61263374} = "Killongbutta";
$areanames{en}->{61263375} = "Yetholme";
$areanames{en}->{61263377} = "Limekilns";
$areanames{en}->{61263378} = "Hill\ End";
$areanames{en}->{61263379} = "Rockley";
$areanames{en}->{61263380} = "Limekilns";
$areanames{en}->{61263387} = "Gingkin";
$areanames{en}->{61263388} = "Hill\ End";
$areanames{en}->{61263389} = "Killongbutta";
$areanames{en}->{61263390} = "Burraga";
$areanames{en}->{61263391} = "Oberon";
$areanames{en}->{61263392} = "Rockley";
$areanames{en}->{61263393} = "Yetholme";
$areanames{en}->{61263396} = "Oberon";
$areanames{en}->{61263400} = "Cowra";
$areanames{en}->{61263401} = "Cowra";
$areanames{en}->{61263402} = "Cowra";
$areanames{en}->{61263403} = "Canowindra";
$areanames{en}->{61263404} = "Gooloogong";
$areanames{en}->{61263405} = "Koorawatha";
$areanames{en}->{61263406} = "Merriganowry";
$areanames{en}->{61263407} = "Reids\ Flat";
$areanames{en}->{61263408} = "Woodstock";
$areanames{en}->{61263409} = "Cowra";
$areanames{en}->{6126341} = "Cowra";
$areanames{en}->{6126342} = "Cowra";
$areanames{en}->{6126343} = "Grenfell";
$areanames{en}->{61263436} = "Greenethorpe";
$areanames{en}->{61263438} = "Tyagong";
$areanames{en}->{6126344} = "Canowindra";
$areanames{en}->{61263448} = "Gooloogong";
$areanames{en}->{61263450} = "Woodstock";
$areanames{en}->{61263451} = "Woodstock";
$areanames{en}->{61263452} = "Reids\ Flat";
$areanames{en}->{61263453} = "Koorawatha";
$areanames{en}->{61263454} = "Koorawatha";
$areanames{en}->{61263455} = "Merriganowry";
$areanames{en}->{61263456} = "Merriganowry";
$areanames{en}->{61263457} = "Merriganowry";
$areanames{en}->{61263458} = "Merriganowry";
$areanames{en}->{61263459} = "Merriganowry";
$areanames{en}->{61263460} = "Hampton";
$areanames{en}->{61263461} = "Hampton";
$areanames{en}->{61263462} = "Lithgow";
$areanames{en}->{61263463} = "Lithgow";
$areanames{en}->{61263464} = "Birriwa";
$areanames{en}->{61263465} = "Birriwa";
$areanames{en}->{61263466} = "Mudgee";
$areanames{en}->{61263467} = "Mudgee";
$areanames{en}->{61263468} = "Cudal";
$areanames{en}->{61263469} = "Cudal";
$areanames{en}->{61263470} = "Grenfell";
$areanames{en}->{61263471} = "Quandialla";
$areanames{en}->{61263472} = "Quandialla";
$areanames{en}->{61263473} = "Quandialla";
$areanames{en}->{61263474} = "Quandialla";
$areanames{en}->{61263475} = "Caragabal";
$areanames{en}->{61263476} = "Caragabal";
$areanames{en}->{61263477} = "Caragabal";
$areanames{en}->{61263478} = "Ooma";
$areanames{en}->{61263479} = "Ooma";
$areanames{en}->{61263480} = "Dunedoo";
$areanames{en}->{61263481} = "Gulgong";
$areanames{en}->{61263482} = "Laheys\ Creek";
$areanames{en}->{61263483} = "Leadville";
$areanames{en}->{61263484} = "Lue";
$areanames{en}->{61263485} = "Mudgee";
$areanames{en}->{61263486} = "Twelve\ Mile";
$areanames{en}->{61263487} = "Windeyer";
$areanames{en}->{61263488} = "Wollar";
$areanames{en}->{61263489} = "Baldry";
$areanames{en}->{61263490} = "Cowra";
$areanames{en}->{61263491} = "Grenfell";
$areanames{en}->{61263492} = "Grenfell";
$areanames{en}->{61263493} = "Caragabal";
$areanames{en}->{61263494} = "Greenethorpe";
$areanames{en}->{61263495} = "Ooma";
$areanames{en}->{61263496} = "Quandialla";
$areanames{en}->{61263497} = "Tyagong";
$areanames{en}->{61263498} = "Cowra";
$areanames{en}->{61263499} = "Cowra";
$areanames{en}->{612635} = "Lithgow";
$areanames{en}->{61263504} = "Hampton";
$areanames{en}->{61263505} = "Meadow\ Flat";
$areanames{en}->{61263506} = "Portland";
$areanames{en}->{61263554} = "Portland";
$areanames{en}->{61263555} = "Portland";
$areanames{en}->{6126357} = "Kandos";
$areanames{en}->{61263571} = "Running\ Stream";
$areanames{en}->{61263572} = "Bylong";
$areanames{en}->{61263574} = "Glen\ Davis";
$areanames{en}->{6126358} = "Bathurst";
$areanames{en}->{61263586} = "Running\ Stream";
$areanames{en}->{61263587} = "Running\ Stream";
$areanames{en}->{61263588} = "Running\ Stream";
$areanames{en}->{61263589} = "Running\ Stream";
$areanames{en}->{61263590} = "Portland";
$areanames{en}->{61263591} = "Portland";
$areanames{en}->{61263592} = "Portland";
$areanames{en}->{61263593} = "Hampton";
$areanames{en}->{61263594} = "Hampton";
$areanames{en}->{61263595} = "Meadow\ Flat";
$areanames{en}->{61263596} = "Meadow\ Flat";
$areanames{en}->{61263597} = "Meadow\ Flat";
$areanames{en}->{61263598} = "Meadow\ Flat";
$areanames{en}->{61263599} = "Meadow\ Flat";
$areanames{en}->{612636} = "Orange";
$areanames{en}->{61263640} = "Cudal";
$areanames{en}->{61263641} = "Euchareena";
$areanames{en}->{61263642} = "Cudal";
$areanames{en}->{61263643} = "Cudal";
$areanames{en}->{61263644} = "Canowindra";
$areanames{en}->{61263645} = "Manildra";
$areanames{en}->{61263646} = "Manildra";
$areanames{en}->{61263647} = "Manildra";
$areanames{en}->{61263648} = "Euchareena";
$areanames{en}->{61263649} = "Manildra";
$areanames{en}->{6126366} = "Millthorpe";
$areanames{en}->{61263660} = "Euchareena";
$areanames{en}->{61263661} = "Molong";
$areanames{en}->{61263668} = "Molong";
$areanames{en}->{61263669} = "Molong";
$areanames{en}->{61263670} = "Millthorpe";
$areanames{en}->{61263671} = "Millthorpe";
$areanames{en}->{61263672} = "Millthorpe";
$areanames{en}->{61263673} = "Millthorpe";
$areanames{en}->{61263674} = "Lyndhurst";
$areanames{en}->{61263675} = "Lyndhurst";
$areanames{en}->{61263676} = "Lyndhurst";
$areanames{en}->{61263677} = "Cumnock";
$areanames{en}->{61263678} = "Cumnock";
$areanames{en}->{61263679} = "Baldry";
$areanames{en}->{6126368} = "Blayney";
$areanames{en}->{61263680} = "Neville";
$areanames{en}->{61263688} = "Neville";
$areanames{en}->{61263694} = "Molong";
$areanames{en}->{61263695} = "Molong";
$areanames{en}->{61263696} = "Molong";
$areanames{en}->{6126370} = "Mudgee";
$areanames{en}->{61263701} = "Twelve\ Mile";
$areanames{en}->{61263702} = "Wollar";
$areanames{en}->{61263703} = "Dunedoo";
$areanames{en}->{61263704} = "Windeyer";
$areanames{en}->{61263710} = "Wollar";
$areanames{en}->{61263711} = "Wollar";
$areanames{en}->{61263712} = "Wollar";
$areanames{en}->{61263713} = "Gulgong";
$areanames{en}->{61263714} = "Gulgong";
$areanames{en}->{61263715} = "Mudgee";
$areanames{en}->{61263716} = "Mudgee";
$areanames{en}->{61263717} = "Mudgee";
$areanames{en}->{61263718} = "Mudgee";
$areanames{en}->{61263719} = "Mudgee";
$areanames{en}->{6126372} = "Mudgee";
$areanames{en}->{61263730} = "Twelve\ Mile";
$areanames{en}->{61263731} = "Mudgee";
$areanames{en}->{61263732} = "Mudgee";
$areanames{en}->{61263733} = "Mudgee";
$areanames{en}->{61263734} = "Wollar";
$areanames{en}->{61263735} = "Wollar";
$areanames{en}->{61263736} = "Lue";
$areanames{en}->{61263737} = "Windeyer";
$areanames{en}->{61263738} = "Windeyer";
$areanames{en}->{61263739} = "Windeyer";
$areanames{en}->{61263740} = "Gulgong";
$areanames{en}->{61263741} = "Gulgong";
$areanames{en}->{61263742} = "Gulgong";
$areanames{en}->{61263743} = "Gulgong";
$areanames{en}->{61263744} = "Gulgong";
$areanames{en}->{61263745} = "Laheys\ Creek";
$areanames{en}->{61263746} = "Laheys\ Creek";
$areanames{en}->{61263747} = "Laheys\ Creek";
$areanames{en}->{61263748} = "Laheys\ Creek";
$areanames{en}->{61263749} = "Laheys\ Creek";
$areanames{en}->{6126375} = "Dunedoo";
$areanames{en}->{61263750} = "Leadville";
$areanames{en}->{61263758} = "Birriwa";
$areanames{en}->{61263759} = "Birriwa";
$areanames{en}->{61263760} = "Cassilis";
$areanames{en}->{61263761} = "Cassilis";
$areanames{en}->{61263762} = "Cassilis";
$areanames{en}->{61263763} = "Cassilis";
$areanames{en}->{61263764} = "Cassilis";
$areanames{en}->{61263765} = "Monteagle";
$areanames{en}->{61263766} = "Monteagle";
$areanames{en}->{61263767} = "Bathurst";
$areanames{en}->{61263768} = "Bathurst";
$areanames{en}->{61263769} = "Orange";
$areanames{en}->{6126377} = "Coolah";
$areanames{en}->{61263780} = "Lue";
$areanames{en}->{61263781} = "Mudgee";
$areanames{en}->{61263782} = "Mudgee";
$areanames{en}->{61263783} = "Birriwa";
$areanames{en}->{61263784} = "Cassilis";
$areanames{en}->{61263785} = "Coolah";
$areanames{en}->{61263786} = "Mudgee";
$areanames{en}->{61263787} = "Gulgong";
$areanames{en}->{61263788} = "Laheys\ Creek";
$areanames{en}->{61263789} = "Leadville";
$areanames{en}->{6126379} = "Kandos";
$areanames{en}->{61263797} = "Glen\ Davis";
$areanames{en}->{61263798} = "Bylong";
$areanames{en}->{61263799} = "Bylong";
$areanames{en}->{61263800} = "Murringo";
$areanames{en}->{61263801} = "Young";
$areanames{en}->{61263802} = "Boorowa";
$areanames{en}->{61263803} = "Bribbaree";
$areanames{en}->{61263804} = "Frogmore";
$areanames{en}->{61263805} = "Galong";
$areanames{en}->{61263806} = "Harden";
$areanames{en}->{61263807} = "Maimuru";
$areanames{en}->{61263808} = "Milvale";
$areanames{en}->{61263809} = "Monteagle";
$areanames{en}->{61263810} = "Tyagong";
$areanames{en}->{61263811} = "Maimuru";
$areanames{en}->{61263812} = "Galong";
$areanames{en}->{61263813} = "Young";
$areanames{en}->{61263814} = "Young";
$areanames{en}->{61263815} = "Young";
$areanames{en}->{61263816} = "Koorawatha";
$areanames{en}->{61263817} = "Merriganowry";
$areanames{en}->{61263818} = "Ooma";
$areanames{en}->{61263819} = "Quandialla";
$areanames{en}->{6126382} = "Young";
$areanames{en}->{61263830} = "Bribbaree";
$areanames{en}->{61263831} = "Bribbaree";
$areanames{en}->{61263832} = "Bribbaree";
$areanames{en}->{61263833} = "Maimuru";
$areanames{en}->{61263834} = "Maimuru";
$areanames{en}->{61263835} = "Monteagle";
$areanames{en}->{61263836} = "Monteagle";
$areanames{en}->{61263837} = "Monteagle";
$areanames{en}->{61263838} = "Monteagle";
$areanames{en}->{61263839} = "Monteagle";
$areanames{en}->{6126384} = "Young";
$areanames{en}->{61263845} = "Murringo";
$areanames{en}->{61263846} = "Murringo";
$areanames{en}->{61263847} = "Milvale";
$areanames{en}->{61263848} = "Milvale";
$areanames{en}->{6126385} = "Boorowa";
$areanames{en}->{61263856} = "Frogmore";
$areanames{en}->{61263857} = "Frogmore";
$areanames{en}->{61263858} = "Frogmore";
$areanames{en}->{61263859} = "Frogmore";
$areanames{en}->{6126386} = "Harden";
$areanames{en}->{61263867} = "Galong";
$areanames{en}->{61263868} = "Galong";
$areanames{en}->{61263870} = "Blayney";
$areanames{en}->{61263871} = "Cudal";
$areanames{en}->{61263872} = "Cumnock";
$areanames{en}->{61263873} = "Euchareena";
$areanames{en}->{61263874} = "Lyndhurst";
$areanames{en}->{61263875} = "Manildra";
$areanames{en}->{61263876} = "Millthorpe";
$areanames{en}->{61263877} = "Molong";
$areanames{en}->{61263878} = "Neville";
$areanames{en}->{61263879} = "Orange";
$areanames{en}->{61263880} = "Bylong";
$areanames{en}->{61263881} = "Glen\ Davis";
$areanames{en}->{61263882} = "Kandos";
$areanames{en}->{61263883} = "Running\ Stream";
$areanames{en}->{61263884} = "Boorowa";
$areanames{en}->{61263885} = "Bribbaree";
$areanames{en}->{61263886} = "Frogmore";
$areanames{en}->{61263887} = "Galong";
$areanames{en}->{61263888} = "Harden";
$areanames{en}->{61263889} = "Maimuru";
$areanames{en}->{61263890} = "Milvale";
$areanames{en}->{61263891} = "Monteagle";
$areanames{en}->{61263892} = "Murringo";
$areanames{en}->{61263893} = "Young";
$areanames{en}->{61263894} = "Reids\ Flat";
$areanames{en}->{61263895} = "Tyagong";
$areanames{en}->{61263896} = "Woodstock";
$areanames{en}->{61263897} = "Hampton";
$areanames{en}->{61263898} = "Lithgow";
$areanames{en}->{61263899} = "Meadow\ Flat";
$areanames{en}->{61263900} = "Lyndhurst";
$areanames{en}->{61263901} = "Neville";
$areanames{en}->{61263902} = "Neville";
$areanames{en}->{61263903} = "Young";
$areanames{en}->{61263904} = "Young";
$areanames{en}->{61263905} = "Harden";
$areanames{en}->{61263906} = "Harden";
$areanames{en}->{61263907} = "Cudal";
$areanames{en}->{61263908} = "Cudal";
$areanames{en}->{61263909} = "Cudal";
$areanames{en}->{61263910} = "Cumnock";
$areanames{en}->{61263911} = "Orange";
$areanames{en}->{61263912} = "Orange";
$areanames{en}->{61263913} = "Orange";
$areanames{en}->{61263914} = "Orange";
$areanames{en}->{61263915} = "Orange";
$areanames{en}->{61263916} = "Harden";
$areanames{en}->{61263917} = "Blayney";
$areanames{en}->{61263918} = "Lyndhurst";
$areanames{en}->{61263919} = "Cudal";
$areanames{en}->{61263920} = "Orange";
$areanames{en}->{61263921} = "Manildra";
$areanames{en}->{61263922} = "Millthorpe";
$areanames{en}->{61263923} = "Molong";
$areanames{en}->{61263924} = "Euchareena";
$areanames{en}->{61263925} = "Neville";
$areanames{en}->{61263926} = "Orange";
$areanames{en}->{61263927} = "Orange";
$areanames{en}->{61263928} = "Orange";
$areanames{en}->{61263929} = "Orange";
$areanames{en}->{6126393} = "Orange";
$areanames{en}->{61263940} = "Grenfell";
$areanames{en}->{61263941} = "Cumnock";
$areanames{en}->{61263942} = "Molong";
$areanames{en}->{61263943} = "Molong";
$areanames{en}->{61263944} = "Euchareena";
$areanames{en}->{61263945} = "Euchareena";
$areanames{en}->{61263946} = "Orange";
$areanames{en}->{61263947} = "Orange";
$areanames{en}->{61263948} = "Orange";
$areanames{en}->{61263949} = "Orange";
$areanames{en}->{61263950} = "Portland";
$areanames{en}->{61263951} = "Birriwa";
$areanames{en}->{61263952} = "Cassilis";
$areanames{en}->{61263953} = "Coolah";
$areanames{en}->{61263954} = "Dunedoo";
$areanames{en}->{61263955} = "Gulgong";
$areanames{en}->{61263956} = "Laheys\ Creek";
$areanames{en}->{61263957} = "Leadville";
$areanames{en}->{61263958} = "Lue";
$areanames{en}->{61263959} = "Mudgee";
$areanames{en}->{61263960} = "Twelve\ Mile";
$areanames{en}->{61263961} = "Windeyer";
$areanames{en}->{61263962} = "Wollar";
$areanames{en}->{61263963} = "Baldry";
$areanames{en}->{61263964} = "Blayney";
$areanames{en}->{61263965} = "Cudal";
$areanames{en}->{61263966} = "Cumnock";
$areanames{en}->{61263967} = "Euchareena";
$areanames{en}->{61263968} = "Lyndhurst";
$areanames{en}->{61263969} = "Manildra";
$areanames{en}->{61263970} = "Millthorpe";
$areanames{en}->{61263971} = "Molong";
$areanames{en}->{61263972} = "Neville";
$areanames{en}->{61263973} = "Orange";
$areanames{en}->{61263974} = "Bylong";
$areanames{en}->{61263975} = "Glen\ Davis";
$areanames{en}->{61263976} = "Kandos";
$areanames{en}->{61263977} = "Running\ Stream";
$areanames{en}->{61263978} = "Boorowa";
$areanames{en}->{61263979} = "Bribbaree";
$areanames{en}->{61263980} = "Frogmore";
$areanames{en}->{61263981} = "Galong";
$areanames{en}->{61263982} = "Harden";
$areanames{en}->{61263983} = "Maimuru";
$areanames{en}->{61263984} = "Milvale";
$areanames{en}->{61263985} = "Monteagle";
$areanames{en}->{61263986} = "Murringo";
$areanames{en}->{61263987} = "Young";
$areanames{en}->{61263988} = "Woodstock";
$areanames{en}->{61263989} = "Hampton";
$areanames{en}->{61263990} = "Lithgow";
$areanames{en}->{61263991} = "Meadow\ Flat";
$areanames{en}->{61263992} = "Portland";
$areanames{en}->{61263993} = "Birriwa";
$areanames{en}->{61263994} = "Cassilis";
$areanames{en}->{61263995} = "Coolah";
$areanames{en}->{61263996} = "Dunedoo";
$areanames{en}->{61263997} = "Gulgong";
$areanames{en}->{61263998} = "Laheys\ Creek";
$areanames{en}->{61263999} = "Cowra";
$areanames{en}->{61264000} = "Adaminaby";
$areanames{en}->{61264001} = "Adaminaby";
$areanames{en}->{61264002} = "Adaminaby";
$areanames{en}->{61264003} = "Ando";
$areanames{en}->{61264004} = "Ando";
$areanames{en}->{61264005} = "Ando";
$areanames{en}->{61264006} = "Bega";
$areanames{en}->{61264007} = "Bega";
$areanames{en}->{61264008} = "Bega";
$areanames{en}->{61264009} = "Bega";
$areanames{en}->{61264010} = "Bemboka";
$areanames{en}->{61264011} = "Bemboka";
$areanames{en}->{61264012} = "Bemboka";
$areanames{en}->{61264013} = "Bendoc";
$areanames{en}->{61264014} = "Bendoc";
$areanames{en}->{61264015} = "Bendoc";
$areanames{en}->{61264016} = "Berridale";
$areanames{en}->{61264017} = "Berridale";
$areanames{en}->{61264018} = "Berridale";
$areanames{en}->{61264019} = "Bemboka";
$areanames{en}->{61264020} = "Bobundara";
$areanames{en}->{61264021} = "Bobundara";
$areanames{en}->{61264022} = "Bobundara";
$areanames{en}->{61264023} = "Bombala";
$areanames{en}->{61264024} = "Bombala";
$areanames{en}->{61264025} = "Bombala";
$areanames{en}->{61264026} = "Bonang";
$areanames{en}->{61264027} = "Bonang";
$areanames{en}->{61264028} = "Bonang";
$areanames{en}->{61264029} = "Candelo";
$areanames{en}->{61264030} = "Bredbo";
$areanames{en}->{61264031} = "Bredbo";
$areanames{en}->{61264032} = "Bredbo";
$areanames{en}->{61264033} = "Cabramurra";
$areanames{en}->{61264034} = "Cabramurra";
$areanames{en}->{61264035} = "Cabramurra";
$areanames{en}->{61264036} = "Candelo";
$areanames{en}->{61264037} = "Candelo";
$areanames{en}->{61264038} = "Candelo";
$areanames{en}->{61264039} = "Cobargo";
$areanames{en}->{61264040} = "Cathcart";
$areanames{en}->{61264041} = "Cathcart";
$areanames{en}->{61264042} = "Cathcart";
$areanames{en}->{61264043} = "Cobargo";
$areanames{en}->{61264044} = "Cobargo";
$areanames{en}->{61264045} = "Cobargo";
$areanames{en}->{61264046} = "Cooma";
$areanames{en}->{61264047} = "Cooma";
$areanames{en}->{61264048} = "Cooma";
$areanames{en}->{61264049} = "Eden";
$areanames{en}->{61264050} = "Dalgety";
$areanames{en}->{61264051} = "Dalgety";
$areanames{en}->{61264052} = "Dalgety";
$areanames{en}->{61264053} = "Delegate";
$areanames{en}->{61264054} = "Delegate";
$areanames{en}->{61264055} = "Delegate";
$areanames{en}->{61264056} = "Eden";
$areanames{en}->{61264057} = "Eden";
$areanames{en}->{61264058} = "Eden";
$areanames{en}->{61264059} = "Merimbula";
$areanames{en}->{61264060} = "Eucumbene";
$areanames{en}->{61264061} = "Eucumbene";
$areanames{en}->{61264062} = "Eucumbene";
$areanames{en}->{61264063} = "Jindabyne\ South";
$areanames{en}->{61264064} = "Jindabyne\ South";
$areanames{en}->{61264065} = "Jindabyne\ South";
$areanames{en}->{61264066} = "Merimbula";
$areanames{en}->{61264067} = "Merimbula";
$areanames{en}->{61264068} = "Merimbula";
$areanames{en}->{61264069} = "Tathra";
$areanames{en}->{61264070} = "Nimmitabel";
$areanames{en}->{61264071} = "Nimmitabel";
$areanames{en}->{61264072} = "Nimmitabel";
$areanames{en}->{61264073} = "Numeralla";
$areanames{en}->{61264074} = "Numeralla";
$areanames{en}->{61264075} = "Numeralla";
$areanames{en}->{61264076} = "Shannons\ Flat";
$areanames{en}->{61264077} = "Shannons\ Flat";
$areanames{en}->{61264078} = "Shannons\ Flat";
$areanames{en}->{61264079} = "Wonboyn\ Lake";
$areanames{en}->{61264080} = "Tathra";
$areanames{en}->{61264081} = "Tathra";
$areanames{en}->{61264082} = "Tathra";
$areanames{en}->{61264083} = "Thredbo\ Village";
$areanames{en}->{61264084} = "Thredbo\ Village";
$areanames{en}->{61264085} = "Thredbo\ Village";
$areanames{en}->{61264086} = "Wonboyn\ Lake";
$areanames{en}->{61264087} = "Wonboyn\ Lake";
$areanames{en}->{61264088} = "Wonboyn\ Lake";
$areanames{en}->{61264089} = "Adaminaby";
$areanames{en}->{61264090} = "Bega";
$areanames{en}->{61264091} = "Bemboka";
$areanames{en}->{61264092} = "Candelo";
$areanames{en}->{61264093} = "Cobargo";
$areanames{en}->{61264094} = "Eden";
$areanames{en}->{61264095} = "Merimbula";
$areanames{en}->{61264096} = "Tathra";
$areanames{en}->{61264097} = "Wonboyn\ Lake";
$areanames{en}->{61264098} = "Delegate";
$areanames{en}->{61264099} = "Eucumbene";
$areanames{en}->{61264100} = "Jindabyne\ South";
$areanames{en}->{61264101} = "Nimmitabel";
$areanames{en}->{61264102} = "Numeralla";
$areanames{en}->{61264103} = "Shannons\ Flat";
$areanames{en}->{61264104} = "Thredbo\ Village";
$areanames{en}->{61264105} = "Bendoc";
$areanames{en}->{61264106} = "Berridale";
$areanames{en}->{61264107} = "Bobundara";
$areanames{en}->{61264108} = "Bombala";
$areanames{en}->{61264109} = "Bonang";
$areanames{en}->{61264110} = "Bredbo";
$areanames{en}->{61264111} = "Cabramurra";
$areanames{en}->{61264112} = "Cathcart";
$areanames{en}->{61264113} = "Cooma";
$areanames{en}->{61264114} = "Dalgety";
$areanames{en}->{61264115} = "Adaminaby";
$areanames{en}->{61264116} = "Ando";
$areanames{en}->{61264117} = "Ando";
$areanames{en}->{61264118} = "Bendoc";
$areanames{en}->{61264119} = "Berridale";
$areanames{en}->{61264120} = "Bobundara";
$areanames{en}->{61264121} = "Bombala";
$areanames{en}->{61264122} = "Bonang";
$areanames{en}->{61264123} = "Bredbo";
$areanames{en}->{61264124} = "Cabramurra";
$areanames{en}->{61264125} = "Cathcart";
$areanames{en}->{61264126} = "Cooma";
$areanames{en}->{61264127} = "Dalgety";
$areanames{en}->{61264128} = "Delegate";
$areanames{en}->{61264129} = "Eucumbene";
$areanames{en}->{61264130} = "Jindabyne\ South";
$areanames{en}->{61264131} = "Nimmitabel";
$areanames{en}->{61264132} = "Numeralla";
$areanames{en}->{61264133} = "Shannons\ Flat";
$areanames{en}->{61264134} = "Thredbo\ Village";
$areanames{en}->{61264135} = "Bega";
$areanames{en}->{61264136} = "Bemboka";
$areanames{en}->{61264137} = "Candelo";
$areanames{en}->{61264138} = "Cobargo";
$areanames{en}->{61264139} = "Eden";
$areanames{en}->{61264140} = "Merimbula";
$areanames{en}->{61264141} = "Tathra";
$areanames{en}->{61264142} = "Wonboyn\ Lake";
$areanames{en}->{61264143} = "Delegate";
$areanames{en}->{61264144} = "Eucumbene";
$areanames{en}->{61264145} = "Bendoc";
$areanames{en}->{61264146} = "Berridale";
$areanames{en}->{61264147} = "Bobundara";
$areanames{en}->{61264148} = "Bombala";
$areanames{en}->{61264149} = "Bonang";
$areanames{en}->{61264150} = "Jindabyne\ South";
$areanames{en}->{61264151} = "Nimmitabel";
$areanames{en}->{61264152} = "Numeralla";
$areanames{en}->{61264153} = "Shannons\ Flat";
$areanames{en}->{61264154} = "Thredbo\ Village";
$areanames{en}->{61264155} = "Adaminaby";
$areanames{en}->{61264156} = "Ando";
$areanames{en}->{61264157} = "Bredbo";
$areanames{en}->{61264158} = "Cabramurra";
$areanames{en}->{61264159} = "Cathcart";
$areanames{en}->{61264160} = "Cooma";
$areanames{en}->{61264161} = "Dalgety";
$areanames{en}->{61264162} = "Bega";
$areanames{en}->{61264163} = "Bemboka";
$areanames{en}->{61264164} = "Candelo";
$areanames{en}->{61264165} = "Cobargo";
$areanames{en}->{61264166} = "Eden";
$areanames{en}->{61264167} = "Merimbula";
$areanames{en}->{61264168} = "Tathra";
$areanames{en}->{61264169} = "Wonboyn\ Lake";
$areanames{en}->{61264170} = "Adaminaby";
$areanames{en}->{61264171} = "Ando";
$areanames{en}->{61264172} = "Bendoc";
$areanames{en}->{61264173} = "Berridale";
$areanames{en}->{61264174} = "Bobundara";
$areanames{en}->{61264175} = "Bombala";
$areanames{en}->{61264176} = "Bonang";
$areanames{en}->{61264177} = "Bredbo";
$areanames{en}->{61264178} = "Cabramurra";
$areanames{en}->{61264179} = "Cathcart";
$areanames{en}->{61264180} = "Cooma";
$areanames{en}->{61264181} = "Dalgety";
$areanames{en}->{61264182} = "Delegate";
$areanames{en}->{61264183} = "Eucumbene";
$areanames{en}->{61264184} = "Jindabyne\ South";
$areanames{en}->{61264185} = "Nimmitabel";
$areanames{en}->{61264186} = "Numeralla";
$areanames{en}->{61264187} = "Shannons\ Flat";
$areanames{en}->{61264188} = "Thredbo\ Village";
$areanames{en}->{61264189} = "Bega";
$areanames{en}->{61264190} = "Bemboka";
$areanames{en}->{61264191} = "Candelo";
$areanames{en}->{61264192} = "Cobargo";
$areanames{en}->{61264193} = "Eden";
$areanames{en}->{61264194} = "Merimbula";
$areanames{en}->{61264195} = "Tathra";
$areanames{en}->{61264196} = "Wonboyn\ Lake";
$areanames{en}->{61264197} = "Adaminaby";
$areanames{en}->{61264198} = "Ando";
$areanames{en}->{61264199} = "Bendoc";
$areanames{en}->{61264200} = "Berridale";
$areanames{en}->{61264201} = "Bobundara";
$areanames{en}->{61264202} = "Bombala";
$areanames{en}->{61264203} = "Bonang";
$areanames{en}->{61264204} = "Bredbo";
$areanames{en}->{61264205} = "Cabramurra";
$areanames{en}->{61264206} = "Cathcart";
$areanames{en}->{61264207} = "Cooma";
$areanames{en}->{61264208} = "Dalgety";
$areanames{en}->{61264209} = "Delegate";
$areanames{en}->{61264210} = "Eucumbene";
$areanames{en}->{61264211} = "Jindabyne\ South";
$areanames{en}->{61264212} = "Nimmitabel";
$areanames{en}->{61264213} = "Numeralla";
$areanames{en}->{61264214} = "Shannons\ Flat";
$areanames{en}->{61264215} = "Thredbo\ Village";
$areanames{en}->{61264216} = "Bega";
$areanames{en}->{61264217} = "Bemboka";
$areanames{en}->{61264218} = "Candelo";
$areanames{en}->{61264219} = "Cobargo";
$areanames{en}->{61264220} = "Eden";
$areanames{en}->{61264221} = "Merimbula";
$areanames{en}->{61264222} = "Tathra";
$areanames{en}->{61264223} = "Wonboyn\ Lake";
$areanames{en}->{61264224} = "Adaminaby";
$areanames{en}->{61264225} = "Ando";
$areanames{en}->{61264226} = "Bendoc";
$areanames{en}->{61264227} = "Berridale";
$areanames{en}->{61264228} = "Bobundara";
$areanames{en}->{61264229} = "Bombala";
$areanames{en}->{61264230} = "Bonang";
$areanames{en}->{61264231} = "Bredbo";
$areanames{en}->{61264232} = "Cabramurra";
$areanames{en}->{61264233} = "Cathcart";
$areanames{en}->{61264234} = "Cooma";
$areanames{en}->{61264235} = "Dalgety";
$areanames{en}->{61264236} = "Delegate";
$areanames{en}->{61264237} = "Eucumbene";
$areanames{en}->{61264238} = "Jindabyne\ South";
$areanames{en}->{61264239} = "Nimmitabel";
$areanames{en}->{61264240} = "Numeralla";
$areanames{en}->{61264241} = "Shannons\ Flat";
$areanames{en}->{61264242} = "Thredbo\ Village";
$areanames{en}->{61264243} = "Bega";
$areanames{en}->{61264244} = "Bemboka";
$areanames{en}->{61264245} = "Bega";
$areanames{en}->{61264246} = "Cobargo";
$areanames{en}->{61264247} = "Bega";
$areanames{en}->{61264248} = "Merimbula";
$areanames{en}->{61264249} = "Tathra";
$areanames{en}->{61264250} = "Bemboka";
$areanames{en}->{61264251} = "Candelo";
$areanames{en}->{61264252} = "Cobargo";
$areanames{en}->{61264253} = "Eden";
$areanames{en}->{61264254} = "Berridale";
$areanames{en}->{61264255} = "Merimbula";
$areanames{en}->{61264256} = "Tathra";
$areanames{en}->{61264257} = "Wonboyn\ Lake";
$areanames{en}->{61264258} = "Adaminaby";
$areanames{en}->{61264259} = "Ando";
$areanames{en}->{61264260} = "Bendoc";
$areanames{en}->{61264261} = "Cooma";
$areanames{en}->{61264262} = "Berridale";
$areanames{en}->{61264263} = "Bobundara";
$areanames{en}->{61264264} = "Bombala";
$areanames{en}->{61264265} = "Jindabyne\ South";
$areanames{en}->{61264266} = "Bonang";
$areanames{en}->{61264267} = "Bredbo";
$areanames{en}->{61264268} = "Cabramurra";
$areanames{en}->{61264269} = "Cathcart";
$areanames{en}->{61264270} = "Merimbula";
$areanames{en}->{61264271} = "Berridale";
$areanames{en}->{61264272} = "Cooma";
$areanames{en}->{61264273} = "Wonboyn\ Lake";
$areanames{en}->{61264274} = "Wonboyn\ Lake";
$areanames{en}->{61264275} = "Tathra";
$areanames{en}->{61264276} = "Tathra";
$areanames{en}->{61264277} = "Merimbula";
$areanames{en}->{61264278} = "Merimbula";
$areanames{en}->{61264279} = "Eden";
$areanames{en}->{61264280} = "Eden";
$areanames{en}->{61264281} = "Cobargo";
$areanames{en}->{61264282} = "Cobargo";
$areanames{en}->{61264283} = "Candelo";
$areanames{en}->{61264284} = "Candelo";
$areanames{en}->{61264285} = "Bega";
$areanames{en}->{61264286} = "Bega";
$areanames{en}->{61264287} = "Bemboka";
$areanames{en}->{61264288} = "Bemboka";
$areanames{en}->{61264289} = "Adaminaby";
$areanames{en}->{61264290} = "Adaminaby";
$areanames{en}->{61264291} = "Bobundara";
$areanames{en}->{61264292} = "Bobundara";
$areanames{en}->{61264293} = "Bombala";
$areanames{en}->{61264294} = "Bombala";
$areanames{en}->{61264295} = "Bredbo";
$areanames{en}->{61264296} = "Bredbo";
$areanames{en}->{61264297} = "Cooma";
$areanames{en}->{61264298} = "Cooma";
$areanames{en}->{61264299} = "Nimmitabel";
$areanames{en}->{61264300} = "Nimmitabel";
$areanames{en}->{61264301} = "Numeralla";
$areanames{en}->{61264302} = "Numeralla";
$areanames{en}->{61264303} = "Shannons\ Flat";
$areanames{en}->{61264304} = "Shannons\ Flat";
$areanames{en}->{61264305} = "Thredbo\ Village";
$areanames{en}->{61264306} = "Thredbo\ Village";
$areanames{en}->{61264307} = "Cooma";
$areanames{en}->{61264308} = "Berridale";
$areanames{en}->{61264309} = "Berridale";
$areanames{en}->{61264310} = "Ando";
$areanames{en}->{61264311} = "Ando";
$areanames{en}->{61264312} = "Cathcart";
$areanames{en}->{61264313} = "Cathcart";
$areanames{en}->{61264314} = "Delegate";
$areanames{en}->{61264315} = "Delegate";
$areanames{en}->{61264316} = "Cooma";
$areanames{en}->{61264317} = "Merimbula";
$areanames{en}->{61264318} = "Berridale";
$areanames{en}->{61264319} = "Cooma";
$areanames{en}->{61264320} = "Dalgety";
$areanames{en}->{61264321} = "Bredbo";
$areanames{en}->{61264322} = "Tathra";
$areanames{en}->{61264323} = "Cobargo";
$areanames{en}->{61264324} = "Bemboka";
$areanames{en}->{61264325} = "Candelo";
$areanames{en}->{61264326} = "Cabramurra";
$areanames{en}->{61264327} = "Merimbula";
$areanames{en}->{61264328} = "Cathcart";
$areanames{en}->{61264329} = "Delegate";
$areanames{en}->{61264330} = "Eucumbene";
$areanames{en}->{61264331} = "Thredbo\ Village";
$areanames{en}->{61264332} = "Jindabyne\ South";
$areanames{en}->{61264333} = "Bobundara";
$areanames{en}->{61264334} = "Numeralla";
$areanames{en}->{61264335} = "Bonang";
$areanames{en}->{61264336} = "Bega";
$areanames{en}->{61264337} = "Eucumbene";
$areanames{en}->{61264338} = "Wonboyn\ Lake";
$areanames{en}->{61264339} = "Jindabyne\ South";
$areanames{en}->{61264340} = "Nimmitabel";
$areanames{en}->{61264341} = "Shannons\ Flat";
$areanames{en}->{61264342} = "Bendoc";
$areanames{en}->{61264343} = "Delegate";
$areanames{en}->{61264344} = "Cooma";
$areanames{en}->{61264345} = "Nimmitabel";
$areanames{en}->{61264346} = "Eden";
$areanames{en}->{61264347} = "Bombala";
$areanames{en}->{61264348} = "Dalgety";
$areanames{en}->{61264349} = "Numeralla";
$areanames{en}->{61264350} = "Shannons\ Flat";
$areanames{en}->{61264351} = "Adaminaby";
$areanames{en}->{61264352} = "Berridale";
$areanames{en}->{61264353} = "Bredbo";
$areanames{en}->{61264354} = "Tathra";
$areanames{en}->{61264355} = "Cobargo";
$areanames{en}->{61264356} = "Bemboka";
$areanames{en}->{61264357} = "Candelo";
$areanames{en}->{61264358} = "Cabramurra";
$areanames{en}->{61264359} = "Thredbo\ Village";
$areanames{en}->{61264360} = "Adaminaby";
$areanames{en}->{61264361} = "Merimbula";
$areanames{en}->{61264362} = "Cathcart";
$areanames{en}->{61264363} = "Thredbo\ Village";
$areanames{en}->{61264364} = "Jindabyne\ South";
$areanames{en}->{61264365} = "Bobundara";
$areanames{en}->{61264366} = "Numeralla";
$areanames{en}->{61264367} = "Bonang";
$areanames{en}->{61264368} = "Bega";
$areanames{en}->{61264369} = "Ando";
$areanames{en}->{61264370} = "Bega";
$areanames{en}->{61264371} = "Eucumbene";
$areanames{en}->{61264372} = "Wonboyn\ Lake";
$areanames{en}->{61264373} = "Shannons\ Flat";
$areanames{en}->{61264374} = "Bendoc";
$areanames{en}->{61264375} = "Delegate";
$areanames{en}->{61264376} = "Ando";
$areanames{en}->{61264377} = "Nimmitabel";
$areanames{en}->{61264378} = "Eden";
$areanames{en}->{61264379} = "Bemboka";
$areanames{en}->{61264380} = "Bendoc";
$areanames{en}->{61264381} = "Bombala";
$areanames{en}->{61264382} = "Dalgety";
$areanames{en}->{61264383} = "Adaminaby";
$areanames{en}->{61264384} = "Bonang";
$areanames{en}->{61264385} = "Cooma";
$areanames{en}->{61264386} = "Berridale";
$areanames{en}->{61264387} = "Cathcart";
$areanames{en}->{61264388} = "Bendoc";
$areanames{en}->{61264389} = "Bobundara";
$areanames{en}->{61264390} = "Bombala";
$areanames{en}->{61264391} = "Eucumbene";
$areanames{en}->{61264392} = "Berridale";
$areanames{en}->{61264393} = "Delegate";
$areanames{en}->{61264394} = "Ando";
$areanames{en}->{61264395} = "Bredbo";
$areanames{en}->{61264396} = "Thredbo\ Village";
$areanames{en}->{61264397} = "Bonang";
$areanames{en}->{61264398} = "Bredbo";
$areanames{en}->{61264399} = "Cabramurra";
$areanames{en}->{61264400} = "Candelo";
$areanames{en}->{61264401} = "Cathcart";
$areanames{en}->{61264402} = "Cobargo";
$areanames{en}->{61264403} = "Nimmitabel";
$areanames{en}->{61264404} = "Cooma";
$areanames{en}->{61264405} = "Jindabyne\ South";
$areanames{en}->{61264406} = "Bombala";
$areanames{en}->{61264407} = "Dalgety";
$areanames{en}->{61264408} = "Dalgety";
$areanames{en}->{61264409} = "Delegate";
$areanames{en}->{61264410} = "Eden";
$areanames{en}->{61264411} = "Shannons\ Flat";
$areanames{en}->{61264412} = "Bobundara";
$areanames{en}->{61264413} = "Adaminaby";
$areanames{en}->{61264414} = "Cabramurra";
$areanames{en}->{61264415} = "Numeralla";
$areanames{en}->{61264416} = "Bega";
$areanames{en}->{61264417} = "Tathra";
$areanames{en}->{61264418} = "Cobargo";
$areanames{en}->{61264419} = "Eucumbene";
$areanames{en}->{61264420} = "Jindabyne\ South";
$areanames{en}->{61264421} = "Bemboka";
$areanames{en}->{61264422} = "Candelo";
$areanames{en}->{61264423} = "Wonboyn\ Lake";
$areanames{en}->{61264424} = "Merimbula";
$areanames{en}->{61264425} = "Eden";
$areanames{en}->{61264426} = "Merimbula";
$areanames{en}->{61264427} = "Nimmitabel";
$areanames{en}->{61264428} = "Numeralla";
$areanames{en}->{61264429} = "Shannons\ Flat";
$areanames{en}->{61264430} = "Tathra";
$areanames{en}->{61264431} = "Thredbo\ Village";
$areanames{en}->{61264432} = "Wonboyn\ Lake";
$areanames{en}->{61264433} = "Adaminaby";
$areanames{en}->{61264434} = "Ando";
$areanames{en}->{61264435} = "Bega";
$areanames{en}->{61264436} = "Bemboka";
$areanames{en}->{61264437} = "Bendoc";
$areanames{en}->{61264438} = "Berridale";
$areanames{en}->{61264439} = "Bobundara";
$areanames{en}->{6126444} = "Bega";
$areanames{en}->{61264450} = "Bega";
$areanames{en}->{61264451} = "Jindabyne\ South";
$areanames{en}->{61264452} = "Jindabyne\ South";
$areanames{en}->{61264453} = "Cooma";
$areanames{en}->{61264454} = "Cooma";
$areanames{en}->{61264455} = "Cooma";
$areanames{en}->{61264456} = "Bombala";
$areanames{en}->{61264457} = "Bonang";
$areanames{en}->{61264458} = "Merimbula";
$areanames{en}->{61264459} = "Merimbula";
$areanames{en}->{61264460} = "Bredbo";
$areanames{en}->{61264461} = "Cabramurra";
$areanames{en}->{61264462} = "Candelo";
$areanames{en}->{61264463} = "Cathcart";
$areanames{en}->{61264464} = "Cobargo";
$areanames{en}->{61264465} = "Cooma";
$areanames{en}->{61264466} = "Dalgety";
$areanames{en}->{61264467} = "Delegate";
$areanames{en}->{61264468} = "Eden";
$areanames{en}->{61264469} = "Cooma";
$areanames{en}->{61264470} = "Eucumbene";
$areanames{en}->{61264471} = "Jindabyne\ South";
$areanames{en}->{61264472} = "Merimbula";
$areanames{en}->{61264473} = "Nimmitabel";
$areanames{en}->{61264474} = "Numeralla";
$areanames{en}->{61264475} = "Shannons\ Flat";
$areanames{en}->{61264476} = "Tathra";
$areanames{en}->{61264477} = "Thredbo\ Village";
$areanames{en}->{61264478} = "Wonboyn\ Lake";
$areanames{en}->{61264479} = "Adaminaby";
$areanames{en}->{61264480} = "Berridale";
$areanames{en}->{61264481} = "Berridale";
$areanames{en}->{61264482} = "Eucumbene";
$areanames{en}->{61264483} = "Eucumbene";
$areanames{en}->{61264484} = "Bonang";
$areanames{en}->{61264485} = "Bonang";
$areanames{en}->{61264486} = "Cabramurra";
$areanames{en}->{61264487} = "Cabramurra";
$areanames{en}->{61264488} = "Berridale";
$areanames{en}->{61264489} = "Bega";
$areanames{en}->{61264490} = "Bendoc";
$areanames{en}->{61264491} = "Berridale";
$areanames{en}->{61264492} = "Bobundara";
$areanames{en}->{61264493} = "Bredbo";
$areanames{en}->{61264494} = "Cabramurra";
$areanames{en}->{61264495} = "Dalgety";
$areanames{en}->{61264496} = "Delegate";
$areanames{en}->{61264497} = "Nimmitabel";
$areanames{en}->{61264498} = "Numeralla";
$areanames{en}->{61264499} = "Thredbo\ Village";
$areanames{en}->{61264500} = "Jindabyne\ South";
$areanames{en}->{61264501} = "Cooma";
$areanames{en}->{61264502} = "Cooma";
$areanames{en}->{61264503} = "Cooma";
$areanames{en}->{61264504} = "Adaminaby";
$areanames{en}->{61264505} = "Berridale";
$areanames{en}->{61264506} = "Bobundara";
$areanames{en}->{61264507} = "Bredbo";
$areanames{en}->{61264508} = "Dalgety";
$areanames{en}->{61264509} = "Eucumbene";
$areanames{en}->{61264510} = "Berridale";
$areanames{en}->{61264511} = "Berridale";
$areanames{en}->{61264512} = "Berridale";
$areanames{en}->{61264513} = "Berridale";
$areanames{en}->{61264514} = "Berridale";
$areanames{en}->{61264515} = "Thredbo\ Village";
$areanames{en}->{61264516} = "Thredbo\ Village";
$areanames{en}->{61264517} = "Thredbo\ Village";
$areanames{en}->{61264518} = "Bombala";
$areanames{en}->{61264519} = "Bombala";
$areanames{en}->{6126452} = "Cooma";
$areanames{en}->{6126453} = "Cooma";
$areanames{en}->{61264533} = "Numeralla";
$areanames{en}->{61264535} = "Bobundara";
$areanames{en}->{61264536} = "Bobundara";
$areanames{en}->{61264540} = "Adaminaby";
$areanames{en}->{61264541} = "Adaminaby";
$areanames{en}->{61264542} = "Adaminaby";
$areanames{en}->{61264543} = "Bredbo";
$areanames{en}->{61264544} = "Bredbo";
$areanames{en}->{61264545} = "Shannons\ Flat";
$areanames{en}->{61264546} = "Nimmitabel";
$areanames{en}->{61264547} = "Adaminaby";
$areanames{en}->{61264548} = "Cabramurra";
$areanames{en}->{61264549} = "Cabramurra";
$areanames{en}->{6126455} = "Cooma";
$areanames{en}->{6126456} = "Berridale";
$areanames{en}->{61264565} = "Dalgety";
$areanames{en}->{61264566} = "Dalgety";
$areanames{en}->{61264568} = "Eucumbene";
$areanames{en}->{61264569} = "Eucumbene";
$areanames{en}->{6126457} = "Thredbo\ Village";
$areanames{en}->{61264571} = "Berridale";
$areanames{en}->{61264572} = "Berridale";
$areanames{en}->{61264578} = "Jindabyne\ South";
$areanames{en}->{61264579} = "Jindabyne\ South";
$areanames{en}->{61264580} = "Bonang";
$areanames{en}->{61264581} = "Bendoc";
$areanames{en}->{61264582} = "Cathcart";
$areanames{en}->{61264583} = "Bombala";
$areanames{en}->{61264584} = "Bombala";
$areanames{en}->{61264585} = "Bombala";
$areanames{en}->{61264586} = "Ando";
$areanames{en}->{61264587} = "Bombala";
$areanames{en}->{61264588} = "Delegate";
$areanames{en}->{61264589} = "Delegate";
$areanames{en}->{61264590} = "Bendoc";
$areanames{en}->{61264591} = "Nimmitabel";
$areanames{en}->{61264592} = "Numeralla";
$areanames{en}->{61264593} = "Shannons\ Flat";
$areanames{en}->{61264594} = "Thredbo\ Village";
$areanames{en}->{61264595} = "Bombala";
$areanames{en}->{61264596} = "Bonang";
$areanames{en}->{61264597} = "Cathcart";
$areanames{en}->{61264598} = "Delegate";
$areanames{en}->{61264599} = "Ando";
$areanames{en}->{61264600} = "Bendoc";
$areanames{en}->{61264601} = "Bendoc";
$areanames{en}->{61264602} = "Merimbula";
$areanames{en}->{61264603} = "Merimbula";
$areanames{en}->{61264604} = "Merimbula";
$areanames{en}->{61264605} = "Merimbula";
$areanames{en}->{61264606} = "Merimbula";
$areanames{en}->{61264607} = "Ando";
$areanames{en}->{61264608} = "Bega";
$areanames{en}->{61264609} = "Bemboka";
$areanames{en}->{61264610} = "Bendoc";
$areanames{en}->{61264611} = "Berridale";
$areanames{en}->{61264612} = "Bobundara";
$areanames{en}->{61264613} = "Bombala";
$areanames{en}->{61264614} = "Bonang";
$areanames{en}->{61264615} = "Bredbo";
$areanames{en}->{61264616} = "Cabramurra";
$areanames{en}->{61264617} = "Candelo";
$areanames{en}->{61264618} = "Cathcart";
$areanames{en}->{61264619} = "Cobargo";
$areanames{en}->{61264620} = "Cooma";
$areanames{en}->{61264621} = "Dalgety";
$areanames{en}->{61264622} = "Delegate";
$areanames{en}->{61264623} = "Eden";
$areanames{en}->{61264624} = "Eucumbene";
$areanames{en}->{61264625} = "Jindabyne\ South";
$areanames{en}->{61264626} = "Merimbula";
$areanames{en}->{61264627} = "Nimmitabel";
$areanames{en}->{61264628} = "Numeralla";
$areanames{en}->{61264629} = "Shannons\ Flat";
$areanames{en}->{61264630} = "Tathra";
$areanames{en}->{61264631} = "Thredbo\ Village";
$areanames{en}->{61264632} = "Wonboyn\ Lake";
$areanames{en}->{61264633} = "Adaminaby";
$areanames{en}->{61264634} = "Ando";
$areanames{en}->{61264635} = "Bega";
$areanames{en}->{61264636} = "Bemboka";
$areanames{en}->{61264637} = "Bendoc";
$areanames{en}->{61264638} = "Berridale";
$areanames{en}->{61264639} = "Bobundara";
$areanames{en}->{61264640} = "Bombala";
$areanames{en}->{61264641} = "Bonang";
$areanames{en}->{61264642} = "Bredbo";
$areanames{en}->{61264643} = "Cabramurra";
$areanames{en}->{61264644} = "Candelo";
$areanames{en}->{61264645} = "Cathcart";
$areanames{en}->{61264646} = "Cobargo";
$areanames{en}->{61264647} = "Cooma";
$areanames{en}->{61264648} = "Dalgety";
$areanames{en}->{61264649} = "Delegate";
$areanames{en}->{61264650} = "Eden";
$areanames{en}->{61264651} = "Eucumbene";
$areanames{en}->{61264652} = "Jindabyne\ South";
$areanames{en}->{61264653} = "Merimbula";
$areanames{en}->{61264654} = "Nimmitabel";
$areanames{en}->{61264655} = "Adaminaby";
$areanames{en}->{61264656} = "Ando";
$areanames{en}->{61264657} = "Bega";
$areanames{en}->{61264658} = "Bemboka";
$areanames{en}->{61264659} = "Bendoc";
$areanames{en}->{61264660} = "Berridale";
$areanames{en}->{61264661} = "Bobundara";
$areanames{en}->{61264662} = "Bombala";
$areanames{en}->{61264663} = "Bonang";
$areanames{en}->{61264664} = "Bredbo";
$areanames{en}->{61264665} = "Cabramurra";
$areanames{en}->{61264666} = "Candelo";
$areanames{en}->{61264667} = "Cathcart";
$areanames{en}->{61264668} = "Cobargo";
$areanames{en}->{61264669} = "Cooma";
$areanames{en}->{61264670} = "Dalgety";
$areanames{en}->{61264671} = "Delegate";
$areanames{en}->{61264672} = "Eden";
$areanames{en}->{61264673} = "Eucumbene";
$areanames{en}->{61264674} = "Jindabyne\ South";
$areanames{en}->{61264675} = "Merimbula";
$areanames{en}->{61264676} = "Nimmitabel";
$areanames{en}->{61264677} = "Numeralla";
$areanames{en}->{61264678} = "Shannons\ Flat";
$areanames{en}->{61264679} = "Tathra";
$areanames{en}->{61264680} = "Thredbo\ Village";
$areanames{en}->{61264681} = "Wonboyn\ Lake";
$areanames{en}->{61264682} = "Numeralla";
$areanames{en}->{61264683} = "Shannons\ Flat";
$areanames{en}->{61264684} = "Tathra";
$areanames{en}->{61264685} = "Thredbo\ Village";
$areanames{en}->{61264686} = "Wonboyn\ Lake";
$areanames{en}->{61264687} = "Adaminaby";
$areanames{en}->{61264688} = "Ando";
$areanames{en}->{61264689} = "Bega";
$areanames{en}->{61264690} = "Bemboka";
$areanames{en}->{61264691} = "Bendoc";
$areanames{en}->{61264692} = "Berridale";
$areanames{en}->{61264693} = "Bobundara";
$areanames{en}->{61264694} = "Bombala";
$areanames{en}->{61264695} = "Bonang";
$areanames{en}->{61264696} = "Bredbo";
$areanames{en}->{61264697} = "Cabramurra";
$areanames{en}->{61264698} = "Candelo";
$areanames{en}->{61264699} = "Cathcart";
$areanames{en}->{61264700} = "Cobargo";
$areanames{en}->{61264701} = "Cooma";
$areanames{en}->{61264702} = "Dalgety";
$areanames{en}->{61264703} = "Delegate";
$areanames{en}->{61264704} = "Eden";
$areanames{en}->{61264705} = "Eucumbene";
$areanames{en}->{61264706} = "Jindabyne\ South";
$areanames{en}->{61264707} = "Merimbula";
$areanames{en}->{61264708} = "Nimmitabel";
$areanames{en}->{61264709} = "Numeralla";
$areanames{en}->{61264710} = "Shannons\ Flat";
$areanames{en}->{61264711} = "Tathra";
$areanames{en}->{61264712} = "Thredbo\ Village";
$areanames{en}->{61264713} = "Wonboyn\ Lake";
$areanames{en}->{61264714} = "Adaminaby";
$areanames{en}->{61264715} = "Ando";
$areanames{en}->{61264716} = "Bega";
$areanames{en}->{61264717} = "Bemboka";
$areanames{en}->{61264718} = "Bendoc";
$areanames{en}->{61264719} = "Berridale";
$areanames{en}->{61264720} = "Bobundara";
$areanames{en}->{61264721} = "Bombala";
$areanames{en}->{61264722} = "Bonang";
$areanames{en}->{61264723} = "Bredbo";
$areanames{en}->{61264724} = "Cabramurra";
$areanames{en}->{61264725} = "Candelo";
$areanames{en}->{61264726} = "Cathcart";
$areanames{en}->{61264727} = "Cobargo";
$areanames{en}->{61264728} = "Cooma";
$areanames{en}->{61264729} = "Dalgety";
$areanames{en}->{61264730} = "Delegate";
$areanames{en}->{61264731} = "Eden";
$areanames{en}->{61264732} = "Eucumbene";
$areanames{en}->{61264733} = "Jindabyne\ South";
$areanames{en}->{61264734} = "Merimbula";
$areanames{en}->{61264735} = "Nimmitabel";
$areanames{en}->{61264736} = "Numeralla";
$areanames{en}->{61264737} = "Shannons\ Flat";
$areanames{en}->{61264738} = "Tathra";
$areanames{en}->{61264739} = "Thredbo\ Village";
$areanames{en}->{61264740} = "Wonboyn\ Lake";
$areanames{en}->{61264741} = "Adaminaby";
$areanames{en}->{61264742} = "Ando";
$areanames{en}->{61264743} = "Bega";
$areanames{en}->{61264744} = "Bemboka";
$areanames{en}->{61264745} = "Bendoc";
$areanames{en}->{61264746} = "Berridale";
$areanames{en}->{61264747} = "Bobundara";
$areanames{en}->{61264748} = "Bombala";
$areanames{en}->{61264749} = "Bonang";
$areanames{en}->{61264750} = "Bredbo";
$areanames{en}->{61264751} = "Cabramurra";
$areanames{en}->{61264752} = "Candelo";
$areanames{en}->{61264753} = "Cathcart";
$areanames{en}->{61264754} = "Cobargo";
$areanames{en}->{61264755} = "Cooma";
$areanames{en}->{61264756} = "Dalgety";
$areanames{en}->{61264757} = "Delegate";
$areanames{en}->{61264758} = "Eden";
$areanames{en}->{61264759} = "Eucumbene";
$areanames{en}->{61264760} = "Jindabyne\ South";
$areanames{en}->{61264761} = "Merimbula";
$areanames{en}->{61264762} = "Nimmitabel";
$areanames{en}->{61264763} = "Numeralla";
$areanames{en}->{61264764} = "Shannons\ Flat";
$areanames{en}->{61264765} = "Tathra";
$areanames{en}->{61264766} = "Thredbo\ Village";
$areanames{en}->{61264767} = "Wonboyn\ Lake";
$areanames{en}->{61264768} = "Bombala";
$areanames{en}->{61264890} = "Delegate";
$areanames{en}->{61264891} = "Eucumbene";
$areanames{en}->{61264892} = "Jindabyne\ South";
$areanames{en}->{61264893} = "Nimmitabel";
$areanames{en}->{61264894} = "Numeralla";
$areanames{en}->{61264895} = "Shannons\ Flat";
$areanames{en}->{61264896} = "Thredbo\ Village";
$areanames{en}->{61264897} = "Dalgety";
$areanames{en}->{61264898} = "Dalgety";
$areanames{en}->{61264899} = "Bega";
$areanames{en}->{61264900} = "Bendoc";
$areanames{en}->{61264901} = "Berridale";
$areanames{en}->{61264902} = "Bobundara";
$areanames{en}->{61264903} = "Bombala";
$areanames{en}->{61264904} = "Bonang";
$areanames{en}->{61264905} = "Bredbo";
$areanames{en}->{61264906} = "Cabramurra";
$areanames{en}->{61264907} = "Cathcart";
$areanames{en}->{61264908} = "Cooma";
$areanames{en}->{61264909} = "Dalgety";
$areanames{en}->{6126491} = "Bega";
$areanames{en}->{6126492} = "Bega";
$areanames{en}->{6126493} = "Cobargo";
$areanames{en}->{61264930} = "Bemboka";
$areanames{en}->{61264931} = "Candelo";
$areanames{en}->{61264932} = "Candelo";
$areanames{en}->{61264940} = "Tathra";
$areanames{en}->{61264941} = "Tathra";
$areanames{en}->{61264942} = "Candelo";
$areanames{en}->{61264943} = "Merimbula";
$areanames{en}->{61264944} = "Tathra";
$areanames{en}->{61264945} = "Tathra";
$areanames{en}->{61264946} = "Tathra";
$areanames{en}->{61264947} = "Bega";
$areanames{en}->{61264948} = "Bega";
$areanames{en}->{61264949} = "Merimbula";
$areanames{en}->{6126495} = "Merimbula";
$areanames{en}->{6126496} = "Eden";
$areanames{en}->{61264969} = "Wonboyn\ Lake";
$areanames{en}->{61264970} = "Bemboka";
$areanames{en}->{61264971} = "Candelo";
$areanames{en}->{61264972} = "Eden";
$areanames{en}->{61264973} = "Eden";
$areanames{en}->{61264974} = "Merimbula";
$areanames{en}->{61264975} = "Merimbula";
$areanames{en}->{61264976} = "Merimbula";
$areanames{en}->{61264977} = "Tathra";
$areanames{en}->{61264978} = "Cobargo";
$areanames{en}->{61264979} = "Cobargo";
$areanames{en}->{61264980} = "Bega";
$areanames{en}->{61264981} = "Bemboka";
$areanames{en}->{61264982} = "Candelo";
$areanames{en}->{61264983} = "Cobargo";
$areanames{en}->{61264984} = "Eden";
$areanames{en}->{61264985} = "Merimbula";
$areanames{en}->{61264986} = "Tathra";
$areanames{en}->{61264987} = "Wonboyn\ Lake";
$areanames{en}->{61264988} = "Adaminaby";
$areanames{en}->{61264989} = "Ando";
$areanames{en}->{61264990} = "Bega";
$areanames{en}->{61264991} = "Bega";
$areanames{en}->{61264992} = "Bega";
$areanames{en}->{61264993} = "Bemboka";
$areanames{en}->{61264994} = "Candelo";
$areanames{en}->{61264995} = "Cobargo";
$areanames{en}->{61264996} = "Eden";
$areanames{en}->{61264997} = "Wonboyn\ Lake";
$areanames{en}->{61264998} = "Merimbula";
$areanames{en}->{61264999} = "Tathra";
$areanames{en}->{61265000} = "Port\ Macquarie";
$areanames{en}->{61265001} = "Port\ Macquarie";
$areanames{en}->{61265002} = "Port\ Macquarie";
$areanames{en}->{61265003} = "Taree";
$areanames{en}->{61265004} = "Taree";
$areanames{en}->{61265005} = "Taree";
$areanames{en}->{61265006} = "Baerami";
$areanames{en}->{61265007} = "Baerami";
$areanames{en}->{61265008} = "Baerami";
$areanames{en}->{61265009} = "Port\ Macquarie";
$areanames{en}->{61265010} = "Bowraville";
$areanames{en}->{61265011} = "Bowraville";
$areanames{en}->{61265012} = "Bowraville";
$areanames{en}->{61265013} = "Broke";
$areanames{en}->{61265014} = "Broke";
$areanames{en}->{61265015} = "Broke";
$areanames{en}->{61265016} = "Bunnan";
$areanames{en}->{61265017} = "Bunnan";
$areanames{en}->{61265018} = "Bunnan";
$areanames{en}->{61265019} = "Bowraville";
$areanames{en}->{61265020} = "Bunnor";
$areanames{en}->{61265021} = "Bunnor";
$areanames{en}->{61265022} = "Bunnor";
$areanames{en}->{61265023} = "Byabarra";
$areanames{en}->{61265024} = "Byabarra";
$areanames{en}->{61265025} = "Byabarra";
$areanames{en}->{61265026} = "Castle\ Rock";
$areanames{en}->{61265027} = "Castle\ Rock";
$areanames{en}->{61265028} = "Castle\ Rock";
$areanames{en}->{61265029} = "Comara";
$areanames{en}->{61265030} = "Comara";
$areanames{en}->{61265031} = "Comara";
$areanames{en}->{61265032} = "Comara";
$areanames{en}->{61265033} = "Comboyne";
$areanames{en}->{61265034} = "Comboyne";
$areanames{en}->{61265035} = "Comboyne";
$areanames{en}->{61265036} = "Coopernook";
$areanames{en}->{61265037} = "Coopernook";
$areanames{en}->{61265038} = "Coopernook";
$areanames{en}->{61265039} = "Kempsey";
$areanames{en}->{61265040} = "Denman";
$areanames{en}->{61265041} = "Denman";
$areanames{en}->{61265042} = "Denman";
$areanames{en}->{61265043} = "Ellenborough";
$areanames{en}->{61265044} = "Ellenborough";
$areanames{en}->{61265045} = "Ellenborough";
$areanames{en}->{61265046} = "Ellerston";
$areanames{en}->{61265047} = "Ellerston";
$areanames{en}->{61265048} = "Ellerston";
$areanames{en}->{61265049} = "Macksville";
$areanames{en}->{61265050} = "Forster";
$areanames{en}->{61265051} = "Forster";
$areanames{en}->{61265052} = "Forster";
$areanames{en}->{61265053} = "Glendonbrook";
$areanames{en}->{61265054} = "Glendonbrook";
$areanames{en}->{61265055} = "Glendonbrook";
$areanames{en}->{61265056} = "Gloucester";
$areanames{en}->{61265057} = "Gloucester";
$areanames{en}->{61265058} = "Gloucester";
$areanames{en}->{61265059} = "Smithtown";
$areanames{en}->{61265060} = "Howes\ Valley";
$areanames{en}->{61265061} = "Howes\ Valley";
$areanames{en}->{61265062} = "Howes\ Valley";
$areanames{en}->{61265063} = "Hunter\ Springs";
$areanames{en}->{61265064} = "Hunter\ Springs";
$areanames{en}->{61265065} = "Hunter\ Springs";
$areanames{en}->{61265066} = "Idaville";
$areanames{en}->{61265067} = "Idaville";
$areanames{en}->{61265068} = "Idaville";
$areanames{en}->{61265069} = "Stuarts\ Point";
$areanames{en}->{61265070} = "Jerrys\ Plains";
$areanames{en}->{61265071} = "Jerrys\ Plains";
$areanames{en}->{61265072} = "Jerrys\ Plains";
$areanames{en}->{61265073} = "Kempsey";
$areanames{en}->{61265074} = "Kempsey";
$areanames{en}->{61265075} = "Kempsey";
$areanames{en}->{61265076} = "Krambach";
$areanames{en}->{61265077} = "Krambach";
$areanames{en}->{61265078} = "Krambach";
$areanames{en}->{61265079} = "Taylors\ Arm";
$areanames{en}->{61265080} = "Lord\ Howe\ Island";
$areanames{en}->{61265081} = "Lord\ Howe\ Island";
$areanames{en}->{61265082} = "Lord\ Howe\ Island";
$areanames{en}->{61265083} = "Macksville";
$areanames{en}->{61265084} = "Macksville";
$areanames{en}->{61265085} = "Macksville";
$areanames{en}->{61265086} = "Merriwa";
$areanames{en}->{61265087} = "Merriwa";
$areanames{en}->{61265088} = "Merriwa";
$areanames{en}->{61265089} = "Toorooka";
$areanames{en}->{61265090} = "Moonan\ Flat";
$areanames{en}->{61265091} = "Moonan\ Flat";
$areanames{en}->{61265092} = "Moonan\ Flat";
$areanames{en}->{61265093} = "Mount\ George";
$areanames{en}->{61265094} = "Mount\ George";
$areanames{en}->{61265095} = "Mount\ George";
$areanames{en}->{61265096} = "Mount\ Olive";
$areanames{en}->{61265097} = "Mount\ Olive";
$areanames{en}->{61265098} = "Mount\ Olive";
$areanames{en}->{61265099} = "Lord\ Howe\ Island";
$areanames{en}->{61265100} = "Murrurundi";
$areanames{en}->{61265101} = "Murrurundi";
$areanames{en}->{61265102} = "Murrurundi";
$areanames{en}->{61265103} = "Muswellbrook";
$areanames{en}->{61265104} = "Muswellbrook";
$areanames{en}->{61265105} = "Muswellbrook";
$areanames{en}->{61265106} = "Pacific\ Palms";
$areanames{en}->{61265107} = "Pacific\ Palms";
$areanames{en}->{61265108} = "Pacific\ Palms";
$areanames{en}->{61265109} = "Baerami";
$areanames{en}->{61265110} = "Putty";
$areanames{en}->{61265111} = "Putty";
$areanames{en}->{61265112} = "Putty";
$areanames{en}->{61265113} = "Ravensworth";
$areanames{en}->{61265114} = "Ravensworth";
$areanames{en}->{61265115} = "Ravensworth";
$areanames{en}->{61265116} = "Rawdon\ Vale";
$areanames{en}->{61265117} = "Rawdon\ Vale";
$areanames{en}->{61265118} = "Rawdon\ Vale";
$areanames{en}->{61265119} = "Bunnan";
$areanames{en}->{61265120} = "Rookhurst";
$areanames{en}->{61265121} = "Rookhurst";
$areanames{en}->{61265122} = "Rookhurst";
$areanames{en}->{61265123} = "Scone";
$areanames{en}->{61265124} = "Scone";
$areanames{en}->{61265125} = "Scone";
$areanames{en}->{61265126} = "Singleton";
$areanames{en}->{61265127} = "Singleton";
$areanames{en}->{61265128} = "Singleton";
$areanames{en}->{61265129} = "Castle\ Rock";
$areanames{en}->{61265130} = "Smithtown";
$areanames{en}->{61265131} = "Smithtown";
$areanames{en}->{61265132} = "Smithtown";
$areanames{en}->{61265133} = "Stuarts\ Point";
$areanames{en}->{61265134} = "Stuarts\ Point";
$areanames{en}->{61265135} = "Stuarts\ Point";
$areanames{en}->{61265136} = "Taylors\ Arm";
$areanames{en}->{61265137} = "Taylors\ Arm";
$areanames{en}->{61265138} = "Taylors\ Arm";
$areanames{en}->{61265139} = "Denman";
$areanames{en}->{61265140} = "Telegraph\ Point";
$areanames{en}->{61265141} = "Telegraph\ Point";
$areanames{en}->{61265142} = "Telegraph\ Point";
$areanames{en}->{61265143} = "Toorooka";
$areanames{en}->{61265144} = "Toorooka";
$areanames{en}->{61265145} = "Toorooka";
$areanames{en}->{61265146} = "Widden\ Valley";
$areanames{en}->{61265147} = "Widden\ Valley";
$areanames{en}->{61265148} = "Widden\ Valley";
$areanames{en}->{61265149} = "Ellerston";
$areanames{en}->{61265150} = "Taree";
$areanames{en}->{61265151} = "Taree";
$areanames{en}->{61265152} = "Taree";
$areanames{en}->{61265153} = "Bowraville";
$areanames{en}->{61265154} = "Comara";
$areanames{en}->{61265155} = "Kempsey";
$areanames{en}->{61265156} = "Macksville";
$areanames{en}->{61265157} = "Smithtown";
$areanames{en}->{61265158} = "Stuarts\ Point";
$areanames{en}->{61265159} = "Taylors\ Arm";
$areanames{en}->{61265160} = "Port\ Macquarie";
$areanames{en}->{61265161} = "Port\ Macquarie";
$areanames{en}->{61265162} = "Port\ Macquarie";
$areanames{en}->{61265163} = "Toorooka";
$areanames{en}->{61265164} = "Lord\ Howe\ Island";
$areanames{en}->{61265165} = "Hunter\ Springs";
$areanames{en}->{61265166} = "Idaville";
$areanames{en}->{61265167} = "Merriwa";
$areanames{en}->{61265168} = "Moonan\ Flat";
$areanames{en}->{61265169} = "Murrurundi";
$areanames{en}->{61265170} = "Muswellbrook";
$areanames{en}->{61265171} = "Scone";
$areanames{en}->{61265172} = "Widden\ Valley";
$areanames{en}->{61265173} = "Bunnan";
$areanames{en}->{61265174} = "Castle\ Rock";
$areanames{en}->{61265175} = "Denman";
$areanames{en}->{61265176} = "Ellerston";
$areanames{en}->{61265177} = "Baerami";
$areanames{en}->{61265178} = "Howes\ Valley";
$areanames{en}->{61265179} = "Jerrys\ Plains";
$areanames{en}->{61265180} = "Mount\ Olive";
$areanames{en}->{61265181} = "Putty";
$areanames{en}->{61265182} = "Ravensworth";
$areanames{en}->{61265183} = "Singleton";
$areanames{en}->{61265184} = "Broke";
$areanames{en}->{61265185} = "Glendonbrook";
$areanames{en}->{61265186} = "Pacific\ Palms";
$areanames{en}->{61265187} = "Rawdon\ Vale";
$areanames{en}->{61265188} = "Rookhurst";
$areanames{en}->{61265189} = "Taree";
$areanames{en}->{61265190} = "Krambach";
$areanames{en}->{61265191} = "Mount\ George";
$areanames{en}->{61265192} = "Comboyne";
$areanames{en}->{61265193} = "Coopernook";
$areanames{en}->{61265194} = "Forster";
$areanames{en}->{61265195} = "Gloucester";
$areanames{en}->{61265196} = "Byabarra";
$areanames{en}->{61265197} = "Ellenborough";
$areanames{en}->{61265198} = "Port\ Macquarie";
$areanames{en}->{61265199} = "Telegraph\ Point";
$areanames{en}->{61265200} = "Broke";
$areanames{en}->{61265201} = "Mount\ Olive";
$areanames{en}->{61265202} = "Ravensworth";
$areanames{en}->{61265203} = "Ravensworth";
$areanames{en}->{61265204} = "Ravensworth";
$areanames{en}->{61265205} = "Hunter\ Springs";
$areanames{en}->{61265206} = "Idaville";
$areanames{en}->{61265207} = "Merriwa";
$areanames{en}->{61265208} = "Moonan\ Flat";
$areanames{en}->{61265209} = "Murrurundi";
$areanames{en}->{61265210} = "Castle\ Rock";
$areanames{en}->{61265211} = "Castle\ Rock";
$areanames{en}->{61265212} = "Denman";
$areanames{en}->{61265213} = "Denman";
$areanames{en}->{61265214} = "Ellerston";
$areanames{en}->{61265215} = "Scone";
$areanames{en}->{61265216} = "Scone";
$areanames{en}->{61265217} = "Merriwa";
$areanames{en}->{61265218} = "Muswellbrook";
$areanames{en}->{61265219} = "Scone";
$areanames{en}->{61265220} = "Widden\ Valley";
$areanames{en}->{61265221} = "Broke";
$areanames{en}->{61265222} = "Glendonbrook";
$areanames{en}->{61265223} = "Howes\ Valley";
$areanames{en}->{61265224} = "Jerrys\ Plains";
$areanames{en}->{61265225} = "Mount\ Olive";
$areanames{en}->{61265226} = "Putty";
$areanames{en}->{61265227} = "Ravensworth";
$areanames{en}->{61265228} = "Singleton";
$areanames{en}->{61265229} = "Comboyne";
$areanames{en}->{61265230} = "Coopernook";
$areanames{en}->{61265231} = "Forster";
$areanames{en}->{61265232} = "Gloucester";
$areanames{en}->{61265233} = "Krambach";
$areanames{en}->{61265234} = "Mount\ George";
$areanames{en}->{61265235} = "Pacific\ Palms";
$areanames{en}->{61265236} = "Rawdon\ Vale";
$areanames{en}->{61265237} = "Rookhurst";
$areanames{en}->{61265238} = "Taree";
$areanames{en}->{61265239} = "Byabarra";
$areanames{en}->{61265240} = "Ellenborough";
$areanames{en}->{61265241} = "Port\ Macquarie";
$areanames{en}->{61265242} = "Telegraph\ Point";
$areanames{en}->{61265243} = "Bowraville";
$areanames{en}->{61265244} = "Comara";
$areanames{en}->{61265245} = "Kempsey";
$areanames{en}->{61265246} = "Macksville";
$areanames{en}->{61265247} = "Smithtown";
$areanames{en}->{61265248} = "Stuarts\ Point";
$areanames{en}->{61265249} = "Taylors\ Arm";
$areanames{en}->{61265250} = "Toorooka";
$areanames{en}->{61265251} = "Lord\ Howe\ Island";
$areanames{en}->{61265252} = "Hunter\ Springs";
$areanames{en}->{61265253} = "Idaville";
$areanames{en}->{61265254} = "Merriwa";
$areanames{en}->{61265255} = "Moonan\ Flat";
$areanames{en}->{61265256} = "Murrurundi";
$areanames{en}->{61265257} = "Baerami";
$areanames{en}->{61265258} = "Bunnan";
$areanames{en}->{61265259} = "Castle\ Rock";
$areanames{en}->{61265260} = "Denman";
$areanames{en}->{61265261} = "Ellerston";
$areanames{en}->{61265262} = "Muswellbrook";
$areanames{en}->{61265263} = "Scone";
$areanames{en}->{61265264} = "Widden\ Valley";
$areanames{en}->{61265265} = "Howes\ Valley";
$areanames{en}->{61265266} = "Jerrys\ Plains";
$areanames{en}->{61265267} = "Broke";
$areanames{en}->{61265268} = "Glendonbrook";
$areanames{en}->{61265269} = "Denman";
$areanames{en}->{61265270} = "Mount\ Olive";
$areanames{en}->{61265271} = "Putty";
$areanames{en}->{61265272} = "Ravensworth";
$areanames{en}->{61265273} = "Singleton";
$areanames{en}->{61265274} = "Pacific\ Palms";
$areanames{en}->{61265275} = "Rawdon\ Vale";
$areanames{en}->{61265276} = "Rookhurst";
$areanames{en}->{61265277} = "Taree";
$areanames{en}->{61265278} = "Comboyne";
$areanames{en}->{61265279} = "Coopernook";
$areanames{en}->{61265280} = "Forster";
$areanames{en}->{61265281} = "Gloucester";
$areanames{en}->{61265282} = "Krambach";
$areanames{en}->{61265283} = "Mount\ George";
$areanames{en}->{61265284} = "Byabarra";
$areanames{en}->{61265285} = "Ellenborough";
$areanames{en}->{61265286} = "Port\ Macquarie";
$areanames{en}->{61265287} = "Telegraph\ Point";
$areanames{en}->{61265288} = "Bowraville";
$areanames{en}->{61265289} = "Comara";
$areanames{en}->{61265290} = "Kempsey";
$areanames{en}->{61265291} = "Macksville";
$areanames{en}->{61265292} = "Smithtown";
$areanames{en}->{61265293} = "Stuarts\ Point";
$areanames{en}->{61265294} = "Taylors\ Arm";
$areanames{en}->{61265295} = "Toorooka";
$areanames{en}->{61265296} = "Lord\ Howe\ Island";
$areanames{en}->{61265297} = "Baerami";
$areanames{en}->{61265298} = "Bunnan";
$areanames{en}->{61265299} = "Castle\ Rock";
$areanames{en}->{61265300} = "Denman";
$areanames{en}->{61265301} = "Ellerston";
$areanames{en}->{61265302} = "Hunter\ Springs";
$areanames{en}->{61265303} = "Idaville";
$areanames{en}->{61265304} = "Merriwa";
$areanames{en}->{61265305} = "Moonan\ Flat";
$areanames{en}->{61265306} = "Murrurundi";
$areanames{en}->{61265307} = "Muswellbrook";
$areanames{en}->{61265308} = "Scone";
$areanames{en}->{61265309} = "Widden\ Valley";
$areanames{en}->{61265310} = "Broke";
$areanames{en}->{61265311} = "Glendonbrook";
$areanames{en}->{61265312} = "Howes\ Valley";
$areanames{en}->{61265313} = "Jerrys\ Plains";
$areanames{en}->{61265314} = "Mount\ Olive";
$areanames{en}->{61265315} = "Putty";
$areanames{en}->{61265316} = "Ravensworth";
$areanames{en}->{61265317} = "Singleton";
$areanames{en}->{61265318} = "Comboyne";
$areanames{en}->{61265319} = "Coopernook";
$areanames{en}->{61265320} = "Forster";
$areanames{en}->{61265321} = "Gloucester";
$areanames{en}->{61265322} = "Krambach";
$areanames{en}->{61265323} = "Mount\ George";
$areanames{en}->{61265324} = "Pacific\ Palms";
$areanames{en}->{61265325} = "Merriwa";
$areanames{en}->{61265326} = "Rawdon\ Vale";
$areanames{en}->{61265327} = "Rookhurst";
$areanames{en}->{61265328} = "Taree";
$areanames{en}->{61265329} = "Byabarra";
$areanames{en}->{61265330} = "Ellenborough";
$areanames{en}->{61265331} = "Port\ Macquarie";
$areanames{en}->{61265332} = "Telegraph\ Point";
$areanames{en}->{61265333} = "Bowraville";
$areanames{en}->{61265334} = "Comara";
$areanames{en}->{61265335} = "Kempsey";
$areanames{en}->{61265336} = "Macksville";
$areanames{en}->{61265337} = "Smithtown";
$areanames{en}->{61265338} = "Stuarts\ Point";
$areanames{en}->{61265339} = "Taylors\ Arm";
$areanames{en}->{61265340} = "Toorooka";
$areanames{en}->{61265341} = "Lord\ Howe\ Island";
$areanames{en}->{61265342} = "Baerami";
$areanames{en}->{61265343} = "Bunnan";
$areanames{en}->{61265344} = "Castle\ Rock";
$areanames{en}->{61265345} = "Denman";
$areanames{en}->{61265346} = "Ellerston";
$areanames{en}->{61265347} = "Hunter\ Springs";
$areanames{en}->{61265348} = "Idaville";
$areanames{en}->{61265349} = "Merriwa";
$areanames{en}->{61265350} = "Moonan\ Flat";
$areanames{en}->{61265351} = "Murrurundi";
$areanames{en}->{61265352} = "Muswellbrook";
$areanames{en}->{61265353} = "Scone";
$areanames{en}->{61265354} = "Widden\ Valley";
$areanames{en}->{61265355} = "Broke";
$areanames{en}->{61265356} = "Glendonbrook";
$areanames{en}->{61265357} = "Howes\ Valley";
$areanames{en}->{61265358} = "Jerrys\ Plains";
$areanames{en}->{61265359} = "Mount\ Olive";
$areanames{en}->{61265360} = "Putty";
$areanames{en}->{61265361} = "Ravensworth";
$areanames{en}->{61265362} = "Singleton";
$areanames{en}->{61265363} = "Comboyne";
$areanames{en}->{61265364} = "Coopernook";
$areanames{en}->{61265365} = "Forster";
$areanames{en}->{61265366} = "Gloucester";
$areanames{en}->{61265367} = "Krambach";
$areanames{en}->{61265368} = "Mount\ George";
$areanames{en}->{61265369} = "Pacific\ Palms";
$areanames{en}->{61265370} = "Forster";
$areanames{en}->{61265371} = "Gloucester";
$areanames{en}->{61265372} = "Gloucester";
$areanames{en}->{61265373} = "Gloucester";
$areanames{en}->{61265374} = "Mount\ George";
$areanames{en}->{61265375} = "Mount\ George";
$areanames{en}->{61265376} = "Pacific\ Palms";
$areanames{en}->{61265377} = "Rawdon\ Vale";
$areanames{en}->{61265378} = "Rookhurst";
$areanames{en}->{61265379} = "Taree";
$areanames{en}->{61265380} = "Comboyne";
$areanames{en}->{61265381} = "Coopernook";
$areanames{en}->{61265382} = "Coopernook";
$areanames{en}->{61265383} = "Coopernook";
$areanames{en}->{61265384} = "Gloucester";
$areanames{en}->{61265385} = "Gloucester";
$areanames{en}->{61265386} = "Krambach";
$areanames{en}->{61265387} = "Krambach";
$areanames{en}->{61265388} = "Pacific\ Palms";
$areanames{en}->{61265389} = "Rawdon\ Vale";
$areanames{en}->{6126539} = "Taree";
$areanames{en}->{61265396} = "Forster";
$areanames{en}->{61265397} = "Forster";
$areanames{en}->{61265398} = "Forster";
$areanames{en}->{61265399} = "Forster";
$areanames{en}->{61265400} = "Muswellbrook";
$areanames{en}->{61265401} = "Scone";
$areanames{en}->{61265402} = "Scone";
$areanames{en}->{61265403} = "Bunnan";
$areanames{en}->{61265404} = "Hunter\ Springs";
$areanames{en}->{61265405} = "Moonan\ Flat";
$areanames{en}->{61265406} = "Murrurundi";
$areanames{en}->{61265407} = "Ellerston";
$areanames{en}->{61265408} = "Muswellbrook";
$areanames{en}->{61265409} = "Muswellbrook";
$areanames{en}->{6126541} = "Muswellbrook";
$areanames{en}->{6126542} = "Muswellbrook";
$areanames{en}->{6126543} = "Muswellbrook";
$areanames{en}->{61265440} = "Scone";
$areanames{en}->{61265441} = "Scone";
$areanames{en}->{61265442} = "Scone";
$areanames{en}->{61265443} = "Scone";
$areanames{en}->{61265444} = "Scone";
$areanames{en}->{61265445} = "Muswellbrook";
$areanames{en}->{61265446} = "Muswellbrook";
$areanames{en}->{61265447} = "Muswellbrook";
$areanames{en}->{61265448} = "Muswellbrook";
$areanames{en}->{61265449} = "Muswellbrook";
$areanames{en}->{6126545} = "Scone";
$areanames{en}->{61265454} = "Bunnan";
$areanames{en}->{61265455} = "Bunnan";
$areanames{en}->{61265456} = "Bunnan";
$areanames{en}->{61265457} = "Bunnan";
$areanames{en}->{61265460} = "Murrurundi";
$areanames{en}->{61265461} = "Moonan\ Flat";
$areanames{en}->{61265462} = "Moonan\ Flat";
$areanames{en}->{61265463} = "Moonan\ Flat";
$areanames{en}->{61265464} = "Hunter\ Springs";
$areanames{en}->{61265465} = "Ellerston";
$areanames{en}->{61265466} = "Murrurundi";
$areanames{en}->{61265467} = "Murrurundi";
$areanames{en}->{61265468} = "Murrurundi";
$areanames{en}->{61265469} = "Murrurundi";
$areanames{en}->{61265470} = "Widden\ Valley";
$areanames{en}->{61265471} = "Denman";
$areanames{en}->{61265472} = "Denman";
$areanames{en}->{61265473} = "Denman";
$areanames{en}->{61265474} = "Denman";
$areanames{en}->{61265475} = "Baerami";
$areanames{en}->{61265476} = "Baerami";
$areanames{en}->{61265477} = "Baerami";
$areanames{en}->{61265478} = "Castle\ Rock";
$areanames{en}->{61265479} = "Castle\ Rock";
$areanames{en}->{6126548} = "Merriwa";
$areanames{en}->{61265487} = "Idaville";
$areanames{en}->{61265488} = "Idaville";
$areanames{en}->{61265489} = "Idaville";
$areanames{en}->{61265490} = "Muswellbrook";
$areanames{en}->{61265491} = "Moonan\ Flat";
$areanames{en}->{61265492} = "Muswellbrook";
$areanames{en}->{61265493} = "Muswellbrook";
$areanames{en}->{61265494} = "Baerami";
$areanames{en}->{61265495} = "Castle\ Rock";
$areanames{en}->{61265496} = "Denman";
$areanames{en}->{61265497} = "Idaville";
$areanames{en}->{61265498} = "Merriwa";
$areanames{en}->{61265499} = "Widden\ Valley";
$areanames{en}->{61265500} = "Taree";
$areanames{en}->{61265501} = "Taree";
$areanames{en}->{61265502} = "Krambach";
$areanames{en}->{61265503} = "Comboyne";
$areanames{en}->{61265504} = "Comboyne";
$areanames{en}->{61265505} = "Comboyne";
$areanames{en}->{61265506} = "Mount\ George";
$areanames{en}->{61265507} = "Mount\ George";
$areanames{en}->{61265508} = "Mount\ George";
$areanames{en}->{61265509} = "Pacific\ Palms";
$areanames{en}->{6126551} = "Taree";
$areanames{en}->{6126552} = "Taree";
$areanames{en}->{61265529} = "Pacific\ Palms";
$areanames{en}->{6126553} = "Taree";
$areanames{en}->{6126554} = "Forster";
$areanames{en}->{61265540} = "Pacific\ Palms";
$areanames{en}->{61265544} = "Pacific\ Palms";
$areanames{en}->{6126555} = "Forster";
$areanames{en}->{6126556} = "Coopernook";
$areanames{en}->{6126557} = "Taree";
$areanames{en}->{61265572} = "Forster";
$areanames{en}->{61265575} = "Forster";
$areanames{en}->{61265576} = "Forster";
$areanames{en}->{6126558} = "Gloucester";
$areanames{en}->{61265583} = "Rawdon\ Vale";
$areanames{en}->{61265585} = "Rawdon\ Vale";
$areanames{en}->{61265586} = "Rookhurst";
$areanames{en}->{61265587} = "Rookhurst";
$areanames{en}->{6126559} = "Coopernook";
$areanames{en}->{61265591} = "Krambach";
$areanames{en}->{61265592} = "Taree";
$areanames{en}->{61265593} = "Taree";
$areanames{en}->{61265600} = "Taylors\ Arm";
$areanames{en}->{61265601} = "Kempsey";
$areanames{en}->{61265602} = "Kempsey";
$areanames{en}->{61265603} = "Comara";
$areanames{en}->{61265604} = "Smithtown";
$areanames{en}->{61265605} = "Toorooka";
$areanames{en}->{61265606} = "Lord\ Howe\ Island";
$areanames{en}->{61265607} = "Macksville";
$areanames{en}->{61265608} = "Stuarts\ Point";
$areanames{en}->{61265609} = "Bowraville";
$areanames{en}->{6126561} = "Kempsey";
$areanames{en}->{6126562} = "Kempsey";
$areanames{en}->{6126563} = "Kempsey";
$areanames{en}->{61265632} = "Lord\ Howe\ Island";
$areanames{en}->{6126564} = "Bowraville";
$areanames{en}->{61265640} = "Taylors\ Arm";
$areanames{en}->{61265641} = "Rawdon\ Vale";
$areanames{en}->{61265642} = "Taylors\ Arm";
$areanames{en}->{6126565} = "Smithtown";
$areanames{en}->{6126566} = "Kempsey";
$areanames{en}->{61265665} = "Smithtown";
$areanames{en}->{61265666} = "Smithtown";
$areanames{en}->{61265667} = "Smithtown";
$areanames{en}->{61265670} = "Smithtown";
$areanames{en}->{61265671} = "Toorooka";
$areanames{en}->{61265672} = "Toorooka";
$areanames{en}->{61265673} = "Toorooka";
$areanames{en}->{61265674} = "Smithtown";
$areanames{en}->{61265675} = "Smithtown";
$areanames{en}->{61265676} = "Smithtown";
$areanames{en}->{61265677} = "Smithtown";
$areanames{en}->{61265678} = "Comara";
$areanames{en}->{61265679} = "Toorooka";
$areanames{en}->{6126568} = "Macksville";
$areanames{en}->{6126569} = "Macksville";
$areanames{en}->{61265690} = "Stuarts\ Point";
$areanames{en}->{61265691} = "Stuarts\ Point";
$areanames{en}->{61265699} = "Stuarts\ Point";
$areanames{en}->{612657} = "Singleton";
$areanames{en}->{61265700} = "Ravensworth";
$areanames{en}->{61265704} = "Broke";
$areanames{en}->{61265705} = "Mount\ Olive";
$areanames{en}->{61265706} = "Glendonbrook";
$areanames{en}->{61265707} = "Howes\ Valley";
$areanames{en}->{61265708} = "Jerrys\ Plains";
$areanames{en}->{61265709} = "Ravensworth";
$areanames{en}->{6126576} = "Jerrys\ Plains";
$areanames{en}->{61265760} = "Ravensworth";
$areanames{en}->{61265761} = "Ravensworth";
$areanames{en}->{61265762} = "Ravensworth";
$areanames{en}->{61265763} = "Ravensworth";
$areanames{en}->{61265770} = "Mount\ Olive";
$areanames{en}->{61265771} = "Mount\ Olive";
$areanames{en}->{61265772} = "Mount\ Olive";
$areanames{en}->{61265773} = "Mount\ Olive";
$areanames{en}->{61265774} = "Mount\ Olive";
$areanames{en}->{61265775} = "Glendonbrook";
$areanames{en}->{61265776} = "Glendonbrook";
$areanames{en}->{61265777} = "Glendonbrook";
$areanames{en}->{61265778} = "Glendonbrook";
$areanames{en}->{61265779} = "Glendonbrook";
$areanames{en}->{61265790} = "Broke";
$areanames{en}->{61265791} = "Broke";
$areanames{en}->{61265792} = "Broke";
$areanames{en}->{61265793} = "Howes\ Valley";
$areanames{en}->{61265794} = "Howes\ Valley";
$areanames{en}->{61265795} = "Putty";
$areanames{en}->{61265796} = "Putty";
$areanames{en}->{61265797} = "Putty";
$areanames{en}->{61265798} = "Broke";
$areanames{en}->{61265799} = "Broke";
$areanames{en}->{612658} = "Port\ Macquarie";
$areanames{en}->{61265804} = "Ellenborough";
$areanames{en}->{61265805} = "Telegraph\ Point";
$areanames{en}->{61265806} = "Byabarra";
$areanames{en}->{61265850} = "Telegraph\ Point";
$areanames{en}->{61265858} = "Telegraph\ Point";
$areanames{en}->{61265859} = "Telegraph\ Point";
$areanames{en}->{6126587} = "Ellenborough";
$areanames{en}->{61265870} = "Byabarra";
$areanames{en}->{61265871} = "Byabarra";
$areanames{en}->{61265872} = "Byabarra";
$areanames{en}->{61265873} = "Byabarra";
$areanames{en}->{61265890} = "Telegraph\ Point";
$areanames{en}->{61265891} = "Telegraph\ Point";
$areanames{en}->{6126590} = "Port\ Macquarie";
$areanames{en}->{61265910} = "Pacific\ Palms";
$areanames{en}->{61265911} = "Taree";
$areanames{en}->{61265912} = "Taree";
$areanames{en}->{61265913} = "Taree";
$areanames{en}->{61265914} = "Comboyne";
$areanames{en}->{61265915} = "Coopernook";
$areanames{en}->{61265916} = "Forster";
$areanames{en}->{61265917} = "Forster";
$areanames{en}->{61265918} = "Krambach";
$areanames{en}->{61265919} = "Mount\ George";
$areanames{en}->{6126592} = "Taree";
$areanames{en}->{61265921} = "Rawdon\ Vale";
$areanames{en}->{61265922} = "Rookhurst";
$areanames{en}->{61265923} = "Gloucester";
$areanames{en}->{61265930} = "Pacific\ Palms";
$areanames{en}->{61265931} = "Rawdon\ Vale";
$areanames{en}->{61265932} = "Rookhurst";
$areanames{en}->{61265933} = "Taree";
$areanames{en}->{61265934} = "Byabarra";
$areanames{en}->{61265935} = "Ellenborough";
$areanames{en}->{61265936} = "Port\ Macquarie";
$areanames{en}->{61265937} = "Telegraph\ Point";
$areanames{en}->{61265938} = "Krambach";
$areanames{en}->{61265939} = "Mount\ George";
$areanames{en}->{61265940} = "Rookhurst";
$areanames{en}->{61265941} = "Byabarra";
$areanames{en}->{61265942} = "Ellenborough";
$areanames{en}->{61265943} = "Telegraph\ Point";
$areanames{en}->{61265944} = "Taree";
$areanames{en}->{61265945} = "Taree";
$areanames{en}->{61265946} = "Taree";
$areanames{en}->{61265947} = "Taree";
$areanames{en}->{61265948} = "Bowraville";
$areanames{en}->{61265949} = "Comara";
$areanames{en}->{61265950} = "Howes\ Valley";
$areanames{en}->{61265951} = "Jerrys\ Plains";
$areanames{en}->{61265952} = "Mount\ Olive";
$areanames{en}->{61265953} = "Putty";
$areanames{en}->{61265954} = "Ravensworth";
$areanames{en}->{61265955} = "Singleton";
$areanames{en}->{61265956} = "Comboyne";
$areanames{en}->{61265957} = "Coopernook";
$areanames{en}->{61265958} = "Forster";
$areanames{en}->{61265959} = "Gloucester";
$areanames{en}->{61265960} = "Hunter\ Springs";
$areanames{en}->{61265961} = "Idaville";
$areanames{en}->{61265962} = "Merriwa";
$areanames{en}->{61265963} = "Moonan\ Flat";
$areanames{en}->{61265964} = "Murrurundi";
$areanames{en}->{61265965} = "Muswellbrook";
$areanames{en}->{61265966} = "Scone";
$areanames{en}->{61265967} = "Widden\ Valley";
$areanames{en}->{61265968} = "Broke";
$areanames{en}->{61265969} = "Glendonbrook";
$areanames{en}->{61265970} = "Toorooka";
$areanames{en}->{61265971} = "Stuarts\ Point";
$areanames{en}->{61265972} = "Stuarts\ Point";
$areanames{en}->{61265973} = "Smithtown";
$areanames{en}->{61265974} = "Smithtown";
$areanames{en}->{61265975} = "Smithtown";
$areanames{en}->{61265976} = "Bunnan";
$areanames{en}->{61265977} = "Castle\ Rock";
$areanames{en}->{61265978} = "Denman";
$areanames{en}->{61265979} = "Ellerston";
$areanames{en}->{6126598} = "Macksville";
$areanames{en}->{61265990} = "Bowraville";
$areanames{en}->{61265991} = "Comara";
$areanames{en}->{61265992} = "Kempsey";
$areanames{en}->{61265993} = "Macksville";
$areanames{en}->{61265994} = "Smithtown";
$areanames{en}->{61265995} = "Stuarts\ Point";
$areanames{en}->{61265996} = "Taylors\ Arm";
$areanames{en}->{61265997} = "Toorooka";
$areanames{en}->{61265998} = "Lord\ Howe\ Island";
$areanames{en}->{61265999} = "Baerami";
$areanames{en}->{61266000} = "Coffs\ Harbour";
$areanames{en}->{61266001} = "Coffs\ Harbour";
$areanames{en}->{61266002} = "Coffs\ Harbour";
$areanames{en}->{61266003} = "Ballina";
$areanames{en}->{61266004} = "Ballina";
$areanames{en}->{61266005} = "Ballina";
$areanames{en}->{61266006} = "Bellingen";
$areanames{en}->{61266007} = "Bellingen";
$areanames{en}->{61266008} = "Bellingen";
$areanames{en}->{61266009} = "Coffs\ Harbour";
$areanames{en}->{61266010} = "Bonalbo";
$areanames{en}->{61266011} = "Bonalbo";
$areanames{en}->{61266012} = "Bonalbo";
$areanames{en}->{61266013} = "Casino";
$areanames{en}->{61266014} = "Casino";
$areanames{en}->{61266015} = "Casino";
$areanames{en}->{61266016} = "Coffs\ Harbour";
$areanames{en}->{61266017} = "Coffs\ Harbour";
$areanames{en}->{61266018} = "Coffs\ Harbour";
$areanames{en}->{61266019} = "Coffs\ Harbour";
$areanames{en}->{61266020} = "Copmanhurst";
$areanames{en}->{61266021} = "Copmanhurst";
$areanames{en}->{61266022} = "Copmanhurst";
$areanames{en}->{61266023} = "Coutts\ Crossing";
$areanames{en}->{61266024} = "Coutts\ Crossing";
$areanames{en}->{61266025} = "Coutts\ Crossing";
$areanames{en}->{61266026} = "Dorrigo";
$areanames{en}->{61266027} = "Dorrigo";
$areanames{en}->{61266028} = "Dorrigo";
$areanames{en}->{61266029} = "Bonalbo";
$areanames{en}->{6126603} = "Maclean";
$areanames{en}->{61266036} = "Coutts\ Crossing";
$areanames{en}->{61266037} = "Coutts\ Crossing";
$areanames{en}->{61266038} = "Glenreagh";
$areanames{en}->{61266039} = "Glenreagh";
$areanames{en}->{61266040} = "Grafton";
$areanames{en}->{61266041} = "Grafton";
$areanames{en}->{61266042} = "Grafton";
$areanames{en}->{61266043} = "Dyraaba";
$areanames{en}->{61266044} = "Dyraaba";
$areanames{en}->{61266045} = "Dyraaba";
$areanames{en}->{61266046} = "Ettrick";
$areanames{en}->{61266047} = "Ettrick";
$areanames{en}->{61266048} = "Ettrick";
$areanames{en}->{61266049} = "Grafton";
$areanames{en}->{61266050} = "Glenreagh";
$areanames{en}->{61266051} = "Glenreagh";
$areanames{en}->{61266052} = "Glenreagh";
$areanames{en}->{61266053} = "Grafton";
$areanames{en}->{61266054} = "Grafton";
$areanames{en}->{61266055} = "Grafton";
$areanames{en}->{61266056} = "Hernani";
$areanames{en}->{61266057} = "Hernani";
$areanames{en}->{61266058} = "Hernani";
$areanames{en}->{61266059} = "Casino";
$areanames{en}->{61266060} = "Kyogle";
$areanames{en}->{61266061} = "Kyogle";
$areanames{en}->{61266062} = "Kyogle";
$areanames{en}->{61266063} = "Lawrence";
$areanames{en}->{61266064} = "Lawrence";
$areanames{en}->{61266065} = "Lawrence";
$areanames{en}->{61266066} = "Leeville";
$areanames{en}->{61266067} = "Leeville";
$areanames{en}->{61266068} = "Leeville";
$areanames{en}->{61266069} = "Dyraaba";
$areanames{en}->{61266070} = "Lismore";
$areanames{en}->{61266071} = "Lismore";
$areanames{en}->{61266072} = "Lismore";
$areanames{en}->{61266073} = "Maclean";
$areanames{en}->{61266074} = "Maclean";
$areanames{en}->{61266075} = "Maclean";
$areanames{en}->{61266076} = "Mallanganee";
$areanames{en}->{61266077} = "Mallanganee";
$areanames{en}->{61266078} = "Mallanganee";
$areanames{en}->{61266079} = "Mullumbimby";
$areanames{en}->{61266080} = "Mullumbimby";
$areanames{en}->{61266081} = "Mullumbimby";
$areanames{en}->{61266082} = "Mullumbimby";
$areanames{en}->{61266083} = "Murwillumbah";
$areanames{en}->{61266084} = "Murwillumbah";
$areanames{en}->{61266085} = "Murwillumbah";
$areanames{en}->{61266086} = "Nimbin";
$areanames{en}->{61266087} = "Nimbin";
$areanames{en}->{61266088} = "Nimbin";
$areanames{en}->{61266089} = "Leeville";
$areanames{en}->{61266090} = "Rappville";
$areanames{en}->{61266091} = "Rappville";
$areanames{en}->{61266092} = "Rappville";
$areanames{en}->{61266093} = "Tabulam";
$areanames{en}->{61266094} = "Tabulam";
$areanames{en}->{61266095} = "Tabulam";
$areanames{en}->{61266096} = "Thora";
$areanames{en}->{61266097} = "Thora";
$areanames{en}->{61266098} = "Thora";
$areanames{en}->{61266099} = "Mallanganee";
$areanames{en}->{61266100} = "Tyalgum";
$areanames{en}->{61266101} = "Tyalgum";
$areanames{en}->{61266102} = "Tyalgum";
$areanames{en}->{61266103} = "Tyringham";
$areanames{en}->{61266104} = "Tyringham";
$areanames{en}->{61266105} = "Tyringham";
$areanames{en}->{61266106} = "Ulong";
$areanames{en}->{61266107} = "Ulong";
$areanames{en}->{61266108} = "Ulong";
$areanames{en}->{61266109} = "Rappville";
$areanames{en}->{61266110} = "Urbenville";
$areanames{en}->{61266111} = "Urbenville";
$areanames{en}->{61266112} = "Urbenville";
$areanames{en}->{61266113} = "Whiporie";
$areanames{en}->{61266114} = "Whiporie";
$areanames{en}->{61266115} = "Whiporie";
$areanames{en}->{61266116} = "Wiangaree";
$areanames{en}->{61266117} = "Wiangaree";
$areanames{en}->{61266118} = "Wiangaree";
$areanames{en}->{61266119} = "Tabulam";
$areanames{en}->{61266120} = "Woodburn";
$areanames{en}->{61266121} = "Woodburn";
$areanames{en}->{61266122} = "Woodburn";
$areanames{en}->{61266123} = "Woodenbong";
$areanames{en}->{61266124} = "Woodenbong";
$areanames{en}->{61266125} = "Woodenbong";
$areanames{en}->{61266126} = "Wooli";
$areanames{en}->{61266127} = "Wooli";
$areanames{en}->{61266128} = "Wooli";
$areanames{en}->{61266129} = "Whiporie";
$areanames{en}->{61266130} = "Coffs\ Harbour";
$areanames{en}->{61266131} = "Bonalbo";
$areanames{en}->{61266132} = "Casino";
$areanames{en}->{61266133} = "Dyraaba";
$areanames{en}->{61266134} = "Leeville";
$areanames{en}->{61266135} = "Mallanganee";
$areanames{en}->{61266136} = "Rappville";
$areanames{en}->{61266137} = "Tabulam";
$areanames{en}->{61266138} = "Whiporie";
$areanames{en}->{61266139} = "Dorrigo";
$areanames{en}->{61266140} = "Hernani";
$areanames{en}->{61266141} = "Thora";
$areanames{en}->{61266142} = "Tyringham";
$areanames{en}->{61266143} = "Ulong";
$areanames{en}->{61266144} = "Bellingen";
$areanames{en}->{61266145} = "Coffs\ Harbour";
$areanames{en}->{61266146} = "Maclean";
$areanames{en}->{61266147} = "Wooli";
$areanames{en}->{61266148} = "Copmanhurst";
$areanames{en}->{61266149} = "Coutts\ Crossing";
$areanames{en}->{61266150} = "Glenreagh";
$areanames{en}->{61266151} = "Grafton";
$areanames{en}->{61266152} = "Lawrence";
$areanames{en}->{61266153} = "Ettrick";
$areanames{en}->{61266154} = "Kyogle";
$areanames{en}->{61266155} = "Urbenville";
$areanames{en}->{61266156} = "Wiangaree";
$areanames{en}->{61266157} = "Woodenbong";
$areanames{en}->{61266158} = "Nimbin";
$areanames{en}->{61266159} = "Woodburn";
$areanames{en}->{6126616} = "Lismore";
$areanames{en}->{61266170} = "Lismore";
$areanames{en}->{61266171} = "Grafton";
$areanames{en}->{61266172} = "Grafton";
$areanames{en}->{61266173} = "Ballina";
$areanames{en}->{61266174} = "Lismore";
$areanames{en}->{61266175} = "Mullumbimby";
$areanames{en}->{61266176} = "Murwillumbah";
$areanames{en}->{61266177} = "Tyalgum";
$areanames{en}->{61266178} = "Bellingen";
$areanames{en}->{61266179} = "Coffs\ Harbour";
$areanames{en}->{6126618} = "Ballina";
$areanames{en}->{61266190} = "Lismore";
$areanames{en}->{61266191} = "Lismore";
$areanames{en}->{61266192} = "Lismore";
$areanames{en}->{61266193} = "Dorrigo";
$areanames{en}->{61266194} = "Hernani";
$areanames{en}->{61266195} = "Grafton";
$areanames{en}->{61266196} = "Grafton";
$areanames{en}->{61266197} = "Thora";
$areanames{en}->{61266198} = "Tyringham";
$areanames{en}->{61266199} = "Ulong";
$areanames{en}->{612662} = "Lismore";
$areanames{en}->{61266205} = "Ballina";
$areanames{en}->{61266206} = "Ballina";
$areanames{en}->{61266208} = "Woodburn";
$areanames{en}->{61266209} = "Mullumbimby";
$areanames{en}->{61266267} = "Mullumbimby";
$areanames{en}->{61266268} = "Ballina";
$areanames{en}->{6126630} = "Kyogle";
$areanames{en}->{61266302} = "Ettrick";
$areanames{en}->{61266303} = "Urbenville";
$areanames{en}->{61266304} = "Wiangaree";
$areanames{en}->{61266305} = "Woodenbong";
$areanames{en}->{61266310} = "Copmanhurst";
$areanames{en}->{61266311} = "Coutts\ Crossing";
$areanames{en}->{61266312} = "Glenreagh";
$areanames{en}->{61266313} = "Grafton";
$areanames{en}->{61266314} = "Lawrence";
$areanames{en}->{61266315} = "Maclean";
$areanames{en}->{61266316} = "Wooli";
$areanames{en}->{61266317} = "Ettrick";
$areanames{en}->{61266318} = "Kyogle";
$areanames{en}->{61266319} = "Urbenville";
$areanames{en}->{6126632} = "Kyogle";
$areanames{en}->{6126633} = "Kyogle";
$areanames{en}->{61266339} = "Ettrick";
$areanames{en}->{6126634} = "Urbenville";
$areanames{en}->{6126635} = "Woodenbong";
$areanames{en}->{6126636} = "Wiangaree";
$areanames{en}->{61266370} = "Wiangaree";
$areanames{en}->{61266371} = "Woodenbong";
$areanames{en}->{61266372} = "Ballina";
$areanames{en}->{61266373} = "Lismore";
$areanames{en}->{61266374} = "Mullumbimby";
$areanames{en}->{61266375} = "Nimbin";
$areanames{en}->{61266376} = "Woodburn";
$areanames{en}->{61266377} = "Murwillumbah";
$areanames{en}->{61266378} = "Tyalgum";
$areanames{en}->{61266379} = "Bonalbo";
$areanames{en}->{61266380} = "Casino";
$areanames{en}->{61266381} = "Dyraaba";
$areanames{en}->{61266382} = "Leeville";
$areanames{en}->{61266383} = "Mallanganee";
$areanames{en}->{61266384} = "Rappville";
$areanames{en}->{61266385} = "Tabulam";
$areanames{en}->{61266386} = "Whiporie";
$areanames{en}->{61266387} = "Dorrigo";
$areanames{en}->{61266388} = "Bellingen";
$areanames{en}->{61266389} = "Coffs\ Harbour";
$areanames{en}->{6126639} = "Mullumbimby";
$areanames{en}->{61266400} = "Maclean";
$areanames{en}->{61266401} = "Grafton";
$areanames{en}->{61266402} = "Grafton";
$areanames{en}->{61266403} = "Grafton";
$areanames{en}->{61266404} = "Lawrence";
$areanames{en}->{61266405} = "Copmanhurst";
$areanames{en}->{61266406} = "Coutts\ Crossing";
$areanames{en}->{61266407} = "Glenreagh";
$areanames{en}->{61266408} = "Wooli";
$areanames{en}->{61266409} = "Grafton";
$areanames{en}->{6126641} = "Grafton";
$areanames{en}->{6126642} = "Grafton";
$areanames{en}->{6126643} = "Grafton";
$areanames{en}->{6126644} = "Grafton";
$areanames{en}->{6126645} = "Maclean";
$areanames{en}->{6126646} = "Maclean";
$areanames{en}->{6126647} = "Copmanhurst";
$areanames{en}->{61266476} = "Maclean";
$areanames{en}->{61266477} = "Lawrence";
$areanames{en}->{61266478} = "Lawrence";
$areanames{en}->{61266479} = "Lawrence";
$areanames{en}->{6126648} = "Coffs\ Harbour";
$areanames{en}->{61266480} = "Thora";
$areanames{en}->{61266481} = "Ulong";
$areanames{en}->{61266488} = "Hernani";
$areanames{en}->{61266489} = "Tyringham";
$areanames{en}->{61266490} = "Glenreagh";
$areanames{en}->{61266491} = "Glenreagh";
$areanames{en}->{61266492} = "Glenreagh";
$areanames{en}->{61266493} = "Coutts\ Crossing";
$areanames{en}->{61266494} = "Coutts\ Crossing";
$areanames{en}->{61266495} = "Coutts\ Crossing";
$areanames{en}->{61266496} = "Coutts\ Crossing";
$areanames{en}->{61266497} = "Wooli";
$areanames{en}->{61266498} = "Wooli";
$areanames{en}->{61266499} = "Wooli";
$areanames{en}->{612665} = "Coffs\ Harbour";
$areanames{en}->{61266545} = "Ulong";
$areanames{en}->{61266546} = "Ulong";
$areanames{en}->{6126655} = "Bellingen";
$areanames{en}->{61266558} = "Thora";
$areanames{en}->{6126657} = "Dorrigo";
$areanames{en}->{61266576} = "Hernani";
$areanames{en}->{61266577} = "Hernani";
$areanames{en}->{61266578} = "Tyringham";
$areanames{en}->{61266579} = "Tyringham";
$areanames{en}->{61266590} = "Dorrigo";
$areanames{en}->{61266595} = "Bellingen";
$areanames{en}->{61266600} = "Casino";
$areanames{en}->{61266601} = "Casino";
$areanames{en}->{61266602} = "Casino";
$areanames{en}->{61266603} = "Whiporie";
$areanames{en}->{61266604} = "Rappville";
$areanames{en}->{61266605} = "Leeville";
$areanames{en}->{61266606} = "Dyraaba";
$areanames{en}->{61266607} = "Mallanganee";
$areanames{en}->{61266608} = "Tabulam";
$areanames{en}->{61266609} = "Bonalbo";
$areanames{en}->{6126661} = "Casino";
$areanames{en}->{61266611} = "Tabulam";
$areanames{en}->{61266613} = "Tabulam";
$areanames{en}->{61266617} = "Rappville";
$areanames{en}->{61266619} = "Whiporie";
$areanames{en}->{6126662} = "Casino";
$areanames{en}->{6126663} = "Casino";
$areanames{en}->{61266640} = "Leeville";
$areanames{en}->{61266641} = "Leeville";
$areanames{en}->{61266642} = "Leeville";
$areanames{en}->{61266643} = "Leeville";
$areanames{en}->{61266644} = "Leeville";
$areanames{en}->{61266645} = "Mallanganee";
$areanames{en}->{61266646} = "Mallanganee";
$areanames{en}->{61266647} = "Mallanganee";
$areanames{en}->{61266648} = "Mallanganee";
$areanames{en}->{61266649} = "Mallanganee";
$areanames{en}->{6126665} = "Bonalbo";
$areanames{en}->{61266650} = "Hernani";
$areanames{en}->{6126666} = "Tabulam";
$areanames{en}->{6126667} = "Dyraaba";
$areanames{en}->{61266680} = "Thora";
$areanames{en}->{61266681} = "Tyringham";
$areanames{en}->{61266682} = "Ulong";
$areanames{en}->{61266683} = "Copmanhurst";
$areanames{en}->{61266684} = "Coutts\ Crossing";
$areanames{en}->{61266685} = "Maclean";
$areanames{en}->{61266686} = "Wooli";
$areanames{en}->{61266687} = "Glenreagh";
$areanames{en}->{61266688} = "Rappville";
$areanames{en}->{61266689} = "Rappville";
$areanames{en}->{6126669} = "Grafton";
$areanames{en}->{612667} = "Murwillumbah";
$areanames{en}->{61266703} = "Tyalgum";
$areanames{en}->{61266750} = "Grafton";
$areanames{en}->{61266751} = "Lawrence";
$areanames{en}->{61266752} = "Ettrick";
$areanames{en}->{61266753} = "Kyogle";
$areanames{en}->{61266754} = "Urbenville";
$areanames{en}->{61266755} = "Wiangaree";
$areanames{en}->{61266756} = "Woodenbong";
$areanames{en}->{61266757} = "Nimbin";
$areanames{en}->{61266758} = "Woodburn";
$areanames{en}->{61266759} = "Ballina";
$areanames{en}->{61266780} = "Lismore";
$areanames{en}->{61266781} = "Mullumbimby";
$areanames{en}->{61266783} = "Tyalgum";
$areanames{en}->{61266784} = "Bonalbo";
$areanames{en}->{61266785} = "Casino";
$areanames{en}->{61266786} = "Dyraaba";
$areanames{en}->{61266787} = "Leeville";
$areanames{en}->{61266788} = "Mallanganee";
$areanames{en}->{61266789} = "Rappville";
$areanames{en}->{6126679} = "Tyalgum";
$areanames{en}->{6126680} = "Mullumbimby";
$areanames{en}->{6126681} = "Ballina";
$areanames{en}->{6126682} = "Woodburn";
$areanames{en}->{6126683} = "Woodburn";
$areanames{en}->{61266834} = "Ballina";
$areanames{en}->{61266835} = "Ballina";
$areanames{en}->{6126684} = "Mullumbimby";
$areanames{en}->{6126685} = "Mullumbimby";
$areanames{en}->{6126686} = "Ballina";
$areanames{en}->{6126687} = "Ballina";
$areanames{en}->{6126688} = "Nimbin";
$areanames{en}->{6126689} = "Nimbin";
$areanames{en}->{6126690} = "Coffs\ Harbour";
$areanames{en}->{6126691} = "Coffs\ Harbour";
$areanames{en}->{61266920} = "Bellingen";
$areanames{en}->{61266921} = "Bellingen";
$areanames{en}->{61266922} = "Bellingen";
$areanames{en}->{61266923} = "Bellingen";
$areanames{en}->{61266924} = "Bellingen";
$areanames{en}->{61266925} = "Dorrigo";
$areanames{en}->{61266926} = "Dorrigo";
$areanames{en}->{61266927} = "Dorrigo";
$areanames{en}->{61266928} = "Thora";
$areanames{en}->{61266929} = "Thora";
$areanames{en}->{61266930} = "Nimbin";
$areanames{en}->{61266931} = "Woodburn";
$areanames{en}->{61266932} = "Murwillumbah";
$areanames{en}->{61266933} = "Tyalgum";
$areanames{en}->{61266934} = "Maclean";
$areanames{en}->{61266935} = "Wooli";
$areanames{en}->{61266936} = "Ettrick";
$areanames{en}->{61266937} = "Kyogle";
$areanames{en}->{61266938} = "Urbenville";
$areanames{en}->{61266939} = "Wiangaree";
$areanames{en}->{61266940} = "Woodenbong";
$areanames{en}->{61266941} = "Ballina";
$areanames{en}->{61266942} = "Lismore";
$areanames{en}->{61266943} = "Mullumbimby";
$areanames{en}->{61266944} = "Dorrigo";
$areanames{en}->{61266945} = "Hernani";
$areanames{en}->{61266946} = "Thora";
$areanames{en}->{61266947} = "Tyringham";
$areanames{en}->{61266948} = "Ulong";
$areanames{en}->{61266949} = "Copmanhurst";
$areanames{en}->{61266950} = "Coutts\ Crossing";
$areanames{en}->{61266951} = "Glenreagh";
$areanames{en}->{61266952} = "Grafton";
$areanames{en}->{61266953} = "Lawrence";
$areanames{en}->{61266954} = "Bonalbo";
$areanames{en}->{61266955} = "Casino";
$areanames{en}->{61266956} = "Dyraaba";
$areanames{en}->{61266957} = "Leeville";
$areanames{en}->{61266958} = "Mallanganee";
$areanames{en}->{61266959} = "Rappville";
$areanames{en}->{61266960} = "Tabulam";
$areanames{en}->{61266961} = "Whiporie";
$areanames{en}->{61266962} = "Bellingen";
$areanames{en}->{61266963} = "Coffs\ Harbour";
$areanames{en}->{61266964} = "Tabulam";
$areanames{en}->{61266965} = "Whiporie";
$areanames{en}->{61266966} = "Bellingen";
$areanames{en}->{61266967} = "Dorrigo";
$areanames{en}->{61266968} = "Hernani";
$areanames{en}->{61266969} = "Thora";
$areanames{en}->{61266970} = "Tyringham";
$areanames{en}->{61266971} = "Ulong";
$areanames{en}->{61266972} = "Copmanhurst";
$areanames{en}->{61266973} = "Coutts\ Crossing";
$areanames{en}->{61266974} = "Glenreagh";
$areanames{en}->{61266975} = "Grafton";
$areanames{en}->{61266976} = "Lawrence";
$areanames{en}->{61266977} = "Maclean";
$areanames{en}->{61266978} = "Wooli";
$areanames{en}->{61266979} = "Ettrick";
$areanames{en}->{61266980} = "Kyogle";
$areanames{en}->{61266981} = "Urbenville";
$areanames{en}->{61266982} = "Wiangaree";
$areanames{en}->{61266983} = "Woodenbong";
$areanames{en}->{61266984} = "Ballina";
$areanames{en}->{61266985} = "Lismore";
$areanames{en}->{61266986} = "Mullumbimby";
$areanames{en}->{61266987} = "Nimbin";
$areanames{en}->{61266988} = "Woodburn";
$areanames{en}->{61266989} = "Murwillumbah";
$areanames{en}->{61266990} = "Tyalgum";
$areanames{en}->{61266991} = "Coffs\ Harbour";
$areanames{en}->{61266992} = "Coffs\ Harbour";
$areanames{en}->{61266993} = "Coffs\ Harbour";
$areanames{en}->{61266994} = "Bonalbo";
$areanames{en}->{61266995} = "Casino";
$areanames{en}->{61266996} = "Dyraaba";
$areanames{en}->{61266997} = "Leeville";
$areanames{en}->{61266998} = "Mallanganee";
$areanames{en}->{61266999} = "Rappville";
$areanames{en}->{61267000} = "Tamworth";
$areanames{en}->{61267001} = "Tamworth";
$areanames{en}->{61267002} = "Tamworth";
$areanames{en}->{61267003} = "Aberfoyle";
$areanames{en}->{61267004} = "Armidale";
$areanames{en}->{61267005} = "Baan\ Baa";
$areanames{en}->{61267006} = "Banoon";
$areanames{en}->{61267007} = "Barraba";
$areanames{en}->{61267008} = "Barwick";
$areanames{en}->{61267009} = "Bellata";
$areanames{en}->{61267010} = "Bendemeer";
$areanames{en}->{61267011} = "Ogunbil";
$areanames{en}->{61267012} = "Nundle";
$areanames{en}->{61267013} = "Nundle";
$areanames{en}->{61267014} = "Currabubula";
$areanames{en}->{61267015} = "Currabubula";
$areanames{en}->{61267016} = "Somerton";
$areanames{en}->{61267017} = "Tamworth";
$areanames{en}->{61267018} = "Tamworth";
$areanames{en}->{61267019} = "Tamworth";
$areanames{en}->{6126702} = "Tamworth";
$areanames{en}->{61267030} = "Ben\ Lomond";
$areanames{en}->{61267031} = "Bendemeer";
$areanames{en}->{61267032} = "Bingara";
$areanames{en}->{61267033} = "Boggabri";
$areanames{en}->{61267034} = "Bohena";
$areanames{en}->{61267035} = "Boomi";
$areanames{en}->{61267036} = "Boorolong";
$areanames{en}->{61267037} = "Breeza";
$areanames{en}->{61267038} = "Bundarra";
$areanames{en}->{61267039} = "Bundella";
$areanames{en}->{61267040} = "Burren\ Junction";
$areanames{en}->{61267041} = "Careunga";
$areanames{en}->{61267042} = "Caroda";
$areanames{en}->{61267043} = "Collarenebri";
$areanames{en}->{61267044} = "Coolatai";
$areanames{en}->{61267045} = "Copeton\ Dam";
$areanames{en}->{61267046} = "Craigleigh";
$areanames{en}->{61267047} = "Croppa\ Creek";
$areanames{en}->{61267048} = "Curlewis";
$areanames{en}->{61267049} = "Currabubula";
$areanames{en}->{61267050} = "Bunnor";
$areanames{en}->{61267051} = "Careunga";
$areanames{en}->{61267052} = "Croppa\ Creek";
$areanames{en}->{61267053} = "Garah";
$areanames{en}->{61267054} = "Gurley";
$areanames{en}->{61267055} = "Gurley";
$areanames{en}->{61267056} = "Mungindi";
$areanames{en}->{61267057} = "Mungindi";
$areanames{en}->{61267058} = "Pallamallawa";
$areanames{en}->{61267059} = "Mirriadool";
$areanames{en}->{61267060} = "Cuttabri";
$areanames{en}->{61267061} = "Deepwater";
$areanames{en}->{61267062} = "Delungra";
$areanames{en}->{61267063} = "Drake";
$areanames{en}->{61267064} = "Ebor";
$areanames{en}->{61267065} = "Elcombe";
$areanames{en}->{61267066} = "Emmaville";
$areanames{en}->{61267067} = "Frazers\ Creek";
$areanames{en}->{61267068} = "Garah";
$areanames{en}->{61267069} = "Glen\ Elgin";
$areanames{en}->{61267070} = "Armidale";
$areanames{en}->{61267071} = "Armidale";
$areanames{en}->{61267072} = "Armidale";
$areanames{en}->{61267073} = "Glen\ Innes";
$areanames{en}->{61267074} = "Glencoe";
$areanames{en}->{61267075} = "Goolhi";
$areanames{en}->{61267076} = "Graman";
$areanames{en}->{61267077} = "Gundabloui";
$areanames{en}->{61267078} = "Gunnedah";
$areanames{en}->{61267079} = "Gunyerwarildi";
$areanames{en}->{61267080} = "Gurley";
$areanames{en}->{61267081} = "Guyra";
$areanames{en}->{61267082} = "Halls\ Creek";
$areanames{en}->{61267083} = "Ingleba";
$areanames{en}->{61267084} = "Inverell";
$areanames{en}->{61267085} = "Kelvin";
$areanames{en}->{61267086} = "Kingstown";
$areanames{en}->{61267087} = "Limbri";
$areanames{en}->{61267088} = "Manilla";
$areanames{en}->{61267089} = "Marple";
$areanames{en}->{61267090} = "Mirriadool";
$areanames{en}->{61267091} = "Moona\ Plains";
$areanames{en}->{61267092} = "Moree";
$areanames{en}->{61267093} = "Mullaley";
$areanames{en}->{61267094} = "Mungindi";
$areanames{en}->{61267095} = "Narrabri";
$areanames{en}->{61267096} = "Nowendoc";
$areanames{en}->{61267097} = "Nullamanna";
$areanames{en}->{61267098} = "Nundle";
$areanames{en}->{61267099} = "Oakey\ Creek";
$areanames{en}->{61267100} = "Oban";
$areanames{en}->{61267101} = "Ogunbil";
$areanames{en}->{61267102} = "Pallamallawa";
$areanames{en}->{61267103} = "Pilliga";
$areanames{en}->{61267104} = "Pine\ Ridge";
$areanames{en}->{61267105} = "Pinkett";
$areanames{en}->{61267106} = "Plumthorpe";
$areanames{en}->{61267107} = "Quirindi";
$areanames{en}->{61267108} = "Rocky\ Creek";
$areanames{en}->{61267109} = "Rowena";
$areanames{en}->{61267110} = "Aberfoyle";
$areanames{en}->{61267111} = "Armidale";
$areanames{en}->{61267112} = "Boorolong";
$areanames{en}->{61267113} = "Ebor";
$areanames{en}->{61267114} = "Guyra";
$areanames{en}->{61267115} = "Ingleba";
$areanames{en}->{61267116} = "Kingstown";
$areanames{en}->{61267117} = "Marple";
$areanames{en}->{61267118} = "Moona\ Plains";
$areanames{en}->{61267119} = "Nowendoc";
$areanames{en}->{61267120} = "Sandy\ Flat";
$areanames{en}->{61267121} = "Somerton";
$areanames{en}->{61267122} = "Spring\ Plains";
$areanames{en}->{61267123} = "Tambar\ Springs";
$areanames{en}->{61267124} = "Tamworth";
$areanames{en}->{61267125} = "Tenterden";
$areanames{en}->{61267126} = "Tenterfield";
$areanames{en}->{61267127} = "Tingha";
$areanames{en}->{61267128} = "Upper\ Horton";
$areanames{en}->{61267129} = "Uralla";
$areanames{en}->{61267130} = "Walcha";
$areanames{en}->{61267131} = "Walcha\ Road";
$areanames{en}->{61267132} = "Warialda";
$areanames{en}->{61267133} = "Wee\ Waa";
$areanames{en}->{61267134} = "Weemelah";
$areanames{en}->{61267135} = "Wellingrove";
$areanames{en}->{61267136} = "Wenna";
$areanames{en}->{61267137} = "Willow\ Tree";
$areanames{en}->{61267138} = "Wollomombi";
$areanames{en}->{61267139} = "Yarrie\ Lake";
$areanames{en}->{61267140} = "Yarrowitch";
$areanames{en}->{61267141} = "Oban";
$areanames{en}->{61267142} = "Tenterden";
$areanames{en}->{61267143} = "Uralla";
$areanames{en}->{61267144} = "Walcha";
$areanames{en}->{61267145} = "Walcha\ Road";
$areanames{en}->{61267146} = "Wollomombi";
$areanames{en}->{61267147} = "Nowendoc";
$areanames{en}->{61267148} = "Aberfoyle";
$areanames{en}->{61267149} = "Armidale";
$areanames{en}->{61267150} = "Tamworth";
$areanames{en}->{61267151} = "Armidale";
$areanames{en}->{61267152} = "Quirindi";
$areanames{en}->{61267153} = "Tambar\ Springs";
$areanames{en}->{61267154} = "Willow\ Tree";
$areanames{en}->{61267155} = "Bingara";
$areanames{en}->{61267156} = "Bundarra";
$areanames{en}->{61267157} = "Coolatai";
$areanames{en}->{61267158} = "Copeton\ Dam";
$areanames{en}->{61267159} = "Craigleigh";
$areanames{en}->{61267160} = "Delungra";
$areanames{en}->{61267161} = "Elcombe";
$areanames{en}->{61267162} = "Frazers\ Creek";
$areanames{en}->{61267163} = "Graman";
$areanames{en}->{61267164} = "Gunyerwarildi";
$areanames{en}->{61267165} = "Inverell";
$areanames{en}->{61267166} = "Nullamanna";
$areanames{en}->{61267167} = "Oakey\ Creek";
$areanames{en}->{61267168} = "Tingha";
$areanames{en}->{61267169} = "Warialda";
$areanames{en}->{61267170} = "Boomi";
$areanames{en}->{61267171} = "Bunnor";
$areanames{en}->{61267172} = "Careunga";
$areanames{en}->{61267173} = "Collarenebri";
$areanames{en}->{61267174} = "Croppa\ Creek";
$areanames{en}->{61267175} = "Garah";
$areanames{en}->{61267176} = "Gundabloui";
$areanames{en}->{61267177} = "Gurley";
$areanames{en}->{61267178} = "Mirriadool";
$areanames{en}->{61267179} = "Moree";
$areanames{en}->{61267180} = "Mungindi";
$areanames{en}->{61267181} = "Pallamallawa";
$areanames{en}->{61267182} = "Weemelah";
$areanames{en}->{61267183} = "Wenna";
$areanames{en}->{61267184} = "Baan\ Baa";
$areanames{en}->{61267185} = "Bellata";
$areanames{en}->{61267186} = "Bohena";
$areanames{en}->{61267187} = "Burren\ Junction";
$areanames{en}->{61267188} = "Cuttabri";
$areanames{en}->{61267189} = "Narrabri";
$areanames{en}->{61267190} = "Pilliga";
$areanames{en}->{61267191} = "Rowena";
$areanames{en}->{61267192} = "Spring\ Plains";
$areanames{en}->{61267193} = "Wee\ Waa";
$areanames{en}->{61267194} = "Yarrie\ Lake";
$areanames{en}->{61267195} = "Bendemeer";
$areanames{en}->{61267196} = "Currabubula";
$areanames{en}->{61267197} = "Limbri";
$areanames{en}->{61267198} = "Nundle";
$areanames{en}->{61267199} = "Ogunbil";
$areanames{en}->{61267200} = "Inverell";
$areanames{en}->{61267201} = "Gunyerwarildi";
$areanames{en}->{61267202} = "Oakey\ Creek";
$areanames{en}->{61267203} = "Tingha";
$areanames{en}->{61267204} = "Nullamanna";
$areanames{en}->{61267205} = "Frazers\ Creek";
$areanames{en}->{61267206} = "Bundarra";
$areanames{en}->{61267207} = "Coolatai";
$areanames{en}->{61267208} = "Inverell";
$areanames{en}->{61267209} = "Inverell";
$areanames{en}->{6126721} = "Inverell";
$areanames{en}->{6126722} = "Inverell";
$areanames{en}->{61267230} = "Inverell";
$areanames{en}->{61267231} = "Inverell";
$areanames{en}->{61267232} = "Inverell";
$areanames{en}->{61267233} = "Tingha";
$areanames{en}->{61267234} = "Tingha";
$areanames{en}->{61267235} = "Tingha";
$areanames{en}->{61267236} = "Copeton\ Dam";
$areanames{en}->{61267237} = "Bundarra";
$areanames{en}->{61267238} = "Bundarra";
$areanames{en}->{61267239} = "Bundarra";
$areanames{en}->{61267240} = "Bingara";
$areanames{en}->{61267241} = "Bingara";
$areanames{en}->{61267242} = "Bingara";
$areanames{en}->{61267243} = "Bingara";
$areanames{en}->{61267244} = "Oban";
$areanames{en}->{61267245} = "Tenterden";
$areanames{en}->{61267246} = "Uralla";
$areanames{en}->{61267247} = "Elcombe";
$areanames{en}->{61267248} = "Delungra";
$areanames{en}->{61267249} = "Delungra";
$areanames{en}->{61267250} = "Delungra";
$areanames{en}->{61267251} = "Nullamanna";
$areanames{en}->{61267252} = "Craigleigh";
$areanames{en}->{61267253} = "Craigleigh";
$areanames{en}->{61267254} = "Graman";
$areanames{en}->{61267255} = "Graman";
$areanames{en}->{61267256} = "Graman";
$areanames{en}->{61267257} = "Coolatai";
$areanames{en}->{61267258} = "Frazers\ Creek";
$areanames{en}->{61267259} = "Gunyerwarildi";
$areanames{en}->{61267260} = "Copeton\ Dam";
$areanames{en}->{61267261} = "Copeton\ Dam";
$areanames{en}->{61267262} = "Graman";
$areanames{en}->{61267263} = "Graman";
$areanames{en}->{61267264} = "Nullamanna";
$areanames{en}->{61267265} = "Somerton";
$areanames{en}->{61267266} = "Tamworth";
$areanames{en}->{61267267} = "Pine\ Ridge";
$areanames{en}->{61267268} = "Curlewis";
$areanames{en}->{61267269} = "Goolhi";
$areanames{en}->{61267270} = "Gunnedah";
$areanames{en}->{61267271} = "Kelvin";
$areanames{en}->{61267272} = "Mullaley";
$areanames{en}->{61267273} = "Glen\ Innes";
$areanames{en}->{61267274} = "Glencoe";
$areanames{en}->{61267275} = "Pinkett";
$areanames{en}->{61267276} = "Rocky\ Creek";
$areanames{en}->{61267277} = "Sandy\ Flat";
$areanames{en}->{61267278} = "Tenterfield";
$areanames{en}->{61267279} = "Wellingrove";
$areanames{en}->{61267280} = "Bingara";
$areanames{en}->{61267281} = "Inverell";
$areanames{en}->{61267282} = "Inverell";
$areanames{en}->{61267283} = "Copeton\ Dam";
$areanames{en}->{61267284} = "Craigleigh";
$areanames{en}->{61267285} = "Delungra";
$areanames{en}->{61267286} = "Elcombe";
$areanames{en}->{61267287} = "Graman";
$areanames{en}->{61267288} = "Inverell";
$areanames{en}->{61267289} = "Warialda";
$areanames{en}->{61267290} = "Warialda";
$areanames{en}->{61267291} = "Warialda";
$areanames{en}->{61267292} = "Warialda";
$areanames{en}->{61267293} = "Warialda";
$areanames{en}->{61267294} = "Oakey\ Creek";
$areanames{en}->{61267295} = "Gunyerwarildi";
$areanames{en}->{61267296} = "Elcombe";
$areanames{en}->{61267297} = "Elcombe";
$areanames{en}->{61267298} = "Coolatai";
$areanames{en}->{61267299} = "Coolatai";
$areanames{en}->{61267300} = "Glen\ Elgin";
$areanames{en}->{61267301} = "Glen\ Innes";
$areanames{en}->{61267302} = "Glen\ Innes";
$areanames{en}->{61267303} = "Ben\ Lomond";
$areanames{en}->{61267304} = "Deepwater";
$areanames{en}->{61267305} = "Glencoe";
$areanames{en}->{61267306} = "Wellingrove";
$areanames{en}->{61267307} = "Pinkett";
$areanames{en}->{61267308} = "Rocky\ Creek";
$areanames{en}->{61267309} = "Emmaville";
$areanames{en}->{61267310} = "Walcha";
$areanames{en}->{61267311} = "Walcha\ Road";
$areanames{en}->{61267312} = "Wollomombi";
$areanames{en}->{61267313} = "Yarrowitch";
$areanames{en}->{61267314} = "Banoon";
$areanames{en}->{61267315} = "Barraba";
$areanames{en}->{61267316} = "Caroda";
$areanames{en}->{61267317} = "Halls\ Creek";
$areanames{en}->{61267318} = "Manilla";
$areanames{en}->{61267319} = "Plumthorpe";
$areanames{en}->{6126732} = "Glen\ Innes";
$areanames{en}->{61267330} = "Ben\ Lomond";
$areanames{en}->{61267331} = "Ben\ Lomond";
$areanames{en}->{61267332} = "Ben\ Lomond";
$areanames{en}->{61267333} = "Glencoe";
$areanames{en}->{61267334} = "Pinkett";
$areanames{en}->{61267335} = "Glen\ Elgin";
$areanames{en}->{61267336} = "Wellingrove";
$areanames{en}->{61267337} = "Rocky\ Creek";
$areanames{en}->{61267338} = "Rocky\ Creek";
$areanames{en}->{61267339} = "Wellingrove";
$areanames{en}->{61267340} = "Glen\ Innes";
$areanames{en}->{61267341} = "Glen\ Innes";
$areanames{en}->{61267342} = "Glen\ Innes";
$areanames{en}->{61267343} = "Glen\ Innes";
$areanames{en}->{61267344} = "Deepwater";
$areanames{en}->{61267345} = "Deepwater";
$areanames{en}->{61267346} = "Emmaville";
$areanames{en}->{61267347} = "Emmaville";
$areanames{en}->{61267348} = "Emmaville";
$areanames{en}->{61267349} = "Emmaville";
$areanames{en}->{61267350} = "Boggabri";
$areanames{en}->{61267351} = "Breeza";
$areanames{en}->{61267352} = "Bundella";
$areanames{en}->{61267353} = "Halls\ Creek";
$areanames{en}->{61267354} = "Manilla";
$areanames{en}->{61267355} = "Plumthorpe";
$areanames{en}->{61267356} = "Upper\ Horton";
$areanames{en}->{61267357} = "Barwick";
$areanames{en}->{61267358} = "Ben\ Lomond";
$areanames{en}->{61267359} = "Deepwater";
$areanames{en}->{6126736} = "Tenterfield";
$areanames{en}->{61267370} = "Sandy\ Flat";
$areanames{en}->{61267371} = "Sandy\ Flat";
$areanames{en}->{61267372} = "Sandy\ Flat";
$areanames{en}->{61267373} = "Sandy\ Flat";
$areanames{en}->{61267374} = "Sandy\ Flat";
$areanames{en}->{61267375} = "Barwick";
$areanames{en}->{61267376} = "Drake";
$areanames{en}->{61267377} = "Drake";
$areanames{en}->{61267378} = "Drake";
$areanames{en}->{61267379} = "Drake";
$areanames{en}->{61267380} = "Uralla";
$areanames{en}->{61267381} = "Uralla";
$areanames{en}->{61267382} = "Uralla";
$areanames{en}->{61267383} = "Walcha";
$areanames{en}->{61267384} = "Guyra";
$areanames{en}->{61267385} = "Guyra";
$areanames{en}->{61267386} = "Upper\ Horton";
$areanames{en}->{61267387} = "Armidale";
$areanames{en}->{61267388} = "Armidale";
$areanames{en}->{61267389} = "Armidale";
$areanames{en}->{61267390} = "Glen\ Innes";
$areanames{en}->{61267391} = "Tenterfield";
$areanames{en}->{61267392} = "Barwick";
$areanames{en}->{61267393} = "Drake";
$areanames{en}->{61267394} = "Sandy\ Flat";
$areanames{en}->{61267395} = "Tenterfield";
$areanames{en}->{61267396} = "Glen\ Innes";
$areanames{en}->{61267397} = "Glen\ Innes";
$areanames{en}->{61267398} = "Glen\ Innes";
$areanames{en}->{61267399} = "Glen\ Innes";
$areanames{en}->{61267400} = "Bundella";
$areanames{en}->{61267401} = "Gunnedah";
$areanames{en}->{61267402} = "Gunnedah";
$areanames{en}->{61267403} = "Boggabri";
$areanames{en}->{61267404} = "Breeza";
$areanames{en}->{61267405} = "Curlewis";
$areanames{en}->{61267406} = "Goolhi";
$areanames{en}->{61267407} = "Kelvin";
$areanames{en}->{61267408} = "Mullaley";
$areanames{en}->{61267409} = "Tambar\ Springs";
$areanames{en}->{6126741} = "Gunnedah";
$areanames{en}->{61267411} = "Pine\ Ridge";
$areanames{en}->{61267412} = "Quirindi";
$areanames{en}->{61267413} = "Willow\ Tree";
$areanames{en}->{6126742} = "Gunnedah";
$areanames{en}->{61267430} = "Gunnedah";
$areanames{en}->{61267431} = "Gunnedah";
$areanames{en}->{61267432} = "Kelvin";
$areanames{en}->{61267433} = "Kelvin";
$areanames{en}->{61267434} = "Boggabri";
$areanames{en}->{61267435} = "Goolhi";
$areanames{en}->{61267436} = "Goolhi";
$areanames{en}->{61267437} = "Mullaley";
$areanames{en}->{61267438} = "Mullaley";
$areanames{en}->{61267439} = "Mullaley";
$areanames{en}->{6126744} = "Curlewis";
$areanames{en}->{61267442} = "Tambar\ Springs";
$areanames{en}->{61267443} = "Tambar\ Springs";
$areanames{en}->{61267444} = "Tambar\ Springs";
$areanames{en}->{61267445} = "Breeza";
$areanames{en}->{61267450} = "Drake";
$areanames{en}->{61267451} = "Emmaville";
$areanames{en}->{61267452} = "Glen\ Elgin";
$areanames{en}->{61267453} = "Oban";
$areanames{en}->{61267454} = "Tenterden";
$areanames{en}->{61267455} = "Uralla";
$areanames{en}->{61267456} = "Walcha";
$areanames{en}->{61267457} = "Walcha\ Road";
$areanames{en}->{61267458} = "Wollomombi";
$areanames{en}->{61267459} = "Yarrowitch";
$areanames{en}->{6126746} = "Quirindi";
$areanames{en}->{61267470} = "Willow\ Tree";
$areanames{en}->{61267471} = "Willow\ Tree";
$areanames{en}->{61267472} = "Pine\ Ridge";
$areanames{en}->{61267473} = "Pine\ Ridge";
$areanames{en}->{61267474} = "Pine\ Ridge";
$areanames{en}->{61267475} = "Willow\ Tree";
$areanames{en}->{61267476} = "Bundella";
$areanames{en}->{61267477} = "Bundella";
$areanames{en}->{61267478} = "Bundella";
$areanames{en}->{61267479} = "Bundella";
$areanames{en}->{6126748} = "Gunnedah";
$areanames{en}->{61267486} = "Ben\ Lomond";
$areanames{en}->{61267487} = "Deepwater";
$areanames{en}->{61267488} = "Drake";
$areanames{en}->{61267489} = "Emmaville";
$areanames{en}->{61267490} = "Willow\ Tree";
$areanames{en}->{61267491} = "Pine\ Ridge";
$areanames{en}->{61267492} = "Pine\ Ridge";
$areanames{en}->{61267493} = "Kelvin";
$areanames{en}->{61267494} = "Kelvin";
$areanames{en}->{61267495} = "Boggabri";
$areanames{en}->{61267496} = "Boggabri";
$areanames{en}->{61267497} = "Boggabri";
$areanames{en}->{61267498} = "Goolhi";
$areanames{en}->{61267499} = "Goolhi";
$areanames{en}->{61267500} = "Moree";
$areanames{en}->{61267501} = "Mungindi";
$areanames{en}->{61267502} = "Pallamallawa";
$areanames{en}->{61267503} = "Weemelah";
$areanames{en}->{61267504} = "Wenna";
$areanames{en}->{61267505} = "Gundabloui";
$areanames{en}->{61267506} = "Moree";
$areanames{en}->{61267507} = "Moree";
$areanames{en}->{61267508} = "Moree";
$areanames{en}->{61267509} = "Moree";
$areanames{en}->{6126751} = "Moree";
$areanames{en}->{6126752} = "Moree";
$areanames{en}->{61267530} = "Wenna";
$areanames{en}->{61267531} = "Wenna";
$areanames{en}->{61267532} = "Mungindi";
$areanames{en}->{61267533} = "Bunnor";
$areanames{en}->{61267534} = "Boomi";
$areanames{en}->{61267535} = "Boomi";
$areanames{en}->{61267536} = "Weemelah";
$areanames{en}->{61267537} = "Weemelah";
$areanames{en}->{61267538} = "Bunnor";
$areanames{en}->{61267539} = "Mirriadool";
$areanames{en}->{61267540} = "Pallamallawa";
$areanames{en}->{61267541} = "Pallamallawa";
$areanames{en}->{61267542} = "Garah";
$areanames{en}->{61267543} = "Garah";
$areanames{en}->{61267544} = "Garah";
$areanames{en}->{61267545} = "Croppa\ Creek";
$areanames{en}->{61267546} = "Gurley";
$areanames{en}->{61267547} = "Croppa\ Creek";
$areanames{en}->{61267548} = "Careunga";
$areanames{en}->{61267549} = "Pallamallawa";
$areanames{en}->{61267550} = "Somerton";
$areanames{en}->{61267551} = "Bendemeer";
$areanames{en}->{61267552} = "Tamworth";
$areanames{en}->{61267553} = "Tamworth";
$areanames{en}->{61267554} = "Tamworth";
$areanames{en}->{61267555} = "Tamworth";
$areanames{en}->{61267556} = "Tamworth";
$areanames{en}->{61267557} = "Limbri";
$areanames{en}->{61267558} = "Nundle";
$areanames{en}->{61267559} = "Ogunbil";
$areanames{en}->{6126756} = "Collarenebri";
$areanames{en}->{61267565} = "Gundabloui";
$areanames{en}->{6126757} = "Moree";
$areanames{en}->{61267580} = "Glen\ Elgin";
$areanames{en}->{61267581} = "Glen\ Innes";
$areanames{en}->{61267582} = "Glencoe";
$areanames{en}->{61267583} = "Pinkett";
$areanames{en}->{61267584} = "Rocky\ Creek";
$areanames{en}->{61267585} = "Sandy\ Flat";
$areanames{en}->{61267586} = "Tenterfield";
$areanames{en}->{61267587} = "Wellingrove";
$areanames{en}->{61267588} = "Boggabri";
$areanames{en}->{61267589} = "Breeza";
$areanames{en}->{61267590} = "Mirriadool";
$areanames{en}->{61267591} = "Moree";
$areanames{en}->{61267592} = "Moree";
$areanames{en}->{61267593} = "Boomi";
$areanames{en}->{61267594} = "Bunnor";
$areanames{en}->{61267595} = "Collarenebri";
$areanames{en}->{61267596} = "Careunga";
$areanames{en}->{61267597} = "Croppa\ Creek";
$areanames{en}->{61267598} = "Garah";
$areanames{en}->{61267599} = "Gurley";
$areanames{en}->{6126760} = "Tamworth";
$areanames{en}->{61267606} = "Somerton";
$areanames{en}->{6126763} = "Tamworth";
$areanames{en}->{61267636} = "Currabubula";
$areanames{en}->{6126764} = "Tamworth";
$areanames{en}->{61267640} = "Bendemeer";
$areanames{en}->{61267642} = "Nundle";
$areanames{en}->{61267643} = "Limbri";
$areanames{en}->{61267644} = "Limbri";
$areanames{en}->{6126767} = "Tamworth";
$areanames{en}->{61267676} = "Somerton";
$areanames{en}->{6126768} = "Tamworth";
$areanames{en}->{61267686} = "Currabubula";
$areanames{en}->{61267687} = "Currabubula";
$areanames{en}->{61267688} = "Currabubula";
$areanames{en}->{61267689} = "Currabubula";
$areanames{en}->{61267690} = "Ogunbil";
$areanames{en}->{61267691} = "Nundle";
$areanames{en}->{61267692} = "Ogunbil";
$areanames{en}->{61267693} = "Nundle";
$areanames{en}->{61267694} = "Nundle";
$areanames{en}->{61267695} = "Tamworth";
$areanames{en}->{61267696} = "Bendemeer";
$areanames{en}->{61267697} = "Somerton";
$areanames{en}->{61267698} = "Currabubula";
$areanames{en}->{61267699} = "Currabubula";
$areanames{en}->{61267700} = "Tenterden";
$areanames{en}->{61267701} = "Armidale";
$areanames{en}->{61267702} = "Armidale";
$areanames{en}->{61267703} = "Armidale";
$areanames{en}->{61267704} = "Bundella";
$areanames{en}->{61267705} = "Boorolong";
$areanames{en}->{61267706} = "Ebor";
$areanames{en}->{61267707} = "Guyra";
$areanames{en}->{61267708} = "Kingstown";
$areanames{en}->{61267709} = "Marple";
$areanames{en}->{6126771} = "Armidale";
$areanames{en}->{6126772} = "Armidale";
$areanames{en}->{6126773} = "Armidale";
$areanames{en}->{61267740} = "Walcha";
$areanames{en}->{61267741} = "Walcha";
$areanames{en}->{61267742} = "Walcha";
$areanames{en}->{61267743} = "Ingleba";
$areanames{en}->{61267744} = "Moona\ Plains";
$areanames{en}->{61267745} = "Nowendoc";
$areanames{en}->{61267746} = "Yarrowitch";
$areanames{en}->{61267747} = "Walcha\ Road";
$areanames{en}->{61267748} = "Armidale";
$areanames{en}->{61267749} = "Armidale";
$areanames{en}->{61267750} = "Guyra";
$areanames{en}->{61267751} = "Armidale";
$areanames{en}->{61267752} = "Armidale";
$areanames{en}->{61267753} = "Armidale";
$areanames{en}->{61267754} = "Armidale";
$areanames{en}->{61267755} = "Boorolong";
$areanames{en}->{61267756} = "Boorolong";
$areanames{en}->{61267757} = "Ebor";
$areanames{en}->{61267758} = "Aberfoyle";
$areanames{en}->{61267759} = "Ebor";
$areanames{en}->{6126776} = "Armidale";
$areanames{en}->{61267761} = "Uralla";
$areanames{en}->{61267762} = "Oban";
$areanames{en}->{61267763} = "Wollomombi";
$areanames{en}->{61267770} = "Nowendoc";
$areanames{en}->{61267771} = "Walcha";
$areanames{en}->{61267772} = "Walcha";
$areanames{en}->{61267773} = "Walcha";
$areanames{en}->{61267774} = "Walcha";
$areanames{en}->{61267775} = "Walcha\ Road";
$areanames{en}->{61267776} = "Ingleba";
$areanames{en}->{61267777} = "Yarrowitch";
$areanames{en}->{61267778} = "Moona\ Plains";
$areanames{en}->{61267779} = "Moona\ Plains";
$areanames{en}->{6126778} = "Uralla";
$areanames{en}->{61267780} = "Walcha";
$areanames{en}->{61267781} = "Wollomombi";
$areanames{en}->{61267782} = "Marple";
$areanames{en}->{61267789} = "Kingstown";
$areanames{en}->{61267790} = "Guyra";
$areanames{en}->{61267791} = "Guyra";
$areanames{en}->{61267792} = "Guyra";
$areanames{en}->{61267793} = "Guyra";
$areanames{en}->{61267794} = "Tenterden";
$areanames{en}->{61267795} = "Oban";
$areanames{en}->{61267796} = "Oban";
$areanames{en}->{61267797} = "Oban";
$areanames{en}->{61267798} = "Oban";
$areanames{en}->{61267799} = "Oban";
$areanames{en}->{61267800} = "Curlewis";
$areanames{en}->{61267801} = "Barraba";
$areanames{en}->{61267802} = "Barraba";
$areanames{en}->{61267803} = "Halls\ Creek";
$areanames{en}->{61267804} = "Caroda";
$areanames{en}->{61267805} = "Goolhi";
$areanames{en}->{61267806} = "Manilla";
$areanames{en}->{61267807} = "Plumthorpe";
$areanames{en}->{61267808} = "Upper\ Horton";
$areanames{en}->{61267809} = "Gunnedah";
$areanames{en}->{61267810} = "Burren\ Junction";
$areanames{en}->{61267811} = "Burren\ Junction";
$areanames{en}->{61267812} = "Yarrie\ Lake";
$areanames{en}->{61267813} = "Kelvin";
$areanames{en}->{61267814} = "Mullaley";
$areanames{en}->{61267815} = "Marple";
$areanames{en}->{61267816} = "Moona\ Plains";
$areanames{en}->{61267817} = "Nowendoc";
$areanames{en}->{61267818} = "Pine\ Ridge";
$areanames{en}->{61267819} = "Quirindi";
$areanames{en}->{61267820} = "Tambar\ Springs";
$areanames{en}->{61267821} = "Barraba";
$areanames{en}->{61267822} = "Barraba";
$areanames{en}->{61267823} = "Willow\ Tree";
$areanames{en}->{61267824} = "Bingara";
$areanames{en}->{61267825} = "Barraba";
$areanames{en}->{61267826} = "Coolatai";
$areanames{en}->{61267827} = "Upper\ Horton";
$areanames{en}->{61267828} = "Upper\ Horton";
$areanames{en}->{61267829} = "Upper\ Horton";
$areanames{en}->{6126783} = "Caroda";
$areanames{en}->{61267830} = "Banoon";
$areanames{en}->{61267831} = "Plumthorpe";
$areanames{en}->{61267832} = "Upper\ Horton";
$areanames{en}->{61267833} = "Upper\ Horton";
$areanames{en}->{61267840} = "Copeton\ Dam";
$areanames{en}->{61267841} = "Craigleigh";
$areanames{en}->{61267842} = "Delungra";
$areanames{en}->{61267843} = "Elcombe";
$areanames{en}->{61267844} = "Frazers\ Creek";
$areanames{en}->{61267845} = "Graman";
$areanames{en}->{61267846} = "Gunyerwarildi";
$areanames{en}->{61267847} = "Inverell";
$areanames{en}->{61267848} = "Nullamanna";
$areanames{en}->{61267849} = "Oakey\ Creek";
$areanames{en}->{6126785} = "Manilla";
$areanames{en}->{61267860} = "Halls\ Creek";
$areanames{en}->{61267861} = "Halls\ Creek";
$areanames{en}->{61267862} = "Tingha";
$areanames{en}->{61267863} = "Warialda";
$areanames{en}->{61267864} = "Boomi";
$areanames{en}->{61267865} = "Bunnor";
$areanames{en}->{61267866} = "Careunga";
$areanames{en}->{61267867} = "Collarenebri";
$areanames{en}->{61267868} = "Croppa\ Creek";
$areanames{en}->{61267869} = "Garah";
$areanames{en}->{61267870} = "Banoon";
$areanames{en}->{61267871} = "Barraba";
$areanames{en}->{61267872} = "Caroda";
$areanames{en}->{61267873} = "Aberfoyle";
$areanames{en}->{61267874} = "Armidale";
$areanames{en}->{61267875} = "Boorolong";
$areanames{en}->{61267876} = "Ebor";
$areanames{en}->{61267877} = "Guyra";
$areanames{en}->{61267878} = "Ingleba";
$areanames{en}->{61267879} = "Kingstown";
$areanames{en}->{61267880} = "Armidale";
$areanames{en}->{61267881} = "Armidale";
$areanames{en}->{61267882} = "Armidale";
$areanames{en}->{61267883} = "Tamworth";
$areanames{en}->{61267884} = "Boorolong";
$areanames{en}->{61267885} = "Ebor";
$areanames{en}->{61267886} = "Guyra";
$areanames{en}->{61267887} = "Ingleba";
$areanames{en}->{61267888} = "Kingstown";
$areanames{en}->{61267889} = "Glen\ Innes";
$areanames{en}->{61267890} = "Glencoe";
$areanames{en}->{61267891} = "Pinkett";
$areanames{en}->{61267892} = "Rocky\ Creek";
$areanames{en}->{61267893} = "Sandy\ Flat";
$areanames{en}->{61267894} = "Tenterfield";
$areanames{en}->{61267895} = "Wellingrove";
$areanames{en}->{61267896} = "Barwick";
$areanames{en}->{61267897} = "Tambar\ Springs";
$areanames{en}->{61267898} = "Willow\ Tree";
$areanames{en}->{61267899} = "Pine\ Ridge";
$areanames{en}->{6126790} = "Narrabri";
$areanames{en}->{61267901} = "Rowena";
$areanames{en}->{61267902} = "Spring\ Plains";
$areanames{en}->{61267903} = "Wee\ Waa";
$areanames{en}->{61267904} = "Yarrie\ Lake";
$areanames{en}->{61267910} = "Curlewis";
$areanames{en}->{61267911} = "Goolhi";
$areanames{en}->{61267912} = "Gunnedah";
$areanames{en}->{61267913} = "Kelvin";
$areanames{en}->{61267914} = "Mullaley";
$areanames{en}->{61267915} = "Boggabri";
$areanames{en}->{61267916} = "Breeza";
$areanames{en}->{61267917} = "Bundella";
$areanames{en}->{61267918} = "Bingara";
$areanames{en}->{61267919} = "Bundarra";
$areanames{en}->{6126792} = "Narrabri";
$areanames{en}->{61267930} = "Narrabri";
$areanames{en}->{61267931} = "Wee\ Waa";
$areanames{en}->{61267932} = "Bohena";
$areanames{en}->{61267933} = "Narrabri";
$areanames{en}->{61267934} = "Narrabri";
$areanames{en}->{61267935} = "Narrabri";
$areanames{en}->{61267936} = "Narrabri";
$areanames{en}->{61267937} = "Bellata";
$areanames{en}->{61267938} = "Bellata";
$areanames{en}->{61267939} = "Bellata";
$areanames{en}->{61267940} = "Gundabloui";
$areanames{en}->{61267941} = "Gurley";
$areanames{en}->{61267942} = "Mirriadool";
$areanames{en}->{61267943} = "Moree";
$areanames{en}->{61267944} = "Baan\ Baa";
$areanames{en}->{61267945} = "Mungindi";
$areanames{en}->{61267946} = "Pallamallawa";
$areanames{en}->{61267947} = "Weemelah";
$areanames{en}->{61267948} = "Wenna";
$areanames{en}->{61267949} = "Baan\ Baa";
$areanames{en}->{6126795} = "Wee\ Waa";
$areanames{en}->{61267956} = "Yarrie\ Lake";
$areanames{en}->{61267959} = "Yarrie\ Lake";
$areanames{en}->{61267960} = "Burren\ Junction";
$areanames{en}->{61267961} = "Burren\ Junction";
$areanames{en}->{61267962} = "Cuttabri";
$areanames{en}->{61267963} = "Pilliga";
$areanames{en}->{61267964} = "Pilliga";
$areanames{en}->{61267965} = "Rowena";
$areanames{en}->{61267966} = "Rowena";
$areanames{en}->{61267967} = "Spring\ Plains";
$areanames{en}->{61267968} = "Bellata";
$areanames{en}->{61267969} = "Bellata";
$areanames{en}->{61267970} = "Coolatai";
$areanames{en}->{61267971} = "Copeton\ Dam";
$areanames{en}->{61267972} = "Craigleigh";
$areanames{en}->{61267973} = "Inverell";
$areanames{en}->{61267974} = "Garah";
$areanames{en}->{61267975} = "Gundabloui";
$areanames{en}->{61267976} = "Gurley";
$areanames{en}->{61267977} = "Mirriadool";
$areanames{en}->{61267978} = "Moree";
$areanames{en}->{61267979} = "Mungindi";
$areanames{en}->{61267980} = "Pallamallawa";
$areanames{en}->{61267981} = "Weemelah";
$areanames{en}->{61267982} = "Wenna";
$areanames{en}->{61267983} = "Bendemeer";
$areanames{en}->{61267984} = "Currabubula";
$areanames{en}->{61267985} = "Limbri";
$areanames{en}->{61267986} = "Nundle";
$areanames{en}->{61267987} = "Ogunbil";
$areanames{en}->{61267988} = "Somerton";
$areanames{en}->{61267989} = "Tamworth";
$areanames{en}->{61267990} = "Pilliga";
$areanames{en}->{61267991} = "Narrabri";
$areanames{en}->{61267992} = "Narrabri";
$areanames{en}->{61267993} = "Bellata";
$areanames{en}->{61267994} = "Bellata";
$areanames{en}->{61267995} = "Narrabri";
$areanames{en}->{61267996} = "Narrabri";
$areanames{en}->{61267997} = "Bohena";
$areanames{en}->{61267998} = "Burren\ Junction";
$areanames{en}->{61267999} = "Cuttabri";
$areanames{en}->{61268000} = "Dubbo";
$areanames{en}->{61268001} = "Dubbo";
$areanames{en}->{61268002} = "Dubbo";
$areanames{en}->{61268003} = "Airlands";
$areanames{en}->{61268004} = "Albert";
$areanames{en}->{61268005} = "Alectown";
$areanames{en}->{61268006} = "Balladoran";
$areanames{en}->{61268007} = "Ballimore";
$areanames{en}->{61268008} = "Banar";
$areanames{en}->{61268009} = "Baradine";
$areanames{en}->{61268010} = "Geurie";
$areanames{en}->{61268011} = "Dubbo";
$areanames{en}->{61268012} = "Dubbo";
$areanames{en}->{61268013} = "Dubbo";
$areanames{en}->{61268014} = "Dubbo";
$areanames{en}->{61268015} = "Narromine";
$areanames{en}->{61268016} = "Narromine";
$areanames{en}->{61268017} = "Narromine";
$areanames{en}->{61268018} = "Wyanga";
$areanames{en}->{61268019} = "Farrendale";
$areanames{en}->{61268020} = "Barrier";
$areanames{en}->{61268021} = "Bedgerebong";
$areanames{en}->{61268022} = "Berkley\ Downs";
$areanames{en}->{61268023} = "Bindogundra";
$areanames{en}->{61268024} = "Binnaway";
$areanames{en}->{61268025} = "Bobadah";
$areanames{en}->{61268026} = "Bogan\ Gate";
$areanames{en}->{61268027} = "Bonnay";
$areanames{en}->{61268028} = "Boona\ Mountain";
$areanames{en}->{61268029} = "Boorooma";
$areanames{en}->{61268030} = "Borah\ Tank";
$areanames{en}->{61268031} = "Bourke";
$areanames{en}->{61268032} = "Brewarrina";
$areanames{en}->{61268033} = "Bruie\ Plains";
$areanames{en}->{61268034} = "Buckinguy";
$areanames{en}->{61268035} = "Carinda";
$areanames{en}->{61268036} = "Coalbaggie";
$areanames{en}->{61268037} = "Cobar";
$areanames{en}->{61268038} = "Colane";
$areanames{en}->{61268039} = "Collie";
$areanames{en}->{61268040} = "Condobolin";
$areanames{en}->{61268041} = "Coolabah";
$areanames{en}->{61268042} = "Coonabarabran";
$areanames{en}->{61268043} = "Coonamble";
$areanames{en}->{61268044} = "Cumborah";
$areanames{en}->{61268045} = "Curban";
$areanames{en}->{61268046} = "Cuttaburra";
$areanames{en}->{61268047} = "Dandaloo";
$areanames{en}->{61268048} = "Double\ Peaks";
$areanames{en}->{61268049} = "Dubbo";
$areanames{en}->{61268050} = "Eugowra";
$areanames{en}->{61268051} = "Fairholme";
$areanames{en}->{61268052} = "Farrendale";
$areanames{en}->{61268053} = "Forbes";
$areanames{en}->{61268054} = "Geurie";
$areanames{en}->{61268055} = "Gilgandra";
$areanames{en}->{61268056} = "Gilgooma";
$areanames{en}->{61268057} = "Ginghet";
$areanames{en}->{61268058} = "Girilambone";
$areanames{en}->{61268059} = "Gollan";
$areanames{en}->{61268060} = "Goodooga";
$areanames{en}->{61268061} = "Goorianawa";
$areanames{en}->{61268062} = "Grawin";
$areanames{en}->{61268063} = "Gulargambone";
$areanames{en}->{61268064} = "Gwabegar";
$areanames{en}->{61268065} = "Hermidale";
$areanames{en}->{61268066} = "Kiacatoo";
$areanames{en}->{61268067} = "Lake\ Cargelligo";
$areanames{en}->{61268068} = "Lightning\ Ridge";
$areanames{en}->{61268069} = "Magometon";
$areanames{en}->{61268070} = "Mandagery";
$areanames{en}->{61268071} = "Mendooran";
$areanames{en}->{61268072} = "Mount\ Foster";
$areanames{en}->{61268073} = "Mount\ Herring";
$areanames{en}->{61268074} = "Mullengudgery";
$areanames{en}->{61268075} = "Mungery";
$areanames{en}->{61268076} = "Myamley";
$areanames{en}->{61268077} = "Naradhan";
$areanames{en}->{61268078} = "Narran";
$areanames{en}->{61268079} = "Narromine";
$areanames{en}->{61268080} = "Barrier";
$areanames{en}->{612680801} = "Cobar";
$areanames{en}->{612680804} = "Barrier\/Cobar";
$areanames{en}->{612680809} = "Barrier\/Cobar";
$areanames{en}->{61268081} = "Barrinford";
$areanames{en}->{61268082} = "Bourke";
$areanames{en}->{61268083} = "Brewarrina";
$areanames{en}->{61268084} = "Cobar";
$areanames{en}->{61268085} = "Cuttaburra";
$areanames{en}->{61268086} = "Narran";
$areanames{en}->{61268087} = "Albert";
$areanames{en}->{61268088} = "Banar";
$areanames{en}->{61268089} = "Bobadah";
$areanames{en}->{61268090} = "Gollan";
$areanames{en}->{61268091} = "Stuart\ Town";
$areanames{en}->{61268092} = "Rocky\ Glen";
$areanames{en}->{61268093} = "Purlewaugh";
$areanames{en}->{61268094} = "Curban";
$areanames{en}->{61268095} = "Yarragrin";
$areanames{en}->{61268096} = "Dubbo";
$areanames{en}->{61268097} = "Dubbo";
$areanames{en}->{61268098} = "Dubbo";
$areanames{en}->{61268099} = "Dubbo";
$areanames{en}->{61268100} = "Neilrex";
$areanames{en}->{61268101} = "Nyngan";
$areanames{en}->{61268102} = "Parkes";
$areanames{en}->{61268103} = "Peak\ Hill";
$areanames{en}->{61268104} = "Purlewaugh";
$areanames{en}->{61268105} = "Quambone";
$areanames{en}->{61268106} = "Rocky\ Glen";
$areanames{en}->{61268107} = "Stuart\ Town";
$areanames{en}->{61268108} = "Teridgerie";
$areanames{en}->{61268109} = "Tooraweenah";
$areanames{en}->{61268110} = "Tottenham";
$areanames{en}->{61268111} = "Trangie";
$areanames{en}->{61268112} = "Trundle";
$areanames{en}->{61268113} = "Tullamore";
$areanames{en}->{61268114} = "Tyrie";
$areanames{en}->{61268115} = "Walgett";
$areanames{en}->{61268116} = "Warren";
$areanames{en}->{61268117} = "Warrington";
$areanames{en}->{61268118} = "Warrumbungle";
$areanames{en}->{61268119} = "Weelong";
$areanames{en}->{61268120} = "Weetaliba";
$areanames{en}->{61268121} = "Wellington";
$areanames{en}->{61268122} = "Widgeland";
$areanames{en}->{61268123} = "Wirrinya";
$areanames{en}->{61268124} = "Wyanga";
$areanames{en}->{61268125} = "Yarrabandai";
$areanames{en}->{61268126} = "Yarragrin";
$areanames{en}->{61268127} = "Yeoval";
$areanames{en}->{61268128} = "Dubbo";
$areanames{en}->{61268129} = "Yeoval";
$areanames{en}->{61268130} = "Dubbo";
$areanames{en}->{61268131} = "Dubbo";
$areanames{en}->{61268132} = "Warren";
$areanames{en}->{61268133} = "Weetaliba";
$areanames{en}->{61268134} = "Wyanga";
$areanames{en}->{61268135} = "Yarragrin";
$areanames{en}->{61268136} = "Goorianawa";
$areanames{en}->{61268137} = "Gwabegar";
$areanames{en}->{61268138} = "Mendooran";
$areanames{en}->{61268139} = "Narromine";
$areanames{en}->{61268140} = "Neilrex";
$areanames{en}->{61268141} = "Purlewaugh";
$areanames{en}->{61268142} = "Rocky\ Glen";
$areanames{en}->{61268143} = "Tooraweenah";
$areanames{en}->{61268144} = "Collie";
$areanames{en}->{61268145} = "Coonabarabran";
$areanames{en}->{61268146} = "Curban";
$areanames{en}->{61268147} = "Dandaloo";
$areanames{en}->{61268148} = "Dubbo";
$areanames{en}->{61268149} = "Farrendale";
$areanames{en}->{61268150} = "Geurie";
$areanames{en}->{61268151} = "Gilgandra";
$areanames{en}->{61268152} = "Airlands";
$areanames{en}->{61268153} = "Balladoran";
$areanames{en}->{61268154} = "Ballimore";
$areanames{en}->{61268155} = "Baradine";
$areanames{en}->{61268156} = "Eugowra";
$areanames{en}->{61268157} = "Forbes";
$areanames{en}->{61268158} = "Lightning\ Ridge";
$areanames{en}->{61268159} = "Dubbo";
$areanames{en}->{61268160} = "Condobolin";
$areanames{en}->{61268161} = "Condobolin";
$areanames{en}->{61268162} = "Bruie\ Plains";
$areanames{en}->{61268163} = "Parkes";
$areanames{en}->{61268164} = "Parkes";
$areanames{en}->{61268165} = "Parkes";
$areanames{en}->{61268166} = "Walgett";
$areanames{en}->{61268167} = "Bonnay";
$areanames{en}->{61268168} = "Boorooma";
$areanames{en}->{61268169} = "Borah\ Tank";
$areanames{en}->{61268170} = "Berkley\ Downs";
$areanames{en}->{61268171} = "Bogan\ Gate";
$areanames{en}->{61268172} = "Bruie\ Plains";
$areanames{en}->{61268173} = "Mandagery";
$areanames{en}->{61268174} = "Mungery";
$areanames{en}->{61268175} = "Parkes";
$areanames{en}->{61268176} = "Peak\ Hill";
$areanames{en}->{61268177} = "Gulargambone";
$areanames{en}->{61268178} = "Gilgandra";
$areanames{en}->{61268179} = "Walgett";
$areanames{en}->{61268180} = "Bogan\ Gate";
$areanames{en}->{61268181} = "Bruie\ Plains";
$areanames{en}->{61268182} = "Mandagery";
$areanames{en}->{61268183} = "Mungery";
$areanames{en}->{61268184} = "Parkes";
$areanames{en}->{61268185} = "Peak\ Hill";
$areanames{en}->{61268186} = "Yarrabandai";
$areanames{en}->{61268187} = "Gollan";
$areanames{en}->{61268188} = "Stuart\ Town";
$areanames{en}->{61268189} = "Wellington";
$areanames{en}->{61268190} = "Colane";
$areanames{en}->{61268191} = "Coolabah";
$areanames{en}->{61268192} = "Girilambone";
$areanames{en}->{61268193} = "Hermidale";
$areanames{en}->{61268194} = "Mount\ Foster";
$areanames{en}->{61268195} = "Mullengudgery";
$areanames{en}->{61268196} = "Nyngan";
$areanames{en}->{61268197} = "Widgeland";
$areanames{en}->{61268198} = "Alectown";
$areanames{en}->{61268199} = "Bindogundra";
$areanames{en}->{61268200} = "Buckinguy";
$areanames{en}->{61268201} = "Borah\ Tank";
$areanames{en}->{61268202} = "Bonnay";
$areanames{en}->{61268203} = "Walgett";
$areanames{en}->{61268204} = "Berkley\ Downs";
$areanames{en}->{61268205} = "Lightning\ Ridge";
$areanames{en}->{61268206} = "Goodooga";
$areanames{en}->{61268207} = "Grawin";
$areanames{en}->{61268208} = "Cumborah";
$areanames{en}->{61268209} = "Boorooma";
$areanames{en}->{61268210} = "Boona\ Mountain";
$areanames{en}->{61268211} = "Condobolin";
$areanames{en}->{61268212} = "Double\ Peaks";
$areanames{en}->{61268213} = "Fairholme";
$areanames{en}->{61268214} = "Kiacatoo";
$areanames{en}->{61268215} = "Lake\ Cargelligo";
$areanames{en}->{61268216} = "Mount\ Herring";
$areanames{en}->{61268217} = "Myamley";
$areanames{en}->{61268218} = "Naradhan";
$areanames{en}->{61268219} = "Tottenham";
$areanames{en}->{6126822} = "Coonamble";
$areanames{en}->{61268230} = "Quambone";
$areanames{en}->{61268231} = "Buckinguy";
$areanames{en}->{61268232} = "Carinda";
$areanames{en}->{61268233} = "Carinda";
$areanames{en}->{61268234} = "Warrington";
$areanames{en}->{61268235} = "Teridgerie";
$areanames{en}->{61268236} = "Carinda";
$areanames{en}->{61268237} = "Carinda";
$areanames{en}->{61268238} = "Gilgooma";
$areanames{en}->{61268239} = "Gilgooma";
$areanames{en}->{61268240} = "Quambone";
$areanames{en}->{61268241} = "Quambone";
$areanames{en}->{61268242} = "Quambone";
$areanames{en}->{61268243} = "Warrington";
$areanames{en}->{61268244} = "Buckinguy";
$areanames{en}->{61268245} = "Buckinguy";
$areanames{en}->{61268246} = "Ginghet";
$areanames{en}->{61268247} = "Grawin";
$areanames{en}->{61268248} = "Lightning\ Ridge";
$areanames{en}->{61268249} = "Walgett";
$areanames{en}->{61268250} = "Gulargambone";
$areanames{en}->{61268251} = "Gulargambone";
$areanames{en}->{61268252} = "Warrumbungle";
$areanames{en}->{61268253} = "Warrumbungle";
$areanames{en}->{61268254} = "Warrumbungle";
$areanames{en}->{61268255} = "Magometon";
$areanames{en}->{61268256} = "Magometon";
$areanames{en}->{61268257} = "Magometon";
$areanames{en}->{61268258} = "Magometon";
$areanames{en}->{61268259} = "Magometon";
$areanames{en}->{61268260} = "Neilrex";
$areanames{en}->{61268261} = "Narromine";
$areanames{en}->{61268262} = "Farrendale";
$areanames{en}->{61268263} = "Wyanga";
$areanames{en}->{61268264} = "Narromine";
$areanames{en}->{61268265} = "Dubbo";
$areanames{en}->{61268266} = "Coonabarabran";
$areanames{en}->{61268267} = "Dubbo";
$areanames{en}->{61268268} = "Dubbo";
$areanames{en}->{61268269} = "Dubbo";
$areanames{en}->{61268270} = "Warrington";
$areanames{en}->{61268271} = "Coonamble";
$areanames{en}->{61268272} = "Carinda";
$areanames{en}->{61268273} = "Gilgooma";
$areanames{en}->{61268274} = "Gulargambone";
$areanames{en}->{61268275} = "Magometon";
$areanames{en}->{61268276} = "Quambone";
$areanames{en}->{61268277} = "Teridgerie";
$areanames{en}->{61268278} = "Warrumbungle";
$areanames{en}->{61268279} = "Ginghet";
$areanames{en}->{61268280} = "Walgett";
$areanames{en}->{61268281} = "Walgett";
$areanames{en}->{61268282} = "Walgett";
$areanames{en}->{61268283} = "Walgett";
$areanames{en}->{61268284} = "Bonnay";
$areanames{en}->{61268285} = "Berkley\ Downs";
$areanames{en}->{61268286} = "Walgett";
$areanames{en}->{61268287} = "Borah\ Tank";
$areanames{en}->{61268288} = "Cumborah";
$areanames{en}->{61268289} = "Boorooma";
$areanames{en}->{6126829} = "Lightning\ Ridge";
$areanames{en}->{61268293} = "Grawin";
$areanames{en}->{61268295} = "Goodooga";
$areanames{en}->{61268296} = "Goodooga";
$areanames{en}->{61268297} = "Goodooga";
$areanames{en}->{61268300} = "Bourke";
$areanames{en}->{61268301} = "Bourke";
$areanames{en}->{61268302} = "Cobar";
$areanames{en}->{61268303} = "Trundle";
$areanames{en}->{61268304} = "Narran";
$areanames{en}->{61268305} = "Brewarrina";
$areanames{en}->{61268306} = "Cuttaburra";
$areanames{en}->{61268307} = "Cuttaburra";
$areanames{en}->{61268308} = "Bourke";
$areanames{en}->{61268309} = "Cobar";
$areanames{en}->{61268310} = "Nyngan";
$areanames{en}->{61268311} = "Nyngan";
$areanames{en}->{61268312} = "Tullamore";
$areanames{en}->{61268313} = "Buckinguy";
$areanames{en}->{61268314} = "Carinda";
$areanames{en}->{61268315} = "Coonamble";
$areanames{en}->{61268316} = "Gilgooma";
$areanames{en}->{61268317} = "Ginghet";
$areanames{en}->{61268318} = "Gulargambone";
$areanames{en}->{61268319} = "Magometon";
$areanames{en}->{6126832} = "Nyngan";
$areanames{en}->{61268330} = "Hermidale";
$areanames{en}->{61268331} = "Girilambone";
$areanames{en}->{61268332} = "Mount\ Foster\/Coolabah";
$areanames{en}->{612683320} = "Mount\ Foster";
$areanames{en}->{612683321} = "Coolabah";
$areanames{en}->{61268333} = "Coolabah";
$areanames{en}->{61268334} = "Widgeland";
$areanames{en}->{61268335} = "Mount\ Foster";
$areanames{en}->{61268336} = "Hermidale";
$areanames{en}->{61268337} = "Colane";
$areanames{en}->{61268338} = "Buckinguy";
$areanames{en}->{61268339} = "Mullengudgery";
$areanames{en}->{61268340} = "Quambone";
$areanames{en}->{61268341} = "Teridgerie";
$areanames{en}->{61268342} = "Warrington";
$areanames{en}->{61268343} = "Warrumbungle";
$areanames{en}->{61268344} = "Airlands";
$areanames{en}->{61268345} = "Balladoran";
$areanames{en}->{61268346} = "Ballimore";
$areanames{en}->{61268347} = "Walgett";
$areanames{en}->{61268348} = "Dubbo";
$areanames{en}->{61268349} = "Dubbo";
$areanames{en}->{61268350} = "Nyngan";
$areanames{en}->{61268351} = "Nyngan";
$areanames{en}->{61268352} = "Hermidale";
$areanames{en}->{61268353} = "Widgeland";
$areanames{en}->{61268354} = "Coolabah";
$areanames{en}->{61268355} = "Girilambone";
$areanames{en}->{61268356} = "Mount\ Foster";
$areanames{en}->{61268357} = "Colane";
$areanames{en}->{61268358} = "Mullengudgery";
$areanames{en}->{61268359} = "Nyngan";
$areanames{en}->{612683600} = "Collie";
$areanames{en}->{612683601} = "Collie";
$areanames{en}->{612683602} = "Collie";
$areanames{en}->{612683603} = "Collie";
$areanames{en}->{612683606} = "Collie";
$areanames{en}->{61268361} = "Cobar";
$areanames{en}->{61268362} = "Cobar";
$areanames{en}->{61268363} = "Cobar";
$areanames{en}->{61268364} = "Cobar";
$areanames{en}->{61268365} = "Cobar";
$areanames{en}->{61268366} = "Cobar";
$areanames{en}->{61268367} = "Cobar";
$areanames{en}->{612683680} = "Coonabarabran";
$areanames{en}->{612683681} = "Coonabarabran";
$areanames{en}->{612683682} = "Coonabarabran";
$areanames{en}->{612683683} = "Coonabarabran";
$areanames{en}->{612683684} = "Coonabarabran";
$areanames{en}->{612683685} = "Coonabarabran";
$areanames{en}->{612683686} = "Coonabarabran";
$areanames{en}->{612683687} = "Coonabarabran";
$areanames{en}->{612683690} = "Curban";
$areanames{en}->{612683691} = "Curban";
$areanames{en}->{612683692} = "Curban";
$areanames{en}->{612683693} = "Curban";
$areanames{en}->{612683696} = "Curban";
$areanames{en}->{612683700} = "Dandaloo";
$areanames{en}->{612683701} = "Dandaloo";
$areanames{en}->{612683702} = "Dandaloo";
$areanames{en}->{612683703} = "Dandaloo";
$areanames{en}->{612683706} = "Dandaloo";
$areanames{en}->{612683710} = "Dubbo";
$areanames{en}->{612683711} = "Dubbo";
$areanames{en}->{612683712} = "Dubbo";
$areanames{en}->{612683713} = "Dubbo";
$areanames{en}->{612683714} = "Dubbo";
$areanames{en}->{612683720} = "Farrendale";
$areanames{en}->{612683721} = "Farrendale";
$areanames{en}->{612683722} = "Farrendale";
$areanames{en}->{612683723} = "Farrendale";
$areanames{en}->{612683726} = "Farrendale";
$areanames{en}->{61268373} = "Barrier";
$areanames{en}->{612683740} = "Geurie";
$areanames{en}->{612683741} = "Geurie";
$areanames{en}->{612683742} = "Geurie";
$areanames{en}->{612683743} = "Geurie";
$areanames{en}->{612683746} = "Geurie";
$areanames{en}->{612683750} = "Gilgandra";
$areanames{en}->{612683751} = "Gilgandra";
$areanames{en}->{612683752} = "Gilgandra";
$areanames{en}->{612683753} = "Gilgandra";
$areanames{en}->{612683754} = "Gilgandra";
$areanames{en}->{612683755} = "Gilgandra";
$areanames{en}->{612683756} = "Gilgandra";
$areanames{en}->{612683757} = "Gilgandra";
$areanames{en}->{612683760} = "Goorianawa";
$areanames{en}->{612683761} = "Goorianawa";
$areanames{en}->{612683762} = "Goorianawa";
$areanames{en}->{612683763} = "Goorianawa";
$areanames{en}->{612683766} = "Goorianawa";
$areanames{en}->{612683770} = "Gwabegar";
$areanames{en}->{612683771} = "Gwabegar";
$areanames{en}->{612683772} = "Gwabegar";
$areanames{en}->{612683773} = "Gwabegar";
$areanames{en}->{612683776} = "Gwabegar";
$areanames{en}->{612683780} = "Mendooran";
$areanames{en}->{612683781} = "Mendooran";
$areanames{en}->{612683782} = "Mendooran";
$areanames{en}->{612683783} = "Mendooran";
$areanames{en}->{612683786} = "Mendooran";
$areanames{en}->{612683790} = "Narromine";
$areanames{en}->{612683791} = "Narromine";
$areanames{en}->{612683792} = "Narromine";
$areanames{en}->{612683793} = "Narromine";
$areanames{en}->{612683796} = "Narromine";
$areanames{en}->{61268380} = "Coolabah";
$areanames{en}->{61268381} = "Girilambone";
$areanames{en}->{61268382} = "Girilambone";
$areanames{en}->{61268383} = "Colane";
$areanames{en}->{61268384} = "Mullengudgery";
$areanames{en}->{61268385} = "Bonnay";
$areanames{en}->{61268386} = "Boorooma";
$areanames{en}->{61268387} = "Borah\ Tank";
$areanames{en}->{61268388} = "Cumborah";
$areanames{en}->{61268389} = "Goodooga";
$areanames{en}->{61268390} = "Brewarrina";
$areanames{en}->{61268391} = "Brewarrina";
$areanames{en}->{61268392} = "Brewarrina";
$areanames{en}->{61268393} = "Brewarrina";
$areanames{en}->{612683940} = "Neilrex";
$areanames{en}->{612683941} = "Neilrex";
$areanames{en}->{612683942} = "Neilrex";
$areanames{en}->{612683943} = "Neilrex";
$areanames{en}->{612683946} = "Neilrex";
$areanames{en}->{612683950} = "Purlewaugh";
$areanames{en}->{612683951} = "Purlewaugh";
$areanames{en}->{612683952} = "Purlewaugh";
$areanames{en}->{612683953} = "Purlewaugh";
$areanames{en}->{612683956} = "Purlewaugh";
$areanames{en}->{612683960} = "Rocky\ Glen";
$areanames{en}->{612683961} = "Rocky\ Glen";
$areanames{en}->{612683962} = "Rocky\ Glen";
$areanames{en}->{612683963} = "Rocky\ Glen";
$areanames{en}->{612683966} = "Rocky\ Glen";
$areanames{en}->{61268397} = "Narran";
$areanames{en}->{61268398} = "Narran";
$areanames{en}->{61268399} = "Narran";
$areanames{en}->{6126840} = "Wellington";
$areanames{en}->{61268403} = "Gollan";
$areanames{en}->{61268404} = "Stuart\ Town";
$areanames{en}->{61268405} = "Yeoval";
$areanames{en}->{6126841} = "Dubbo";
$areanames{en}->{6126842} = "Coonabarabran";
$areanames{en}->{61268428} = "Purlewaugh";
$areanames{en}->{61268429} = "Rocky\ Glen";
$areanames{en}->{61268430} = "Baradine";
$areanames{en}->{61268431} = "Baradine";
$areanames{en}->{612684320} = "Tooraweenah";
$areanames{en}->{612684321} = "Tooraweenah";
$areanames{en}->{612684322} = "Tooraweenah";
$areanames{en}->{612684323} = "Tooraweenah";
$areanames{en}->{612684326} = "Tooraweenah";
$areanames{en}->{612684330} = "Trangie";
$areanames{en}->{612684331} = "Trangie";
$areanames{en}->{612684332} = "Trangie";
$areanames{en}->{612684333} = "Trangie";
$areanames{en}->{612684336} = "Trangie";
$areanames{en}->{612684338} = "Trangie";
$areanames{en}->{61268434} = "Baradine";
$areanames{en}->{61268435} = "Airlands";
$areanames{en}->{61268436} = "Gwabegar";
$areanames{en}->{61268437} = "Goorianawa";
$areanames{en}->{61268438} = "Goorianawa";
$areanames{en}->{61268439} = "Goorianawa";
$areanames{en}->{6126844} = "Binnaway";
$areanames{en}->{61268446} = "Weetaliba";
$areanames{en}->{61268447} = "Weetaliba";
$areanames{en}->{61268448} = "Weetaliba";
$areanames{en}->{61268449} = "Weetaliba";
$areanames{en}->{61268450} = "Wellington";
$areanames{en}->{61268451} = "Wellington";
$areanames{en}->{61268452} = "Wellington";
$areanames{en}->{61268453} = "Wellington";
$areanames{en}->{61268454} = "Wellington";
$areanames{en}->{61268455} = "Wellington";
$areanames{en}->{612684560} = "Tyrie";
$areanames{en}->{612684563} = "Tyrie";
$areanames{en}->{612684564} = "Tyrie";
$areanames{en}->{612684565} = "Tyrie";
$areanames{en}->{612684566} = "Tyrie";
$areanames{en}->{612684568} = "Tyrie";
$areanames{en}->{612684570} = "Warren";
$areanames{en}->{612684571} = "Warren";
$areanames{en}->{612684572} = "Warren";
$areanames{en}->{612684573} = "Warren";
$areanames{en}->{612684576} = "Warren";
$areanames{en}->{612684580} = "Weetaliba";
$areanames{en}->{612684581} = "Weetaliba";
$areanames{en}->{612684582} = "Weetaliba";
$areanames{en}->{612684583} = "Weetaliba";
$areanames{en}->{612684586} = "Weetaliba";
$areanames{en}->{61268459} = "Wellington";
$areanames{en}->{61268460} = "Wellington";
$areanames{en}->{61268461} = "Wellington";
$areanames{en}->{61268462} = "Wellington";
$areanames{en}->{61268463} = "Wellington";
$areanames{en}->{61268464} = "Yeoval";
$areanames{en}->{61268465} = "Yeoval";
$areanames{en}->{61268466} = "Gollan";
$areanames{en}->{61268467} = "Stuart\ Town";
$areanames{en}->{61268468} = "Stuart\ Town";
$areanames{en}->{61268469} = "Stuart\ Town";
$areanames{en}->{61268470} = "Gilgandra";
$areanames{en}->{61268471} = "Gilgandra";
$areanames{en}->{61268472} = "Gilgandra";
$areanames{en}->{61268473} = "Warren";
$areanames{en}->{61268474} = "Warren";
$areanames{en}->{61268475} = "Warren";
$areanames{en}->{61268476} = "Warren";
$areanames{en}->{61268477} = "Warren";
$areanames{en}->{61268478} = "Gilgandra";
$areanames{en}->{61268479} = "Collie";
$areanames{en}->{61268480} = "Collie";
$areanames{en}->{61268481} = "Tooraweenah";
$areanames{en}->{61268482} = "Tooraweenah";
$areanames{en}->{61268483} = "Tooraweenah";
$areanames{en}->{61268484} = "Tooraweenah";
$areanames{en}->{61268485} = "Curban";
$areanames{en}->{61268486} = "Curban";
$areanames{en}->{61268487} = "Curban";
$areanames{en}->{61268488} = "Yarragrin";
$areanames{en}->{61268489} = "Yarragrin";
$areanames{en}->{612684900} = "Wyanga";
$areanames{en}->{612684901} = "Wyanga";
$areanames{en}->{612684902} = "Wyanga";
$areanames{en}->{612684903} = "Wyanga";
$areanames{en}->{612684906} = "Wyanga";
$areanames{en}->{61268491} = "Coonabarabran";
$areanames{en}->{61268492} = "Coonabarabran";
$areanames{en}->{612684930} = "Yarragrin";
$areanames{en}->{612684931} = "Yarragrin";
$areanames{en}->{612684932} = "Yarragrin";
$areanames{en}->{612684933} = "Yarragrin";
$areanames{en}->{612684936} = "Yarragrin";
$areanames{en}->{61268494} = "Binnaway";
$areanames{en}->{61268495} = "Goorianawa";
$areanames{en}->{61268496} = "Gwabegar";
$areanames{en}->{61268497} = "Purlewaugh";
$areanames{en}->{61268498} = "Rocky\ Glen";
$areanames{en}->{61268499} = "Weetaliba";
$areanames{en}->{6126850} = "Forbes";
$areanames{en}->{61268503} = "Bedgerebong";
$areanames{en}->{61268504} = "Eugowra";
$areanames{en}->{61268505} = "Weelong";
$areanames{en}->{61268506} = "Wirrinya";
$areanames{en}->{6126851} = "Forbes";
$areanames{en}->{6126852} = "Forbes";
$areanames{en}->{6126853} = "Forbes";
$areanames{en}->{61268540} = "Warren";
$areanames{en}->{61268541} = "Weetaliba";
$areanames{en}->{61268542} = "Wyanga";
$areanames{en}->{61268543} = "Yarragrin";
$areanames{en}->{61268544} = "Bedgerebong";
$areanames{en}->{61268545} = "Eugowra";
$areanames{en}->{61268546} = "Forbes";
$areanames{en}->{61268547} = "Weelong";
$areanames{en}->{61268548} = "Wirrinya";
$areanames{en}->{61268549} = "Berkley\ Downs";
$areanames{en}->{61268550} = "Wirrinya";
$areanames{en}->{61268551} = "Wirrinya";
$areanames{en}->{61268552} = "Wirrinya";
$areanames{en}->{61268553} = "Wirrinya";
$areanames{en}->{612685540} = "Bedgerebong";
$areanames{en}->{612685541} = "Bedgerebong";
$areanames{en}->{612685542} = "Bedgerebong";
$areanames{en}->{612685543} = "Bedgerebong";
$areanames{en}->{612685546} = "Bedgerebong";
$areanames{en}->{612685548} = "Bedgerebong";
$areanames{en}->{612685550} = "Eugowra";
$areanames{en}->{612685551} = "Eugowra";
$areanames{en}->{612685552} = "Eugowra";
$areanames{en}->{612685553} = "Eugowra";
$areanames{en}->{612685556} = "Eugowra";
$areanames{en}->{612685560} = "Forbes";
$areanames{en}->{612685561} = "Forbes";
$areanames{en}->{612685562} = "Forbes";
$areanames{en}->{612685563} = "Forbes";
$areanames{en}->{612685566} = "Forbes";
$areanames{en}->{612685570} = "Weelong";
$areanames{en}->{612685573} = "Weelong";
$areanames{en}->{612685574} = "Weelong";
$areanames{en}->{612685575} = "Weelong";
$areanames{en}->{612685576} = "Weelong";
$areanames{en}->{612685578} = "Weelong";
$areanames{en}->{612685580} = "Wirrinya";
$areanames{en}->{612685583} = "Wirrinya";
$areanames{en}->{612685584} = "Wirrinya";
$areanames{en}->{612685585} = "Wirrinya";
$areanames{en}->{612685586} = "Wirrinya";
$areanames{en}->{612685588} = "Wirrinya";
$areanames{en}->{612685590} = "Berkley\ Downs";
$areanames{en}->{612685591} = "Berkley\ Downs";
$areanames{en}->{612685592} = "Berkley\ Downs";
$areanames{en}->{612685593} = "Berkley\ Downs";
$areanames{en}->{612685596} = "Berkley\ Downs";
$areanames{en}->{61268560} = "Weelong";
$areanames{en}->{61268561} = "Weelong";
$areanames{en}->{61268562} = "Weelong";
$areanames{en}->{61268563} = "Weelong";
$areanames{en}->{612685640} = "Bonnay";
$areanames{en}->{612685641} = "Bonnay";
$areanames{en}->{612685642} = "Bonnay";
$areanames{en}->{612685643} = "Bonnay";
$areanames{en}->{612685646} = "Bonnay";
$areanames{en}->{612685650} = "Boorooma";
$areanames{en}->{612685651} = "Boorooma";
$areanames{en}->{612685652} = "Boorooma";
$areanames{en}->{612685653} = "Boorooma";
$areanames{en}->{612685656} = "Boorooma";
$areanames{en}->{612685660} = "Borah\ Tank";
$areanames{en}->{612685661} = "Borah\ Tank";
$areanames{en}->{612685662} = "Borah\ Tank";
$areanames{en}->{612685663} = "Borah\ Tank";
$areanames{en}->{612685666} = "Borah\ Tank";
$areanames{en}->{612685670} = "Cumborah";
$areanames{en}->{612685671} = "Cumborah";
$areanames{en}->{612685672} = "Cumborah";
$areanames{en}->{612685673} = "Cumborah";
$areanames{en}->{612685674} = "Cumborah";
$areanames{en}->{612685675} = "Cumborah";
$areanames{en}->{612685676} = "Cumborah";
$areanames{en}->{612685677} = "Cumborah";
$areanames{en}->{612685678} = "Cumborah";
$areanames{en}->{612685680} = "Goodooga";
$areanames{en}->{612685683} = "Goodooga";
$areanames{en}->{612685684} = "Goodooga";
$areanames{en}->{612685685} = "Goodooga";
$areanames{en}->{612685686} = "Goodooga";
$areanames{en}->{612685688} = "Goodooga";
$areanames{en}->{612685690} = "Grawin";
$areanames{en}->{612685691} = "Grawin";
$areanames{en}->{612685692} = "Grawin";
$areanames{en}->{612685693} = "Grawin";
$areanames{en}->{612685696} = "Grawin";
$areanames{en}->{612685698} = "Grawin";
$areanames{en}->{61268570} = "Bedgerebong";
$areanames{en}->{61268571} = "Bedgerebong";
$areanames{en}->{61268572} = "Bedgerebong";
$areanames{en}->{61268573} = "Bedgerebong";
$areanames{en}->{61268574} = "Bedgerebong";
$areanames{en}->{61268575} = "Bedgerebong";
$areanames{en}->{61268576} = "Bedgerebong";
$areanames{en}->{612685770} = "Lightning\ Ridge";
$areanames{en}->{612685771} = "Lightning\ Ridge";
$areanames{en}->{612685772} = "Lightning\ Ridge";
$areanames{en}->{612685773} = "Lightning\ Ridge";
$areanames{en}->{612685774} = "Lightning\ Ridge";
$areanames{en}->{612685775} = "Lightning\ Ridge";
$areanames{en}->{612685776} = "Lightning\ Ridge";
$areanames{en}->{612685777} = "Lightning\ Ridge";
$areanames{en}->{612685780} = "Walgett";
$areanames{en}->{612685781} = "Walgett";
$areanames{en}->{612685782} = "Walgett";
$areanames{en}->{612685783} = "Walgett";
$areanames{en}->{612685786} = "Walgett";
$areanames{en}->{612685790} = "Colane";
$areanames{en}->{612685793} = "Colane";
$areanames{en}->{612685794} = "Colane";
$areanames{en}->{612685795} = "Colane";
$areanames{en}->{612685796} = "Colane";
$areanames{en}->{612685798} = "Colane";
$areanames{en}->{612685800} = "Coolabah";
$areanames{en}->{612685803} = "Coolabah";
$areanames{en}->{612685804} = "Coolabah";
$areanames{en}->{612685805} = "Coolabah";
$areanames{en}->{612685806} = "Coolabah";
$areanames{en}->{612685808} = "Coolabah";
$areanames{en}->{612685810} = "Girilambone";
$areanames{en}->{612685813} = "Girilambone";
$areanames{en}->{612685814} = "Girilambone";
$areanames{en}->{612685815} = "Girilambone";
$areanames{en}->{612685816} = "Girilambone";
$areanames{en}->{612685818} = "Girilambone";
$areanames{en}->{612685820} = "Hermidale";
$areanames{en}->{612685823} = "Hermidale";
$areanames{en}->{612685824} = "Hermidale";
$areanames{en}->{612685825} = "Hermidale";
$areanames{en}->{612685826} = "Hermidale";
$areanames{en}->{612685828} = "Hermidale";
$areanames{en}->{612685830} = "Mount\ Foster";
$areanames{en}->{612685833} = "Mount\ Foster";
$areanames{en}->{612685834} = "Mount\ Foster";
$areanames{en}->{612685835} = "Mount\ Foster";
$areanames{en}->{612685836} = "Mount\ Foster";
$areanames{en}->{612685838} = "Mount\ Foster";
$areanames{en}->{612685840} = "Mullengudgery";
$areanames{en}->{612685843} = "Mullengudgery";
$areanames{en}->{612685844} = "Mullengudgery";
$areanames{en}->{612685845} = "Mullengudgery";
$areanames{en}->{612685846} = "Mullengudgery";
$areanames{en}->{612685848} = "Mullengudgery";
$areanames{en}->{612685850} = "Nyngan";
$areanames{en}->{612685851} = "Nyngan";
$areanames{en}->{612685852} = "Nyngan";
$areanames{en}->{612685853} = "Nyngan";
$areanames{en}->{612685856} = "Nyngan";
$areanames{en}->{612685858} = "Nyngan";
$areanames{en}->{612685860} = "Widgeland";
$areanames{en}->{612685863} = "Widgeland";
$areanames{en}->{612685864} = "Widgeland";
$areanames{en}->{612685865} = "Widgeland";
$areanames{en}->{612685866} = "Widgeland";
$areanames{en}->{612685868} = "Widgeland";
$areanames{en}->{612685870} = "Alectown";
$areanames{en}->{612685873} = "Alectown";
$areanames{en}->{612685874} = "Alectown";
$areanames{en}->{612685875} = "Alectown";
$areanames{en}->{612685876} = "Alectown";
$areanames{en}->{612685878} = "Alectown";
$areanames{en}->{612685880} = "Bindogundra";
$areanames{en}->{612685883} = "Bindogundra";
$areanames{en}->{612685884} = "Bindogundra";
$areanames{en}->{612685885} = "Bindogundra";
$areanames{en}->{612685886} = "Bindogundra";
$areanames{en}->{612685888} = "Bindogundra";
$areanames{en}->{612685890} = "Bogan\ Gate";
$areanames{en}->{612685891} = "Bogan\ Gate";
$areanames{en}->{612685892} = "Bogan\ Gate";
$areanames{en}->{612685893} = "Bogan\ Gate";
$areanames{en}->{612685896} = "Bogan\ Gate";
$areanames{en}->{6126859} = "Eugowra";
$areanames{en}->{61268600} = "Goorianawa";
$areanames{en}->{61268601} = "Gwabegar";
$areanames{en}->{61268602} = "Mendooran";
$areanames{en}->{61268603} = "Narromine";
$areanames{en}->{61268604} = "Neilrex";
$areanames{en}->{61268605} = "Purlewaugh";
$areanames{en}->{61268606} = "Rocky\ Glen";
$areanames{en}->{61268607} = "Tooraweenah";
$areanames{en}->{61268608} = "Trangie";
$areanames{en}->{61268609} = "Tyrie";
$areanames{en}->{61268610} = "Bruie\ Plains";
$areanames{en}->{61268611} = "Parkes";
$areanames{en}->{61268612} = "Parkes";
$areanames{en}->{61268613} = "Alectown";
$areanames{en}->{61268614} = "Bindogundra";
$areanames{en}->{61268615} = "Bogan\ Gate";
$areanames{en}->{61268616} = "Mandagery";
$areanames{en}->{61268617} = "Peak\ Hill";
$areanames{en}->{61268618} = "Yarrabandai";
$areanames{en}->{61268619} = "Mungery";
$areanames{en}->{6126862} = "Parkes";
$areanames{en}->{6126863} = "Parkes";
$areanames{en}->{6126864} = "Bogan\ Gate";
$areanames{en}->{61268642} = "Yarrabandai";
$areanames{en}->{61268650} = "Bruie\ Plains";
$areanames{en}->{61268651} = "Mandagery";
$areanames{en}->{61268652} = "Alectown";
$areanames{en}->{61268653} = "Alectown";
$areanames{en}->{61268654} = "Mungery";
$areanames{en}->{61268655} = "Parkes";
$areanames{en}->{61268656} = "Peak\ Hill";
$areanames{en}->{61268657} = "Yarrabandai";
$areanames{en}->{61268658} = "Gollan";
$areanames{en}->{61268659} = "Stuart\ Town";
$areanames{en}->{61268660} = "Mandagery";
$areanames{en}->{61268661} = "Mandagery";
$areanames{en}->{61268662} = "Bindogundra";
$areanames{en}->{61268663} = "Bindogundra";
$areanames{en}->{61268664} = "Bindogundra";
$areanames{en}->{61268665} = "Wellington";
$areanames{en}->{61268666} = "Yeoval";
$areanames{en}->{61268667} = "Baradine";
$areanames{en}->{61268668} = "Binnaway";
$areanames{en}->{61268669} = "Coalbaggie";
$areanames{en}->{61268670} = "Mandagery";
$areanames{en}->{61268671} = "Mandagery";
$areanames{en}->{61268672} = "Dubbo";
$areanames{en}->{61268673} = "Dubbo";
$areanames{en}->{61268674} = "Dubbo";
$areanames{en}->{61268675} = "Berkley\ Downs";
$areanames{en}->{61268676} = "Berkley\ Downs";
$areanames{en}->{61268677} = "Bourke";
$areanames{en}->{61268678} = "Bourke";
$areanames{en}->{61268679} = "Dubbo";
$areanames{en}->{61268680} = "Yarrabandai";
$areanames{en}->{61268681} = "Yarrabandai";
$areanames{en}->{61268682} = "Cobar";
$areanames{en}->{61268683} = "Cobar";
$areanames{en}->{61268684} = "Lake\ Cargelligo";
$areanames{en}->{61268685} = "Lake\ Cargelligo";
$areanames{en}->{61268686} = "Stuart\ Town";
$areanames{en}->{61268687} = "Stuart\ Town";
$areanames{en}->{61268688} = "Gilgandra";
$areanames{en}->{61268689} = "Gilgandra";
$areanames{en}->{6126869} = "Peak\ Hill";
$areanames{en}->{61268697} = "Mungery";
$areanames{en}->{61268698} = "Mungery";
$areanames{en}->{61268699} = "Bruie\ Plains";
$areanames{en}->{6126870} = "Bourke";
$areanames{en}->{61268710} = "Barrier";
$areanames{en}->{61268711} = "Barrinford";
$areanames{en}->{61268712} = "Bourke";
$areanames{en}->{61268713} = "Brewarrina";
$areanames{en}->{61268714} = "Cobar";
$areanames{en}->{61268715} = "Cuttaburra";
$areanames{en}->{61268716} = "Narran";
$areanames{en}->{61268717} = "Albert";
$areanames{en}->{61268718} = "Banar";
$areanames{en}->{61268719} = "Bobadah";
$areanames{en}->{61268720} = "Bourke";
$areanames{en}->{61268721} = "Bourke";
$areanames{en}->{61268722} = "Bourke";
$areanames{en}->{61268723} = "Bourke";
$areanames{en}->{61268724} = "Bourke";
$areanames{en}->{61268725} = "Cuttaburra";
$areanames{en}->{61268726} = "Cuttaburra";
$areanames{en}->{61268727} = "Cuttaburra";
$areanames{en}->{61268728} = "Cuttaburra";
$areanames{en}->{61268729} = "Cuttaburra";
$areanames{en}->{61268730} = "Boona\ Mountain";
$areanames{en}->{61268731} = "Condobolin";
$areanames{en}->{61268732} = "Double\ Peaks";
$areanames{en}->{61268733} = "Fairholme";
$areanames{en}->{61268734} = "Kiacatoo";
$areanames{en}->{61268735} = "Lake\ Cargelligo";
$areanames{en}->{61268736} = "Mount\ Herring";
$areanames{en}->{61268737} = "Myamley";
$areanames{en}->{61268738} = "Naradhan";
$areanames{en}->{61268739} = "Tottenham";
$areanames{en}->{6126874} = "Cuttaburra";
$areanames{en}->{61268744} = "Narran";
$areanames{en}->{61268745} = "Trundle";
$areanames{en}->{61268750} = "Binnaway";
$areanames{en}->{61268751} = "Coalbaggie";
$areanames{en}->{61268752} = "Collie";
$areanames{en}->{61268753} = "Coonabarabran";
$areanames{en}->{61268754} = "Curban";
$areanames{en}->{61268755} = "Dandaloo";
$areanames{en}->{61268756} = "Dubbo";
$areanames{en}->{61268757} = "Farrendale";
$areanames{en}->{61268758} = "Geurie";
$areanames{en}->{61268759} = "Gilgandra";
$areanames{en}->{61268760} = "Gulargambone";
$areanames{en}->{61268761} = "Magometon";
$areanames{en}->{61268762} = "Quambone";
$areanames{en}->{61268763} = "Teridgerie";
$areanames{en}->{61268764} = "Warrington";
$areanames{en}->{61268765} = "Warrumbungle";
$areanames{en}->{61268766} = "Airlands";
$areanames{en}->{61268767} = "Balladoran";
$areanames{en}->{61268768} = "Ballimore";
$areanames{en}->{61268769} = "Baradine";
$areanames{en}->{61268770} = "Myamley";
$areanames{en}->{61268771} = "Naradhan";
$areanames{en}->{61268772} = "Tottenham";
$areanames{en}->{61268773} = "Trundle";
$areanames{en}->{61268774} = "Tullamore";
$areanames{en}->{61268775} = "Buckinguy";
$areanames{en}->{61268776} = "Carinda";
$areanames{en}->{61268777} = "Coonamble";
$areanames{en}->{61268778} = "Gilgooma";
$areanames{en}->{61268779} = "Ginghet";
$areanames{en}->{61268780} = "Tullamore";
$areanames{en}->{61268781} = "Buckinguy";
$areanames{en}->{61268782} = "Carinda";
$areanames{en}->{61268783} = "Coonamble";
$areanames{en}->{61268784} = "Gilgooma";
$areanames{en}->{61268785} = "Ginghet";
$areanames{en}->{61268786} = "Gulargambone";
$areanames{en}->{61268787} = "Magometon";
$areanames{en}->{61268788} = "Quambone";
$areanames{en}->{61268789} = "Teridgerie";
$areanames{en}->{61268790} = "Boona\ Mountain";
$areanames{en}->{61268791} = "Condobolin";
$areanames{en}->{61268792} = "Double\ Peaks";
$areanames{en}->{61268793} = "Fairholme";
$areanames{en}->{61268794} = "Kiacatoo";
$areanames{en}->{61268795} = "Lake\ Cargelligo";
$areanames{en}->{61268796} = "Mount\ Herring";
$areanames{en}->{61268797} = "Cobar";
$areanames{en}->{61268798} = "Cobar";
$areanames{en}->{61268799} = "Cobar";
$areanames{en}->{61268800} = "Yarragrin";
$areanames{en}->{61268801} = "Curban";
$areanames{en}->{61268802} = "Ballimore";
$areanames{en}->{61268803} = "Warrington";
$areanames{en}->{61268804} = "Geurie";
$areanames{en}->{61268805} = "Gilgandra";
$areanames{en}->{61268806} = "Mendooran";
$areanames{en}->{61268807} = "Tooraweenah";
$areanames{en}->{61268808} = "Trangie";
$areanames{en}->{61268809} = "Tyrie";
$areanames{en}->{6126881} = "Dubbo";
$areanames{en}->{6126882} = "Dubbo";
$areanames{en}->{6126883} = "Dubbo";
$areanames{en}->{61268830} = "Dandaloo";
$areanames{en}->{61268837} = "Warren";
$areanames{en}->{61268838} = "Coalbaggie";
$areanames{en}->{61268839} = "Collie";
$areanames{en}->{6126884} = "Dubbo";
$areanames{en}->{6126885} = "Dubbo";
$areanames{en}->{61268860} = "Mendooran";
$areanames{en}->{61268861} = "Mendooran";
$areanames{en}->{61268862} = "Mendooran";
$areanames{en}->{61268863} = "Neilrex";
$areanames{en}->{61268864} = "Neilrex";
$areanames{en}->{61268865} = "Ballimore";
$areanames{en}->{61268866} = "Ballimore";
$areanames{en}->{61268867} = "Ballimore";
$areanames{en}->{61268868} = "Warrumbungle";
$areanames{en}->{61268869} = "Airlands";
$areanames{en}->{61268870} = "Geurie";
$areanames{en}->{61268871} = "Geurie";
$areanames{en}->{61268872} = "Dubbo";
$areanames{en}->{61268873} = "Dubbo";
$areanames{en}->{61268874} = "Dubbo";
$areanames{en}->{61268875} = "Dubbo";
$areanames{en}->{61268876} = "Coalbaggie";
$areanames{en}->{61268877} = "Geurie";
$areanames{en}->{61268878} = "Geurie";
$areanames{en}->{61268879} = "Coalbaggie";
$areanames{en}->{61268880} = "Balladoran";
$areanames{en}->{61268881} = "Balladoran";
$areanames{en}->{61268882} = "Ballimore";
$areanames{en}->{61268883} = "Tyrie";
$areanames{en}->{61268884} = "Dandaloo";
$areanames{en}->{61268885} = "Dubbo";
$areanames{en}->{61268886} = "Trangie";
$areanames{en}->{61268887} = "Trangie";
$areanames{en}->{61268888} = "Trangie";
$areanames{en}->{61268889} = "Trangie";
$areanames{en}->{6126889} = "Narromine";
$areanames{en}->{61268890} = "Farrendale";
$areanames{en}->{61268898} = "Wyanga";
$areanames{en}->{61268900} = "Naradhan";
$areanames{en}->{61268901} = "Condobolin";
$areanames{en}->{61268902} = "Baradine";
$areanames{en}->{61268903} = "Bobadah";
$areanames{en}->{61268904} = "Condobolin";
$areanames{en}->{61268905} = "Condobolin";
$areanames{en}->{61268906} = "Fairholme";
$areanames{en}->{61268907} = "Kiacatoo";
$areanames{en}->{61268908} = "Lake\ Cargelligo";
$areanames{en}->{61268909} = "Double\ Peaks";
$areanames{en}->{61268910} = "Condobolin";
$areanames{en}->{61268911} = "Mount\ Herring";
$areanames{en}->{61268912} = "Condobolin";
$areanames{en}->{61268913} = "Tullamore";
$areanames{en}->{61268914} = "Boona\ Mountain";
$areanames{en}->{61268915} = "Myamley";
$areanames{en}->{61268916} = "Tottenham";
$areanames{en}->{61268917} = "Trundle";
$areanames{en}->{61268918} = "Binnaway";
$areanames{en}->{61268919} = "Condobolin";
$areanames{en}->{61268920} = "Tullamore";
$areanames{en}->{61268921} = "Trundle";
$areanames{en}->{61268922} = "Trundle";
$areanames{en}->{61268923} = "Tullamore";
$areanames{en}->{61268924} = "Tottenham";
$areanames{en}->{61268925} = "Tullamore";
$areanames{en}->{61268926} = "Tullamore";
$areanames{en}->{61268927} = "Trundle";
$areanames{en}->{61268928} = "Albert";
$areanames{en}->{61268929} = "Myamley";
$areanames{en}->{61268930} = "Myamley";
$areanames{en}->{61268931} = "Myamley";
$areanames{en}->{61268932} = "Myamley";
$areanames{en}->{61268933} = "Myamley";
$areanames{en}->{61268934} = "Tottenham";
$areanames{en}->{61268935} = "Tullamore";
$areanames{en}->{61268936} = "Myamley";
$areanames{en}->{61268937} = "Boona\ Mountain";
$areanames{en}->{61268938} = "Boona\ Mountain";
$areanames{en}->{61268939} = "Boona\ Mountain";
$areanames{en}->{61268940} = "Coalbaggie";
$areanames{en}->{61268941} = "Collie";
$areanames{en}->{61268942} = "Coonabarabran";
$areanames{en}->{61268943} = "Curban";
$areanames{en}->{61268944} = "Dandaloo";
$areanames{en}->{61268945} = "Farrendale";
$areanames{en}->{61268946} = "Geurie";
$areanames{en}->{61268947} = "Gilgandra";
$areanames{en}->{61268948} = "Goorianawa";
$areanames{en}->{61268949} = "Gwabegar";
$areanames{en}->{6126895} = "Condobolin";
$areanames{en}->{61268957} = "Banar";
$areanames{en}->{61268958} = "Mendooran";
$areanames{en}->{61268959} = "Narromine";
$areanames{en}->{61268960} = "Mount\ Herring";
$areanames{en}->{61268961} = "Mount\ Herring";
$areanames{en}->{61268962} = "Mount\ Herring";
$areanames{en}->{61268963} = "Bobadah";
$areanames{en}->{61268964} = "Fairholme";
$areanames{en}->{61268965} = "Kiacatoo";
$areanames{en}->{61268966} = "Lake\ Cargelligo";
$areanames{en}->{61268967} = "Double\ Peaks";
$areanames{en}->{61268968} = "Double\ Peaks";
$areanames{en}->{61268969} = "Naradhan";
$areanames{en}->{61268970} = "Fairholme";
$areanames{en}->{61268971} = "Fairholme";
$areanames{en}->{61268972} = "Fairholme";
$areanames{en}->{61268973} = "Fairholme";
$areanames{en}->{61268974} = "Bobadah";
$areanames{en}->{61268975} = "Fairholme";
$areanames{en}->{61268976} = "Lake\ Cargelligo";
$areanames{en}->{61268977} = "Double\ Peaks";
$areanames{en}->{61268978} = "Double\ Peaks";
$areanames{en}->{61268979} = "Double\ Peaks";
$areanames{en}->{6126898} = "Lake\ Cargelligo";
$areanames{en}->{61268987} = "Naradhan";
$areanames{en}->{61268988} = "Naradhan";
$areanames{en}->{61268989} = "Naradhan";
$areanames{en}->{61268990} = "Barrier";
$areanames{en}->{61268991} = "Barrinford";
$areanames{en}->{61268992} = "Bourke";
$areanames{en}->{61268993} = "Brewarrina";
$areanames{en}->{61268994} = "Cobar";
$areanames{en}->{61268995} = "Cuttaburra";
$areanames{en}->{61268996} = "Narran";
$areanames{en}->{61268997} = "Albert";
$areanames{en}->{61268998} = "Banar";
$areanames{en}->{61268999} = "Bobadah";
$areanames{en}->{61269000} = "Wagga\ Wagga";
$areanames{en}->{61269001} = "Wagga\ Wagga";
$areanames{en}->{61269002} = "Wagga\ Wagga";
$areanames{en}->{61269003} = "Adelong";
$areanames{en}->{61269004} = "Alleena";
$areanames{en}->{61269005} = "Ardlethan";
$areanames{en}->{61269006} = "Ariah\ Park";
$areanames{en}->{61269007} = "Bambilla";
$areanames{en}->{61269008} = "Barellan";
$areanames{en}->{61269009} = "Barmedman";
$areanames{en}->{61269010} = "Barmedman\ East";
$areanames{en}->{61269011} = "Batlow";
$areanames{en}->{61269012} = "Bethungra";
$areanames{en}->{61269013} = "Bidgeemia";
$areanames{en}->{61269014} = "Black\ Stump";
$areanames{en}->{61269015} = "Booroorban";
$areanames{en}->{61269016} = "Boree\ Creek";
$areanames{en}->{61269017} = "Bunda";
$areanames{en}->{61269018} = "Bundure";
$areanames{en}->{61269019} = "Burcher";
$areanames{en}->{61269020} = "Burra";
$areanames{en}->{61269021} = "Carabost";
$areanames{en}->{61269022} = "Carrathool";
$areanames{en}->{61269023} = "Coleambally";
$areanames{en}->{61269024} = "Coolac";
$areanames{en}->{61269025} = "Coolamon";
$areanames{en}->{61269026} = "Cootamundra";
$areanames{en}->{61269027} = "Cowabbie";
$areanames{en}->{61269028} = "Currawarna";
$areanames{en}->{61269029} = "Darlington\ Point";
$areanames{en}->{61269030} = "Egansford";
$areanames{en}->{61269031} = "Gala\ Vale";
$areanames{en}->{61269032} = "Galore";
$areanames{en}->{61269033} = "Ganmain";
$areanames{en}->{61269034} = "Goolgowi";
$areanames{en}->{61269035} = "Griffith";
$areanames{en}->{61269036} = "Grong\ Grong";
$areanames{en}->{61269037} = "Gunbar";
$areanames{en}->{61269038} = "Gundagai";
$areanames{en}->{61269039} = "Hay";
$areanames{en}->{61269040} = "Henty";
$areanames{en}->{61269041} = "Hillston";
$areanames{en}->{61269042} = "Humula";
$areanames{en}->{61269043} = "Ivanhoe";
$areanames{en}->{61269044} = "Junee";
$areanames{en}->{61269045} = "Junee\ Reefs";
$areanames{en}->{61269046} = "Kikoira";
$areanames{en}->{61269047} = "Kyeamba";
$areanames{en}->{61269048} = "Lachlan";
$areanames{en}->{61269049} = "Landervale";
$areanames{en}->{61269050} = "Leeton";
$areanames{en}->{61269051} = "Lockhart";
$areanames{en}->{61269052} = "Mangoplah";
$areanames{en}->{61269053} = "Mannus";
$areanames{en}->{61269054} = "Marsden";
$areanames{en}->{61269055} = "Maude";
$areanames{en}->{61269056} = "Melbergen";
$areanames{en}->{61269057} = "Merriwagga";
$areanames{en}->{61269058} = "Milbrulong";
$areanames{en}->{61269059} = "Morundah";
$areanames{en}->{61269060} = "Nangus";
$areanames{en}->{61269061} = "Narraburra";
$areanames{en}->{61269062} = "Narrandera";
$areanames{en}->{61269063} = "Rankins\ Springs";
$areanames{en}->{61269064} = "Rannock";
$areanames{en}->{61269065} = "Sandigo";
$areanames{en}->{61269066} = "Springdale";
$areanames{en}->{61269067} = "Stanbridge";
$areanames{en}->{61269068} = "Stockinbingal";
$areanames{en}->{61269069} = "Talbingo";
$areanames{en}->{61269070} = "Tallimba";
$areanames{en}->{61269071} = "Tarcutta";
$areanames{en}->{61269072} = "Temora";
$areanames{en}->{61269073} = "The\ Rock";
$areanames{en}->{61269074} = "Tooma";
$areanames{en}->{61269075} = "Tullibigeal";
$areanames{en}->{61269076} = "Tumbarumba";
$areanames{en}->{61269077} = "Tumorrama";
$areanames{en}->{61269078} = "Tumut";
$areanames{en}->{61269079} = "Ungarie";
$areanames{en}->{61269080} = "Urana";
$areanames{en}->{61269081} = "Wallanthery";
$areanames{en}->{61269082} = "Wallendbeen";
$areanames{en}->{61269083} = "Wantabadgery";
$areanames{en}->{61269084} = "Warralonga";
$areanames{en}->{61269085} = "Warrawidgee";
$areanames{en}->{61269086} = "Wee\ Elwah";
$areanames{en}->{61269087} = "Weethalle";
$areanames{en}->{61269088} = "West\ Wyalong";
$areanames{en}->{61269089} = "Winchendon\ Vale";
$areanames{en}->{6126909} = "Griffith";
$areanames{en}->{61269100} = "Yaven\ Creek";
$areanames{en}->{61269101} = "Yenda";
$areanames{en}->{61269102} = "Griffith";
$areanames{en}->{61269103} = "Wagga\ Wagga";
$areanames{en}->{61269104} = "Wagga\ Wagga";
$areanames{en}->{61269105} = "Griffith";
$areanames{en}->{61269106} = "Stockinbingal";
$areanames{en}->{61269107} = "Talbingo";
$areanames{en}->{61269108} = "Tooma";
$areanames{en}->{61269109} = "Tumbarumba";
$areanames{en}->{61269110} = "Wagga\ Wagga";
$areanames{en}->{61269111} = "Tumorrama";
$areanames{en}->{61269112} = "Tumut";
$areanames{en}->{61269113} = "Wallendbeen";
$areanames{en}->{61269114} = "Yaven\ Creek";
$areanames{en}->{61269115} = "Adelong";
$areanames{en}->{61269116} = "Batlow";
$areanames{en}->{61269117} = "Bethungra";
$areanames{en}->{61269118} = "Burra";
$areanames{en}->{61269119} = "Carabost";
$areanames{en}->{61269120} = "Coolac";
$areanames{en}->{61269121} = "Cootamundra";
$areanames{en}->{61269122} = "Gundagai";
$areanames{en}->{61269123} = "Mannus";
$areanames{en}->{61269124} = "Nangus";
$areanames{en}->{61269125} = "Melbergen";
$areanames{en}->{61269126} = "Merriwagga";
$areanames{en}->{61269127} = "Rankins\ Springs";
$areanames{en}->{61269128} = "Wallanthery";
$areanames{en}->{61269129} = "Warrawidgee";
$areanames{en}->{61269130} = "Wee\ Elwah";
$areanames{en}->{61269131} = "Yenda";
$areanames{en}->{61269132} = "Bunda";
$areanames{en}->{61269133} = "Darlington\ Point";
$areanames{en}->{61269134} = "Goolgowi";
$areanames{en}->{61269135} = "Griffith";
$areanames{en}->{61269136} = "Gunbar";
$areanames{en}->{61269137} = "Hillston";
$areanames{en}->{61269138} = "Barellan";
$areanames{en}->{61269139} = "Black\ Stump";
$areanames{en}->{61269140} = "Hay";
$areanames{en}->{61269141} = "Ivanhoe";
$areanames{en}->{61269142} = "Lachlan";
$areanames{en}->{61269143} = "Maude";
$areanames{en}->{61269144} = "Bambilla";
$areanames{en}->{61269145} = "Booroorban";
$areanames{en}->{61269146} = "Carrathool";
$areanames{en}->{61269147} = "Leeton";
$areanames{en}->{61269148} = "Morundah";
$areanames{en}->{61269149} = "Narrandera";
$areanames{en}->{61269150} = "Sandigo";
$areanames{en}->{61269151} = "Stanbridge";
$areanames{en}->{61269152} = "Bundure";
$areanames{en}->{61269153} = "Coleambally";
$areanames{en}->{61269154} = "Egansford";
$areanames{en}->{61269155} = "Gala\ Vale";
$areanames{en}->{61269156} = "Grong\ Grong";
$areanames{en}->{61269157} = "Landervale";
$areanames{en}->{61269158} = "Ardlethan";
$areanames{en}->{61269159} = "Ariah\ Park";
$areanames{en}->{61269160} = "Barmedman";
$areanames{en}->{61269161} = "Barmedman\ East";
$areanames{en}->{61269162} = "Narraburra";
$areanames{en}->{61269163} = "Springdale";
$areanames{en}->{61269164} = "Temora";
$areanames{en}->{61269165} = "Mangoplah";
$areanames{en}->{61269166} = "Milbrulong";
$areanames{en}->{61269167} = "Rannock";
$areanames{en}->{61269168} = "Tarcutta";
$areanames{en}->{61269169} = "The\ Rock";
$areanames{en}->{61269170} = "Urana";
$areanames{en}->{61269171} = "Wagga\ Wagga";
$areanames{en}->{61269172} = "Wantabadgery";
$areanames{en}->{61269173} = "Winchendon\ Vale";
$areanames{en}->{61269174} = "Cowabbie";
$areanames{en}->{61269175} = "Currawarna";
$areanames{en}->{61269176} = "Galore";
$areanames{en}->{61269177} = "Ganmain";
$areanames{en}->{61269178} = "Henty";
$areanames{en}->{61269179} = "Humula";
$areanames{en}->{61269180} = "Junee";
$areanames{en}->{61269181} = "Junee\ Reefs";
$areanames{en}->{61269182} = "Kyeamba";
$areanames{en}->{61269183} = "Lockhart";
$areanames{en}->{61269184} = "Bidgeemia";
$areanames{en}->{61269185} = "Boree\ Creek";
$areanames{en}->{61269186} = "Coolamon";
$areanames{en}->{61269187} = "Burcher";
$areanames{en}->{61269188} = "Kikoira";
$areanames{en}->{61269189} = "Marsden";
$areanames{en}->{61269190} = "Tallimba";
$areanames{en}->{61269191} = "Tullibigeal";
$areanames{en}->{61269192} = "Ungarie";
$areanames{en}->{61269193} = "Warralonga";
$areanames{en}->{61269194} = "Weethalle";
$areanames{en}->{61269195} = "West\ Wyalong";
$areanames{en}->{61269196} = "Alleena";
$areanames{en}->{61269197} = "Weethalle";
$areanames{en}->{612691980} = "Rannock";
$areanames{en}->{612691981} = "Rannock";
$areanames{en}->{612691982} = "Rannock";
$areanames{en}->{612691983} = "Rannock";
$areanames{en}->{612691984} = "Wagga\ Wagga";
$areanames{en}->{612691985} = "Rannock\/Wagga\ Wagga";
$areanames{en}->{612691986} = "Rannock\/Wagga\ Wagga";
$areanames{en}->{612691987} = "Rannock";
$areanames{en}->{612691988} = "Rannock\/Wagga\ Wagga";
$areanames{en}->{612691989} = "Rannock\/Wagga\ Wagga";
$areanames{en}->{61269199} = "Tarcutta";
$areanames{en}->{61269200} = "The\ Rock";
$areanames{en}->{61269201} = "The\ Rock";
$areanames{en}->{61269202} = "The\ Rock";
$areanames{en}->{61269203} = "The\ Rock";
$areanames{en}->{61269204} = "Lockhart";
$areanames{en}->{61269205} = "Lockhart";
$areanames{en}->{61269206} = "Milbrulong";
$areanames{en}->{61269207} = "Bidgeemia";
$areanames{en}->{61269208} = "Urana";
$areanames{en}->{61269209} = "Urana";
$areanames{en}->{6126921} = "Wagga\ Wagga";
$areanames{en}->{6126922} = "Wagga\ Wagga";
$areanames{en}->{6126923} = "Wagga\ Wagga";
$areanames{en}->{6126924} = "Junee";
$areanames{en}->{61269247} = "Junee\ Reefs";
$areanames{en}->{6126925} = "Wagga\ Wagga";
$areanames{en}->{6126926} = "Wagga\ Wagga";
$areanames{en}->{61269270} = "Wagga\ Wagga";
$areanames{en}->{61269271} = "Boree\ Creek";
$areanames{en}->{61269272} = "Coolamon";
$areanames{en}->{61269273} = "Coolamon";
$areanames{en}->{61269274} = "Coolamon";
$areanames{en}->{61269275} = "Winchendon\ Vale";
$areanames{en}->{61269276} = "Ganmain";
$areanames{en}->{61269277} = "Ganmain";
$areanames{en}->{61269278} = "Rannock";
$areanames{en}->{61269279} = "Cowabbie";
$areanames{en}->{61269280} = "Kyeamba";
$areanames{en}->{61269281} = "Kyeamba";
$areanames{en}->{61269282} = "Currawarna";
$areanames{en}->{61269283} = "Galore";
$areanames{en}->{61269284} = "Wantabadgery";
$areanames{en}->{61269285} = "Mangoplah";
$areanames{en}->{61269286} = "Mangoplah";
$areanames{en}->{61269287} = "Tarcutta";
$areanames{en}->{61269288} = "Tarcutta";
$areanames{en}->{61269289} = "Humula";
$areanames{en}->{6126929} = "Henty";
$areanames{en}->{61269290} = "Currawarna";
$areanames{en}->{61269291} = "Currawarna";
$areanames{en}->{61269295} = "Lockhart";
$areanames{en}->{612693} = "Wagga\ Wagga";
$areanames{en}->{61269300} = "Winchendon\ Vale";
$areanames{en}->{61269301} = "Coolamon";
$areanames{en}->{61269302} = "Cowabbie";
$areanames{en}->{61269303} = "Galore";
$areanames{en}->{61269304} = "Ganmain";
$areanames{en}->{61269305} = "Junee";
$areanames{en}->{61269306} = "Junee";
$areanames{en}->{61269307} = "Lockhart";
$areanames{en}->{61269308} = "Rannock";
$areanames{en}->{61269309} = "Urana";
$areanames{en}->{61269340} = "Adelong";
$areanames{en}->{61269341} = "Batlow";
$areanames{en}->{61269342} = "Springdale";
$areanames{en}->{61269343} = "Bidgeemia";
$areanames{en}->{61269344} = "Coolamon";
$areanames{en}->{61269345} = "Ganmain";
$areanames{en}->{61269346} = "Junee";
$areanames{en}->{61269347} = "Lockhart";
$areanames{en}->{61269348} = "The\ Rock";
$areanames{en}->{61269349} = "Wantabadgery";
$areanames{en}->{61269350} = "Bethungra";
$areanames{en}->{61269351} = "Burra";
$areanames{en}->{61269352} = "Carabost";
$areanames{en}->{61269353} = "Coolac";
$areanames{en}->{61269354} = "Cootamundra";
$areanames{en}->{61269355} = "Gundagai";
$areanames{en}->{61269356} = "Mannus";
$areanames{en}->{61269357} = "Nangus";
$areanames{en}->{61269358} = "Stockinbingal";
$areanames{en}->{61269359} = "Talbingo";
$areanames{en}->{61269380} = "Kyeamba";
$areanames{en}->{61269387} = "Henty";
$areanames{en}->{61269388} = "Humula";
$areanames{en}->{61269389} = "Junee\ Reefs";
$areanames{en}->{61269390} = "Currawarna";
$areanames{en}->{61269391} = "Mangoplah";
$areanames{en}->{61269392} = "Milbrulong";
$areanames{en}->{61269393} = "Tarcutta";
$areanames{en}->{61269394} = "The\ Rock";
$areanames{en}->{61269396} = "Wantabadgery";
$areanames{en}->{61269398} = "Bidgeemia";
$areanames{en}->{61269399} = "Boree\ Creek";
$areanames{en}->{61269400} = "Tooma";
$areanames{en}->{61269401} = "Cootamundra";
$areanames{en}->{61269402} = "Cootamundra";
$areanames{en}->{61269403} = "Bethungra";
$areanames{en}->{61269404} = "Stockinbingal";
$areanames{en}->{61269405} = "Wallendbeen";
$areanames{en}->{61269406} = "Gundagai";
$areanames{en}->{61269407} = "Burra";
$areanames{en}->{61269408} = "Coolac";
$areanames{en}->{61269409} = "Nangus";
$areanames{en}->{61269410} = "Mannus";
$areanames{en}->{61269411} = "Tumut";
$areanames{en}->{61269412} = "Tumut";
$areanames{en}->{61269413} = "Adelong";
$areanames{en}->{61269414} = "Batlow";
$areanames{en}->{61269415} = "Talbingo";
$areanames{en}->{61269416} = "Tumorrama";
$areanames{en}->{61269417} = "Yaven\ Creek";
$areanames{en}->{61269418} = "Tumbarumba";
$areanames{en}->{61269419} = "Carabost";
$areanames{en}->{6126942} = "Cootamundra";
$areanames{en}->{61269430} = "Stockinbingal";
$areanames{en}->{61269431} = "Stockinbingal";
$areanames{en}->{61269432} = "Wallendbeen";
$areanames{en}->{61269433} = "Cootamundra";
$areanames{en}->{61269434} = "Bethungra";
$areanames{en}->{61269435} = "Bethungra";
$areanames{en}->{61269436} = "Coolac";
$areanames{en}->{61269437} = "Coolac";
$areanames{en}->{61269438} = "Coolac";
$areanames{en}->{61269439} = "Coolac";
$areanames{en}->{6126944} = "Gundagai";
$areanames{en}->{61269447} = "Nangus";
$areanames{en}->{61269448} = "Burra";
$areanames{en}->{6126945} = "Coolac";
$areanames{en}->{61269456} = "Tooma";
$areanames{en}->{61269457} = "Tumbarumba";
$areanames{en}->{61269458} = "Tumorrama";
$areanames{en}->{61269459} = "Tumut";
$areanames{en}->{612694600} = "Wallendbeen";
$areanames{en}->{612694601} = "Wallendbeen";
$areanames{en}->{612694602} = "Wallendbeen";
$areanames{en}->{612694603} = "Wallendbeen";
$areanames{en}->{612694606} = "Wallendbeen";
$areanames{en}->{61269461} = "Adelong";
$areanames{en}->{61269462} = "Adelong";
$areanames{en}->{612694630} = "Yaven\ Creek";
$areanames{en}->{612694631} = "Yaven\ Creek";
$areanames{en}->{612694632} = "Yaven\ Creek";
$areanames{en}->{612694633} = "Yaven\ Creek";
$areanames{en}->{612694636} = "Yaven\ Creek";
$areanames{en}->{61269464} = "Adelong";
$areanames{en}->{61269465} = "Yaven\ Creek";
$areanames{en}->{61269466} = "Tumorrama";
$areanames{en}->{61269467} = "Adelong";
$areanames{en}->{61269468} = "Adelong";
$areanames{en}->{61269469} = "Adelong";
$areanames{en}->{6126947} = "Tumut";
$areanames{en}->{6126948} = "Tumbarumba";
$areanames{en}->{61269484} = "Tooma";
$areanames{en}->{61269485} = "Mannus";
$areanames{en}->{61269486} = "Carabost";
$areanames{en}->{61269490} = "Batlow";
$areanames{en}->{61269491} = "Batlow";
$areanames{en}->{61269492} = "Batlow";
$areanames{en}->{61269493} = "Batlow";
$areanames{en}->{61269494} = "Talbingo";
$areanames{en}->{61269495} = "Talbingo";
$areanames{en}->{61269496} = "Barellan";
$areanames{en}->{61269497} = "Black\ Stump";
$areanames{en}->{61269498} = "Bunda";
$areanames{en}->{61269499} = "Darlington\ Point";
$areanames{en}->{6126950} = "Narrandera";
$areanames{en}->{61269501} = "Egansford";
$areanames{en}->{61269502} = "Coleambally";
$areanames{en}->{61269503} = "Gala\ Vale";
$areanames{en}->{6126951} = "Narrandera";
$areanames{en}->{61269511} = "Leeton";
$areanames{en}->{61269512} = "Leeton";
$areanames{en}->{61269513} = "Leeton";
$areanames{en}->{61269514} = "Stanbridge";
$areanames{en}->{61269520} = "Goolgowi";
$areanames{en}->{61269521} = "Griffith";
$areanames{en}->{61269522} = "Gunbar";
$areanames{en}->{61269523} = "Hillston";
$areanames{en}->{61269524} = "Melbergen";
$areanames{en}->{61269525} = "Merriwagga";
$areanames{en}->{61269526} = "Rankins\ Springs";
$areanames{en}->{61269527} = "Wallanthery";
$areanames{en}->{61269528} = "Warrawidgee";
$areanames{en}->{61269529} = "Wee\ Elwah";
$areanames{en}->{6126953} = "Leeton";
$areanames{en}->{61269540} = "Egansford";
$areanames{en}->{61269541} = "Egansford";
$areanames{en}->{61269542} = "Egansford";
$areanames{en}->{61269543} = "Egansford";
$areanames{en}->{61269544} = "Coleambally";
$areanames{en}->{61269545} = "Egansford";
$areanames{en}->{61269546} = "Coleambally";
$areanames{en}->{61269547} = "Coleambally";
$areanames{en}->{61269548} = "Gala\ Vale";
$areanames{en}->{61269549} = "Coleambally";
$areanames{en}->{6126955} = "Leeton";
$areanames{en}->{61269550} = "Stanbridge";
$areanames{en}->{61269551} = "Stanbridge";
$areanames{en}->{61269552} = "Stanbridge";
$areanames{en}->{61269553} = "Landervale";
$areanames{en}->{6126956} = "Landervale";
$areanames{en}->{61269560} = "Bundure";
$areanames{en}->{61269561} = "Bundure";
$areanames{en}->{61269562} = "Grong\ Grong";
$areanames{en}->{61269570} = "The\ Rock";
$areanames{en}->{61269571} = "Urana";
$areanames{en}->{61269572} = "Wagga\ Wagga";
$areanames{en}->{61269573} = "Wantabadgery";
$areanames{en}->{61269574} = "Winchendon\ Vale";
$areanames{en}->{61269575} = "Alleena";
$areanames{en}->{61269576} = "Burcher";
$areanames{en}->{61269577} = "Kikoira";
$areanames{en}->{61269578} = "Marsden";
$areanames{en}->{61269579} = "Tallimba";
$areanames{en}->{61269580} = "Narrandera";
$areanames{en}->{61269581} = "Narrandera";
$areanames{en}->{61269582} = "Narrandera";
$areanames{en}->{61269583} = "Narrandera";
$areanames{en}->{61269584} = "Bundure";
$areanames{en}->{61269585} = "Grong\ Grong";
$areanames{en}->{61269586} = "Landervale";
$areanames{en}->{61269587} = "Morundah";
$areanames{en}->{61269588} = "Sandigo";
$areanames{en}->{61269589} = "Narrandera";
$areanames{en}->{6126959} = "Narrandera";
$areanames{en}->{61269597} = "Morundah";
$areanames{en}->{61269598} = "Sandigo";
$areanames{en}->{61269600} = "Rankins\ Springs";
$areanames{en}->{61269601} = "Griffith";
$areanames{en}->{61269602} = "Griffith";
$areanames{en}->{61269603} = "Griffith";
$areanames{en}->{61269604} = "Yenda";
$areanames{en}->{61269605} = "Darlington\ Point";
$areanames{en}->{61269606} = "Goolgowi";
$areanames{en}->{61269607} = "Gunbar";
$areanames{en}->{61269608} = "Black\ Stump";
$areanames{en}->{61269609} = "Merriwagga";
$areanames{en}->{61269610} = "Griffith";
$areanames{en}->{61269611} = "Bunda";
$areanames{en}->{61269612} = "Warrawidgee";
$areanames{en}->{61269613} = "Yenda";
$areanames{en}->{61269614} = "Melbergen";
$areanames{en}->{61269615} = "Wee\ Elwah";
$areanames{en}->{61269616} = "Wallanthery";
$areanames{en}->{61269617} = "Hillston";
$areanames{en}->{61269618} = "Griffith";
$areanames{en}->{61269619} = "Griffith";
$areanames{en}->{6126962} = "Griffith";
$areanames{en}->{6126963} = "Griffith";
$areanames{en}->{61269639} = "Barellan";
$areanames{en}->{6126964} = "Griffith";
$areanames{en}->{6126965} = "Goolgowi";
$areanames{en}->{61269652} = "Gunbar";
$areanames{en}->{61269653} = "Melbergen";
$areanames{en}->{61269654} = "Merriwagga";
$areanames{en}->{61269660} = "Griffith";
$areanames{en}->{61269661} = "Rankins\ Springs";
$areanames{en}->{61269662} = "Griffith";
$areanames{en}->{61269663} = "Rankins\ Springs";
$areanames{en}->{61269664} = "Rankins\ Springs";
$areanames{en}->{61269665} = "Rankins\ Springs";
$areanames{en}->{61269666} = "Rankins\ Springs";
$areanames{en}->{61269667} = "Griffith";
$areanames{en}->{61269668} = "Griffith";
$areanames{en}->{61269669} = "Griffith";
$areanames{en}->{61269670} = "Hillston";
$areanames{en}->{61269671} = "Hillston";
$areanames{en}->{61269672} = "Hillston";
$areanames{en}->{61269673} = "Hillston";
$areanames{en}->{61269674} = "Wallanthery";
$areanames{en}->{61269675} = "Bunda";
$areanames{en}->{61269676} = "Black\ Stump";
$areanames{en}->{61269677} = "Black\ Stump";
$areanames{en}->{61269678} = "Wee\ Elwah";
$areanames{en}->{61269679} = "Wee\ Elwah";
$areanames{en}->{61269680} = "Yenda";
$areanames{en}->{61269681} = "Yenda";
$areanames{en}->{61269682} = "Yenda";
$areanames{en}->{61269683} = "Yenda";
$areanames{en}->{61269684} = "Darlington\ Point";
$areanames{en}->{61269685} = "Darlington\ Point";
$areanames{en}->{61269686} = "Warrawidgee";
$areanames{en}->{61269687} = "Warrawidgee";
$areanames{en}->{61269688} = "Goolgowi";
$areanames{en}->{61269689} = "Goolgowi";
$areanames{en}->{6126969} = "Griffith";
$areanames{en}->{61269700} = "Warralonga";
$areanames{en}->{61269701} = "West\ Wyalong";
$areanames{en}->{61269702} = "West\ Wyalong";
$areanames{en}->{61269703} = "Kikoira";
$areanames{en}->{61269704} = "West\ Wyalong";
$areanames{en}->{61269705} = "Burcher";
$areanames{en}->{61269706} = "Marsden";
$areanames{en}->{61269707} = "Tallimba";
$areanames{en}->{61269708} = "Tullibigeal";
$areanames{en}->{61269709} = "Ungarie";
$areanames{en}->{6126971} = "Wagga\ Wagga";
$areanames{en}->{61269720} = "West\ Wyalong";
$areanames{en}->{61269721} = "West\ Wyalong";
$areanames{en}->{61269722} = "West\ Wyalong";
$areanames{en}->{61269723} = "West\ Wyalong";
$areanames{en}->{61269724} = "West\ Wyalong";
$areanames{en}->{61269725} = "Burcher";
$areanames{en}->{61269726} = "Kikoira";
$areanames{en}->{61269727} = "Marsden";
$areanames{en}->{61269728} = "Marsden";
$areanames{en}->{61269729} = "Tullibigeal";
$areanames{en}->{61269730} = "Temora";
$areanames{en}->{61269731} = "Temora";
$areanames{en}->{61269732} = "Ariah\ Park";
$areanames{en}->{61269733} = "Bambilla";
$areanames{en}->{61269734} = "Booroorban";
$areanames{en}->{61269735} = "Carrathool";
$areanames{en}->{61269736} = "Hay";
$areanames{en}->{61269737} = "Temora";
$areanames{en}->{61269738} = "Springdale";
$areanames{en}->{61269739} = "Narraburra";
$areanames{en}->{61269740} = "Ariah\ Park";
$areanames{en}->{61269741} = "Ariah\ Park";
$areanames{en}->{61269742} = "Ivanhoe";
$areanames{en}->{61269743} = "Ariah\ Park";
$areanames{en}->{61269744} = "Lachlan";
$areanames{en}->{61269745} = "Maude";
$areanames{en}->{61269746} = "Bundure";
$areanames{en}->{61269747} = "Coleambally";
$areanames{en}->{61269748} = "Egansford";
$areanames{en}->{61269749} = "Gala\ Vale";
$areanames{en}->{61269750} = "Grong\ Grong";
$areanames{en}->{61269751} = "Landervale";
$areanames{en}->{61269752} = "Alleena";
$areanames{en}->{61269753} = "Burcher";
$areanames{en}->{61269754} = "Burcher";
$areanames{en}->{61269755} = "Warralonga";
$areanames{en}->{61269756} = "Weethalle";
$areanames{en}->{61269757} = "Tallimba";
$areanames{en}->{61269758} = "Ungarie";
$areanames{en}->{61269759} = "Ungarie";
$areanames{en}->{61269760} = "Leeton";
$areanames{en}->{61269761} = "Morundah";
$areanames{en}->{61269762} = "Barmedman";
$areanames{en}->{61269763} = "Barmedman";
$areanames{en}->{61269764} = "Barmedman\ East";
$areanames{en}->{61269765} = "Narrandera";
$areanames{en}->{61269766} = "Sandigo";
$areanames{en}->{61269767} = "Stanbridge";
$areanames{en}->{61269768} = "Ardlethan";
$areanames{en}->{61269769} = "Ariah\ Park";
$areanames{en}->{6126977} = "Temora";
$areanames{en}->{61269780} = "Temora";
$areanames{en}->{61269781} = "Temora";
$areanames{en}->{61269782} = "Ardlethan";
$areanames{en}->{61269783} = "Ardlethan";
$areanames{en}->{61269784} = "Barmedman";
$areanames{en}->{61269785} = "Barmedman\ East";
$areanames{en}->{61269786} = "Narraburra";
$areanames{en}->{61269787} = "Springdale";
$areanames{en}->{61269788} = "Temora";
$areanames{en}->{61269789} = "Bidgeemia";
$areanames{en}->{6126979} = "West\ Wyalong";
$areanames{en}->{61269791} = "Weethalle";
$areanames{en}->{61269800} = "Temora";
$areanames{en}->{61269801} = "Temora";
$areanames{en}->{61269802} = "Temora";
$areanames{en}->{61269803} = "Ardlethan";
$areanames{en}->{61269804} = "Boree\ Creek";
$areanames{en}->{61269805} = "Coolamon";
$areanames{en}->{61269806} = "Cowabbie";
$areanames{en}->{61269807} = "Narraburra";
$areanames{en}->{61269808} = "Springdale";
$areanames{en}->{61269809} = "Temora";
$areanames{en}->{61269810} = "Talbingo";
$areanames{en}->{61269811} = "Tumut";
$areanames{en}->{61269812} = "Tumut";
$areanames{en}->{61269813} = "Tumut";
$areanames{en}->{61269814} = "Tumut";
$areanames{en}->{61269815} = "Gundagai";
$areanames{en}->{61269816} = "Gundagai";
$areanames{en}->{61269817} = "Gundagai";
$areanames{en}->{61269818} = "Cootamundra";
$areanames{en}->{61269819} = "Cootamundra";
$areanames{en}->{61269820} = "Currawarna";
$areanames{en}->{61269821} = "Bethungra";
$areanames{en}->{61269822} = "Mannus";
$areanames{en}->{61269823} = "Nangus";
$areanames{en}->{61269824} = "Nangus";
$areanames{en}->{61269825} = "Stockinbingal";
$areanames{en}->{61269826} = "Tooma";
$areanames{en}->{61269827} = "Tumbarumba";
$areanames{en}->{61269828} = "Tumut";
$areanames{en}->{61269829} = "Wallendbeen";
$areanames{en}->{61269830} = "Wantabadgery";
$areanames{en}->{61269831} = "Griffith";
$areanames{en}->{61269832} = "Griffith";
$areanames{en}->{61269833} = "Griffith";
$areanames{en}->{61269834} = "Wagga\ Wagga";
$areanames{en}->{61269835} = "Tullibigeal";
$areanames{en}->{61269836} = "Ungarie";
$areanames{en}->{61269837} = "Warralonga";
$areanames{en}->{61269838} = "Weethalle";
$areanames{en}->{61269839} = "West\ Wyalong";
$areanames{en}->{61269840} = "Adelong";
$areanames{en}->{61269841} = "Batlow";
$areanames{en}->{61269842} = "Bethungra";
$areanames{en}->{61269843} = "Burra";
$areanames{en}->{61269844} = "Carabost";
$areanames{en}->{61269845} = "Coolac";
$areanames{en}->{61269846} = "Cootamundra";
$areanames{en}->{61269847} = "Gundagai";
$areanames{en}->{61269848} = "Mannus";
$areanames{en}->{61269849} = "Nangus";
$areanames{en}->{61269850} = "Burcher";
$areanames{en}->{61269851} = "Kikoira";
$areanames{en}->{61269852} = "Marsden";
$areanames{en}->{61269853} = "Tallimba";
$areanames{en}->{61269854} = "Tullibigeal";
$areanames{en}->{61269855} = "Ungarie";
$areanames{en}->{61269856} = "Warralonga";
$areanames{en}->{61269857} = "Weethalle";
$areanames{en}->{61269858} = "West\ Wyalong";
$areanames{en}->{61269859} = "Stockinbingal";
$areanames{en}->{61269860} = "Mangoplah";
$areanames{en}->{61269861} = "Milbrulong";
$areanames{en}->{61269862} = "Rannock";
$areanames{en}->{61269863} = "Tarcutta";
$areanames{en}->{61269864} = "The\ Rock";
$areanames{en}->{61269865} = "Urana";
$areanames{en}->{61269866} = "Wagga\ Wagga";
$areanames{en}->{61269867} = "Wantabadgery";
$areanames{en}->{61269868} = "Winchendon\ Vale";
$areanames{en}->{61269869} = "Alleena";
$areanames{en}->{61269870} = "Cowabbie";
$areanames{en}->{61269871} = "Currawarna";
$areanames{en}->{61269872} = "Galore";
$areanames{en}->{61269873} = "Ganmain";
$areanames{en}->{61269874} = "Henty";
$areanames{en}->{61269875} = "Humula";
$areanames{en}->{61269876} = "Junee";
$areanames{en}->{61269877} = "Junee\ Reefs";
$areanames{en}->{61269878} = "Kyeamba";
$areanames{en}->{61269879} = "Lockhart";
$areanames{en}->{61269880} = "Ardlethan";
$areanames{en}->{61269881} = "Ariah\ Park";
$areanames{en}->{61269882} = "Barmedman";
$areanames{en}->{61269883} = "Barmedman\ East";
$areanames{en}->{61269884} = "Narraburra";
$areanames{en}->{61269885} = "Springdale";
$areanames{en}->{61269886} = "Temora";
$areanames{en}->{61269887} = "Bidgeemia";
$areanames{en}->{61269888} = "Boree\ Creek";
$areanames{en}->{61269889} = "Coolamon";
$areanames{en}->{61269890} = "Burcher";
$areanames{en}->{61269891} = "Ungarie";
$areanames{en}->{61269892} = "Galore";
$areanames{en}->{61269893} = "Ganmain";
$areanames{en}->{61269894} = "Henty";
$areanames{en}->{61269895} = "Leeton";
$areanames{en}->{61269896} = "Morundah";
$areanames{en}->{61269897} = "Narrandera";
$areanames{en}->{61269898} = "Sandigo";
$areanames{en}->{61269899} = "Stanbridge";
$areanames{en}->{61269900} = "Hay";
$areanames{en}->{61269901} = "Hay";
$areanames{en}->{61269902} = "Ivanhoe";
$areanames{en}->{61269903} = "Booroorban";
$areanames{en}->{61269904} = "Humula";
$areanames{en}->{61269905} = "Carrathool";
$areanames{en}->{61269906} = "Maude";
$areanames{en}->{61269907} = "Lachlan";
$areanames{en}->{61269908} = "Hay";
$areanames{en}->{61269909} = "Hay";
$areanames{en}->{61269910} = "Junee";
$areanames{en}->{61269911} = "Bunda";
$areanames{en}->{61269912} = "Darlington\ Point";
$areanames{en}->{61269913} = "Griffith";
$areanames{en}->{61269914} = "Griffith";
$areanames{en}->{61269915} = "Melbergen";
$areanames{en}->{61269916} = "Merriwagga";
$areanames{en}->{61269917} = "Rankins\ Springs";
$areanames{en}->{61269918} = "Wallanthery";
$areanames{en}->{61269919} = "Yenda";
$areanames{en}->{61269920} = "Hay";
$areanames{en}->{61269921} = "Ivanhoe";
$areanames{en}->{61269922} = "Lachlan";
$areanames{en}->{61269923} = "Maude";
$areanames{en}->{61269924} = "Bundure";
$areanames{en}->{61269925} = "Coleambally";
$areanames{en}->{61269926} = "Egansford";
$areanames{en}->{61269927} = "Gala\ Vale";
$areanames{en}->{61269928} = "Grong\ Grong";
$areanames{en}->{61269929} = "Landervale";
$areanames{en}->{61269930} = "Booroorban";
$areanames{en}->{61269931} = "Hay";
$areanames{en}->{61269932} = "Hay";
$areanames{en}->{61269933} = "Hay";
$areanames{en}->{61269934} = "Hay";
$areanames{en}->{61269935} = "Carrathool";
$areanames{en}->{61269936} = "Maude";
$areanames{en}->{61269937} = "Lachlan";
$areanames{en}->{61269938} = "Lachlan";
$areanames{en}->{61269939} = "Lachlan";
$areanames{en}->{61269940} = "Melbergen";
$areanames{en}->{61269941} = "Merriwagga";
$areanames{en}->{61269942} = "Rankins\ Springs";
$areanames{en}->{61269943} = "Wallanthery";
$areanames{en}->{61269944} = "Warrawidgee";
$areanames{en}->{61269945} = "Wee\ Elwah";
$areanames{en}->{61269946} = "Yenda";
$areanames{en}->{61269947} = "Bambilla";
$areanames{en}->{61269948} = "Booroorban";
$areanames{en}->{61269949} = "Carrathool";
$areanames{en}->{61269950} = "Ivanhoe";
$areanames{en}->{61269951} = "Ivanhoe";
$areanames{en}->{61269952} = "Ivanhoe";
$areanames{en}->{61269953} = "Bambilla";
$areanames{en}->{61269954} = "Bambilla";
$areanames{en}->{61269955} = "Junee\ Reefs";
$areanames{en}->{61269956} = "Kyeamba";
$areanames{en}->{61269957} = "Lockhart";
$areanames{en}->{61269958} = "Mangoplah";
$areanames{en}->{61269959} = "Milbrulong";
$areanames{en}->{6126996} = "Wagga\ Wagga";
$areanames{en}->{61269970} = "Carrathool";
$areanames{en}->{61269971} = "Maude";
$areanames{en}->{61269972} = "Hay";
$areanames{en}->{61269973} = "Hay";
$areanames{en}->{61269974} = "Bunda";
$areanames{en}->{61269975} = "Darlington\ Point";
$areanames{en}->{61269976} = "Goolgowi";
$areanames{en}->{61269977} = "Griffith";
$areanames{en}->{61269978} = "Gunbar";
$areanames{en}->{61269979} = "Hillston";
$areanames{en}->{61269980} = "Stockinbingal";
$areanames{en}->{61269981} = "Talbingo";
$areanames{en}->{61269982} = "Tooma";
$areanames{en}->{61269983} = "Tumbarumba";
$areanames{en}->{61269984} = "Tumorrama";
$areanames{en}->{61269985} = "Tumut";
$areanames{en}->{61269986} = "Wallendbeen";
$areanames{en}->{61269987} = "Yaven\ Creek";
$areanames{en}->{61269988} = "Barellan";
$areanames{en}->{61269989} = "Black\ Stump";
$areanames{en}->{61269990} = "Adelong";
$areanames{en}->{61269991} = "Batlow";
$areanames{en}->{61269992} = "Bethungra";
$areanames{en}->{61269993} = "Burra";
$areanames{en}->{61269994} = "Carabost";
$areanames{en}->{61269995} = "Coolac";
$areanames{en}->{61269996} = "Cootamundra";
$areanames{en}->{61269997} = "Gundagai";
$areanames{en}->{61269998} = "Mannus";
$areanames{en}->{61269999} = "Nangus";
$areanames{en}->{6127200} = "Sydney";
$areanames{en}->{6127201} = "Sydney";
$areanames{en}->{61275000} = "Engadine";
$areanames{en}->{61275001} = "Sutherland";
$areanames{en}->{61275002} = "Engadine";
$areanames{en}->{61275003} = "Sutherland";
$areanames{en}->{61275004} = "Engadine";
$areanames{en}->{61275005} = "Sutherland";
$areanames{en}->{61275006} = "Engadine";
$areanames{en}->{61275007} = "Sutherland";
$areanames{en}->{61275008} = "Engadine";
$areanames{en}->{61275009} = "Sutherland";
$areanames{en}->{61275010} = "Engadine";
$areanames{en}->{61275011} = "Sutherland";
$areanames{en}->{61275012} = "Engadine";
$areanames{en}->{61275013} = "Sutherland";
$areanames{en}->{61275014} = "Engadine";
$areanames{en}->{61275015} = "Sutherland";
$areanames{en}->{6127800} = "Parramatta";
$areanames{en}->{6127801} = "Parramatta";
$areanames{en}->{6127802} = "Parramatta";
$areanames{en}->{6127803} = "Parramatta";
$areanames{en}->{61278040} = "Parramatta";
$areanames{en}->{61278041} = "Parramatta";
$areanames{en}->{61278042} = "Parramatta";
$areanames{en}->{61278043} = "Parramatta";
$areanames{en}->{61278044} = "Parramatta";
$areanames{en}->{61278045} = "Parramatta";
$areanames{en}->{61278046} = "Parramatta";
$areanames{en}->{6127805} = "Parramatta";
$areanames{en}->{6127806} = "Parramatta";
$areanames{en}->{6127807} = "Parramatta";
$areanames{en}->{61278082} = "Parramatta";
$areanames{en}->{61278083} = "Parramatta";
$areanames{en}->{61278084} = "Parramatta";
$areanames{en}->{61278085} = "Parramatta";
$areanames{en}->{61278086} = "Parramatta";
$areanames{en}->{6127809} = "Parramatta";
$areanames{en}->{6127810} = "Parramatta";
$areanames{en}->{6127814} = "Parramatta";
$areanames{en}->{6127900} = "Sydney";
$areanames{en}->{6127902} = "Sydney";
$areanames{en}->{6127903} = "Sydney";
$areanames{en}->{6127909} = "Sydney";
$areanames{en}->{6127922} = "Sydney";
$areanames{en}->{6127923} = "Sydney";
$areanames{en}->{6127924} = "Sydney";
$areanames{en}->{6127966} = "Sydney";
$areanames{en}->{61279888} = "Sydney";
$areanames{en}->{612800} = "Sydney";
$areanames{en}->{612801} = "Sydney";
$areanames{en}->{612802} = "Sydney";
$areanames{en}->{612803} = "Sydney";
$areanames{en}->{6128040} = "Sydney";
$areanames{en}->{6128041} = "Sydney";
$areanames{en}->{6128042} = "Sydney";
$areanames{en}->{61280430} = "Sydney";
$areanames{en}->{61280431} = "Sydney";
$areanames{en}->{61280432} = "Sydney";
$areanames{en}->{61280433} = "Sydney";
$areanames{en}->{61280445} = "Sydney";
$areanames{en}->{61280446} = "Sydney";
$areanames{en}->{61280447} = "Sydney";
$areanames{en}->{61280448} = "Sydney";
$areanames{en}->{61280449} = "Sydney";
$areanames{en}->{6128045} = "Sydney";
$areanames{en}->{6128046} = "Sydney";
$areanames{en}->{6128047} = "Sydney";
$areanames{en}->{6128048} = "Sydney";
$areanames{en}->{6128049} = "Sydney";
$areanames{en}->{612805} = "Sydney";
$areanames{en}->{612806} = "Sydney";
$areanames{en}->{612807} = "Sydney";
$areanames{en}->{612808} = "Sydney";
$areanames{en}->{6128090} = "Sydney";
$areanames{en}->{6128094} = "Sydney";
$areanames{en}->{6128100} = "Bankstown";
$areanames{en}->{6128101} = "Liverpool";
$areanames{en}->{6128102} = "Bankstown";
$areanames{en}->{6128103} = "Liverpool";
$areanames{en}->{61281030} = "Bankstown";
$areanames{en}->{61281031} = "Bankstown";
$areanames{en}->{61281032} = "Bankstown";
$areanames{en}->{61281034} = "Sydney";
$areanames{en}->{61281040} = "Liverpool";
$areanames{en}->{61281041} = "Liverpool";
$areanames{en}->{61281042} = "Sydney";
$areanames{en}->{61281043} = "Liverpool";
$areanames{en}->{61281044} = "Bankstown";
$areanames{en}->{61281045} = "Bankstown";
$areanames{en}->{61281046} = "Liverpool";
$areanames{en}->{61281047} = "Bankstown";
$areanames{en}->{61281048} = "Liverpool";
$areanames{en}->{61281049} = "Bankstown";
$areanames{en}->{6128105} = "Liverpool";
$areanames{en}->{61281051} = "Bankstown";
$areanames{en}->{61281053} = "Bankstown";
$areanames{en}->{61281055} = "Bankstown";
$areanames{en}->{61281057} = "Bankstown";
$areanames{en}->{61281060} = "Bankstown";
$areanames{en}->{61281061} = "Liverpool";
$areanames{en}->{6128107} = "Liverpool";
$areanames{en}->{6128113} = "Sydney";
$areanames{en}->{6128114} = "Sydney";
$areanames{en}->{6128115} = "Sydney";
$areanames{en}->{6128116} = "Sydney";
$areanames{en}->{6128117} = "Sydney";
$areanames{en}->{61281180} = "Bankstown";
$areanames{en}->{61281181} = "Liverpool";
$areanames{en}->{61281182} = "Liverpool";
$areanames{en}->{61281183} = "Liverpool";
$areanames{en}->{61281184} = "Liverpool";
$areanames{en}->{61281185} = "Liverpool";
$areanames{en}->{61281186} = "Liverpool";
$areanames{en}->{61281187} = "Liverpool";
$areanames{en}->{61281188} = "Liverpool";
$areanames{en}->{6128119} = "Liverpool";
$areanames{en}->{6128120} = "Sydney";
$areanames{en}->{6128121} = "Sydney";
$areanames{en}->{6128122} = "Sydney";
$areanames{en}->{6128123} = "Sydney";
$areanames{en}->{6128188} = "Sydney";
$areanames{en}->{6128189} = "Liverpool";
$areanames{en}->{6128197} = "Sydney";
$areanames{en}->{6128198} = "Sydney";
$areanames{en}->{6128199} = "Sydney";
$areanames{en}->{612820} = "Sydney";
$areanames{en}->{612821} = "Sydney";
$areanames{en}->{612822} = "Sydney";
$areanames{en}->{612823} = "Sydney";
$areanames{en}->{612824} = "Sydney";
$areanames{en}->{612825} = "Sydney";
$areanames{en}->{6128260} = "Sydney";
$areanames{en}->{61282611} = "Sydney";
$areanames{en}->{61282614} = "Sydney";
$areanames{en}->{61282615} = "Sydney";
$areanames{en}->{61282616} = "Sydney";
$areanames{en}->{61282617} = "Sydney";
$areanames{en}->{61282618} = "Sydney";
$areanames{en}->{61282619} = "Sydney";
$areanames{en}->{6128262} = "Sydney";
$areanames{en}->{6128263} = "Sydney";
$areanames{en}->{6128264} = "Sydney";
$areanames{en}->{6128265} = "Sydney";
$areanames{en}->{6128266} = "Sydney";
$areanames{en}->{6128267} = "Sydney";
$areanames{en}->{6128268} = "Sydney";
$areanames{en}->{61282690} = "Sydney";
$areanames{en}->{612827} = "Sydney";
$areanames{en}->{612828} = "Sydney";
$areanames{en}->{612829} = "Sydney";
$areanames{en}->{612830} = "Sydney";
$areanames{en}->{612831} = "Sydney";
$areanames{en}->{612832} = "Sydney";
$areanames{en}->{612833} = "Sydney";
$areanames{en}->{612834} = "Sydney";
$areanames{en}->{6128350} = "Sydney";
$areanames{en}->{6128353} = "Sydney";
$areanames{en}->{6128354} = "Sydney";
$areanames{en}->{6128355} = "Sydney";
$areanames{en}->{6128356} = "Sydney";
$areanames{en}->{6128362} = "Sydney";
$areanames{en}->{6128363} = "Sydney";
$areanames{en}->{6128364} = "Sydney";
$areanames{en}->{6128372} = "Sydney";
$areanames{en}->{6128373} = "Sydney";
$areanames{en}->{6128374} = "Sydney";
$areanames{en}->{6128375} = "Sydney";
$areanames{en}->{6128376} = "Sydney";
$areanames{en}->{6128377} = "Sydney";
$areanames{en}->{6128378} = "Sydney";
$areanames{en}->{6128379} = "Sydney";
$areanames{en}->{6128380} = "Sydney";
$areanames{en}->{6128381} = "Sydney";
$areanames{en}->{6128382} = "Sydney";
$areanames{en}->{6128383} = "Sydney";
$areanames{en}->{6128384} = "Sydney";
$areanames{en}->{6128385} = "Sydney";
$areanames{en}->{6128386} = "Sydney";
$areanames{en}->{6128387} = "Sydney";
$areanames{en}->{6128388} = "Sydney";
$areanames{en}->{6128394} = "Sydney";
$areanames{en}->{6128396} = "Sydney";
$areanames{en}->{6128397} = "Sydney";
$areanames{en}->{6128398} = "Sydney";
$areanames{en}->{6128399} = "Sydney";
$areanames{en}->{6128400} = "Avalon\ Beach";
$areanames{en}->{6128401} = "Terrey\ Hills";
$areanames{en}->{6128402} = "Avalon\ Beach";
$areanames{en}->{61284030} = "Terrey\ Hills";
$areanames{en}->{61284031} = "Avalon\ Beach";
$areanames{en}->{61284032} = "Dural";
$areanames{en}->{61284033} = "Avalon\ Beach";
$areanames{en}->{61284034} = "Dural";
$areanames{en}->{61284035} = "Terrey\ Hills";
$areanames{en}->{61284036} = "Dural";
$areanames{en}->{61284037} = "Avalon\ Beach";
$areanames{en}->{61284038} = "Avalon\ Beach";
$areanames{en}->{61284039} = "Terrey\ Hills";
$areanames{en}->{6128404} = "Sydney";
$areanames{en}->{6128405} = "Sydney";
$areanames{en}->{61284059} = "Avalon\ Beach";
$areanames{en}->{6128406} = "Terrey\ Hills";
$areanames{en}->{61284070} = "Terrey\ Hills";
$areanames{en}->{61284071} = "Avalon\ Beach";
$areanames{en}->{61284072} = "Terrey\ Hills";
$areanames{en}->{61284073} = "Dural";
$areanames{en}->{61284074} = "Avalon\ Beach";
$areanames{en}->{61284075} = "Dural";
$areanames{en}->{61284076} = "Terrey\ Hills";
$areanames{en}->{61284077} = "Avalon\ Beach";
$areanames{en}->{61284078} = "Dural";
$areanames{en}->{61284079} = "Terrey\ Hills";
$areanames{en}->{6128408} = "Dural";
$areanames{en}->{6128409} = "Dural";
$areanames{en}->{6128410} = "Dural";
$areanames{en}->{6128411} = "Terrey\ Hills";
$areanames{en}->{6128412} = "Sydney";
$areanames{en}->{6128413} = "Sydney";
$areanames{en}->{6128414} = "Avalon\ Beach";
$areanames{en}->{61284150} = "Dural";
$areanames{en}->{61284151} = "Dural";
$areanames{en}->{61284152} = "Dural";
$areanames{en}->{61284153} = "Terrey\ Hills";
$areanames{en}->{61284154} = "Terrey\ Hills";
$areanames{en}->{61284155} = "Terrey\ Hills";
$areanames{en}->{61284156} = "Sydney";
$areanames{en}->{61284157} = "Sydney";
$areanames{en}->{61284158} = "Sydney";
$areanames{en}->{61284159} = "Sydney";
$areanames{en}->{6128416} = "Sydney";
$areanames{en}->{61284166} = "Dural";
$areanames{en}->{61284167} = "Avalon\ Beach";
$areanames{en}->{61284168} = "Avalon\ Beach";
$areanames{en}->{61284169} = "Dural";
$areanames{en}->{61284170} = "Terrey\ Hills";
$areanames{en}->{61284171} = "Dural";
$areanames{en}->{61284172} = "Sydney";
$areanames{en}->{61284173} = "Terrey\ Hills";
$areanames{en}->{61284174} = "Terrey\ Hills";
$areanames{en}->{61284175} = "Dural";
$areanames{en}->{61284176} = "Avalon\ Beach";
$areanames{en}->{61284177} = "Sydney";
$areanames{en}->{61284178} = "Terrey\ Hills";
$areanames{en}->{61284179} = "Dural";
$areanames{en}->{61284180} = "Terrey\ Hills";
$areanames{en}->{61284181} = "Avalon\ Beach";
$areanames{en}->{61284182} = "Avalon\ Beach";
$areanames{en}->{61284183} = "Dural";
$areanames{en}->{61284184} = "Terrey\ Hills";
$areanames{en}->{61284185} = "Avalon\ Beach";
$areanames{en}->{61284186} = "Dural";
$areanames{en}->{61284187} = "Terrey\ Hills";
$areanames{en}->{61284188} = "Avalon\ Beach";
$areanames{en}->{61284189} = "Dural";
$areanames{en}->{61284190} = "Terrey\ Hills";
$areanames{en}->{61284191} = "Avalon\ Beach";
$areanames{en}->{61284192} = "Dural";
$areanames{en}->{61284193} = "Terrey\ Hills";
$areanames{en}->{61284194} = "Avalon\ Beach";
$areanames{en}->{61284195} = "Dural";
$areanames{en}->{61284196} = "Terrey\ Hills";
$areanames{en}->{61284197} = "Avalon\ Beach";
$areanames{en}->{61284198} = "Dural";
$areanames{en}->{61284199} = "Terrey\ Hills";
$areanames{en}->{61284200} = "Avalon\ Beach";
$areanames{en}->{61284201} = "Dural";
$areanames{en}->{61284202} = "Terrey\ Hills";
$areanames{en}->{61284203} = "Avalon\ Beach";
$areanames{en}->{61284204} = "Dural";
$areanames{en}->{61284205} = "Terrey\ Hills";
$areanames{en}->{6128422} = "Sydney";
$areanames{en}->{6128423} = "Sydney";
$areanames{en}->{6128424} = "Sydney";
$areanames{en}->{6128425} = "Sydney";
$areanames{en}->{6128426} = "Sydney";
$areanames{en}->{6128436} = "Sydney";
$areanames{en}->{6128437} = "Sydney";
$areanames{en}->{6128438} = "Terrey\ Hills";
$areanames{en}->{6128439} = "Terrey\ Hills";
$areanames{en}->{6128440} = "Sydney";
$areanames{en}->{6128443} = "Dural";
$areanames{en}->{6128444} = "Avalon\ Beach";
$areanames{en}->{6128445} = "Terrey\ Hills";
$areanames{en}->{6128446} = "Sydney";
$areanames{en}->{6128447} = "Dural";
$areanames{en}->{6128448} = "Sydney";
$areanames{en}->{6128456} = "Sydney";
$areanames{en}->{6128457} = "Terrey\ Hills";
$areanames{en}->{6128458} = "Sydney";
$areanames{en}->{6128459} = "Sydney";
$areanames{en}->{6128467} = "Sydney";
$areanames{en}->{6128484} = "Sydney";
$areanames{en}->{6128488} = "Sydney";
$areanames{en}->{6128495} = "Avalon\ Beach";
$areanames{en}->{6128500} = "Engadine";
$areanames{en}->{6128501} = "Engadine";
$areanames{en}->{6128502} = "Sutherland";
$areanames{en}->{6128503} = "Engadine";
$areanames{en}->{6128504} = "Sydney";
$areanames{en}->{6128505} = "Sydney";
$areanames{en}->{6128506} = "Sutherland";
$areanames{en}->{6128507} = "Sydney";
$areanames{en}->{6128508} = "Engadine";
$areanames{en}->{6128509} = "Sydney";
$areanames{en}->{6128510} = "Sutherland";
$areanames{en}->{6128511} = "Engadine";
$areanames{en}->{6128512} = "Sydney";
$areanames{en}->{6128513} = "Sutherland";
$areanames{en}->{6128514} = "Sydney";
$areanames{en}->{6128515} = "Sutherland";
$areanames{en}->{6128516} = "Engadine";
$areanames{en}->{6128517} = "Sutherland";
$areanames{en}->{6128518} = "Engadine";
$areanames{en}->{61285181} = "Sutherland";
$areanames{en}->{61285183} = "Sutherland";
$areanames{en}->{61285187} = "Sutherland";
$areanames{en}->{6128519} = "Sutherland";
$areanames{en}->{61285200} = "Sutherland";
$areanames{en}->{61285201} = "Engadine";
$areanames{en}->{61285202} = "Sutherland";
$areanames{en}->{61285203} = "Sydney";
$areanames{en}->{61285204} = "Sutherland";
$areanames{en}->{61285205} = "Sydney";
$areanames{en}->{61285206} = "Engadine";
$areanames{en}->{61285207} = "Engadine";
$areanames{en}->{61285208} = "Sutherland";
$areanames{en}->{61285210} = "Sutherland";
$areanames{en}->{61285211} = "Engadine";
$areanames{en}->{61285212} = "Sutherland";
$areanames{en}->{61285213} = "Engadine";
$areanames{en}->{61285214} = "Sutherland";
$areanames{en}->{61285215} = "Engadine";
$areanames{en}->{61285216} = "Engadine";
$areanames{en}->{61285217} = "Sutherland";
$areanames{en}->{61285218} = "Engadine";
$areanames{en}->{61285219} = "Sutherland";
$areanames{en}->{6128522} = "Sutherland";
$areanames{en}->{6128523} = "Sutherland";
$areanames{en}->{6128524} = "Sydney";
$areanames{en}->{6128525} = "Sutherland";
$areanames{en}->{6128535} = "Sutherland";
$areanames{en}->{6128536} = "Sutherland";
$areanames{en}->{61285370} = "Sutherland";
$areanames{en}->{61285371} = "Sutherland";
$areanames{en}->{61285372} = "Sutherland";
$areanames{en}->{61285373} = "Sutherland";
$areanames{en}->{61285374} = "Sutherland";
$areanames{en}->{6128539} = "Sutherland";
$areanames{en}->{6128540} = "Sydney";
$areanames{en}->{6128541} = "Sydney";
$areanames{en}->{6128542} = "Sydney";
$areanames{en}->{6128543} = "Sutherland";
$areanames{en}->{6128544} = "Sutherland";
$areanames{en}->{6128545} = "Engadine";
$areanames{en}->{61285458} = "Sutherland";
$areanames{en}->{6128548} = "Engadine";
$areanames{en}->{6128549} = "Sydney";
$areanames{en}->{6128555} = "Engadine";
$areanames{en}->{6128556} = "Sutherland";
$areanames{en}->{6128557} = "Engadine";
$areanames{en}->{6128558} = "Sydney";
$areanames{en}->{61285590} = "Sutherland";
$areanames{en}->{6128565} = "Sydney";
$areanames{en}->{6128566} = "Sydney";
$areanames{en}->{6128567} = "Sydney";
$areanames{en}->{6128568} = "Sydney";
$areanames{en}->{6128569} = "Sydney";
$areanames{en}->{612857} = "Sydney";
$areanames{en}->{6128578} = "Sutherland";
$areanames{en}->{6128580} = "Sydney";
$areanames{en}->{61285810} = "Sutherland";
$areanames{en}->{61285811} = "Engadine";
$areanames{en}->{61285812} = "Sutherland";
$areanames{en}->{61285813} = "Sutherland";
$areanames{en}->{61285814} = "Sutherland";
$areanames{en}->{61285815} = "Sutherland";
$areanames{en}->{6128582} = "Sutherland";
$areanames{en}->{6128583} = "Sydney";
$areanames{en}->{6128584} = "Sydney";
$areanames{en}->{6128585} = "Sydney";
$areanames{en}->{6128586} = "Sydney";
$areanames{en}->{6128587} = "Sydney";
$areanames{en}->{6128588} = "Sydney";
$areanames{en}->{6128589} = "Sydney";
$areanames{en}->{612859} = "Sydney";
$areanames{en}->{6128600} = "Blacktown";
$areanames{en}->{6128601} = "Parramatta";
$areanames{en}->{6128602} = "Blacktown";
$areanames{en}->{6128603} = "Blacktown";
$areanames{en}->{6128604} = "Parramatta";
$areanames{en}->{61286047} = "Blacktown";
$areanames{en}->{61286048} = "Blacktown";
$areanames{en}->{61286049} = "Blacktown";
$areanames{en}->{6128605} = "Blacktown";
$areanames{en}->{6128606} = "Parramatta";
$areanames{en}->{6128607} = "Blacktown";
$areanames{en}->{61286076} = "Sydney";
$areanames{en}->{61286077} = "Parramatta";
$areanames{en}->{61286078} = "Sydney";
$areanames{en}->{6128608} = "Blacktown";
$areanames{en}->{61286081} = "Parramatta";
$areanames{en}->{61286090} = "Blacktown";
$areanames{en}->{61286091} = "Blacktown";
$areanames{en}->{61286092} = "Blacktown";
$areanames{en}->{61286093} = "Blacktown";
$areanames{en}->{61286094} = "Blacktown";
$areanames{en}->{61286095} = "Blacktown";
$areanames{en}->{6128610} = "Blacktown";
$areanames{en}->{6128622} = "Sydney";
$areanames{en}->{6128623} = "Parramatta";
$areanames{en}->{6128624} = "Parramatta";
$areanames{en}->{6128625} = "Blacktown";
$areanames{en}->{6128626} = "Parramatta";
$areanames{en}->{6128627} = "Sydney";
$areanames{en}->{6128628} = "Parramatta";
$areanames{en}->{6128629} = "Blacktown";
$areanames{en}->{6128630} = "Blacktown";
$areanames{en}->{6128631} = "Blacktown";
$areanames{en}->{6128632} = "Blacktown";
$areanames{en}->{6128633} = "Parramatta";
$areanames{en}->{6128644} = "Sydney";
$areanames{en}->{6128645} = "Blacktown";
$areanames{en}->{6128646} = "Blacktown";
$areanames{en}->{6128650} = "Sydney";
$areanames{en}->{6128651} = "Sydney";
$areanames{en}->{6128652} = "Blacktown";
$areanames{en}->{61286600} = "Parramatta";
$areanames{en}->{61286601} = "Parramatta";
$areanames{en}->{61286602} = "Parramatta";
$areanames{en}->{61286603} = "Parramatta";
$areanames{en}->{61286604} = "Parramatta";
$areanames{en}->{61286609} = "Blacktown";
$areanames{en}->{6128661} = "Parramatta";
$areanames{en}->{61286620} = "Blacktown";
$areanames{en}->{61286621} = "Blacktown";
$areanames{en}->{61286622} = "Blacktown";
$areanames{en}->{61286623} = "Blacktown";
$areanames{en}->{61286624} = "Blacktown";
$areanames{en}->{61286629} = "Sydney";
$areanames{en}->{6128663} = "Blacktown";
$areanames{en}->{6128664} = "Blacktown";
$areanames{en}->{61286654} = "Sydney";
$areanames{en}->{61286655} = "Parramatta";
$areanames{en}->{61286656} = "Blacktown";
$areanames{en}->{61286657} = "Blacktown";
$areanames{en}->{61286658} = "Blacktown";
$areanames{en}->{61286659} = "Blacktown";
$areanames{en}->{6128666} = "Sydney";
$areanames{en}->{6128667} = "Sydney";
$areanames{en}->{6128668} = "Sydney";
$areanames{en}->{6128669} = "Sydney";
$areanames{en}->{6128670} = "Blacktown";
$areanames{en}->{6128671} = "Blacktown";
$areanames{en}->{61286721} = "Blacktown";
$areanames{en}->{61286722} = "Blacktown";
$areanames{en}->{61286766} = "Parramatta";
$areanames{en}->{61286767} = "Blacktown";
$areanames{en}->{6128677} = "Parramatta";
$areanames{en}->{6128678} = "Blacktown";
$areanames{en}->{6128688} = "Parramatta";
$areanames{en}->{6128700} = "Bankstown";
$areanames{en}->{6128701} = "Sydney";
$areanames{en}->{6128702} = "Bankstown";
$areanames{en}->{6128703} = "Liverpool";
$areanames{en}->{6128704} = "Sydney";
$areanames{en}->{6128705} = "Sydney";
$areanames{en}->{6128706} = "Liverpool";
$areanames{en}->{6128707} = "Bankstown";
$areanames{en}->{6128708} = "Bankstown";
$areanames{en}->{6128709} = "Bankstown";
$areanames{en}->{6128710} = "Bankstown";
$areanames{en}->{6128711} = "Liverpool";
$areanames{en}->{6128712} = "Liverpool";
$areanames{en}->{6128713} = "Bankstown";
$areanames{en}->{6128714} = "Sydney";
$areanames{en}->{6128715} = "Bankstown";
$areanames{en}->{6128716} = "Liverpool";
$areanames{en}->{6128717} = "Bankstown";
$areanames{en}->{6128718} = "Bankstown";
$areanames{en}->{6128719} = "Sydney";
$areanames{en}->{612872} = "Bankstown";
$areanames{en}->{6128721} = "Sydney";
$areanames{en}->{6128726} = "Sydney";
$areanames{en}->{6128727} = "Liverpool";
$areanames{en}->{6128729} = "Liverpool";
$areanames{en}->{61287300} = "Liverpool";
$areanames{en}->{61287301} = "Liverpool";
$areanames{en}->{61287302} = "Bankstown";
$areanames{en}->{61287303} = "Liverpool";
$areanames{en}->{61287304} = "Bankstown";
$areanames{en}->{61287305} = "Liverpool";
$areanames{en}->{61287306} = "Bankstown";
$areanames{en}->{61287307} = "Liverpool";
$areanames{en}->{61287308} = "Bankstown";
$areanames{en}->{61287309} = "Bankstown";
$areanames{en}->{6128731} = "Liverpool";
$areanames{en}->{6128732} = "Sydney";
$areanames{en}->{6128733} = "Bankstown";
$areanames{en}->{61287340} = "Liverpool";
$areanames{en}->{61287341} = "Bankstown";
$areanames{en}->{61287342} = "Liverpool";
$areanames{en}->{61287343} = "Liverpool";
$areanames{en}->{61287344} = "Bankstown";
$areanames{en}->{61287345} = "Liverpool";
$areanames{en}->{61287350} = "Bankstown";
$areanames{en}->{61287351} = "Bankstown";
$areanames{en}->{61287352} = "Bankstown";
$areanames{en}->{61287353} = "Bankstown";
$areanames{en}->{61287354} = "Bankstown";
$areanames{en}->{61287355} = "Liverpool";
$areanames{en}->{61287356} = "Liverpool";
$areanames{en}->{61287357} = "Liverpool";
$areanames{en}->{61287358} = "Liverpool";
$areanames{en}->{61287359} = "Liverpool";
$areanames{en}->{6128736} = "Sydney";
$areanames{en}->{6128737} = "Sydney";
$areanames{en}->{6128738} = "Liverpool";
$areanames{en}->{6128739} = "Bankstown";
$areanames{en}->{6128740} = "Liverpool";
$areanames{en}->{6128741} = "Sydney";
$areanames{en}->{61287420} = "Liverpool";
$areanames{en}->{61287421} = "Liverpool";
$areanames{en}->{61287422} = "Liverpool";
$areanames{en}->{61287423} = "Liverpool";
$areanames{en}->{61287424} = "Liverpool";
$areanames{en}->{6128745} = "Sydney";
$areanames{en}->{6128746} = "Sydney";
$areanames{en}->{61287470} = "Liverpool";
$areanames{en}->{61287471} = "Bankstown";
$areanames{en}->{61287472} = "Bankstown";
$areanames{en}->{61287473} = "Bankstown";
$areanames{en}->{61287474} = "Bankstown";
$areanames{en}->{61287475} = "Bankstown";
$areanames{en}->{61287478} = "Liverpool";
$areanames{en}->{6128748} = "Sydney";
$areanames{en}->{61287490} = "Bankstown";
$areanames{en}->{61287491} = "Bankstown";
$areanames{en}->{61287492} = "Bankstown";
$areanames{en}->{61287493} = "Bankstown";
$areanames{en}->{61287494} = "Sydney";
$areanames{en}->{61287495} = "Sydney";
$areanames{en}->{61287496} = "Sydney";
$areanames{en}->{61287497} = "Liverpool";
$areanames{en}->{61287498} = "Liverpool";
$areanames{en}->{61287499} = "Liverpool";
$areanames{en}->{612875} = "Sydney";
$areanames{en}->{6128760} = "Bankstown";
$areanames{en}->{6128761} = "Bankstown";
$areanames{en}->{6128762} = "Sydney";
$areanames{en}->{6128763} = "Liverpool";
$areanames{en}->{6128764} = "Bankstown";
$areanames{en}->{6128765} = "Sydney";
$areanames{en}->{6128766} = "Bankstown";
$areanames{en}->{6128767} = "Sydney";
$areanames{en}->{6128768} = "Bankstown";
$areanames{en}->{6128769} = "Liverpool";
$areanames{en}->{6128771} = "Bankstown";
$areanames{en}->{6128772} = "Bankstown";
$areanames{en}->{6128773} = "Bankstown";
$areanames{en}->{6128774} = "Bankstown";
$areanames{en}->{6128775} = "Sydney";
$areanames{en}->{6128776} = "Liverpool";
$areanames{en}->{6128777} = "Liverpool";
$areanames{en}->{61287777} = "Sydney";
$areanames{en}->{6128778} = "Liverpool";
$areanames{en}->{6128781} = "Liverpool";
$areanames{en}->{6128782} = "Liverpool";
$areanames{en}->{6128783} = "Liverpool";
$areanames{en}->{6128784} = "Liverpool";
$areanames{en}->{6128785} = "Liverpool";
$areanames{en}->{6128786} = "Liverpool";
$areanames{en}->{6128787} = "Liverpool";
$areanames{en}->{6128788} = "Liverpool";
$areanames{en}->{6128789} = "Sydney";
$areanames{en}->{6128790} = "Bankstown";
$areanames{en}->{6128795} = "Liverpool";
$areanames{en}->{6128796} = "Liverpool";
$areanames{en}->{6128797} = "Liverpool";
$areanames{en}->{6128798} = "Liverpool";
$areanames{en}->{6128799} = "Sydney";
$areanames{en}->{612880} = "Blacktown";
$areanames{en}->{6128800} = "Sydney";
$areanames{en}->{6128802} = "Parramatta";
$areanames{en}->{6128810} = "Parramatta";
$areanames{en}->{6128811} = "Blacktown";
$areanames{en}->{6128812} = "Parramatta";
$areanames{en}->{6128813} = "Parramatta";
$areanames{en}->{6128814} = "Blacktown";
$areanames{en}->{6128815} = "Sydney";
$areanames{en}->{6128816} = "Blacktown";
$areanames{en}->{6128817} = "Sydney";
$areanames{en}->{6128818} = "Blacktown";
$areanames{en}->{6128819} = "Sydney";
$areanames{en}->{6128820} = "Parramatta";
$areanames{en}->{6128821} = "Parramatta";
$areanames{en}->{6128822} = "Blacktown";
$areanames{en}->{6128823} = "Sydney";
$areanames{en}->{6128824} = "Blacktown";
$areanames{en}->{6128825} = "Blacktown";
$areanames{en}->{6128826} = "Parramatta";
$areanames{en}->{6128827} = "Blacktown";
$areanames{en}->{6128828} = "Sydney";
$areanames{en}->{6128829} = "Parramatta";
$areanames{en}->{612883} = "Parramatta";
$areanames{en}->{6128834} = "Blacktown";
$areanames{en}->{612884} = "Parramatta";
$areanames{en}->{6128840} = "Blacktown";
$areanames{en}->{6128847} = "Blacktown";
$areanames{en}->{612885} = "Parramatta";
$areanames{en}->{6128856} = "Blacktown";
$areanames{en}->{6128857} = "Blacktown";
$areanames{en}->{612886} = "Parramatta";
$areanames{en}->{6128864} = "Sydney";
$areanames{en}->{6128866} = "Sydney";
$areanames{en}->{6128867} = "Blacktown";
$areanames{en}->{6128869} = "Blacktown";
$areanames{en}->{612887} = "Sydney";
$areanames{en}->{6128872} = "Parramatta";
$areanames{en}->{612888} = "Blacktown";
$areanames{en}->{6128880} = "Sydney";
$areanames{en}->{612889} = "Parramatta";
$areanames{en}->{6128899} = "Sydney";
$areanames{en}->{612890} = "Sydney";
$areanames{en}->{6128906} = "Dural";
$areanames{en}->{6128909} = "Avalon\ Beach";
$areanames{en}->{6128910} = "Dural";
$areanames{en}->{6128911} = "Terrey\ Hills";
$areanames{en}->{6128912} = "Sydney";
$areanames{en}->{6128913} = "Sydney";
$areanames{en}->{6128914} = "Terrey\ Hills";
$areanames{en}->{6128915} = "Sydney";
$areanames{en}->{6128916} = "Sydney";
$areanames{en}->{6128917} = "Sydney";
$areanames{en}->{6128918} = "Sydney";
$areanames{en}->{61289190} = "Avalon\ Beach";
$areanames{en}->{61289191} = "Dural";
$areanames{en}->{61289192} = "Terrey\ Hills";
$areanames{en}->{61289193} = "Avalon\ Beach";
$areanames{en}->{61289194} = "Dural";
$areanames{en}->{61289195} = "Avalon\ Beach";
$areanames{en}->{61289196} = "Avalon\ Beach";
$areanames{en}->{61289197} = "Dural";
$areanames{en}->{61289198} = "Dural";
$areanames{en}->{6128920} = "Sydney";
$areanames{en}->{6128921} = "Terrey\ Hills";
$areanames{en}->{6128922} = "Sydney";
$areanames{en}->{6128923} = "Sydney";
$areanames{en}->{6128924} = "Terrey\ Hills";
$areanames{en}->{61289240} = "Dural";
$areanames{en}->{6128925} = "Sydney";
$areanames{en}->{61289260} = "Avalon\ Beach";
$areanames{en}->{61289261} = "Avalon\ Beach";
$areanames{en}->{61289262} = "Avalon\ Beach";
$areanames{en}->{6128934} = "Sydney";
$areanames{en}->{6128935} = "Sydney";
$areanames{en}->{6128936} = "Sydney";
$areanames{en}->{6128937} = "Sydney";
$areanames{en}->{6128955} = "Sydney";
$areanames{en}->{6128956} = "Sydney";
$areanames{en}->{6128957} = "Sydney";
$areanames{en}->{6128958} = "Sydney";
$areanames{en}->{6128959} = "Sydney";
$areanames{en}->{612896} = "Sydney";
$areanames{en}->{6128970} = "Sydney";
$areanames{en}->{6128971} = "Sydney";
$areanames{en}->{6128972} = "Sydney";
$areanames{en}->{6128973} = "Sydney";
$areanames{en}->{6128974} = "Sydney";
$areanames{en}->{6128976} = "Sydney";
$areanames{en}->{6128977} = "Sydney";
$areanames{en}->{6128978} = "Sydney";
$areanames{en}->{6128980} = "Avalon\ Beach";
$areanames{en}->{6128985} = "Sydney";
$areanames{en}->{6128986} = "Sydney";
$areanames{en}->{6128987} = "Sydney";
$areanames{en}->{6128988} = "Sydney";
$areanames{en}->{6128989} = "Dural";
$areanames{en}->{6128998} = "Terrey\ Hills";
$areanames{en}->{61289988} = "Sydney";
$areanames{en}->{6128999} = "Sydney";
$areanames{en}->{61290} = "Sydney";
$areanames{en}->{61290345} = "Sydney\/Liverpool";
$areanames{en}->{612903454} = "Liverpool";
$areanames{en}->{6129100} = "Sydney";
$areanames{en}->{6129101} = "Sydney";
$areanames{en}->{6129102} = "Sydney";
$areanames{en}->{6129103} = "Sydney";
$areanames{en}->{6129105} = "Sydney";
$areanames{en}->{61291060} = "Sydney";
$areanames{en}->{61291061} = "Sydney";
$areanames{en}->{61291062} = "Sydney";
$areanames{en}->{61291063} = "Sydney";
$areanames{en}->{61291064} = "Sydney";
$areanames{en}->{6129111} = "Sydney";
$areanames{en}->{6129112} = "Sydney";
$areanames{en}->{6129113} = "Sydney";
$areanames{en}->{6129114} = "Sydney";
$areanames{en}->{6129115} = "Sydney";
$areanames{en}->{6129116} = "Sydney";
$areanames{en}->{6129117} = "Sydney";
$areanames{en}->{6129118} = "Sydney";
$areanames{en}->{6129119} = "Sydney";
$areanames{en}->{6129120} = "Sydney";
$areanames{en}->{6129121} = "Sydney";
$areanames{en}->{6129122} = "Sydney";
$areanames{en}->{6129123} = "Sydney";
$areanames{en}->{6129124} = "Sydney";
$areanames{en}->{6129125} = "Sydney";
$areanames{en}->{6129126} = "Sydney";
$areanames{en}->{612913} = "Sydney";
$areanames{en}->{6129140} = "Sydney";
$areanames{en}->{6129141} = "Sydney";
$areanames{en}->{6129144} = "Sydney";
$areanames{en}->{6129146} = "Sydney";
$areanames{en}->{612915} = "Sydney";
$areanames{en}->{6129153} = "Sutherland";
$areanames{en}->{6129160} = "Sydney";
$areanames{en}->{6129161} = "Sydney";
$areanames{en}->{6129162} = "Sydney";
$areanames{en}->{6129163} = "Sydney";
$areanames{en}->{6129164} = "Sydney";
$areanames{en}->{6129165} = "Sydney";
$areanames{en}->{6129166} = "Sydney";
$areanames{en}->{6129167} = "Sydney";
$areanames{en}->{6129168} = "Sydney";
$areanames{en}->{6129181} = "Sydney";
$areanames{en}->{6129186} = "Sydney";
$areanames{en}->{6129188} = "Sydney";
$areanames{en}->{6129189} = "Sydney";
$areanames{en}->{612919} = "Sydney";
$areanames{en}->{61292} = "Sydney";
$areanames{en}->{6129203} = "Liverpool";
$areanames{en}->{6129204} = "Parramatta";
$areanames{en}->{6129205} = "Bankstown";
$areanames{en}->{6129208} = "Blacktown";
$areanames{en}->{612930} = "Sydney";
$areanames{en}->{612931} = "Sydney";
$areanames{en}->{612932} = "Sydney";
$areanames{en}->{612933} = "Sydney";
$areanames{en}->{612934} = "Sydney";
$areanames{en}->{612935} = "Sydney";
$areanames{en}->{6129354} = "Parramatta";
$areanames{en}->{612936} = "Sydney";
$areanames{en}->{6129372} = "Sydney";
$areanames{en}->{61293723} = "Terrey\ Hills";
$areanames{en}->{612938} = "Sydney";
$areanames{en}->{612939} = "Sydney";
$areanames{en}->{61294} = "Sydney";
$areanames{en}->{6129407} = "Parramatta";
$areanames{en}->{6129408} = "Sutherland";
$areanames{en}->{6129421} = "Blacktown";
$areanames{en}->{6129426} = "Liverpool";
$areanames{en}->{6129441} = "Terrey\ Hills";
$areanames{en}->{6129443} = "Avalon\ Beach";
$areanames{en}->{6129444} = "Dural";
$areanames{en}->{6129445} = "Dural";
$areanames{en}->{6129446} = "Terrey\ Hills";
$areanames{en}->{6129447} = "Terrey\ Hills";
$areanames{en}->{6129450} = "Terrey\ Hills";
$areanames{en}->{6129456} = "Avalon\ Beach";
$areanames{en}->{6129457} = "Terrey\ Hills";
$areanames{en}->{612947} = "Terrey\ Hills";
$areanames{en}->{612948} = "Terrey\ Hills";
$areanames{en}->{612950} = "Sydney";
$areanames{en}->{6129501} = "Sutherland";
$areanames{en}->{612951} = "Sydney";
$areanames{en}->{612952} = "Sutherland";
$areanames{en}->{6129520} = "Engadine";
$areanames{en}->{6129529} = "Sydney";
$areanames{en}->{6129530} = "Sutherland";
$areanames{en}->{6129531} = "Sutherland";
$areanames{en}->{6129532} = "Sutherland";
$areanames{en}->{6129533} = "Sutherland";
$areanames{en}->{6129534} = "Sutherland";
$areanames{en}->{6129535} = "Sutherland";
$areanames{en}->{6129536} = "Sydney";
$areanames{en}->{6129537} = "Sydney";
$areanames{en}->{61295380} = "Sydney";
$areanames{en}->{61295381} = "Sutherland";
$areanames{en}->{61295382} = "Sutherland";
$areanames{en}->{61295383} = "Sutherland";
$areanames{en}->{61295384} = "Sutherland";
$areanames{en}->{61295385} = "Sutherland";
$areanames{en}->{61295386} = "Sydney";
$areanames{en}->{61295395} = "Sydney";
$areanames{en}->{61295396} = "Sydney";
$areanames{en}->{61295397} = "Sydney";
$areanames{en}->{61295398} = "Sydney";
$areanames{en}->{61295399} = "Sydney";
$areanames{en}->{612954} = "Sutherland";
$areanames{en}->{6129546} = "Sydney";
$areanames{en}->{6129547} = "Sydney";
$areanames{en}->{6129548} = "Engadine";
$areanames{en}->{6129549} = "Sydney";
$areanames{en}->{612955} = "Sydney";
$areanames{en}->{612956} = "Sydney";
$areanames{en}->{612957} = "Sydney";
$areanames{en}->{6129574} = "Sutherland";
$areanames{en}->{6129575} = "Sutherland";
$areanames{en}->{6129576} = "Sutherland";
$areanames{en}->{612958} = "Sydney";
$areanames{en}->{6129584} = "Sutherland";
$areanames{en}->{6129589} = "Sutherland";
$areanames{en}->{612959} = "Sydney";
$areanames{en}->{612960} = "Liverpool";
$areanames{en}->{6129610} = "Liverpool";
$areanames{en}->{6129611} = "Sydney";
$areanames{en}->{6129612} = "Liverpool";
$areanames{en}->{6129613} = "Parramatta";
$areanames{en}->{6129614} = "Parramatta";
$areanames{en}->{6129615} = "Parramatta";
$areanames{en}->{6129616} = "Liverpool";
$areanames{en}->{6129617} = "Parramatta";
$areanames{en}->{6129618} = "Liverpool";
$areanames{en}->{6129619} = "Sydney";
$areanames{en}->{612962} = "Blacktown";
$areanames{en}->{612963} = "Parramatta";
$areanames{en}->{6129632} = "Bankstown";
$areanames{en}->{612964} = "Sydney";
$areanames{en}->{6129644} = "Bankstown";
$areanames{en}->{6129645} = "Bankstown";
$areanames{en}->{612965} = "Dural";
$areanames{en}->{6129650} = "Sydney";
$areanames{en}->{6129657} = "Sydney";
$areanames{en}->{6129659} = "Parramatta";
$areanames{en}->{612966} = "Sydney";
$areanames{en}->{6129668} = "Sutherland";
$areanames{en}->{612967} = "Blacktown";
$areanames{en}->{612968} = "Parramatta";
$areanames{en}->{6129681} = "Bankstown";
$areanames{en}->{612969} = "Sydney";
$areanames{en}->{612970} = "Sydney";
$areanames{en}->{6129707} = "Bankstown";
$areanames{en}->{6129708} = "Bankstown";
$areanames{en}->{6129709} = "Bankstown";
$areanames{en}->{612971} = "Sydney";
$areanames{en}->{6129710} = "Sutherland";
$areanames{en}->{6129711} = "Liverpool";
$areanames{en}->{6129717} = "Sutherland";
$areanames{en}->{612972} = "Bankstown";
$areanames{en}->{6129720} = "Liverpool";
$areanames{en}->{6129729} = "Liverpool";
$areanames{en}->{6129730} = "Liverpool";
$areanames{en}->{6129731} = "Liverpool";
$areanames{en}->{6129732} = "Liverpool";
$areanames{en}->{6129733} = "Liverpool";
$areanames{en}->{6129734} = "Liverpool";
$areanames{en}->{6129735} = "Sydney";
$areanames{en}->{6129736} = "Sydney";
$areanames{en}->{6129737} = "Sydney";
$areanames{en}->{6129738} = "Bankstown";
$areanames{en}->{6129739} = "Sydney";
$areanames{en}->{612974} = "Sydney";
$areanames{en}->{61297437} = "Bankstown";
$areanames{en}->{61297438} = "Bankstown";
$areanames{en}->{61297439} = "Bankstown";
$areanames{en}->{6129750} = "Sydney";
$areanames{en}->{6129751} = "Sydney";
$areanames{en}->{6129752} = "Sydney";
$areanames{en}->{61297521} = "Bankstown";
$areanames{en}->{6129753} = "Liverpool";
$areanames{en}->{6129754} = "Bankstown";
$areanames{en}->{6129755} = "Bankstown";
$areanames{en}->{6129756} = "Liverpool";
$areanames{en}->{6129757} = "Liverpool";
$areanames{en}->{6129758} = "Sydney";
$areanames{en}->{6129759} = "Sydney";
$areanames{en}->{6129760} = "Parramatta";
$areanames{en}->{6129761} = "Parramatta";
$areanames{en}->{6129762} = "Parramatta";
$areanames{en}->{6129763} = "Sydney";
$areanames{en}->{6129764} = "Sydney";
$areanames{en}->{6129765} = "Liverpool";
$areanames{en}->{6129766} = "Bankstown";
$areanames{en}->{6129767} = "Sydney";
$areanames{en}->{6129768} = "Parramatta";
$areanames{en}->{6129769} = "Parramatta";
$areanames{en}->{612977} = "Sydney";
$areanames{en}->{6129771} = "Bankstown";
$areanames{en}->{6129772} = "Bankstown";
$areanames{en}->{6129773} = "Bankstown";
$areanames{en}->{6129774} = "Bankstown";
$areanames{en}->{612978} = "Bankstown";
$areanames{en}->{6129784} = "Sydney";
$areanames{en}->{6129787} = "Sydney";
$areanames{en}->{6129789} = "Sydney";
$areanames{en}->{612979} = "Bankstown";
$areanames{en}->{6129797} = "Sydney";
$areanames{en}->{6129798} = "Sydney";
$areanames{en}->{6129799} = "Sydney";
$areanames{en}->{612980} = "Sydney";
$areanames{en}->{6129806} = "Parramatta";
$areanames{en}->{612981} = "Sydney";
$areanames{en}->{612982} = "Liverpool";
$areanames{en}->{612983} = "Blacktown";
$areanames{en}->{612984} = "Parramatta";
$areanames{en}->{6129844} = "Sydney";
$areanames{en}->{61298447} = "Liverpool";
$areanames{en}->{61298463} = "Sydney";
$areanames{en}->{6129847} = "Terrey\ Hills";
$areanames{en}->{612985} = "Sydney";
$areanames{en}->{6129851} = "Blacktown";
$areanames{en}->{6129852} = "Blacktown";
$areanames{en}->{6129853} = "Blacktown";
$areanames{en}->{6129854} = "Blacktown";
$areanames{en}->{6129860} = "Parramatta";
$areanames{en}->{6129861} = "Sydney";
$areanames{en}->{6129862} = "Blacktown";
$areanames{en}->{6129863} = "Blacktown";
$areanames{en}->{6129864} = "Blacktown";
$areanames{en}->{6129865} = "Parramatta";
$areanames{en}->{6129866} = "Sydney";
$areanames{en}->{6129867} = "Sydney";
$areanames{en}->{6129868} = "Sydney";
$areanames{en}->{6129869} = "Sydney";
$areanames{en}->{6129870} = "Sydney";
$areanames{en}->{6129871} = "Parramatta";
$areanames{en}->{6129872} = "Parramatta";
$areanames{en}->{6129873} = "Parramatta";
$areanames{en}->{61298739} = "Sydney";
$areanames{en}->{6129875} = "Terrey\ Hills";
$areanames{en}->{6129876} = "Sydney";
$areanames{en}->{6129877} = "Sydney";
$areanames{en}->{6129878} = "Sydney";
$areanames{en}->{6129879} = "Sydney";
$areanames{en}->{612988} = "Sydney";
$areanames{en}->{6129881} = "Blacktown";
$areanames{en}->{6129883} = "Avalon\ Beach";
$areanames{en}->{6129885} = "Blacktown";
$areanames{en}->{612989} = "Parramatta";
$areanames{en}->{6129892} = "Bankstown";
$areanames{en}->{61299} = "Sydney";
$areanames{en}->{61299105} = "Terrey\ Hills";
$areanames{en}->{61299107} = "Terrey\ Hills";
$areanames{en}->{61299108} = "Terrey\ Hills";
$areanames{en}->{61299109} = "Terrey\ Hills";
$areanames{en}->{61299120} = "Parramatta";
$areanames{en}->{61299121} = "Parramatta";
$areanames{en}->{61299122} = "Parramatta";
$areanames{en}->{61299123} = "Parramatta";
$areanames{en}->{61299124} = "Parramatta";
$areanames{en}->{61299125} = "Blacktown";
$areanames{en}->{61299126} = "Bankstown";
$areanames{en}->{61299127} = "Blacktown";
$areanames{en}->{61299128} = "Blacktown";
$areanames{en}->{61299129} = "Blacktown";
$areanames{en}->{6129913} = "Terrey\ Hills";
$areanames{en}->{61299140} = "Liverpool";
$areanames{en}->{61299141} = "Liverpool";
$areanames{en}->{61299142} = "Bankstown";
$areanames{en}->{61299143} = "Bankstown";
$areanames{en}->{61299144} = "Bankstown";
$areanames{en}->{61299145} = "Bankstown";
$areanames{en}->{61299146} = "Sutherland";
$areanames{en}->{61299147} = "Sutherland";
$areanames{en}->{61299148} = "Bankstown";
$areanames{en}->{61299149} = "Engadine";
$areanames{en}->{61299159} = "Sutherland";
$areanames{en}->{6129918} = "Avalon\ Beach";
$areanames{en}->{6129920} = "Blacktown";
$areanames{en}->{61299330} = "Parramatta";
$areanames{en}->{61299331} = "Parramatta";
$areanames{en}->{61299332} = "Parramatta";
$areanames{en}->{61299333} = "Liverpool";
$areanames{en}->{61299334} = "Liverpool";
$areanames{en}->{61299335} = "Liverpool";
$areanames{en}->{61299336} = "Blacktown";
$areanames{en}->{61299337} = "Blacktown";
$areanames{en}->{61299338} = "Parramatta";
$areanames{en}->{61299339} = "Sutherland";
$areanames{en}->{6129940} = "Terrey\ Hills";
$areanames{en}->{61299430} = "Terrey\ Hills";
$areanames{en}->{61299431} = "Terrey\ Hills";
$areanames{en}->{61299432} = "Terrey\ Hills";
$areanames{en}->{61299433} = "Terrey\ Hills";
$areanames{en}->{61299434} = "Terrey\ Hills";
$areanames{en}->{6129944} = "Terrey\ Hills";
$areanames{en}->{6129945} = "Terrey\ Hills";
$areanames{en}->{6129946} = "Avalon\ Beach";
$areanames{en}->{61299477} = "Parramatta";
$areanames{en}->{6129970} = "Terrey\ Hills";
$areanames{en}->{6129973} = "Avalon\ Beach";
$areanames{en}->{6129974} = "Avalon\ Beach";
$areanames{en}->{6129979} = "Terrey\ Hills";
$areanames{en}->{6129980} = "Terrey\ Hills";
$areanames{en}->{6129985} = "Avalon\ Beach";
$areanames{en}->{6129986} = "Terrey\ Hills";
$areanames{en}->{6129987} = "Terrey\ Hills";
$areanames{en}->{6129989} = "Terrey\ Hills";
$areanames{en}->{6129991} = "Avalon\ Beach";
$areanames{en}->{6129992} = "Dural";
$areanames{en}->{61299966} = "Parramatta";
$areanames{en}->{61299967} = "Parramatta";
$areanames{en}->{6129997} = "Terrey\ Hills";
$areanames{en}->{6129998} = "Terrey\ Hills";
$areanames{en}->{6129999} = "Terrey\ Hills";
$areanames{en}->{61340000} = "Balranald";
$areanames{en}->{61340001} = "Box\ Creek";
$areanames{en}->{61340002} = "Curyo";
$areanames{en}->{61340003} = "Hopetoun";
$areanames{en}->{61340004} = "Patchewollock";
$areanames{en}->{61340005} = "Woomelang";
$areanames{en}->{61340006} = "Anabranch";
$areanames{en}->{61340007} = "Arumpo";
$areanames{en}->{61340008} = "Boundary\ Bend";
$areanames{en}->{61340009} = "Karawinna";
$areanames{en}->{61340010} = "Nangiloc";
$areanames{en}->{61340011} = "Palinyewah";
$areanames{en}->{61340012} = "Pan\ Ban";
$areanames{en}->{61340013} = "Pooncarie";
$areanames{en}->{61340014} = "Robinvale";
$areanames{en}->{61340015} = "Rufus\ River";
$areanames{en}->{61340016} = "Scotia";
$areanames{en}->{61340017} = "Wemen";
$areanames{en}->{61340018} = "Wentworth";
$areanames{en}->{61340019} = "Werrimull";
$areanames{en}->{61340020} = "Willandra\ Lakes";
$areanames{en}->{61340021} = "Turriff";
$areanames{en}->{61340022} = "Cowangie";
$areanames{en}->{61340023} = "Mittyack";
$areanames{en}->{61340024} = "Murrayville";
$areanames{en}->{61340025} = "Ouyen";
$areanames{en}->{61340026} = "Tempy";
$areanames{en}->{61340027} = "Underbool";
$areanames{en}->{61340028} = "Annuello";
$areanames{en}->{61340029} = "Berriwillock";
$areanames{en}->{61340030} = "Culgoa";
$areanames{en}->{61340031} = "Cunninyeuk";
$areanames{en}->{61340032} = "Kyalite";
$areanames{en}->{61340033} = "Mallan";
$areanames{en}->{61340034} = "Manangatang";
$areanames{en}->{61340035} = "Nandaly";
$areanames{en}->{61340036} = "Natya";
$areanames{en}->{61340037} = "Nyah";
$areanames{en}->{61340038} = "Sea\ Lake";
$areanames{en}->{61340039} = "Ultima";
$areanames{en}->{61340040} = "Waitchie";
$areanames{en}->{61340041} = "Balranald";
$areanames{en}->{61340042} = "Box\ Creek";
$areanames{en}->{61340043} = "Curyo";
$areanames{en}->{61340044} = "Hopetoun";
$areanames{en}->{61340045} = "Patchewollock";
$areanames{en}->{61340046} = "Turriff";
$areanames{en}->{61340047} = "Woomelang";
$areanames{en}->{61340048} = "Anabranch";
$areanames{en}->{61340049} = "Arumpo";
$areanames{en}->{61340050} = "Boundary\ Bend";
$areanames{en}->{61340051} = "Karawinna";
$areanames{en}->{61340052} = "Mildura";
$areanames{en}->{61340053} = "Nangiloc";
$areanames{en}->{61340054} = "Palinyewah";
$areanames{en}->{61340055} = "Pan\ Ban";
$areanames{en}->{61340056} = "Pooncarie";
$areanames{en}->{61340057} = "Robinvale";
$areanames{en}->{61340058} = "Rufus\ River";
$areanames{en}->{61340059} = "Scotia";
$areanames{en}->{61340060} = "Wemen";
$areanames{en}->{61340061} = "Wentworth";
$areanames{en}->{61340062} = "Werrimull";
$areanames{en}->{61340063} = "Willandra\ Lakes";
$areanames{en}->{61340064} = "Cowangie";
$areanames{en}->{61340065} = "Mittyack";
$areanames{en}->{61340066} = "Murrayville";
$areanames{en}->{61340067} = "Ouyen";
$areanames{en}->{61340068} = "Tempy";
$areanames{en}->{61340069} = "Underbool";
$areanames{en}->{61340070} = "Annuello";
$areanames{en}->{61340071} = "Berriwillock";
$areanames{en}->{61340072} = "Culgoa";
$areanames{en}->{61340073} = "Cunninyeuk";
$areanames{en}->{61340074} = "Kyalite";
$areanames{en}->{61340075} = "Mallan";
$areanames{en}->{61340076} = "Manangatang";
$areanames{en}->{61340077} = "Nandaly";
$areanames{en}->{61340078} = "Natya";
$areanames{en}->{61340079} = "Nyah";
$areanames{en}->{61340080} = "Sea\ Lake";
$areanames{en}->{61340081} = "Swan\ Hill";
$areanames{en}->{61340082} = "Ultima";
$areanames{en}->{61340083} = "Waitchie";
$areanames{en}->{61340084} = "Wentworth";
$areanames{en}->{61340085} = "Wentworth";
$areanames{en}->{61340086} = "Karawinna";
$areanames{en}->{61340087} = "Karawinna";
$areanames{en}->{61340088} = "Patchewollock";
$areanames{en}->{61340089} = "Patchewollock";
$areanames{en}->{61340090} = "Mildura";
$areanames{en}->{61340091} = "Mildura";
$areanames{en}->{61340092} = "Mildura";
$areanames{en}->{61340093} = "Willandra\ Lakes";
$areanames{en}->{61340094} = "Willandra\ Lakes";
$areanames{en}->{61340095} = "Anabranch";
$areanames{en}->{61340096} = "Anabranch";
$areanames{en}->{61340097} = "Rufus\ River";
$areanames{en}->{61340098} = "Rufus\ River";
$areanames{en}->{61340099} = "Werrimull";
$areanames{en}->{61340100} = "Werrimull";
$areanames{en}->{61340101} = "Cowangie";
$areanames{en}->{61340102} = "Cowangie";
$areanames{en}->{61340103} = "Cunninyeuk";
$areanames{en}->{61340104} = "Cunninyeuk";
$areanames{en}->{61340105} = "Mildura";
$areanames{en}->{61340106} = "Mildura";
$areanames{en}->{61340107} = "Swan\ Hill";
$areanames{en}->{61340108} = "Mildura";
$areanames{en}->{61340109} = "Balranald";
$areanames{en}->{61340110} = "Wentworth";
$areanames{en}->{61340111} = "Mildura";
$areanames{en}->{61340112} = "Box\ Creek";
$areanames{en}->{61340113} = "Balranald";
$areanames{en}->{61340114} = "Manangatang";
$areanames{en}->{61340115} = "Hopetoun";
$areanames{en}->{61340116} = "Wentworth";
$areanames{en}->{61340117} = "Wemen";
$areanames{en}->{61340118} = "Rufus\ River";
$areanames{en}->{61340119} = "Wentworth";
$areanames{en}->{61340120} = "Box\ Creek";
$areanames{en}->{61340121} = "Curyo";
$areanames{en}->{61340122} = "Kyalite";
$areanames{en}->{61340123} = "Sea\ Lake";
$areanames{en}->{61340124} = "Natya";
$areanames{en}->{61340125} = "Berriwillock";
$areanames{en}->{61340126} = "Culgoa";
$areanames{en}->{61340127} = "Ouyen";
$areanames{en}->{61340128} = "Underbool";
$areanames{en}->{61340129} = "Anabranch";
$areanames{en}->{61340130} = "Arumpo";
$areanames{en}->{61340131} = "Anabranch";
$areanames{en}->{61340132} = "Robinvale";
$areanames{en}->{61340133} = "Annuello";
$areanames{en}->{61340134} = "Arumpo";
$areanames{en}->{61340135} = "Palinyewah";
$areanames{en}->{61340136} = "Tempy";
$areanames{en}->{61340137} = "Murrayville";
$areanames{en}->{61340138} = "Nandaly";
$areanames{en}->{61340139} = "Boundary\ Bend";
$areanames{en}->{61340140} = "Karawinna";
$areanames{en}->{61340141} = "Pooncarie";
$areanames{en}->{61340142} = "Mittyack";
$areanames{en}->{61340143} = "Patchewollock";
$areanames{en}->{61340144} = "Boundary\ Bend";
$areanames{en}->{61340145} = "Nangiloc";
$areanames{en}->{61340146} = "Nyah";
$areanames{en}->{61340147} = "Karawinna";
$areanames{en}->{61340148} = "Cunninyeuk";
$areanames{en}->{61340149} = "Mildura";
$areanames{en}->{61340150} = "Nangiloc";
$areanames{en}->{61340151} = "Turriff";
$areanames{en}->{61340152} = "Woomelang";
$areanames{en}->{61340153} = "Mallan";
$areanames{en}->{61340154} = "Cowangie";
$areanames{en}->{61340155} = "Ultima";
$areanames{en}->{61340156} = "Mildura";
$areanames{en}->{61340157} = "Willandra\ Lakes";
$areanames{en}->{61340158} = "Pan\ Ban";
$areanames{en}->{61340159} = "Palinyewah";
$areanames{en}->{61340160} = "Pan\ Ban";
$areanames{en}->{61340161} = "Waitchie";
$areanames{en}->{61340162} = "Swan\ Hill";
$areanames{en}->{61340163} = "Scotia";
$areanames{en}->{61340164} = "Werrimull";
$areanames{en}->{61340165} = "Mildura";
$areanames{en}->{61340166} = "Box\ Creek";
$areanames{en}->{61340167} = "Balranald";
$areanames{en}->{61340168} = "Manangatang";
$areanames{en}->{61340169} = "Pooncarie";
$areanames{en}->{61340170} = "Robinvale";
$areanames{en}->{61340171} = "Hopetoun";
$areanames{en}->{61340172} = "Wentworth";
$areanames{en}->{61340173} = "Wemen";
$areanames{en}->{61340174} = "Rufus\ River";
$areanames{en}->{61340175} = "Curyo";
$areanames{en}->{61340176} = "Kyalite";
$areanames{en}->{61340177} = "Sea\ Lake";
$areanames{en}->{61340178} = "Natya";
$areanames{en}->{61340179} = "Rufus\ River";
$areanames{en}->{61340180} = "Scotia";
$areanames{en}->{61340181} = "Berriwillock";
$areanames{en}->{61340182} = "Culgoa";
$areanames{en}->{61340183} = "Ouyen";
$areanames{en}->{61340184} = "Underbool";
$areanames{en}->{61340185} = "Anabranch";
$areanames{en}->{61340186} = "Robinvale";
$areanames{en}->{61340187} = "Annuello";
$areanames{en}->{61340188} = "Arumpo";
$areanames{en}->{61340189} = "Wemen";
$areanames{en}->{61340190} = "Wentworth";
$areanames{en}->{61340191} = "Palinyewah";
$areanames{en}->{61340192} = "Tempy";
$areanames{en}->{61340193} = "Murrayville";
$areanames{en}->{61340194} = "Nandaly";
$areanames{en}->{61340195} = "Pooncarie";
$areanames{en}->{61340196} = "Mittyack";
$areanames{en}->{61340197} = "Patchewollock";
$areanames{en}->{61340198} = "Boundary\ Bend";
$areanames{en}->{61340199} = "Werrimull";
$areanames{en}->{61340200} = "Willandra\ Lakes";
$areanames{en}->{61340201} = "Nangiloc";
$areanames{en}->{61340202} = "Nyah";
$areanames{en}->{61340203} = "Karawinna";
$areanames{en}->{61340204} = "Cunninyeuk";
$areanames{en}->{61340205} = "Turriff";
$areanames{en}->{61340206} = "Woomelang";
$areanames{en}->{61340207} = "Mallan";
$areanames{en}->{61340208} = "Cowangie";
$areanames{en}->{61340209} = "Annuello";
$areanames{en}->{61340210} = "Berriwillock";
$areanames{en}->{61340211} = "Ultima";
$areanames{en}->{61340212} = "Mildura";
$areanames{en}->{61340213} = "Willandra\ Lakes";
$areanames{en}->{61340214} = "Pan\ Ban";
$areanames{en}->{61340215} = "Waitchie";
$areanames{en}->{61340216} = "Swan\ Hill";
$areanames{en}->{61340217} = "Scotia";
$areanames{en}->{61340218} = "Werrimull";
$areanames{en}->{61340219} = "Culgoa";
$areanames{en}->{61340220} = "Cunninyeuk";
$areanames{en}->{61340221} = "Mildura";
$areanames{en}->{61340222} = "Manangatang";
$areanames{en}->{61340223} = "Hopetoun";
$areanames{en}->{61340224} = "Wentworth";
$areanames{en}->{61340225} = "Wemen";
$areanames{en}->{61340226} = "Rufus\ River";
$areanames{en}->{61340227} = "Curyo";
$areanames{en}->{61340228} = "Kyalite";
$areanames{en}->{61340229} = "Kyalite";
$areanames{en}->{61340230} = "Mallan";
$areanames{en}->{61340231} = "Sea\ Lake";
$areanames{en}->{61340232} = "Natya";
$areanames{en}->{61340233} = "Berriwillock";
$areanames{en}->{61340234} = "Culgoa";
$areanames{en}->{61340235} = "Ouyen";
$areanames{en}->{61340236} = "Underbool";
$areanames{en}->{61340237} = "Anabranch";
$areanames{en}->{61340238} = "Robinvale";
$areanames{en}->{61340239} = "Manangatang";
$areanames{en}->{61340240} = "Nandaly";
$areanames{en}->{61340241} = "Annuello";
$areanames{en}->{61340242} = "Arumpo";
$areanames{en}->{61340243} = "Palinyewah";
$areanames{en}->{61340244} = "Tempy";
$areanames{en}->{61340245} = "Murrayville";
$areanames{en}->{61340246} = "Nandaly";
$areanames{en}->{61340247} = "Pooncarie";
$areanames{en}->{61340248} = "Mittyack";
$areanames{en}->{61340249} = "Natya";
$areanames{en}->{61340250} = "Nyah";
$areanames{en}->{61340251} = "Patchewollock";
$areanames{en}->{61340252} = "Boundary\ Bend";
$areanames{en}->{61340253} = "Nangiloc";
$areanames{en}->{61340254} = "Nyah";
$areanames{en}->{61340255} = "Karawinna";
$areanames{en}->{61340256} = "Cunninyeuk";
$areanames{en}->{61340257} = "Turriff";
$areanames{en}->{61340258} = "Woomelang";
$areanames{en}->{61340259} = "Sea\ Lake";
$areanames{en}->{61340260} = "Swan\ Hill";
$areanames{en}->{61340261} = "Mallan";
$areanames{en}->{61340262} = "Cowangie";
$areanames{en}->{61340263} = "Ultima";
$areanames{en}->{61340264} = "Willandra\ Lakes";
$areanames{en}->{61340265} = "Pan\ Ban";
$areanames{en}->{61340266} = "Waitchie";
$areanames{en}->{61340267} = "Swan\ Hill";
$areanames{en}->{61340268} = "Scotia";
$areanames{en}->{61340269} = "Ultima";
$areanames{en}->{61340270} = "Waitchie";
$areanames{en}->{61340271} = "Werrimull";
$areanames{en}->{61340272} = "Box\ Creek";
$areanames{en}->{61340273} = "Cowangie";
$areanames{en}->{61340274} = "Mittyack";
$areanames{en}->{61340275} = "Murrayville";
$areanames{en}->{61340276} = "Ouyen";
$areanames{en}->{61340277} = "Tempy";
$areanames{en}->{61340278} = "Underbool";
$areanames{en}->{61340279} = "Curyo";
$areanames{en}->{61340280} = "Hopetoun";
$areanames{en}->{61340281} = "Patchewollock";
$areanames{en}->{61340282} = "Turriff";
$areanames{en}->{61340283} = "Woomelang";
$areanames{en}->{61340284} = "Balranald";
$areanames{en}->{61340285} = "Anabranch";
$areanames{en}->{61340286} = "Annuello";
$areanames{en}->{61340287} = "Arumpo";
$areanames{en}->{61340288} = "Balranald";
$areanames{en}->{61340289} = "Berriwillock";
$areanames{en}->{61340290} = "Boundary\ Bend";
$areanames{en}->{61340291} = "Box\ Creek";
$areanames{en}->{61340292} = "Cowangie";
$areanames{en}->{61340293} = "Culgoa";
$areanames{en}->{61340294} = "Cunninyeuk";
$areanames{en}->{61340295} = "Curyo";
$areanames{en}->{61340296} = "Hopetoun";
$areanames{en}->{61340297} = "Karawinna";
$areanames{en}->{61340298} = "Kyalite";
$areanames{en}->{61340299} = "Mallan";
$areanames{en}->{61340300} = "Manangatang";
$areanames{en}->{61340301} = "Mildura";
$areanames{en}->{61340302} = "Mittyack";
$areanames{en}->{61340303} = "Murrayville";
$areanames{en}->{61340304} = "Nandaly";
$areanames{en}->{61340305} = "Nangiloc";
$areanames{en}->{61340306} = "Natya";
$areanames{en}->{61340307} = "Nyah";
$areanames{en}->{61340308} = "Ouyen";
$areanames{en}->{61340309} = "Palinyewah";
$areanames{en}->{61340310} = "Pan\ Ban";
$areanames{en}->{61340311} = "Patchewollock";
$areanames{en}->{61340312} = "Pooncarie";
$areanames{en}->{61340313} = "Robinvale";
$areanames{en}->{61340314} = "Rufus\ River";
$areanames{en}->{61340315} = "Scotia";
$areanames{en}->{61340316} = "Sea\ Lake";
$areanames{en}->{61340317} = "Swan\ Hill";
$areanames{en}->{61340318} = "Tempy";
$areanames{en}->{61340319} = "Turriff";
$areanames{en}->{61340320} = "Ultima";
$areanames{en}->{61340321} = "Underbool";
$areanames{en}->{61340322} = "Waitchie";
$areanames{en}->{61340323} = "Wemen";
$areanames{en}->{61340324} = "Wentworth";
$areanames{en}->{61340325} = "Werrimull";
$areanames{en}->{61340326} = "Willandra\ Lakes";
$areanames{en}->{61340327} = "Woomelang";
$areanames{en}->{61340328} = "Anabranch";
$areanames{en}->{61340329} = "Annuello";
$areanames{en}->{61340330} = "Arumpo";
$areanames{en}->{61340331} = "Balranald";
$areanames{en}->{61340332} = "Berriwillock";
$areanames{en}->{61340333} = "Boundary\ Bend";
$areanames{en}->{61340334} = "Box\ Creek";
$areanames{en}->{61340335} = "Cowangie";
$areanames{en}->{61340336} = "Culgoa";
$areanames{en}->{61340337} = "Cunninyeuk";
$areanames{en}->{61340338} = "Curyo";
$areanames{en}->{61340339} = "Hopetoun";
$areanames{en}->{61340340} = "Karawinna";
$areanames{en}->{61340341} = "Kyalite";
$areanames{en}->{61340342} = "Mallan";
$areanames{en}->{61340343} = "Manangatang";
$areanames{en}->{61340344} = "Mildura";
$areanames{en}->{61340345} = "Mittyack";
$areanames{en}->{61340346} = "Murrayville";
$areanames{en}->{61340347} = "Nandaly";
$areanames{en}->{61340348} = "Nangiloc";
$areanames{en}->{61340349} = "Natya";
$areanames{en}->{61340350} = "Nyah";
$areanames{en}->{61340351} = "Ouyen";
$areanames{en}->{61340352} = "Palinyewah";
$areanames{en}->{61340353} = "Pan\ Ban";
$areanames{en}->{61340354} = "Patchewollock";
$areanames{en}->{61340355} = "Pooncarie";
$areanames{en}->{61340356} = "Robinvale";
$areanames{en}->{61340357} = "Rufus\ River";
$areanames{en}->{61340358} = "Scotia";
$areanames{en}->{61340359} = "Sea\ Lake";
$areanames{en}->{61340360} = "Swan\ Hill";
$areanames{en}->{61340361} = "Tempy";
$areanames{en}->{61340362} = "Turriff";
$areanames{en}->{61340363} = "Ultima";
$areanames{en}->{61340364} = "Underbool";
$areanames{en}->{61340365} = "Waitchie";
$areanames{en}->{61340366} = "Wemen";
$areanames{en}->{61340367} = "Wentworth";
$areanames{en}->{61340368} = "Werrimull";
$areanames{en}->{61340369} = "Willandra\ Lakes";
$areanames{en}->{61340370} = "Woomelang";
$areanames{en}->{61340371} = "Anabranch";
$areanames{en}->{61340372} = "Annuello";
$areanames{en}->{61340373} = "Arumpo";
$areanames{en}->{61340374} = "Balranald";
$areanames{en}->{61340375} = "Berriwillock";
$areanames{en}->{61340376} = "Boundary\ Bend";
$areanames{en}->{61340377} = "Box\ Creek";
$areanames{en}->{61340378} = "Cowangie";
$areanames{en}->{61340379} = "Culgoa";
$areanames{en}->{61340380} = "Cunninyeuk";
$areanames{en}->{61340381} = "Curyo";
$areanames{en}->{61340382} = "Hopetoun";
$areanames{en}->{61340383} = "Karawinna";
$areanames{en}->{61340384} = "Kyalite";
$areanames{en}->{61340385} = "Mallan";
$areanames{en}->{61340386} = "Manangatang";
$areanames{en}->{61340387} = "Mildura";
$areanames{en}->{61340388} = "Mittyack";
$areanames{en}->{61340389} = "Murrayville";
$areanames{en}->{61340390} = "Nandaly";
$areanames{en}->{61340391} = "Nangiloc";
$areanames{en}->{61340392} = "Natya";
$areanames{en}->{61340393} = "Nyah";
$areanames{en}->{61340394} = "Ouyen";
$areanames{en}->{61340395} = "Palinyewah";
$areanames{en}->{61340396} = "Pan\ Ban";
$areanames{en}->{61340397} = "Patchewollock";
$areanames{en}->{61340398} = "Pooncarie";
$areanames{en}->{61340399} = "Robinvale";
$areanames{en}->{61340400} = "Rufus\ River";
$areanames{en}->{61340401} = "Scotia";
$areanames{en}->{61340402} = "Sea\ Lake";
$areanames{en}->{61340403} = "Swan\ Hill";
$areanames{en}->{61340404} = "Mildura";
$areanames{en}->{61340405} = "Mildura";
$areanames{en}->{61340406} = "Murrayville";
$areanames{en}->{61340407} = "Murrayville";
$areanames{en}->{61340408} = "Tempy";
$areanames{en}->{61340409} = "Turriff";
$areanames{en}->{61340410} = "Ultima";
$areanames{en}->{61340411} = "Underbool";
$areanames{en}->{61340412} = "Waitchie";
$areanames{en}->{61340413} = "Wemen";
$areanames{en}->{61340414} = "Wentworth";
$areanames{en}->{61340415} = "Werrimull";
$areanames{en}->{61340416} = "Willandra\ Lakes";
$areanames{en}->{61340417} = "Woomelang";
$areanames{en}->{61340418} = "Anabranch";
$areanames{en}->{61340419} = "Annuello";
$areanames{en}->{61340420} = "Arumpo";
$areanames{en}->{61340421} = "Balranald";
$areanames{en}->{61340422} = "Berriwillock";
$areanames{en}->{61340423} = "Boundary\ Bend";
$areanames{en}->{61340424} = "Box\ Creek";
$areanames{en}->{61340425} = "Cowangie";
$areanames{en}->{61340426} = "Culgoa";
$areanames{en}->{61340427} = "Cunninyeuk";
$areanames{en}->{61340428} = "Curyo";
$areanames{en}->{61340429} = "Hopetoun";
$areanames{en}->{61340430} = "Karawinna";
$areanames{en}->{61340431} = "Kyalite";
$areanames{en}->{61340432} = "Mallan";
$areanames{en}->{61340433} = "Manangatang";
$areanames{en}->{61340434} = "Mildura";
$areanames{en}->{61340435} = "Mittyack";
$areanames{en}->{61340436} = "Murrayville";
$areanames{en}->{61340437} = "Nandaly";
$areanames{en}->{61340438} = "Nangiloc";
$areanames{en}->{61340439} = "Natya";
$areanames{en}->{61340440} = "Nyah";
$areanames{en}->{61340441} = "Ouyen";
$areanames{en}->{61340442} = "Palinyewah";
$areanames{en}->{61340443} = "Pan\ Ban";
$areanames{en}->{61340444} = "Patchewollock";
$areanames{en}->{61340445} = "Pooncarie";
$areanames{en}->{61340446} = "Robinvale";
$areanames{en}->{61340447} = "Rufus\ River";
$areanames{en}->{61340448} = "Scotia";
$areanames{en}->{61340449} = "Sea\ Lake";
$areanames{en}->{61340450} = "Swan\ Hill";
$areanames{en}->{61340451} = "Tempy";
$areanames{en}->{61340452} = "Turriff";
$areanames{en}->{61340453} = "Ultima";
$areanames{en}->{61340454} = "Underbool";
$areanames{en}->{61340455} = "Waitchie";
$areanames{en}->{61340456} = "Wemen";
$areanames{en}->{61340457} = "Wentworth";
$areanames{en}->{61340458} = "Werrimull";
$areanames{en}->{61340459} = "Willandra\ Lakes";
$areanames{en}->{61340460} = "Woomelang";
$areanames{en}->{61340461} = "Anabranch";
$areanames{en}->{61340462} = "Annuello";
$areanames{en}->{61340463} = "Arumpo";
$areanames{en}->{61340464} = "Balranald";
$areanames{en}->{61340465} = "Berriwillock";
$areanames{en}->{61340466} = "Boundary\ Bend";
$areanames{en}->{61340467} = "Box\ Creek";
$areanames{en}->{61340468} = "Cowangie";
$areanames{en}->{61340469} = "Culgoa";
$areanames{en}->{61340470} = "Cunninyeuk";
$areanames{en}->{61340471} = "Curyo";
$areanames{en}->{61340472} = "Hopetoun";
$areanames{en}->{61340473} = "Karawinna";
$areanames{en}->{61340474} = "Kyalite";
$areanames{en}->{61340475} = "Mallan";
$areanames{en}->{61340476} = "Manangatang";
$areanames{en}->{61340477} = "Mildura";
$areanames{en}->{61340478} = "Mittyack";
$areanames{en}->{61340479} = "Murrayville";
$areanames{en}->{61340480} = "Nandaly";
$areanames{en}->{61340481} = "Nangiloc";
$areanames{en}->{61340482} = "Natya";
$areanames{en}->{61340483} = "Nyah";
$areanames{en}->{61340484} = "Ouyen";
$areanames{en}->{61340485} = "Palinyewah";
$areanames{en}->{61340486} = "Pan\ Ban";
$areanames{en}->{61340487} = "Patchewollock";
$areanames{en}->{61340488} = "Pooncarie";
$areanames{en}->{61340489} = "Robinvale";
$areanames{en}->{61340490} = "Rufus\ River";
$areanames{en}->{61340491} = "Scotia";
$areanames{en}->{61340492} = "Sea\ Lake";
$areanames{en}->{61340493} = "Swan\ Hill";
$areanames{en}->{61340494} = "Tempy";
$areanames{en}->{61340495} = "Turriff";
$areanames{en}->{61340496} = "Ultima";
$areanames{en}->{61340497} = "Underbool";
$areanames{en}->{61340498} = "Waitchie";
$areanames{en}->{61340499} = "Wemen";
$areanames{en}->{61340500} = "Wentworth";
$areanames{en}->{61340501} = "Werrimull";
$areanames{en}->{61340502} = "Willandra\ Lakes";
$areanames{en}->{61340503} = "Woomelang";
$areanames{en}->{61340504} = "Anabranch";
$areanames{en}->{61340505} = "Annuello";
$areanames{en}->{61340506} = "Arumpo";
$areanames{en}->{61340507} = "Balranald";
$areanames{en}->{61340508} = "Berriwillock";
$areanames{en}->{61340509} = "Boundary\ Bend";
$areanames{en}->{61340510} = "Box\ Creek";
$areanames{en}->{61340511} = "Cowangie";
$areanames{en}->{61340512} = "Culgoa";
$areanames{en}->{61340513} = "Cunninyeuk";
$areanames{en}->{61340514} = "Curyo";
$areanames{en}->{61340515} = "Hopetoun";
$areanames{en}->{61340516} = "Karawinna";
$areanames{en}->{61340517} = "Kyalite";
$areanames{en}->{61340518} = "Mallan";
$areanames{en}->{61340519} = "Manangatang";
$areanames{en}->{61340520} = "Mildura";
$areanames{en}->{61340521} = "Mittyack";
$areanames{en}->{61340522} = "Murrayville";
$areanames{en}->{61340523} = "Nandaly";
$areanames{en}->{61340524} = "Nangiloc";
$areanames{en}->{61340525} = "Natya";
$areanames{en}->{61340526} = "Nyah";
$areanames{en}->{61340527} = "Ouyen";
$areanames{en}->{61340528} = "Palinyewah";
$areanames{en}->{61340529} = "Pan\ Ban";
$areanames{en}->{61340530} = "Patchewollock";
$areanames{en}->{61340531} = "Pooncarie";
$areanames{en}->{61340532} = "Robinvale";
$areanames{en}->{61340533} = "Rufus\ River";
$areanames{en}->{61340534} = "Scotia";
$areanames{en}->{61340535} = "Sea\ Lake";
$areanames{en}->{61340536} = "Swan\ Hill";
$areanames{en}->{61340537} = "Tempy";
$areanames{en}->{61340538} = "Turriff";
$areanames{en}->{61340539} = "Ultima";
$areanames{en}->{61340540} = "Underbool";
$areanames{en}->{61340541} = "Waitchie";
$areanames{en}->{61340542} = "Wemen";
$areanames{en}->{61340543} = "Wentworth";
$areanames{en}->{61340544} = "Werrimull";
$areanames{en}->{61340545} = "Willandra\ Lakes";
$areanames{en}->{61340546} = "Woomelang";
$areanames{en}->{61340547} = "Anabranch";
$areanames{en}->{61340548} = "Annuello";
$areanames{en}->{61340549} = "Arumpo";
$areanames{en}->{61340550} = "Balranald";
$areanames{en}->{61340551} = "Berriwillock";
$areanames{en}->{61340552} = "Boundary\ Bend";
$areanames{en}->{61340553} = "Box\ Creek";
$areanames{en}->{61340554} = "Cowangie";
$areanames{en}->{61340555} = "Culgoa";
$areanames{en}->{61340556} = "Cunninyeuk";
$areanames{en}->{61340557} = "Curyo";
$areanames{en}->{61340558} = "Hopetoun";
$areanames{en}->{61340559} = "Karawinna";
$areanames{en}->{61340560} = "Kyalite";
$areanames{en}->{61340561} = "Mallan";
$areanames{en}->{61340562} = "Manangatang";
$areanames{en}->{61340563} = "Mildura";
$areanames{en}->{61340564} = "Mittyack";
$areanames{en}->{61340565} = "Murrayville";
$areanames{en}->{61340566} = "Nandaly";
$areanames{en}->{61340567} = "Nangiloc";
$areanames{en}->{61340568} = "Natya";
$areanames{en}->{61340569} = "Nyah";
$areanames{en}->{61340570} = "Ouyen";
$areanames{en}->{61340571} = "Palinyewah";
$areanames{en}->{61340572} = "Pan\ Ban";
$areanames{en}->{61340573} = "Patchewollock";
$areanames{en}->{61340574} = "Pooncarie";
$areanames{en}->{61340575} = "Robinvale";
$areanames{en}->{61340576} = "Rufus\ River";
$areanames{en}->{61340577} = "Scotia";
$areanames{en}->{61340578} = "Sea\ Lake";
$areanames{en}->{61340579} = "Swan\ Hill";
$areanames{en}->{61340580} = "Tempy";
$areanames{en}->{61340581} = "Turriff";
$areanames{en}->{61340582} = "Ultima";
$areanames{en}->{61340583} = "Underbool";
$areanames{en}->{61340584} = "Waitchie";
$areanames{en}->{61340585} = "Wemen";
$areanames{en}->{61340586} = "Wentworth";
$areanames{en}->{61340587} = "Werrimull";
$areanames{en}->{61340588} = "Willandra\ Lakes";
$areanames{en}->{61340589} = "Woomelang";
$areanames{en}->{61340590} = "Anabranch";
$areanames{en}->{61340591} = "Annuello";
$areanames{en}->{61340592} = "Arumpo";
$areanames{en}->{61340593} = "Balranald";
$areanames{en}->{61340594} = "Berriwillock";
$areanames{en}->{61340595} = "Boundary\ Bend";
$areanames{en}->{61340596} = "Box\ Creek";
$areanames{en}->{61340597} = "Cowangie";
$areanames{en}->{61340598} = "Culgoa";
$areanames{en}->{61340599} = "Cunninyeuk";
$areanames{en}->{61340600} = "Curyo";
$areanames{en}->{61340601} = "Hopetoun";
$areanames{en}->{61340602} = "Karawinna";
$areanames{en}->{61340603} = "Kyalite";
$areanames{en}->{61340604} = "Mallan";
$areanames{en}->{61340605} = "Manangatang";
$areanames{en}->{61340606} = "Mildura";
$areanames{en}->{61340607} = "Mittyack";
$areanames{en}->{61340608} = "Murrayville";
$areanames{en}->{61340609} = "Nandaly";
$areanames{en}->{61340610} = "Nangiloc";
$areanames{en}->{61340611} = "Natya";
$areanames{en}->{61340612} = "Nyah";
$areanames{en}->{61340613} = "Ouyen";
$areanames{en}->{61340614} = "Palinyewah";
$areanames{en}->{61340615} = "Pan\ Ban";
$areanames{en}->{61340616} = "Patchewollock";
$areanames{en}->{61340617} = "Pooncarie";
$areanames{en}->{61340618} = "Robinvale";
$areanames{en}->{61340619} = "Rufus\ River";
$areanames{en}->{61340620} = "Scotia";
$areanames{en}->{61340621} = "Sea\ Lake";
$areanames{en}->{61340622} = "Swan\ Hill";
$areanames{en}->{61340623} = "Tempy";
$areanames{en}->{61340624} = "Turriff";
$areanames{en}->{61340625} = "Ultima";
$areanames{en}->{61340626} = "Underbool";
$areanames{en}->{61340627} = "Waitchie";
$areanames{en}->{61340628} = "Wemen";
$areanames{en}->{61340629} = "Wentworth";
$areanames{en}->{61340630} = "Werrimull";
$areanames{en}->{61340631} = "Willandra\ Lakes";
$areanames{en}->{61340632} = "Woomelang";
$areanames{en}->{61341000} = "Bairnsdale";
$areanames{en}->{61341001} = "Bruthen";
$areanames{en}->{61341002} = "Buchan";
$areanames{en}->{61341003} = "Cabbage\ Tree\ Creek";
$areanames{en}->{61341004} = "Cann\ River";
$areanames{en}->{61341005} = "Club\ Terrace";
$areanames{en}->{61341006} = "Combienbar";
$areanames{en}->{61341007} = "Dinner\ Plain";
$areanames{en}->{61341008} = "Ensay";
$areanames{en}->{61341009} = "Gelantipy";
$areanames{en}->{61341010} = "Genoa";
$areanames{en}->{61341011} = "Goongerah";
$areanames{en}->{61341012} = "Lakes\ Entrance";
$areanames{en}->{61341013} = "Lindenow";
$areanames{en}->{61341014} = "Mallacoota";
$areanames{en}->{61341015} = "Meerlieu";
$areanames{en}->{61341016} = "Mount\ Taylor";
$areanames{en}->{61341017} = "Nowa\ Nowa";
$areanames{en}->{61341018} = "Omeo";
$areanames{en}->{61341019} = "Orbost";
$areanames{en}->{61341020} = "Swifts\ Creek";
$areanames{en}->{61341021} = "Baw\ Baw";
$areanames{en}->{61341022} = "Erica";
$areanames{en}->{61341023} = "Gormandale";
$areanames{en}->{61341024} = "Morwell";
$areanames{en}->{61341025} = "Rosedale";
$areanames{en}->{61341026} = "Traralgon";
$areanames{en}->{61341027} = "Woodside";
$areanames{en}->{61341028} = "Yarram";
$areanames{en}->{61341029} = "Yinnar";
$areanames{en}->{61341030} = "Clydebank";
$areanames{en}->{61341031} = "Dargo";
$areanames{en}->{61341032} = "Golden\ Beach";
$areanames{en}->{61341033} = "Heyfield";
$areanames{en}->{61341034} = "Licola";
$areanames{en}->{61341035} = "Loch\ Sport";
$areanames{en}->{61341036} = "Maffra";
$areanames{en}->{61341037} = "Munro";
$areanames{en}->{61341038} = "Sale";
$areanames{en}->{61341039} = "Seaspray";
$areanames{en}->{61341040} = "Bairnsdale";
$areanames{en}->{61341041} = "Bruthen";
$areanames{en}->{61341042} = "Buchan";
$areanames{en}->{61341043} = "Cabbage\ Tree\ Creek";
$areanames{en}->{61341044} = "Cann\ River";
$areanames{en}->{61341045} = "Club\ Terrace";
$areanames{en}->{61341046} = "Combienbar";
$areanames{en}->{61341047} = "Dinner\ Plain";
$areanames{en}->{61341048} = "Ensay";
$areanames{en}->{61341049} = "Gelantipy";
$areanames{en}->{61341050} = "Genoa";
$areanames{en}->{61341051} = "Goongerah";
$areanames{en}->{61341052} = "Lakes\ Entrance";
$areanames{en}->{61341053} = "Lindenow";
$areanames{en}->{61341054} = "Mallacoota";
$areanames{en}->{61341055} = "Meerlieu";
$areanames{en}->{61341056} = "Mount\ Taylor";
$areanames{en}->{61341057} = "Nowa\ Nowa";
$areanames{en}->{61341058} = "Omeo";
$areanames{en}->{61341059} = "Orbost";
$areanames{en}->{61341060} = "Swifts\ Creek";
$areanames{en}->{61341061} = "Baw\ Baw";
$areanames{en}->{61341062} = "Erica";
$areanames{en}->{61341063} = "Gormandale";
$areanames{en}->{61341064} = "Morwell";
$areanames{en}->{61341065} = "Rosedale";
$areanames{en}->{61341066} = "Traralgon";
$areanames{en}->{61341067} = "Woodside";
$areanames{en}->{61341068} = "Yarram";
$areanames{en}->{61341069} = "Yinnar";
$areanames{en}->{61341070} = "Cabbage\ Tree\ Creek";
$areanames{en}->{61341071} = "Cann\ River";
$areanames{en}->{61341072} = "Club\ Terrace";
$areanames{en}->{61341073} = "Combienbar";
$areanames{en}->{61341074} = "Dinner\ Plain";
$areanames{en}->{61341075} = "Ensay";
$areanames{en}->{61341076} = "Gelantipy";
$areanames{en}->{61341077} = "Genoa";
$areanames{en}->{61341078} = "Goongerah";
$areanames{en}->{61341079} = "Lakes\ Entrance";
$areanames{en}->{61341080} = "Lindenow";
$areanames{en}->{61341081} = "Mallacoota";
$areanames{en}->{61341082} = "Meerlieu";
$areanames{en}->{61341083} = "Mount\ Taylor";
$areanames{en}->{61341084} = "Nowa\ Nowa";
$areanames{en}->{61341085} = "Omeo";
$areanames{en}->{61341086} = "Swifts\ Creek";
$areanames{en}->{61341087} = "Bairnsdale";
$areanames{en}->{61341088} = "Bruthen";
$areanames{en}->{61341089} = "Bairnsdale";
$areanames{en}->{61341090} = "Bruthen";
$areanames{en}->{61341091} = "Morwell";
$areanames{en}->{61341092} = "Buchan";
$areanames{en}->{61341093} = "Cabbage\ Tree\ Creek";
$areanames{en}->{61341094} = "Cann\ River";
$areanames{en}->{61341095} = "Club\ Terrace";
$areanames{en}->{61341096} = "Combienbar";
$areanames{en}->{61341097} = "Dinner\ Plain";
$areanames{en}->{61341098} = "Ensay";
$areanames{en}->{61341099} = "Gelantipy";
$areanames{en}->{61341100} = "Genoa";
$areanames{en}->{61341101} = "Goongerah";
$areanames{en}->{61341102} = "Lakes\ Entrance";
$areanames{en}->{61341103} = "Lindenow";
$areanames{en}->{61341104} = "Mallacoota";
$areanames{en}->{61341105} = "Meerlieu";
$areanames{en}->{61341106} = "Orbost";
$areanames{en}->{61341107} = "Swifts\ Creek";
$areanames{en}->{61341108} = "Mount\ Taylor";
$areanames{en}->{61341109} = "Nowa\ Nowa";
$areanames{en}->{61341110} = "Gormandale";
$areanames{en}->{61341111} = "Morwell";
$areanames{en}->{61341112} = "Omeo";
$areanames{en}->{61341113} = "Traralgon";
$areanames{en}->{61341114} = "Orbost";
$areanames{en}->{61341115} = "Swifts\ Creek";
$areanames{en}->{61341116} = "Baw\ Baw";
$areanames{en}->{61341117} = "Erica";
$areanames{en}->{61341118} = "Gormandale";
$areanames{en}->{61341119} = "Morwell";
$areanames{en}->{61341120} = "Heyfield";
$areanames{en}->{61341121} = "Rosedale";
$areanames{en}->{61341122} = "Traralgon";
$areanames{en}->{61341123} = "Woodside";
$areanames{en}->{61341124} = "Yarram";
$areanames{en}->{61341125} = "Sale";
$areanames{en}->{61341126} = "Yinnar";
$areanames{en}->{61341127} = "Dargo";
$areanames{en}->{61341128} = "Dargo";
$areanames{en}->{61341129} = "Heyfield";
$areanames{en}->{61341130} = "Heyfield";
$areanames{en}->{61341131} = "Licola";
$areanames{en}->{61341132} = "Licola";
$areanames{en}->{61341133} = "Seaspray";
$areanames{en}->{61341134} = "Seaspray";
$areanames{en}->{61341135} = "Morwell";
$areanames{en}->{61341136} = "Morwell";
$areanames{en}->{61341137} = "Sale";
$areanames{en}->{61341138} = "Sale";
$areanames{en}->{61341139} = "Sale";
$areanames{en}->{61341140} = "Traralgon";
$areanames{en}->{61341141} = "Traralgon";
$areanames{en}->{61341142} = "Traralgon";
$areanames{en}->{61341143} = "Morwell";
$areanames{en}->{61341144} = "Traralgon";
$areanames{en}->{61341145} = "Orbost";
$areanames{en}->{61341146} = "Clydebank";
$areanames{en}->{61341147} = "Swifts\ Creek";
$areanames{en}->{61341148} = "Mount\ Taylor";
$areanames{en}->{61341149} = "Clydebank";
$areanames{en}->{61341150} = "Dargo";
$areanames{en}->{61341151} = "Golden\ Beach";
$areanames{en}->{61341152} = "Traralgon";
$areanames{en}->{61341153} = "Meerlieu";
$areanames{en}->{61341154} = "Woodside";
$areanames{en}->{61341155} = "Gormandale";
$areanames{en}->{61341156} = "Yinnar";
$areanames{en}->{61341157} = "Cabbage\ Tree\ Creek";
$areanames{en}->{61341158} = "Yarram";
$areanames{en}->{61341159} = "Golden\ Beach";
$areanames{en}->{61341160} = "Heyfield";
$areanames{en}->{61341161} = "Goongerah";
$areanames{en}->{61341162} = "Bairnsdale";
$areanames{en}->{61341163} = "Licola";
$areanames{en}->{61341164} = "Dinner\ Plain";
$areanames{en}->{61341165} = "Ensay";
$areanames{en}->{61341166} = "Sale";
$areanames{en}->{61341167} = "Lakes\ Entrance";
$areanames{en}->{61341168} = "Buchan";
$areanames{en}->{61341169} = "Licola";
$areanames{en}->{61341170} = "Loch\ Sport";
$areanames{en}->{61341171} = "Baw\ Baw";
$areanames{en}->{61341172} = "Rosedale";
$areanames{en}->{61341173} = "Morwell";
$areanames{en}->{61341174} = "Nowa\ Nowa";
$areanames{en}->{61341175} = "Munro";
$areanames{en}->{61341176} = "Club\ Terrace";
$areanames{en}->{61341177} = "Erica";
$areanames{en}->{61341178} = "Cann\ River";
$areanames{en}->{61341179} = "Maffra";
$areanames{en}->{61341180} = "Munro";
$areanames{en}->{61341181} = "Combienbar";
$areanames{en}->{61341182} = "Seaspray";
$areanames{en}->{61341183} = "Lindenow";
$areanames{en}->{61341184} = "Maffra";
$areanames{en}->{61341185} = "Dargo";
$areanames{en}->{61341186} = "Mallacoota";
$areanames{en}->{61341187} = "Loch\ Sport";
$areanames{en}->{61341188} = "Omeo";
$areanames{en}->{61341189} = "Sale";
$areanames{en}->{61341190} = "Seaspray";
$areanames{en}->{61341191} = "Genoa";
$areanames{en}->{61341192} = "Orbost";
$areanames{en}->{61341193} = "Heyfield";
$areanames{en}->{61341194} = "Bruthen";
$areanames{en}->{61341195} = "Gelantipy";
$areanames{en}->{61341196} = "Clydebank";
$areanames{en}->{61341197} = "Swifts\ Creek";
$areanames{en}->{61341198} = "Mount\ Taylor";
$areanames{en}->{61341199} = "Sale";
$areanames{en}->{61341200} = "Morwell";
$areanames{en}->{61341201} = "Golden\ Beach";
$areanames{en}->{61341202} = "Traralgon";
$areanames{en}->{61341203} = "Meerlieu";
$areanames{en}->{61341204} = "Woodside";
$areanames{en}->{61341205} = "Gormandale";
$areanames{en}->{61341206} = "Yinnar";
$areanames{en}->{61341207} = "Cabbage\ Tree\ Creek";
$areanames{en}->{61341208} = "Yarram";
$areanames{en}->{61341209} = "Bairnsdale";
$areanames{en}->{61341210} = "Baw\ Baw";
$areanames{en}->{61341211} = "Goongerah";
$areanames{en}->{61341212} = "Bairnsdale";
$areanames{en}->{61341213} = "Licola";
$areanames{en}->{61341214} = "Dinner\ Plain";
$areanames{en}->{61341215} = "Ensay";
$areanames{en}->{61341216} = "Sale";
$areanames{en}->{61341217} = "Lakes\ Entrance";
$areanames{en}->{61341218} = "Buchan";
$areanames{en}->{61341219} = "Bruthen";
$areanames{en}->{61341220} = "Buchan";
$areanames{en}->{61341221} = "Baw\ Baw";
$areanames{en}->{61341222} = "Rosedale";
$areanames{en}->{61341223} = "Morwell";
$areanames{en}->{61341224} = "Nowa\ Nowa";
$areanames{en}->{61341225} = "Munro";
$areanames{en}->{61341226} = "Club\ Terrace";
$areanames{en}->{61341227} = "Erica";
$areanames{en}->{61341228} = "Cann\ River";
$areanames{en}->{61341229} = "Cabbage\ Tree\ Creek";
$areanames{en}->{61341230} = "Cann\ River";
$areanames{en}->{61341231} = "Combienbar";
$areanames{en}->{61341232} = "Seaspray";
$areanames{en}->{61341233} = "Lindenow";
$areanames{en}->{61341234} = "Maffra";
$areanames{en}->{61341235} = "Dargo";
$areanames{en}->{61341236} = "Mallacoota";
$areanames{en}->{61341237} = "Loch\ Sport";
$areanames{en}->{61341238} = "Omeo";
$areanames{en}->{61341239} = "Club\ Terrace";
$areanames{en}->{61341240} = "Clydebank";
$areanames{en}->{61341241} = "Genoa";
$areanames{en}->{61341242} = "Orbost";
$areanames{en}->{61341243} = "Heyfield";
$areanames{en}->{61341244} = "Bruthen";
$areanames{en}->{61341245} = "Gelantipy";
$areanames{en}->{61341246} = "Lindenow";
$areanames{en}->{61341247} = "Clydebank";
$areanames{en}->{61341248} = "Swifts\ Creek";
$areanames{en}->{61341249} = "Combienbar";
$areanames{en}->{61341250} = "Dargo";
$areanames{en}->{61341251} = "Mount\ Taylor";
$areanames{en}->{61341252} = "Golden\ Beach";
$areanames{en}->{61341253} = "Meerlieu";
$areanames{en}->{61341254} = "Woodside";
$areanames{en}->{61341255} = "Gormandale";
$areanames{en}->{61341256} = "Yinnar";
$areanames{en}->{61341257} = "Cabbage\ Tree\ Creek";
$areanames{en}->{61341258} = "Yarram";
$areanames{en}->{61341259} = "Dinner\ Plain";
$areanames{en}->{61341260} = "Ensay";
$areanames{en}->{61341261} = "Goongerah";
$areanames{en}->{61341262} = "Licola";
$areanames{en}->{61341263} = "Dinner\ Plain";
$areanames{en}->{61341264} = "Ensay";
$areanames{en}->{61341265} = "Buchan";
$areanames{en}->{61341266} = "Baw\ Baw";
$areanames{en}->{61341267} = "Rosedale";
$areanames{en}->{61341268} = "Nowa\ Nowa";
$areanames{en}->{61341269} = "Erica";
$areanames{en}->{61341270} = "Gelantipy";
$areanames{en}->{61341271} = "Munro";
$areanames{en}->{61341272} = "Club\ Terrace";
$areanames{en}->{61341273} = "Erica";
$areanames{en}->{61341274} = "Cann\ River";
$areanames{en}->{61341275} = "Combienbar";
$areanames{en}->{61341276} = "Seaspray";
$areanames{en}->{61341277} = "Dargo";
$areanames{en}->{61341278} = "Mallacoota";
$areanames{en}->{61341279} = "Genoa";
$areanames{en}->{61341280} = "Golden\ Beach";
$areanames{en}->{61341281} = "Loch\ Sport";
$areanames{en}->{61341282} = "Omeo";
$areanames{en}->{61341283} = "Genoa";
$areanames{en}->{61341284} = "Orbost";
$areanames{en}->{61341285} = "Heyfield";
$areanames{en}->{61341286} = "Bruthen";
$areanames{en}->{61341287} = "Gelantipy";
$areanames{en}->{61341288} = "Goongerah";
$areanames{en}->{61341289} = "Gormandale";
$areanames{en}->{61341290} = "Heyfield";
$areanames{en}->{61341291} = "Lakes\ Entrance";
$areanames{en}->{61341292} = "Licola";
$areanames{en}->{61341293} = "Lindenow";
$areanames{en}->{61341294} = "Loch\ Sport";
$areanames{en}->{61341295} = "Maffra";
$areanames{en}->{61341296} = "Mallacoota";
$areanames{en}->{61341297} = "Meerlieu";
$areanames{en}->{61341298} = "Morwell";
$areanames{en}->{61341299} = "Mount\ Taylor";
$areanames{en}->{61341300} = "Munro";
$areanames{en}->{61341301} = "Nowa\ Nowa";
$areanames{en}->{61341302} = "Omeo";
$areanames{en}->{61341303} = "Orbost";
$areanames{en}->{61341304} = "Rosedale";
$areanames{en}->{61341305} = "Sale";
$areanames{en}->{61341306} = "Seaspray";
$areanames{en}->{61341307} = "Swifts\ Creek";
$areanames{en}->{61341308} = "Traralgon";
$areanames{en}->{61341309} = "Woodside";
$areanames{en}->{61341310} = "Yarram";
$areanames{en}->{61341311} = "Yinnar";
$areanames{en}->{61341312} = "Bairnsdale";
$areanames{en}->{61341313} = "Baw\ Baw";
$areanames{en}->{61341314} = "Bruthen";
$areanames{en}->{61341315} = "Buchan";
$areanames{en}->{61341316} = "Cabbage\ Tree\ Creek";
$areanames{en}->{61341317} = "Cann\ River";
$areanames{en}->{61341318} = "Club\ Terrace";
$areanames{en}->{61341319} = "Clydebank";
$areanames{en}->{61341320} = "Combienbar";
$areanames{en}->{61341321} = "Dargo";
$areanames{en}->{61341322} = "Dinner\ Plain";
$areanames{en}->{61341323} = "Ensay";
$areanames{en}->{61341324} = "Erica";
$areanames{en}->{61341325} = "Gelantipy";
$areanames{en}->{61341326} = "Genoa";
$areanames{en}->{61341327} = "Golden\ Beach";
$areanames{en}->{61341328} = "Goongerah";
$areanames{en}->{61341329} = "Gormandale";
$areanames{en}->{61341330} = "Heyfield";
$areanames{en}->{61341331} = "Lakes\ Entrance";
$areanames{en}->{61341332} = "Licola";
$areanames{en}->{61341333} = "Lindenow";
$areanames{en}->{61341334} = "Loch\ Sport";
$areanames{en}->{61341335} = "Maffra";
$areanames{en}->{61341336} = "Mallacoota";
$areanames{en}->{61341337} = "Meerlieu";
$areanames{en}->{61341338} = "Morwell";
$areanames{en}->{61341339} = "Mount\ Taylor";
$areanames{en}->{61341340} = "Munro";
$areanames{en}->{61341341} = "Nowa\ Nowa";
$areanames{en}->{61341342} = "Omeo";
$areanames{en}->{61341343} = "Orbost";
$areanames{en}->{61341344} = "Rosedale";
$areanames{en}->{61341345} = "Sale";
$areanames{en}->{61341346} = "Seaspray";
$areanames{en}->{61341347} = "Swifts\ Creek";
$areanames{en}->{61341348} = "Traralgon";
$areanames{en}->{61341349} = "Woodside";
$areanames{en}->{61341350} = "Yarram";
$areanames{en}->{61341351} = "Yinnar";
$areanames{en}->{61341352} = "Bairnsdale";
$areanames{en}->{61341353} = "Baw\ Baw";
$areanames{en}->{61341354} = "Bruthen";
$areanames{en}->{61341355} = "Buchan";
$areanames{en}->{61341356} = "Cabbage\ Tree\ Creek";
$areanames{en}->{61341357} = "Cann\ River";
$areanames{en}->{61341358} = "Club\ Terrace";
$areanames{en}->{61341359} = "Clydebank";
$areanames{en}->{61341360} = "Combienbar";
$areanames{en}->{61341361} = "Dargo";
$areanames{en}->{61341362} = "Dinner\ Plain";
$areanames{en}->{61341363} = "Ensay";
$areanames{en}->{61341364} = "Erica";
$areanames{en}->{61341365} = "Gelantipy";
$areanames{en}->{61341366} = "Genoa";
$areanames{en}->{61341367} = "Golden\ Beach";
$areanames{en}->{61341368} = "Goongerah";
$areanames{en}->{61341369} = "Gormandale";
$areanames{en}->{61341370} = "Heyfield";
$areanames{en}->{61341371} = "Lakes\ Entrance";
$areanames{en}->{61341372} = "Licola";
$areanames{en}->{61341373} = "Lindenow";
$areanames{en}->{61341374} = "Loch\ Sport";
$areanames{en}->{61341375} = "Maffra";
$areanames{en}->{61341376} = "Mallacoota";
$areanames{en}->{61341377} = "Meerlieu";
$areanames{en}->{61341378} = "Morwell";
$areanames{en}->{61341379} = "Mount\ Taylor";
$areanames{en}->{61341380} = "Munro";
$areanames{en}->{61341381} = "Nowa\ Nowa";
$areanames{en}->{61341382} = "Omeo";
$areanames{en}->{61341383} = "Orbost";
$areanames{en}->{61341384} = "Rosedale";
$areanames{en}->{61341385} = "Sale";
$areanames{en}->{61341386} = "Seaspray";
$areanames{en}->{61341387} = "Swifts\ Creek";
$areanames{en}->{61341388} = "Traralgon";
$areanames{en}->{61341389} = "Woodside";
$areanames{en}->{61341390} = "Yarram";
$areanames{en}->{61341391} = "Yinnar";
$areanames{en}->{61341392} = "Sale";
$areanames{en}->{61341393} = "Bairnsdale";
$areanames{en}->{61341394} = "Sale";
$areanames{en}->{61341395} = "Sale";
$areanames{en}->{61341396} = "Sale";
$areanames{en}->{61341397} = "Woodside";
$areanames{en}->{61341398} = "Woodside";
$areanames{en}->{61341399} = "Woodside";
$areanames{en}->{61341400} = "Bairnsdale";
$areanames{en}->{61341401} = "Baw\ Baw";
$areanames{en}->{61341402} = "Bruthen";
$areanames{en}->{61341403} = "Buchan";
$areanames{en}->{61341404} = "Cabbage\ Tree\ Creek";
$areanames{en}->{61341405} = "Cann\ River";
$areanames{en}->{61341406} = "Club\ Terrace";
$areanames{en}->{61341407} = "Clydebank";
$areanames{en}->{61341408} = "Combienbar";
$areanames{en}->{61341409} = "Dargo";
$areanames{en}->{61341410} = "Dinner\ Plain";
$areanames{en}->{61341411} = "Morwell";
$areanames{en}->{61341412} = "Morwell";
$areanames{en}->{61341413} = "Morwell";
$areanames{en}->{61341414} = "Sale";
$areanames{en}->{61341415} = "Bairnsdale";
$areanames{en}->{61341416} = "Dargo";
$areanames{en}->{61341417} = "Dargo";
$areanames{en}->{61341418} = "Dargo";
$areanames{en}->{61341419} = "Ensay";
$areanames{en}->{61341420} = "Erica";
$areanames{en}->{61341421} = "Gelantipy";
$areanames{en}->{61341422} = "Genoa";
$areanames{en}->{61341423} = "Golden\ Beach";
$areanames{en}->{61341424} = "Goongerah";
$areanames{en}->{61341425} = "Gormandale";
$areanames{en}->{61341426} = "Heyfield";
$areanames{en}->{61341427} = "Lakes\ Entrance";
$areanames{en}->{61341428} = "Licola";
$areanames{en}->{61341429} = "Lindenow";
$areanames{en}->{61341430} = "Loch\ Sport";
$areanames{en}->{61341431} = "Maffra";
$areanames{en}->{61341432} = "Mallacoota";
$areanames{en}->{61341433} = "Meerlieu";
$areanames{en}->{61341434} = "Morwell";
$areanames{en}->{61341435} = "Bairnsdale";
$areanames{en}->{61341436} = "Baw\ Baw";
$areanames{en}->{61341437} = "Bruthen";
$areanames{en}->{61341438} = "Buchan";
$areanames{en}->{61341439} = "Cabbage\ Tree\ Creek";
$areanames{en}->{61341440} = "Cann\ River";
$areanames{en}->{61341441} = "Club\ Terrace";
$areanames{en}->{61341442} = "Clydebank";
$areanames{en}->{61341443} = "Combienbar";
$areanames{en}->{61341444} = "Dargo";
$areanames{en}->{61341445} = "Dinner\ Plain";
$areanames{en}->{61341446} = "Ensay";
$areanames{en}->{61341447} = "Erica";
$areanames{en}->{61341448} = "Gelantipy";
$areanames{en}->{61341449} = "Genoa";
$areanames{en}->{61341450} = "Golden\ Beach";
$areanames{en}->{61341451} = "Goongerah";
$areanames{en}->{61341452} = "Gormandale";
$areanames{en}->{61341453} = "Heyfield";
$areanames{en}->{61341454} = "Lakes\ Entrance";
$areanames{en}->{61341455} = "Licola";
$areanames{en}->{61341456} = "Lindenow";
$areanames{en}->{61341457} = "Loch\ Sport";
$areanames{en}->{61341458} = "Maffra";
$areanames{en}->{61341459} = "Mallacoota";
$areanames{en}->{61341460} = "Meerlieu";
$areanames{en}->{61341461} = "Morwell";
$areanames{en}->{61341462} = "Mount\ Taylor";
$areanames{en}->{61341463} = "Munro";
$areanames{en}->{61341464} = "Nowa\ Nowa";
$areanames{en}->{61341465} = "Omeo";
$areanames{en}->{61341466} = "Orbost";
$areanames{en}->{61341467} = "Rosedale";
$areanames{en}->{61341468} = "Sale";
$areanames{en}->{61341469} = "Seaspray";
$areanames{en}->{61341470} = "Swifts\ Creek";
$areanames{en}->{61341471} = "Traralgon";
$areanames{en}->{61341472} = "Woodside";
$areanames{en}->{61341473} = "Yarram";
$areanames{en}->{61341474} = "Yinnar";
$areanames{en}->{61341475} = "Mount\ Taylor";
$areanames{en}->{61341476} = "Munro";
$areanames{en}->{61341477} = "Nowa\ Nowa";
$areanames{en}->{61341478} = "Omeo";
$areanames{en}->{61341479} = "Orbost";
$areanames{en}->{61341480} = "Rosedale";
$areanames{en}->{61341481} = "Sale";
$areanames{en}->{61341482} = "Seaspray";
$areanames{en}->{61341483} = "Swifts\ Creek";
$areanames{en}->{61341484} = "Traralgon";
$areanames{en}->{61341485} = "Woodside";
$areanames{en}->{61341486} = "Yarram";
$areanames{en}->{61341487} = "Yinnar";
$areanames{en}->{61341488} = "Bairnsdale";
$areanames{en}->{61341489} = "Baw\ Baw";
$areanames{en}->{61341490} = "Bruthen";
$areanames{en}->{61341491} = "Buchan";
$areanames{en}->{61341492} = "Cabbage\ Tree\ Creek";
$areanames{en}->{61341493} = "Cann\ River";
$areanames{en}->{61341494} = "Club\ Terrace";
$areanames{en}->{61341495} = "Clydebank";
$areanames{en}->{61341496} = "Combienbar";
$areanames{en}->{61341497} = "Dargo";
$areanames{en}->{61341498} = "Dinner\ Plain";
$areanames{en}->{61341499} = "Ensay";
$areanames{en}->{61341500} = "Erica";
$areanames{en}->{61341501} = "Gelantipy";
$areanames{en}->{61341502} = "Genoa";
$areanames{en}->{61341503} = "Golden\ Beach";
$areanames{en}->{61341504} = "Goongerah";
$areanames{en}->{61341505} = "Gormandale";
$areanames{en}->{61341506} = "Heyfield";
$areanames{en}->{61341507} = "Lakes\ Entrance";
$areanames{en}->{61341508} = "Licola";
$areanames{en}->{61341509} = "Lindenow";
$areanames{en}->{61341510} = "Loch\ Sport";
$areanames{en}->{61341511} = "Maffra";
$areanames{en}->{61341512} = "Mallacoota";
$areanames{en}->{61341513} = "Meerlieu";
$areanames{en}->{61341514} = "Morwell";
$areanames{en}->{61341515} = "Mount\ Taylor";
$areanames{en}->{61341516} = "Munro";
$areanames{en}->{61341517} = "Nowa\ Nowa";
$areanames{en}->{61341518} = "Omeo";
$areanames{en}->{61341519} = "Orbost";
$areanames{en}->{61341520} = "Rosedale";
$areanames{en}->{61341521} = "Sale";
$areanames{en}->{61341522} = "Seaspray";
$areanames{en}->{61341523} = "Swifts\ Creek";
$areanames{en}->{61341524} = "Traralgon";
$areanames{en}->{61341525} = "Woodside";
$areanames{en}->{61341526} = "Yarram";
$areanames{en}->{61341527} = "Yinnar";
$areanames{en}->{61341528} = "Bairnsdale";
$areanames{en}->{61341529} = "Baw\ Baw";
$areanames{en}->{61341530} = "Bruthen";
$areanames{en}->{61341531} = "Buchan";
$areanames{en}->{61341532} = "Cabbage\ Tree\ Creek";
$areanames{en}->{61341533} = "Cann\ River";
$areanames{en}->{61341534} = "Club\ Terrace";
$areanames{en}->{61341535} = "Clydebank";
$areanames{en}->{61341536} = "Combienbar";
$areanames{en}->{61341537} = "Dargo";
$areanames{en}->{61341538} = "Dinner\ Plain";
$areanames{en}->{61341539} = "Ensay";
$areanames{en}->{61341540} = "Erica";
$areanames{en}->{61341541} = "Gelantipy";
$areanames{en}->{61341542} = "Genoa";
$areanames{en}->{61341543} = "Golden\ Beach";
$areanames{en}->{61341544} = "Goongerah";
$areanames{en}->{61341545} = "Gormandale";
$areanames{en}->{61341546} = "Heyfield";
$areanames{en}->{61341547} = "Lakes\ Entrance";
$areanames{en}->{61341548} = "Licola";
$areanames{en}->{61341549} = "Lindenow";
$areanames{en}->{61341550} = "Loch\ Sport";
$areanames{en}->{61341551} = "Maffra";
$areanames{en}->{61341552} = "Mallacoota";
$areanames{en}->{61341553} = "Meerlieu";
$areanames{en}->{61341554} = "Morwell";
$areanames{en}->{61341555} = "Mount\ Taylor";
$areanames{en}->{61341556} = "Munro";
$areanames{en}->{61341557} = "Nowa\ Nowa";
$areanames{en}->{61341558} = "Omeo";
$areanames{en}->{61341559} = "Orbost";
$areanames{en}->{61341560} = "Rosedale";
$areanames{en}->{61341561} = "Sale";
$areanames{en}->{61341562} = "Seaspray";
$areanames{en}->{61341563} = "Swifts\ Creek";
$areanames{en}->{61341564} = "Traralgon";
$areanames{en}->{61341565} = "Woodside";
$areanames{en}->{61341566} = "Yarram";
$areanames{en}->{61341567} = "Yinnar";
$areanames{en}->{61341568} = "Bairnsdale";
$areanames{en}->{61341569} = "Baw\ Baw";
$areanames{en}->{61341570} = "Bruthen";
$areanames{en}->{61341571} = "Buchan";
$areanames{en}->{61341572} = "Cabbage\ Tree\ Creek";
$areanames{en}->{61341573} = "Cann\ River";
$areanames{en}->{61341574} = "Club\ Terrace";
$areanames{en}->{61341575} = "Clydebank";
$areanames{en}->{61341576} = "Combienbar";
$areanames{en}->{61341577} = "Dargo";
$areanames{en}->{61341578} = "Dinner\ Plain";
$areanames{en}->{61341579} = "Ensay";
$areanames{en}->{61341580} = "Erica";
$areanames{en}->{61341581} = "Gelantipy";
$areanames{en}->{61341582} = "Genoa";
$areanames{en}->{61341583} = "Golden\ Beach";
$areanames{en}->{61341584} = "Goongerah";
$areanames{en}->{61341585} = "Gormandale";
$areanames{en}->{61341586} = "Heyfield";
$areanames{en}->{61341587} = "Lakes\ Entrance";
$areanames{en}->{61341588} = "Licola";
$areanames{en}->{61341589} = "Lindenow";
$areanames{en}->{61341590} = "Loch\ Sport";
$areanames{en}->{61341591} = "Maffra";
$areanames{en}->{61341592} = "Mallacoota";
$areanames{en}->{61341593} = "Meerlieu";
$areanames{en}->{61341594} = "Morwell";
$areanames{en}->{61341595} = "Mount\ Taylor";
$areanames{en}->{61341596} = "Munro";
$areanames{en}->{61341597} = "Nowa\ Nowa";
$areanames{en}->{61341598} = "Omeo";
$areanames{en}->{61341599} = "Orbost";
$areanames{en}->{61341600} = "Rosedale";
$areanames{en}->{61341601} = "Sale";
$areanames{en}->{61341602} = "Seaspray";
$areanames{en}->{61341603} = "Swifts\ Creek";
$areanames{en}->{61341604} = "Traralgon";
$areanames{en}->{61341605} = "Woodside";
$areanames{en}->{61341606} = "Yarram";
$areanames{en}->{61341607} = "Yinnar";
$areanames{en}->{61342000} = "Beech\ Forest";
$areanames{en}->{61342001} = "Birregurra";
$areanames{en}->{61342002} = "Colac";
$areanames{en}->{61342003} = "Cressy";
$areanames{en}->{61342004} = "Kennedys\ Creek";
$areanames{en}->{61342005} = "Lavers\ Hill";
$areanames{en}->{61342006} = "Swan\ Marsh";
$areanames{en}->{61342007} = "Aireys\ Inlet";
$areanames{en}->{61342008} = "Anglesea";
$areanames{en}->{61342009} = "Bannockburn";
$areanames{en}->{61342010} = "Geelong";
$areanames{en}->{61342011} = "Inverleigh";
$areanames{en}->{61342012} = "Lara";
$areanames{en}->{61342013} = "Lorne";
$areanames{en}->{61342014} = "Meredith";
$areanames{en}->{61342015} = "Queenscliff";
$areanames{en}->{61342016} = "Torquay";
$areanames{en}->{61342017} = "Bannockburn";
$areanames{en}->{61342018} = "Meredith";
$areanames{en}->{61342019} = "Lorne";
$areanames{en}->{6134202} = "Queenscliff";
$areanames{en}->{61342030} = "Geelong";
$areanames{en}->{61342031} = "Aireys\ Inlet";
$areanames{en}->{61342032} = "Anglesea";
$areanames{en}->{61342033} = "Bannockburn";
$areanames{en}->{61342034} = "Inverleigh";
$areanames{en}->{61342035} = "Lara";
$areanames{en}->{61342036} = "Lorne";
$areanames{en}->{61342037} = "Meredith";
$areanames{en}->{61342038} = "Queenscliff";
$areanames{en}->{61342039} = "Torquay";
$areanames{en}->{61342040} = "Winchelsea\ South";
$areanames{en}->{61342041} = "Wingeel";
$areanames{en}->{61342042} = "Lara";
$areanames{en}->{61342043} = "Inverleigh";
$areanames{en}->{61342044} = "Apollo\ Bay";
$areanames{en}->{61342045} = "Apollo\ Bay";
$areanames{en}->{61342046} = "Barwon\ Downs";
$areanames{en}->{61342047} = "Barwon\ Downs";
$areanames{en}->{61342048} = "Beeac";
$areanames{en}->{61342049} = "Beeac";
$areanames{en}->{61342050} = "Birregurra";
$areanames{en}->{61342051} = "Birregurra";
$areanames{en}->{61342052} = "Colac";
$areanames{en}->{61342053} = "Colac";
$areanames{en}->{61342054} = "Cressy";
$areanames{en}->{61342055} = "Cressy";
$areanames{en}->{61342056} = "Lavers\ Hill";
$areanames{en}->{61342057} = "Lavers\ Hill";
$areanames{en}->{61342058} = "Swan\ Marsh";
$areanames{en}->{61342059} = "Swan\ Marsh";
$areanames{en}->{61342060} = "Geelong";
$areanames{en}->{61342061} = "Geelong";
$areanames{en}->{61342062} = "Queenscliff";
$areanames{en}->{61342063} = "Aireys\ Inlet";
$areanames{en}->{61342064} = "Aireys\ Inlet";
$areanames{en}->{61342065} = "Geelong";
$areanames{en}->{61342066} = "Geelong";
$areanames{en}->{61342067} = "Geelong";
$areanames{en}->{61342068} = "Beech\ Forest";
$areanames{en}->{61342069} = "Beech\ Forest";
$areanames{en}->{6134207} = "Geelong";
$areanames{en}->{6134208} = "Geelong";
$areanames{en}->{6134209} = "Geelong";
$areanames{en}->{61342100} = "Geelong";
$areanames{en}->{61342101} = "Geelong";
$areanames{en}->{61342102} = "Lara";
$areanames{en}->{61342103} = "Torquay";
$areanames{en}->{61342104} = "Apollo\ Bay";
$areanames{en}->{61342105} = "Lavers\ Hill";
$areanames{en}->{61342106} = "Inverleigh";
$areanames{en}->{61342107} = "Winchelsea\ South";
$areanames{en}->{61342108} = "Bannockburn";
$areanames{en}->{61342109} = "Geelong";
$areanames{en}->{61342110} = "Geelong";
$areanames{en}->{61342111} = "Beeac";
$areanames{en}->{61342112} = "Cressy";
$areanames{en}->{61342113} = "Aireys\ Inlet";
$areanames{en}->{61342114} = "Beech\ Forest";
$areanames{en}->{61342115} = "Wingeel";
$areanames{en}->{61342116} = "Swan\ Marsh";
$areanames{en}->{61342117} = "Kennedys\ Creek";
$areanames{en}->{61342118} = "Birregurra";
$areanames{en}->{61342119} = "Geelong";
$areanames{en}->{61342120} = "Geelong";
$areanames{en}->{61342121} = "Queenscliff";
$areanames{en}->{61342122} = "Lorne";
$areanames{en}->{61342123} = "Meredith";
$areanames{en}->{61342124} = "Colac";
$areanames{en}->{61342125} = "Anglesea";
$areanames{en}->{61342126} = "Barwon\ Downs";
$areanames{en}->{61342127} = "Lara";
$areanames{en}->{61342128} = "Torquay";
$areanames{en}->{61342129} = "Aireys\ Inlet";
$areanames{en}->{61342130} = "Anglesea";
$areanames{en}->{61342131} = "Apollo\ Bay";
$areanames{en}->{61342132} = "Lavers\ Hill";
$areanames{en}->{61342133} = "Inverleigh";
$areanames{en}->{61342134} = "Winchelsea\ South";
$areanames{en}->{61342135} = "Bannockburn";
$areanames{en}->{61342136} = "Beeac";
$areanames{en}->{61342137} = "Cressy";
$areanames{en}->{61342138} = "Aireys\ Inlet";
$areanames{en}->{61342139} = "Apollo\ Bay";
$areanames{en}->{61342140} = "Bannockburn";
$areanames{en}->{61342141} = "Beech\ Forest";
$areanames{en}->{61342142} = "Wingeel";
$areanames{en}->{61342143} = "Swan\ Marsh";
$areanames{en}->{61342144} = "Kennedys\ Creek";
$areanames{en}->{61342145} = "Birregurra";
$areanames{en}->{61342146} = "Queenscliff";
$areanames{en}->{61342147} = "Lorne";
$areanames{en}->{61342148} = "Meredith";
$areanames{en}->{61342149} = "Geelong";
$areanames{en}->{6134215} = "Geelong";
$areanames{en}->{61342160} = "Geelong";
$areanames{en}->{61342161} = "Geelong";
$areanames{en}->{61342162} = "Colac";
$areanames{en}->{61342163} = "Anglesea";
$areanames{en}->{61342164} = "Barwon\ Downs";
$areanames{en}->{61342165} = "Geelong";
$areanames{en}->{61342166} = "Torquay";
$areanames{en}->{61342167} = "Apollo\ Bay";
$areanames{en}->{61342168} = "Lavers\ Hill";
$areanames{en}->{61342169} = "Barwon\ Downs";
$areanames{en}->{61342170} = "Beeac";
$areanames{en}->{61342171} = "Inverleigh";
$areanames{en}->{61342172} = "Winchelsea\ South";
$areanames{en}->{61342173} = "Bannockburn";
$areanames{en}->{61342174} = "Beeac";
$areanames{en}->{61342175} = "Cressy";
$areanames{en}->{61342176} = "Aireys\ Inlet";
$areanames{en}->{61342177} = "Beech\ Forest";
$areanames{en}->{61342178} = "Wingeel";
$areanames{en}->{61342179} = "Beech\ Forest";
$areanames{en}->{61342180} = "Birregurra";
$areanames{en}->{61342181} = "Swan\ Marsh";
$areanames{en}->{61342182} = "Kennedys\ Creek";
$areanames{en}->{61342183} = "Birregurra";
$areanames{en}->{61342184} = "Lorne";
$areanames{en}->{61342185} = "Meredith";
$areanames{en}->{61342186} = "Anglesea";
$areanames{en}->{61342187} = "Barwon\ Downs";
$areanames{en}->{61342188} = "Geelong";
$areanames{en}->{61342189} = "Colac";
$areanames{en}->{61342190} = "Cressy";
$areanames{en}->{61342191} = "Geelong";
$areanames{en}->{61342192} = "Geelong";
$areanames{en}->{61342193} = "Inverleigh";
$areanames{en}->{61342194} = "Kennedys\ Creek";
$areanames{en}->{61342195} = "Lara";
$areanames{en}->{61342196} = "Lavers\ Hill";
$areanames{en}->{61342197} = "Lorne";
$areanames{en}->{61342198} = "Meredith";
$areanames{en}->{61342199} = "Queenscliff";
$areanames{en}->{61342200} = "Swan\ Marsh";
$areanames{en}->{61342201} = "Torquay";
$areanames{en}->{61342202} = "Winchelsea\ South";
$areanames{en}->{61342203} = "Wingeel";
$areanames{en}->{61342204} = "Aireys\ Inlet";
$areanames{en}->{61342205} = "Anglesea";
$areanames{en}->{61342206} = "Apollo\ Bay";
$areanames{en}->{61342207} = "Bannockburn";
$areanames{en}->{61342208} = "Barwon\ Downs";
$areanames{en}->{61342209} = "Beeac";
$areanames{en}->{61342210} = "Beech\ Forest";
$areanames{en}->{61342211} = "Birregurra";
$areanames{en}->{61342212} = "Colac";
$areanames{en}->{61342213} = "Cressy";
$areanames{en}->{61342214} = "Geelong";
$areanames{en}->{61342215} = "Inverleigh";
$areanames{en}->{61342216} = "Kennedys\ Creek";
$areanames{en}->{61342217} = "Lara";
$areanames{en}->{61342218} = "Lavers\ Hill";
$areanames{en}->{61342219} = "Lorne";
$areanames{en}->{61342220} = "Meredith";
$areanames{en}->{61342221} = "Queenscliff";
$areanames{en}->{61342222} = "Swan\ Marsh";
$areanames{en}->{61342223} = "Torquay";
$areanames{en}->{61342224} = "Winchelsea\ South";
$areanames{en}->{61342225} = "Wingeel";
$areanames{en}->{61342226} = "Geelong";
$areanames{en}->{61342227} = "Geelong";
$areanames{en}->{61342228} = "Geelong";
$areanames{en}->{61342229} = "Geelong";
$areanames{en}->{61342230} = "Aireys\ Inlet";
$areanames{en}->{61342231} = "Anglesea";
$areanames{en}->{61342232} = "Apollo\ Bay";
$areanames{en}->{61342233} = "Bannockburn";
$areanames{en}->{61342234} = "Barwon\ Downs";
$areanames{en}->{61342235} = "Beeac";
$areanames{en}->{61342236} = "Beech\ Forest";
$areanames{en}->{61342237} = "Birregurra";
$areanames{en}->{61342238} = "Colac";
$areanames{en}->{61342239} = "Cressy";
$areanames{en}->{61342240} = "Geelong";
$areanames{en}->{61342241} = "Inverleigh";
$areanames{en}->{61342242} = "Kennedys\ Creek";
$areanames{en}->{61342243} = "Lara";
$areanames{en}->{61342244} = "Lavers\ Hill";
$areanames{en}->{61342245} = "Lorne";
$areanames{en}->{61342246} = "Meredith";
$areanames{en}->{61342247} = "Queenscliff";
$areanames{en}->{61342248} = "Swan\ Marsh";
$areanames{en}->{61342249} = "Torquay";
$areanames{en}->{61342250} = "Winchelsea\ South";
$areanames{en}->{61342251} = "Wingeel";
$areanames{en}->{61342252} = "Queenscliff";
$areanames{en}->{61342253} = "Colac";
$areanames{en}->{61342254} = "Aireys\ Inlet";
$areanames{en}->{61342255} = "Geelong";
$areanames{en}->{61342256} = "Geelong";
$areanames{en}->{61342257} = "Geelong";
$areanames{en}->{61342258} = "Geelong";
$areanames{en}->{61342259} = "Geelong";
$areanames{en}->{61342260} = "Geelong";
$areanames{en}->{61342261} = "Geelong";
$areanames{en}->{61342262} = "Geelong";
$areanames{en}->{61342263} = "Geelong";
$areanames{en}->{61342264} = "Queenscliff";
$areanames{en}->{61342265} = "Queenscliff";
$areanames{en}->{61342266} = "Queenscliff";
$areanames{en}->{61342267} = "Torquay";
$areanames{en}->{61342268} = "Torquay";
$areanames{en}->{61342269} = "Torquay";
$areanames{en}->{61342270} = "Geelong";
$areanames{en}->{61342271} = "Geelong";
$areanames{en}->{61342272} = "Geelong";
$areanames{en}->{61342273} = "Geelong";
$areanames{en}->{61342274} = "Aireys\ Inlet";
$areanames{en}->{61342275} = "Anglesea";
$areanames{en}->{61342276} = "Apollo\ Bay";
$areanames{en}->{61342277} = "Bannockburn";
$areanames{en}->{61342278} = "Barwon\ Downs";
$areanames{en}->{61342279} = "Beeac";
$areanames{en}->{61342280} = "Beech\ Forest";
$areanames{en}->{61342281} = "Birregurra";
$areanames{en}->{61342282} = "Colac";
$areanames{en}->{61342283} = "Cressy";
$areanames{en}->{61342284} = "Geelong";
$areanames{en}->{61342285} = "Inverleigh";
$areanames{en}->{61342286} = "Kennedys\ Creek";
$areanames{en}->{61342287} = "Lara";
$areanames{en}->{61342288} = "Lavers\ Hill";
$areanames{en}->{61342289} = "Lorne";
$areanames{en}->{61342290} = "Meredith";
$areanames{en}->{61342291} = "Queenscliff";
$areanames{en}->{61342292} = "Swan\ Marsh";
$areanames{en}->{61342293} = "Torquay";
$areanames{en}->{61342294} = "Winchelsea\ South";
$areanames{en}->{61342295} = "Wingeel";
$areanames{en}->{61342296} = "Anglesea";
$areanames{en}->{61342297} = "Apollo\ Bay";
$areanames{en}->{61342298} = "Bannockburn";
$areanames{en}->{61342299} = "Barwon\ Downs";
$areanames{en}->{61342300} = "Beeac";
$areanames{en}->{61342301} = "Beech\ Forest";
$areanames{en}->{61342302} = "Birregurra";
$areanames{en}->{61342303} = "Colac";
$areanames{en}->{61342304} = "Cressy";
$areanames{en}->{61342305} = "Geelong";
$areanames{en}->{61342306} = "Inverleigh";
$areanames{en}->{61342307} = "Kennedys\ Creek";
$areanames{en}->{61342308} = "Lara";
$areanames{en}->{61342309} = "Lavers\ Hill";
$areanames{en}->{61342310} = "Lorne";
$areanames{en}->{61342311} = "Meredith";
$areanames{en}->{61342312} = "Queenscliff";
$areanames{en}->{61342313} = "Swan\ Marsh";
$areanames{en}->{61342314} = "Torquay";
$areanames{en}->{61342315} = "Winchelsea\ South";
$areanames{en}->{61342316} = "Wingeel";
$areanames{en}->{61342317} = "Aireys\ Inlet";
$areanames{en}->{61342318} = "Anglesea";
$areanames{en}->{61342319} = "Apollo\ Bay";
$areanames{en}->{61342320} = "Bannockburn";
$areanames{en}->{61342321} = "Barwon\ Downs";
$areanames{en}->{61342322} = "Beeac";
$areanames{en}->{61342323} = "Beech\ Forest";
$areanames{en}->{61342324} = "Birregurra";
$areanames{en}->{61342325} = "Colac";
$areanames{en}->{61342326} = "Cressy";
$areanames{en}->{61342327} = "Geelong";
$areanames{en}->{61342328} = "Inverleigh";
$areanames{en}->{61342329} = "Kennedys\ Creek";
$areanames{en}->{61342330} = "Lara";
$areanames{en}->{61342331} = "Lavers\ Hill";
$areanames{en}->{61342332} = "Lorne";
$areanames{en}->{61342333} = "Meredith";
$areanames{en}->{61342334} = "Queenscliff";
$areanames{en}->{61342335} = "Swan\ Marsh";
$areanames{en}->{61342336} = "Torquay";
$areanames{en}->{61342337} = "Winchelsea\ South";
$areanames{en}->{61342338} = "Wingeel";
$areanames{en}->{61342339} = "Aireys\ Inlet";
$areanames{en}->{61342340} = "Anglesea";
$areanames{en}->{61342341} = "Apollo\ Bay";
$areanames{en}->{61342342} = "Bannockburn";
$areanames{en}->{61342343} = "Barwon\ Downs";
$areanames{en}->{61342344} = "Beeac";
$areanames{en}->{61342345} = "Beech\ Forest";
$areanames{en}->{61342346} = "Birregurra";
$areanames{en}->{61342347} = "Colac";
$areanames{en}->{61342348} = "Cressy";
$areanames{en}->{61342349} = "Geelong";
$areanames{en}->{61342350} = "Inverleigh";
$areanames{en}->{61342351} = "Kennedys\ Creek";
$areanames{en}->{61342352} = "Lara";
$areanames{en}->{61342353} = "Lavers\ Hill";
$areanames{en}->{61342354} = "Lorne";
$areanames{en}->{61342355} = "Meredith";
$areanames{en}->{61342356} = "Queenscliff";
$areanames{en}->{61342357} = "Swan\ Marsh";
$areanames{en}->{61342358} = "Torquay";
$areanames{en}->{61342359} = "Winchelsea\ South";
$areanames{en}->{61342360} = "Wingeel";
$areanames{en}->{61342361} = "Aireys\ Inlet";
$areanames{en}->{61342362} = "Anglesea";
$areanames{en}->{61342363} = "Apollo\ Bay";
$areanames{en}->{61342364} = "Bannockburn";
$areanames{en}->{61342365} = "Barwon\ Downs";
$areanames{en}->{61342366} = "Beeac";
$areanames{en}->{61342367} = "Beech\ Forest";
$areanames{en}->{61342368} = "Birregurra";
$areanames{en}->{61342369} = "Colac";
$areanames{en}->{61342370} = "Cressy";
$areanames{en}->{61342371} = "Geelong";
$areanames{en}->{61342372} = "Inverleigh";
$areanames{en}->{61342373} = "Kennedys\ Creek";
$areanames{en}->{61342374} = "Lara";
$areanames{en}->{61342375} = "Lavers\ Hill";
$areanames{en}->{61342376} = "Lorne";
$areanames{en}->{61342377} = "Meredith";
$areanames{en}->{61342378} = "Queenscliff";
$areanames{en}->{61342379} = "Swan\ Marsh";
$areanames{en}->{61342380} = "Torquay";
$areanames{en}->{61342381} = "Winchelsea\ South";
$areanames{en}->{61342382} = "Wingeel";
$areanames{en}->{61342383} = "Queenscliff";
$areanames{en}->{61342412} = "Torquay";
$areanames{en}->{61342413} = "Torquay";
$areanames{en}->{61342414} = "Queenscliff";
$areanames{en}->{61342415} = "Lara";
$areanames{en}->{61342416} = "Geelong";
$areanames{en}->{61342417} = "Torquay";
$areanames{en}->{61342418} = "Torquay";
$areanames{en}->{61342419} = "Torquay";
$areanames{en}->{61342424} = "Geelong";
$areanames{en}->{61342425} = "Geelong";
$areanames{en}->{61342426} = "Geelong";
$areanames{en}->{61342427} = "Geelong";
$areanames{en}->{61342428} = "Kennedys\ Creek";
$areanames{en}->{61342429} = "Kennedys\ Creek";
$areanames{en}->{6134243} = "Geelong";
$areanames{en}->{61342440} = "Queenscliff";
$areanames{en}->{61342441} = "Geelong";
$areanames{en}->{61342442} = "Geelong";
$areanames{en}->{61342443} = "Barwon\ Downs";
$areanames{en}->{61342444} = "Barwon\ Downs";
$areanames{en}->{61342445} = "Barwon\ Downs";
$areanames{en}->{61342446} = "Torquay";
$areanames{en}->{61342447} = "Colac";
$areanames{en}->{61342448} = "Geelong";
$areanames{en}->{61342449} = "Geelong";
$areanames{en}->{6134245} = "Geelong";
$areanames{en}->{61342460} = "Geelong";
$areanames{en}->{61342461} = "Geelong";
$areanames{en}->{6134300} = "Horsham";
$areanames{en}->{61343010} = "Stawell";
$areanames{en}->{61343011} = "Daylesford";
$areanames{en}->{61343012} = "Mount\ Wallace";
$areanames{en}->{61343013} = "Mount\ Wallace";
$areanames{en}->{61343014} = "Bacchus\ Marsh";
$areanames{en}->{61343015} = "Ballarat";
$areanames{en}->{61343016} = "Ballarat";
$areanames{en}->{613430173} = "Ballarat";
$areanames{en}->{61343018} = "Yaapeet";
$areanames{en}->{61343019} = "Yaapeet";
$areanames{en}->{6134302} = "Bacchus\ Marsh";
$areanames{en}->{6134303} = "Ballarat";
$areanames{en}->{6134304} = "Ballarat";
$areanames{en}->{61343050} = "Banyena";
$areanames{en}->{61343051} = "Banyena";
$areanames{en}->{61343052} = "Beulah";
$areanames{en}->{61343053} = "Beulah";
$areanames{en}->{61343054} = "Clear\ Lake";
$areanames{en}->{61343055} = "Clear\ Lake";
$areanames{en}->{61343056} = "Crymelon";
$areanames{en}->{61343057} = "Crymelon";
$areanames{en}->{61343058} = "Gerang\ Gerung";
$areanames{en}->{61343059} = "Gerang\ Gerung";
$areanames{en}->{61343060} = "Goroke";
$areanames{en}->{61343061} = "Goroke";
$areanames{en}->{61343062} = "Jeparit";
$areanames{en}->{61343063} = "Jeparit";
$areanames{en}->{61343064} = "Minimay";
$areanames{en}->{61343065} = "Minimay";
$areanames{en}->{61343066} = "Minyip";
$areanames{en}->{61343067} = "Minyip";
$areanames{en}->{61343068} = "Rainbow";
$areanames{en}->{61343069} = "Rainbow";
$areanames{en}->{61343070} = "Broughton";
$areanames{en}->{61343071} = "Broughton";
$areanames{en}->{61343072} = "Lorquon";
$areanames{en}->{61343073} = "Lorquon";
$areanames{en}->{61343074} = "Serviceton";
$areanames{en}->{61343075} = "Serviceton";
$areanames{en}->{61343076} = "Telopea\ Downs";
$areanames{en}->{61343077} = "Telopea\ Downs";
$areanames{en}->{61343078} = "Marnoo";
$areanames{en}->{61343079} = "Marnoo";
$areanames{en}->{6134308} = "Ballarat";
$areanames{en}->{61343090} = "Ballarat";
$areanames{en}->{61343091} = "Bacchus\ Marsh";
$areanames{en}->{61343092} = "Bacchus\ Marsh";
$areanames{en}->{61343093} = "Ararat";
$areanames{en}->{61343094} = "Ballarat";
$areanames{en}->{61343095} = "Stawell";
$areanames{en}->{61343096} = "Horsham";
$areanames{en}->{61343097} = "Bacchus\ Marsh";
$areanames{en}->{61343098} = "Stawell";
$areanames{en}->{61343099} = "Ararat";
$areanames{en}->{61343100} = "Bacchus\ Marsh";
$areanames{en}->{61343101} = "Horsham";
$areanames{en}->{61343102} = "Ballarat";
$areanames{en}->{61343103} = "Ballan";
$areanames{en}->{61343104} = "Beaufort";
$areanames{en}->{61343105} = "Horsham";
$areanames{en}->{61343106} = "Ballarat";
$areanames{en}->{61343107} = "Ballarat";
$areanames{en}->{61343108} = "Bacchus\ Marsh";
$areanames{en}->{61343109} = "Creswick";
$areanames{en}->{61343110} = "Creswick";
$areanames{en}->{61343111} = "Ballarat";
$areanames{en}->{61343112} = "Halls\ Gap";
$areanames{en}->{61343113} = "Buninyong";
$areanames{en}->{61343114} = "Ballarat";
$areanames{en}->{613431150} = "Ararat";
$areanames{en}->{613431151} = "Bacchus\ Marsh";
$areanames{en}->{613431152} = "Ballan";
$areanames{en}->{613431153} = "Ballarat";
$areanames{en}->{613431154} = "Balliang";
$areanames{en}->{613431155} = "Bangerang";
$areanames{en}->{613431156} = "Banyena";
$areanames{en}->{613431157} = "Beaufort";
$areanames{en}->{613431158} = "Beulah";
$areanames{en}->{613431159} = "Broughton";
$areanames{en}->{613431160} = "Buangor";
$areanames{en}->{613431161} = "Buninyong";
$areanames{en}->{613431162} = "Clear\ Lake";
$areanames{en}->{613431163} = "Creswick";
$areanames{en}->{613431164} = "Crymelon";
$areanames{en}->{613431165} = "Dadswells\ Bridge";
$areanames{en}->{613431166} = "Daylesford";
$areanames{en}->{613431167} = "Dimboola";
$areanames{en}->{613431168} = "Elmhurst";
$areanames{en}->{613431169} = "Gerang\ Gerung";
$areanames{en}->{613431170} = "Glenisla";
$areanames{en}->{613431171} = "Glenorchy";
$areanames{en}->{613431172} = "Goroke";
$areanames{en}->{613431173} = "Halls\ Gap";
$areanames{en}->{613431174} = "Horsham";
$areanames{en}->{613431175} = "Jeparit";
$areanames{en}->{613431176} = "Kalkee";
$areanames{en}->{613431177} = "Kaniva";
$areanames{en}->{613431178} = "Laharum";
$areanames{en}->{613431179} = "Lake\ Bolac";
$areanames{en}->{613431180} = "Landsborough";
$areanames{en}->{613431181} = "Learmonth";
$areanames{en}->{613431182} = "Linton";
$areanames{en}->{613431183} = "Lorquon";
$areanames{en}->{613431184} = "Marnoo";
$areanames{en}->{613431185} = "Maroona";
$areanames{en}->{613431186} = "Minimay";
$areanames{en}->{613431187} = "Minyip";
$areanames{en}->{613431188} = "Mount\ Wallace";
$areanames{en}->{613431189} = "Moyston";
$areanames{en}->{613431190} = "Murtoa";
$areanames{en}->{613431191} = "Natimuk";
$areanames{en}->{613431192} = "Navarre";
$areanames{en}->{613431193} = "Nhill";
$areanames{en}->{613431194} = "Polkemmet";
$areanames{en}->{613431195} = "Rainbow";
$areanames{en}->{613431196} = "Rokewood";
$areanames{en}->{613431197} = "Scarsdale";
$areanames{en}->{613431198} = "Serviceton";
$areanames{en}->{613431199} = "Skipton";
$areanames{en}->{613431200} = "Stawell";
$areanames{en}->{613431201} = "Stoneleigh";
$areanames{en}->{613431202} = "Streatham";
$areanames{en}->{613431203} = "Telopea\ Downs";
$areanames{en}->{613431204} = "Warracknabeal";
$areanames{en}->{613431205} = "Wilkur";
$areanames{en}->{613431206} = "Willaura";
$areanames{en}->{613431207} = "Yaapeet";
$areanames{en}->{613431208} = "Ararat";
$areanames{en}->{613431209} = "Bacchus\ Marsh";
$areanames{en}->{61343121} = "Rokewood";
$areanames{en}->{61343122} = "Bangerang";
$areanames{en}->{61343123} = "Banyena";
$areanames{en}->{61343124} = "Beaufort";
$areanames{en}->{61343125} = "Beulah";
$areanames{en}->{61343126} = "Broughton";
$areanames{en}->{61343127} = "Buangor";
$areanames{en}->{61343128} = "Buninyong";
$areanames{en}->{61343129} = "Clear\ Lake";
$areanames{en}->{6134313} = "Ballarat";
$areanames{en}->{61343130} = "Creswick";
$areanames{en}->{61343131} = "Crymelon";
$areanames{en}->{61343140} = "Dimboola";
$areanames{en}->{61343141} = "Elmhurst";
$areanames{en}->{61343142} = "Gerang\ Gerung";
$areanames{en}->{61343143} = "Glenorchy";
$areanames{en}->{61343144} = "Goroke";
$areanames{en}->{61343145} = "Jeparit";
$areanames{en}->{61343146} = "Kalkee";
$areanames{en}->{61343147} = "Laharum";
$areanames{en}->{61343148} = "Lake\ Bolac";
$areanames{en}->{61343149} = "Landsborough";
$areanames{en}->{61343150} = "Learmonth";
$areanames{en}->{61343151} = "Linton";
$areanames{en}->{61343152} = "Lorquon";
$areanames{en}->{61343153} = "Marnoo";
$areanames{en}->{61343154} = "Minyip";
$areanames{en}->{61343155} = "Mount\ Wallace";
$areanames{en}->{61343156} = "Moyston";
$areanames{en}->{61343157} = "Murtoa";
$areanames{en}->{61343158} = "Natimuk";
$areanames{en}->{61343159} = "Navarre";
$areanames{en}->{61343160} = "Skipton";
$areanames{en}->{61343161} = "Stawell";
$areanames{en}->{61343162} = "Stoneleigh";
$areanames{en}->{61343163} = "Streatham";
$areanames{en}->{61343164} = "Telopea\ Downs";
$areanames{en}->{61343165} = "Wilkur";
$areanames{en}->{61343166} = "Willaura";
$areanames{en}->{61343167} = "Yaapeet";
$areanames{en}->{61343168} = "Kaniva";
$areanames{en}->{613431690} = "Ballan";
$areanames{en}->{613431691} = "Ballarat";
$areanames{en}->{613431692} = "Balliang";
$areanames{en}->{613431693} = "Bangerang";
$areanames{en}->{613431694} = "Banyena";
$areanames{en}->{613431695} = "Beaufort";
$areanames{en}->{613431696} = "Beulah";
$areanames{en}->{613431697} = "Broughton";
$areanames{en}->{613431698} = "Buangor";
$areanames{en}->{613431699} = "Buninyong";
$areanames{en}->{613431700} = "Clear\ Lake";
$areanames{en}->{613431701} = "Creswick";
$areanames{en}->{613431702} = "Crymelon";
$areanames{en}->{613431703} = "Dadswells\ Bridge";
$areanames{en}->{613431704} = "Daylesford";
$areanames{en}->{613431705} = "Dimboola";
$areanames{en}->{613431706} = "Elmhurst";
$areanames{en}->{613431707} = "Gerang\ Gerung";
$areanames{en}->{613431708} = "Glenisla";
$areanames{en}->{613431709} = "Glenorchy";
$areanames{en}->{613431710} = "Goroke";
$areanames{en}->{613431711} = "Halls\ Gap";
$areanames{en}->{613431712} = "Horsham";
$areanames{en}->{613431713} = "Jeparit";
$areanames{en}->{613431714} = "Kalkee";
$areanames{en}->{613431715} = "Kaniva";
$areanames{en}->{613431716} = "Laharum";
$areanames{en}->{613431717} = "Lake\ Bolac";
$areanames{en}->{613431718} = "Landsborough";
$areanames{en}->{613431719} = "Learmonth";
$areanames{en}->{613431720} = "Linton";
$areanames{en}->{613431721} = "Lorquon";
$areanames{en}->{613431722} = "Marnoo";
$areanames{en}->{613431723} = "Maroona";
$areanames{en}->{613431724} = "Minimay";
$areanames{en}->{613431725} = "Minyip";
$areanames{en}->{613431726} = "Mount\ Wallace";
$areanames{en}->{613431727} = "Moyston";
$areanames{en}->{613431728} = "Murtoa";
$areanames{en}->{613431729} = "Natimuk";
$areanames{en}->{613431730} = "Navarre";
$areanames{en}->{613431731} = "Nhill";
$areanames{en}->{613431732} = "Polkemmet";
$areanames{en}->{613431733} = "Rainbow";
$areanames{en}->{613431734} = "Rokewood";
$areanames{en}->{613431735} = "Scarsdale";
$areanames{en}->{613431736} = "Serviceton";
$areanames{en}->{613431737} = "Skipton";
$areanames{en}->{613431738} = "Stawell";
$areanames{en}->{613431739} = "Stoneleigh";
$areanames{en}->{613431740} = "Streatham";
$areanames{en}->{613431741} = "Telopea\ Downs";
$areanames{en}->{613431742} = "Warracknabeal";
$areanames{en}->{613431743} = "Wilkur";
$areanames{en}->{613431744} = "Willaura";
$areanames{en}->{613431745} = "Yaapeet";
$areanames{en}->{613431746} = "Ararat";
$areanames{en}->{613431747} = "Bacchus\ Marsh";
$areanames{en}->{613431748} = "Ballan";
$areanames{en}->{613431749} = "Ballarat";
$areanames{en}->{61343175} = "Scarsdale";
$areanames{en}->{613431760} = "Balliang";
$areanames{en}->{613431761} = "Bangerang";
$areanames{en}->{613431762} = "Banyena";
$areanames{en}->{613431763} = "Beaufort";
$areanames{en}->{613431764} = "Beulah";
$areanames{en}->{613431765} = "Broughton";
$areanames{en}->{613431766} = "Buangor";
$areanames{en}->{613431767} = "Buninyong";
$areanames{en}->{613431768} = "Clear\ Lake";
$areanames{en}->{613431769} = "Creswick";
$areanames{en}->{613431770} = "Crymelon";
$areanames{en}->{613431771} = "Dadswells\ Bridge";
$areanames{en}->{613431772} = "Daylesford";
$areanames{en}->{613431773} = "Dimboola";
$areanames{en}->{613431774} = "Elmhurst";
$areanames{en}->{613431775} = "Gerang\ Gerung";
$areanames{en}->{613431776} = "Glenisla";
$areanames{en}->{613431777} = "Glenorchy";
$areanames{en}->{613431778} = "Goroke";
$areanames{en}->{613431779} = "Halls\ Gap";
$areanames{en}->{613431780} = "Horsham";
$areanames{en}->{613431781} = "Jeparit";
$areanames{en}->{613431782} = "Kalkee";
$areanames{en}->{613431783} = "Kaniva";
$areanames{en}->{613431784} = "Laharum";
$areanames{en}->{613431785} = "Lake\ Bolac";
$areanames{en}->{613431786} = "Landsborough";
$areanames{en}->{613431787} = "Learmonth";
$areanames{en}->{613431788} = "Linton";
$areanames{en}->{613431789} = "Lorquon";
$areanames{en}->{613431790} = "Marnoo";
$areanames{en}->{613431791} = "Maroona";
$areanames{en}->{613431792} = "Minimay";
$areanames{en}->{613431793} = "Minyip";
$areanames{en}->{613431794} = "Mount\ Wallace";
$areanames{en}->{613431795} = "Moyston";
$areanames{en}->{613431796} = "Murtoa";
$areanames{en}->{613431797} = "Natimuk";
$areanames{en}->{613431798} = "Navarre";
$areanames{en}->{613431799} = "Nhill";
$areanames{en}->{613431800} = "Polkemmet";
$areanames{en}->{613431801} = "Rainbow";
$areanames{en}->{613431802} = "Rokewood";
$areanames{en}->{613431803} = "Scarsdale";
$areanames{en}->{613431804} = "Serviceton";
$areanames{en}->{613431805} = "Skipton";
$areanames{en}->{613431806} = "Stawell";
$areanames{en}->{613431807} = "Stoneleigh";
$areanames{en}->{613431808} = "Streatham";
$areanames{en}->{613431809} = "Telopea\ Downs";
$areanames{en}->{613431810} = "Warracknabeal";
$areanames{en}->{613431811} = "Wilkur";
$areanames{en}->{613431812} = "Willaura";
$areanames{en}->{613431813} = "Yaapeet";
$areanames{en}->{613431814} = "Ararat";
$areanames{en}->{613431815} = "Bacchus\ Marsh";
$areanames{en}->{613431816} = "Ballan";
$areanames{en}->{613431817} = "Ballarat";
$areanames{en}->{613431818} = "Balliang";
$areanames{en}->{613431819} = "Bangerang";
$areanames{en}->{61343182} = "Murtoa";
$areanames{en}->{61343183} = "Linton";
$areanames{en}->{61343184} = "Daylesford";
$areanames{en}->{61343185} = "Scarsdale";
$areanames{en}->{61343186} = "Scarsdale";
$areanames{en}->{61343187} = "Scarsdale";
$areanames{en}->{613431880} = "Banyena";
$areanames{en}->{613431881} = "Beaufort";
$areanames{en}->{613431882} = "Ararat";
$areanames{en}->{613431883} = "Bacchus\ Marsh";
$areanames{en}->{613431884} = "Ballan";
$areanames{en}->{613431885} = "Ballarat";
$areanames{en}->{613431886} = "Balliang";
$areanames{en}->{613431887} = "Bangerang";
$areanames{en}->{613431888} = "Banyena";
$areanames{en}->{613431889} = "Beaufort";
$areanames{en}->{613431890} = "Beulah";
$areanames{en}->{613431891} = "Broughton";
$areanames{en}->{613431892} = "Buangor";
$areanames{en}->{613431893} = "Buninyong";
$areanames{en}->{613431894} = "Clear\ Lake";
$areanames{en}->{613431895} = "Creswick";
$areanames{en}->{613431896} = "Crymelon";
$areanames{en}->{613431897} = "Dadswells\ Bridge";
$areanames{en}->{613431898} = "Daylesford";
$areanames{en}->{613431899} = "Dimboola";
$areanames{en}->{613431900} = "Elmhurst";
$areanames{en}->{613431901} = "Gerang\ Gerung";
$areanames{en}->{613431902} = "Glenisla";
$areanames{en}->{613431903} = "Glenorchy";
$areanames{en}->{613431904} = "Goroke";
$areanames{en}->{613431905} = "Halls\ Gap";
$areanames{en}->{613431906} = "Horsham";
$areanames{en}->{613431907} = "Jeparit";
$areanames{en}->{613431908} = "Kalkee";
$areanames{en}->{613431909} = "Kaniva";
$areanames{en}->{613431910} = "Laharum";
$areanames{en}->{613431911} = "Lake\ Bolac";
$areanames{en}->{613431912} = "Landsborough";
$areanames{en}->{613431913} = "Learmonth";
$areanames{en}->{613431914} = "Linton";
$areanames{en}->{613431915} = "Lorquon";
$areanames{en}->{613431916} = "Marnoo";
$areanames{en}->{613431917} = "Maroona";
$areanames{en}->{613431918} = "Minimay";
$areanames{en}->{613431919} = "Minyip";
$areanames{en}->{613431920} = "Mount\ Wallace";
$areanames{en}->{613431921} = "Moyston";
$areanames{en}->{613431922} = "Murtoa";
$areanames{en}->{613431923} = "Natimuk";
$areanames{en}->{613431924} = "Navarre";
$areanames{en}->{613431925} = "Nhill";
$areanames{en}->{613431926} = "Polkemmet";
$areanames{en}->{613431927} = "Rainbow";
$areanames{en}->{613431928} = "Rokewood";
$areanames{en}->{613431929} = "Scarsdale";
$areanames{en}->{613431930} = "Serviceton";
$areanames{en}->{613431931} = "Skipton";
$areanames{en}->{613431932} = "Stawell";
$areanames{en}->{613431933} = "Stoneleigh";
$areanames{en}->{613431934} = "Streatham";
$areanames{en}->{613431935} = "Telopea\ Downs";
$areanames{en}->{613431936} = "Warracknabeal";
$areanames{en}->{613431937} = "Wilkur";
$areanames{en}->{613431938} = "Willaura";
$areanames{en}->{613431939} = "Yaapeet";
$areanames{en}->{61343194} = "Bacchus\ Marsh";
$areanames{en}->{613431950} = "Beulah";
$areanames{en}->{613431951} = "Broughton";
$areanames{en}->{613431952} = "Buangor";
$areanames{en}->{613431953} = "Buninyong";
$areanames{en}->{613431954} = "Clear\ Lake";
$areanames{en}->{613431955} = "Creswick";
$areanames{en}->{613431956} = "Crymelon";
$areanames{en}->{613431957} = "Dadswells\ Bridge";
$areanames{en}->{613431958} = "Daylesford";
$areanames{en}->{613431959} = "Dimboola";
$areanames{en}->{613431960} = "Elmhurst";
$areanames{en}->{613431961} = "Gerang\ Gerung";
$areanames{en}->{613431962} = "Glenisla";
$areanames{en}->{613431963} = "Glenorchy";
$areanames{en}->{613431964} = "Goroke";
$areanames{en}->{613431965} = "Halls\ Gap";
$areanames{en}->{613431966} = "Horsham";
$areanames{en}->{613431967} = "Jeparit";
$areanames{en}->{613431968} = "Kalkee";
$areanames{en}->{613431969} = "Kaniva";
$areanames{en}->{613431970} = "Laharum";
$areanames{en}->{613431971} = "Lake\ Bolac";
$areanames{en}->{613431972} = "Landsborough";
$areanames{en}->{613431973} = "Learmonth";
$areanames{en}->{613431974} = "Linton";
$areanames{en}->{613431975} = "Lorquon";
$areanames{en}->{613431976} = "Marnoo";
$areanames{en}->{613431977} = "Maroona";
$areanames{en}->{613431978} = "Minimay";
$areanames{en}->{613431979} = "Minyip";
$areanames{en}->{613431980} = "Mount\ Wallace";
$areanames{en}->{613431981} = "Moyston";
$areanames{en}->{613431982} = "Murtoa";
$areanames{en}->{613431983} = "Natimuk";
$areanames{en}->{613431984} = "Navarre";
$areanames{en}->{613431985} = "Nhill";
$areanames{en}->{613431986} = "Polkemmet";
$areanames{en}->{613431987} = "Rainbow";
$areanames{en}->{613431988} = "Rokewood";
$areanames{en}->{613431989} = "Scarsdale";
$areanames{en}->{613431990} = "Serviceton";
$areanames{en}->{613431991} = "Skipton";
$areanames{en}->{613431992} = "Stawell";
$areanames{en}->{613431993} = "Stoneleigh";
$areanames{en}->{613431994} = "Streatham";
$areanames{en}->{613431995} = "Telopea\ Downs";
$areanames{en}->{613431996} = "Warracknabeal";
$areanames{en}->{613431997} = "Wilkur";
$areanames{en}->{613431998} = "Willaura";
$areanames{en}->{613431999} = "Yaapeet";
$areanames{en}->{613432000} = "Ararat";
$areanames{en}->{613432001} = "Bacchus\ Marsh";
$areanames{en}->{613432002} = "Ballan";
$areanames{en}->{613432003} = "Ballarat";
$areanames{en}->{613432004} = "Balliang";
$areanames{en}->{613432005} = "Bangerang";
$areanames{en}->{613432006} = "Banyena";
$areanames{en}->{613432007} = "Beaufort";
$areanames{en}->{613432008} = "Beulah";
$areanames{en}->{613432009} = "Broughton";
$areanames{en}->{613432010} = "Buangor";
$areanames{en}->{613432011} = "Buninyong";
$areanames{en}->{613432012} = "Clear\ Lake";
$areanames{en}->{613432013} = "Creswick";
$areanames{en}->{613432014} = "Crymelon";
$areanames{en}->{613432015} = "Dadswells\ Bridge";
$areanames{en}->{613432016} = "Daylesford";
$areanames{en}->{613432017} = "Dimboola";
$areanames{en}->{613432018} = "Elmhurst";
$areanames{en}->{613432019} = "Gerang\ Gerung";
$areanames{en}->{613432020} = "Glenisla";
$areanames{en}->{613432021} = "Glenorchy";
$areanames{en}->{613432022} = "Goroke";
$areanames{en}->{613432023} = "Halls\ Gap";
$areanames{en}->{613432024} = "Horsham";
$areanames{en}->{613432025} = "Jeparit";
$areanames{en}->{613432026} = "Kalkee";
$areanames{en}->{613432027} = "Kaniva";
$areanames{en}->{613432028} = "Laharum";
$areanames{en}->{613432029} = "Lake\ Bolac";
$areanames{en}->{613432030} = "Landsborough";
$areanames{en}->{613432031} = "Learmonth";
$areanames{en}->{613432032} = "Linton";
$areanames{en}->{613432033} = "Lorquon";
$areanames{en}->{613432034} = "Marnoo";
$areanames{en}->{613432035} = "Maroona";
$areanames{en}->{613432036} = "Minimay";
$areanames{en}->{613432037} = "Minyip";
$areanames{en}->{613432038} = "Mount\ Wallace";
$areanames{en}->{613432039} = "Moyston";
$areanames{en}->{613432040} = "Murtoa";
$areanames{en}->{613432041} = "Natimuk";
$areanames{en}->{613432042} = "Navarre";
$areanames{en}->{613432043} = "Nhill";
$areanames{en}->{613432044} = "Polkemmet";
$areanames{en}->{613432045} = "Rainbow";
$areanames{en}->{613432046} = "Rokewood";
$areanames{en}->{613432047} = "Scarsdale";
$areanames{en}->{613432048} = "Serviceton";
$areanames{en}->{613432049} = "Skipton";
$areanames{en}->{613432050} = "Stawell";
$areanames{en}->{613432051} = "Stoneleigh";
$areanames{en}->{613432052} = "Streatham";
$areanames{en}->{613432053} = "Telopea\ Downs";
$areanames{en}->{613432054} = "Warracknabeal";
$areanames{en}->{613432055} = "Wilkur";
$areanames{en}->{613432056} = "Willaura";
$areanames{en}->{613432057} = "Yaapeet";
$areanames{en}->{613432058} = "Ararat";
$areanames{en}->{613432059} = "Bacchus\ Marsh";
$areanames{en}->{613432060} = "Ballan";
$areanames{en}->{613432061} = "Ballarat";
$areanames{en}->{613432062} = "Balliang";
$areanames{en}->{613432063} = "Bangerang";
$areanames{en}->{613432064} = "Banyena";
$areanames{en}->{613432065} = "Beaufort";
$areanames{en}->{613432066} = "Beulah";
$areanames{en}->{613432067} = "Broughton";
$areanames{en}->{613432068} = "Buangor";
$areanames{en}->{613432069} = "Buninyong";
$areanames{en}->{613432070} = "Clear\ Lake";
$areanames{en}->{613432071} = "Creswick";
$areanames{en}->{613432072} = "Crymelon";
$areanames{en}->{613432073} = "Dadswells\ Bridge";
$areanames{en}->{613432074} = "Daylesford";
$areanames{en}->{613432075} = "Dimboola";
$areanames{en}->{613432076} = "Elmhurst";
$areanames{en}->{613432077} = "Gerang\ Gerung";
$areanames{en}->{613432078} = "Glenisla";
$areanames{en}->{613432079} = "Glenorchy";
$areanames{en}->{613432080} = "Goroke";
$areanames{en}->{613432081} = "Halls\ Gap";
$areanames{en}->{613432082} = "Horsham";
$areanames{en}->{613432083} = "Jeparit";
$areanames{en}->{613432084} = "Kalkee";
$areanames{en}->{613432085} = "Kaniva";
$areanames{en}->{613432086} = "Laharum";
$areanames{en}->{613432087} = "Lake\ Bolac";
$areanames{en}->{613432088} = "Landsborough";
$areanames{en}->{613432089} = "Learmonth";
$areanames{en}->{613432090} = "Linton";
$areanames{en}->{613432091} = "Lorquon";
$areanames{en}->{613432092} = "Marnoo";
$areanames{en}->{613432093} = "Maroona";
$areanames{en}->{613432094} = "Minimay";
$areanames{en}->{613432095} = "Minyip";
$areanames{en}->{613432096} = "Mount\ Wallace";
$areanames{en}->{613432097} = "Moyston";
$areanames{en}->{613432098} = "Murtoa";
$areanames{en}->{613432099} = "Natimuk";
$areanames{en}->{613432100} = "Navarre";
$areanames{en}->{613432101} = "Nhill";
$areanames{en}->{613432102} = "Polkemmet";
$areanames{en}->{613432103} = "Rainbow";
$areanames{en}->{613432104} = "Rokewood";
$areanames{en}->{613432105} = "Scarsdale";
$areanames{en}->{613432106} = "Serviceton";
$areanames{en}->{613432107} = "Skipton";
$areanames{en}->{613432108} = "Stawell";
$areanames{en}->{613432109} = "Stoneleigh";
$areanames{en}->{61343211} = "Horsham";
$areanames{en}->{613432120} = "Streatham";
$areanames{en}->{613432121} = "Telopea\ Downs";
$areanames{en}->{613432122} = "Warracknabeal";
$areanames{en}->{613432123} = "Wilkur";
$areanames{en}->{613432124} = "Willaura";
$areanames{en}->{613432125} = "Yaapeet";
$areanames{en}->{613432126} = "Ararat";
$areanames{en}->{613432127} = "Bacchus\ Marsh";
$areanames{en}->{613432128} = "Ballan";
$areanames{en}->{613432129} = "Ballarat";
$areanames{en}->{613432130} = "Balliang";
$areanames{en}->{613432131} = "Bangerang";
$areanames{en}->{613432132} = "Banyena";
$areanames{en}->{613432133} = "Beaufort";
$areanames{en}->{613432134} = "Beulah";
$areanames{en}->{613432135} = "Broughton";
$areanames{en}->{613432136} = "Buangor";
$areanames{en}->{613432137} = "Buninyong";
$areanames{en}->{613432138} = "Clear\ Lake";
$areanames{en}->{613432139} = "Creswick";
$areanames{en}->{613432140} = "Crymelon";
$areanames{en}->{613432141} = "Dadswells\ Bridge";
$areanames{en}->{613432142} = "Daylesford";
$areanames{en}->{613432143} = "Dimboola";
$areanames{en}->{613432144} = "Elmhurst";
$areanames{en}->{613432145} = "Gerang\ Gerung";
$areanames{en}->{613432146} = "Glenisla";
$areanames{en}->{613432147} = "Glenorchy";
$areanames{en}->{613432148} = "Goroke";
$areanames{en}->{613432149} = "Halls\ Gap";
$areanames{en}->{613432150} = "Horsham";
$areanames{en}->{613432151} = "Jeparit";
$areanames{en}->{613432152} = "Kalkee";
$areanames{en}->{613432153} = "Kaniva";
$areanames{en}->{613432154} = "Laharum";
$areanames{en}->{613432155} = "Lake\ Bolac";
$areanames{en}->{613432156} = "Landsborough";
$areanames{en}->{613432157} = "Learmonth";
$areanames{en}->{613432158} = "Linton";
$areanames{en}->{613432159} = "Lorquon";
$areanames{en}->{613432160} = "Marnoo";
$areanames{en}->{613432161} = "Maroona";
$areanames{en}->{613432162} = "Minimay";
$areanames{en}->{613432163} = "Minyip";
$areanames{en}->{613432164} = "Mount\ Wallace";
$areanames{en}->{613432165} = "Moyston";
$areanames{en}->{613432166} = "Murtoa";
$areanames{en}->{613432167} = "Natimuk";
$areanames{en}->{613432168} = "Navarre";
$areanames{en}->{613432169} = "Nhill";
$areanames{en}->{61343217} = "Horsham";
$areanames{en}->{61343218} = "Horsham";
$areanames{en}->{61343219} = "Horsham";
$areanames{en}->{61343220} = "Horsham";
$areanames{en}->{613432210} = "Polkemmet";
$areanames{en}->{613432211} = "Rainbow";
$areanames{en}->{613432212} = "Rokewood";
$areanames{en}->{613432213} = "Scarsdale";
$areanames{en}->{613432214} = "Serviceton";
$areanames{en}->{613432215} = "Skipton";
$areanames{en}->{613432216} = "Stawell";
$areanames{en}->{613432217} = "Stoneleigh";
$areanames{en}->{613432218} = "Streatham";
$areanames{en}->{613432219} = "Telopea\ Downs";
$areanames{en}->{613432220} = "Warracknabeal";
$areanames{en}->{613432221} = "Wilkur";
$areanames{en}->{613432222} = "Willaura";
$areanames{en}->{613432223} = "Yaapeet";
$areanames{en}->{61343223} = "Ballan";
$areanames{en}->{61343224} = "Ballan";
$areanames{en}->{61343225} = "Ballan";
$areanames{en}->{61343226} = "Balliang";
$areanames{en}->{61343227} = "Balliang";
$areanames{en}->{61343228} = "Balliang";
$areanames{en}->{61343229} = "Dadswells\ Bridge";
$areanames{en}->{61343240} = "Maroona";
$areanames{en}->{61343259} = "Serviceton";
$areanames{en}->{6134330} = "Ballarat";
$areanames{en}->{6134331} = "Ballarat";
$areanames{en}->{6134332} = "Ballarat";
$areanames{en}->{6134333} = "Ballarat";
$areanames{en}->{6134334} = "Ballarat";
$areanames{en}->{61343350} = "Ballarat";
$areanames{en}->{61343351} = "Ballarat";
$areanames{en}->{61343352} = "Ballarat";
$areanames{en}->{61343353} = "Ballarat";
$areanames{en}->{61343354} = "Ballarat";
$areanames{en}->{61343355} = "Ballarat";
$areanames{en}->{61343356} = "Ararat";
$areanames{en}->{61343357} = "Ararat";
$areanames{en}->{61343358} = "Ararat";
$areanames{en}->{6134336} = "Ballarat";
$areanames{en}->{6134337} = "Ballarat";
$areanames{en}->{6134338} = "Ballarat";
$areanames{en}->{6134339} = "Ballarat";
$areanames{en}->{61343429} = "Ballan";
$areanames{en}->{6134343} = "Ballarat";
$areanames{en}->{61343440} = "Ballarat";
$areanames{en}->{61343441} = "Horsham";
$areanames{en}->{61343442} = "Horsham";
$areanames{en}->{61343443} = "Horsham";
$areanames{en}->{61343444} = "Ballarat";
$areanames{en}->{61343496} = "Ballarat";
$areanames{en}->{61343677} = "Bacchus\ Marsh";
$areanames{en}->{61343678} = "Bacchus\ Marsh";
$areanames{en}->{61343679} = "Bacchus\ Marsh";
$areanames{en}->{61343680} = "Buninyong";
$areanames{en}->{61343681} = "Buninyong";
$areanames{en}->{61343682} = "Buninyong";
$areanames{en}->{61343683} = "Creswick";
$areanames{en}->{61343684} = "Creswick";
$areanames{en}->{61343726} = "Ballarat";
$areanames{en}->{61343727} = "Ballarat";
$areanames{en}->{61343728} = "Ballarat";
$areanames{en}->{61343729} = "Ballarat";
$areanames{en}->{61343730} = "Ballarat";
$areanames{en}->{61343731} = "Ballarat";
$areanames{en}->{61343732} = "Ballarat";
$areanames{en}->{61343733} = "Ballarat";
$areanames{en}->{61343734} = "Ballarat";
$areanames{en}->{61343735} = "Balliang";
$areanames{en}->{61343737} = "Daylesford";
$areanames{en}->{61343738} = "Daylesford";
$areanames{en}->{61343739} = "Daylesford";
$areanames{en}->{61344000} = "Romsey";
$areanames{en}->{61344001} = "Kyneton";
$areanames{en}->{61344002} = "Gisborne";
$areanames{en}->{61344003} = "Romsey";
$areanames{en}->{61344004} = "Woodend";
$areanames{en}->{61344005} = "Maryborough";
$areanames{en}->{61344006} = "Castlemaine";
$areanames{en}->{61344007} = "Echuca";
$areanames{en}->{61344008} = "Moonambel";
$areanames{en}->{61344009} = "Bendigo";
$areanames{en}->{61344010} = "Strathfieldsaye";
$areanames{en}->{61344011} = "Strathfieldsaye";
$areanames{en}->{61344012} = "Boort";
$areanames{en}->{61344013} = "Boort";
$areanames{en}->{61344014} = "Echuca";
$areanames{en}->{61344015} = "Echuca";
$areanames{en}->{61344016} = "Gunbower";
$areanames{en}->{61344017} = "Gunbower";
$areanames{en}->{61344018} = "Rochester";
$areanames{en}->{61344019} = "Rochester";
$areanames{en}->{61344020} = "Logan";
$areanames{en}->{61344021} = "Logan";
$areanames{en}->{61344022} = "Nullawil";
$areanames{en}->{61344023} = "Nullawil";
$areanames{en}->{61344024} = "St\ Arnaud";
$areanames{en}->{61344025} = "St\ Arnaud";
$areanames{en}->{61344026} = "Traynors\ Lagoon";
$areanames{en}->{61344027} = "Traynors\ Lagoon";
$areanames{en}->{61344028} = "Watchem";
$areanames{en}->{61344029} = "Watchem";
$areanames{en}->{61344030} = "Wedderburn";
$areanames{en}->{61344031} = "Wedderburn";
$areanames{en}->{61344032} = "Wycheproof";
$areanames{en}->{61344033} = "Wycheproof";
$areanames{en}->{61344034} = "Cohuna";
$areanames{en}->{61344035} = "Cohuna";
$areanames{en}->{61344036} = "Kerang";
$areanames{en}->{61344037} = "Kerang";
$areanames{en}->{61344038} = "Lake\ Meran";
$areanames{en}->{61344039} = "Lake\ Meran";
$areanames{en}->{61344040} = "Lalbert";
$areanames{en}->{61344041} = "Lalbert";
$areanames{en}->{61344042} = "Murrabit";
$areanames{en}->{61344043} = "Murrabit";
$areanames{en}->{61344044} = "Quambatook";
$areanames{en}->{61344045} = "Quambatook";
$areanames{en}->{61344046} = "Gisborne";
$areanames{en}->{61344047} = "Gisborne";
$areanames{en}->{61344048} = "Kyneton";
$areanames{en}->{61344049} = "Kyneton";
$areanames{en}->{61344050} = "Redesdale";
$areanames{en}->{61344051} = "Redesdale";
$areanames{en}->{61344052} = "Romsey";
$areanames{en}->{61344053} = "Romsey";
$areanames{en}->{61344054} = "Trentham";
$areanames{en}->{61344055} = "Trentham";
$areanames{en}->{61344056} = "Woodend";
$areanames{en}->{61344057} = "Woodend";
$areanames{en}->{61344058} = "Amphitheatre";
$areanames{en}->{61344059} = "Amphitheatre";
$areanames{en}->{61344060} = "Avoca";
$areanames{en}->{61344061} = "Avoca";
$areanames{en}->{61344062} = "Bealiba";
$areanames{en}->{61344063} = "Bealiba";
$areanames{en}->{61344064} = "Carisbrook";
$areanames{en}->{61344065} = "Carisbrook";
$areanames{en}->{61344066} = "Castlemaine";
$areanames{en}->{61344067} = "Castlemaine";
$areanames{en}->{61344068} = "Dunolly";
$areanames{en}->{61344069} = "Dunolly";
$areanames{en}->{61344070} = "Harcourt";
$areanames{en}->{61344071} = "Harcourt";
$areanames{en}->{61344072} = "Maldon";
$areanames{en}->{61344073} = "Maldon";
$areanames{en}->{61344074} = "Maryborough";
$areanames{en}->{61344075} = "Maryborough";
$areanames{en}->{61344076} = "Moonambel";
$areanames{en}->{61344077} = "Moonambel";
$areanames{en}->{61344078} = "Newstead";
$areanames{en}->{61344079} = "Newstead";
$areanames{en}->{61344080} = "Talbot";
$areanames{en}->{61344081} = "Talbot";
$areanames{en}->{61344082} = "Gisborne";
$areanames{en}->{61344083} = "Bendigo";
$areanames{en}->{61344084} = "Bendigo";
$areanames{en}->{61344085} = "Bendigo";
$areanames{en}->{61344086} = "Bendigo";
$areanames{en}->{61344087} = "Lockington";
$areanames{en}->{61344088} = "Lockington";
$areanames{en}->{61344089} = "Avoca";
$areanames{en}->{6134409} = "Bendigo";
$areanames{en}->{61344100} = "Bendigo";
$areanames{en}->{61344101} = "Gisborne";
$areanames{en}->{61344102} = "Kyneton";
$areanames{en}->{61344103} = "Bendigo";
$areanames{en}->{61344104} = "Castlemaine";
$areanames{en}->{61344105} = "Strathfieldsaye";
$areanames{en}->{61344106} = "Kyneton";
$areanames{en}->{61344107} = "Maryborough";
$areanames{en}->{61344108} = "Echuca";
$areanames{en}->{61344109} = "Castlemaine";
$areanames{en}->{61344110} = "Maryborough";
$areanames{en}->{61344111} = "Bendigo";
$areanames{en}->{61344112} = "Kyneton";
$areanames{en}->{61344113} = "Newstead";
$areanames{en}->{61344114} = "Trentham";
$areanames{en}->{61344115} = "Maryborough";
$areanames{en}->{61344116} = "Heathcote";
$areanames{en}->{61344117} = "Echuca";
$areanames{en}->{61344118} = "Kyneton";
$areanames{en}->{613441190} = "Amphitheatre";
$areanames{en}->{613441191} = "Avoca";
$areanames{en}->{613441192} = "Barham";
$areanames{en}->{613441193} = "Bealiba";
$areanames{en}->{613441194} = "Beazleys\ Bridge";
$areanames{en}->{613441195} = "Bendigo";
$areanames{en}->{613441196} = "Birchip";
$areanames{en}->{613441197} = "Boort";
$areanames{en}->{613441198} = "Bridgewater";
$areanames{en}->{613441199} = "Buckrabanyule";
$areanames{en}->{613441200} = "Carisbrook";
$areanames{en}->{613441201} = "Castlemaine";
$areanames{en}->{613441202} = "Charlton";
$areanames{en}->{613441203} = "Cohuna";
$areanames{en}->{613441204} = "Colbinabbin";
$areanames{en}->{613441205} = "Dingee";
$areanames{en}->{613441206} = "Donald";
$areanames{en}->{613441207} = "Dunolly";
$areanames{en}->{613441208} = "Echuca";
$areanames{en}->{613441209} = "Elmore";
$areanames{en}->{613441210} = "Gisborne";
$areanames{en}->{613441211} = "Goornong";
$areanames{en}->{613441212} = "Gowar\ East";
$areanames{en}->{613441213} = "Gunbower";
$areanames{en}->{613441214} = "Harcourt";
$areanames{en}->{613441215} = "Heathcote";
$areanames{en}->{613441216} = "Inglewood";
$areanames{en}->{613441217} = "Jarklin";
$areanames{en}->{613441218} = "Kerang";
$areanames{en}->{613441219} = "Korong\ Vale";
$areanames{en}->{613441220} = "Kyneton";
$areanames{en}->{613441221} = "Laen";
$areanames{en}->{613441222} = "Lake\ Meran";
$areanames{en}->{613441223} = "Lalbert";
$areanames{en}->{613441224} = "Llanelly";
$areanames{en}->{613441225} = "Lockington";
$areanames{en}->{613441226} = "Logan";
$areanames{en}->{613441227} = "Maldon";
$areanames{en}->{613441228} = "Marong";
$areanames{en}->{613441229} = "Maryborough";
$areanames{en}->{613441230} = "Mitiamo";
$areanames{en}->{613441231} = "Moonambel";
$areanames{en}->{613441232} = "Murrabit";
$areanames{en}->{613441233} = "Newstead";
$areanames{en}->{613441234} = "Nullawil";
$areanames{en}->{613441235} = "Pyramid\ Hill";
$areanames{en}->{613441236} = "Quambatook";
$areanames{en}->{613441237} = "Raywood";
$areanames{en}->{613441238} = "Redesdale";
$areanames{en}->{613441239} = "Rochester";
$areanames{en}->{613441240} = "Romsey";
$areanames{en}->{613441241} = "St\ Arnaud";
$areanames{en}->{613441242} = "Strathfieldsaye";
$areanames{en}->{613441243} = "Talbot";
$areanames{en}->{613441244} = "Tennyson";
$areanames{en}->{613441245} = "Traynors\ Lagoon";
$areanames{en}->{613441246} = "Trentham";
$areanames{en}->{613441247} = "Tullakool";
$areanames{en}->{613441248} = "Watchem";
$areanames{en}->{613441249} = "Wedderburn";
$areanames{en}->{613441250} = "Womboota";
$areanames{en}->{613441251} = "Woodend";
$areanames{en}->{613441252} = "Wycheproof";
$areanames{en}->{613441253} = "Amphitheatre";
$areanames{en}->{613441254} = "Avoca";
$areanames{en}->{613441255} = "Barham";
$areanames{en}->{613441256} = "Bealiba";
$areanames{en}->{613441257} = "Beazleys\ Bridge";
$areanames{en}->{613441258} = "Bendigo";
$areanames{en}->{613441259} = "Birchip";
$areanames{en}->{61344126} = "Gunbower";
$areanames{en}->{61344127} = "Barham";
$areanames{en}->{61344128} = "Bealiba";
$areanames{en}->{61344129} = "Beazleys\ Bridge";
$areanames{en}->{61344130} = "Bridgewater";
$areanames{en}->{61344131} = "Buckrabanyule";
$areanames{en}->{61344132} = "Dingee";
$areanames{en}->{61344133} = "Dunolly";
$areanames{en}->{61344134} = "Elmore";
$areanames{en}->{61344135} = "Goornong";
$areanames{en}->{61344136} = "Gowar\ East";
$areanames{en}->{61344137} = "Gunbower";
$areanames{en}->{61344138} = "Inglewood";
$areanames{en}->{61344139} = "Jarklin";
$areanames{en}->{61344140} = "Korong\ Vale";
$areanames{en}->{61344141} = "Lalbert";
$areanames{en}->{61344142} = "Lockington";
$areanames{en}->{61344143} = "Logan";
$areanames{en}->{61344144} = "Maldon";
$areanames{en}->{61344145} = "Marong";
$areanames{en}->{61344146} = "Murrabit";
$areanames{en}->{61344147} = "Newstead";
$areanames{en}->{61344148} = "Nullawil";
$areanames{en}->{61344149} = "Pyramid\ Hill";
$areanames{en}->{61344150} = "Quambatook";
$areanames{en}->{61344151} = "Raywood";
$areanames{en}->{61344152} = "Redesdale";
$areanames{en}->{61344153} = "Romsey";
$areanames{en}->{61344154} = "Strathfieldsaye";
$areanames{en}->{61344155} = "Tennyson";
$areanames{en}->{61344156} = "Trentham";
$areanames{en}->{61344157} = "Watchem";
$areanames{en}->{61344158} = "Wedderburn";
$areanames{en}->{61344159} = "Womboota";
$areanames{en}->{61344160} = "Woodend";
$areanames{en}->{61344161} = "Bendigo";
$areanames{en}->{61344162} = "Bendigo";
$areanames{en}->{61344163} = "Bendigo";
$areanames{en}->{61344164} = "Wycheproof";
$areanames{en}->{61344165} = "Carisbrook";
$areanames{en}->{61344166} = "Boort";
$areanames{en}->{61344167} = "Donald";
$areanames{en}->{61344168} = "Harcourt";
$areanames{en}->{613441690} = "Boort";
$areanames{en}->{613441691} = "Bridgewater";
$areanames{en}->{613441692} = "Buckrabanyule";
$areanames{en}->{613441693} = "Carisbrook";
$areanames{en}->{613441694} = "Castlemaine";
$areanames{en}->{613441695} = "Charlton";
$areanames{en}->{613441696} = "Cohuna";
$areanames{en}->{613441697} = "Colbinabbin";
$areanames{en}->{613441698} = "Dingee";
$areanames{en}->{613441699} = "Donald";
$areanames{en}->{613441700} = "Dunolly";
$areanames{en}->{613441701} = "Echuca";
$areanames{en}->{613441702} = "Elmore";
$areanames{en}->{613441703} = "Gisborne";
$areanames{en}->{613441704} = "Goornong";
$areanames{en}->{613441705} = "Gowar\ East";
$areanames{en}->{613441706} = "Gunbower";
$areanames{en}->{613441707} = "Harcourt";
$areanames{en}->{613441708} = "Heathcote";
$areanames{en}->{613441709} = "Inglewood";
$areanames{en}->{613441710} = "Jarklin";
$areanames{en}->{613441711} = "Kerang";
$areanames{en}->{613441712} = "Korong\ Vale";
$areanames{en}->{613441713} = "Kyneton";
$areanames{en}->{613441714} = "Laen";
$areanames{en}->{613441715} = "Lake\ Meran";
$areanames{en}->{613441716} = "Lalbert";
$areanames{en}->{613441717} = "Llanelly";
$areanames{en}->{613441718} = "Lockington";
$areanames{en}->{613441719} = "Logan";
$areanames{en}->{613441720} = "Maldon";
$areanames{en}->{613441721} = "Marong";
$areanames{en}->{613441722} = "Maryborough";
$areanames{en}->{613441723} = "Mitiamo";
$areanames{en}->{613441724} = "Moonambel";
$areanames{en}->{613441725} = "Murrabit";
$areanames{en}->{613441726} = "Newstead";
$areanames{en}->{613441727} = "Nullawil";
$areanames{en}->{613441728} = "Pyramid\ Hill";
$areanames{en}->{613441729} = "Quambatook";
$areanames{en}->{613441730} = "Raywood";
$areanames{en}->{613441731} = "Redesdale";
$areanames{en}->{613441732} = "Rochester";
$areanames{en}->{613441733} = "Romsey";
$areanames{en}->{613441734} = "St\ Arnaud";
$areanames{en}->{613441735} = "Strathfieldsaye";
$areanames{en}->{613441736} = "Talbot";
$areanames{en}->{613441737} = "Tennyson";
$areanames{en}->{613441738} = "Traynors\ Lagoon";
$areanames{en}->{613441739} = "Trentham";
$areanames{en}->{613441740} = "Tullakool";
$areanames{en}->{613441741} = "Watchem";
$areanames{en}->{613441742} = "Wedderburn";
$areanames{en}->{613441743} = "Womboota";
$areanames{en}->{613441744} = "Woodend";
$areanames{en}->{613441745} = "Wycheproof";
$areanames{en}->{613441746} = "Amphitheatre";
$areanames{en}->{613441747} = "Avoca";
$areanames{en}->{613441748} = "Barham";
$areanames{en}->{613441749} = "Bealiba";
$areanames{en}->{61344175} = "Maldon";
$areanames{en}->{61344176} = "Marong";
$areanames{en}->{61344177} = "Woodend";
$areanames{en}->{613441780} = "Beazleys\ Bridge";
$areanames{en}->{613441781} = "Bendigo";
$areanames{en}->{613441782} = "Birchip";
$areanames{en}->{613441783} = "Boort";
$areanames{en}->{613441784} = "Bridgewater";
$areanames{en}->{613441785} = "Buckrabanyule";
$areanames{en}->{613441786} = "Carisbrook";
$areanames{en}->{613441787} = "Castlemaine";
$areanames{en}->{613441788} = "Charlton";
$areanames{en}->{613441789} = "Cohuna";
$areanames{en}->{613441790} = "Colbinabbin";
$areanames{en}->{613441791} = "Dingee";
$areanames{en}->{613441792} = "Donald";
$areanames{en}->{613441793} = "Dunolly";
$areanames{en}->{613441794} = "Echuca";
$areanames{en}->{613441795} = "Elmore";
$areanames{en}->{613441796} = "Gisborne";
$areanames{en}->{613441797} = "Goornong";
$areanames{en}->{613441798} = "Gowar\ East";
$areanames{en}->{613441799} = "Gunbower";
$areanames{en}->{613441800} = "Harcourt";
$areanames{en}->{613441801} = "Heathcote";
$areanames{en}->{613441802} = "Inglewood";
$areanames{en}->{613441803} = "Jarklin";
$areanames{en}->{613441804} = "Kerang";
$areanames{en}->{613441805} = "Korong\ Vale";
$areanames{en}->{613441806} = "Kyneton";
$areanames{en}->{613441807} = "Laen";
$areanames{en}->{613441808} = "Lake\ Meran";
$areanames{en}->{613441809} = "Lalbert";
$areanames{en}->{613441810} = "Llanelly";
$areanames{en}->{613441811} = "Lockington";
$areanames{en}->{613441812} = "Logan";
$areanames{en}->{613441813} = "Maldon";
$areanames{en}->{613441814} = "Marong";
$areanames{en}->{613441815} = "Maryborough";
$areanames{en}->{613441816} = "Mitiamo";
$areanames{en}->{613441817} = "Moonambel";
$areanames{en}->{613441818} = "Murrabit";
$areanames{en}->{613441819} = "Newstead";
$areanames{en}->{61344182} = "Bendigo";
$areanames{en}->{61344183} = "Bendigo";
$areanames{en}->{61344184} = "Korong\ Vale";
$areanames{en}->{61344185} = "Rochester";
$areanames{en}->{61344186} = "Birchip";
$areanames{en}->{613441870} = "Nullawil";
$areanames{en}->{613441871} = "Pyramid\ Hill";
$areanames{en}->{613441872} = "Quambatook";
$areanames{en}->{613441873} = "Raywood";
$areanames{en}->{613441874} = "Redesdale";
$areanames{en}->{613441875} = "Rochester";
$areanames{en}->{613441876} = "Romsey";
$areanames{en}->{613441877} = "St\ Arnaud";
$areanames{en}->{613441878} = "Strathfieldsaye";
$areanames{en}->{613441879} = "Talbot";
$areanames{en}->{613441880} = "Tennyson";
$areanames{en}->{613441881} = "Traynors\ Lagoon";
$areanames{en}->{613441882} = "Amphitheatre";
$areanames{en}->{613441883} = "Avoca";
$areanames{en}->{613441884} = "Barham";
$areanames{en}->{613441885} = "Bealiba";
$areanames{en}->{613441886} = "Beazleys\ Bridge";
$areanames{en}->{613441887} = "Bendigo";
$areanames{en}->{613441888} = "Birchip";
$areanames{en}->{613441889} = "Boort";
$areanames{en}->{613441890} = "Bridgewater";
$areanames{en}->{613441891} = "Buckrabanyule";
$areanames{en}->{613441892} = "Carisbrook";
$areanames{en}->{613441893} = "Castlemaine";
$areanames{en}->{613441894} = "Charlton";
$areanames{en}->{613441895} = "Cohuna";
$areanames{en}->{613441896} = "Colbinabbin";
$areanames{en}->{613441897} = "Dingee";
$areanames{en}->{613441898} = "Donald";
$areanames{en}->{613441899} = "Dunolly";
$areanames{en}->{613441900} = "Echuca";
$areanames{en}->{613441901} = "Elmore";
$areanames{en}->{613441902} = "Gisborne";
$areanames{en}->{613441903} = "Goornong";
$areanames{en}->{613441904} = "Gowar\ East";
$areanames{en}->{613441905} = "Gunbower";
$areanames{en}->{613441906} = "Harcourt";
$areanames{en}->{613441907} = "Heathcote";
$areanames{en}->{613441908} = "Inglewood";
$areanames{en}->{613441909} = "Jarklin";
$areanames{en}->{613441910} = "Kerang";
$areanames{en}->{613441911} = "Korong\ Vale";
$areanames{en}->{613441912} = "Kyneton";
$areanames{en}->{613441913} = "Laen";
$areanames{en}->{613441914} = "Lake\ Meran";
$areanames{en}->{613441915} = "Lalbert";
$areanames{en}->{613441916} = "Llanelly";
$areanames{en}->{613441917} = "Lockington";
$areanames{en}->{613441918} = "Logan";
$areanames{en}->{613441919} = "Maldon";
$areanames{en}->{613441920} = "Marong";
$areanames{en}->{613441921} = "Maryborough";
$areanames{en}->{613441922} = "Mitiamo";
$areanames{en}->{613441923} = "Moonambel";
$areanames{en}->{613441924} = "Murrabit";
$areanames{en}->{613441925} = "Newstead";
$areanames{en}->{613441926} = "Nullawil";
$areanames{en}->{613441927} = "Pyramid\ Hill";
$areanames{en}->{613441928} = "Quambatook";
$areanames{en}->{613441929} = "Raywood";
$areanames{en}->{613441930} = "Redesdale";
$areanames{en}->{613441931} = "Rochester";
$areanames{en}->{613441932} = "Romsey";
$areanames{en}->{613441933} = "St\ Arnaud";
$areanames{en}->{613441934} = "Strathfieldsaye";
$areanames{en}->{613441935} = "Talbot";
$areanames{en}->{613441936} = "Tennyson";
$areanames{en}->{613441937} = "Traynors\ Lagoon";
$areanames{en}->{613441938} = "Trentham";
$areanames{en}->{613441939} = "Tullakool";
$areanames{en}->{613441940} = "Watchem";
$areanames{en}->{613441941} = "Wedderburn";
$areanames{en}->{613441942} = "Womboota";
$areanames{en}->{613441943} = "Woodend";
$areanames{en}->{613441944} = "Wycheproof";
$areanames{en}->{613441945} = "Trentham";
$areanames{en}->{613441946} = "Tullakool";
$areanames{en}->{613441947} = "Watchem";
$areanames{en}->{613441948} = "Wedderburn";
$areanames{en}->{613441949} = "Womboota";
$areanames{en}->{613441950} = "Woodend";
$areanames{en}->{613441951} = "Wycheproof";
$areanames{en}->{613441952} = "Amphitheatre";
$areanames{en}->{613441953} = "Avoca";
$areanames{en}->{613441954} = "Barham";
$areanames{en}->{613441955} = "Bealiba";
$areanames{en}->{613441956} = "Beazleys\ Bridge";
$areanames{en}->{613441957} = "Bendigo";
$areanames{en}->{613441958} = "Birchip";
$areanames{en}->{613441959} = "Boort";
$areanames{en}->{61344196} = "Goornong";
$areanames{en}->{61344197} = "Kerang";
$areanames{en}->{613441980} = "Bridgewater";
$areanames{en}->{613441981} = "Buckrabanyule";
$areanames{en}->{613441982} = "Carisbrook";
$areanames{en}->{613441983} = "Castlemaine";
$areanames{en}->{613441984} = "Charlton";
$areanames{en}->{613441985} = "Cohuna";
$areanames{en}->{613441986} = "Colbinabbin";
$areanames{en}->{613441987} = "Dingee";
$areanames{en}->{613441988} = "Donald";
$areanames{en}->{613441989} = "Dunolly";
$areanames{en}->{613441990} = "Echuca";
$areanames{en}->{613441991} = "Elmore";
$areanames{en}->{613441992} = "Gisborne";
$areanames{en}->{613441993} = "Goornong";
$areanames{en}->{613441994} = "Gowar\ East";
$areanames{en}->{613441995} = "Gunbower";
$areanames{en}->{613441996} = "Harcourt";
$areanames{en}->{613441997} = "Heathcote";
$areanames{en}->{613441998} = "Inglewood";
$areanames{en}->{613441999} = "Jarklin";
$areanames{en}->{613442000} = "Kerang";
$areanames{en}->{613442001} = "Korong\ Vale";
$areanames{en}->{613442002} = "Kyneton";
$areanames{en}->{613442003} = "Laen";
$areanames{en}->{613442004} = "Lake\ Meran";
$areanames{en}->{613442005} = "Lalbert";
$areanames{en}->{613442006} = "Llanelly";
$areanames{en}->{613442007} = "Lockington";
$areanames{en}->{613442008} = "Logan";
$areanames{en}->{613442009} = "Maldon";
$areanames{en}->{613442010} = "Marong";
$areanames{en}->{613442011} = "Maryborough";
$areanames{en}->{613442012} = "Mitiamo";
$areanames{en}->{613442013} = "Moonambel";
$areanames{en}->{613442014} = "Murrabit";
$areanames{en}->{613442015} = "Newstead";
$areanames{en}->{613442016} = "Nullawil";
$areanames{en}->{613442017} = "Pyramid\ Hill";
$areanames{en}->{613442018} = "Quambatook";
$areanames{en}->{613442019} = "Raywood";
$areanames{en}->{613442020} = "Redesdale";
$areanames{en}->{613442021} = "Rochester";
$areanames{en}->{613442022} = "Romsey";
$areanames{en}->{613442023} = "St\ Arnaud";
$areanames{en}->{613442024} = "Strathfieldsaye";
$areanames{en}->{613442025} = "Talbot";
$areanames{en}->{613442026} = "Tennyson";
$areanames{en}->{613442027} = "Traynors\ Lagoon";
$areanames{en}->{613442028} = "Trentham";
$areanames{en}->{613442029} = "Tullakool";
$areanames{en}->{613442030} = "Watchem";
$areanames{en}->{613442031} = "Wedderburn";
$areanames{en}->{613442032} = "Womboota";
$areanames{en}->{613442033} = "Woodend";
$areanames{en}->{613442034} = "Wycheproof";
$areanames{en}->{613442035} = "Amphitheatre";
$areanames{en}->{613442036} = "Avoca";
$areanames{en}->{613442037} = "Barham";
$areanames{en}->{613442038} = "Bealiba";
$areanames{en}->{613442039} = "Beazleys\ Bridge";
$areanames{en}->{613442040} = "Bendigo";
$areanames{en}->{613442041} = "Birchip";
$areanames{en}->{613442042} = "Boort";
$areanames{en}->{613442043} = "Bridgewater";
$areanames{en}->{613442044} = "Buckrabanyule";
$areanames{en}->{613442045} = "Carisbrook";
$areanames{en}->{613442046} = "Castlemaine";
$areanames{en}->{613442047} = "Charlton";
$areanames{en}->{613442048} = "Cohuna";
$areanames{en}->{613442049} = "Colbinabbin";
$areanames{en}->{613442050} = "Dingee";
$areanames{en}->{613442051} = "Donald";
$areanames{en}->{613442052} = "Dunolly";
$areanames{en}->{613442053} = "Echuca";
$areanames{en}->{613442054} = "Elmore";
$areanames{en}->{613442055} = "Gisborne";
$areanames{en}->{613442056} = "Goornong";
$areanames{en}->{613442057} = "Gowar\ East";
$areanames{en}->{613442058} = "Gunbower";
$areanames{en}->{613442059} = "Harcourt";
$areanames{en}->{613442060} = "Heathcote";
$areanames{en}->{613442061} = "Inglewood";
$areanames{en}->{613442062} = "Jarklin";
$areanames{en}->{613442063} = "Kerang";
$areanames{en}->{613442064} = "Korong\ Vale";
$areanames{en}->{613442065} = "Kyneton";
$areanames{en}->{613442066} = "Laen";
$areanames{en}->{613442067} = "Lake\ Meran";
$areanames{en}->{613442068} = "Lalbert";
$areanames{en}->{613442069} = "Llanelly";
$areanames{en}->{613442070} = "Lockington";
$areanames{en}->{613442071} = "Logan";
$areanames{en}->{613442072} = "Maldon";
$areanames{en}->{613442073} = "Marong";
$areanames{en}->{613442074} = "Maryborough";
$areanames{en}->{613442075} = "Mitiamo";
$areanames{en}->{613442076} = "Moonambel";
$areanames{en}->{613442077} = "Murrabit";
$areanames{en}->{613442078} = "Newstead";
$areanames{en}->{613442079} = "Nullawil";
$areanames{en}->{613442080} = "Pyramid\ Hill";
$areanames{en}->{613442081} = "Quambatook";
$areanames{en}->{613442082} = "Raywood";
$areanames{en}->{613442083} = "Redesdale";
$areanames{en}->{613442084} = "Rochester";
$areanames{en}->{613442085} = "Romsey";
$areanames{en}->{613442086} = "St\ Arnaud";
$areanames{en}->{613442087} = "Strathfieldsaye";
$areanames{en}->{613442088} = "Talbot";
$areanames{en}->{613442089} = "Tennyson";
$areanames{en}->{613442090} = "Traynors\ Lagoon";
$areanames{en}->{613442091} = "Trentham";
$areanames{en}->{613442092} = "Tullakool";
$areanames{en}->{613442093} = "Watchem";
$areanames{en}->{613442094} = "Wedderburn";
$areanames{en}->{613442095} = "Womboota";
$areanames{en}->{613442096} = "Woodend";
$areanames{en}->{613442097} = "Wycheproof";
$areanames{en}->{613442098} = "Amphitheatre";
$areanames{en}->{613442099} = "Avoca";
$areanames{en}->{613442100} = "Barham";
$areanames{en}->{613442101} = "Bealiba";
$areanames{en}->{613442102} = "Beazleys\ Bridge";
$areanames{en}->{613442103} = "Bendigo";
$areanames{en}->{613442104} = "Birchip";
$areanames{en}->{613442105} = "Boort";
$areanames{en}->{613442106} = "Bridgewater";
$areanames{en}->{613442107} = "Buckrabanyule";
$areanames{en}->{613442108} = "Carisbrook";
$areanames{en}->{613442109} = "Castlemaine";
$areanames{en}->{613442110} = "Charlton";
$areanames{en}->{613442111} = "Cohuna";
$areanames{en}->{613442112} = "Colbinabbin";
$areanames{en}->{613442113} = "Dingee";
$areanames{en}->{613442114} = "Donald";
$areanames{en}->{613442115} = "Dunolly";
$areanames{en}->{613442116} = "Echuca";
$areanames{en}->{613442117} = "Elmore";
$areanames{en}->{613442118} = "Gisborne";
$areanames{en}->{613442119} = "Goornong";
$areanames{en}->{613442120} = "Gowar\ East";
$areanames{en}->{613442121} = "Gunbower";
$areanames{en}->{613442122} = "Harcourt";
$areanames{en}->{613442123} = "Heathcote";
$areanames{en}->{613442124} = "Inglewood";
$areanames{en}->{613442125} = "Jarklin";
$areanames{en}->{613442126} = "Kerang";
$areanames{en}->{613442127} = "Korong\ Vale";
$areanames{en}->{613442128} = "Kyneton";
$areanames{en}->{613442129} = "Laen";
$areanames{en}->{613442130} = "Lake\ Meran";
$areanames{en}->{613442131} = "Lalbert";
$areanames{en}->{613442132} = "Llanelly";
$areanames{en}->{613442133} = "Lockington";
$areanames{en}->{613442134} = "Logan";
$areanames{en}->{613442135} = "Maldon";
$areanames{en}->{613442136} = "Marong";
$areanames{en}->{613442137} = "Maryborough";
$areanames{en}->{613442138} = "Mitiamo";
$areanames{en}->{613442139} = "Moonambel";
$areanames{en}->{613442140} = "Murrabit";
$areanames{en}->{613442141} = "Newstead";
$areanames{en}->{613442142} = "Nullawil";
$areanames{en}->{613442143} = "Pyramid\ Hill";
$areanames{en}->{613442144} = "Quambatook";
$areanames{en}->{613442145} = "Raywood";
$areanames{en}->{613442146} = "Redesdale";
$areanames{en}->{613442147} = "Rochester";
$areanames{en}->{613442148} = "Romsey";
$areanames{en}->{613442149} = "St\ Arnaud";
$areanames{en}->{613442150} = "Strathfieldsaye";
$areanames{en}->{613442151} = "Talbot";
$areanames{en}->{613442152} = "Tennyson";
$areanames{en}->{613442153} = "Traynors\ Lagoon";
$areanames{en}->{613442154} = "Trentham";
$areanames{en}->{613442155} = "Tullakool";
$areanames{en}->{613442156} = "Watchem";
$areanames{en}->{613442157} = "Wedderburn";
$areanames{en}->{613442158} = "Womboota";
$areanames{en}->{613442159} = "Woodend";
$areanames{en}->{613442160} = "Wycheproof";
$areanames{en}->{613442161} = "Amphitheatre";
$areanames{en}->{613442162} = "Avoca";
$areanames{en}->{613442163} = "Barham";
$areanames{en}->{613442164} = "Bealiba";
$areanames{en}->{613442165} = "Beazleys\ Bridge";
$areanames{en}->{613442166} = "Bendigo";
$areanames{en}->{613442167} = "Birchip";
$areanames{en}->{613442168} = "Boort";
$areanames{en}->{613442169} = "Bridgewater";
$areanames{en}->{61344217} = "Cohuna";
$areanames{en}->{61344218} = "Quambatook";
$areanames{en}->{61344219} = "Romsey";
$areanames{en}->{613442200} = "Buckrabanyule";
$areanames{en}->{613442201} = "Carisbrook";
$areanames{en}->{613442202} = "Castlemaine";
$areanames{en}->{613442203} = "Charlton";
$areanames{en}->{613442204} = "Cohuna";
$areanames{en}->{613442205} = "Colbinabbin";
$areanames{en}->{613442206} = "Dingee";
$areanames{en}->{613442207} = "Donald";
$areanames{en}->{613442208} = "Dunolly";
$areanames{en}->{613442209} = "Echuca";
$areanames{en}->{613442210} = "Elmore";
$areanames{en}->{613442211} = "Gisborne";
$areanames{en}->{613442212} = "Goornong";
$areanames{en}->{613442213} = "Gowar\ East";
$areanames{en}->{613442214} = "Gunbower";
$areanames{en}->{613442215} = "Harcourt";
$areanames{en}->{613442216} = "Heathcote";
$areanames{en}->{613442217} = "Inglewood";
$areanames{en}->{613442218} = "Jarklin";
$areanames{en}->{613442219} = "Kerang";
$areanames{en}->{613442220} = "Korong\ Vale";
$areanames{en}->{613442221} = "Kyneton";
$areanames{en}->{613442222} = "Laen";
$areanames{en}->{613442223} = "Lake\ Meran";
$areanames{en}->{613442224} = "Lalbert";
$areanames{en}->{613442225} = "Llanelly";
$areanames{en}->{613442226} = "Lockington";
$areanames{en}->{613442227} = "Logan";
$areanames{en}->{613442228} = "Maldon";
$areanames{en}->{613442229} = "Marong";
$areanames{en}->{613442230} = "Maryborough";
$areanames{en}->{613442231} = "Mitiamo";
$areanames{en}->{613442232} = "Moonambel";
$areanames{en}->{613442233} = "Murrabit";
$areanames{en}->{613442234} = "Newstead";
$areanames{en}->{613442235} = "Nullawil";
$areanames{en}->{613442236} = "Pyramid\ Hill";
$areanames{en}->{613442237} = "Quambatook";
$areanames{en}->{613442238} = "Raywood";
$areanames{en}->{613442239} = "Redesdale";
$areanames{en}->{613442240} = "Rochester";
$areanames{en}->{613442241} = "Romsey";
$areanames{en}->{613442242} = "St\ Arnaud";
$areanames{en}->{613442243} = "Strathfieldsaye";
$areanames{en}->{613442244} = "Talbot";
$areanames{en}->{613442245} = "Tennyson";
$areanames{en}->{613442246} = "Traynors\ Lagoon";
$areanames{en}->{613442247} = "Trentham";
$areanames{en}->{613442248} = "Tullakool";
$areanames{en}->{613442249} = "Watchem";
$areanames{en}->{613442250} = "Wedderburn";
$areanames{en}->{613442251} = "Womboota";
$areanames{en}->{613442252} = "Woodend";
$areanames{en}->{613442253} = "Wycheproof";
$areanames{en}->{61344226} = "Bridgewater";
$areanames{en}->{61344227} = "Maldon";
$areanames{en}->{61344230} = "Birchip";
$areanames{en}->{61344249} = "Lake\ Meran";
$areanames{en}->{61344260} = "Moonambel";
$areanames{en}->{61344311} = "Bendigo";
$areanames{en}->{61344312} = "Bendigo";
$areanames{en}->{61344313} = "Bendigo";
$areanames{en}->{61344314} = "Bendigo";
$areanames{en}->{61344315} = "Gisborne";
$areanames{en}->{61344316} = "Gisborne";
$areanames{en}->{61344317} = "Gisborne";
$areanames{en}->{61344318} = "Gisborne";
$areanames{en}->{61344319} = "Gisborne";
$areanames{en}->{61344322} = "Pyramid\ Hill";
$areanames{en}->{61344323} = "Kyneton";
$areanames{en}->{61344324} = "Kyneton";
$areanames{en}->{61344325} = "Gisborne";
$areanames{en}->{61344326} = "Gisborne";
$areanames{en}->{61344327} = "Bendigo";
$areanames{en}->{61344328} = "Bendigo";
$areanames{en}->{61344329} = "Echuca";
$areanames{en}->{6134433} = "Bendigo";
$areanames{en}->{61344340} = "Tennyson";
$areanames{en}->{61344341} = "Tennyson";
$areanames{en}->{61344342} = "Womboota";
$areanames{en}->{61344343} = "Womboota";
$areanames{en}->{61344344} = "Pyramid\ Hill";
$areanames{en}->{61344345} = "Pyramid\ Hill";
$areanames{en}->{61344346} = "Tullakool";
$areanames{en}->{61344347} = "Tullakool";
$areanames{en}->{61344348} = "Avoca";
$areanames{en}->{61344349} = "Avoca";
$areanames{en}->{6134435} = "Bendigo";
$areanames{en}->{61344361} = "Bendigo";
$areanames{en}->{61344362} = "Bendigo";
$areanames{en}->{61344363} = "Bendigo";
$areanames{en}->{61344364} = "Bendigo";
$areanames{en}->{61344365} = "Bendigo";
$areanames{en}->{61344366} = "Bendigo";
$areanames{en}->{61344367} = "Bendigo";
$areanames{en}->{61344368} = "Bendigo";
$areanames{en}->{61344369} = "Bendigo";
$areanames{en}->{61344380} = "Echuca";
$areanames{en}->{61344440} = "Castlemaine";
$areanames{en}->{61344441} = "Castlemaine";
$areanames{en}->{61344442} = "Bendigo";
$areanames{en}->{61344443} = "Bendigo";
$areanames{en}->{61344444} = "Bendigo";
$areanames{en}->{61344445} = "Gisborne";
$areanames{en}->{61344446} = "Goornong";
$areanames{en}->{61344447} = "Tennyson";
$areanames{en}->{61344448} = "Tennyson";
$areanames{en}->{61344449} = "Tennyson";
$areanames{en}->{61344554} = "Bendigo";
$areanames{en}->{61344555} = "Avoca";
$areanames{en}->{61344650} = "Avoca";
$areanames{en}->{61344651} = "Avoca";
$areanames{en}->{61344652} = "Kyneton";
$areanames{en}->{61344653} = "Kyneton";
$areanames{en}->{61345000} = "Woolsthorpe";
$areanames{en}->{61345001} = "Woolsthorpe";
$areanames{en}->{61345002} = "Warrnambool";
$areanames{en}->{61345003} = "Warrnambool";
$areanames{en}->{61345004} = "Port\ Fairy";
$areanames{en}->{61345005} = "Port\ Fairy";
$areanames{en}->{61345006} = "Panmure";
$areanames{en}->{61345007} = "Panmure";
$areanames{en}->{61345008} = "Nirranda";
$areanames{en}->{61345009} = "Nirranda";
$areanames{en}->{61345010} = "Hawkesdale";
$areanames{en}->{61345011} = "Hawkesdale";
$areanames{en}->{61345012} = "Tahara";
$areanames{en}->{61345013} = "Tahara";
$areanames{en}->{61345014} = "Victoria\ Valley";
$areanames{en}->{61345015} = "Victoria\ Valley";
$areanames{en}->{61345016} = "Wallacedale";
$areanames{en}->{61345017} = "Wallacedale";
$areanames{en}->{61345018} = "Wombelano";
$areanames{en}->{61345019} = "Wombelano";
$areanames{en}->{61345020} = "Camperdown";
$areanames{en}->{61345021} = "Camperdown";
$areanames{en}->{61345022} = "Dartmoor";
$areanames{en}->{61345023} = "Dartmoor";
$areanames{en}->{61345024} = "Hamilton";
$areanames{en}->{61345025} = "Hamilton";
$areanames{en}->{61345026} = "Mount\ Richmond";
$areanames{en}->{61345027} = "Mount\ Richmond";
$areanames{en}->{61345028} = "Benayeo";
$areanames{en}->{61345029} = "Benayeo";
$areanames{en}->{61345030} = "Ozenkadnook";
$areanames{en}->{61345031} = "Ozenkadnook";
$areanames{en}->{61345032} = "Poolaijelo";
$areanames{en}->{61345033} = "Poolaijelo";
$areanames{en}->{61345034} = "Balmoral";
$areanames{en}->{61345035} = "Balmoral";
$areanames{en}->{61345036} = "Harrow";
$areanames{en}->{61345037} = "Harrow";
$areanames{en}->{61345038} = "Woodhouse";
$areanames{en}->{61345039} = "Woodhouse";
$areanames{en}->{6134504} = "Warrnambool";
$areanames{en}->{61345040} = "Lake\ Mundi";
$areanames{en}->{61345041} = "Lake\ Mundi";
$areanames{en}->{61345043} = "Portland";
$areanames{en}->{61345048} = "Nirranda";
$areanames{en}->{61345050} = "Warrnambool";
$areanames{en}->{61345051} = "Hamilton";
$areanames{en}->{61345052} = "Warrnambool";
$areanames{en}->{61345053} = "Portland";
$areanames{en}->{61345054} = "Portland";
$areanames{en}->{613450550} = "Apsley";
$areanames{en}->{613450551} = "Balmoral";
$areanames{en}->{613450552} = "Benayeo";
$areanames{en}->{613450553} = "Bessiebelle";
$areanames{en}->{613450554} = "Camperdown";
$areanames{en}->{613450555} = "Caramut";
$areanames{en}->{613450556} = "Casterton";
$areanames{en}->{613450557} = "Cavendish";
$areanames{en}->{613450558} = "Chetwynd";
$areanames{en}->{613450559} = "Cobden";
$areanames{en}->{613450560} = "Coleraine";
$areanames{en}->{613450561} = "Coojar";
$areanames{en}->{613450562} = "Darlington";
$areanames{en}->{613450563} = "Dartmoor";
$areanames{en}->{613450564} = "Derrinallum";
$areanames{en}->{613450565} = "Dorodong";
$areanames{en}->{613450566} = "Dundonnell";
$areanames{en}->{613450567} = "Dunkeld";
$areanames{en}->{613450568} = "Ecklin";
$areanames{en}->{613450569} = "Edenhope";
$areanames{en}->{613450570} = "Glenthompson";
$areanames{en}->{613450571} = "Hamilton";
$areanames{en}->{613450572} = "Harrow";
$areanames{en}->{613450573} = "Hawkesdale";
$areanames{en}->{613450574} = "Heywood";
$areanames{en}->{613450575} = "Lake\ Mundi";
$areanames{en}->{613450576} = "Lismore";
$areanames{en}->{613450577} = "Macarthur";
$areanames{en}->{613450578} = "Merino";
$areanames{en}->{613450579} = "Mortlake";
$areanames{en}->{613450580} = "Mount\ Richmond";
$areanames{en}->{613450581} = "Nirranda";
$areanames{en}->{613450582} = "Ozenkadnook";
$areanames{en}->{613450583} = "Panmure";
$areanames{en}->{613450584} = "Penshurst";
$areanames{en}->{613450585} = "Pomborneit";
$areanames{en}->{613450586} = "Poolaijelo";
$areanames{en}->{613450587} = "Port\ Fairy";
$areanames{en}->{613450588} = "Portland";
$areanames{en}->{613450589} = "South\ Purrumbete";
$areanames{en}->{613450590} = "Strathdownie";
$areanames{en}->{613450591} = "Tahara";
$areanames{en}->{613450592} = "Terang";
$areanames{en}->{613450593} = "Timboon";
$areanames{en}->{613450594} = "Tyrendarra";
$areanames{en}->{613450595} = "Victoria\ Valley";
$areanames{en}->{613450596} = "Wallacedale";
$areanames{en}->{613450597} = "Warrnambool";
$areanames{en}->{613450598} = "Wombelano";
$areanames{en}->{613450599} = "Woodhouse";
$areanames{en}->{613450600} = "Woolsthorpe";
$areanames{en}->{613450601} = "Apsley";
$areanames{en}->{613450602} = "Balmoral";
$areanames{en}->{613450603} = "Benayeo";
$areanames{en}->{613450604} = "Bessiebelle";
$areanames{en}->{613450605} = "Camperdown";
$areanames{en}->{613450606} = "Caramut";
$areanames{en}->{613450607} = "Casterton";
$areanames{en}->{613450608} = "Cavendish";
$areanames{en}->{613450609} = "Chetwynd";
$areanames{en}->{61345061} = "Balmoral";
$areanames{en}->{61345062} = "Benayeo";
$areanames{en}->{61345063} = "Bessiebelle";
$areanames{en}->{61345064} = "Caramut";
$areanames{en}->{61345065} = "Cavendish";
$areanames{en}->{61345066} = "Coleraine";
$areanames{en}->{61345067} = "Coojar";
$areanames{en}->{61345068} = "Dartmoor";
$areanames{en}->{61345069} = "Derrinallum";
$areanames{en}->{61345070} = "Dorodong";
$areanames{en}->{61345071} = "Dunkeld";
$areanames{en}->{61345072} = "Ecklin";
$areanames{en}->{61345073} = "Edenhope";
$areanames{en}->{61345074} = "Harrow";
$areanames{en}->{61345075} = "Lake\ Mundi";
$areanames{en}->{61345076} = "Macarthur";
$areanames{en}->{61345077} = "Mortlake";
$areanames{en}->{61345078} = "Mount\ Richmond";
$areanames{en}->{61345079} = "Nirranda";
$areanames{en}->{61345080} = "Ozenkadnook";
$areanames{en}->{61345081} = "Penshurst";
$areanames{en}->{61345082} = "Pomborneit";
$areanames{en}->{61345083} = "Poolaijelo";
$areanames{en}->{61345084} = "Port\ Fairy";
$areanames{en}->{61345085} = "South\ Purrumbete";
$areanames{en}->{61345086} = "Strathdownie";
$areanames{en}->{61345087} = "Tahara";
$areanames{en}->{61345088} = "Tyrendarra";
$areanames{en}->{61345089} = "Victoria\ Valley";
$areanames{en}->{61345090} = "Wallacedale";
$areanames{en}->{61345091} = "Woodhouse";
$areanames{en}->{61345092} = "Woolsthorpe";
$areanames{en}->{61345093} = "Dundonnell";
$areanames{en}->{61345094} = "Cobden";
$areanames{en}->{61345095} = "Camperdown";
$areanames{en}->{61345096} = "Casterton";
$areanames{en}->{61345097} = "Lismore";
$areanames{en}->{61345098} = "Terang";
$areanames{en}->{613450990} = "Cobden";
$areanames{en}->{613450991} = "Coleraine";
$areanames{en}->{613450992} = "Coojar";
$areanames{en}->{613450993} = "Darlington";
$areanames{en}->{613450994} = "Dartmoor";
$areanames{en}->{613450995} = "Derrinallum";
$areanames{en}->{613450996} = "Dorodong";
$areanames{en}->{613450997} = "Dundonnell";
$areanames{en}->{613450998} = "Dunkeld";
$areanames{en}->{613450999} = "Ecklin";
$areanames{en}->{613451000} = "Edenhope";
$areanames{en}->{613451001} = "Glenthompson";
$areanames{en}->{613451002} = "Hamilton";
$areanames{en}->{613451003} = "Harrow";
$areanames{en}->{613451004} = "Hawkesdale";
$areanames{en}->{613451005} = "Heywood";
$areanames{en}->{613451006} = "Lake\ Mundi";
$areanames{en}->{613451007} = "Lismore";
$areanames{en}->{613451008} = "Macarthur";
$areanames{en}->{613451009} = "Merino";
$areanames{en}->{613451010} = "Mortlake";
$areanames{en}->{613451011} = "Mount\ Richmond";
$areanames{en}->{613451012} = "Nirranda";
$areanames{en}->{613451013} = "Ozenkadnook";
$areanames{en}->{613451014} = "Panmure";
$areanames{en}->{613451015} = "Penshurst";
$areanames{en}->{613451016} = "Pomborneit";
$areanames{en}->{613451017} = "Poolaijelo";
$areanames{en}->{613451018} = "Port\ Fairy";
$areanames{en}->{613451019} = "Portland";
$areanames{en}->{613451020} = "South\ Purrumbete";
$areanames{en}->{613451021} = "Strathdownie";
$areanames{en}->{613451022} = "Tahara";
$areanames{en}->{613451023} = "Terang";
$areanames{en}->{613451024} = "Timboon";
$areanames{en}->{613451025} = "Tyrendarra";
$areanames{en}->{613451026} = "Victoria\ Valley";
$areanames{en}->{613451027} = "Wallacedale";
$areanames{en}->{613451028} = "Warrnambool";
$areanames{en}->{613451029} = "Wombelano";
$areanames{en}->{613451030} = "Woodhouse";
$areanames{en}->{613451031} = "Woolsthorpe";
$areanames{en}->{613451032} = "Apsley";
$areanames{en}->{613451033} = "Balmoral";
$areanames{en}->{613451034} = "Benayeo";
$areanames{en}->{613451035} = "Bessiebelle";
$areanames{en}->{613451036} = "Camperdown";
$areanames{en}->{613451037} = "Caramut";
$areanames{en}->{613451038} = "Casterton";
$areanames{en}->{613451039} = "Cavendish";
$areanames{en}->{61345104} = "Dunkeld";
$areanames{en}->{613451050} = "Chetwynd";
$areanames{en}->{613451051} = "Cobden";
$areanames{en}->{613451052} = "Coleraine";
$areanames{en}->{613451053} = "Coojar";
$areanames{en}->{613451054} = "Darlington";
$areanames{en}->{613451055} = "Dartmoor";
$areanames{en}->{613451056} = "Derrinallum";
$areanames{en}->{613451057} = "Dorodong";
$areanames{en}->{613451058} = "Dundonnell";
$areanames{en}->{613451059} = "Dunkeld";
$areanames{en}->{613451060} = "Ecklin";
$areanames{en}->{613451061} = "Edenhope";
$areanames{en}->{613451062} = "Glenthompson";
$areanames{en}->{613451063} = "Hamilton";
$areanames{en}->{613451064} = "Harrow";
$areanames{en}->{613451065} = "Hawkesdale";
$areanames{en}->{613451066} = "Heywood";
$areanames{en}->{613451067} = "Lake\ Mundi";
$areanames{en}->{613451068} = "Lismore";
$areanames{en}->{613451069} = "Macarthur";
$areanames{en}->{613451070} = "Merino";
$areanames{en}->{613451071} = "Mortlake";
$areanames{en}->{613451072} = "Mount\ Richmond";
$areanames{en}->{613451073} = "Nirranda";
$areanames{en}->{613451074} = "Ozenkadnook";
$areanames{en}->{613451075} = "Panmure";
$areanames{en}->{613451076} = "Penshurst";
$areanames{en}->{613451077} = "Pomborneit";
$areanames{en}->{613451078} = "Poolaijelo";
$areanames{en}->{613451079} = "Port\ Fairy";
$areanames{en}->{613451080} = "Portland";
$areanames{en}->{613451081} = "South\ Purrumbete";
$areanames{en}->{613451082} = "Strathdownie";
$areanames{en}->{613451083} = "Tahara";
$areanames{en}->{613451084} = "Terang";
$areanames{en}->{613451085} = "Timboon";
$areanames{en}->{613451086} = "Tyrendarra";
$areanames{en}->{613451087} = "Victoria\ Valley";
$areanames{en}->{613451088} = "Wallacedale";
$areanames{en}->{613451089} = "Warrnambool";
$areanames{en}->{613451090} = "Wombelano";
$areanames{en}->{613451091} = "Woodhouse";
$areanames{en}->{613451092} = "Woolsthorpe";
$areanames{en}->{613451093} = "Apsley";
$areanames{en}->{613451094} = "Balmoral";
$areanames{en}->{613451095} = "Benayeo";
$areanames{en}->{613451096} = "Bessiebelle";
$areanames{en}->{613451097} = "Camperdown";
$areanames{en}->{613451098} = "Caramut";
$areanames{en}->{613451099} = "Casterton";
$areanames{en}->{61345110} = "Terang";
$areanames{en}->{61345111} = "Mortlake";
$areanames{en}->{61345112} = "Terang";
$areanames{en}->{61345113} = "Terang";
$areanames{en}->{61345114} = "Terang";
$areanames{en}->{613451150} = "Cavendish";
$areanames{en}->{613451151} = "Chetwynd";
$areanames{en}->{613451152} = "Cobden";
$areanames{en}->{613451153} = "Coleraine";
$areanames{en}->{613451154} = "Apsley";
$areanames{en}->{613451155} = "Balmoral";
$areanames{en}->{613451156} = "Benayeo";
$areanames{en}->{613451157} = "Bessiebelle";
$areanames{en}->{613451158} = "Camperdown";
$areanames{en}->{613451159} = "Caramut";
$areanames{en}->{613451160} = "Casterton";
$areanames{en}->{613451161} = "Cavendish";
$areanames{en}->{613451162} = "Chetwynd";
$areanames{en}->{613451163} = "Cobden";
$areanames{en}->{613451164} = "Coleraine";
$areanames{en}->{613451165} = "Coojar";
$areanames{en}->{613451166} = "Darlington";
$areanames{en}->{613451167} = "Dartmoor";
$areanames{en}->{613451168} = "Derrinallum";
$areanames{en}->{613451169} = "Dorodong";
$areanames{en}->{613451170} = "Dundonnell";
$areanames{en}->{613451171} = "Dunkeld";
$areanames{en}->{613451172} = "Ecklin";
$areanames{en}->{613451173} = "Edenhope";
$areanames{en}->{613451174} = "Glenthompson";
$areanames{en}->{613451175} = "Hamilton";
$areanames{en}->{613451176} = "Harrow";
$areanames{en}->{613451177} = "Hawkesdale";
$areanames{en}->{613451178} = "Heywood";
$areanames{en}->{613451179} = "Lake\ Mundi";
$areanames{en}->{613451180} = "Lismore";
$areanames{en}->{613451181} = "Macarthur";
$areanames{en}->{613451182} = "Merino";
$areanames{en}->{613451183} = "Mortlake";
$areanames{en}->{613451184} = "Mount\ Richmond";
$areanames{en}->{613451185} = "Nirranda";
$areanames{en}->{613451186} = "Ozenkadnook";
$areanames{en}->{613451187} = "Panmure";
$areanames{en}->{613451188} = "Penshurst";
$areanames{en}->{613451189} = "Pomborneit";
$areanames{en}->{613451190} = "Poolaijelo";
$areanames{en}->{613451191} = "Port\ Fairy";
$areanames{en}->{613451192} = "Portland";
$areanames{en}->{613451193} = "South\ Purrumbete";
$areanames{en}->{613451194} = "Strathdownie";
$areanames{en}->{613451195} = "Tahara";
$areanames{en}->{613451196} = "Terang";
$areanames{en}->{613451197} = "Timboon";
$areanames{en}->{613451198} = "Tyrendarra";
$areanames{en}->{613451199} = "Victoria\ Valley";
$areanames{en}->{613451200} = "Wallacedale";
$areanames{en}->{613451201} = "Warrnambool";
$areanames{en}->{613451202} = "Wombelano";
$areanames{en}->{613451203} = "Woodhouse";
$areanames{en}->{613451204} = "Woolsthorpe";
$areanames{en}->{613451205} = "Coojar";
$areanames{en}->{613451206} = "Darlington";
$areanames{en}->{613451207} = "Dartmoor";
$areanames{en}->{613451208} = "Derrinallum";
$areanames{en}->{613451209} = "Dorodong";
$areanames{en}->{61345121} = "Warrnambool";
$areanames{en}->{61345122} = "Warrnambool";
$areanames{en}->{61345123} = "Warrnambool";
$areanames{en}->{61345124} = "Timboon";
$areanames{en}->{61345125} = "Timboon";
$areanames{en}->{61345126} = "Timboon";
$areanames{en}->{613451270} = "Dundonnell";
$areanames{en}->{613451271} = "Dunkeld";
$areanames{en}->{613451272} = "Ecklin";
$areanames{en}->{613451273} = "Edenhope";
$areanames{en}->{613451274} = "Glenthompson";
$areanames{en}->{613451275} = "Hamilton";
$areanames{en}->{613451276} = "Harrow";
$areanames{en}->{613451277} = "Hawkesdale";
$areanames{en}->{613451278} = "Heywood";
$areanames{en}->{613451279} = "Lake\ Mundi";
$areanames{en}->{613451280} = "Lismore";
$areanames{en}->{613451281} = "Macarthur";
$areanames{en}->{613451282} = "Merino";
$areanames{en}->{613451283} = "Mortlake";
$areanames{en}->{613451284} = "Mount\ Richmond";
$areanames{en}->{613451285} = "Nirranda";
$areanames{en}->{613451286} = "Ozenkadnook";
$areanames{en}->{613451287} = "Panmure";
$areanames{en}->{613451288} = "Penshurst";
$areanames{en}->{613451289} = "Pomborneit";
$areanames{en}->{613451290} = "Poolaijelo";
$areanames{en}->{613451291} = "Port\ Fairy";
$areanames{en}->{613451292} = "Portland";
$areanames{en}->{613451293} = "South\ Purrumbete";
$areanames{en}->{613451294} = "Strathdownie";
$areanames{en}->{613451295} = "Tahara";
$areanames{en}->{613451296} = "Terang";
$areanames{en}->{613451297} = "Timboon";
$areanames{en}->{613451298} = "Tyrendarra";
$areanames{en}->{613451299} = "Victoria\ Valley";
$areanames{en}->{613451300} = "Wallacedale";
$areanames{en}->{613451301} = "Warrnambool";
$areanames{en}->{613451302} = "Wombelano";
$areanames{en}->{613451303} = "Woodhouse";
$areanames{en}->{613451304} = "Woolsthorpe";
$areanames{en}->{613451305} = "Apsley";
$areanames{en}->{613451306} = "Balmoral";
$areanames{en}->{613451307} = "Benayeo";
$areanames{en}->{613451308} = "Bessiebelle";
$areanames{en}->{613451309} = "Camperdown";
$areanames{en}->{613451310} = "Caramut";
$areanames{en}->{613451311} = "Casterton";
$areanames{en}->{613451312} = "Cavendish";
$areanames{en}->{613451313} = "Chetwynd";
$areanames{en}->{613451314} = "Cobden";
$areanames{en}->{613451315} = "Coleraine";
$areanames{en}->{613451316} = "Coojar";
$areanames{en}->{613451317} = "Darlington";
$areanames{en}->{613451318} = "Dartmoor";
$areanames{en}->{613451319} = "Derrinallum";
$areanames{en}->{613451320} = "Dorodong";
$areanames{en}->{613451321} = "Dundonnell";
$areanames{en}->{613451322} = "Dunkeld";
$areanames{en}->{613451323} = "Ecklin";
$areanames{en}->{613451324} = "Edenhope";
$areanames{en}->{613451325} = "Glenthompson";
$areanames{en}->{613451326} = "Hamilton";
$areanames{en}->{613451327} = "Harrow";
$areanames{en}->{613451328} = "Hawkesdale";
$areanames{en}->{613451329} = "Heywood";
$areanames{en}->{613451330} = "Lake\ Mundi";
$areanames{en}->{613451331} = "Lismore";
$areanames{en}->{613451332} = "Macarthur";
$areanames{en}->{613451333} = "Merino";
$areanames{en}->{613451334} = "Mortlake";
$areanames{en}->{613451335} = "Mount\ Richmond";
$areanames{en}->{613451336} = "Nirranda";
$areanames{en}->{613451337} = "Ozenkadnook";
$areanames{en}->{613451338} = "Panmure";
$areanames{en}->{613451339} = "Penshurst";
$areanames{en}->{613451340} = "Pomborneit";
$areanames{en}->{613451341} = "Poolaijelo";
$areanames{en}->{613451342} = "Port\ Fairy";
$areanames{en}->{613451343} = "Portland";
$areanames{en}->{613451344} = "South\ Purrumbete";
$areanames{en}->{613451345} = "Strathdownie";
$areanames{en}->{613451346} = "Tahara";
$areanames{en}->{613451347} = "Terang";
$areanames{en}->{613451348} = "Timboon";
$areanames{en}->{613451349} = "Tyrendarra";
$areanames{en}->{613451350} = "Victoria\ Valley";
$areanames{en}->{613451351} = "Wallacedale";
$areanames{en}->{613451352} = "Warrnambool";
$areanames{en}->{613451353} = "Wombelano";
$areanames{en}->{613451354} = "Woodhouse";
$areanames{en}->{613451355} = "Woolsthorpe";
$areanames{en}->{613451356} = "Apsley";
$areanames{en}->{613451357} = "Balmoral";
$areanames{en}->{613451358} = "Benayeo";
$areanames{en}->{613451359} = "Bessiebelle";
$areanames{en}->{613451360} = "Camperdown";
$areanames{en}->{613451361} = "Caramut";
$areanames{en}->{613451362} = "Casterton";
$areanames{en}->{613451363} = "Cavendish";
$areanames{en}->{613451364} = "Chetwynd";
$areanames{en}->{613451365} = "Cobden";
$areanames{en}->{613451366} = "Coleraine";
$areanames{en}->{613451367} = "Coojar";
$areanames{en}->{613451368} = "Darlington";
$areanames{en}->{613451369} = "Dartmoor";
$areanames{en}->{613451370} = "Derrinallum";
$areanames{en}->{613451371} = "Dorodong";
$areanames{en}->{613451372} = "Dundonnell";
$areanames{en}->{613451373} = "Dunkeld";
$areanames{en}->{613451374} = "Ecklin";
$areanames{en}->{613451375} = "Edenhope";
$areanames{en}->{613451376} = "Glenthompson";
$areanames{en}->{613451377} = "Hamilton";
$areanames{en}->{613451378} = "Harrow";
$areanames{en}->{613451379} = "Hawkesdale";
$areanames{en}->{613451380} = "Heywood";
$areanames{en}->{613451381} = "Lake\ Mundi";
$areanames{en}->{613451382} = "Lismore";
$areanames{en}->{613451383} = "Macarthur";
$areanames{en}->{613451384} = "Merino";
$areanames{en}->{613451385} = "Mortlake";
$areanames{en}->{613451386} = "Mount\ Richmond";
$areanames{en}->{613451387} = "Nirranda";
$areanames{en}->{613451388} = "Ozenkadnook";
$areanames{en}->{613451389} = "Panmure";
$areanames{en}->{613451390} = "Penshurst";
$areanames{en}->{613451391} = "Pomborneit";
$areanames{en}->{613451392} = "Poolaijelo";
$areanames{en}->{613451393} = "Port\ Fairy";
$areanames{en}->{613451394} = "Portland";
$areanames{en}->{613451395} = "South\ Purrumbete";
$areanames{en}->{613451396} = "Strathdownie";
$areanames{en}->{613451397} = "Tahara";
$areanames{en}->{613451398} = "Terang";
$areanames{en}->{613451399} = "Timboon";
$areanames{en}->{613451400} = "Tyrendarra";
$areanames{en}->{613451401} = "Victoria\ Valley";
$areanames{en}->{613451402} = "Wallacedale";
$areanames{en}->{613451403} = "Warrnambool";
$areanames{en}->{613451404} = "Wombelano";
$areanames{en}->{613451405} = "Woodhouse";
$areanames{en}->{613451406} = "Woolsthorpe";
$areanames{en}->{613451407} = "Apsley";
$areanames{en}->{613451408} = "Balmoral";
$areanames{en}->{613451409} = "Benayeo";
$areanames{en}->{613451410} = "Bessiebelle";
$areanames{en}->{613451411} = "Camperdown";
$areanames{en}->{613451412} = "Caramut";
$areanames{en}->{613451413} = "Casterton";
$areanames{en}->{613451414} = "Cavendish";
$areanames{en}->{613451415} = "Chetwynd";
$areanames{en}->{613451416} = "Cobden";
$areanames{en}->{613451417} = "Coleraine";
$areanames{en}->{613451418} = "Coojar";
$areanames{en}->{613451419} = "Darlington";
$areanames{en}->{613451420} = "Dartmoor";
$areanames{en}->{613451421} = "Derrinallum";
$areanames{en}->{613451422} = "Dorodong";
$areanames{en}->{613451423} = "Dundonnell";
$areanames{en}->{613451424} = "Dunkeld";
$areanames{en}->{613451425} = "Ecklin";
$areanames{en}->{613451426} = "Edenhope";
$areanames{en}->{613451427} = "Glenthompson";
$areanames{en}->{613451428} = "Hamilton";
$areanames{en}->{613451429} = "Harrow";
$areanames{en}->{613451430} = "Hawkesdale";
$areanames{en}->{613451431} = "Heywood";
$areanames{en}->{613451432} = "Lake\ Mundi";
$areanames{en}->{613451433} = "Lismore";
$areanames{en}->{613451434} = "Macarthur";
$areanames{en}->{613451435} = "Merino";
$areanames{en}->{613451436} = "Mortlake";
$areanames{en}->{613451437} = "Mount\ Richmond";
$areanames{en}->{613451438} = "Nirranda";
$areanames{en}->{613451439} = "Ozenkadnook";
$areanames{en}->{613451440} = "Panmure";
$areanames{en}->{613451441} = "Penshurst";
$areanames{en}->{613451442} = "Pomborneit";
$areanames{en}->{613451443} = "Poolaijelo";
$areanames{en}->{613451444} = "Port\ Fairy";
$areanames{en}->{613451445} = "Portland";
$areanames{en}->{613451446} = "South\ Purrumbete";
$areanames{en}->{613451447} = "Strathdownie";
$areanames{en}->{613451448} = "Tahara";
$areanames{en}->{613451449} = "Terang";
$areanames{en}->{613451450} = "Timboon";
$areanames{en}->{613451451} = "Tyrendarra";
$areanames{en}->{613451452} = "Victoria\ Valley";
$areanames{en}->{613451453} = "Wallacedale";
$areanames{en}->{613451454} = "Warrnambool";
$areanames{en}->{613451455} = "Wombelano";
$areanames{en}->{613451456} = "Woodhouse";
$areanames{en}->{613451457} = "Woolsthorpe";
$areanames{en}->{61345149} = "Darlington";
$areanames{en}->{61345160} = "Merino";
$areanames{en}->{61345170} = "Heywood";
$areanames{en}->{61345171} = "Macarthur";
$areanames{en}->{61347000} = "Euroa";
$areanames{en}->{61347001} = "Wangaratta";
$areanames{en}->{61347002} = "Wangaratta";
$areanames{en}->{61347003} = "Kilmore";
$areanames{en}->{61347004} = "Kinglake";
$areanames{en}->{61347005} = "Seymour";
$areanames{en}->{61347006} = "Benalla";
$areanames{en}->{61347007} = "Kilmore";
$areanames{en}->{61347008} = "Mansfield";
$areanames{en}->{61347009} = "Myrtleford";
$areanames{en}->{61347010} = "Kilmore";
$areanames{en}->{61347011} = "Seymour";
$areanames{en}->{61347012} = "Yarrawonga";
$areanames{en}->{613470130} = "Alexandra";
$areanames{en}->{613470131} = "Beechworth";
$areanames{en}->{613470132} = "Benalla";
$areanames{en}->{613470133} = "Bonnie\ Doon";
$areanames{en}->{613470134} = "Bright";
$areanames{en}->{613470135} = "Broadford";
$areanames{en}->{613470136} = "Buffalo\ River";
$areanames{en}->{613470137} = "Cheshunt";
$areanames{en}->{613470138} = "Chiltern";
$areanames{en}->{613470139} = "Creightons\ Creek";
$areanames{en}->{613470140} = "Devlins\ Bridge";
$areanames{en}->{613470141} = "Eildon";
$areanames{en}->{613470142} = "Euroa";
$areanames{en}->{613470143} = "Falls\ Creek";
$areanames{en}->{613470144} = "Flowerdale";
$areanames{en}->{613470145} = "Graytown";
$areanames{en}->{613470146} = "Harrietville";
$areanames{en}->{613470147} = "Jamieson";
$areanames{en}->{613470148} = "Killawarra";
$areanames{en}->{613470149} = "Kilmore";
$areanames{en}->{613470150} = "King\ Valley";
$areanames{en}->{613470151} = "Kinglake";
$areanames{en}->{613470152} = "Kobyboyn";
$areanames{en}->{613470153} = "Longwood";
$areanames{en}->{613470154} = "Mansfield";
$areanames{en}->{613470155} = "Mount\ Beauty";
$areanames{en}->{613470156} = "Mount\ Buller";
$areanames{en}->{613470157} = "Moyhu";
$areanames{en}->{613470158} = "Myrtleford";
$areanames{en}->{613470159} = "Nagambie";
$areanames{en}->{613470160} = "Puckapunyal";
$areanames{en}->{613470161} = "Pyalong";
$areanames{en}->{613470162} = "Seymour";
$areanames{en}->{613470163} = "St\ James";
$areanames{en}->{613470164} = "Strathbogie";
$areanames{en}->{613470165} = "Swanpool";
$areanames{en}->{613470166} = "Taggerty";
$areanames{en}->{613470167} = "Tatong";
$areanames{en}->{613470168} = "Thoona";
$areanames{en}->{613470169} = "Tungamah";
$areanames{en}->{613470170} = "Violet\ Town";
$areanames{en}->{613470171} = "Wangaratta";
$areanames{en}->{613470172} = "Whorouly";
$areanames{en}->{613470173} = "Winton";
$areanames{en}->{613470174} = "Woods\ Point";
$areanames{en}->{613470175} = "Yarck";
$areanames{en}->{613470176} = "Yarrawonga";
$areanames{en}->{613470177} = "Yea";
$areanames{en}->{613470178} = "Alexandra";
$areanames{en}->{613470179} = "Beechworth";
$areanames{en}->{61347018} = "Bonnie\ Doon";
$areanames{en}->{61347019} = "Buffalo\ River";
$areanames{en}->{61347020} = "Creightons\ Creek";
$areanames{en}->{61347021} = "Eildon";
$areanames{en}->{61347022} = "Euroa";
$areanames{en}->{61347023} = "Falls\ Creek";
$areanames{en}->{61347024} = "Flowerdale";
$areanames{en}->{61347025} = "Graytown";
$areanames{en}->{61347026} = "Harrietville";
$areanames{en}->{61347027} = "Jamieson";
$areanames{en}->{61347028} = "Killawarra";
$areanames{en}->{61347029} = "King\ Valley";
$areanames{en}->{61347030} = "Kobyboyn";
$areanames{en}->{61347031} = "Longwood";
$areanames{en}->{61347032} = "Mount\ Beauty";
$areanames{en}->{61347033} = "Mount\ Buller";
$areanames{en}->{61347034} = "Moyhu";
$areanames{en}->{61347035} = "Nagambie";
$areanames{en}->{61347036} = "Puckapunyal";
$areanames{en}->{61347037} = "Pyalong";
$areanames{en}->{61347038} = "Swanpool";
$areanames{en}->{61347039} = "Taggerty";
$areanames{en}->{61347040} = "Tatong";
$areanames{en}->{61347041} = "Thoona";
$areanames{en}->{61347042} = "Tungamah";
$areanames{en}->{61347043} = "Violet\ Town";
$areanames{en}->{61347044} = "Whorouly";
$areanames{en}->{61347045} = "Winton";
$areanames{en}->{61347046} = "Yea";
$areanames{en}->{61347047} = "Myrtleford";
$areanames{en}->{61347048} = "Chiltern";
$areanames{en}->{61347049} = "Seymour";
$areanames{en}->{61347050} = "Broadford";
$areanames{en}->{61347051} = "Bright";
$areanames{en}->{61347052} = "Yarrawonga";
$areanames{en}->{613470530} = "Benalla";
$areanames{en}->{613470531} = "Bonnie\ Doon";
$areanames{en}->{613470532} = "Bright";
$areanames{en}->{613470533} = "Broadford";
$areanames{en}->{613470534} = "Buffalo\ River";
$areanames{en}->{613470535} = "Cheshunt";
$areanames{en}->{613470536} = "Chiltern";
$areanames{en}->{613470537} = "Creightons\ Creek";
$areanames{en}->{613470538} = "Devlins\ Bridge";
$areanames{en}->{613470539} = "Eildon";
$areanames{en}->{613470540} = "Euroa";
$areanames{en}->{613470541} = "Falls\ Creek";
$areanames{en}->{613470542} = "Flowerdale";
$areanames{en}->{613470543} = "Graytown";
$areanames{en}->{613470544} = "Harrietville";
$areanames{en}->{613470545} = "Jamieson";
$areanames{en}->{613470546} = "Killawarra";
$areanames{en}->{613470547} = "Kilmore";
$areanames{en}->{613470548} = "King\ Valley";
$areanames{en}->{613470549} = "Kinglake";
$areanames{en}->{613470550} = "Kobyboyn";
$areanames{en}->{613470551} = "Longwood";
$areanames{en}->{613470552} = "Mansfield";
$areanames{en}->{613470553} = "Mount\ Beauty";
$areanames{en}->{613470554} = "Mount\ Buller";
$areanames{en}->{613470555} = "Moyhu";
$areanames{en}->{613470556} = "Myrtleford";
$areanames{en}->{613470557} = "Nagambie";
$areanames{en}->{613470558} = "Puckapunyal";
$areanames{en}->{613470559} = "Pyalong";
$areanames{en}->{613470560} = "Seymour";
$areanames{en}->{613470561} = "St\ James";
$areanames{en}->{613470562} = "Strathbogie";
$areanames{en}->{613470563} = "Swanpool";
$areanames{en}->{613470564} = "Taggerty";
$areanames{en}->{613470565} = "Tatong";
$areanames{en}->{613470566} = "Thoona";
$areanames{en}->{613470567} = "Tungamah";
$areanames{en}->{613470568} = "Violet\ Town";
$areanames{en}->{613470569} = "Wangaratta";
$areanames{en}->{613470570} = "Whorouly";
$areanames{en}->{613470571} = "Winton";
$areanames{en}->{613470572} = "Woods\ Point";
$areanames{en}->{613470573} = "Yarck";
$areanames{en}->{613470574} = "Yarrawonga";
$areanames{en}->{613470575} = "Yea";
$areanames{en}->{613470576} = "Alexandra";
$areanames{en}->{613470577} = "Beechworth";
$areanames{en}->{613470578} = "Benalla";
$areanames{en}->{613470579} = "Bonnie\ Doon";
$areanames{en}->{613470580} = "Bright";
$areanames{en}->{613470581} = "Broadford";
$areanames{en}->{613470582} = "Buffalo\ River";
$areanames{en}->{613470583} = "Cheshunt";
$areanames{en}->{613470584} = "Chiltern";
$areanames{en}->{613470585} = "Creightons\ Creek";
$areanames{en}->{613470586} = "Devlins\ Bridge";
$areanames{en}->{613470587} = "Eildon";
$areanames{en}->{613470588} = "Euroa";
$areanames{en}->{613470589} = "Falls\ Creek";
$areanames{en}->{613470590} = "Flowerdale";
$areanames{en}->{613470591} = "Graytown";
$areanames{en}->{613470592} = "Harrietville";
$areanames{en}->{613470593} = "Jamieson";
$areanames{en}->{613470594} = "Killawarra";
$areanames{en}->{613470595} = "Kilmore";
$areanames{en}->{613470596} = "King\ Valley";
$areanames{en}->{613470597} = "Kinglake";
$areanames{en}->{613470598} = "Kobyboyn";
$areanames{en}->{613470599} = "Longwood";
$areanames{en}->{613470600} = "Mansfield";
$areanames{en}->{613470601} = "Mount\ Beauty";
$areanames{en}->{613470602} = "Mount\ Buller";
$areanames{en}->{613470603} = "Moyhu";
$areanames{en}->{613470604} = "Myrtleford";
$areanames{en}->{613470605} = "Nagambie";
$areanames{en}->{613470606} = "Puckapunyal";
$areanames{en}->{613470607} = "Pyalong";
$areanames{en}->{613470608} = "Seymour";
$areanames{en}->{613470609} = "St\ James";
$areanames{en}->{613470610} = "Strathbogie";
$areanames{en}->{613470611} = "Swanpool";
$areanames{en}->{613470612} = "Taggerty";
$areanames{en}->{613470613} = "Tatong";
$areanames{en}->{613470614} = "Thoona";
$areanames{en}->{613470615} = "Tungamah";
$areanames{en}->{613470616} = "Violet\ Town";
$areanames{en}->{613470617} = "Wangaratta";
$areanames{en}->{613470618} = "Whorouly";
$areanames{en}->{613470619} = "Winton";
$areanames{en}->{613470620} = "Woods\ Point";
$areanames{en}->{613470621} = "Yarck";
$areanames{en}->{613470622} = "Yarrawonga";
$areanames{en}->{613470623} = "Yea";
$areanames{en}->{613470624} = "Alexandra";
$areanames{en}->{613470625} = "Beechworth";
$areanames{en}->{613470626} = "Benalla";
$areanames{en}->{613470627} = "Bonnie\ Doon";
$areanames{en}->{613470628} = "Bright";
$areanames{en}->{613470629} = "Broadford";
$areanames{en}->{61347063} = "Wangaratta";
$areanames{en}->{61347064} = "Wangaratta";
$areanames{en}->{61347065} = "Seymour";
$areanames{en}->{61347066} = "Seymour";
$areanames{en}->{613470670} = "Buffalo\ River";
$areanames{en}->{613470671} = "Cheshunt";
$areanames{en}->{613470672} = "Alexandra";
$areanames{en}->{613470673} = "Beechworth";
$areanames{en}->{613470674} = "Benalla";
$areanames{en}->{613470675} = "Bonnie\ Doon";
$areanames{en}->{613470676} = "Bright";
$areanames{en}->{613470677} = "Broadford";
$areanames{en}->{613470678} = "Buffalo\ River";
$areanames{en}->{613470679} = "Cheshunt";
$areanames{en}->{613470680} = "Chiltern";
$areanames{en}->{613470681} = "Creightons\ Creek";
$areanames{en}->{613470682} = "Devlins\ Bridge";
$areanames{en}->{613470683} = "Eildon";
$areanames{en}->{613470684} = "Euroa";
$areanames{en}->{613470685} = "Falls\ Creek";
$areanames{en}->{613470686} = "Flowerdale";
$areanames{en}->{613470687} = "Graytown";
$areanames{en}->{613470688} = "Harrietville";
$areanames{en}->{613470689} = "Jamieson";
$areanames{en}->{613470690} = "Killawarra";
$areanames{en}->{613470691} = "Kilmore";
$areanames{en}->{613470692} = "King\ Valley";
$areanames{en}->{613470693} = "Kinglake";
$areanames{en}->{613470694} = "Kobyboyn";
$areanames{en}->{613470695} = "Longwood";
$areanames{en}->{613470696} = "Mansfield";
$areanames{en}->{613470697} = "Mount\ Beauty";
$areanames{en}->{613470698} = "Mount\ Buller";
$areanames{en}->{613470699} = "Moyhu";
$areanames{en}->{613470700} = "Myrtleford";
$areanames{en}->{613470701} = "Nagambie";
$areanames{en}->{613470702} = "Puckapunyal";
$areanames{en}->{613470703} = "Pyalong";
$areanames{en}->{613470704} = "Seymour";
$areanames{en}->{613470705} = "St\ James";
$areanames{en}->{613470706} = "Strathbogie";
$areanames{en}->{613470707} = "Swanpool";
$areanames{en}->{613470708} = "Taggerty";
$areanames{en}->{613470709} = "Tatong";
$areanames{en}->{613470710} = "Thoona";
$areanames{en}->{613470711} = "Tungamah";
$areanames{en}->{613470712} = "Violet\ Town";
$areanames{en}->{613470713} = "Wangaratta";
$areanames{en}->{613470714} = "Whorouly";
$areanames{en}->{613470715} = "Winton";
$areanames{en}->{613470716} = "Woods\ Point";
$areanames{en}->{613470717} = "Yarck";
$areanames{en}->{613470718} = "Yarrawonga";
$areanames{en}->{613470719} = "Yea";
$areanames{en}->{61347072} = "Falls\ Creek";
$areanames{en}->{61347073} = "Broadford";
$areanames{en}->{61347074} = "Broadford";
$areanames{en}->{61347075} = "Broadford";
$areanames{en}->{61347076} = "Broadford";
$areanames{en}->{613470770} = "Chiltern";
$areanames{en}->{613470771} = "Creightons\ Creek";
$areanames{en}->{613470772} = "Devlins\ Bridge";
$areanames{en}->{613470773} = "Eildon";
$areanames{en}->{613470774} = "Euroa";
$areanames{en}->{613470775} = "Falls\ Creek";
$areanames{en}->{613470776} = "Flowerdale";
$areanames{en}->{613470777} = "Graytown";
$areanames{en}->{613470778} = "Harrietville";
$areanames{en}->{613470779} = "Jamieson";
$areanames{en}->{613470780} = "Killawarra";
$areanames{en}->{613470781} = "Kilmore";
$areanames{en}->{613470782} = "King\ Valley";
$areanames{en}->{613470783} = "Kinglake";
$areanames{en}->{613470784} = "Kobyboyn";
$areanames{en}->{613470785} = "Longwood";
$areanames{en}->{613470786} = "Mansfield";
$areanames{en}->{613470787} = "Mount\ Beauty";
$areanames{en}->{613470788} = "Mount\ Buller";
$areanames{en}->{613470789} = "Moyhu";
$areanames{en}->{613470790} = "Myrtleford";
$areanames{en}->{613470791} = "Nagambie";
$areanames{en}->{613470792} = "Puckapunyal";
$areanames{en}->{613470793} = "Pyalong";
$areanames{en}->{613470794} = "Seymour";
$areanames{en}->{613470795} = "St\ James";
$areanames{en}->{613470796} = "Strathbogie";
$areanames{en}->{613470797} = "Swanpool";
$areanames{en}->{613470798} = "Taggerty";
$areanames{en}->{613470799} = "Tatong";
$areanames{en}->{613470800} = "Thoona";
$areanames{en}->{613470801} = "Tungamah";
$areanames{en}->{613470802} = "Violet\ Town";
$areanames{en}->{613470803} = "Wangaratta";
$areanames{en}->{613470804} = "Whorouly";
$areanames{en}->{613470805} = "Winton";
$areanames{en}->{613470806} = "Woods\ Point";
$areanames{en}->{613470807} = "Yarck";
$areanames{en}->{613470808} = "Yarrawonga";
$areanames{en}->{613470809} = "Yea";
$areanames{en}->{613470810} = "Alexandra";
$areanames{en}->{613470811} = "Beechworth";
$areanames{en}->{613470812} = "Benalla";
$areanames{en}->{613470813} = "Bonnie\ Doon";
$areanames{en}->{613470814} = "Bright";
$areanames{en}->{613470815} = "Broadford";
$areanames{en}->{613470816} = "Buffalo\ River";
$areanames{en}->{613470817} = "Cheshunt";
$areanames{en}->{613470818} = "Chiltern";
$areanames{en}->{613470819} = "Creightons\ Creek";
$areanames{en}->{613470820} = "Devlins\ Bridge";
$areanames{en}->{613470821} = "Eildon";
$areanames{en}->{613470822} = "Euroa";
$areanames{en}->{613470823} = "Falls\ Creek";
$areanames{en}->{613470824} = "Flowerdale";
$areanames{en}->{613470825} = "Graytown";
$areanames{en}->{613470826} = "Harrietville";
$areanames{en}->{613470827} = "Jamieson";
$areanames{en}->{613470828} = "Killawarra";
$areanames{en}->{613470829} = "Kilmore";
$areanames{en}->{613470830} = "King\ Valley";
$areanames{en}->{613470831} = "Kinglake";
$areanames{en}->{613470832} = "Kobyboyn";
$areanames{en}->{613470833} = "Longwood";
$areanames{en}->{613470834} = "Mansfield";
$areanames{en}->{613470835} = "Mount\ Beauty";
$areanames{en}->{613470836} = "Mount\ Buller";
$areanames{en}->{613470837} = "Moyhu";
$areanames{en}->{613470838} = "Myrtleford";
$areanames{en}->{613470839} = "Nagambie";
$areanames{en}->{613470840} = "Puckapunyal";
$areanames{en}->{613470841} = "Pyalong";
$areanames{en}->{613470842} = "Seymour";
$areanames{en}->{613470843} = "St\ James";
$areanames{en}->{613470844} = "Strathbogie";
$areanames{en}->{613470845} = "Swanpool";
$areanames{en}->{613470846} = "Taggerty";
$areanames{en}->{613470847} = "Tatong";
$areanames{en}->{613470848} = "Thoona";
$areanames{en}->{613470849} = "Tungamah";
$areanames{en}->{613470850} = "Violet\ Town";
$areanames{en}->{613470851} = "Wangaratta";
$areanames{en}->{613470852} = "Whorouly";
$areanames{en}->{613470853} = "Winton";
$areanames{en}->{613470854} = "Woods\ Point";
$areanames{en}->{613470855} = "Yarck";
$areanames{en}->{613470856} = "Yarrawonga";
$areanames{en}->{613470857} = "Yea";
$areanames{en}->{613470858} = "Alexandra";
$areanames{en}->{613470859} = "Beechworth";
$areanames{en}->{613470860} = "Benalla";
$areanames{en}->{613470861} = "Bonnie\ Doon";
$areanames{en}->{613470862} = "Bright";
$areanames{en}->{613470863} = "Broadford";
$areanames{en}->{613470864} = "Buffalo\ River";
$areanames{en}->{613470865} = "Cheshunt";
$areanames{en}->{613470866} = "Chiltern";
$areanames{en}->{613470867} = "Creightons\ Creek";
$areanames{en}->{613470868} = "Devlins\ Bridge";
$areanames{en}->{613470869} = "Eildon";
$areanames{en}->{613470870} = "Euroa";
$areanames{en}->{613470871} = "Falls\ Creek";
$areanames{en}->{613470872} = "Flowerdale";
$areanames{en}->{613470873} = "Graytown";
$areanames{en}->{613470874} = "Harrietville";
$areanames{en}->{613470875} = "Jamieson";
$areanames{en}->{613470876} = "Killawarra";
$areanames{en}->{613470877} = "Kilmore";
$areanames{en}->{613470878} = "King\ Valley";
$areanames{en}->{613470879} = "Kinglake";
$areanames{en}->{613470880} = "Kobyboyn";
$areanames{en}->{613470881} = "Longwood";
$areanames{en}->{613470882} = "Mansfield";
$areanames{en}->{613470883} = "Mount\ Beauty";
$areanames{en}->{613470884} = "Mount\ Buller";
$areanames{en}->{613470885} = "Moyhu";
$areanames{en}->{613470886} = "Myrtleford";
$areanames{en}->{613470887} = "Nagambie";
$areanames{en}->{613470888} = "Puckapunyal";
$areanames{en}->{613470889} = "Pyalong";
$areanames{en}->{613470890} = "Seymour";
$areanames{en}->{613470891} = "St\ James";
$areanames{en}->{613470892} = "Strathbogie";
$areanames{en}->{613470893} = "Swanpool";
$areanames{en}->{613470894} = "Taggerty";
$areanames{en}->{613470895} = "Tatong";
$areanames{en}->{613470896} = "Thoona";
$areanames{en}->{613470897} = "Tungamah";
$areanames{en}->{613470898} = "Violet\ Town";
$areanames{en}->{613470899} = "Wangaratta";
$areanames{en}->{613470900} = "Whorouly";
$areanames{en}->{613470901} = "Winton";
$areanames{en}->{613470902} = "Woods\ Point";
$areanames{en}->{613470903} = "Yarck";
$areanames{en}->{613470904} = "Yarrawonga";
$areanames{en}->{613470905} = "Yea";
$areanames{en}->{613470906} = "Alexandra";
$areanames{en}->{613470907} = "Beechworth";
$areanames{en}->{613470908} = "Benalla";
$areanames{en}->{613470909} = "Bonnie\ Doon";
$areanames{en}->{613470910} = "Bright";
$areanames{en}->{613470911} = "Broadford";
$areanames{en}->{613470912} = "Buffalo\ River";
$areanames{en}->{613470913} = "Cheshunt";
$areanames{en}->{613470914} = "Chiltern";
$areanames{en}->{613470915} = "Creightons\ Creek";
$areanames{en}->{613470916} = "Devlins\ Bridge";
$areanames{en}->{613470917} = "Eildon";
$areanames{en}->{613470918} = "Euroa";
$areanames{en}->{613470919} = "Falls\ Creek";
$areanames{en}->{613470920} = "Flowerdale";
$areanames{en}->{613470921} = "Graytown";
$areanames{en}->{613470922} = "Harrietville";
$areanames{en}->{613470923} = "Jamieson";
$areanames{en}->{613470924} = "Killawarra";
$areanames{en}->{613470925} = "Kilmore";
$areanames{en}->{613470926} = "King\ Valley";
$areanames{en}->{613470927} = "Kinglake";
$areanames{en}->{613470928} = "Kobyboyn";
$areanames{en}->{613470929} = "Longwood";
$areanames{en}->{613470930} = "Mansfield";
$areanames{en}->{613470931} = "Mount\ Beauty";
$areanames{en}->{613470932} = "Mount\ Buller";
$areanames{en}->{613470933} = "Moyhu";
$areanames{en}->{613470934} = "Myrtleford";
$areanames{en}->{613470935} = "Nagambie";
$areanames{en}->{613470936} = "Puckapunyal";
$areanames{en}->{613470937} = "Pyalong";
$areanames{en}->{613470938} = "Seymour";
$areanames{en}->{613470939} = "St\ James";
$areanames{en}->{613470940} = "Strathbogie";
$areanames{en}->{613470941} = "Swanpool";
$areanames{en}->{613470942} = "Taggerty";
$areanames{en}->{613470943} = "Tatong";
$areanames{en}->{613470944} = "Thoona";
$areanames{en}->{613470945} = "Tungamah";
$areanames{en}->{613470946} = "Violet\ Town";
$areanames{en}->{613470947} = "Wangaratta";
$areanames{en}->{613470948} = "Whorouly";
$areanames{en}->{613470949} = "Winton";
$areanames{en}->{613470950} = "Woods\ Point";
$areanames{en}->{613470951} = "Yarck";
$areanames{en}->{613470952} = "Yarrawonga";
$areanames{en}->{613470953} = "Yea";
$areanames{en}->{61347099} = "Cheshunt";
$areanames{en}->{61347110} = "Kinglake";
$areanames{en}->{6134800} = "Shepparton";
$areanames{en}->{61348004} = "Cobram";
$areanames{en}->{61348006} = "Tocumwal";
$areanames{en}->{61348007} = "Cobram";
$areanames{en}->{61348009} = "Berrigan";
$areanames{en}->{61348010} = "Blighty";
$areanames{en}->{61348011} = "Brassi";
$areanames{en}->{61348012} = "Caldwell";
$areanames{en}->{61348013} = "Cobram";
$areanames{en}->{61348014} = "Conargo";
$areanames{en}->{61348015} = "Cornalla";
$areanames{en}->{61348016} = "Deniliquin";
$areanames{en}->{61348017} = "Dookie";
$areanames{en}->{61348018} = "Finley";
$areanames{en}->{61348019} = "Jerilderie";
$areanames{en}->{61348020} = "Jimaringle";
$areanames{en}->{61348021} = "Katamatite";
$areanames{en}->{61348022} = "Katandra\ West";
$areanames{en}->{61348023} = "Kialla\ East";
$areanames{en}->{61348024} = "Kyabram";
$areanames{en}->{61348025} = "Lalalty";
$areanames{en}->{61348026} = "Logie\ Brae";
$areanames{en}->{61348027} = "Mabins\ Well";
$areanames{en}->{61348028} = "Mathoura";
$areanames{en}->{61348029} = "Moulamein";
$areanames{en}->{61348030} = "Nathalia";
$areanames{en}->{61348031} = "Numurkah";
$areanames{en}->{61348032} = "Picola";
$areanames{en}->{61348033} = "Rushworth";
$areanames{en}->{61348034} = "Shepparton";
$areanames{en}->{61348035} = "Tatura";
$areanames{en}->{61348036} = "Tocumwal";
$areanames{en}->{61348037} = "Tongala";
$areanames{en}->{61348038} = "Undera";
$areanames{en}->{61348039} = "Wakool";
$areanames{en}->{6134804} = "Shepparton";
$areanames{en}->{61348040} = "Wanganella";
$areanames{en}->{61348041} = "Yalca";
$areanames{en}->{61348050} = "Tatura";
$areanames{en}->{61348051} = "Shepparton";
$areanames{en}->{61348052} = "Kialla\ East";
$areanames{en}->{61348053} = "Kyabram";
$areanames{en}->{61348054} = "Berrigan";
$areanames{en}->{61348055} = "Blighty";
$areanames{en}->{61348056} = "Brassi";
$areanames{en}->{61348057} = "Caldwell";
$areanames{en}->{61348058} = "Cobram";
$areanames{en}->{61348059} = "Conargo";
$areanames{en}->{61348060} = "Cornalla";
$areanames{en}->{61348061} = "Deniliquin";
$areanames{en}->{61348062} = "Dookie";
$areanames{en}->{61348063} = "Finley";
$areanames{en}->{61348064} = "Jerilderie";
$areanames{en}->{61348065} = "Jimaringle";
$areanames{en}->{61348066} = "Katamatite";
$areanames{en}->{61348067} = "Katandra\ West";
$areanames{en}->{61348068} = "Kialla\ East";
$areanames{en}->{61348069} = "Kyabram";
$areanames{en}->{61348070} = "Lalalty";
$areanames{en}->{61348071} = "Logie\ Brae";
$areanames{en}->{61348072} = "Mabins\ Well";
$areanames{en}->{61348073} = "Mathoura";
$areanames{en}->{61348074} = "Moulamein";
$areanames{en}->{61348075} = "Nathalia";
$areanames{en}->{61348076} = "Numurkah";
$areanames{en}->{61348077} = "Picola";
$areanames{en}->{61348078} = "Rushworth";
$areanames{en}->{61348079} = "Shepparton";
$areanames{en}->{61348080} = "Tatura";
$areanames{en}->{61348081} = "Tocumwal";
$areanames{en}->{61348082} = "Tongala";
$areanames{en}->{61348083} = "Undera";
$areanames{en}->{61348084} = "Wakool";
$areanames{en}->{61348085} = "Wanganella";
$areanames{en}->{61348086} = "Yalca";
$areanames{en}->{61348087} = "Tatura";
$areanames{en}->{61348088} = "Tatura";
$areanames{en}->{61348089} = "Tatura";
$areanames{en}->{61348090} = "Berrigan";
$areanames{en}->{61348091} = "Blighty";
$areanames{en}->{61348092} = "Brassi";
$areanames{en}->{61348093} = "Caldwell";
$areanames{en}->{61348094} = "Cobram";
$areanames{en}->{61348095} = "Conargo";
$areanames{en}->{61348096} = "Cornalla";
$areanames{en}->{61348097} = "Deniliquin";
$areanames{en}->{61348098} = "Dookie";
$areanames{en}->{61348099} = "Finley";
$areanames{en}->{61348100} = "Jerilderie";
$areanames{en}->{61348101} = "Jimaringle";
$areanames{en}->{61348102} = "Katamatite";
$areanames{en}->{61348103} = "Katandra\ West";
$areanames{en}->{61348104} = "Kialla\ East";
$areanames{en}->{61348105} = "Kyabram";
$areanames{en}->{61348106} = "Lalalty";
$areanames{en}->{61348107} = "Logie\ Brae";
$areanames{en}->{61348108} = "Mabins\ Well";
$areanames{en}->{61348109} = "Mathoura";
$areanames{en}->{61348110} = "Moulamein";
$areanames{en}->{61348111} = "Nathalia";
$areanames{en}->{61348112} = "Numurkah";
$areanames{en}->{61348113} = "Picola";
$areanames{en}->{61348114} = "Rushworth";
$areanames{en}->{61348115} = "Shepparton";
$areanames{en}->{61348116} = "Tatura";
$areanames{en}->{61348117} = "Tocumwal";
$areanames{en}->{61348118} = "Tongala";
$areanames{en}->{61348119} = "Undera";
$areanames{en}->{6134812} = "Shepparton";
$areanames{en}->{61348120} = "Wakool";
$areanames{en}->{61348130} = "Shepparton";
$areanames{en}->{61348131} = "Wanganella";
$areanames{en}->{61348132} = "Yalca";
$areanames{en}->{61348133} = "Tongala";
$areanames{en}->{61348134} = "Tongala";
$areanames{en}->{61348135} = "Tongala";
$areanames{en}->{61348136} = "Tocumwal";
$areanames{en}->{61348137} = "Tocumwal";
$areanames{en}->{61348138} = "Tocumwal";
$areanames{en}->{61348139} = "Berrigan";
$areanames{en}->{61348140} = "Blighty";
$areanames{en}->{61348141} = "Brassi";
$areanames{en}->{61348142} = "Caldwell";
$areanames{en}->{61348143} = "Cobram";
$areanames{en}->{61348144} = "Conargo";
$areanames{en}->{61348145} = "Cornalla";
$areanames{en}->{61348146} = "Deniliquin";
$areanames{en}->{61348147} = "Dookie";
$areanames{en}->{61348148} = "Finley";
$areanames{en}->{61348149} = "Jerilderie";
$areanames{en}->{61348150} = "Jimaringle";
$areanames{en}->{61348151} = "Katamatite";
$areanames{en}->{61348152} = "Katandra\ West";
$areanames{en}->{61348153} = "Kialla\ East";
$areanames{en}->{61348154} = "Kyabram";
$areanames{en}->{61348155} = "Lalalty";
$areanames{en}->{61348156} = "Logie\ Brae";
$areanames{en}->{61348157} = "Mabins\ Well";
$areanames{en}->{61348158} = "Mathoura";
$areanames{en}->{61348159} = "Moulamein";
$areanames{en}->{61348160} = "Berrigan";
$areanames{en}->{61348161} = "Blighty";
$areanames{en}->{61348162} = "Brassi";
$areanames{en}->{61348163} = "Caldwell";
$areanames{en}->{61348164} = "Cobram";
$areanames{en}->{61348165} = "Conargo";
$areanames{en}->{61348166} = "Cornalla";
$areanames{en}->{61348167} = "Deniliquin";
$areanames{en}->{61348168} = "Dookie";
$areanames{en}->{61348169} = "Finley";
$areanames{en}->{61348170} = "Jerilderie";
$areanames{en}->{61348171} = "Jimaringle";
$areanames{en}->{61348172} = "Katamatite";
$areanames{en}->{61348173} = "Katandra\ West";
$areanames{en}->{61348174} = "Kialla\ East";
$areanames{en}->{61348175} = "Kyabram";
$areanames{en}->{61348176} = "Lalalty";
$areanames{en}->{61348177} = "Logie\ Brae";
$areanames{en}->{61348178} = "Mabins\ Well";
$areanames{en}->{61348179} = "Mathoura";
$areanames{en}->{61348180} = "Moulamein";
$areanames{en}->{61348181} = "Nathalia";
$areanames{en}->{61348182} = "Numurkah";
$areanames{en}->{61348183} = "Picola";
$areanames{en}->{61348184} = "Rushworth";
$areanames{en}->{61348185} = "Shepparton";
$areanames{en}->{61348186} = "Tatura";
$areanames{en}->{61348187} = "Tocumwal";
$areanames{en}->{61348188} = "Tongala";
$areanames{en}->{61348189} = "Undera";
$areanames{en}->{61348190} = "Wakool";
$areanames{en}->{61348191} = "Wanganella";
$areanames{en}->{61348192} = "Yalca";
$areanames{en}->{61348193} = "Wakool";
$areanames{en}->{61348194} = "Wakool";
$areanames{en}->{61348195} = "Wakool";
$areanames{en}->{61348196} = "Shepparton";
$areanames{en}->{61348197} = "Shepparton";
$areanames{en}->{61348198} = "Shepparton";
$areanames{en}->{61348199} = "Nathalia";
$areanames{en}->{61348200} = "Numurkah";
$areanames{en}->{61348201} = "Picola";
$areanames{en}->{61348202} = "Rushworth";
$areanames{en}->{61348203} = "Shepparton";
$areanames{en}->{61348204} = "Tatura";
$areanames{en}->{61348205} = "Tocumwal";
$areanames{en}->{61348206} = "Tongala";
$areanames{en}->{61348207} = "Undera";
$areanames{en}->{61348208} = "Wakool";
$areanames{en}->{61348209} = "Wanganella";
$areanames{en}->{61348210} = "Yalca";
$areanames{en}->{61348211} = "Berrigan";
$areanames{en}->{61348212} = "Blighty";
$areanames{en}->{61348213} = "Brassi";
$areanames{en}->{61348214} = "Caldwell";
$areanames{en}->{61348215} = "Cobram";
$areanames{en}->{61348216} = "Conargo";
$areanames{en}->{61348217} = "Cornalla";
$areanames{en}->{61348218} = "Deniliquin";
$areanames{en}->{61348219} = "Dookie";
$areanames{en}->{61348220} = "Finley";
$areanames{en}->{61348221} = "Jerilderie";
$areanames{en}->{61348222} = "Jimaringle";
$areanames{en}->{61348223} = "Katamatite";
$areanames{en}->{61348224} = "Katandra\ West";
$areanames{en}->{61348225} = "Kialla\ East";
$areanames{en}->{61348226} = "Kyabram";
$areanames{en}->{61348227} = "Lalalty";
$areanames{en}->{61348228} = "Logie\ Brae";
$areanames{en}->{61348229} = "Mabins\ Well";
$areanames{en}->{61348230} = "Mathoura";
$areanames{en}->{61348231} = "Moulamein";
$areanames{en}->{61348232} = "Nathalia";
$areanames{en}->{61348233} = "Numurkah";
$areanames{en}->{61348234} = "Picola";
$areanames{en}->{61348235} = "Rushworth";
$areanames{en}->{61348236} = "Shepparton";
$areanames{en}->{61348237} = "Tatura";
$areanames{en}->{61348238} = "Tocumwal";
$areanames{en}->{61348239} = "Tongala";
$areanames{en}->{61348240} = "Undera";
$areanames{en}->{61348241} = "Wakool";
$areanames{en}->{61348242} = "Wanganella";
$areanames{en}->{61348243} = "Yalca";
$areanames{en}->{61348244} = "Berrigan";
$areanames{en}->{61348245} = "Blighty";
$areanames{en}->{61348246} = "Brassi";
$areanames{en}->{61348247} = "Caldwell";
$areanames{en}->{61348248} = "Cobram";
$areanames{en}->{61348249} = "Conargo";
$areanames{en}->{61348250} = "Cornalla";
$areanames{en}->{61348251} = "Deniliquin";
$areanames{en}->{61348252} = "Dookie";
$areanames{en}->{61348253} = "Finley";
$areanames{en}->{61348254} = "Jerilderie";
$areanames{en}->{61348255} = "Jimaringle";
$areanames{en}->{61348256} = "Katamatite";
$areanames{en}->{61348257} = "Katandra\ West";
$areanames{en}->{61348258} = "Kialla\ East";
$areanames{en}->{61348259} = "Kyabram";
$areanames{en}->{61348260} = "Lalalty";
$areanames{en}->{61348261} = "Logie\ Brae";
$areanames{en}->{61348262} = "Mabins\ Well";
$areanames{en}->{61348263} = "Mathoura";
$areanames{en}->{61348264} = "Moulamein";
$areanames{en}->{61348265} = "Nathalia";
$areanames{en}->{61348266} = "Numurkah";
$areanames{en}->{61348267} = "Picola";
$areanames{en}->{61348268} = "Rushworth";
$areanames{en}->{61348269} = "Shepparton";
$areanames{en}->{61348270} = "Tatura";
$areanames{en}->{61348271} = "Tocumwal";
$areanames{en}->{61348272} = "Tongala";
$areanames{en}->{61348273} = "Undera";
$areanames{en}->{61348274} = "Wakool";
$areanames{en}->{61348275} = "Wanganella";
$areanames{en}->{61348276} = "Yalca";
$areanames{en}->{61348277} = "Berrigan";
$areanames{en}->{61348278} = "Blighty";
$areanames{en}->{61348279} = "Brassi";
$areanames{en}->{61348280} = "Caldwell";
$areanames{en}->{61348281} = "Cobram";
$areanames{en}->{61348282} = "Conargo";
$areanames{en}->{61348283} = "Cornalla";
$areanames{en}->{61348284} = "Deniliquin";
$areanames{en}->{61348285} = "Dookie";
$areanames{en}->{61348286} = "Finley";
$areanames{en}->{61348287} = "Jerilderie";
$areanames{en}->{61348288} = "Jimaringle";
$areanames{en}->{61348289} = "Katamatite";
$areanames{en}->{61348290} = "Katandra\ West";
$areanames{en}->{61348291} = "Kialla\ East";
$areanames{en}->{61348292} = "Kyabram";
$areanames{en}->{61348293} = "Lalalty";
$areanames{en}->{61348294} = "Logie\ Brae";
$areanames{en}->{61348295} = "Mabins\ Well";
$areanames{en}->{61348296} = "Mathoura";
$areanames{en}->{61348297} = "Moulamein";
$areanames{en}->{61348298} = "Nathalia";
$areanames{en}->{61348299} = "Numurkah";
$areanames{en}->{61348300} = "Picola";
$areanames{en}->{61348301} = "Rushworth";
$areanames{en}->{61348302} = "Shepparton";
$areanames{en}->{61348303} = "Tatura";
$areanames{en}->{61348304} = "Tocumwal";
$areanames{en}->{61348305} = "Tongala";
$areanames{en}->{61348306} = "Undera";
$areanames{en}->{61348307} = "Wakool";
$areanames{en}->{61348308} = "Wanganella";
$areanames{en}->{61348309} = "Yalca";
$areanames{en}->{6135000} = "Mildura";
$areanames{en}->{61350010} = "Mildura";
$areanames{en}->{61350011} = "Balranald";
$areanames{en}->{61350012} = "Box\ Creek";
$areanames{en}->{61350013} = "Curyo";
$areanames{en}->{61350014} = "Hopetoun";
$areanames{en}->{61350015} = "Nyah";
$areanames{en}->{61350016} = "Swan\ Hill";
$areanames{en}->{61350017} = "Werrimull";
$areanames{en}->{61350018} = "Balranald";
$areanames{en}->{61350019} = "Box\ Creek";
$areanames{en}->{61350020} = "Mildura";
$areanames{en}->{61350021} = "Mildura";
$areanames{en}->{61350022} = "Patchewollock";
$areanames{en}->{61350023} = "Turriff";
$areanames{en}->{61350024} = "Woomelang";
$areanames{en}->{61350025} = "Wentworth";
$areanames{en}->{61350026} = "Werrimull";
$areanames{en}->{61350027} = "Willandra\ Lakes";
$areanames{en}->{61350028} = "Karawinna";
$areanames{en}->{61350029} = "Mildura";
$areanames{en}->{61350030} = "Anabranch";
$areanames{en}->{61350031} = "Anabranch";
$areanames{en}->{61350032} = "Anabranch";
$areanames{en}->{61350033} = "Annuello";
$areanames{en}->{61350034} = "Annuello";
$areanames{en}->{61350035} = "Annuello";
$areanames{en}->{61350036} = "Arumpo";
$areanames{en}->{61350037} = "Arumpo";
$areanames{en}->{61350038} = "Arumpo";
$areanames{en}->{61350039} = "Nangiloc";
$areanames{en}->{61350040} = "Balranald";
$areanames{en}->{61350041} = "Balranald";
$areanames{en}->{61350042} = "Balranald";
$areanames{en}->{61350043} = "Berriwillock";
$areanames{en}->{61350044} = "Berriwillock";
$areanames{en}->{61350045} = "Berriwillock";
$areanames{en}->{61350046} = "Boundary\ Bend";
$areanames{en}->{61350047} = "Boundary\ Bend";
$areanames{en}->{61350048} = "Boundary\ Bend";
$areanames{en}->{61350049} = "Palinyewah";
$areanames{en}->{61350050} = "Box\ Creek";
$areanames{en}->{61350051} = "Box\ Creek";
$areanames{en}->{61350052} = "Box\ Creek";
$areanames{en}->{61350053} = "Cowangie";
$areanames{en}->{61350054} = "Cowangie";
$areanames{en}->{61350055} = "Cowangie";
$areanames{en}->{61350056} = "Culgoa";
$areanames{en}->{61350057} = "Culgoa";
$areanames{en}->{61350058} = "Culgoa";
$areanames{en}->{61350059} = "Pan\ Ban";
$areanames{en}->{61350060} = "Cunninyeuk";
$areanames{en}->{61350061} = "Cunninyeuk";
$areanames{en}->{61350062} = "Cunninyeuk";
$areanames{en}->{61350063} = "Curyo";
$areanames{en}->{61350064} = "Curyo";
$areanames{en}->{61350065} = "Curyo";
$areanames{en}->{61350066} = "Hopetoun";
$areanames{en}->{61350067} = "Hopetoun";
$areanames{en}->{61350068} = "Hopetoun";
$areanames{en}->{61350069} = "Pooncarie";
$areanames{en}->{61350070} = "Karawinna";
$areanames{en}->{61350071} = "Karawinna";
$areanames{en}->{61350072} = "Karawinna";
$areanames{en}->{61350073} = "Kyalite";
$areanames{en}->{61350074} = "Kyalite";
$areanames{en}->{61350075} = "Kyalite";
$areanames{en}->{61350076} = "Mallan";
$areanames{en}->{61350077} = "Mallan";
$areanames{en}->{61350078} = "Mallan";
$areanames{en}->{61350079} = "Robinvale";
$areanames{en}->{61350080} = "Manangatang";
$areanames{en}->{61350081} = "Manangatang";
$areanames{en}->{61350082} = "Manangatang";
$areanames{en}->{61350083} = "Mildura";
$areanames{en}->{61350084} = "Mildura";
$areanames{en}->{61350085} = "Mildura";
$areanames{en}->{61350086} = "Mittyack";
$areanames{en}->{61350087} = "Mittyack";
$areanames{en}->{61350088} = "Mittyack";
$areanames{en}->{61350089} = "Rufus\ River";
$areanames{en}->{61350090} = "Murrayville";
$areanames{en}->{61350091} = "Murrayville";
$areanames{en}->{61350092} = "Murrayville";
$areanames{en}->{61350093} = "Nandaly";
$areanames{en}->{61350094} = "Nandaly";
$areanames{en}->{61350095} = "Nandaly";
$areanames{en}->{61350096} = "Nangiloc";
$areanames{en}->{61350097} = "Nangiloc";
$areanames{en}->{61350098} = "Nangiloc";
$areanames{en}->{61350099} = "Scotia";
$areanames{en}->{61350100} = "Natya";
$areanames{en}->{61350101} = "Natya";
$areanames{en}->{61350102} = "Natya";
$areanames{en}->{61350103} = "Nyah";
$areanames{en}->{61350104} = "Nyah";
$areanames{en}->{61350105} = "Nyah";
$areanames{en}->{61350106} = "Ouyen";
$areanames{en}->{61350107} = "Ouyen";
$areanames{en}->{61350108} = "Ouyen";
$areanames{en}->{61350109} = "Wemen";
$areanames{en}->{61350110} = "Palinyewah";
$areanames{en}->{61350111} = "Palinyewah";
$areanames{en}->{61350112} = "Palinyewah";
$areanames{en}->{61350113} = "Pan\ Ban";
$areanames{en}->{61350114} = "Pan\ Ban";
$areanames{en}->{61350115} = "Pan\ Ban";
$areanames{en}->{61350116} = "Patchewollock";
$areanames{en}->{61350117} = "Patchewollock";
$areanames{en}->{61350118} = "Patchewollock";
$areanames{en}->{61350119} = "Anabranch";
$areanames{en}->{61350120} = "Pooncarie";
$areanames{en}->{61350121} = "Pooncarie";
$areanames{en}->{61350122} = "Pooncarie";
$areanames{en}->{61350123} = "Robinvale";
$areanames{en}->{61350124} = "Robinvale";
$areanames{en}->{61350125} = "Robinvale";
$areanames{en}->{61350126} = "Rufus\ River";
$areanames{en}->{61350127} = "Rufus\ River";
$areanames{en}->{61350128} = "Rufus\ River";
$areanames{en}->{61350129} = "Arumpo";
$areanames{en}->{61350130} = "Scotia";
$areanames{en}->{61350131} = "Scotia";
$areanames{en}->{61350132} = "Scotia";
$areanames{en}->{61350133} = "Sea\ Lake";
$areanames{en}->{61350134} = "Sea\ Lake";
$areanames{en}->{61350135} = "Sea\ Lake";
$areanames{en}->{61350136} = "Swan\ Hill";
$areanames{en}->{61350137} = "Swan\ Hill";
$areanames{en}->{61350138} = "Swan\ Hill";
$areanames{en}->{61350139} = "Boundary\ Bend";
$areanames{en}->{61350140} = "Tempy";
$areanames{en}->{61350141} = "Tempy";
$areanames{en}->{61350142} = "Tempy";
$areanames{en}->{61350143} = "Turriff";
$areanames{en}->{61350144} = "Turriff";
$areanames{en}->{61350145} = "Turriff";
$areanames{en}->{61350146} = "Ultima";
$areanames{en}->{61350147} = "Ultima";
$areanames{en}->{61350148} = "Ultima";
$areanames{en}->{61350149} = "Cowangie";
$areanames{en}->{61350150} = "Underbool";
$areanames{en}->{61350151} = "Underbool";
$areanames{en}->{61350152} = "Underbool";
$areanames{en}->{61350153} = "Waitchie";
$areanames{en}->{61350154} = "Waitchie";
$areanames{en}->{61350155} = "Waitchie";
$areanames{en}->{61350156} = "Wemen";
$areanames{en}->{61350157} = "Wemen";
$areanames{en}->{61350158} = "Wemen";
$areanames{en}->{61350159} = "Mittyack";
$areanames{en}->{61350160} = "Wentworth";
$areanames{en}->{61350161} = "Wentworth";
$areanames{en}->{61350162} = "Wentworth";
$areanames{en}->{61350163} = "Werrimull";
$areanames{en}->{61350164} = "Werrimull";
$areanames{en}->{61350165} = "Werrimull";
$areanames{en}->{61350166} = "Willandra\ Lakes";
$areanames{en}->{61350167} = "Willandra\ Lakes";
$areanames{en}->{61350168} = "Willandra\ Lakes";
$areanames{en}->{61350169} = "Murrayville";
$areanames{en}->{61350170} = "Woomelang";
$areanames{en}->{61350171} = "Woomelang";
$areanames{en}->{61350172} = "Woomelang";
$areanames{en}->{61350173} = "Ouyen";
$areanames{en}->{61350174} = "Tempy";
$areanames{en}->{61350175} = "Underbool";
$areanames{en}->{61350176} = "Swan\ Hill";
$areanames{en}->{61350177} = "Ultima";
$areanames{en}->{61350178} = "Waitchie";
$areanames{en}->{61350179} = "Berriwillock";
$areanames{en}->{6135018} = "Mildura";
$areanames{en}->{61350190} = "Culgoa";
$areanames{en}->{61350191} = "Cunninyeuk";
$areanames{en}->{61350192} = "Kyalite";
$areanames{en}->{61350193} = "Mallan";
$areanames{en}->{61350194} = "Manangatang";
$areanames{en}->{61350195} = "Nandaly";
$areanames{en}->{61350196} = "Natya";
$areanames{en}->{61350197} = "Nyah";
$areanames{en}->{61350198} = "Wentworth";
$areanames{en}->{61350199} = "Sea\ Lake";
$areanames{en}->{6135020} = "Balranald";
$areanames{en}->{61350204} = "Box\ Creek";
$areanames{en}->{61350205} = "Curyo";
$areanames{en}->{61350206} = "Box\ Creek";
$areanames{en}->{6135021} = "Mildura";
$areanames{en}->{6135022} = "Mildura";
$areanames{en}->{61350226} = "Wentworth";
$areanames{en}->{6135023} = "Mildura";
$areanames{en}->{6135024} = "Mildura";
$areanames{en}->{6135025} = "Mildura";
$areanames{en}->{6135026} = "Robinvale";
$areanames{en}->{61350260} = "Wemen";
$areanames{en}->{61350267} = "Boundary\ Bend";
$areanames{en}->{61350268} = "Boundary\ Bend";
$areanames{en}->{6135027} = "Wentworth";
$areanames{en}->{61350270} = "Anabranch";
$areanames{en}->{61350271} = "Scotia";
$areanames{en}->{61350278} = "Rufus\ River";
$areanames{en}->{61350279} = "Palinyewah";
$areanames{en}->{61350280} = "Werrimull";
$areanames{en}->{61350281} = "Werrimull";
$areanames{en}->{61350282} = "Werrimull";
$areanames{en}->{61350283} = "Werrimull";
$areanames{en}->{61350284} = "Karawinna";
$areanames{en}->{61350285} = "Karawinna";
$areanames{en}->{61350286} = "Hopetoun";
$areanames{en}->{61350287} = "Patchewollock";
$areanames{en}->{61350288} = "Turriff";
$areanames{en}->{61350289} = "Woomelang";
$areanames{en}->{61350290} = "Anabranch";
$areanames{en}->{61350291} = "Nangiloc";
$areanames{en}->{61350292} = "Nangiloc";
$areanames{en}->{61350293} = "Nangiloc";
$areanames{en}->{61350294} = "Nangiloc";
$areanames{en}->{61350295} = "Pooncarie";
$areanames{en}->{61350296} = "Pan\ Ban";
$areanames{en}->{61350297} = "Arumpo";
$areanames{en}->{61350298} = "Arumpo";
$areanames{en}->{61350299} = "Arumpo";
$areanames{en}->{6135030} = "Nyah";
$areanames{en}->{61350300} = "Boundary\ Bend";
$areanames{en}->{61350307} = "Karawinna";
$areanames{en}->{61350308} = "Mildura";
$areanames{en}->{61350309} = "Nangiloc";
$areanames{en}->{61350310} = "Palinyewah";
$areanames{en}->{61350311} = "Annuello";
$areanames{en}->{61350312} = "Annuello";
$areanames{en}->{61350313} = "Pan\ Ban";
$areanames{en}->{61350314} = "Pooncarie";
$areanames{en}->{61350315} = "Robinvale";
$areanames{en}->{61350316} = "Rufus\ River";
$areanames{en}->{61350317} = "Scotia";
$areanames{en}->{61350318} = "Wemen";
$areanames{en}->{61350319} = "Wentworth";
$areanames{en}->{6135032} = "Swan\ Hill";
$areanames{en}->{6135033} = "Swan\ Hill";
$areanames{en}->{61350340} = "Mallan";
$areanames{en}->{61350341} = "Mallan";
$areanames{en}->{61350342} = "Cunninyeuk";
$areanames{en}->{61350343} = "Cunninyeuk";
$areanames{en}->{61350344} = "Cunninyeuk";
$areanames{en}->{61350345} = "Cunninyeuk";
$areanames{en}->{61350346} = "Mallan";
$areanames{en}->{61350347} = "Mallan";
$areanames{en}->{61350348} = "Werrimull";
$areanames{en}->{61350349} = "Willandra\ Lakes";
$areanames{en}->{61350350} = "Cowangie";
$areanames{en}->{61350351} = "Manangatang";
$areanames{en}->{61350352} = "Manangatang";
$areanames{en}->{61350353} = "Manangatang";
$areanames{en}->{61350354} = "Manangatang";
$areanames{en}->{61350355} = "Mittyack";
$areanames{en}->{61350356} = "Murrayville";
$areanames{en}->{61350357} = "Ouyen";
$areanames{en}->{61350358} = "Tempy";
$areanames{en}->{61350359} = "Underbool";
$areanames{en}->{6135036} = "Swan\ Hill";
$areanames{en}->{61350370} = "Annuello";
$areanames{en}->{61350371} = "Swan\ Hill";
$areanames{en}->{61350372} = "Swan\ Hill";
$areanames{en}->{61350373} = "Swan\ Hill";
$areanames{en}->{61350374} = "Berriwillock";
$areanames{en}->{61350375} = "Culgoa";
$areanames{en}->{61350376} = "Swan\ Hill";
$areanames{en}->{61350377} = "Swan\ Hill";
$areanames{en}->{61350378} = "Cunninyeuk";
$areanames{en}->{61350379} = "Kyalite";
$areanames{en}->{61350380} = "Mallan";
$areanames{en}->{61350381} = "Kyalite";
$areanames{en}->{61350382} = "Kyalite";
$areanames{en}->{61350383} = "Manangatang";
$areanames{en}->{61350384} = "Nandaly";
$areanames{en}->{61350385} = "Natya";
$areanames{en}->{61350386} = "Nyah";
$areanames{en}->{61350387} = "Sea\ Lake";
$areanames{en}->{61350388} = "Natya";
$areanames{en}->{61350389} = "Natya";
$areanames{en}->{61350390} = "Swan\ Hill";
$areanames{en}->{61350391} = "Waitchie";
$areanames{en}->{61350392} = "Waitchie";
$areanames{en}->{61350393} = "Ultima";
$areanames{en}->{61350394} = "Waitchie";
$areanames{en}->{61350395} = "Mildura";
$areanames{en}->{61350396} = "Ultima";
$areanames{en}->{61350397} = "Ultima";
$areanames{en}->{61350398} = "Ultima";
$areanames{en}->{61350399} = "Ultima";
$areanames{en}->{61350400} = "Annuello";
$areanames{en}->{61350401} = "Curyo";
$areanames{en}->{61350402} = "Hopetoun";
$areanames{en}->{61350403} = "Patchewollock";
$areanames{en}->{61350404} = "Turriff";
$areanames{en}->{61350405} = "Woomelang";
$areanames{en}->{61350406} = "Anabranch";
$areanames{en}->{61350407} = "Arumpo";
$areanames{en}->{61350408} = "Boundary\ Bend";
$areanames{en}->{61350409} = "Karawinna";
$areanames{en}->{61350410} = "Mildura";
$areanames{en}->{61350411} = "Nangiloc";
$areanames{en}->{61350412} = "Palinyewah";
$areanames{en}->{61350413} = "Pan\ Ban";
$areanames{en}->{61350414} = "Pooncarie";
$areanames{en}->{61350415} = "Robinvale";
$areanames{en}->{61350416} = "Rufus\ River";
$areanames{en}->{61350417} = "Scotia";
$areanames{en}->{61350418} = "Wemen";
$areanames{en}->{61350419} = "Wentworth";
$areanames{en}->{61350420} = "Werrimull";
$areanames{en}->{61350421} = "Willandra\ Lakes";
$areanames{en}->{61350422} = "Cowangie";
$areanames{en}->{61350423} = "Mittyack";
$areanames{en}->{61350424} = "Murrayville";
$areanames{en}->{61350425} = "Ouyen";
$areanames{en}->{61350426} = "Tempy";
$areanames{en}->{61350427} = "Underbool";
$areanames{en}->{61350428} = "Annuello";
$areanames{en}->{61350429} = "Berriwillock";
$areanames{en}->{61350430} = "Culgoa";
$areanames{en}->{61350431} = "Cunninyeuk";
$areanames{en}->{61350432} = "Kyalite";
$areanames{en}->{61350433} = "Mallan";
$areanames{en}->{61350434} = "Manangatang";
$areanames{en}->{61350435} = "Nandaly";
$areanames{en}->{61350436} = "Natya";
$areanames{en}->{61350437} = "Nyah";
$areanames{en}->{61350438} = "Sea\ Lake";
$areanames{en}->{61350439} = "Swan\ Hill";
$areanames{en}->{61350440} = "Ultima";
$areanames{en}->{61350441} = "Waitchie";
$areanames{en}->{61350442} = "Balranald";
$areanames{en}->{61350443} = "Box\ Creek";
$areanames{en}->{61350444} = "Curyo";
$areanames{en}->{61350445} = "Hopetoun";
$areanames{en}->{61350446} = "Patchewollock";
$areanames{en}->{61350447} = "Turriff";
$areanames{en}->{61350448} = "Woomelang";
$areanames{en}->{61350449} = "Anabranch";
$areanames{en}->{61350450} = "Arumpo";
$areanames{en}->{61350451} = "Boundary\ Bend";
$areanames{en}->{61350452} = "Karawinna";
$areanames{en}->{61350453} = "Mildura";
$areanames{en}->{61350454} = "Nangiloc";
$areanames{en}->{61350455} = "Palinyewah";
$areanames{en}->{61350456} = "Pan\ Ban";
$areanames{en}->{61350457} = "Pooncarie";
$areanames{en}->{61350458} = "Robinvale";
$areanames{en}->{61350459} = "Rufus\ River";
$areanames{en}->{61350460} = "Scotia";
$areanames{en}->{61350461} = "Wemen";
$areanames{en}->{61350462} = "Wentworth";
$areanames{en}->{61350463} = "Werrimull";
$areanames{en}->{61350464} = "Willandra\ Lakes";
$areanames{en}->{61350465} = "Cowangie";
$areanames{en}->{61350466} = "Mittyack";
$areanames{en}->{61350467} = "Murrayville";
$areanames{en}->{61350468} = "Ouyen";
$areanames{en}->{61350469} = "Tempy";
$areanames{en}->{61350470} = "Underbool";
$areanames{en}->{61350471} = "Annuello";
$areanames{en}->{61350472} = "Berriwillock";
$areanames{en}->{61350473} = "Culgoa";
$areanames{en}->{61350474} = "Cunninyeuk";
$areanames{en}->{61350475} = "Kyalite";
$areanames{en}->{61350476} = "Mallan";
$areanames{en}->{61350477} = "Manangatang";
$areanames{en}->{61350478} = "Nandaly";
$areanames{en}->{61350479} = "Natya";
$areanames{en}->{61350480} = "Nyah";
$areanames{en}->{61350481} = "Sea\ Lake";
$areanames{en}->{61350482} = "Swan\ Hill";
$areanames{en}->{61350483} = "Ultima";
$areanames{en}->{61350484} = "Waitchie";
$areanames{en}->{61350485} = "Mildura";
$areanames{en}->{61350486} = "Swan\ Hill";
$areanames{en}->{61350487} = "Mildura";
$areanames{en}->{61350488} = "Balranald";
$areanames{en}->{61350489} = "Box\ Creek";
$areanames{en}->{61350490} = "Curyo";
$areanames{en}->{61350491} = "Hopetoun";
$areanames{en}->{61350492} = "Patchewollock";
$areanames{en}->{61350493} = "Turriff";
$areanames{en}->{61350494} = "Woomelang";
$areanames{en}->{61350495} = "Anabranch";
$areanames{en}->{61350496} = "Arumpo";
$areanames{en}->{61350497} = "Boundary\ Bend";
$areanames{en}->{61350498} = "Karawinna";
$areanames{en}->{61350499} = "Nangiloc";
$areanames{en}->{6135051} = "Mildura";
$areanames{en}->{61350518} = "Robinvale";
$areanames{en}->{61350520} = "Wemen";
$areanames{en}->{61350521} = "Scotia";
$areanames{en}->{61350522} = "Wentworth";
$areanames{en}->{61350523} = "Rufus\ River";
$areanames{en}->{61350524} = "Palinyewah";
$areanames{en}->{61350525} = "Anabranch";
$areanames{en}->{61350526} = "Swan\ Hill";
$areanames{en}->{61350527} = "Swan\ Hill";
$areanames{en}->{61350528} = "Curyo";
$areanames{en}->{61350529} = "Curyo";
$areanames{en}->{61350530} = "Hopetoun";
$areanames{en}->{61350531} = "Hopetoun";
$areanames{en}->{61350532} = "Turriff";
$areanames{en}->{61350533} = "Turriff";
$areanames{en}->{61350534} = "Woomelang";
$areanames{en}->{61350535} = "Woomelang";
$areanames{en}->{61350536} = "Kyalite";
$areanames{en}->{61350537} = "Kyalite";
$areanames{en}->{61350538} = "Boundary\ Bend";
$areanames{en}->{61350539} = "Boundary\ Bend";
$areanames{en}->{61350540} = "Mildura";
$areanames{en}->{61350541} = "Mildura";
$areanames{en}->{61350542} = "Nangiloc";
$areanames{en}->{61350543} = "Nangiloc";
$areanames{en}->{61350544} = "Robinvale";
$areanames{en}->{61350545} = "Robinvale";
$areanames{en}->{61350546} = "Wemen";
$areanames{en}->{61350547} = "Wemen";
$areanames{en}->{61350548} = "Mittyack";
$areanames{en}->{61350549} = "Mittyack";
$areanames{en}->{6135055} = "Mildura";
$areanames{en}->{61350560} = "Underbool";
$areanames{en}->{61350561} = "Underbool";
$areanames{en}->{61350562} = "Mallan";
$areanames{en}->{61350563} = "Mallan";
$areanames{en}->{61350600} = "Mildura";
$areanames{en}->{61350601} = "Mildura";
$areanames{en}->{61350602} = "Willandra\ Lakes";
$areanames{en}->{61350603} = "Willandra\ Lakes";
$areanames{en}->{61350604} = "Willandra\ Lakes";
$areanames{en}->{61350605} = "Manangatang";
$areanames{en}->{61350606} = "Manangatang";
$areanames{en}->{61350607} = "Manangatang";
$areanames{en}->{61350608} = "Mildura";
$areanames{en}->{61350609} = "Mildura";
$areanames{en}->{61350610} = "Palinyewah";
$areanames{en}->{61350611} = "Pan\ Ban";
$areanames{en}->{61350612} = "Pooncarie";
$areanames{en}->{61350613} = "Robinvale";
$areanames{en}->{61350614} = "Rufus\ River";
$areanames{en}->{61350615} = "Scotia";
$areanames{en}->{61350616} = "Wemen";
$areanames{en}->{61350617} = "Wentworth";
$areanames{en}->{61350618} = "Willandra\ Lakes";
$areanames{en}->{61350619} = "Cowangie";
$areanames{en}->{61350620} = "Mittyack";
$areanames{en}->{61350621} = "Murrayville";
$areanames{en}->{61350622} = "Ouyen";
$areanames{en}->{61350623} = "Tempy";
$areanames{en}->{61350624} = "Underbool";
$areanames{en}->{61350625} = "Annuello";
$areanames{en}->{61350626} = "Berriwillock";
$areanames{en}->{61350627} = "Culgoa";
$areanames{en}->{61350628} = "Cunninyeuk";
$areanames{en}->{61350629} = "Kyalite";
$areanames{en}->{61350630} = "Mallan";
$areanames{en}->{61350631} = "Manangatang";
$areanames{en}->{61350632} = "Nandaly";
$areanames{en}->{61350633} = "Natya";
$areanames{en}->{61350634} = "Sea\ Lake";
$areanames{en}->{61350635} = "Ultima";
$areanames{en}->{61350636} = "Waitchie";
$areanames{en}->{61350637} = "Ultima";
$areanames{en}->{61350638} = "Ultima";
$areanames{en}->{61350639} = "Manangatang";
$areanames{en}->{61350640} = "Manangatang";
$areanames{en}->{61350641} = "Nandaly";
$areanames{en}->{61350642} = "Nandaly";
$areanames{en}->{61350643} = "Natya";
$areanames{en}->{61350644} = "Natya";
$areanames{en}->{61350645} = "Nyah";
$areanames{en}->{61350646} = "Nyah";
$areanames{en}->{61350647} = "Sea\ Lake";
$areanames{en}->{61350648} = "Sea\ Lake";
$areanames{en}->{61350650} = "Swan\ Hill";
$areanames{en}->{61350651} = "Ultima";
$areanames{en}->{61350652} = "Waitchie";
$areanames{en}->{61350653} = "Mildura";
$areanames{en}->{61350654} = "Swan\ Hill";
$areanames{en}->{61350655} = "Arumpo";
$areanames{en}->{61350656} = "Arumpo";
$areanames{en}->{61350657} = "Palinyewah";
$areanames{en}->{61350658} = "Palinyewah";
$areanames{en}->{61350659} = "Mildura";
$areanames{en}->{61350660} = "Berriwillock";
$areanames{en}->{61350661} = "Culgoa";
$areanames{en}->{61350662} = "Cunninyeuk";
$areanames{en}->{61350663} = "Kyalite";
$areanames{en}->{61350664} = "Mallan";
$areanames{en}->{61350665} = "Manangatang";
$areanames{en}->{61350666} = "Nandaly";
$areanames{en}->{61350667} = "Natya";
$areanames{en}->{61350668} = "Nyah";
$areanames{en}->{61350669} = "Sea\ Lake";
$areanames{en}->{61350670} = "Wentworth";
$areanames{en}->{61350671} = "Werrimull";
$areanames{en}->{61350672} = "Willandra\ Lakes";
$areanames{en}->{61350673} = "Cowangie";
$areanames{en}->{61350674} = "Mittyack";
$areanames{en}->{61350675} = "Murrayville";
$areanames{en}->{61350676} = "Ouyen";
$areanames{en}->{61350677} = "Tempy";
$areanames{en}->{61350678} = "Underbool";
$areanames{en}->{61350679} = "Annuello";
$areanames{en}->{61350680} = "Karawinna";
$areanames{en}->{61350681} = "Mildura";
$areanames{en}->{61350682} = "Nangiloc";
$areanames{en}->{61350683} = "Palinyewah";
$areanames{en}->{61350684} = "Pan\ Ban";
$areanames{en}->{61350685} = "Pooncarie";
$areanames{en}->{61350686} = "Robinvale";
$areanames{en}->{61350687} = "Rufus\ River";
$areanames{en}->{61350688} = "Scotia";
$areanames{en}->{61350689} = "Wemen";
$areanames{en}->{61350690} = "Balranald";
$areanames{en}->{61350691} = "Box\ Creek";
$areanames{en}->{61350692} = "Curyo";
$areanames{en}->{61350693} = "Hopetoun";
$areanames{en}->{61350694} = "Patchewollock";
$areanames{en}->{61350695} = "Turriff";
$areanames{en}->{61350696} = "Woomelang";
$areanames{en}->{61350697} = "Anabranch";
$areanames{en}->{61350698} = "Arumpo";
$areanames{en}->{61350699} = "Boundary\ Bend";
$areanames{en}->{61350700} = "Mildura";
$areanames{en}->{61350701} = "Sea\ Lake";
$areanames{en}->{61350702} = "Sea\ Lake";
$areanames{en}->{61350703} = "Sea\ Lake";
$areanames{en}->{61350704} = "Annuello";
$areanames{en}->{61350705} = "Annuello";
$areanames{en}->{61350706} = "Berriwillock";
$areanames{en}->{61350707} = "Berriwillock";
$areanames{en}->{61350708} = "Culgoa";
$areanames{en}->{61350709} = "Culgoa";
$areanames{en}->{61350710} = "Ouyen";
$areanames{en}->{61350711} = "Ouyen";
$areanames{en}->{61350712} = "Tempy";
$areanames{en}->{61350713} = "Tempy";
$areanames{en}->{61350714} = "Balranald";
$areanames{en}->{61350715} = "Balranald";
$areanames{en}->{61350716} = "Box\ Creek";
$areanames{en}->{61350717} = "Box\ Creek";
$areanames{en}->{61350718} = "Box\ Creek";
$areanames{en}->{61350719} = "Balranald";
$areanames{en}->{61350720} = "Mildura";
$areanames{en}->{61350721} = "Mildura";
$areanames{en}->{61350722} = "Mildura";
$areanames{en}->{61350723} = "Swan\ Hill";
$areanames{en}->{61350724} = "Swan\ Hill";
$areanames{en}->{61350725} = "Swan\ Hill";
$areanames{en}->{61350726} = "Woomelang";
$areanames{en}->{61350727} = "Waitchie";
$areanames{en}->{61350728} = "Waitchie";
$areanames{en}->{61350729} = "Box\ Creek";
$areanames{en}->{61350730} = "Swan\ Hill";
$areanames{en}->{61350731} = "Swan\ Hill";
$areanames{en}->{61350746} = "Willandra\ Lakes";
$areanames{en}->{61350747} = "Willandra\ Lakes";
$areanames{en}->{61350748} = "Willandra\ Lakes";
$areanames{en}->{61350749} = "Willandra\ Lakes";
$areanames{en}->{61350771} = "Culgoa";
$areanames{en}->{61350772} = "Culgoa";
$areanames{en}->{61350773} = "Mildura";
$areanames{en}->{61350774} = "Mildura";
$areanames{en}->{61350775} = "Mildura";
$areanames{en}->{61350781} = "Nandaly";
$areanames{en}->{61350782} = "Nandaly";
$areanames{en}->{61350791} = "Berriwillock";
$areanames{en}->{61350792} = "Berriwillock";
$areanames{en}->{61350812} = "Woomelang";
$areanames{en}->{61350813} = "Woomelang";
$areanames{en}->{61350815} = "Woomelang";
$areanames{en}->{61350816} = "Woomelang";
$areanames{en}->{61350823} = "Turriff";
$areanames{en}->{61350824} = "Turriff";
$areanames{en}->{61350832} = "Hopetoun";
$areanames{en}->{61350833} = "Hopetoun";
$areanames{en}->{61350834} = "Hopetoun";
$areanames{en}->{61350835} = "Hopetoun";
$areanames{en}->{61350836} = "Hopetoun";
$areanames{en}->{61350837} = "Hopetoun";
$areanames{en}->{61350838} = "Hopetoun";
$areanames{en}->{61350839} = "Mildura";
$areanames{en}->{61350840} = "Mildura";
$areanames{en}->{61350841} = "Patchewollock";
$areanames{en}->{61350842} = "Patchewollock";
$areanames{en}->{61350853} = "Curyo";
$areanames{en}->{61350854} = "Curyo";
$areanames{en}->{61350910} = "Ouyen";
$areanames{en}->{61350911} = "Ouyen";
$areanames{en}->{61350912} = "Ouyen";
$areanames{en}->{61350913} = "Ouyen";
$areanames{en}->{61350914} = "Ouyen";
$areanames{en}->{61350917} = "Underbool";
$areanames{en}->{61350921} = "Ouyen";
$areanames{en}->{61350922} = "Ouyen";
$areanames{en}->{61350923} = "Ouyen";
$areanames{en}->{61350931} = "Mittyack";
$areanames{en}->{61350932} = "Mittyack";
$areanames{en}->{61350933} = "Ultima";
$areanames{en}->{61350934} = "Ultima";
$areanames{en}->{61350935} = "Ultima";
$areanames{en}->{61350936} = "Tempy";
$areanames{en}->{61350937} = "Tempy";
$areanames{en}->{61350940} = "Underbool";
$areanames{en}->{61350941} = "Underbool";
$areanames{en}->{61350942} = "Underbool";
$areanames{en}->{61350945} = "Underbool";
$areanames{en}->{61350946} = "Underbool";
$areanames{en}->{61350951} = "Murrayville";
$areanames{en}->{61350952} = "Murrayville";
$areanames{en}->{61350956} = "Cowangie";
$areanames{en}->{61350957} = "Cowangie";
$areanames{en}->{61351000} = "Morwell";
$areanames{en}->{61351001} = "Morwell";
$areanames{en}->{61351002} = "Morwell";
$areanames{en}->{61351003} = "Morwell";
$areanames{en}->{61351004} = "Swifts\ Creek";
$areanames{en}->{61351005} = "Genoa";
$areanames{en}->{61351006} = "Goongerah";
$areanames{en}->{61351007} = "Lakes\ Entrance";
$areanames{en}->{61351008} = "Lindenow";
$areanames{en}->{61351009} = "Mallacoota";
$areanames{en}->{6135101} = "Morwell";
$areanames{en}->{61351020} = "Bairnsdale";
$areanames{en}->{61351021} = "Bairnsdale";
$areanames{en}->{61351022} = "Bairnsdale";
$areanames{en}->{61351023} = "Baw\ Baw";
$areanames{en}->{61351024} = "Baw\ Baw";
$areanames{en}->{61351025} = "Baw\ Baw";
$areanames{en}->{61351026} = "Bruthen";
$areanames{en}->{61351027} = "Bruthen";
$areanames{en}->{61351028} = "Bruthen";
$areanames{en}->{61351029} = "Meerlieu";
$areanames{en}->{61351030} = "Buchan";
$areanames{en}->{61351031} = "Buchan";
$areanames{en}->{61351032} = "Buchan";
$areanames{en}->{61351033} = "Cabbage\ Tree\ Creek";
$areanames{en}->{61351034} = "Cabbage\ Tree\ Creek";
$areanames{en}->{61351035} = "Cabbage\ Tree\ Creek";
$areanames{en}->{61351036} = "Cann\ River";
$areanames{en}->{61351037} = "Cann\ River";
$areanames{en}->{61351038} = "Cann\ River";
$areanames{en}->{61351039} = "Mount\ Taylor";
$areanames{en}->{61351040} = "Club\ Terrace";
$areanames{en}->{61351041} = "Club\ Terrace";
$areanames{en}->{61351042} = "Club\ Terrace";
$areanames{en}->{61351043} = "Clydebank";
$areanames{en}->{61351044} = "Clydebank";
$areanames{en}->{61351045} = "Clydebank";
$areanames{en}->{61351046} = "Combienbar";
$areanames{en}->{61351047} = "Combienbar";
$areanames{en}->{61351048} = "Combienbar";
$areanames{en}->{61351049} = "Nowa\ Nowa";
$areanames{en}->{61351050} = "Dargo";
$areanames{en}->{61351051} = "Dargo";
$areanames{en}->{61351052} = "Dargo";
$areanames{en}->{61351053} = "Dinner\ Plain";
$areanames{en}->{61351054} = "Dinner\ Plain";
$areanames{en}->{61351055} = "Dinner\ Plain";
$areanames{en}->{61351056} = "Ensay";
$areanames{en}->{61351057} = "Ensay";
$areanames{en}->{61351058} = "Ensay";
$areanames{en}->{61351059} = "Omeo";
$areanames{en}->{61351060} = "Erica";
$areanames{en}->{61351061} = "Erica";
$areanames{en}->{61351062} = "Erica";
$areanames{en}->{61351063} = "Gelantipy";
$areanames{en}->{61351064} = "Gelantipy";
$areanames{en}->{61351065} = "Gelantipy";
$areanames{en}->{61351066} = "Genoa";
$areanames{en}->{61351067} = "Genoa";
$areanames{en}->{61351068} = "Genoa";
$areanames{en}->{61351069} = "Orbost";
$areanames{en}->{61351070} = "Golden\ Beach";
$areanames{en}->{61351071} = "Golden\ Beach";
$areanames{en}->{61351072} = "Golden\ Beach";
$areanames{en}->{61351073} = "Goongerah";
$areanames{en}->{61351074} = "Goongerah";
$areanames{en}->{61351075} = "Goongerah";
$areanames{en}->{61351076} = "Gormandale";
$areanames{en}->{61351077} = "Gormandale";
$areanames{en}->{61351078} = "Gormandale";
$areanames{en}->{61351079} = "Bairnsdale";
$areanames{en}->{61351080} = "Heyfield";
$areanames{en}->{61351081} = "Heyfield";
$areanames{en}->{61351082} = "Heyfield";
$areanames{en}->{61351083} = "Lakes\ Entrance";
$areanames{en}->{61351084} = "Lakes\ Entrance";
$areanames{en}->{61351085} = "Lakes\ Entrance";
$areanames{en}->{61351086} = "Licola";
$areanames{en}->{61351087} = "Licola";
$areanames{en}->{61351088} = "Licola";
$areanames{en}->{61351089} = "Bruthen";
$areanames{en}->{61351090} = "Lindenow";
$areanames{en}->{61351091} = "Lindenow";
$areanames{en}->{61351092} = "Lindenow";
$areanames{en}->{61351093} = "Loch\ Sport";
$areanames{en}->{61351094} = "Loch\ Sport";
$areanames{en}->{61351095} = "Loch\ Sport";
$areanames{en}->{61351096} = "Maffra";
$areanames{en}->{61351097} = "Maffra";
$areanames{en}->{61351098} = "Maffra";
$areanames{en}->{61351099} = "Buchan";
$areanames{en}->{61351100} = "Mallacoota";
$areanames{en}->{61351101} = "Mallacoota";
$areanames{en}->{61351102} = "Mallacoota";
$areanames{en}->{61351103} = "Meerlieu";
$areanames{en}->{61351104} = "Meerlieu";
$areanames{en}->{61351105} = "Meerlieu";
$areanames{en}->{61351106} = "Morwell";
$areanames{en}->{61351107} = "Morwell";
$areanames{en}->{61351108} = "Morwell";
$areanames{en}->{61351109} = "Cabbage\ Tree\ Creek";
$areanames{en}->{61351110} = "Mount\ Taylor";
$areanames{en}->{61351111} = "Mount\ Taylor";
$areanames{en}->{61351112} = "Mount\ Taylor";
$areanames{en}->{61351113} = "Munro";
$areanames{en}->{61351114} = "Munro";
$areanames{en}->{61351115} = "Munro";
$areanames{en}->{61351116} = "Nowa\ Nowa";
$areanames{en}->{61351117} = "Nowa\ Nowa";
$areanames{en}->{61351118} = "Nowa\ Nowa";
$areanames{en}->{61351119} = "Cann\ River";
$areanames{en}->{61351120} = "Omeo";
$areanames{en}->{61351121} = "Omeo";
$areanames{en}->{61351122} = "Omeo";
$areanames{en}->{61351123} = "Orbost";
$areanames{en}->{61351124} = "Orbost";
$areanames{en}->{61351125} = "Orbost";
$areanames{en}->{61351126} = "Rosedale";
$areanames{en}->{61351127} = "Rosedale";
$areanames{en}->{61351128} = "Rosedale";
$areanames{en}->{61351129} = "Club\ Terrace";
$areanames{en}->{61351130} = "Sale";
$areanames{en}->{61351131} = "Sale";
$areanames{en}->{61351132} = "Sale";
$areanames{en}->{61351133} = "Seaspray";
$areanames{en}->{61351134} = "Seaspray";
$areanames{en}->{61351135} = "Seaspray";
$areanames{en}->{61351136} = "Swifts\ Creek";
$areanames{en}->{61351137} = "Swifts\ Creek";
$areanames{en}->{61351138} = "Swifts\ Creek";
$areanames{en}->{61351139} = "Combienbar";
$areanames{en}->{61351140} = "Traralgon";
$areanames{en}->{61351141} = "Traralgon";
$areanames{en}->{61351142} = "Traralgon";
$areanames{en}->{61351143} = "Woodside";
$areanames{en}->{61351144} = "Woodside";
$areanames{en}->{61351145} = "Woodside";
$areanames{en}->{61351146} = "Yarram";
$areanames{en}->{61351147} = "Yarram";
$areanames{en}->{61351148} = "Yarram";
$areanames{en}->{61351149} = "Dinner\ Plain";
$areanames{en}->{61351150} = "Yinnar";
$areanames{en}->{61351151} = "Yinnar";
$areanames{en}->{61351152} = "Yinnar";
$areanames{en}->{61351153} = "Ensay";
$areanames{en}->{61351154} = "Gelantipy";
$areanames{en}->{61351155} = "Baw\ Baw";
$areanames{en}->{61351156} = "Erica";
$areanames{en}->{61351157} = "Gormandale";
$areanames{en}->{61351158} = "Morwell";
$areanames{en}->{61351159} = "Rosedale";
$areanames{en}->{61351160} = "Traralgon";
$areanames{en}->{61351161} = "Bairnsdale";
$areanames{en}->{61351162} = "Orbost";
$areanames{en}->{61351163} = "Baw\ Baw";
$areanames{en}->{61351164} = "Erica";
$areanames{en}->{61351165} = "Morwell";
$areanames{en}->{61351166} = "Morwell";
$areanames{en}->{61351167} = "Traralgon";
$areanames{en}->{61351168} = "Maffra";
$areanames{en}->{61351169} = "Sale";
$areanames{en}->{61351170} = "Woodside";
$areanames{en}->{61351171} = "Yarram";
$areanames{en}->{61351172} = "Yinnar";
$areanames{en}->{61351173} = "Seaspray";
$areanames{en}->{61351174} = "Clydebank";
$areanames{en}->{61351175} = "Dargo";
$areanames{en}->{61351176} = "Golden\ Beach";
$areanames{en}->{61351177} = "Heyfield";
$areanames{en}->{61351178} = "Licola";
$areanames{en}->{61351179} = "Loch\ Sport";
$areanames{en}->{61351180} = "Maffra";
$areanames{en}->{61351181} = "Munro";
$areanames{en}->{61351182} = "Sale";
$areanames{en}->{61351183} = "Bairnsdale";
$areanames{en}->{61351184} = "Bruthen";
$areanames{en}->{61351185} = "Buchan";
$areanames{en}->{61351186} = "Cabbage\ Tree\ Creek";
$areanames{en}->{61351187} = "Cann\ River";
$areanames{en}->{61351188} = "Club\ Terrace";
$areanames{en}->{61351189} = "Combienbar";
$areanames{en}->{61351190} = "Dinner\ Plain";
$areanames{en}->{61351191} = "Ensay";
$areanames{en}->{61351192} = "Gelantipy";
$areanames{en}->{61351193} = "Genoa";
$areanames{en}->{61351194} = "Goongerah";
$areanames{en}->{61351195} = "Lakes\ Entrance";
$areanames{en}->{61351196} = "Lindenow";
$areanames{en}->{61351197} = "Mallacoota";
$areanames{en}->{61351198} = "Meerlieu";
$areanames{en}->{61351199} = "Mount\ Taylor";
$areanames{en}->{6135120} = "Morwell";
$areanames{en}->{61351207} = "Bairnsdale";
$areanames{en}->{61351208} = "Baw\ Baw";
$areanames{en}->{61351209} = "Bruthen";
$areanames{en}->{61351210} = "Nowa\ Nowa";
$areanames{en}->{61351211} = "Omeo";
$areanames{en}->{61351212} = "Orbost";
$areanames{en}->{61351213} = "Swifts\ Creek";
$areanames{en}->{61351214} = "Baw\ Baw";
$areanames{en}->{61351215} = "Erica";
$areanames{en}->{61351216} = "Gormandale";
$areanames{en}->{61351217} = "Morwell";
$areanames{en}->{61351218} = "Rosedale";
$areanames{en}->{61351219} = "Traralgon";
$areanames{en}->{6135122} = "Morwell";
$areanames{en}->{61351240} = "Buchan";
$areanames{en}->{61351241} = "Cabbage\ Tree\ Creek";
$areanames{en}->{61351242} = "Cann\ River";
$areanames{en}->{61351243} = "Club\ Terrace";
$areanames{en}->{61351244} = "Combienbar";
$areanames{en}->{61351245} = "Dinner\ Plain";
$areanames{en}->{61351246} = "Ensay";
$areanames{en}->{61351247} = "Gelantipy";
$areanames{en}->{61351248} = "Genoa";
$areanames{en}->{61351249} = "Goongerah";
$areanames{en}->{6135126} = "Morwell";
$areanames{en}->{6135127} = "Morwell";
$areanames{en}->{6135128} = "Morwell";
$areanames{en}->{61351290} = "Lakes\ Entrance";
$areanames{en}->{61351291} = "Lindenow";
$areanames{en}->{61351292} = "Mallacoota";
$areanames{en}->{61351293} = "Meerlieu";
$areanames{en}->{61351294} = "Mount\ Taylor";
$areanames{en}->{61351295} = "Nowa\ Nowa";
$areanames{en}->{61351296} = "Omeo";
$areanames{en}->{61351297} = "Orbost";
$areanames{en}->{61351298} = "Swifts\ Creek";
$areanames{en}->{61351299} = "Baw\ Baw";
$areanames{en}->{613513} = "Morwell";
$areanames{en}->{61351300} = "Erica";
$areanames{en}->{61351301} = "Gormandale";
$areanames{en}->{61351303} = "Rosedale";
$areanames{en}->{61351304} = "Traralgon";
$areanames{en}->{61351305} = "Woodside";
$areanames{en}->{61351306} = "Yarram";
$areanames{en}->{61351307} = "Yinnar";
$areanames{en}->{61351308} = "Clydebank";
$areanames{en}->{61351309} = "Dargo";
$areanames{en}->{61351370} = "Golden\ Beach";
$areanames{en}->{61351371} = "Heyfield";
$areanames{en}->{61351372} = "Licola";
$areanames{en}->{61351373} = "Loch\ Sport";
$areanames{en}->{61351374} = "Maffra";
$areanames{en}->{61351375} = "Munro";
$areanames{en}->{61351376} = "Sale";
$areanames{en}->{61351377} = "Seaspray";
$areanames{en}->{61351378} = "Bruthen";
$areanames{en}->{61351379} = "Buchan";
$areanames{en}->{61351380} = "Gormandale";
$areanames{en}->{61351381} = "Rosedale";
$areanames{en}->{61351382} = "Woodside";
$areanames{en}->{61351383} = "Yarram";
$areanames{en}->{61351384} = "Yinnar";
$areanames{en}->{61351385} = "Clydebank";
$areanames{en}->{61351386} = "Dargo";
$areanames{en}->{61351387} = "Golden\ Beach";
$areanames{en}->{61351388} = "Heyfield";
$areanames{en}->{61351389} = "Licola";
$areanames{en}->{6135139} = "Maffra";
$areanames{en}->{61351397} = "Heyfield";
$areanames{en}->{61351398} = "Licola";
$areanames{en}->{61351399} = "Loch\ Sport";
$areanames{en}->{61351400} = "Munro";
$areanames{en}->{61351401} = "Dargo";
$areanames{en}->{61351402} = "Dargo";
$areanames{en}->{61351403} = "Seaspray";
$areanames{en}->{61351404} = "Heyfield";
$areanames{en}->{61351405} = "Licola";
$areanames{en}->{61351406} = "Dargo";
$areanames{en}->{61351407} = "Munro";
$areanames{en}->{61351408} = "Sale";
$areanames{en}->{61351409} = "Seaspray";
$areanames{en}->{61351410} = "Bairnsdale";
$areanames{en}->{61351411} = "Maffra";
$areanames{en}->{61351412} = "Lakes\ Entrance";
$areanames{en}->{61351413} = "Maffra";
$areanames{en}->{61351414} = "Sale";
$areanames{en}->{61351415} = "Traralgon";
$areanames{en}->{61351416} = "Bairnsdale";
$areanames{en}->{61351417} = "Bairnsdale";
$areanames{en}->{61351418} = "Bairnsdale";
$areanames{en}->{61351419} = "Maffra";
$areanames{en}->{61351420} = "Sale";
$areanames{en}->{61351421} = "Sale";
$areanames{en}->{61351422} = "Sale";
$areanames{en}->{61351423} = "Sale";
$areanames{en}->{61351424} = "Sale";
$areanames{en}->{61351425} = "Golden\ Beach";
$areanames{en}->{61351426} = "Seaspray";
$areanames{en}->{61351427} = "Combienbar";
$areanames{en}->{61351428} = "Combienbar";
$areanames{en}->{61351429} = "Morwell";
$areanames{en}->{6135143} = "Sale";
$areanames{en}->{6135144} = "Sale";
$areanames{en}->{6135145} = "Maffra";
$areanames{en}->{61351450} = "Clydebank";
$areanames{en}->{61351458} = "Munro";
$areanames{en}->{61351460} = "Loch\ Sport";
$areanames{en}->{61351461} = "Loch\ Sport";
$areanames{en}->{61351462} = "Woodside";
$areanames{en}->{61351463} = "Golden\ Beach";
$areanames{en}->{61351464} = "Seaspray";
$areanames{en}->{61351465} = "Golden\ Beach";
$areanames{en}->{61351466} = "Sale";
$areanames{en}->{61351467} = "Sale";
$areanames{en}->{61351468} = "Seaspray";
$areanames{en}->{61351469} = "Loch\ Sport";
$areanames{en}->{6135147} = "Maffra";
$areanames{en}->{61351476} = "Dinner\ Plain";
$areanames{en}->{61351477} = "Dinner\ Plain";
$areanames{en}->{61351478} = "Genoa";
$areanames{en}->{61351479} = "Genoa";
$areanames{en}->{6135148} = "Heyfield";
$areanames{en}->{61351484} = "Yarram";
$areanames{en}->{61351485} = "Yinnar";
$areanames{en}->{61351487} = "Clydebank";
$areanames{en}->{61351488} = "Licola";
$areanames{en}->{6135149} = "Sale";
$areanames{en}->{61351498} = "Clydebank";
$areanames{en}->{6135150} = "Bairnsdale";
$areanames{en}->{61351505} = "Loch\ Sport";
$areanames{en}->{61351506} = "Maffra";
$areanames{en}->{61351508} = "Dinner\ Plain";
$areanames{en}->{61351509} = "Lakes\ Entrance";
$areanames{en}->{61351510} = "Dargo";
$areanames{en}->{61351511} = "Golden\ Beach";
$areanames{en}->{61351512} = "Heyfield";
$areanames{en}->{61351513} = "Licola";
$areanames{en}->{61351514} = "Loch\ Sport";
$areanames{en}->{61351515} = "Maffra";
$areanames{en}->{61351516} = "Munro";
$areanames{en}->{61351517} = "Sale";
$areanames{en}->{61351518} = "Seaspray";
$areanames{en}->{61351519} = "Dargo";
$areanames{en}->{6135152} = "Bairnsdale";
$areanames{en}->{6135153} = "Bairnsdale";
$areanames{en}->{61351534} = "Bruthen";
$areanames{en}->{61351535} = "Bruthen";
$areanames{en}->{6135154} = "Orbost";
$areanames{en}->{61351540} = "Goongerah";
$areanames{en}->{61351544} = "Cabbage\ Tree\ Creek";
$areanames{en}->{61351545} = "Cabbage\ Tree\ Creek";
$areanames{en}->{6135155} = "Lakes\ Entrance";
$areanames{en}->{61351550} = "Gelantipy";
$areanames{en}->{61351557} = "Nowa\ Nowa";
$areanames{en}->{61351559} = "Buchan";
$areanames{en}->{6135156} = "Bairnsdale";
$areanames{en}->{61351562} = "Lakes\ Entrance";
$areanames{en}->{61351563} = "Lakes\ Entrance";
$areanames{en}->{61351564} = "Lakes\ Entrance";
$areanames{en}->{61351565} = "Lakes\ Entrance";
$areanames{en}->{61351570} = "Ensay";
$areanames{en}->{61351571} = "Lindenow";
$areanames{en}->{61351572} = "Lindenow";
$areanames{en}->{61351573} = "Ensay";
$areanames{en}->{61351574} = "Ensay";
$areanames{en}->{61351575} = "Bruthen";
$areanames{en}->{61351576} = "Lindenow";
$areanames{en}->{61351577} = "Meerlieu";
$areanames{en}->{61351578} = "Meerlieu";
$areanames{en}->{61351579} = "Mount\ Taylor";
$areanames{en}->{61351580} = "Mallacoota";
$areanames{en}->{61351581} = "Cabbage\ Tree\ Creek";
$areanames{en}->{61351582} = "Cann\ River";
$areanames{en}->{61351583} = "Club\ Terrace";
$areanames{en}->{61351584} = "Club\ Terrace";
$areanames{en}->{61351585} = "Combienbar";
$areanames{en}->{61351586} = "Cann\ River";
$areanames{en}->{61351587} = "Cann\ River";
$areanames{en}->{61351588} = "Genoa";
$areanames{en}->{61351589} = "Traralgon";
$areanames{en}->{61351590} = "Omeo";
$areanames{en}->{61351591} = "Omeo";
$areanames{en}->{61351592} = "Cann\ River";
$areanames{en}->{61351593} = "Cann\ River";
$areanames{en}->{61351594} = "Swifts\ Creek";
$areanames{en}->{61351595} = "Swifts\ Creek";
$areanames{en}->{61351596} = "Dinner\ Plain";
$areanames{en}->{61351597} = "Omeo";
$areanames{en}->{61351598} = "Omeo";
$areanames{en}->{61351599} = "Omeo";
$areanames{en}->{61351600} = "Morwell";
$areanames{en}->{61351601} = "Morwell";
$areanames{en}->{61351602} = "Morwell";
$areanames{en}->{61351603} = "Meerlieu";
$areanames{en}->{61351604} = "Meerlieu";
$areanames{en}->{61351605} = "Mount\ Taylor";
$areanames{en}->{61351606} = "Mount\ Taylor";
$areanames{en}->{61351607} = "Nowa\ Nowa";
$areanames{en}->{61351608} = "Nowa\ Nowa";
$areanames{en}->{61351609} = "Traralgon";
$areanames{en}->{61351610} = "Orbost";
$areanames{en}->{61351611} = "Orbost";
$areanames{en}->{61351612} = "Orbost";
$areanames{en}->{61351613} = "Goongerah";
$areanames{en}->{61351614} = "Cabbage\ Tree\ Creek";
$areanames{en}->{61351615} = "Club\ Terrace";
$areanames{en}->{61351616} = "Combienbar";
$areanames{en}->{61351617} = "Cann\ River";
$areanames{en}->{61351618} = "Genoa";
$areanames{en}->{61351619} = "Mallacoota";
$areanames{en}->{61351620} = "Nowa\ Nowa";
$areanames{en}->{61351621} = "Buchan";
$areanames{en}->{61351622} = "Gelantipy";
$areanames{en}->{61351623} = "Lakes\ Entrance";
$areanames{en}->{61351624} = "Ensay";
$areanames{en}->{61351625} = "Bruthen";
$areanames{en}->{61351626} = "Meerlieu";
$areanames{en}->{61351627} = "Mount\ Taylor";
$areanames{en}->{61351628} = "Omeo";
$areanames{en}->{61351629} = "Swifts\ Creek";
$areanames{en}->{61351630} = "Dargo";
$areanames{en}->{61351631} = "Yinnar";
$areanames{en}->{61351632} = "Yinnar";
$areanames{en}->{61351633} = "Omeo";
$areanames{en}->{61351634} = "Omeo";
$areanames{en}->{61351635} = "Orbost";
$areanames{en}->{61351636} = "Orbost";
$areanames{en}->{61351637} = "Swifts\ Creek";
$areanames{en}->{61351638} = "Swifts\ Creek";
$areanames{en}->{61351639} = "Goongerah";
$areanames{en}->{61351640} = "Bairnsdale";
$areanames{en}->{61351641} = "Morwell";
$areanames{en}->{61351642} = "Traralgon";
$areanames{en}->{61351643} = "Maffra";
$areanames{en}->{61351644} = "Sale";
$areanames{en}->{61351645} = "Lakes\ Entrance";
$areanames{en}->{61351646} = "Lakes\ Entrance";
$areanames{en}->{61351647} = "Lindenow";
$areanames{en}->{61351648} = "Lindenow";
$areanames{en}->{61351649} = "Lakes\ Entrance";
$areanames{en}->{61351650} = "Morwell";
$areanames{en}->{61351651} = "Baw\ Baw";
$areanames{en}->{61351652} = "Erica";
$areanames{en}->{61351653} = "Erica";
$areanames{en}->{61351654} = "Erica";
$areanames{en}->{61351655} = "Rosedale";
$areanames{en}->{61351656} = "Erica";
$areanames{en}->{61351657} = "Seaspray";
$areanames{en}->{61351658} = "Club\ Terrace";
$areanames{en}->{61351659} = "Club\ Terrace";
$areanames{en}->{61351660} = "Morwell";
$areanames{en}->{61351661} = "Morwell";
$areanames{en}->{61351662} = "Morwell";
$areanames{en}->{61351663} = "Buchan";
$areanames{en}->{61351664} = "Buchan";
$areanames{en}->{61351665} = "Clydebank";
$areanames{en}->{61351666} = "Clydebank";
$areanames{en}->{61351667} = "Golden\ Beach";
$areanames{en}->{61351668} = "Golden\ Beach";
$areanames{en}->{61351669} = "Buchan";
$areanames{en}->{61351670} = "Morwell";
$areanames{en}->{61351671} = "Morwell";
$areanames{en}->{61351672} = "Morwell";
$areanames{en}->{61351673} = "Loch\ Sport";
$areanames{en}->{61351674} = "Loch\ Sport";
$areanames{en}->{61351675} = "Maffra";
$areanames{en}->{61351676} = "Maffra";
$areanames{en}->{61351677} = "Munro";
$areanames{en}->{61351678} = "Munro";
$areanames{en}->{61351679} = "Heyfield";
$areanames{en}->{61351680} = "Morwell";
$areanames{en}->{61351681} = "Morwell";
$areanames{en}->{61351682} = "Morwell";
$areanames{en}->{61351683} = "Ensay";
$areanames{en}->{61351684} = "Ensay";
$areanames{en}->{61351685} = "Gelantipy";
$areanames{en}->{61351686} = "Gelantipy";
$areanames{en}->{61351687} = "Goongerah";
$areanames{en}->{61351688} = "Goongerah";
$areanames{en}->{61351689} = "Bairnsdale";
$areanames{en}->{61351690} = "Bairnsdale";
$areanames{en}->{61351691} = "Yinnar";
$areanames{en}->{61351692} = "Yinnar";
$areanames{en}->{61351693} = "Yinnar";
$areanames{en}->{61351694} = "Seaspray";
$areanames{en}->{61351695} = "Yinnar";
$areanames{en}->{61351696} = "Yinnar";
$areanames{en}->{61351697} = "Sale";
$areanames{en}->{61351698} = "Sale";
$areanames{en}->{61351699} = "Sale";
$areanames{en}->{61351711} = "Traralgon";
$areanames{en}->{61351721} = "Traralgon";
$areanames{en}->{61351722} = "Traralgon";
$areanames{en}->{61351723} = "Traralgon";
$areanames{en}->{61351724} = "Traralgon";
$areanames{en}->{61351725} = "Baw\ Baw";
$areanames{en}->{61351726} = "Baw\ Baw";
$areanames{en}->{61351727} = "Erica";
$areanames{en}->{61351728} = "Erica";
$areanames{en}->{61351729} = "Traralgon";
$areanames{en}->{6135173} = "Traralgon";
$areanames{en}->{6135174} = "Traralgon";
$areanames{en}->{6135175} = "Traralgon";
$areanames{en}->{6135176} = "Traralgon";
$areanames{en}->{6135177} = "Traralgon";
$areanames{en}->{61351779} = "Rosedale";
$areanames{en}->{61351780} = "Gelantipy";
$areanames{en}->{61351781} = "Swifts\ Creek";
$areanames{en}->{61351782} = "Mount\ Taylor";
$areanames{en}->{61351783} = "Dinner\ Plain";
$areanames{en}->{61351784} = "Buchan";
$areanames{en}->{61351785} = "Bruthen";
$areanames{en}->{61351786} = "Bruthen";
$areanames{en}->{61351787} = "Mallacoota";
$areanames{en}->{61351788} = "Mallacoota";
$areanames{en}->{61351789} = "Mallacoota";
$areanames{en}->{61351790} = "Nowa\ Nowa";
$areanames{en}->{61351791} = "Genoa";
$areanames{en}->{61351792} = "Goongerah";
$areanames{en}->{61351793} = "Cabbage\ Tree\ Creek";
$areanames{en}->{61351794} = "Combienbar";
$areanames{en}->{61351795} = "Lakes\ Entrance";
$areanames{en}->{61351796} = "Meerlieu";
$areanames{en}->{61351797} = "Cann\ River";
$areanames{en}->{61351798} = "Club\ Terrace";
$areanames{en}->{61351799} = "Omeo";
$areanames{en}->{61351800} = "Clydebank";
$areanames{en}->{61351801} = "Dargo";
$areanames{en}->{61351802} = "Dargo";
$areanames{en}->{61351803} = "Golden\ Beach";
$areanames{en}->{61351804} = "Heyfield";
$areanames{en}->{61351805} = "Licola";
$areanames{en}->{61351806} = "Loch\ Sport";
$areanames{en}->{61351807} = "Maffra";
$areanames{en}->{61351808} = "Munro";
$areanames{en}->{61351809} = "Sale";
$areanames{en}->{61351810} = "Swifts\ Creek";
$areanames{en}->{61351811} = "Baw\ Baw";
$areanames{en}->{61351812} = "Erica";
$areanames{en}->{61351813} = "Gormandale";
$areanames{en}->{61351814} = "Morwell";
$areanames{en}->{61351815} = "Rosedale";
$areanames{en}->{61351816} = "Traralgon";
$areanames{en}->{61351817} = "Woodside";
$areanames{en}->{61351818} = "Yarram";
$areanames{en}->{61351819} = "Yinnar";
$areanames{en}->{61351820} = "Yarram";
$areanames{en}->{61351821} = "Gormandale";
$areanames{en}->{61351822} = "Gormandale";
$areanames{en}->{61351823} = "Morwell";
$areanames{en}->{61351824} = "Morwell";
$areanames{en}->{61351825} = "Yarram";
$areanames{en}->{61351826} = "Yarram";
$areanames{en}->{61351827} = "Yarram";
$areanames{en}->{61351828} = "Sale";
$areanames{en}->{61351829} = "Sale";
$areanames{en}->{6135183} = "Yarram";
$areanames{en}->{61351834} = "Rosedale";
$areanames{en}->{61351835} = "Rosedale";
$areanames{en}->{61351836} = "Traralgon";
$areanames{en}->{61351837} = "Traralgon";
$areanames{en}->{61351840} = "Yarram";
$areanames{en}->{61351841} = "Yarram";
$areanames{en}->{61351842} = "Traralgon";
$areanames{en}->{61351843} = "Traralgon";
$areanames{en}->{61351844} = "Traralgon";
$areanames{en}->{61351850} = "Yarram";
$areanames{en}->{61351851} = "Yarram";
$areanames{en}->{61351860} = "Yarram";
$areanames{en}->{61351861} = "Yarram";
$areanames{en}->{6135187} = "Woodside";
$areanames{en}->{61351876} = "Yarram";
$areanames{en}->{61351877} = "Yarram";
$areanames{en}->{61351878} = "Yinnar";
$areanames{en}->{61351879} = "Yinnar";
$areanames{en}->{61351880} = "Yarram";
$areanames{en}->{61351881} = "Yarram";
$areanames{en}->{61351882} = "Yarram";
$areanames{en}->{61351883} = "Yarram";
$areanames{en}->{61351884} = "Yarram";
$areanames{en}->{61351885} = "Mallacoota";
$areanames{en}->{61351886} = "Mallacoota";
$areanames{en}->{61351888} = "Yarram";
$areanames{en}->{61351889} = "Woodside";
$areanames{en}->{61351890} = "Woodside";
$areanames{en}->{61351891} = "Woodside";
$areanames{en}->{61351892} = "Woodside";
$areanames{en}->{61351900} = "Genoa";
$areanames{en}->{61351901} = "Goongerah";
$areanames{en}->{61351902} = "Lakes\ Entrance";
$areanames{en}->{61351903} = "Lindenow";
$areanames{en}->{61351904} = "Mallacoota";
$areanames{en}->{61351905} = "Meerlieu";
$areanames{en}->{61351906} = "Mount\ Taylor";
$areanames{en}->{61351907} = "Nowa\ Nowa";
$areanames{en}->{61351908} = "Omeo";
$areanames{en}->{61351909} = "Orbost";
$areanames{en}->{61351915} = "Traralgon";
$areanames{en}->{61351918} = "Traralgon";
$areanames{en}->{61351919} = "Morwell";
$areanames{en}->{61351920} = "Morwell";
$areanames{en}->{61351921} = "Morwell";
$areanames{en}->{61351922} = "Morwell";
$areanames{en}->{61351923} = "Traralgon";
$areanames{en}->{61351924} = "Traralgon";
$areanames{en}->{61351925} = "Traralgon";
$areanames{en}->{61351930} = "Bairnsdale";
$areanames{en}->{61351931} = "Bruthen";
$areanames{en}->{61351932} = "Buchan";
$areanames{en}->{61351933} = "Cabbage\ Tree\ Creek";
$areanames{en}->{61351934} = "Cann\ River";
$areanames{en}->{61351935} = "Club\ Terrace";
$areanames{en}->{61351936} = "Combienbar";
$areanames{en}->{61351937} = "Dinner\ Plain";
$areanames{en}->{61351938} = "Ensay";
$areanames{en}->{61351939} = "Gelantipy";
$areanames{en}->{61351940} = "Gormandale";
$areanames{en}->{61351941} = "Gormandale";
$areanames{en}->{61351942} = "Gormandale";
$areanames{en}->{61351949} = "Gormandale";
$areanames{en}->{61351955} = "Gormandale";
$areanames{en}->{61351956} = "Gormandale";
$areanames{en}->{61351966} = "Gormandale";
$areanames{en}->{61351977} = "Gormandale";
$areanames{en}->{61351978} = "Gormandale";
$areanames{en}->{61351981} = "Rosedale";
$areanames{en}->{61351982} = "Rosedale";
$areanames{en}->{61351987} = "Bairnsdale";
$areanames{en}->{61351988} = "Bairnsdale";
$areanames{en}->{61351989} = "Bairnsdale";
$areanames{en}->{61351990} = "Rosedale";
$areanames{en}->{61351991} = "Rosedale";
$areanames{en}->{61351992} = "Rosedale";
$areanames{en}->{61351993} = "Rosedale";
$areanames{en}->{61351994} = "Rosedale";
$areanames{en}->{6135200} = "Geelong";
$areanames{en}->{6135201} = "Geelong";
$areanames{en}->{6135202} = "Geelong";
$areanames{en}->{61352026} = "Geelong\/Lara\/Geelong";
$areanames{en}->{61352030} = "Aireys\ Inlet";
$areanames{en}->{61352031} = "Aireys\ Inlet";
$areanames{en}->{61352032} = "Aireys\ Inlet";
$areanames{en}->{61352033} = "Anglesea";
$areanames{en}->{61352034} = "Anglesea";
$areanames{en}->{61352035} = "Anglesea";
$areanames{en}->{61352036} = "Apollo\ Bay";
$areanames{en}->{61352037} = "Apollo\ Bay";
$areanames{en}->{61352038} = "Apollo\ Bay";
$areanames{en}->{61352039} = "Apollo\ Bay";
$areanames{en}->{61352040} = "Bannockburn";
$areanames{en}->{61352041} = "Bannockburn";
$areanames{en}->{61352042} = "Bannockburn";
$areanames{en}->{61352043} = "Barwon\ Downs";
$areanames{en}->{61352044} = "Barwon\ Downs";
$areanames{en}->{61352045} = "Barwon\ Downs";
$areanames{en}->{61352046} = "Beeac";
$areanames{en}->{61352047} = "Beeac";
$areanames{en}->{61352048} = "Beeac";
$areanames{en}->{61352049} = "Barwon\ Downs";
$areanames{en}->{61352050} = "Beech\ Forest";
$areanames{en}->{61352051} = "Beech\ Forest";
$areanames{en}->{61352052} = "Beech\ Forest";
$areanames{en}->{61352053} = "Birregurra";
$areanames{en}->{61352054} = "Birregurra";
$areanames{en}->{61352055} = "Birregurra";
$areanames{en}->{61352056} = "Colac";
$areanames{en}->{61352057} = "Colac";
$areanames{en}->{61352058} = "Colac";
$areanames{en}->{61352059} = "Beeac";
$areanames{en}->{61352060} = "Cressy";
$areanames{en}->{61352061} = "Cressy";
$areanames{en}->{61352062} = "Cressy";
$areanames{en}->{61352063} = "Inverleigh";
$areanames{en}->{61352064} = "Inverleigh";
$areanames{en}->{61352065} = "Inverleigh";
$areanames{en}->{61352066} = "Kennedys\ Creek";
$areanames{en}->{61352067} = "Kennedys\ Creek";
$areanames{en}->{61352068} = "Kennedys\ Creek";
$areanames{en}->{61352069} = "Beech\ Forest";
$areanames{en}->{61352070} = "Lara";
$areanames{en}->{61352071} = "Lara";
$areanames{en}->{61352072} = "Lara";
$areanames{en}->{61352073} = "Lavers\ Hill";
$areanames{en}->{61352074} = "Lavers\ Hill";
$areanames{en}->{61352075} = "Lavers\ Hill";
$areanames{en}->{61352076} = "Lorne";
$areanames{en}->{61352077} = "Lorne";
$areanames{en}->{61352078} = "Lorne";
$areanames{en}->{61352079} = "Birregurra";
$areanames{en}->{61352080} = "Meredith";
$areanames{en}->{61352081} = "Meredith";
$areanames{en}->{61352082} = "Meredith";
$areanames{en}->{61352083} = "Queenscliff";
$areanames{en}->{61352084} = "Queenscliff";
$areanames{en}->{61352085} = "Queenscliff";
$areanames{en}->{61352086} = "Swan\ Marsh";
$areanames{en}->{61352087} = "Swan\ Marsh";
$areanames{en}->{61352088} = "Swan\ Marsh";
$areanames{en}->{61352089} = "Colac";
$areanames{en}->{61352090} = "Torquay";
$areanames{en}->{61352091} = "Torquay";
$areanames{en}->{61352092} = "Torquay";
$areanames{en}->{61352093} = "Winchelsea\ South";
$areanames{en}->{61352094} = "Winchelsea\ South";
$areanames{en}->{61352095} = "Winchelsea\ South";
$areanames{en}->{61352096} = "Wingeel";
$areanames{en}->{61352097} = "Wingeel";
$areanames{en}->{61352098} = "Wingeel";
$areanames{en}->{61352099} = "Cressy";
$areanames{en}->{61352100} = "Kennedys\ Creek";
$areanames{en}->{61352101} = "Lavers\ Hill";
$areanames{en}->{61352102} = "Swan\ Marsh";
$areanames{en}->{61352103} = "Winchelsea\ South";
$areanames{en}->{61352104} = "Wingeel";
$areanames{en}->{61352105} = "Aireys\ Inlet";
$areanames{en}->{61352106} = "Anglesea";
$areanames{en}->{61352107} = "Bannockburn";
$areanames{en}->{61352108} = "Geelong";
$areanames{en}->{61352109} = "Inverleigh";
$areanames{en}->{61352110} = "Lara";
$areanames{en}->{61352111} = "Lorne";
$areanames{en}->{61352112} = "Meredith";
$areanames{en}->{61352113} = "Queenscliff";
$areanames{en}->{61352114} = "Torquay";
$areanames{en}->{61352115} = "Apollo\ Bay";
$areanames{en}->{61352116} = "Barwon\ Downs";
$areanames{en}->{61352117} = "Beeac";
$areanames{en}->{61352118} = "Beech\ Forest";
$areanames{en}->{61352119} = "Birregurra";
$areanames{en}->{61352120} = "Colac";
$areanames{en}->{61352121} = "Cressy";
$areanames{en}->{61352122} = "Kennedys\ Creek";
$areanames{en}->{61352123} = "Lavers\ Hill";
$areanames{en}->{61352124} = "Swan\ Marsh";
$areanames{en}->{61352125} = "Aireys\ Inlet";
$areanames{en}->{61352126} = "Anglesea";
$areanames{en}->{61352127} = "Bannockburn";
$areanames{en}->{61352128} = "Geelong";
$areanames{en}->{61352129} = "Inverleigh";
$areanames{en}->{61352130} = "Lara";
$areanames{en}->{61352131} = "Lorne";
$areanames{en}->{61352132} = "Meredith";
$areanames{en}->{61352133} = "Queenscliff";
$areanames{en}->{61352134} = "Torquay";
$areanames{en}->{61352135} = "Winchelsea\ South";
$areanames{en}->{61352136} = "Wingeel";
$areanames{en}->{61352137} = "Apollo\ Bay";
$areanames{en}->{61352138} = "Barwon\ Downs";
$areanames{en}->{61352139} = "Beeac";
$areanames{en}->{61352140} = "Beech\ Forest";
$areanames{en}->{61352141} = "Birregurra";
$areanames{en}->{61352142} = "Colac";
$areanames{en}->{61352143} = "Cressy";
$areanames{en}->{61352144} = "Kennedys\ Creek";
$areanames{en}->{61352145} = "Lavers\ Hill";
$areanames{en}->{61352146} = "Swan\ Marsh";
$areanames{en}->{61352147} = "Aireys\ Inlet";
$areanames{en}->{61352148} = "Anglesea";
$areanames{en}->{61352149} = "Bannockburn";
$areanames{en}->{6135215} = "Geelong";
$areanames{en}->{61352160} = "Inverleigh";
$areanames{en}->{61352161} = "Colac";
$areanames{en}->{61352162} = "Barwon\ Downs";
$areanames{en}->{61352163} = "Queenscliff";
$areanames{en}->{61352164} = "Winchelsea\ South";
$areanames{en}->{61352165} = "Wingeel";
$areanames{en}->{61352166} = "Lara";
$areanames{en}->{61352167} = "Lorne";
$areanames{en}->{61352168} = "Meredith";
$areanames{en}->{61352169} = "Queenscliff";
$areanames{en}->{61352170} = "Torquay";
$areanames{en}->{61352171} = "Apollo\ Bay";
$areanames{en}->{61352172} = "Beeac";
$areanames{en}->{61352173} = "Beech\ Forest";
$areanames{en}->{61352174} = "Birregurra";
$areanames{en}->{61352175} = "Cressy";
$areanames{en}->{61352176} = "Kennedys\ Creek";
$areanames{en}->{61352177} = "Lavers\ Hill";
$areanames{en}->{61352178} = "Swan\ Marsh";
$areanames{en}->{61352179} = "Aireys\ Inlet";
$areanames{en}->{61352180} = "Anglesea";
$areanames{en}->{61352181} = "Bannockburn";
$areanames{en}->{61352182} = "Inverleigh";
$areanames{en}->{61352183} = "Lorne";
$areanames{en}->{61352184} = "Meredith";
$areanames{en}->{61352185} = "Torquay";
$areanames{en}->{61352186} = "Winchelsea\ South";
$areanames{en}->{61352187} = "Wingeel";
$areanames{en}->{61352188} = "Apollo\ Bay";
$areanames{en}->{61352189} = "Barwon\ Downs";
$areanames{en}->{61352190} = "Beeac";
$areanames{en}->{61352191} = "Beech\ Forest";
$areanames{en}->{61352192} = "Birregurra";
$areanames{en}->{61352193} = "Colac";
$areanames{en}->{61352194} = "Cressy";
$areanames{en}->{61352195} = "Kennedys\ Creek";
$areanames{en}->{61352196} = "Lavers\ Hill";
$areanames{en}->{61352197} = "Swan\ Marsh";
$areanames{en}->{61352198} = "Aireys\ Inlet";
$areanames{en}->{61352199} = "Anglesea";
$areanames{en}->{613522} = "Geelong";
$areanames{en}->{61352200} = "Aireys\ Inlet";
$areanames{en}->{61352201} = "Wingeel";
$areanames{en}->{61352202} = "Anglesea";
$areanames{en}->{61352203} = "Anglesea";
$areanames{en}->{61352204} = "Queenscliff";
$areanames{en}->{61352205} = "Torquay";
$areanames{en}->{61352206} = "Inverleigh";
$areanames{en}->{61352207} = "Bannockburn";
$areanames{en}->{61352208} = "Lara";
$areanames{en}->{61352209} = "Meredith";
$areanames{en}->{61352279} = "Lara";
$areanames{en}->{61352289} = "Lorne";
$areanames{en}->{61352300} = "Colac";
$areanames{en}->{61352301} = "Beeac";
$areanames{en}->{61352302} = "Swan\ Marsh";
$areanames{en}->{61352303} = "Beech\ Forest";
$areanames{en}->{61352304} = "Birregurra";
$areanames{en}->{61352305} = "Barwon\ Downs";
$areanames{en}->{61352306} = "Apollo\ Bay";
$areanames{en}->{61352307} = "Lavers\ Hill";
$areanames{en}->{61352308} = "Kennedys\ Creek";
$areanames{en}->{61352309} = "Cressy";
$areanames{en}->{6135231} = "Colac";
$areanames{en}->{6135232} = "Colac";
$areanames{en}->{6135233} = "Colac";
$areanames{en}->{61352340} = "Colac";
$areanames{en}->{61352341} = "Colac";
$areanames{en}->{61352342} = "Colac";
$areanames{en}->{61352343} = "Colac";
$areanames{en}->{61352344} = "Geelong";
$areanames{en}->{61352345} = "Geelong";
$areanames{en}->{61352346} = "Beeac";
$areanames{en}->{61352347} = "Beeac";
$areanames{en}->{61352348} = "Beeac";
$areanames{en}->{61352349} = "Beeac";
$areanames{en}->{6135235} = "Swan\ Marsh";
$areanames{en}->{61352350} = "Beech\ Forest";
$areanames{en}->{61352357} = "Beech\ Forest";
$areanames{en}->{61352358} = "Beech\ Forest";
$areanames{en}->{61352359} = "Beech\ Forest";
$areanames{en}->{61352360} = "Bannockburn";
$areanames{en}->{61352361} = "Birregurra";
$areanames{en}->{61352362} = "Birregurra";
$areanames{en}->{61352363} = "Birregurra";
$areanames{en}->{61352364} = "Birregurra";
$areanames{en}->{61352365} = "Birregurra";
$areanames{en}->{61352366} = "Barwon\ Downs";
$areanames{en}->{61352367} = "Barwon\ Downs";
$areanames{en}->{61352368} = "Barwon\ Downs";
$areanames{en}->{61352369} = "Lavers\ Hill";
$areanames{en}->{6135237} = "Apollo\ Bay";
$areanames{en}->{61352373} = "Lavers\ Hill";
$areanames{en}->{61352374} = "Lavers\ Hill";
$areanames{en}->{61352375} = "Lavers\ Hill";
$areanames{en}->{6135238} = "Cressy";
$areanames{en}->{61352383} = "Kennedys\ Creek";
$areanames{en}->{61352390} = "Beeac";
$areanames{en}->{61352391} = "Beeac";
$areanames{en}->{61352392} = "Birregurra";
$areanames{en}->{61352393} = "Apollo\ Bay";
$areanames{en}->{61352394} = "Lavers\ Hill";
$areanames{en}->{61352395} = "Kennedys\ Creek";
$areanames{en}->{61352396} = "Swan\ Marsh";
$areanames{en}->{61352397} = "Barwon\ Downs";
$areanames{en}->{61352398} = "Beech\ Forest";
$areanames{en}->{61352399} = "Beech\ Forest";
$areanames{en}->{613524} = "Geelong";
$areanames{en}->{61352420} = "Inverleigh";
$areanames{en}->{61352421} = "Lara";
$areanames{en}->{61352422} = "Lorne";
$areanames{en}->{61352423} = "Meredith";
$areanames{en}->{61352424} = "Queenscliff";
$areanames{en}->{61352425} = "Torquay";
$areanames{en}->{61352426} = "Winchelsea\ South";
$areanames{en}->{61352427} = "Wingeel";
$areanames{en}->{61352429} = "Queenscliff";
$areanames{en}->{613525} = "Geelong";
$areanames{en}->{6135252} = "Queenscliff";
$areanames{en}->{6135260} = "Geelong";
$areanames{en}->{6135261} = "Torquay";
$areanames{en}->{6135262} = "Torquay";
$areanames{en}->{6135263} = "Anglesea";
$areanames{en}->{6135264} = "Torquay";
$areanames{en}->{6135265} = "Inverleigh";
$areanames{en}->{6135266} = "Inverleigh";
$areanames{en}->{6135267} = "Anglesea";
$areanames{en}->{6135268} = "Geelong";
$areanames{en}->{61352690} = "Apollo\ Bay";
$areanames{en}->{61352691} = "Geelong";
$areanames{en}->{61352692} = "Geelong";
$areanames{en}->{61352693} = "Geelong";
$areanames{en}->{61352694} = "Geelong";
$areanames{en}->{61352695} = "Winchelsea\ South";
$areanames{en}->{61352696} = "Wingeel";
$areanames{en}->{61352697} = "Barwon\ Downs";
$areanames{en}->{61352698} = "Beeac";
$areanames{en}->{61352699} = "Beech\ Forest";
$areanames{en}->{613527} = "Geelong";
$areanames{en}->{61352700} = "Birregurra";
$areanames{en}->{61352701} = "Colac";
$areanames{en}->{61352702} = "Cressy";
$areanames{en}->{61352703} = "Kennedys\ Creek";
$areanames{en}->{61352704} = "Lavers\ Hill";
$areanames{en}->{61352705} = "Swan\ Marsh";
$areanames{en}->{61352706} = "Aireys\ Inlet";
$areanames{en}->{61352707} = "Anglesea";
$areanames{en}->{61352708} = "Bannockburn";
$areanames{en}->{61352800} = "Inverleigh";
$areanames{en}->{61352801} = "Lara";
$areanames{en}->{61352802} = "Lorne";
$areanames{en}->{61352803} = "Meredith";
$areanames{en}->{61352804} = "Queenscliff";
$areanames{en}->{61352805} = "Torquay";
$areanames{en}->{61352806} = "Winchelsea\ South";
$areanames{en}->{61352807} = "Wingeel";
$areanames{en}->{61352808} = "Geelong";
$areanames{en}->{61352809} = "Lara";
$areanames{en}->{6135281} = "Bannockburn";
$areanames{en}->{6135282} = "Lara";
$areanames{en}->{6135283} = "Lara";
$areanames{en}->{6135284} = "Lara";
$areanames{en}->{6135285} = "Lara";
$areanames{en}->{6135286} = "Meredith";
$areanames{en}->{6135287} = "Wingeel";
$areanames{en}->{6135288} = "Winchelsea\ South";
$areanames{en}->{6135289} = "Lorne";
$areanames{en}->{61352896} = "Aireys\ Inlet";
$areanames{en}->{61352897} = "Aireys\ Inlet";
$areanames{en}->{61352898} = "Aireys\ Inlet";
$areanames{en}->{61352900} = "Apollo\ Bay";
$areanames{en}->{61352901} = "Barwon\ Downs";
$areanames{en}->{61352902} = "Beeac";
$areanames{en}->{61352903} = "Beech\ Forest";
$areanames{en}->{61352904} = "Birregurra";
$areanames{en}->{61352905} = "Colac";
$areanames{en}->{61352906} = "Cressy";
$areanames{en}->{61352907} = "Kennedys\ Creek";
$areanames{en}->{61352908} = "Lavers\ Hill";
$areanames{en}->{61352909} = "Swan\ Marsh";
$areanames{en}->{61352910} = "Aireys\ Inlet";
$areanames{en}->{61352911} = "Anglesea";
$areanames{en}->{61352912} = "Bannockburn";
$areanames{en}->{61352913} = "Geelong";
$areanames{en}->{61352914} = "Inverleigh";
$areanames{en}->{61352915} = "Lara";
$areanames{en}->{61352916} = "Lorne";
$areanames{en}->{61352917} = "Meredith";
$areanames{en}->{61352918} = "Queenscliff";
$areanames{en}->{61352919} = "Torquay";
$areanames{en}->{6135292} = "Geelong";
$areanames{en}->{6135293} = "Lara";
$areanames{en}->{6135294} = "Geelong";
$areanames{en}->{61352950} = "Aireys\ Inlet";
$areanames{en}->{61352951} = "Anglesea";
$areanames{en}->{61352952} = "Bannockburn";
$areanames{en}->{61352953} = "Inverleigh";
$areanames{en}->{61352954} = "Lara";
$areanames{en}->{61352955} = "Meredith";
$areanames{en}->{61352956} = "Lorne";
$areanames{en}->{61352957} = "Queenscliff";
$areanames{en}->{61352958} = "Winchelsea\ South";
$areanames{en}->{61352959} = "Wingeel";
$areanames{en}->{61352960} = "Torquay";
$areanames{en}->{61352961} = "Apollo\ Bay";
$areanames{en}->{61352962} = "Beeac";
$areanames{en}->{61352963} = "Beech\ Forest";
$areanames{en}->{61352964} = "Birregurra";
$areanames{en}->{61352965} = "Colac";
$areanames{en}->{61352966} = "Lavers\ Hill";
$areanames{en}->{61352967} = "Kennedys\ Creek";
$areanames{en}->{61352968} = "Swan\ Marsh";
$areanames{en}->{61352969} = "Cressy";
$areanames{en}->{61352970} = "Barwon\ Downs";
$areanames{en}->{61352971} = "Colac";
$areanames{en}->{61352972} = "Lara";
$areanames{en}->{61352973} = "Queenscliff";
$areanames{en}->{61352974} = "Anglesea";
$areanames{en}->{61352975} = "Wingeel";
$areanames{en}->{61352976} = "Winchelsea\ South";
$areanames{en}->{61352977} = "Torquay";
$areanames{en}->{61352978} = "Queenscliff";
$areanames{en}->{61352979} = "Geelong";
$areanames{en}->{6135298} = "Geelong";
$areanames{en}->{61352990} = "Colac";
$areanames{en}->{61352991} = "Lara";
$areanames{en}->{61352992} = "Torquay";
$areanames{en}->{61352993} = "Colac";
$areanames{en}->{61352994} = "Aireys\ Inlet";
$areanames{en}->{61352995} = "Winchelsea\ South";
$areanames{en}->{61352996} = "Wingeel";
$areanames{en}->{61352997} = "Apollo\ Bay";
$areanames{en}->{61352998} = "Barwon\ Downs";
$areanames{en}->{61352999} = "Beeac";
$areanames{en}->{61353000} = "Ballarat";
$areanames{en}->{61353001} = "Ballarat";
$areanames{en}->{61353002} = "Ballarat";
$areanames{en}->{61353003} = "Ararat";
$areanames{en}->{61353004} = "Bacchus\ Marsh";
$areanames{en}->{61353005} = "Ballan";
$areanames{en}->{61353006} = "Balliang";
$areanames{en}->{61353007} = "Bangerang";
$areanames{en}->{61353008} = "Banyena";
$areanames{en}->{61353009} = "Beaufort";
$areanames{en}->{61353010} = "Beulah";
$areanames{en}->{61353011} = "Broughton";
$areanames{en}->{61353012} = "Buangor";
$areanames{en}->{61353013} = "Buninyong";
$areanames{en}->{61353014} = "Clear\ Lake";
$areanames{en}->{61353015} = "Creswick";
$areanames{en}->{61353016} = "Crymelon";
$areanames{en}->{61353017} = "Dadswells\ Bridge";
$areanames{en}->{61353018} = "Daylesford";
$areanames{en}->{61353019} = "Dimboola";
$areanames{en}->{61353020} = "Elmhurst";
$areanames{en}->{61353021} = "Gerang\ Gerung";
$areanames{en}->{61353022} = "Glenisla";
$areanames{en}->{61353023} = "Glenorchy";
$areanames{en}->{61353024} = "Goroke";
$areanames{en}->{61353025} = "Halls\ Gap";
$areanames{en}->{61353026} = "Horsham";
$areanames{en}->{61353027} = "Jeparit";
$areanames{en}->{61353028} = "Kalkee";
$areanames{en}->{61353029} = "Kaniva";
$areanames{en}->{6135303} = "Ballarat";
$areanames{en}->{6135304} = "Ballarat";
$areanames{en}->{61353050} = "Laharum";
$areanames{en}->{61353051} = "Lake\ Bolac";
$areanames{en}->{61353052} = "Landsborough";
$areanames{en}->{61353053} = "Learmonth";
$areanames{en}->{61353054} = "Linton";
$areanames{en}->{61353055} = "Marnoo";
$areanames{en}->{61353056} = "Maroona";
$areanames{en}->{61353057} = "Minimay";
$areanames{en}->{61353058} = "Minyip";
$areanames{en}->{61353059} = "Mount\ Wallace";
$areanames{en}->{61353060} = "Moyston";
$areanames{en}->{61353061} = "Murtoa";
$areanames{en}->{61353062} = "Natimuk";
$areanames{en}->{61353063} = "Navarre";
$areanames{en}->{61353064} = "Nhill";
$areanames{en}->{61353065} = "Polkemmet";
$areanames{en}->{61353066} = "Rainbow";
$areanames{en}->{61353067} = "Rokewood";
$areanames{en}->{61353068} = "Scarsdale";
$areanames{en}->{61353069} = "Serviceton";
$areanames{en}->{61353070} = "Skipton";
$areanames{en}->{61353071} = "Stawell";
$areanames{en}->{61353072} = "Stoneleigh";
$areanames{en}->{61353073} = "Streatham";
$areanames{en}->{61353074} = "Telopea\ Downs";
$areanames{en}->{61353075} = "Warracknabeal";
$areanames{en}->{61353076} = "Wilkur";
$areanames{en}->{61353077} = "Willaura";
$areanames{en}->{61353078} = "Yaapeet";
$areanames{en}->{61353079} = "Willaura";
$areanames{en}->{6135308} = "Ballarat";
$areanames{en}->{61353090} = "Ballarat";
$areanames{en}->{61353091} = "Ballarat";
$areanames{en}->{61353092} = "Ballarat";
$areanames{en}->{61353093} = "Ballarat";
$areanames{en}->{61353094} = "Streatham";
$areanames{en}->{61353095} = "Maroona";
$areanames{en}->{61353096} = "Buninyong";
$areanames{en}->{61353097} = "Beaufort";
$areanames{en}->{61353098} = "Learmonth";
$areanames{en}->{61353099} = "Skipton";
$areanames{en}->{61353100} = "Moyston";
$areanames{en}->{61353101} = "Ararat";
$areanames{en}->{61353102} = "Stawell";
$areanames{en}->{61353103} = "Maroona";
$areanames{en}->{61353104} = "Moyston";
$areanames{en}->{61353105} = "Horsham";
$areanames{en}->{61353106} = "Bacchus\ Marsh";
$areanames{en}->{61353107} = "Balliang";
$areanames{en}->{61353108} = "Navarre";
$areanames{en}->{61353109} = "Stawell";
$areanames{en}->{61353110} = "Landsborough";
$areanames{en}->{61353111} = "Marnoo";
$areanames{en}->{61353112} = "Glenorchy";
$areanames{en}->{61353113} = "Halls\ Gap";
$areanames{en}->{61353114} = "Lake\ Bolac";
$areanames{en}->{61353115} = "Dadswells\ Bridge";
$areanames{en}->{61353116} = "Elmhurst";
$areanames{en}->{61353117} = "Ararat";
$areanames{en}->{61353118} = "Buangor";
$areanames{en}->{61353119} = "Stoneleigh";
$areanames{en}->{61353120} = "Skipton";
$areanames{en}->{61353121} = "Scarsdale";
$areanames{en}->{61353122} = "Daylesford";
$areanames{en}->{61353123} = "Learmonth";
$areanames{en}->{61353124} = "Linton";
$areanames{en}->{61353125} = "Rokewood";
$areanames{en}->{61353126} = "Creswick";
$areanames{en}->{61353127} = "Ballarat";
$areanames{en}->{61353128} = "Beaufort";
$areanames{en}->{61353129} = "Buninyong";
$areanames{en}->{61353130} = "Yaapeet";
$areanames{en}->{61353131} = "Kalkee";
$areanames{en}->{61353132} = "Laharum";
$areanames{en}->{61353133} = "Minimay";
$areanames{en}->{61353134} = "Minyip";
$areanames{en}->{61353135} = "Murtoa";
$areanames{en}->{61353136} = "Natimuk";
$areanames{en}->{61353137} = "Polkemmet";
$areanames{en}->{61353138} = "Rainbow";
$areanames{en}->{61353139} = "Warracknabeal";
$areanames{en}->{61353140} = "Wilkur";
$areanames{en}->{61353141} = "Banyena";
$areanames{en}->{61353142} = "Beulah";
$areanames{en}->{61353143} = "Clear\ Lake";
$areanames{en}->{61353144} = "Crymelon";
$areanames{en}->{61353145} = "Dimboola";
$areanames{en}->{61353146} = "Gerang\ Gerung";
$areanames{en}->{61353147} = "Glenisla";
$areanames{en}->{61353148} = "Goroke";
$areanames{en}->{61353149} = "Horsham";
$areanames{en}->{61353150} = "Jeparit";
$areanames{en}->{61353151} = "Bangerang";
$areanames{en}->{61353152} = "Bacchus\ Marsh";
$areanames{en}->{61353153} = "Ballan";
$areanames{en}->{61353154} = "Balliang";
$areanames{en}->{61353155} = "Mount\ Wallace";
$areanames{en}->{61353156} = "Telopea\ Downs";
$areanames{en}->{61353157} = "Broughton";
$areanames{en}->{61353158} = "Kaniva";
$areanames{en}->{61353159} = "Lorquon";
$areanames{en}->{61353160} = "Nhill";
$areanames{en}->{61353161} = "Serviceton";
$areanames{en}->{613531620} = "Ararat";
$areanames{en}->{613531621} = "Ararat";
$areanames{en}->{613531622} = "Ararat";
$areanames{en}->{613531623} = "Ararat";
$areanames{en}->{613531624} = "Ararat";
$areanames{en}->{613531625} = "Ararat";
$areanames{en}->{613531630} = "Buangor";
$areanames{en}->{613531631} = "Buangor";
$areanames{en}->{613531632} = "Buangor";
$areanames{en}->{613531633} = "Buangor";
$areanames{en}->{613531637} = "Buangor";
$areanames{en}->{613531640} = "Dadswells\ Bridge";
$areanames{en}->{613531641} = "Dadswells\ Bridge";
$areanames{en}->{613531642} = "Dadswells\ Bridge";
$areanames{en}->{613531643} = "Dadswells\ Bridge";
$areanames{en}->{613531647} = "Dadswells\ Bridge";
$areanames{en}->{613531650} = "Elmhurst";
$areanames{en}->{613531651} = "Elmhurst";
$areanames{en}->{613531652} = "Elmhurst";
$areanames{en}->{613531653} = "Elmhurst";
$areanames{en}->{613531657} = "Elmhurst";
$areanames{en}->{613531660} = "Glenorchy";
$areanames{en}->{613531661} = "Glenorchy";
$areanames{en}->{613531662} = "Glenorchy";
$areanames{en}->{613531663} = "Glenorchy";
$areanames{en}->{613531667} = "Glenorchy";
$areanames{en}->{613531670} = "Halls\ Gap";
$areanames{en}->{613531671} = "Halls\ Gap";
$areanames{en}->{613531672} = "Halls\ Gap";
$areanames{en}->{613531673} = "Halls\ Gap";
$areanames{en}->{613531674} = "Halls\ Gap";
$areanames{en}->{613531677} = "Halls\ Gap";
$areanames{en}->{613531680} = "Lake\ Bolac";
$areanames{en}->{613531681} = "Lake\ Bolac";
$areanames{en}->{613531682} = "Lake\ Bolac";
$areanames{en}->{613531683} = "Lake\ Bolac";
$areanames{en}->{613531687} = "Lake\ Bolac";
$areanames{en}->{613531690} = "Landsborough";
$areanames{en}->{613531691} = "Landsborough";
$areanames{en}->{613531692} = "Landsborough";
$areanames{en}->{613531693} = "Landsborough";
$areanames{en}->{613531697} = "Landsborough";
$areanames{en}->{613531700} = "Marnoo";
$areanames{en}->{613531701} = "Marnoo";
$areanames{en}->{613531702} = "Marnoo";
$areanames{en}->{613531703} = "Marnoo";
$areanames{en}->{613531707} = "Marnoo";
$areanames{en}->{613531710} = "Maroona";
$areanames{en}->{613531711} = "Maroona";
$areanames{en}->{613531712} = "Maroona";
$areanames{en}->{613531713} = "Maroona";
$areanames{en}->{613531717} = "Maroona";
$areanames{en}->{613531720} = "Moyston";
$areanames{en}->{613531721} = "Moyston";
$areanames{en}->{613531722} = "Moyston";
$areanames{en}->{613531723} = "Moyston";
$areanames{en}->{613531727} = "Moyston";
$areanames{en}->{613531730} = "Navarre";
$areanames{en}->{613531731} = "Navarre";
$areanames{en}->{613531732} = "Navarre";
$areanames{en}->{613531733} = "Navarre";
$areanames{en}->{613531737} = "Navarre";
$areanames{en}->{613531740} = "Stawell";
$areanames{en}->{613531741} = "Stawell";
$areanames{en}->{613531742} = "Stawell";
$areanames{en}->{613531743} = "Stawell";
$areanames{en}->{613531745} = "Stawell";
$areanames{en}->{613531746} = "Stawell";
$areanames{en}->{613531747} = "Stawell";
$areanames{en}->{613531750} = "Streatham";
$areanames{en}->{613531751} = "Streatham";
$areanames{en}->{613531752} = "Streatham";
$areanames{en}->{613531753} = "Streatham";
$areanames{en}->{613531757} = "Streatham";
$areanames{en}->{613531760} = "Willaura";
$areanames{en}->{613531761} = "Willaura";
$areanames{en}->{613531762} = "Willaura";
$areanames{en}->{613531763} = "Willaura";
$areanames{en}->{613531764} = "Willaura";
$areanames{en}->{613531767} = "Willaura";
$areanames{en}->{613531770} = "Ballarat";
$areanames{en}->{613531771} = "Ballarat";
$areanames{en}->{613531772} = "Ballarat";
$areanames{en}->{613531773} = "Ballarat";
$areanames{en}->{613531774} = "Ballarat";
$areanames{en}->{613531780} = "Beaufort";
$areanames{en}->{613531781} = "Beaufort";
$areanames{en}->{613531782} = "Beaufort";
$areanames{en}->{613531783} = "Beaufort";
$areanames{en}->{613531784} = "Beaufort";
$areanames{en}->{613531787} = "Beaufort";
$areanames{en}->{613531790} = "Buninyong";
$areanames{en}->{613531791} = "Buninyong";
$areanames{en}->{613531792} = "Buninyong";
$areanames{en}->{613531793} = "Buninyong";
$areanames{en}->{613531794} = "Buninyong";
$areanames{en}->{613531797} = "Buninyong";
$areanames{en}->{613531800} = "Creswick";
$areanames{en}->{613531801} = "Creswick";
$areanames{en}->{613531802} = "Creswick";
$areanames{en}->{613531803} = "Creswick";
$areanames{en}->{613531804} = "Creswick";
$areanames{en}->{613531807} = "Creswick";
$areanames{en}->{613531808} = "Creswick";
$areanames{en}->{613531810} = "Daylesford";
$areanames{en}->{613531811} = "Daylesford";
$areanames{en}->{613531812} = "Daylesford";
$areanames{en}->{613531813} = "Daylesford";
$areanames{en}->{613531814} = "Daylesford";
$areanames{en}->{613531817} = "Daylesford";
$areanames{en}->{613531820} = "Learmonth";
$areanames{en}->{613531821} = "Learmonth";
$areanames{en}->{613531822} = "Learmonth";
$areanames{en}->{613531823} = "Learmonth";
$areanames{en}->{613531827} = "Learmonth";
$areanames{en}->{613531830} = "Linton";
$areanames{en}->{613531831} = "Linton";
$areanames{en}->{613531832} = "Linton";
$areanames{en}->{613531833} = "Linton";
$areanames{en}->{613531837} = "Linton";
$areanames{en}->{613531840} = "Rokewood";
$areanames{en}->{613531841} = "Rokewood";
$areanames{en}->{613531842} = "Rokewood";
$areanames{en}->{613531843} = "Rokewood";
$areanames{en}->{613531847} = "Rokewood";
$areanames{en}->{613531850} = "Scarsdale";
$areanames{en}->{613531851} = "Scarsdale";
$areanames{en}->{613531852} = "Scarsdale";
$areanames{en}->{613531853} = "Scarsdale";
$areanames{en}->{613531854} = "Scarsdale";
$areanames{en}->{613531857} = "Scarsdale";
$areanames{en}->{613531858} = "Scarsdale";
$areanames{en}->{613531860} = "Skipton";
$areanames{en}->{613531861} = "Skipton";
$areanames{en}->{613531862} = "Skipton";
$areanames{en}->{613531863} = "Skipton";
$areanames{en}->{613531864} = "Skipton";
$areanames{en}->{613531867} = "Skipton";
$areanames{en}->{613531870} = "Stoneleigh";
$areanames{en}->{613531871} = "Stoneleigh";
$areanames{en}->{613531872} = "Stoneleigh";
$areanames{en}->{613531873} = "Stoneleigh";
$areanames{en}->{613531877} = "Stoneleigh";
$areanames{en}->{613531880} = "Bangerang";
$areanames{en}->{613531881} = "Bangerang";
$areanames{en}->{613531882} = "Bangerang";
$areanames{en}->{613531883} = "Bangerang";
$areanames{en}->{613531887} = "Bangerang";
$areanames{en}->{613531890} = "Banyena";
$areanames{en}->{613531891} = "Banyena";
$areanames{en}->{613531892} = "Banyena";
$areanames{en}->{613531893} = "Banyena";
$areanames{en}->{613531897} = "Banyena";
$areanames{en}->{613531900} = "Beulah";
$areanames{en}->{613531901} = "Beulah";
$areanames{en}->{613531902} = "Beulah";
$areanames{en}->{613531903} = "Beulah";
$areanames{en}->{613531907} = "Beulah";
$areanames{en}->{613531910} = "Clear\ Lake";
$areanames{en}->{613531911} = "Clear\ Lake";
$areanames{en}->{613531912} = "Clear\ Lake";
$areanames{en}->{613531913} = "Clear\ Lake";
$areanames{en}->{613531917} = "Clear\ Lake";
$areanames{en}->{613531920} = "Crymelon";
$areanames{en}->{613531921} = "Crymelon";
$areanames{en}->{613531922} = "Crymelon";
$areanames{en}->{613531923} = "Crymelon";
$areanames{en}->{613531927} = "Crymelon";
$areanames{en}->{613531930} = "Dimboola";
$areanames{en}->{613531931} = "Dimboola";
$areanames{en}->{613531932} = "Dimboola";
$areanames{en}->{613531933} = "Dimboola";
$areanames{en}->{613531937} = "Dimboola";
$areanames{en}->{613531940} = "Gerang\ Gerung";
$areanames{en}->{613531941} = "Gerang\ Gerung";
$areanames{en}->{613531942} = "Gerang\ Gerung";
$areanames{en}->{613531943} = "Gerang\ Gerung";
$areanames{en}->{613531947} = "Gerang\ Gerung";
$areanames{en}->{613531950} = "Glenisla";
$areanames{en}->{613531951} = "Glenisla";
$areanames{en}->{613531952} = "Glenisla";
$areanames{en}->{613531953} = "Glenisla";
$areanames{en}->{613531957} = "Glenisla";
$areanames{en}->{613531960} = "Goroke";
$areanames{en}->{613531961} = "Goroke";
$areanames{en}->{613531962} = "Goroke";
$areanames{en}->{613531963} = "Goroke";
$areanames{en}->{613531967} = "Goroke";
$areanames{en}->{613531970} = "Horsham";
$areanames{en}->{613531971} = "Horsham";
$areanames{en}->{613531972} = "Horsham";
$areanames{en}->{613531973} = "Horsham";
$areanames{en}->{613531974} = "Horsham";
$areanames{en}->{613531977} = "Horsham";
$areanames{en}->{613531980} = "Jeparit";
$areanames{en}->{613531981} = "Jeparit";
$areanames{en}->{613531982} = "Jeparit";
$areanames{en}->{613531983} = "Jeparit";
$areanames{en}->{613531987} = "Jeparit";
$areanames{en}->{613531990} = "Kalkee";
$areanames{en}->{613531991} = "Kalkee";
$areanames{en}->{613531992} = "Kalkee";
$areanames{en}->{613531993} = "Kalkee";
$areanames{en}->{613531997} = "Kalkee";
$areanames{en}->{6135320} = "Ballarat";
$areanames{en}->{61353210} = "Buninyong";
$areanames{en}->{61353211} = "Scarsdale";
$areanames{en}->{61353212} = "Learmonth";
$areanames{en}->{61353213} = "Linton";
$areanames{en}->{61353214} = "Creswick";
$areanames{en}->{61353215} = "Rokewood";
$areanames{en}->{61353216} = "Daylesford";
$areanames{en}->{61353217} = "Beaufort";
$areanames{en}->{61353218} = "Skipton";
$areanames{en}->{61353219} = "Stoneleigh";
$areanames{en}->{613532200} = "Laharum";
$areanames{en}->{613532201} = "Laharum";
$areanames{en}->{613532202} = "Laharum";
$areanames{en}->{613532203} = "Laharum";
$areanames{en}->{613532207} = "Laharum";
$areanames{en}->{613532210} = "Minimay";
$areanames{en}->{613532211} = "Minimay";
$areanames{en}->{613532212} = "Minimay";
$areanames{en}->{613532213} = "Minimay";
$areanames{en}->{613532217} = "Minimay";
$areanames{en}->{613532220} = "Minyip";
$areanames{en}->{613532221} = "Minyip";
$areanames{en}->{613532222} = "Minyip";
$areanames{en}->{613532223} = "Minyip";
$areanames{en}->{613532227} = "Minyip";
$areanames{en}->{613532230} = "Murtoa";
$areanames{en}->{613532231} = "Murtoa";
$areanames{en}->{613532232} = "Murtoa";
$areanames{en}->{613532233} = "Murtoa";
$areanames{en}->{613532234} = "Murtoa";
$areanames{en}->{613532237} = "Murtoa";
$areanames{en}->{61353224} = "Ballarat";
$areanames{en}->{61353225} = "Ballarat";
$areanames{en}->{613532260} = "Rainbow";
$areanames{en}->{613532261} = "Rainbow";
$areanames{en}->{613532262} = "Rainbow";
$areanames{en}->{613532263} = "Rainbow";
$areanames{en}->{613532267} = "Rainbow";
$areanames{en}->{613532270} = "Warracknabeal";
$areanames{en}->{613532271} = "Warracknabeal";
$areanames{en}->{613532272} = "Warracknabeal";
$areanames{en}->{613532273} = "Warracknabeal";
$areanames{en}->{613532274} = "Warracknabeal";
$areanames{en}->{613532277} = "Warracknabeal";
$areanames{en}->{613532280} = "Wilkur";
$areanames{en}->{613532281} = "Wilkur";
$areanames{en}->{613532282} = "Wilkur";
$areanames{en}->{613532283} = "Wilkur";
$areanames{en}->{613532287} = "Wilkur";
$areanames{en}->{613532290} = "Yaapeet";
$areanames{en}->{613532291} = "Yaapeet";
$areanames{en}->{613532292} = "Yaapeet";
$areanames{en}->{613532293} = "Yaapeet";
$areanames{en}->{613532297} = "Yaapeet";
$areanames{en}->{613532300} = "Bacchus\ Marsh";
$areanames{en}->{613532301} = "Bacchus\ Marsh";
$areanames{en}->{613532302} = "Bacchus\ Marsh";
$areanames{en}->{613532303} = "Bacchus\ Marsh";
$areanames{en}->{613532304} = "Bacchus\ Marsh";
$areanames{en}->{613532305} = "Bacchus\ Marsh";
$areanames{en}->{613532306} = "Bacchus\ Marsh";
$areanames{en}->{613532307} = "Bacchus\ Marsh";
$areanames{en}->{613532310} = "Ballan";
$areanames{en}->{613532311} = "Ballan";
$areanames{en}->{613532312} = "Ballan";
$areanames{en}->{613532313} = "Ballan";
$areanames{en}->{613532314} = "Ballan";
$areanames{en}->{613532315} = "Ballan";
$areanames{en}->{613532316} = "Ballan";
$areanames{en}->{613532317} = "Ballan";
$areanames{en}->{613532320} = "Balliang";
$areanames{en}->{613532321} = "Balliang";
$areanames{en}->{613532322} = "Balliang";
$areanames{en}->{613532323} = "Balliang";
$areanames{en}->{613532324} = "Balliang";
$areanames{en}->{613532325} = "Balliang";
$areanames{en}->{613532326} = "Balliang";
$areanames{en}->{613532327} = "Balliang";
$areanames{en}->{613532330} = "Mount\ Wallace";
$areanames{en}->{613532331} = "Mount\ Wallace";
$areanames{en}->{613532332} = "Mount\ Wallace";
$areanames{en}->{613532333} = "Mount\ Wallace";
$areanames{en}->{613532334} = "Mount\ Wallace";
$areanames{en}->{613532335} = "Mount\ Wallace";
$areanames{en}->{613532336} = "Mount\ Wallace";
$areanames{en}->{613532337} = "Mount\ Wallace";
$areanames{en}->{613532340} = "Broughton";
$areanames{en}->{613532341} = "Broughton";
$areanames{en}->{613532342} = "Broughton";
$areanames{en}->{613532343} = "Broughton";
$areanames{en}->{613532347} = "Broughton";
$areanames{en}->{613532350} = "Kaniva";
$areanames{en}->{613532351} = "Kaniva";
$areanames{en}->{613532352} = "Kaniva";
$areanames{en}->{613532353} = "Kaniva";
$areanames{en}->{613532357} = "Kaniva";
$areanames{en}->{613532360} = "Lorquon";
$areanames{en}->{613532361} = "Lorquon";
$areanames{en}->{613532362} = "Lorquon";
$areanames{en}->{613532363} = "Lorquon";
$areanames{en}->{613532367} = "Lorquon";
$areanames{en}->{613532370} = "Nhill";
$areanames{en}->{613532371} = "Nhill";
$areanames{en}->{613532372} = "Nhill";
$areanames{en}->{613532373} = "Nhill";
$areanames{en}->{613532374} = "Nhill";
$areanames{en}->{613532377} = "Nhill";
$areanames{en}->{613532380} = "Serviceton";
$areanames{en}->{613532381} = "Serviceton";
$areanames{en}->{613532382} = "Serviceton";
$areanames{en}->{613532383} = "Serviceton";
$areanames{en}->{613532387} = "Serviceton";
$areanames{en}->{613532390} = "Telopea\ Downs";
$areanames{en}->{613532391} = "Telopea\ Downs";
$areanames{en}->{613532392} = "Telopea\ Downs";
$areanames{en}->{613532393} = "Telopea\ Downs";
$areanames{en}->{613532397} = "Telopea\ Downs";
$areanames{en}->{613532400} = "Natimuk";
$areanames{en}->{613532401} = "Natimuk";
$areanames{en}->{613532402} = "Natimuk";
$areanames{en}->{613532403} = "Natimuk";
$areanames{en}->{613532407} = "Natimuk";
$areanames{en}->{613532410} = "Polkemmet";
$areanames{en}->{613532411} = "Polkemmet";
$areanames{en}->{613532412} = "Polkemmet";
$areanames{en}->{613532413} = "Polkemmet";
$areanames{en}->{613532417} = "Polkemmet";
$areanames{en}->{61353242} = "Ballarat";
$areanames{en}->{61353243} = "Ararat";
$areanames{en}->{61353244} = "Ararat";
$areanames{en}->{61353245} = "Buangor";
$areanames{en}->{61353246} = "Dadswells\ Bridge";
$areanames{en}->{61353247} = "Elmhurst";
$areanames{en}->{61353248} = "Glenorchy";
$areanames{en}->{61353249} = "Halls\ Gap";
$areanames{en}->{61353250} = "Lake\ Bolac";
$areanames{en}->{61353251} = "Landsborough";
$areanames{en}->{61353252} = "Marnoo";
$areanames{en}->{61353253} = "Navarre";
$areanames{en}->{61353254} = "Streatham";
$areanames{en}->{61353255} = "Willaura";
$areanames{en}->{61353256} = "Creswick";
$areanames{en}->{61353257} = "Daylesford";
$areanames{en}->{61353258} = "Linton";
$areanames{en}->{61353259} = "Rokewood";
$areanames{en}->{61353260} = "Ballarat";
$areanames{en}->{61353261} = "Ballarat";
$areanames{en}->{61353262} = "Scarsdale";
$areanames{en}->{61353263} = "Stoneleigh";
$areanames{en}->{61353264} = "Bangerang";
$areanames{en}->{61353265} = "Banyena";
$areanames{en}->{61353266} = "Beulah";
$areanames{en}->{61353267} = "Clear\ Lake";
$areanames{en}->{61353268} = "Crymelon";
$areanames{en}->{61353269} = "Dimboola";
$areanames{en}->{6135327} = "Ballarat";
$areanames{en}->{61353280} = "Gerang\ Gerung";
$areanames{en}->{61353281} = "Glenisla";
$areanames{en}->{61353282} = "Goroke";
$areanames{en}->{61353283} = "Jeparit";
$areanames{en}->{61353284} = "Kalkee";
$areanames{en}->{61353285} = "Laharum";
$areanames{en}->{61353286} = "Minimay";
$areanames{en}->{61353287} = "Minyip";
$areanames{en}->{61353288} = "Murtoa";
$areanames{en}->{61353289} = "Natimuk";
$areanames{en}->{6135329} = "Ballarat";
$areanames{en}->{613533} = "Ballarat";
$areanames{en}->{61353400} = "Ballarat";
$areanames{en}->{61353401} = "Skipton";
$areanames{en}->{61353402} = "Skipton";
$areanames{en}->{61353403} = "Rokewood";
$areanames{en}->{61353404} = "Polkemmet";
$areanames{en}->{61353405} = "Stoneleigh";
$areanames{en}->{61353406} = "Stoneleigh";
$areanames{en}->{61353407} = "Stoneleigh";
$areanames{en}->{61353408} = "Skipton";
$areanames{en}->{61353409} = "Rainbow";
$areanames{en}->{6135341} = "Buninyong";
$areanames{en}->{6135342} = "Scarsdale";
$areanames{en}->{61353426} = "Ballarat";
$areanames{en}->{61353429} = "Ballarat";
$areanames{en}->{6135343} = "Learmonth";
$areanames{en}->{6135344} = "Linton";
$areanames{en}->{6135345} = "Creswick";
$areanames{en}->{6135346} = "Rokewood";
$areanames{en}->{61353470} = "Horsham";
$areanames{en}->{61353471} = "Buangor";
$areanames{en}->{61353472} = "Buangor";
$areanames{en}->{61353473} = "Dadswells\ Bridge";
$areanames{en}->{61353474} = "Dadswells\ Bridge";
$areanames{en}->{61353475} = "Elmhurst";
$areanames{en}->{61353476} = "Elmhurst";
$areanames{en}->{61353477} = "Glenorchy";
$areanames{en}->{61353478} = "Glenorchy";
$areanames{en}->{61353479} = "Ballarat";
$areanames{en}->{6135348} = "Daylesford";
$areanames{en}->{6135349} = "Beaufort";
$areanames{en}->{61353500} = "Telopea\ Downs";
$areanames{en}->{61353501} = "Lake\ Bolac";
$areanames{en}->{61353502} = "Lake\ Bolac";
$areanames{en}->{61353503} = "Lake\ Bolac";
$areanames{en}->{61353504} = "Lake\ Bolac";
$areanames{en}->{61353505} = "Lake\ Bolac";
$areanames{en}->{61353506} = "Streatham";
$areanames{en}->{61353507} = "Streatham";
$areanames{en}->{61353508} = "Streatham";
$areanames{en}->{61353509} = "Streatham";
$areanames{en}->{6135351} = "Ararat";
$areanames{en}->{6135352} = "Ararat";
$areanames{en}->{61353530} = "Warracknabeal";
$areanames{en}->{61353531} = "Wilkur";
$areanames{en}->{61353532} = "Yaapeet";
$areanames{en}->{61353533} = "Ballan";
$areanames{en}->{61353534} = "Mount\ Wallace";
$areanames{en}->{61353535} = "Broughton";
$areanames{en}->{61353536} = "Kaniva";
$areanames{en}->{61353537} = "Lorquon";
$areanames{en}->{61353538} = "Nhill";
$areanames{en}->{61353539} = "Serviceton";
$areanames{en}->{61353540} = "Maroona";
$areanames{en}->{61353541} = "Willaura";
$areanames{en}->{61353542} = "Moyston";
$areanames{en}->{61353543} = "Buangor";
$areanames{en}->{61353544} = "Buangor";
$areanames{en}->{61353545} = "Buangor";
$areanames{en}->{61353546} = "Moyston";
$areanames{en}->{61353547} = "Maroona";
$areanames{en}->{61353548} = "Elmhurst";
$areanames{en}->{61353549} = "Elmhurst";
$areanames{en}->{61353550} = "Ararat";
$areanames{en}->{61353551} = "Ararat";
$areanames{en}->{61353552} = "Ararat";
$areanames{en}->{61353553} = "Ararat";
$areanames{en}->{61353554} = "Moyston";
$areanames{en}->{61353555} = "Elmhurst";
$areanames{en}->{61353556} = "Buangor";
$areanames{en}->{61353557} = "Maroona";
$areanames{en}->{61353558} = "Lake\ Bolac";
$areanames{en}->{61353559} = "Streatham";
$areanames{en}->{6135356} = "Halls\ Gap";
$areanames{en}->{61353560} = "Telopea\ Downs";
$areanames{en}->{61353561} = "Buninyong";
$areanames{en}->{61353562} = "Stawell";
$areanames{en}->{61353569} = "Landsborough";
$areanames{en}->{6135357} = "Navarre";
$areanames{en}->{6135358} = "Stawell";
$areanames{en}->{61353590} = "Glenorchy";
$areanames{en}->{61353591} = "Ballarat";
$areanames{en}->{61353592} = "Marnoo";
$areanames{en}->{61353593} = "Marnoo";
$areanames{en}->{61353594} = "Buangor";
$areanames{en}->{61353595} = "Dadswells\ Bridge";
$areanames{en}->{61353596} = "Dadswells\ Bridge";
$areanames{en}->{61353597} = "Dadswells\ Bridge";
$areanames{en}->{61353598} = "Glenorchy";
$areanames{en}->{61353599} = "Glenorchy";
$areanames{en}->{6135360} = "Mount\ Wallace";
$areanames{en}->{61353610} = "Stawell";
$areanames{en}->{61353611} = "Stawell";
$areanames{en}->{61353612} = "Stawell";
$areanames{en}->{61353613} = "Stawell";
$areanames{en}->{61353614} = "Halls\ Gap";
$areanames{en}->{61353615} = "Landsborough";
$areanames{en}->{61353616} = "Navarre";
$areanames{en}->{61353617} = "Marnoo";
$areanames{en}->{61353618} = "Dadswells\ Bridge";
$areanames{en}->{61353619} = "Glenorchy";
$areanames{en}->{6135362} = "Horsham";
$areanames{en}->{61353627} = "Kalkee";
$areanames{en}->{61353628} = "Laharum";
$areanames{en}->{61353629} = "Banyena";
$areanames{en}->{61353630} = "Murtoa";
$areanames{en}->{61353631} = "Minyip";
$areanames{en}->{61353632} = "Goroke";
$areanames{en}->{61353633} = "Minimay";
$areanames{en}->{61353634} = "Natimuk";
$areanames{en}->{61353635} = "Polkemmet";
$areanames{en}->{61353636} = "Clear\ Lake";
$areanames{en}->{61353637} = "Dimboola";
$areanames{en}->{61353638} = "Gerang\ Gerung";
$areanames{en}->{61353639} = "Glenisla";
$areanames{en}->{61353640} = "Kaniva";
$areanames{en}->{61353641} = "Kaniva";
$areanames{en}->{61353642} = "Ballarat";
$areanames{en}->{61353643} = "Landsborough";
$areanames{en}->{61353644} = "Landsborough";
$areanames{en}->{61353645} = "Maroona";
$areanames{en}->{61353646} = "Maroona";
$areanames{en}->{61353647} = "Moyston";
$areanames{en}->{61353648} = "Moyston";
$areanames{en}->{61353649} = "Ballarat";
$areanames{en}->{61353650} = "Nhill";
$areanames{en}->{61353651} = "Nhill";
$areanames{en}->{61353652} = "Nhill";
$areanames{en}->{61353653} = "Nhill";
$areanames{en}->{61353654} = "Nhill";
$areanames{en}->{61353655} = "Lorquon";
$areanames{en}->{61353656} = "Kaniva";
$areanames{en}->{61353657} = "Broughton";
$areanames{en}->{61353658} = "Serviceton";
$areanames{en}->{61353659} = "Telopea\ Downs";
$areanames{en}->{6135366} = "Bacchus\ Marsh";
$areanames{en}->{61353667} = "Ballan";
$areanames{en}->{61353668} = "Balliang";
$areanames{en}->{61353669} = "Mount\ Wallace";
$areanames{en}->{6135367} = "Bacchus\ Marsh";
$areanames{en}->{6135368} = "Ballan";
$areanames{en}->{6135369} = "Balliang";
$areanames{en}->{61353700} = "Yaapeet";
$areanames{en}->{61353701} = "Bacchus\ Marsh";
$areanames{en}->{61353702} = "Ballan";
$areanames{en}->{61353703} = "Balliang";
$areanames{en}->{61353704} = "Mount\ Wallace";
$areanames{en}->{61353705} = "Broughton";
$areanames{en}->{61353706} = "Kaniva";
$areanames{en}->{61353707} = "Lorquon";
$areanames{en}->{61353708} = "Nhill";
$areanames{en}->{61353709} = "Serviceton";
$areanames{en}->{61353710} = "Kalkee";
$areanames{en}->{61353711} = "Laharum";
$areanames{en}->{61353712} = "Minimay";
$areanames{en}->{61353713} = "Minyip";
$areanames{en}->{61353714} = "Murtoa";
$areanames{en}->{61353715} = "Natimuk";
$areanames{en}->{61353716} = "Polkemmet";
$areanames{en}->{61353717} = "Rainbow";
$areanames{en}->{61353718} = "Warracknabeal";
$areanames{en}->{61353719} = "Wilkur";
$areanames{en}->{61353720} = "Banyena";
$areanames{en}->{61353721} = "Beulah";
$areanames{en}->{61353722} = "Clear\ Lake";
$areanames{en}->{61353723} = "Crymelon";
$areanames{en}->{61353724} = "Dimboola";
$areanames{en}->{61353725} = "Gerang\ Gerung";
$areanames{en}->{61353726} = "Glenisla";
$areanames{en}->{61353727} = "Goroke";
$areanames{en}->{61353728} = "Horsham";
$areanames{en}->{61353729} = "Jeparit";
$areanames{en}->{61353730} = "Bangerang";
$areanames{en}->{61353731} = "Stoneleigh";
$areanames{en}->{61353732} = "Skipton";
$areanames{en}->{61353733} = "Scarsdale";
$areanames{en}->{61353734} = "Daylesford";
$areanames{en}->{61353735} = "Learmonth";
$areanames{en}->{61353736} = "Linton";
$areanames{en}->{61353737} = "Rokewood";
$areanames{en}->{61353738} = "Creswick";
$areanames{en}->{61353739} = "Willaura";
$areanames{en}->{61353740} = "Ballarat";
$areanames{en}->{61353741} = "Beaufort";
$areanames{en}->{61353742} = "Buninyong";
$areanames{en}->{61353743} = "Streatham";
$areanames{en}->{61353744} = "Maroona";
$areanames{en}->{61353745} = "Moyston";
$areanames{en}->{61353746} = "Navarre";
$areanames{en}->{61353747} = "Stawell";
$areanames{en}->{61353748} = "Landsborough";
$areanames{en}->{61353749} = "Marnoo";
$areanames{en}->{61353750} = "Glenorchy";
$areanames{en}->{61353751} = "Halls\ Gap";
$areanames{en}->{61353752} = "Lake\ Bolac";
$areanames{en}->{61353753} = "Dadswells\ Bridge";
$areanames{en}->{61353754} = "Elmhurst";
$areanames{en}->{61353755} = "Ararat";
$areanames{en}->{61353756} = "Buangor";
$areanames{en}->{61353757} = "Navarre";
$areanames{en}->{61353758} = "Navarre";
$areanames{en}->{61353759} = "Streatham";
$areanames{en}->{61353760} = "Streatham";
$areanames{en}->{61353761} = "Stawell";
$areanames{en}->{61353762} = "Stawell";
$areanames{en}->{61353763} = "Willaura";
$areanames{en}->{61353764} = "Willaura";
$areanames{en}->{61353765} = "Ballarat";
$areanames{en}->{61353766} = "Ballarat";
$areanames{en}->{61353767} = "Beaufort";
$areanames{en}->{61353768} = "Beaufort";
$areanames{en}->{61353769} = "Buninyong";
$areanames{en}->{61353770} = "Buninyong";
$areanames{en}->{61353771} = "Creswick";
$areanames{en}->{61353772} = "Creswick";
$areanames{en}->{61353773} = "Daylesford";
$areanames{en}->{61353774} = "Daylesford";
$areanames{en}->{61353775} = "Learmonth";
$areanames{en}->{61353776} = "Learmonth";
$areanames{en}->{61353777} = "Linton";
$areanames{en}->{61353778} = "Linton";
$areanames{en}->{61353779} = "Rokewood";
$areanames{en}->{61353780} = "Rokewood";
$areanames{en}->{61353781} = "Scarsdale";
$areanames{en}->{61353782} = "Scarsdale";
$areanames{en}->{61353783} = "Skipton";
$areanames{en}->{61353784} = "Skipton";
$areanames{en}->{61353785} = "Stoneleigh";
$areanames{en}->{61353786} = "Stoneleigh";
$areanames{en}->{61353787} = "Bangerang";
$areanames{en}->{61353788} = "Bangerang";
$areanames{en}->{61353789} = "Dimboola";
$areanames{en}->{61353790} = "Dimboola";
$areanames{en}->{61353791} = "Glenisla";
$areanames{en}->{61353792} = "Glenisla";
$areanames{en}->{61353793} = "Horsham";
$areanames{en}->{61353794} = "Horsham";
$areanames{en}->{61353795} = "Kalkee";
$areanames{en}->{61353796} = "Kalkee";
$areanames{en}->{61353797} = "Laharum";
$areanames{en}->{61353798} = "Laharum";
$areanames{en}->{61353799} = "Ballarat";
$areanames{en}->{6135380} = "Glenisla";
$areanames{en}->{61353808} = "Banyena";
$areanames{en}->{61353809} = "Banyena";
$areanames{en}->{6135381} = "Horsham";
$areanames{en}->{6135382} = "Horsham";
$areanames{en}->{61353830} = "Ballarat";
$areanames{en}->{61353831} = "Kalkee";
$areanames{en}->{61353832} = "Kalkee";
$areanames{en}->{61353833} = "Kalkee";
$areanames{en}->{61353834} = "Kalkee";
$areanames{en}->{61353835} = "Laharum";
$areanames{en}->{61353836} = "Laharum";
$areanames{en}->{61353837} = "Laharum";
$areanames{en}->{61353838} = "Laharum";
$areanames{en}->{61353839} = "Laharum";
$areanames{en}->{6135384} = "Horsham";
$areanames{en}->{61353841} = "Ararat";
$areanames{en}->{61353845} = "Ballarat";
$areanames{en}->{61353849} = "Ararat";
$areanames{en}->{6135385} = "Murtoa";
$areanames{en}->{61353856} = "Minyip";
$areanames{en}->{61353857} = "Minyip";
$areanames{en}->{61353858} = "Minyip";
$areanames{en}->{61353859} = "Minyip";
$areanames{en}->{6135386} = "Goroke";
$areanames{en}->{61353866} = "Minimay";
$areanames{en}->{61353867} = "Minimay";
$areanames{en}->{61353868} = "Minimay";
$areanames{en}->{61353869} = "Minimay";
$areanames{en}->{61353870} = "Polkemmet";
$areanames{en}->{61353871} = "Natimuk";
$areanames{en}->{61353872} = "Natimuk";
$areanames{en}->{61353873} = "Dimboola";
$areanames{en}->{61353874} = "Natimuk";
$areanames{en}->{61353875} = "Nhill";
$areanames{en}->{61353876} = "Nhill";
$areanames{en}->{61353877} = "Bacchus\ Marsh";
$areanames{en}->{61353878} = "Bacchus\ Marsh";
$areanames{en}->{61353879} = "Nhill";
$areanames{en}->{6135388} = "Clear\ Lake";
$areanames{en}->{61353890} = "Dimboola";
$areanames{en}->{61353891} = "Dimboola";
$areanames{en}->{61353892} = "Dimboola";
$areanames{en}->{61353893} = "Dimboola";
$areanames{en}->{61353894} = "Dimboola";
$areanames{en}->{61353895} = "Warracknabeal";
$areanames{en}->{61353896} = "Warracknabeal";
$areanames{en}->{61353897} = "Wilkur";
$areanames{en}->{61353898} = "Wilkur";
$areanames{en}->{61353899} = "Gerang\ Gerung";
$areanames{en}->{61353900} = "Crymelon";
$areanames{en}->{61353901} = "Bacchus\ Marsh";
$areanames{en}->{61353902} = "Beulah";
$areanames{en}->{61353903} = "Beulah";
$areanames{en}->{61353904} = "Beulah";
$areanames{en}->{61353905} = "Polkemmet";
$areanames{en}->{61353906} = "Polkemmet";
$areanames{en}->{61353907} = "Ballan";
$areanames{en}->{61353908} = "Ballan";
$areanames{en}->{61353909} = "Crymelon";
$areanames{en}->{61353910} = "Lorquon";
$areanames{en}->{61353911} = "Nhill";
$areanames{en}->{61353912} = "Nhill";
$areanames{en}->{61353913} = "Nhill";
$areanames{en}->{61353914} = "Nhill";
$areanames{en}->{61353915} = "Nhill";
$areanames{en}->{61353916} = "Lake\ Bolac";
$areanames{en}->{61353917} = "Lake\ Bolac";
$areanames{en}->{61353918} = "Lorquon";
$areanames{en}->{61353919} = "Lorquon";
$areanames{en}->{61353920} = "Broughton";
$areanames{en}->{61353921} = "Ballarat";
$areanames{en}->{61353922} = "Kaniva";
$areanames{en}->{61353923} = "Kaniva";
$areanames{en}->{61353924} = "Murtoa";
$areanames{en}->{61353925} = "Murtoa";
$areanames{en}->{61353926} = "Nhill";
$areanames{en}->{61353927} = "Kaniva";
$areanames{en}->{61353928} = "Broughton";
$areanames{en}->{61353929} = "Broughton";
$areanames{en}->{61353930} = "Serviceton";
$areanames{en}->{61353931} = "Serviceton";
$areanames{en}->{61353932} = "Serviceton";
$areanames{en}->{61353933} = "Serviceton";
$areanames{en}->{61353934} = "Serviceton";
$areanames{en}->{61353935} = "Nhill";
$areanames{en}->{61353936} = "Telopea\ Downs";
$areanames{en}->{61353937} = "Telopea\ Downs";
$areanames{en}->{61353938} = "Telopea\ Downs";
$areanames{en}->{61353939} = "Telopea\ Downs";
$areanames{en}->{6135394} = "Warracknabeal";
$areanames{en}->{61353950} = "Serviceton";
$areanames{en}->{61353951} = "Rainbow";
$areanames{en}->{61353952} = "Rainbow";
$areanames{en}->{61353953} = "Creswick";
$areanames{en}->{61353954} = "Rainbow";
$areanames{en}->{61353955} = "Horsham";
$areanames{en}->{61353956} = "Yaapeet";
$areanames{en}->{61353957} = "Yaapeet";
$areanames{en}->{61353958} = "Natimuk";
$areanames{en}->{61353959} = "Natimuk";
$areanames{en}->{61353960} = "Warracknabeal";
$areanames{en}->{61353961} = "Warracknabeal";
$areanames{en}->{61353962} = "Warracknabeal";
$areanames{en}->{61353963} = "Rainbow";
$areanames{en}->{61353964} = "Yaapeet";
$areanames{en}->{61353965} = "Jeparit";
$areanames{en}->{61353966} = "Bangerang";
$areanames{en}->{61353967} = "Wilkur";
$areanames{en}->{61353968} = "Beulah";
$areanames{en}->{61353969} = "Crymelon";
$areanames{en}->{6135397} = "Jeparit";
$areanames{en}->{6135398} = "Warracknabeal";
$areanames{en}->{61353990} = "Wilkur";
$areanames{en}->{61353991} = "Bangerang";
$areanames{en}->{61353992} = "Bangerang";
$areanames{en}->{61353993} = "Bangerang";
$areanames{en}->{61353994} = "Bangerang";
$areanames{en}->{61353995} = "Bangerang";
$areanames{en}->{61353996} = "Serviceton";
$areanames{en}->{61353997} = "Wilkur";
$areanames{en}->{61353998} = "Balliang";
$areanames{en}->{61353999} = "Balliang";
$areanames{en}->{61354000} = "Bendigo";
$areanames{en}->{61354001} = "Bendigo";
$areanames{en}->{61354002} = "Bendigo";
$areanames{en}->{61354003} = "Amphitheatre";
$areanames{en}->{61354004} = "Avoca";
$areanames{en}->{61354005} = "Barham";
$areanames{en}->{61354006} = "Bealiba";
$areanames{en}->{61354007} = "Beazleys\ Bridge";
$areanames{en}->{61354008} = "Birchip";
$areanames{en}->{61354009} = "Boort";
$areanames{en}->{61354010} = "Bridgewater";
$areanames{en}->{61354011} = "Buckrabanyule";
$areanames{en}->{61354012} = "Carisbrook";
$areanames{en}->{61354013} = "Castlemaine";
$areanames{en}->{61354014} = "Charlton";
$areanames{en}->{61354015} = "Cohuna";
$areanames{en}->{61354016} = "Colbinabbin";
$areanames{en}->{61354017} = "Dingee";
$areanames{en}->{61354018} = "Donald";
$areanames{en}->{61354019} = "Dunolly";
$areanames{en}->{61354020} = "Echuca";
$areanames{en}->{61354021} = "Elmore";
$areanames{en}->{61354022} = "Gisborne";
$areanames{en}->{61354023} = "Goornong";
$areanames{en}->{61354024} = "Gowar\ East";
$areanames{en}->{61354025} = "Gunbower";
$areanames{en}->{61354026} = "Harcourt";
$areanames{en}->{61354027} = "Heathcote";
$areanames{en}->{61354028} = "Inglewood";
$areanames{en}->{61354029} = "Jarklin";
$areanames{en}->{61354030} = "Kerang";
$areanames{en}->{61354031} = "Korong\ Vale";
$areanames{en}->{61354032} = "Kyneton";
$areanames{en}->{61354033} = "Laen";
$areanames{en}->{61354034} = "Lake\ Meran";
$areanames{en}->{61354035} = "Lalbert";
$areanames{en}->{61354036} = "Llanelly";
$areanames{en}->{61354037} = "Lockington";
$areanames{en}->{61354038} = "Logan";
$areanames{en}->{61354039} = "Maldon";
$areanames{en}->{61354040} = "Marong";
$areanames{en}->{61354041} = "Maryborough";
$areanames{en}->{61354042} = "Mitiamo";
$areanames{en}->{61354043} = "Moonambel";
$areanames{en}->{61354044} = "Murrabit";
$areanames{en}->{61354045} = "Newstead";
$areanames{en}->{61354046} = "Nullawil";
$areanames{en}->{61354047} = "Pyramid\ Hill";
$areanames{en}->{61354048} = "Quambatook";
$areanames{en}->{61354049} = "Raywood";
$areanames{en}->{61354050} = "Redesdale";
$areanames{en}->{61354051} = "Rochester";
$areanames{en}->{61354052} = "Romsey";
$areanames{en}->{61354053} = "St\ Arnaud";
$areanames{en}->{61354054} = "Strathfieldsaye";
$areanames{en}->{61354055} = "Talbot";
$areanames{en}->{61354056} = "Tennyson";
$areanames{en}->{61354057} = "Traynors\ Lagoon";
$areanames{en}->{61354058} = "Trentham";
$areanames{en}->{61354059} = "Tullakool";
$areanames{en}->{6135406} = "Bendigo";
$areanames{en}->{61354070} = "Castlemaine";
$areanames{en}->{61354071} = "Bendigo";
$areanames{en}->{61354072} = "Bendigo";
$areanames{en}->{61354073} = "Echuca";
$areanames{en}->{61354074} = "Gisborne";
$areanames{en}->{61354075} = "Raywood";
$areanames{en}->{61354076} = "Watchem";
$areanames{en}->{61354077} = "Wedderburn";
$areanames{en}->{61354078} = "Womboota";
$areanames{en}->{61354079} = "Woodend";
$areanames{en}->{61354080} = "Wycheproof";
$areanames{en}->{61354081} = "Strathfieldsaye";
$areanames{en}->{61354082} = "Inglewood";
$areanames{en}->{61354083} = "Jarklin";
$areanames{en}->{61354084} = "Llanelly";
$areanames{en}->{61354085} = "Marong";
$areanames{en}->{61354086} = "Mitiamo";
$areanames{en}->{61354087} = "Goornong";
$areanames{en}->{61354088} = "Heathcote";
$areanames{en}->{61354089} = "Elmore";
$areanames{en}->{61354090} = "Dingee";
$areanames{en}->{61354091} = "Colbinabbin";
$areanames{en}->{61354092} = "Bendigo";
$areanames{en}->{61354093} = "Bridgewater";
$areanames{en}->{61354094} = "Wedderburn";
$areanames{en}->{61354095} = "Wycheproof";
$areanames{en}->{61354096} = "Traynors\ Lagoon";
$areanames{en}->{61354097} = "Watchem";
$areanames{en}->{61354098} = "St\ Arnaud";
$areanames{en}->{61354099} = "Logan";
$areanames{en}->{61354100} = "Bendigo";
$areanames{en}->{61354101} = "Bendigo";
$areanames{en}->{61354102} = "Bendigo";
$areanames{en}->{61354103} = "Nullawil";
$areanames{en}->{61354104} = "Beazleys\ Bridge";
$areanames{en}->{61354105} = "Bendigo\/Moonambel";
$areanames{en}->{613541053} = "Moonambel";
$areanames{en}->{61354106} = "Strathfieldsaye";
$areanames{en}->{613541074} = "Echuca";
$areanames{en}->{61354108} = "Kyneton";
$areanames{en}->{61354109} = "Redesdale";
$areanames{en}->{613541100} = "Bendigo";
$areanames{en}->{613541103} = "Bendigo";
$areanames{en}->{613541108} = "Bendigo";
$areanames{en}->{61354111} = "Castlemaine";
$areanames{en}->{61354112} = "Maryborough";
$areanames{en}->{61354113} = "Newstead";
$areanames{en}->{61354114} = "Trentham";
$areanames{en}->{61354115} = "Birchip";
$areanames{en}->{61354116} = "Buckrabanyule";
$areanames{en}->{61354117} = "Charlton";
$areanames{en}->{61354118} = "Donald";
$areanames{en}->{61354119} = "Gowar\ East";
$areanames{en}->{61354120} = "Korong\ Vale";
$areanames{en}->{61354121} = "Laen";
$areanames{en}->{61354122} = "Womboota";
$areanames{en}->{61354123} = "Lockington";
$areanames{en}->{61354124} = "Rochester";
$areanames{en}->{61354125} = "Tennyson";
$areanames{en}->{61354126} = "Echuca";
$areanames{en}->{61354127} = "Gunbower";
$areanames{en}->{61354128} = "Tullakool";
$areanames{en}->{61354129} = "Barham";
$areanames{en}->{61354130} = "Boort";
$areanames{en}->{61354131} = "Cohuna";
$areanames{en}->{61354132} = "Kerang";
$areanames{en}->{61354133} = "Lake\ Meran";
$areanames{en}->{61354134} = "Lalbert";
$areanames{en}->{61354135} = "Murrabit";
$areanames{en}->{61354136} = "Pyramid\ Hill";
$areanames{en}->{61354137} = "Quambatook";
$areanames{en}->{61354138} = "Gisborne";
$areanames{en}->{61354139} = "Kyneton";
$areanames{en}->{61354140} = "Gisborne";
$areanames{en}->{61354141} = "Gisborne";
$areanames{en}->{61354142} = "Gisborne";
$areanames{en}->{61354143} = "Gisborne";
$areanames{en}->{61354144} = "Redesdale";
$areanames{en}->{61354145} = "Romsey";
$areanames{en}->{61354146} = "Trentham";
$areanames{en}->{61354147} = "Woodend";
$areanames{en}->{61354148} = "Carisbrook";
$areanames{en}->{61354149} = "Castlemaine";
$areanames{en}->{61354150} = "Gisborne";
$areanames{en}->{61354151} = "Gisborne";
$areanames{en}->{61354152} = "Dunolly";
$areanames{en}->{61354153} = "Harcourt";
$areanames{en}->{61354154} = "Maldon";
$areanames{en}->{61354155} = "Maryborough";
$areanames{en}->{61354156} = "Moonambel";
$areanames{en}->{61354157} = "Newstead";
$areanames{en}->{61354158} = "Talbot";
$areanames{en}->{61354159} = "Amphitheatre";
$areanames{en}->{61354160} = "Carisbrook";
$areanames{en}->{61354161} = "Castlemaine";
$areanames{en}->{61354162} = "Dunolly";
$areanames{en}->{61354163} = "Harcourt";
$areanames{en}->{61354164} = "Maldon";
$areanames{en}->{61354165} = "Maryborough";
$areanames{en}->{61354166} = "Moonambel";
$areanames{en}->{61354167} = "Newstead";
$areanames{en}->{61354168} = "Talbot";
$areanames{en}->{61354169} = "Avoca";
$areanames{en}->{61354170} = "Tullakool";
$areanames{en}->{61354171} = "Gisborne";
$areanames{en}->{61354172} = "Kyneton";
$areanames{en}->{61354173} = "Redesdale";
$areanames{en}->{61354174} = "Romsey";
$areanames{en}->{61354175} = "Trentham";
$areanames{en}->{61354176} = "Woodend";
$areanames{en}->{61354177} = "Amphitheatre";
$areanames{en}->{61354178} = "Avoca";
$areanames{en}->{61354179} = "Bealiba";
$areanames{en}->{61354180} = "Womboota";
$areanames{en}->{61354181} = "Barham";
$areanames{en}->{61354182} = "Boort";
$areanames{en}->{61354183} = "Cohuna";
$areanames{en}->{61354184} = "Kerang";
$areanames{en}->{61354185} = "Lake\ Meran";
$areanames{en}->{61354186} = "Lalbert";
$areanames{en}->{61354187} = "Murrabit";
$areanames{en}->{61354188} = "Pyramid\ Hill";
$areanames{en}->{61354189} = "Quambatook";
$areanames{en}->{6135419} = "Kyneton";
$areanames{en}->{613542000} = "Colbinabbin";
$areanames{en}->{613542001} = "Colbinabbin";
$areanames{en}->{613542002} = "Colbinabbin";
$areanames{en}->{613542003} = "Colbinabbin";
$areanames{en}->{613542004} = "Colbinabbin";
$areanames{en}->{613542005} = "Castlemaine";
$areanames{en}->{613542008} = "Colbinabbin";
$areanames{en}->{613542010} = "Dingee";
$areanames{en}->{613542011} = "Dingee";
$areanames{en}->{613542012} = "Dingee";
$areanames{en}->{613542013} = "Dingee";
$areanames{en}->{613542014} = "Dingee";
$areanames{en}->{613542015} = "Echuca";
$areanames{en}->{613542018} = "Dingee";
$areanames{en}->{613542020} = "Elmore";
$areanames{en}->{613542021} = "Elmore";
$areanames{en}->{613542022} = "Elmore";
$areanames{en}->{613542023} = "Elmore";
$areanames{en}->{613542024} = "Elmore";
$areanames{en}->{613542025} = "Kyneton";
$areanames{en}->{613542028} = "Elmore";
$areanames{en}->{613542030} = "Goornong";
$areanames{en}->{613542031} = "Goornong";
$areanames{en}->{613542032} = "Goornong";
$areanames{en}->{613542033} = "Goornong";
$areanames{en}->{613542034} = "Goornong";
$areanames{en}->{613542035} = "Maryborough";
$areanames{en}->{613542038} = "Goornong";
$areanames{en}->{613542040} = "Heathcote";
$areanames{en}->{613542041} = "Heathcote";
$areanames{en}->{613542042} = "Heathcote";
$areanames{en}->{613542043} = "Heathcote";
$areanames{en}->{613542044} = "Heathcote";
$areanames{en}->{613542047} = "Heathcote";
$areanames{en}->{613542050} = "Inglewood";
$areanames{en}->{613542051} = "Inglewood";
$areanames{en}->{613542052} = "Inglewood";
$areanames{en}->{613542053} = "Inglewood";
$areanames{en}->{613542054} = "Inglewood";
$areanames{en}->{613542057} = "Inglewood";
$areanames{en}->{61354206} = "Gisborne";
$areanames{en}->{61354207} = "Gisborne";
$areanames{en}->{61354208} = "Gisborne";
$areanames{en}->{61354209} = "Gisborne";
$areanames{en}->{61354210} = "Kyneton";
$areanames{en}->{61354211} = "Kyneton";
$areanames{en}->{61354212} = "Kyneton";
$areanames{en}->{61354213} = "Kyneton";
$areanames{en}->{613542140} = "Jarklin";
$areanames{en}->{613542141} = "Jarklin";
$areanames{en}->{613542142} = "Jarklin";
$areanames{en}->{613542143} = "Jarklin";
$areanames{en}->{613542144} = "Jarklin";
$areanames{en}->{613542147} = "Jarklin";
$areanames{en}->{61354215} = "Woodend";
$areanames{en}->{61354216} = "Romsey";
$areanames{en}->{61354217} = "Trentham";
$areanames{en}->{613542180} = "Llanelly";
$areanames{en}->{613542181} = "Llanelly";
$areanames{en}->{613542182} = "Llanelly";
$areanames{en}->{613542183} = "Llanelly";
$areanames{en}->{613542184} = "Llanelly";
$areanames{en}->{613542187} = "Llanelly";
$areanames{en}->{61354219} = "Gisborne";
$areanames{en}->{61354220} = "Kyneton";
$areanames{en}->{61354221} = "Kyneton";
$areanames{en}->{61354222} = "Kyneton";
$areanames{en}->{61354223} = "Kyneton";
$areanames{en}->{613542240} = "Marong";
$areanames{en}->{613542241} = "Marong";
$areanames{en}->{613542242} = "Marong";
$areanames{en}->{613542243} = "Marong";
$areanames{en}->{613542244} = "Marong";
$areanames{en}->{613542247} = "Marong";
$areanames{en}->{613542250} = "Mitiamo";
$areanames{en}->{613542251} = "Mitiamo";
$areanames{en}->{613542252} = "Mitiamo";
$areanames{en}->{613542253} = "Mitiamo";
$areanames{en}->{613542254} = "Mitiamo";
$areanames{en}->{613542257} = "Mitiamo";
$areanames{en}->{61354226} = "Kyneton";
$areanames{en}->{61354227} = "Kyneton";
$areanames{en}->{61354228} = "Kyneton";
$areanames{en}->{61354229} = "Kyneton";
$areanames{en}->{613542300} = "Raywood";
$areanames{en}->{613542301} = "Raywood";
$areanames{en}->{613542302} = "Raywood";
$areanames{en}->{613542303} = "Raywood";
$areanames{en}->{613542304} = "Raywood";
$areanames{en}->{613542307} = "Raywood";
$areanames{en}->{613542310} = "Strathfieldsaye";
$areanames{en}->{613542311} = "Strathfieldsaye";
$areanames{en}->{613542312} = "Strathfieldsaye";
$areanames{en}->{613542313} = "Strathfieldsaye";
$areanames{en}->{613542314} = "Strathfieldsaye";
$areanames{en}->{61354232} = "Kyneton";
$areanames{en}->{61354233} = "Kyneton";
$areanames{en}->{61354234} = "Kyneton";
$areanames{en}->{61354235} = "Kyneton";
$areanames{en}->{613542360} = "Beazleys\ Bridge";
$areanames{en}->{613542361} = "Beazleys\ Bridge";
$areanames{en}->{613542362} = "Beazleys\ Bridge";
$areanames{en}->{613542363} = "Beazleys\ Bridge";
$areanames{en}->{613542364} = "Beazleys\ Bridge";
$areanames{en}->{613542367} = "Beazleys\ Bridge";
$areanames{en}->{61354237} = "Kyneton";
$areanames{en}->{613542380} = "Birchip";
$areanames{en}->{613542381} = "Birchip";
$areanames{en}->{613542382} = "Birchip";
$areanames{en}->{613542383} = "Birchip";
$areanames{en}->{613542384} = "Birchip";
$areanames{en}->{613542387} = "Birchip";
$areanames{en}->{61354239} = "Kyneton";
$areanames{en}->{6135424} = "Trentham";
$areanames{en}->{613542500} = "Buckrabanyule";
$areanames{en}->{613542501} = "Buckrabanyule";
$areanames{en}->{613542502} = "Buckrabanyule";
$areanames{en}->{613542503} = "Buckrabanyule";
$areanames{en}->{613542504} = "Buckrabanyule";
$areanames{en}->{613542507} = "Buckrabanyule";
$areanames{en}->{613542510} = "Charlton";
$areanames{en}->{613542511} = "Charlton";
$areanames{en}->{613542512} = "Charlton";
$areanames{en}->{613542513} = "Charlton";
$areanames{en}->{613542514} = "Charlton";
$areanames{en}->{613542517} = "Charlton";
$areanames{en}->{61354252} = "Bendigo";
$areanames{en}->{61354253} = "Redesdale";
$areanames{en}->{61354254} = "Redesdale";
$areanames{en}->{61354255} = "Redesdale";
$areanames{en}->{613542560} = "Gowar\ East";
$areanames{en}->{613542561} = "Gowar\ East";
$areanames{en}->{613542562} = "Gowar\ East";
$areanames{en}->{613542563} = "Gowar\ East";
$areanames{en}->{613542564} = "Gowar\ East";
$areanames{en}->{613542567} = "Gowar\ East";
$areanames{en}->{613542570} = "Korong\ Vale";
$areanames{en}->{613542571} = "Korong\ Vale";
$areanames{en}->{613542572} = "Korong\ Vale";
$areanames{en}->{613542573} = "Korong\ Vale";
$areanames{en}->{613542574} = "Korong\ Vale";
$areanames{en}->{613542577} = "Korong\ Vale";
$areanames{en}->{61354258} = "St\ Arnaud";
$areanames{en}->{613542590} = "Laen";
$areanames{en}->{613542591} = "Laen";
$areanames{en}->{613542592} = "Laen";
$areanames{en}->{613542593} = "Laen";
$areanames{en}->{613542594} = "Laen";
$areanames{en}->{613542597} = "Laen";
$areanames{en}->{613542600} = "Logan";
$areanames{en}->{613542601} = "Logan";
$areanames{en}->{613542602} = "Logan";
$areanames{en}->{613542603} = "Logan";
$areanames{en}->{613542604} = "Logan";
$areanames{en}->{613542607} = "Logan";
$areanames{en}->{61354261} = "Woodend";
$areanames{en}->{61354262} = "Woodend";
$areanames{en}->{61354263} = "Woodend";
$areanames{en}->{61354264} = "Woodend";
$areanames{en}->{613542650} = "Nullawil";
$areanames{en}->{613542651} = "Nullawil";
$areanames{en}->{613542652} = "Nullawil";
$areanames{en}->{613542653} = "Nullawil";
$areanames{en}->{613542654} = "Nullawil";
$areanames{en}->{613542657} = "Nullawil";
$areanames{en}->{613542660} = "St\ Arnaud";
$areanames{en}->{613542661} = "St\ Arnaud";
$areanames{en}->{613542662} = "St\ Arnaud";
$areanames{en}->{613542663} = "St\ Arnaud";
$areanames{en}->{613542664} = "St\ Arnaud";
$areanames{en}->{613542667} = "St\ Arnaud";
$areanames{en}->{613542670} = "Traynors\ Lagoon";
$areanames{en}->{613542671} = "Traynors\ Lagoon";
$areanames{en}->{613542672} = "Traynors\ Lagoon";
$areanames{en}->{613542673} = "Traynors\ Lagoon";
$areanames{en}->{613542674} = "Traynors\ Lagoon";
$areanames{en}->{613542677} = "Traynors\ Lagoon";
$areanames{en}->{613542680} = "Watchem";
$areanames{en}->{613542681} = "Watchem";
$areanames{en}->{613542682} = "Watchem";
$areanames{en}->{613542683} = "Watchem";
$areanames{en}->{613542684} = "Watchem";
$areanames{en}->{613542687} = "Watchem";
$areanames{en}->{613542690} = "Wedderburn";
$areanames{en}->{613542691} = "Wedderburn";
$areanames{en}->{613542692} = "Wedderburn";
$areanames{en}->{613542693} = "Wedderburn";
$areanames{en}->{613542694} = "Wedderburn";
$areanames{en}->{613542697} = "Wedderburn";
$areanames{en}->{61354270} = "Woodend";
$areanames{en}->{61354271} = "Woodend";
$areanames{en}->{61354272} = "Woodend";
$areanames{en}->{61354273} = "Woodend";
$areanames{en}->{61354274} = "Woodend";
$areanames{en}->{61354275} = "Romsey";
$areanames{en}->{613542760} = "Wycheproof";
$areanames{en}->{613542761} = "Wycheproof";
$areanames{en}->{613542762} = "Wycheproof";
$areanames{en}->{613542763} = "Wycheproof";
$areanames{en}->{613542764} = "Wycheproof";
$areanames{en}->{613542767} = "Wycheproof";
$areanames{en}->{613542770} = "Echuca";
$areanames{en}->{613542771} = "Echuca";
$areanames{en}->{613542772} = "Echuca";
$areanames{en}->{613542773} = "Echuca";
$areanames{en}->{613542774} = "Echuca";
$areanames{en}->{613542775} = "Echuca";
$areanames{en}->{613542776} = "Echuca";
$areanames{en}->{61354278} = "Woodend";
$areanames{en}->{61354279} = "Woodend";
$areanames{en}->{6135428} = "Gisborne";
$areanames{en}->{6135429} = "Romsey";
$areanames{en}->{6135430} = "Bendigo";
$areanames{en}->{61354307} = "Goornong";
$areanames{en}->{61354308} = "Elmore";
$areanames{en}->{61354309} = "Colbinabbin";
$areanames{en}->{61354310} = "Heathcote";
$areanames{en}->{61354311} = "Marong";
$areanames{en}->{61354312} = "Raywood";
$areanames{en}->{61354313} = "Mitiamo";
$areanames{en}->{61354314} = "Dingee";
$areanames{en}->{61354315} = "Bridgewater";
$areanames{en}->{61354316} = "Jarklin";
$areanames{en}->{61354317} = "Inglewood";
$areanames{en}->{61354318} = "Llanelly";
$areanames{en}->{61354319} = "Strathfieldsaye";
$areanames{en}->{61354320} = "Bendigo";
$areanames{en}->{61354321} = "Goornong";
$areanames{en}->{61354322} = "Goornong";
$areanames{en}->{61354323} = "Bendigo";
$areanames{en}->{61354324} = "Bendigo";
$areanames{en}->{61354325} = "Elmore";
$areanames{en}->{61354326} = "Elmore";
$areanames{en}->{61354327} = "Elmore";
$areanames{en}->{61354328} = "Colbinabbin";
$areanames{en}->{61354329} = "Colbinabbin";
$areanames{en}->{6135433} = "Heathcote";
$areanames{en}->{61354336} = "Goornong";
$areanames{en}->{61354337} = "Bendigo";
$areanames{en}->{61354338} = "Bendigo";
$areanames{en}->{61354339} = "Bendigo";
$areanames{en}->{6135434} = "Bendigo";
$areanames{en}->{6135435} = "Marong";
$areanames{en}->{61354360} = "Raywood";
$areanames{en}->{61354361} = "Raywood";
$areanames{en}->{61354362} = "Lockington";
$areanames{en}->{61354363} = "Rochester";
$areanames{en}->{61354364} = "Tennyson";
$areanames{en}->{61354365} = "Mitiamo";
$areanames{en}->{61354366} = "Mitiamo";
$areanames{en}->{61354367} = "Mitiamo";
$areanames{en}->{61354368} = "Dingee";
$areanames{en}->{61354369} = "Goornong";
$areanames{en}->{61354370} = "Wedderburn";
$areanames{en}->{61354371} = "Wycheproof";
$areanames{en}->{61354372} = "Bridgewater";
$areanames{en}->{61354373} = "Bridgewater";
$areanames{en}->{61354374} = "Echuca";
$areanames{en}->{61354375} = "Bridgewater";
$areanames{en}->{61354376} = "Gunbower";
$areanames{en}->{61354377} = "Dingee";
$areanames{en}->{61354378} = "Dingee";
$areanames{en}->{61354379} = "Jarklin";
$areanames{en}->{61354380} = "Bendigo";
$areanames{en}->{61354381} = "Bendigo";
$areanames{en}->{61354382} = "Inglewood";
$areanames{en}->{61354383} = "Inglewood";
$areanames{en}->{61354384} = "Inglewood";
$areanames{en}->{61354385} = "Traynors\ Lagoon";
$areanames{en}->{61354386} = "Watchem";
$areanames{en}->{61354387} = "Llanelly";
$areanames{en}->{61354388} = "Llanelly";
$areanames{en}->{61354389} = "Llanelly";
$areanames{en}->{6135439} = "Strathfieldsaye";
$areanames{en}->{613544} = "Bendigo";
$areanames{en}->{613545000} = "Gunbower";
$areanames{en}->{613545001} = "Gunbower";
$areanames{en}->{613545002} = "Gunbower";
$areanames{en}->{613545003} = "Gunbower";
$areanames{en}->{613545004} = "Gunbower";
$areanames{en}->{613545007} = "Gunbower";
$areanames{en}->{613545010} = "Lockington";
$areanames{en}->{613545011} = "Lockington";
$areanames{en}->{613545012} = "Lockington";
$areanames{en}->{613545013} = "Lockington";
$areanames{en}->{613545014} = "Lockington";
$areanames{en}->{613545017} = "Lockington";
$areanames{en}->{613545020} = "Rochester";
$areanames{en}->{613545021} = "Rochester";
$areanames{en}->{613545022} = "Rochester";
$areanames{en}->{613545023} = "Rochester";
$areanames{en}->{613545024} = "Rochester";
$areanames{en}->{613545027} = "Rochester";
$areanames{en}->{61354503} = "Kerang";
$areanames{en}->{61354504} = "Kerang";
$areanames{en}->{61354505} = "Kerang";
$areanames{en}->{61354506} = "Kerang";
$areanames{en}->{61354507} = "Kerang";
$areanames{en}->{61354508} = "Kerang";
$areanames{en}->{61354509} = "Kerang";
$areanames{en}->{61354510} = "Kerang";
$areanames{en}->{61354511} = "Barham";
$areanames{en}->{61354512} = "Tullakool";
$areanames{en}->{61354513} = "Murrabit";
$areanames{en}->{61354514} = "Lake\ Meran";
$areanames{en}->{61354515} = "Boort";
$areanames{en}->{61354516} = "Pyramid\ Hill";
$areanames{en}->{61354517} = "Cohuna";
$areanames{en}->{61354518} = "Quambatook";
$areanames{en}->{61354519} = "Lalbert";
$areanames{en}->{61354520} = "Kerang";
$areanames{en}->{61354521} = "Kerang";
$areanames{en}->{61354522} = "Kerang";
$areanames{en}->{613545230} = "Tennyson";
$areanames{en}->{613545231} = "Tennyson";
$areanames{en}->{613545232} = "Tennyson";
$areanames{en}->{613545233} = "Tennyson";
$areanames{en}->{613545234} = "Tennyson";
$areanames{en}->{613545237} = "Tennyson";
$areanames{en}->{613545240} = "Womboota";
$areanames{en}->{613545241} = "Womboota";
$areanames{en}->{613545242} = "Womboota";
$areanames{en}->{613545243} = "Womboota";
$areanames{en}->{613545244} = "Womboota";
$areanames{en}->{613545247} = "Womboota";
$areanames{en}->{613545250} = "Barham";
$areanames{en}->{613545251} = "Barham";
$areanames{en}->{613545252} = "Barham";
$areanames{en}->{613545253} = "Barham";
$areanames{en}->{613545254} = "Barham";
$areanames{en}->{613545257} = "Barham";
$areanames{en}->{613545260} = "Boort";
$areanames{en}->{613545261} = "Boort";
$areanames{en}->{613545262} = "Boort";
$areanames{en}->{613545263} = "Boort";
$areanames{en}->{613545264} = "Boort";
$areanames{en}->{613545267} = "Boort";
$areanames{en}->{613545270} = "Cohuna";
$areanames{en}->{613545271} = "Cohuna";
$areanames{en}->{613545272} = "Cohuna";
$areanames{en}->{613545273} = "Cohuna";
$areanames{en}->{613545274} = "Cohuna";
$areanames{en}->{613545277} = "Cohuna";
$areanames{en}->{613545280} = "Kerang";
$areanames{en}->{613545281} = "Kerang";
$areanames{en}->{613545282} = "Kerang";
$areanames{en}->{613545283} = "Kerang";
$areanames{en}->{613545284} = "Kerang";
$areanames{en}->{613545287} = "Kerang";
$areanames{en}->{613545290} = "Lake\ Meran";
$areanames{en}->{613545291} = "Lake\ Meran";
$areanames{en}->{613545292} = "Lake\ Meran";
$areanames{en}->{613545293} = "Lake\ Meran";
$areanames{en}->{613545294} = "Lake\ Meran";
$areanames{en}->{613545297} = "Lake\ Meran";
$areanames{en}->{6135453} = "Barham";
$areanames{en}->{61354530} = "Tullakool";
$areanames{en}->{61354539} = "Tullakool";
$areanames{en}->{6135454} = "Bendigo";
$areanames{en}->{61354550} = "St\ Arnaud";
$areanames{en}->{61354551} = "Boort";
$areanames{en}->{61354552} = "Boort";
$areanames{en}->{61354553} = "Boort";
$areanames{en}->{61354554} = "Boort";
$areanames{en}->{61354555} = "Logan";
$areanames{en}->{61354556} = "Nullawil";
$areanames{en}->{61354557} = "Pyramid\ Hill";
$areanames{en}->{61354558} = "Pyramid\ Hill";
$areanames{en}->{61354559} = "Pyramid\ Hill";
$areanames{en}->{6135456} = "Cohuna";
$areanames{en}->{61354570} = "Murrabit";
$areanames{en}->{61354571} = "Quambatook";
$areanames{en}->{61354572} = "Murrabit";
$areanames{en}->{61354573} = "Lalbert";
$areanames{en}->{61354574} = "Quambatook";
$areanames{en}->{61354575} = "Murrabit";
$areanames{en}->{61354576} = "Quambatook";
$areanames{en}->{61354577} = "Lake\ Meran";
$areanames{en}->{61354578} = "Lake\ Meran";
$areanames{en}->{61354579} = "Murrabit";
$areanames{en}->{61354580} = "Raywood";
$areanames{en}->{61354581} = "Strathfieldsaye";
$areanames{en}->{61354582} = "Beazleys\ Bridge";
$areanames{en}->{61354583} = "Birchip";
$areanames{en}->{61354584} = "Buckrabanyule";
$areanames{en}->{61354585} = "Charlton";
$areanames{en}->{61354586} = "Donald";
$areanames{en}->{61354587} = "Gowar\ East";
$areanames{en}->{61354588} = "Korong\ Vale";
$areanames{en}->{61354589} = "Laen";
$areanames{en}->{61354590} = "Maryborough";
$areanames{en}->{61354591} = "Maryborough";
$areanames{en}->{61354592} = "Maryborough";
$areanames{en}->{613545930} = "Lalbert";
$areanames{en}->{613545931} = "Lalbert";
$areanames{en}->{613545932} = "Lalbert";
$areanames{en}->{613545933} = "Lalbert";
$areanames{en}->{613545934} = "Lalbert";
$areanames{en}->{613545937} = "Lalbert";
$areanames{en}->{61354594} = "Carisbrook";
$areanames{en}->{613545950} = "Murrabit";
$areanames{en}->{613545951} = "Murrabit";
$areanames{en}->{613545952} = "Murrabit";
$areanames{en}->{613545953} = "Murrabit";
$areanames{en}->{613545954} = "Murrabit";
$areanames{en}->{613545957} = "Murrabit";
$areanames{en}->{613545960} = "Pyramid\ Hill";
$areanames{en}->{613545961} = "Pyramid\ Hill";
$areanames{en}->{613545962} = "Pyramid\ Hill";
$areanames{en}->{613545963} = "Pyramid\ Hill";
$areanames{en}->{613545964} = "Pyramid\ Hill";
$areanames{en}->{613545967} = "Pyramid\ Hill";
$areanames{en}->{61354597} = "Moonambel";
$areanames{en}->{613545980} = "Quambatook";
$areanames{en}->{613545981} = "Quambatook";
$areanames{en}->{613545982} = "Quambatook";
$areanames{en}->{613545983} = "Quambatook";
$areanames{en}->{613545984} = "Quambatook";
$areanames{en}->{613545987} = "Quambatook";
$areanames{en}->{613545990} = "Tullakool";
$areanames{en}->{613545991} = "Tullakool";
$areanames{en}->{613545992} = "Tullakool";
$areanames{en}->{613545993} = "Tullakool";
$areanames{en}->{613545994} = "Tullakool";
$areanames{en}->{613545997} = "Tullakool";
$areanames{en}->{613546000} = "Gisborne";
$areanames{en}->{613546001} = "Gisborne";
$areanames{en}->{613546002} = "Gisborne";
$areanames{en}->{613546003} = "Gisborne";
$areanames{en}->{613546010} = "Kyneton";
$areanames{en}->{613546011} = "Kyneton";
$areanames{en}->{613546012} = "Kyneton";
$areanames{en}->{613546013} = "Kyneton";
$areanames{en}->{613546014} = "Kyneton";
$areanames{en}->{613546020} = "Redesdale";
$areanames{en}->{613546021} = "Redesdale";
$areanames{en}->{613546022} = "Redesdale";
$areanames{en}->{613546023} = "Redesdale";
$areanames{en}->{613546024} = "Redesdale";
$areanames{en}->{613546025} = "Redesdale";
$areanames{en}->{613546026} = "Redesdale";
$areanames{en}->{613546027} = "Redesdale";
$areanames{en}->{61354603} = "Maryborough";
$areanames{en}->{61354604} = "Maryborough";
$areanames{en}->{61354605} = "Maryborough";
$areanames{en}->{613546060} = "Romsey";
$areanames{en}->{613546061} = "Romsey";
$areanames{en}->{613546062} = "Romsey";
$areanames{en}->{613546063} = "Romsey";
$areanames{en}->{613546064} = "Romsey";
$areanames{en}->{613546065} = "Romsey";
$areanames{en}->{613546066} = "Romsey";
$areanames{en}->{613546067} = "Romsey";
$areanames{en}->{613546070} = "Trentham";
$areanames{en}->{613546071} = "Trentham";
$areanames{en}->{613546072} = "Trentham";
$areanames{en}->{613546073} = "Trentham";
$areanames{en}->{613546074} = "Trentham";
$areanames{en}->{613546075} = "Trentham";
$areanames{en}->{613546076} = "Trentham";
$areanames{en}->{613546077} = "Trentham";
$areanames{en}->{613546080} = "Woodend";
$areanames{en}->{613546081} = "Woodend";
$areanames{en}->{613546082} = "Woodend";
$areanames{en}->{613546083} = "Woodend";
$areanames{en}->{613546084} = "Woodend";
$areanames{en}->{613546085} = "Woodend";
$areanames{en}->{613546086} = "Woodend";
$areanames{en}->{613546087} = "Woodend";
$areanames{en}->{613546090} = "Amphitheatre";
$areanames{en}->{613546091} = "Amphitheatre";
$areanames{en}->{613546092} = "Amphitheatre";
$areanames{en}->{613546093} = "Amphitheatre";
$areanames{en}->{613546094} = "Amphitheatre";
$areanames{en}->{613546097} = "Amphitheatre";
$areanames{en}->{6135461} = "Maryborough";
$areanames{en}->{613546200} = "Avoca";
$areanames{en}->{613546201} = "Avoca";
$areanames{en}->{613546202} = "Avoca";
$areanames{en}->{613546203} = "Avoca";
$areanames{en}->{613546204} = "Avoca";
$areanames{en}->{613546207} = "Avoca";
$areanames{en}->{61354621} = "Maryborough";
$areanames{en}->{61354622} = "Maryborough";
$areanames{en}->{613546230} = "Bealiba";
$areanames{en}->{613546231} = "Bealiba";
$areanames{en}->{613546232} = "Bealiba";
$areanames{en}->{613546233} = "Bealiba";
$areanames{en}->{613546234} = "Bealiba";
$areanames{en}->{613546237} = "Bealiba";
$areanames{en}->{613546240} = "Carisbrook";
$areanames{en}->{613546241} = "Carisbrook";
$areanames{en}->{613546242} = "Carisbrook";
$areanames{en}->{613546243} = "Carisbrook";
$areanames{en}->{613546244} = "Carisbrook";
$areanames{en}->{613546247} = "Carisbrook";
$areanames{en}->{613546250} = "Castlemaine";
$areanames{en}->{613546251} = "Castlemaine";
$areanames{en}->{613546252} = "Castlemaine";
$areanames{en}->{613546253} = "Castlemaine";
$areanames{en}->{613546254} = "Castlemaine";
$areanames{en}->{613546260} = "Dunolly";
$areanames{en}->{613546261} = "Dunolly";
$areanames{en}->{613546262} = "Dunolly";
$areanames{en}->{613546263} = "Dunolly";
$areanames{en}->{613546264} = "Dunolly";
$areanames{en}->{613546267} = "Dunolly";
$areanames{en}->{613546270} = "Harcourt";
$areanames{en}->{613546271} = "Harcourt";
$areanames{en}->{613546272} = "Harcourt";
$areanames{en}->{613546273} = "Harcourt";
$areanames{en}->{613546274} = "Harcourt";
$areanames{en}->{613546277} = "Harcourt";
$areanames{en}->{613546280} = "Maldon";
$areanames{en}->{613546281} = "Maldon";
$areanames{en}->{613546282} = "Maldon";
$areanames{en}->{613546283} = "Maldon";
$areanames{en}->{613546284} = "Maldon";
$areanames{en}->{613546287} = "Maldon";
$areanames{en}->{613546290} = "Maryborough";
$areanames{en}->{613546291} = "Maryborough";
$areanames{en}->{613546292} = "Maryborough";
$areanames{en}->{613546293} = "Maryborough";
$areanames{en}->{613546294} = "Maryborough";
$areanames{en}->{613546300} = "Moonambel";
$areanames{en}->{613546301} = "Moonambel";
$areanames{en}->{613546302} = "Moonambel";
$areanames{en}->{613546303} = "Moonambel";
$areanames{en}->{613546304} = "Moonambel";
$areanames{en}->{613546307} = "Moonambel";
$areanames{en}->{61354631} = "Talbot";
$areanames{en}->{61354632} = "Talbot";
$areanames{en}->{613546330} = "Newstead";
$areanames{en}->{613546331} = "Newstead";
$areanames{en}->{613546332} = "Newstead";
$areanames{en}->{613546333} = "Newstead";
$areanames{en}->{613546334} = "Newstead";
$areanames{en}->{613546337} = "Newstead";
$areanames{en}->{613546340} = "Talbot";
$areanames{en}->{613546341} = "Talbot";
$areanames{en}->{613546342} = "Talbot";
$areanames{en}->{613546343} = "Talbot";
$areanames{en}->{613546344} = "Talbot";
$areanames{en}->{613546347} = "Talbot";
$areanames{en}->{61354635} = "Bendigo";
$areanames{en}->{61354636} = "Redesdale";
$areanames{en}->{61354637} = "Bridgewater";
$areanames{en}->{61354638} = "Colbinabbin";
$areanames{en}->{61354639} = "Dingee";
$areanames{en}->{6135464} = "Carisbrook";
$areanames{en}->{61354650} = "Elmore";
$areanames{en}->{61354651} = "Avoca";
$areanames{en}->{61354652} = "Avoca";
$areanames{en}->{61354653} = "Avoca";
$areanames{en}->{61354654} = "Goornong";
$areanames{en}->{61354655} = "Heathcote";
$areanames{en}->{61354656} = "Inglewood";
$areanames{en}->{61354657} = "Jarklin";
$areanames{en}->{61354658} = "Llanelly";
$areanames{en}->{61354659} = "Marong";
$areanames{en}->{61354660} = "Mitiamo";
$areanames{en}->{61354661} = "Amphitheatre";
$areanames{en}->{61354662} = "Amphitheatre";
$areanames{en}->{61354663} = "Raywood";
$areanames{en}->{61354664} = "Beazleys\ Bridge";
$areanames{en}->{61354665} = "Birchip";
$areanames{en}->{61354666} = "Buckrabanyule";
$areanames{en}->{61354667} = "Amphitheatre";
$areanames{en}->{61354668} = "Charlton";
$areanames{en}->{61354669} = "Donald";
$areanames{en}->{61354670} = "Woodend";
$areanames{en}->{61354671} = "Woodend";
$areanames{en}->{61354672} = "Moonambel";
$areanames{en}->{61354673} = "Gisborne";
$areanames{en}->{61354674} = "Gisborne";
$areanames{en}->{61354675} = "Gisborne";
$areanames{en}->{61354676} = "Inglewood";
$areanames{en}->{61354677} = "Moonambel";
$areanames{en}->{61354678} = "Bendigo";
$areanames{en}->{61354679} = "Bendigo";
$areanames{en}->{61354680} = "Gowar\ East";
$areanames{en}->{61354681} = "Dunolly";
$areanames{en}->{61354682} = "Dunolly";
$areanames{en}->{61354683} = "Korong\ Vale";
$areanames{en}->{61354684} = "Laen";
$areanames{en}->{61354685} = "Logan";
$areanames{en}->{61354686} = "Nullawil";
$areanames{en}->{61354687} = "Dunolly";
$areanames{en}->{61354688} = "Bridgewater";
$areanames{en}->{61354689} = "Bridgewater";
$areanames{en}->{61354690} = "Echuca";
$areanames{en}->{61354691} = "Bealiba";
$areanames{en}->{61354692} = "Bealiba";
$areanames{en}->{61354693} = "St\ Arnaud";
$areanames{en}->{61354694} = "Traynors\ Lagoon";
$areanames{en}->{61354695} = "Watchem";
$areanames{en}->{61354696} = "Wedderburn";
$areanames{en}->{61354697} = "Bealiba";
$areanames{en}->{61354698} = "Wycheproof";
$areanames{en}->{61354699} = "Gunbower";
$areanames{en}->{61354700} = "Lockington";
$areanames{en}->{61354701} = "Rochester";
$areanames{en}->{61354702} = "Tennyson";
$areanames{en}->{61354703} = "Womboota";
$areanames{en}->{61354704} = "Castlemaine";
$areanames{en}->{61354705} = "Castlemaine";
$areanames{en}->{61354706} = "Castlemaine";
$areanames{en}->{61354707} = "Colbinabbin";
$areanames{en}->{61354708} = "Colbinabbin";
$areanames{en}->{61354709} = "Dingee";
$areanames{en}->{6135471} = "Castlemaine";
$areanames{en}->{61354710} = "Dingee";
$areanames{en}->{6135472} = "Castlemaine";
$areanames{en}->{61354727} = "Barham";
$areanames{en}->{61354728} = "Boort";
$areanames{en}->{61354729} = "Cohuna";
$areanames{en}->{61354730} = "Kerang";
$areanames{en}->{61354731} = "Lake\ Meran";
$areanames{en}->{61354732} = "Castlemaine";
$areanames{en}->{61354733} = "Castlemaine";
$areanames{en}->{61354734} = "Castlemaine";
$areanames{en}->{61354735} = "Lalbert";
$areanames{en}->{61354736} = "Murrabit";
$areanames{en}->{61354737} = "Pyramid\ Hill";
$areanames{en}->{61354738} = "Quambatook";
$areanames{en}->{61354739} = "Tullakool";
$areanames{en}->{61354740} = "Romsey";
$areanames{en}->{61354741} = "Harcourt";
$areanames{en}->{61354742} = "Harcourt";
$areanames{en}->{61354743} = "Harcourt";
$areanames{en}->{61354744} = "Woodend";
$areanames{en}->{61354745} = "Amphitheatre";
$areanames{en}->{61354746} = "Avoca";
$areanames{en}->{61354747} = "Bealiba";
$areanames{en}->{61354748} = "Harcourt";
$areanames{en}->{61354749} = "Carisbrook";
$areanames{en}->{6135475} = "Maldon";
$areanames{en}->{6135476} = "Newstead";
$areanames{en}->{6135477} = "St\ Arnaud";
$areanames{en}->{61354776} = "Charlton";
$areanames{en}->{61354777} = "Birchip";
$areanames{en}->{61354778} = "Buckrabanyule";
$areanames{en}->{61354779} = "Nullawil";
$areanames{en}->{61354780} = "Wycheproof";
$areanames{en}->{61354781} = "Wedderburn";
$areanames{en}->{61354782} = "Korong\ Vale";
$areanames{en}->{61354783} = "Logan";
$areanames{en}->{61354784} = "Gowar\ East";
$areanames{en}->{61354785} = "Traynors\ Lagoon";
$areanames{en}->{61354786} = "Donald";
$areanames{en}->{61354787} = "Watchem";
$areanames{en}->{61354788} = "Laen";
$areanames{en}->{61354789} = "Dunolly";
$areanames{en}->{6135479} = "Castlemaine";
$areanames{en}->{61354796} = "Bealiba";
$areanames{en}->{61354797} = "Traynors\ Lagoon";
$areanames{en}->{61354798} = "Maldon";
$areanames{en}->{61354799} = "Newstead";
$areanames{en}->{6135480} = "Echuca";
$areanames{en}->{61354810} = "Echuca";
$areanames{en}->{61354811} = "Echuca";
$areanames{en}->{61354812} = "Echuca";
$areanames{en}->{61354813} = "Echuca";
$areanames{en}->{61354814} = "Echuca";
$areanames{en}->{61354815} = "Rochester";
$areanames{en}->{61354816} = "Harcourt";
$areanames{en}->{61354817} = "Maldon";
$areanames{en}->{61354818} = "Talbot";
$areanames{en}->{61354819} = "Rochester";
$areanames{en}->{6135482} = "Echuca";
$areanames{en}->{61354827} = "Elmore";
$areanames{en}->{61354828} = "Elmore";
$areanames{en}->{61354829} = "Rochester";
$areanames{en}->{6135483} = "Echuca";
$areanames{en}->{61354833} = "Gisborne";
$areanames{en}->{61354834} = "Gisborne";
$areanames{en}->{6135484} = "Rochester";
$areanames{en}->{61354850} = "Inglewood";
$areanames{en}->{61354851} = "Jarklin";
$areanames{en}->{61354852} = "Llanelly";
$areanames{en}->{61354853} = "Marong";
$areanames{en}->{61354854} = "Mitiamo";
$areanames{en}->{61354855} = "Echuca";
$areanames{en}->{61354856} = "Bendigo";
$areanames{en}->{61354857} = "Bendigo";
$areanames{en}->{61354858} = "Goornong";
$areanames{en}->{61354859} = "Heathcote";
$areanames{en}->{61354860} = "Bendigo";
$areanames{en}->{61354861} = "Lockington";
$areanames{en}->{61354862} = "Lockington";
$areanames{en}->{61354863} = "Goornong";
$areanames{en}->{61354864} = "Goornong";
$areanames{en}->{61354865} = "Lockington";
$areanames{en}->{61354866} = "Heathcote";
$areanames{en}->{61354867} = "Heathcote";
$areanames{en}->{61354868} = "Lockington";
$areanames{en}->{61354869} = "Inglewood";
$areanames{en}->{61354870} = "Inglewood";
$areanames{en}->{61354871} = "Gunbower";
$areanames{en}->{61354872} = "Gunbower";
$areanames{en}->{61354873} = "Llanelly";
$areanames{en}->{61354874} = "Llanelly";
$areanames{en}->{61354875} = "Marong";
$areanames{en}->{61354876} = "Marong";
$areanames{en}->{61354877} = "Gunbower";
$areanames{en}->{61354878} = "Mitiamo";
$areanames{en}->{61354879} = "Mitiamo";
$areanames{en}->{61354880} = "Bendigo";
$areanames{en}->{61354881} = "Tennyson";
$areanames{en}->{61354882} = "Tennyson";
$areanames{en}->{61354883} = "Beazleys\ Bridge";
$areanames{en}->{61354884} = "Beazleys\ Bridge";
$areanames{en}->{61354885} = "Birchip";
$areanames{en}->{61354886} = "Birchip";
$areanames{en}->{61354887} = "Tennyson";
$areanames{en}->{61354888} = "Buckrabanyule";
$areanames{en}->{61354889} = "Buckrabanyule";
$areanames{en}->{61354890} = "Barham";
$areanames{en}->{61354891} = "Barham";
$areanames{en}->{61354892} = "Womboota";
$areanames{en}->{61354893} = "Womboota";
$areanames{en}->{61354894} = "Raywood";
$areanames{en}->{61354895} = "Raywood";
$areanames{en}->{61354896} = "Amphitheatre";
$areanames{en}->{61354897} = "Womboota";
$areanames{en}->{61354898} = "Jarklin";
$areanames{en}->{61354899} = "Jarklin";
$areanames{en}->{6135490} = "Echuca";
$areanames{en}->{6135491} = "Charlton";
$areanames{en}->{6135492} = "Birchip";
$areanames{en}->{61354927} = "Buckrabanyule";
$areanames{en}->{61354928} = "Buckrabanyule";
$areanames{en}->{61354929} = "Buckrabanyule";
$areanames{en}->{6135493} = "Nullawil";
$areanames{en}->{61354936} = "Wycheproof";
$areanames{en}->{61354937} = "Wycheproof";
$areanames{en}->{61354938} = "Wycheproof";
$areanames{en}->{61354939} = "Wycheproof";
$areanames{en}->{6135494} = "Wedderburn";
$areanames{en}->{61354947} = "Korong\ Vale";
$areanames{en}->{61354948} = "Korong\ Vale";
$areanames{en}->{61354949} = "Korong\ Vale";
$areanames{en}->{6135495} = "St\ Arnaud";
$areanames{en}->{61354957} = "Charlton";
$areanames{en}->{61354958} = "Charlton";
$areanames{en}->{61354959} = "Gunbower";
$areanames{en}->{613549600} = "Bridgewater";
$areanames{en}->{613549601} = "Bridgewater";
$areanames{en}->{613549602} = "Bridgewater";
$areanames{en}->{613549603} = "Bridgewater";
$areanames{en}->{613549604} = "Bridgewater";
$areanames{en}->{613549607} = "Bridgewater";
$areanames{en}->{61354961} = "Logan";
$areanames{en}->{61354962} = "Logan";
$areanames{en}->{61354963} = "Logan";
$areanames{en}->{61354964} = "Elmore";
$areanames{en}->{61354965} = "Gowar\ East";
$areanames{en}->{61354966} = "Traynors\ Lagoon";
$areanames{en}->{61354967} = "Traynors\ Lagoon";
$areanames{en}->{61354968} = "Traynors\ Lagoon";
$areanames{en}->{61354969} = "Dingee";
$areanames{en}->{613549700} = "Donald";
$areanames{en}->{613549701} = "Donald";
$areanames{en}->{613549702} = "Donald";
$areanames{en}->{613549703} = "Donald";
$areanames{en}->{613549704} = "Donald";
$areanames{en}->{613549707} = "Donald";
$areanames{en}->{61354971} = "Donald";
$areanames{en}->{61354972} = "Donald";
$areanames{en}->{61354973} = "Donald";
$areanames{en}->{61354974} = "Donald";
$areanames{en}->{61354975} = "Bendigo";
$areanames{en}->{61354976} = "Donald";
$areanames{en}->{61354977} = "Donald";
$areanames{en}->{61354978} = "Donald";
$areanames{en}->{61354979} = "Bendigo";
$areanames{en}->{61354980} = "Watchem";
$areanames{en}->{61354981} = "Watchem";
$areanames{en}->{61354982} = "Watchem";
$areanames{en}->{61354983} = "Watchem";
$areanames{en}->{61354984} = "Colbinabbin";
$areanames{en}->{61354985} = "Watchem";
$areanames{en}->{61354986} = "Laen";
$areanames{en}->{61354987} = "Laen";
$areanames{en}->{61354988} = "Bendigo";
$areanames{en}->{61354989} = "Bridgewater";
$areanames{en}->{61354990} = "Gowar\ East";
$areanames{en}->{61354991} = "Gowar\ East";
$areanames{en}->{61354992} = "Korong\ Vale";
$areanames{en}->{61354993} = "Korong\ Vale";
$areanames{en}->{61354994} = "Laen";
$areanames{en}->{61354995} = "Laen";
$areanames{en}->{61354996} = "Bendigo";
$areanames{en}->{61354997} = "Beazleys\ Bridge";
$areanames{en}->{61354998} = "Beazleys\ Bridge";
$areanames{en}->{61354999} = "Beazleys\ Bridge";
$areanames{en}->{6135500} = "Warrnambool";
$areanames{en}->{61355004} = "Cavendish";
$areanames{en}->{61355007} = "Hamilton";
$areanames{en}->{61355008} = "Heywood";
$areanames{en}->{61355009} = "Portland";
$areanames{en}->{61355010} = "Apsley";
$areanames{en}->{61355011} = "Apsley";
$areanames{en}->{61355012} = "Apsley";
$areanames{en}->{61355013} = "Balmoral";
$areanames{en}->{61355014} = "Balmoral";
$areanames{en}->{61355015} = "Balmoral";
$areanames{en}->{61355016} = "Benayeo";
$areanames{en}->{61355017} = "Benayeo";
$areanames{en}->{61355018} = "Benayeo";
$areanames{en}->{61355019} = "Timboon";
$areanames{en}->{61355020} = "Bessiebelle";
$areanames{en}->{61355021} = "Bessiebelle";
$areanames{en}->{61355022} = "Bessiebelle";
$areanames{en}->{61355023} = "Camperdown";
$areanames{en}->{61355024} = "Camperdown";
$areanames{en}->{61355025} = "Camperdown";
$areanames{en}->{61355026} = "Caramut";
$areanames{en}->{61355027} = "Caramut";
$areanames{en}->{61355028} = "Caramut";
$areanames{en}->{61355029} = "Terang";
$areanames{en}->{61355030} = "Casterton";
$areanames{en}->{61355031} = "Casterton";
$areanames{en}->{61355032} = "Casterton";
$areanames{en}->{61355033} = "Cavendish";
$areanames{en}->{61355034} = "Cavendish";
$areanames{en}->{61355035} = "Cavendish";
$areanames{en}->{61355036} = "Chetwynd";
$areanames{en}->{61355037} = "Chetwynd";
$areanames{en}->{61355038} = "Chetwynd";
$areanames{en}->{61355039} = "South\ Purrumbete";
$areanames{en}->{61355040} = "Cobden";
$areanames{en}->{61355041} = "Cobden";
$areanames{en}->{61355042} = "Cobden";
$areanames{en}->{61355043} = "Coleraine";
$areanames{en}->{61355044} = "Coleraine";
$areanames{en}->{61355045} = "Coleraine";
$areanames{en}->{61355046} = "Coojar";
$areanames{en}->{61355047} = "Coojar";
$areanames{en}->{61355048} = "Coojar";
$areanames{en}->{61355049} = "Pomborneit";
$areanames{en}->{61355050} = "Darlington";
$areanames{en}->{61355051} = "Darlington";
$areanames{en}->{61355052} = "Darlington";
$areanames{en}->{61355053} = "Dartmoor";
$areanames{en}->{61355054} = "Dartmoor";
$areanames{en}->{61355055} = "Dartmoor";
$areanames{en}->{61355056} = "Derrinallum";
$areanames{en}->{61355057} = "Derrinallum";
$areanames{en}->{61355058} = "Derrinallum";
$areanames{en}->{61355059} = "Ecklin";
$areanames{en}->{61355060} = "Dorodong";
$areanames{en}->{61355061} = "Dorodong";
$areanames{en}->{61355062} = "Dorodong";
$areanames{en}->{61355063} = "Dundonnell";
$areanames{en}->{61355064} = "Dundonnell";
$areanames{en}->{61355065} = "Dundonnell";
$areanames{en}->{61355066} = "Dunkeld";
$areanames{en}->{61355067} = "Dunkeld";
$areanames{en}->{61355068} = "Dunkeld";
$areanames{en}->{61355069} = "Lismore";
$areanames{en}->{61355070} = "Ecklin";
$areanames{en}->{61355071} = "Ecklin";
$areanames{en}->{61355072} = "Ecklin";
$areanames{en}->{61355073} = "Edenhope";
$areanames{en}->{61355074} = "Edenhope";
$areanames{en}->{61355075} = "Edenhope";
$areanames{en}->{61355076} = "Glenthompson";
$areanames{en}->{61355077} = "Glenthompson";
$areanames{en}->{61355078} = "Glenthompson";
$areanames{en}->{61355079} = "Mortlake";
$areanames{en}->{61355080} = "Hamilton";
$areanames{en}->{61355081} = "Hamilton";
$areanames{en}->{61355082} = "Hamilton";
$areanames{en}->{61355083} = "Harrow";
$areanames{en}->{61355084} = "Harrow";
$areanames{en}->{61355085} = "Harrow";
$areanames{en}->{61355086} = "Hawkesdale";
$areanames{en}->{61355087} = "Hawkesdale";
$areanames{en}->{61355088} = "Hawkesdale";
$areanames{en}->{61355089} = "Darlington";
$areanames{en}->{61355090} = "Heywood";
$areanames{en}->{61355091} = "Heywood";
$areanames{en}->{61355092} = "Heywood";
$areanames{en}->{61355093} = "Lake\ Mundi";
$areanames{en}->{61355094} = "Lake\ Mundi";
$areanames{en}->{61355095} = "Lake\ Mundi";
$areanames{en}->{61355096} = "Lismore";
$areanames{en}->{61355097} = "Lismore";
$areanames{en}->{61355098} = "Lismore";
$areanames{en}->{61355099} = "Derrinallum";
$areanames{en}->{61355100} = "Macarthur";
$areanames{en}->{61355101} = "Macarthur";
$areanames{en}->{61355102} = "Macarthur";
$areanames{en}->{61355103} = "Merino";
$areanames{en}->{61355104} = "Merino";
$areanames{en}->{61355105} = "Merino";
$areanames{en}->{61355106} = "Mortlake";
$areanames{en}->{61355107} = "Mortlake";
$areanames{en}->{61355108} = "Mortlake";
$areanames{en}->{61355109} = "Dundonnell";
$areanames{en}->{61355110} = "Mount\ Richmond";
$areanames{en}->{61355111} = "Mount\ Richmond";
$areanames{en}->{61355112} = "Mount\ Richmond";
$areanames{en}->{61355113} = "Nirranda";
$areanames{en}->{61355114} = "Nirranda";
$areanames{en}->{61355115} = "Nirranda";
$areanames{en}->{61355116} = "Ozenkadnook";
$areanames{en}->{61355117} = "Ozenkadnook";
$areanames{en}->{61355118} = "Ozenkadnook";
$areanames{en}->{61355119} = "Cobden";
$areanames{en}->{61355120} = "Panmure";
$areanames{en}->{61355121} = "Panmure";
$areanames{en}->{61355122} = "Panmure";
$areanames{en}->{61355123} = "Penshurst";
$areanames{en}->{61355124} = "Penshurst";
$areanames{en}->{61355125} = "Penshurst";
$areanames{en}->{61355126} = "Pomborneit";
$areanames{en}->{61355127} = "Pomborneit";
$areanames{en}->{61355128} = "Pomborneit";
$areanames{en}->{61355129} = "Caramut";
$areanames{en}->{61355130} = "Poolaijelo";
$areanames{en}->{61355131} = "Poolaijelo";
$areanames{en}->{61355132} = "Poolaijelo";
$areanames{en}->{61355133} = "Port\ Fairy";
$areanames{en}->{61355134} = "Port\ Fairy";
$areanames{en}->{61355135} = "Port\ Fairy";
$areanames{en}->{61355136} = "Portland";
$areanames{en}->{61355137} = "Portland";
$areanames{en}->{61355138} = "Portland";
$areanames{en}->{61355139} = "Camperdown";
$areanames{en}->{61355140} = "South\ Purrumbete";
$areanames{en}->{61355141} = "South\ Purrumbete";
$areanames{en}->{61355142} = "South\ Purrumbete";
$areanames{en}->{61355143} = "Strathdownie";
$areanames{en}->{61355144} = "Strathdownie";
$areanames{en}->{61355145} = "Strathdownie";
$areanames{en}->{61355146} = "Tahara";
$areanames{en}->{61355147} = "Tahara";
$areanames{en}->{61355148} = "Tahara";
$areanames{en}->{61355149} = "Dorodong";
$areanames{en}->{61355150} = "Terang";
$areanames{en}->{61355151} = "Terang";
$areanames{en}->{61355152} = "Terang";
$areanames{en}->{61355153} = "Timboon";
$areanames{en}->{61355154} = "Timboon";
$areanames{en}->{61355155} = "Timboon";
$areanames{en}->{61355156} = "Tyrendarra";
$areanames{en}->{61355157} = "Tyrendarra";
$areanames{en}->{61355158} = "Tyrendarra";
$areanames{en}->{61355159} = "Lake\ Mundi";
$areanames{en}->{61355160} = "Victoria\ Valley";
$areanames{en}->{61355161} = "Victoria\ Valley";
$areanames{en}->{61355162} = "Victoria\ Valley";
$areanames{en}->{61355163} = "Wallacedale";
$areanames{en}->{61355164} = "Wallacedale";
$areanames{en}->{61355165} = "Wallacedale";
$areanames{en}->{61355166} = "Warrnambool";
$areanames{en}->{61355167} = "Warrnambool";
$areanames{en}->{61355168} = "Warrnambool";
$areanames{en}->{61355169} = "Strathdownie";
$areanames{en}->{61355170} = "Wombelano";
$areanames{en}->{61355171} = "Wombelano";
$areanames{en}->{61355172} = "Wombelano";
$areanames{en}->{61355173} = "Woodhouse";
$areanames{en}->{61355174} = "Woodhouse";
$areanames{en}->{61355175} = "Woodhouse";
$areanames{en}->{61355176} = "Woolsthorpe";
$areanames{en}->{61355177} = "Woolsthorpe";
$areanames{en}->{61355178} = "Woolsthorpe";
$areanames{en}->{61355179} = "Woolsthorpe";
$areanames{en}->{61355180} = "Casterton";
$areanames{en}->{61355181} = "Chetwynd";
$areanames{en}->{61355182} = "Apsley";
$areanames{en}->{61355183} = "Benayeo";
$areanames{en}->{61355184} = "Edenhope";
$areanames{en}->{61355185} = "Ozenkadnook";
$areanames{en}->{61355186} = "Poolaijelo";
$areanames{en}->{61355187} = "Penshurst";
$areanames{en}->{61355188} = "Tahara";
$areanames{en}->{61355189} = "Victoria\ Valley";
$areanames{en}->{61355190} = "Wallacedale";
$areanames{en}->{61355191} = "Wombelano";
$areanames{en}->{61355192} = "Woodhouse";
$areanames{en}->{61355193} = "Bessiebelle";
$areanames{en}->{61355194} = "Cavendish";
$areanames{en}->{61355195} = "Coleraine";
$areanames{en}->{61355196} = "Coojar";
$areanames{en}->{61355197} = "Dunkeld";
$areanames{en}->{61355198} = "Glenthompson";
$areanames{en}->{61355199} = "Hamilton";
$areanames{en}->{61355200} = "Portland";
$areanames{en}->{61355201} = "Tyrendarra";
$areanames{en}->{61355202} = "Mount\ Richmond";
$areanames{en}->{61355203} = "Hawkesdale";
$areanames{en}->{61355204} = "Nirranda";
$areanames{en}->{61355205} = "Panmure";
$areanames{en}->{61355206} = "Port\ Fairy";
$areanames{en}->{61355207} = "Warrnambool";
$areanames{en}->{61355208} = "Mount\ Richmond";
$areanames{en}->{61355209} = "Mount\ Richmond";
$areanames{en}->{6135521} = "Portland";
$areanames{en}->{6135522} = "Portland";
$areanames{en}->{61355226} = "Heywood";
$areanames{en}->{61355227} = "Dartmoor";
$areanames{en}->{61355228} = "Tyrendarra";
$areanames{en}->{61355229} = "Mount\ Richmond";
$areanames{en}->{6135523} = "Portland";
$areanames{en}->{61355240} = "Harrow";
$areanames{en}->{61355241} = "Macarthur";
$areanames{en}->{61355242} = "Merino";
$areanames{en}->{61355243} = "Balmoral";
$areanames{en}->{61355244} = "Tyrendarra";
$areanames{en}->{61355245} = "Dartmoor";
$areanames{en}->{61355246} = "Heywood";
$areanames{en}->{61355247} = "Mount\ Richmond";
$areanames{en}->{61355248} = "Portland";
$areanames{en}->{61355249} = "Woolsthorpe";
$areanames{en}->{6135525} = "Portland";
$areanames{en}->{6135526} = "Portland";
$areanames{en}->{6135527} = "Heywood";
$areanames{en}->{6135528} = "Dartmoor";
$areanames{en}->{6135529} = "Tyrendarra";
$areanames{en}->{61355300} = "Penshurst";
$areanames{en}->{61355301} = "Tahara";
$areanames{en}->{61355302} = "Victoria\ Valley";
$areanames{en}->{61355303} = "Wallacedale";
$areanames{en}->{61355304} = "Wombelano";
$areanames{en}->{61355305} = "Woodhouse";
$areanames{en}->{61355306} = "Dartmoor";
$areanames{en}->{61355307} = "Heywood";
$areanames{en}->{61355308} = "Mount\ Richmond";
$areanames{en}->{61355309} = "Portland";
$areanames{en}->{61355310} = "Bessiebelle";
$areanames{en}->{61355311} = "Cavendish";
$areanames{en}->{61355312} = "Coleraine";
$areanames{en}->{61355313} = "Coojar";
$areanames{en}->{61355314} = "Dunkeld";
$areanames{en}->{61355315} = "Glenthompson";
$areanames{en}->{61355316} = "Hamilton";
$areanames{en}->{61355317} = "Harrow";
$areanames{en}->{61355318} = "Macarthur";
$areanames{en}->{61355319} = "Merino";
$areanames{en}->{61355320} = "Dorodong";
$areanames{en}->{61355321} = "Lake\ Mundi";
$areanames{en}->{61355322} = "Strathdownie";
$areanames{en}->{61355323} = "Apsley";
$areanames{en}->{61355324} = "Benayeo";
$areanames{en}->{61355325} = "Edenhope";
$areanames{en}->{61355326} = "Ozenkadnook";
$areanames{en}->{61355327} = "Poolaijelo";
$areanames{en}->{61355328} = "Balmoral";
$areanames{en}->{61355329} = "Timboon";
$areanames{en}->{61355330} = "Casterton";
$areanames{en}->{61355331} = "Chetwynd";
$areanames{en}->{61355332} = "Terang";
$areanames{en}->{61355333} = "South\ Purrumbete";
$areanames{en}->{61355334} = "Pomborneit";
$areanames{en}->{61355335} = "Ecklin";
$areanames{en}->{61355336} = "Lismore";
$areanames{en}->{61355337} = "Mortlake";
$areanames{en}->{61355338} = "Darlington";
$areanames{en}->{61355339} = "Derrinallum";
$areanames{en}->{61355340} = "Dundonnell";
$areanames{en}->{61355341} = "Cobden";
$areanames{en}->{61355342} = "Caramut";
$areanames{en}->{61355343} = "Camperdown";
$areanames{en}->{61355344} = "Hawkesdale";
$areanames{en}->{61355345} = "Nirranda";
$areanames{en}->{61355346} = "Panmure";
$areanames{en}->{61355347} = "Port\ Fairy";
$areanames{en}->{61355348} = "Warrnambool";
$areanames{en}->{613553490} = "Camperdown";
$areanames{en}->{613553491} = "Camperdown";
$areanames{en}->{613553492} = "Camperdown";
$areanames{en}->{613553493} = "Camperdown";
$areanames{en}->{613553494} = "Camperdown";
$areanames{en}->{613553495} = "Hamilton";
$areanames{en}->{613553496} = "Camperdown";
$areanames{en}->{613553497} = "Camperdown";
$areanames{en}->{613553500} = "Caramut";
$areanames{en}->{613553501} = "Caramut";
$areanames{en}->{613553502} = "Caramut";
$areanames{en}->{613553503} = "Caramut";
$areanames{en}->{613553504} = "Caramut";
$areanames{en}->{613553505} = "Portland";
$areanames{en}->{613553506} = "Caramut";
$areanames{en}->{613553507} = "Caramut";
$areanames{en}->{613553510} = "Cobden";
$areanames{en}->{613553511} = "Cobden";
$areanames{en}->{613553512} = "Cobden";
$areanames{en}->{613553513} = "Cobden";
$areanames{en}->{613553514} = "Cobden";
$areanames{en}->{613553515} = "Cobden";
$areanames{en}->{613553516} = "Cobden";
$areanames{en}->{613553517} = "Cobden";
$areanames{en}->{613553520} = "Darlington";
$areanames{en}->{613553521} = "Darlington";
$areanames{en}->{613553522} = "Darlington";
$areanames{en}->{613553523} = "Darlington";
$areanames{en}->{613553524} = "Darlington";
$areanames{en}->{613553525} = "Darlington";
$areanames{en}->{613553526} = "Darlington";
$areanames{en}->{613553527} = "Darlington";
$areanames{en}->{613553530} = "Derrinallum";
$areanames{en}->{613553531} = "Derrinallum";
$areanames{en}->{613553532} = "Derrinallum";
$areanames{en}->{613553533} = "Derrinallum";
$areanames{en}->{613553536} = "Derrinallum";
$areanames{en}->{613553540} = "Dundonnell";
$areanames{en}->{613553541} = "Dundonnell";
$areanames{en}->{613553542} = "Dundonnell";
$areanames{en}->{613553543} = "Dundonnell";
$areanames{en}->{613553546} = "Dundonnell";
$areanames{en}->{613553550} = "Ecklin";
$areanames{en}->{613553551} = "Ecklin";
$areanames{en}->{613553552} = "Ecklin";
$areanames{en}->{613553553} = "Ecklin";
$areanames{en}->{613553556} = "Ecklin";
$areanames{en}->{613553560} = "Lismore";
$areanames{en}->{613553561} = "Lismore";
$areanames{en}->{613553562} = "Lismore";
$areanames{en}->{613553563} = "Lismore";
$areanames{en}->{613553566} = "Lismore";
$areanames{en}->{613553570} = "Mortlake";
$areanames{en}->{613553571} = "Mortlake";
$areanames{en}->{613553572} = "Mortlake";
$areanames{en}->{613553573} = "Mortlake";
$areanames{en}->{613553576} = "Mortlake";
$areanames{en}->{613553580} = "Pomborneit";
$areanames{en}->{613553581} = "Pomborneit";
$areanames{en}->{613553582} = "Pomborneit";
$areanames{en}->{613553583} = "Pomborneit";
$areanames{en}->{613553586} = "Pomborneit";
$areanames{en}->{613553590} = "South\ Purrumbete";
$areanames{en}->{613553591} = "South\ Purrumbete";
$areanames{en}->{613553592} = "South\ Purrumbete";
$areanames{en}->{613553593} = "South\ Purrumbete";
$areanames{en}->{613553596} = "South\ Purrumbete";
$areanames{en}->{613553600} = "Terang";
$areanames{en}->{613553601} = "Terang";
$areanames{en}->{613553602} = "Terang";
$areanames{en}->{613553603} = "Terang";
$areanames{en}->{613553604} = "Terang";
$areanames{en}->{613553605} = "Terang";
$areanames{en}->{613553606} = "Terang";
$areanames{en}->{613553607} = "Terang";
$areanames{en}->{613553610} = "Timboon";
$areanames{en}->{613553611} = "Timboon";
$areanames{en}->{613553612} = "Timboon";
$areanames{en}->{613553613} = "Timboon";
$areanames{en}->{613553614} = "Timboon";
$areanames{en}->{613553615} = "Timboon";
$areanames{en}->{613553616} = "Timboon";
$areanames{en}->{613553617} = "Timboon";
$areanames{en}->{613553618} = "Timboon";
$areanames{en}->{613553620} = "Casterton";
$areanames{en}->{613553621} = "Casterton";
$areanames{en}->{613553622} = "Casterton";
$areanames{en}->{613553623} = "Casterton";
$areanames{en}->{613553626} = "Casterton";
$areanames{en}->{613553630} = "Chetwynd";
$areanames{en}->{613553631} = "Chetwynd";
$areanames{en}->{613553632} = "Chetwynd";
$areanames{en}->{613553633} = "Chetwynd";
$areanames{en}->{613553636} = "Chetwynd";
$areanames{en}->{613553640} = "Dorodong";
$areanames{en}->{613553641} = "Dorodong";
$areanames{en}->{613553642} = "Dorodong";
$areanames{en}->{613553643} = "Dorodong";
$areanames{en}->{613553646} = "Dorodong";
$areanames{en}->{613553650} = "Lake\ Mundi";
$areanames{en}->{613553651} = "Lake\ Mundi";
$areanames{en}->{613553652} = "Lake\ Mundi";
$areanames{en}->{613553653} = "Lake\ Mundi";
$areanames{en}->{613553656} = "Lake\ Mundi";
$areanames{en}->{613553660} = "Strathdownie";
$areanames{en}->{613553661} = "Strathdownie";
$areanames{en}->{613553662} = "Strathdownie";
$areanames{en}->{613553663} = "Strathdownie";
$areanames{en}->{613553666} = "Strathdownie";
$areanames{en}->{613553670} = "Apsley";
$areanames{en}->{613553671} = "Apsley";
$areanames{en}->{613553672} = "Apsley";
$areanames{en}->{613553673} = "Apsley";
$areanames{en}->{613553676} = "Apsley";
$areanames{en}->{613553680} = "Benayeo";
$areanames{en}->{613553681} = "Benayeo";
$areanames{en}->{613553682} = "Benayeo";
$areanames{en}->{613553683} = "Benayeo";
$areanames{en}->{613553686} = "Benayeo";
$areanames{en}->{613553690} = "Edenhope";
$areanames{en}->{613553691} = "Edenhope";
$areanames{en}->{613553692} = "Edenhope";
$areanames{en}->{613553693} = "Edenhope";
$areanames{en}->{613553694} = "Edenhope";
$areanames{en}->{613553695} = "Edenhope";
$areanames{en}->{613553696} = "Edenhope";
$areanames{en}->{613553697} = "Edenhope";
$areanames{en}->{613553700} = "Ozenkadnook";
$areanames{en}->{613553701} = "Ozenkadnook";
$areanames{en}->{613553702} = "Ozenkadnook";
$areanames{en}->{613553703} = "Ozenkadnook";
$areanames{en}->{613553706} = "Ozenkadnook";
$areanames{en}->{613553710} = "Poolaijelo";
$areanames{en}->{613553711} = "Poolaijelo";
$areanames{en}->{613553712} = "Poolaijelo";
$areanames{en}->{613553713} = "Poolaijelo";
$areanames{en}->{613553716} = "Poolaijelo";
$areanames{en}->{613553720} = "Balmoral";
$areanames{en}->{613553721} = "Balmoral";
$areanames{en}->{613553722} = "Balmoral";
$areanames{en}->{613553723} = "Balmoral";
$areanames{en}->{613553726} = "Balmoral";
$areanames{en}->{613553730} = "Bessiebelle";
$areanames{en}->{613553731} = "Bessiebelle";
$areanames{en}->{613553732} = "Bessiebelle";
$areanames{en}->{613553733} = "Bessiebelle";
$areanames{en}->{613553736} = "Bessiebelle";
$areanames{en}->{613553740} = "Cavendish";
$areanames{en}->{613553741} = "Cavendish";
$areanames{en}->{613553742} = "Cavendish";
$areanames{en}->{613553743} = "Cavendish";
$areanames{en}->{613553746} = "Cavendish";
$areanames{en}->{613553750} = "Coleraine";
$areanames{en}->{613553751} = "Coleraine";
$areanames{en}->{613553752} = "Coleraine";
$areanames{en}->{613553753} = "Coleraine";
$areanames{en}->{613553756} = "Coleraine";
$areanames{en}->{613553760} = "Coojar";
$areanames{en}->{613553761} = "Coojar";
$areanames{en}->{613553762} = "Coojar";
$areanames{en}->{613553763} = "Coojar";
$areanames{en}->{613553766} = "Coojar";
$areanames{en}->{613553770} = "Dunkeld";
$areanames{en}->{613553771} = "Dunkeld";
$areanames{en}->{613553772} = "Dunkeld";
$areanames{en}->{613553773} = "Dunkeld";
$areanames{en}->{613553776} = "Dunkeld";
$areanames{en}->{613553780} = "Glenthompson";
$areanames{en}->{613553781} = "Glenthompson";
$areanames{en}->{613553782} = "Glenthompson";
$areanames{en}->{613553783} = "Glenthompson";
$areanames{en}->{613553786} = "Glenthompson";
$areanames{en}->{613553790} = "Hamilton";
$areanames{en}->{613553791} = "Hamilton";
$areanames{en}->{613553792} = "Hamilton";
$areanames{en}->{613553793} = "Hamilton";
$areanames{en}->{613553794} = "Hamilton";
$areanames{en}->{613553799} = "Hamilton";
$areanames{en}->{613553800} = "Harrow";
$areanames{en}->{613553801} = "Harrow";
$areanames{en}->{613553802} = "Harrow";
$areanames{en}->{613553803} = "Harrow";
$areanames{en}->{613553806} = "Harrow";
$areanames{en}->{613553810} = "Macarthur";
$areanames{en}->{613553811} = "Macarthur";
$areanames{en}->{613553812} = "Macarthur";
$areanames{en}->{613553813} = "Macarthur";
$areanames{en}->{613553816} = "Macarthur";
$areanames{en}->{613553820} = "Merino";
$areanames{en}->{613553821} = "Merino";
$areanames{en}->{613553822} = "Merino";
$areanames{en}->{613553823} = "Merino";
$areanames{en}->{613553826} = "Merino";
$areanames{en}->{613553830} = "Penshurst";
$areanames{en}->{613553831} = "Penshurst";
$areanames{en}->{613553832} = "Penshurst";
$areanames{en}->{613553833} = "Penshurst";
$areanames{en}->{613553836} = "Penshurst";
$areanames{en}->{613553840} = "Tahara";
$areanames{en}->{613553841} = "Tahara";
$areanames{en}->{613553842} = "Tahara";
$areanames{en}->{613553843} = "Tahara";
$areanames{en}->{613553846} = "Tahara";
$areanames{en}->{613553850} = "Victoria\ Valley";
$areanames{en}->{613553851} = "Victoria\ Valley";
$areanames{en}->{613553852} = "Victoria\ Valley";
$areanames{en}->{613553853} = "Victoria\ Valley";
$areanames{en}->{613553856} = "Victoria\ Valley";
$areanames{en}->{613553860} = "Wallacedale";
$areanames{en}->{613553861} = "Wallacedale";
$areanames{en}->{613553862} = "Wallacedale";
$areanames{en}->{613553863} = "Wallacedale";
$areanames{en}->{613553866} = "Wallacedale";
$areanames{en}->{613553870} = "Wombelano";
$areanames{en}->{613553871} = "Wombelano";
$areanames{en}->{613553872} = "Wombelano";
$areanames{en}->{613553873} = "Wombelano";
$areanames{en}->{613553876} = "Wombelano";
$areanames{en}->{613553880} = "Woodhouse";
$areanames{en}->{613553881} = "Woodhouse";
$areanames{en}->{613553882} = "Woodhouse";
$areanames{en}->{613553883} = "Woodhouse";
$areanames{en}->{613553886} = "Woodhouse";
$areanames{en}->{613553890} = "Dartmoor";
$areanames{en}->{613553891} = "Dartmoor";
$areanames{en}->{613553892} = "Dartmoor";
$areanames{en}->{613553893} = "Dartmoor";
$areanames{en}->{613553896} = "Dartmoor";
$areanames{en}->{613553900} = "Heywood";
$areanames{en}->{613553901} = "Heywood";
$areanames{en}->{613553902} = "Heywood";
$areanames{en}->{613553903} = "Heywood";
$areanames{en}->{613553904} = "Heywood";
$areanames{en}->{613553905} = "Heywood";
$areanames{en}->{613553906} = "Heywood";
$areanames{en}->{613553907} = "Heywood";
$areanames{en}->{613553910} = "Mount\ Richmond";
$areanames{en}->{613553911} = "Mount\ Richmond";
$areanames{en}->{613553912} = "Mount\ Richmond";
$areanames{en}->{613553913} = "Mount\ Richmond";
$areanames{en}->{613553916} = "Mount\ Richmond";
$areanames{en}->{613553920} = "Portland";
$areanames{en}->{613553921} = "Portland";
$areanames{en}->{613553922} = "Portland";
$areanames{en}->{613553923} = "Portland";
$areanames{en}->{613553924} = "Portland";
$areanames{en}->{613553925} = "Portland";
$areanames{en}->{613553930} = "Tyrendarra";
$areanames{en}->{613553931} = "Tyrendarra";
$areanames{en}->{613553932} = "Tyrendarra";
$areanames{en}->{613553933} = "Tyrendarra";
$areanames{en}->{613553936} = "Tyrendarra";
$areanames{en}->{613553940} = "Hawkesdale";
$areanames{en}->{613553941} = "Hawkesdale";
$areanames{en}->{613553942} = "Hawkesdale";
$areanames{en}->{613553943} = "Hawkesdale";
$areanames{en}->{613553946} = "Hawkesdale";
$areanames{en}->{613553950} = "Nirranda";
$areanames{en}->{613553951} = "Nirranda";
$areanames{en}->{613553952} = "Nirranda";
$areanames{en}->{613553953} = "Nirranda";
$areanames{en}->{613553960} = "Panmure";
$areanames{en}->{613553961} = "Panmure";
$areanames{en}->{613553962} = "Panmure";
$areanames{en}->{613553963} = "Panmure";
$areanames{en}->{613553964} = "Panmure";
$areanames{en}->{613553965} = "Panmure";
$areanames{en}->{613553966} = "Panmure";
$areanames{en}->{613553967} = "Panmure";
$areanames{en}->{613553970} = "Port\ Fairy";
$areanames{en}->{613553971} = "Port\ Fairy";
$areanames{en}->{613553972} = "Port\ Fairy";
$areanames{en}->{613553973} = "Port\ Fairy";
$areanames{en}->{613553974} = "Port\ Fairy";
$areanames{en}->{613553975} = "Port\ Fairy";
$areanames{en}->{613553976} = "Port\ Fairy";
$areanames{en}->{613553977} = "Port\ Fairy";
$areanames{en}->{613553978} = "Port\ Fairy";
$areanames{en}->{613553980} = "Warrnambool";
$areanames{en}->{613553981} = "Warrnambool";
$areanames{en}->{613553982} = "Warrnambool";
$areanames{en}->{613553983} = "Warrnambool";
$areanames{en}->{613553984} = "Warrnambool";
$areanames{en}->{613553988} = "Warrnambool";
$areanames{en}->{613553990} = "Woolsthorpe";
$areanames{en}->{613553991} = "Woolsthorpe";
$areanames{en}->{613553992} = "Woolsthorpe";
$areanames{en}->{613553993} = "Woolsthorpe";
$areanames{en}->{613553994} = "Woolsthorpe";
$areanames{en}->{613553995} = "Woolsthorpe";
$areanames{en}->{613553996} = "Woolsthorpe";
$areanames{en}->{613553997} = "Woolsthorpe";
$areanames{en}->{61355400} = "Chetwynd";
$areanames{en}->{61355401} = "Chetwynd";
$areanames{en}->{61355402} = "Casterton";
$areanames{en}->{61355403} = "Camperdown";
$areanames{en}->{61355404} = "Caramut";
$areanames{en}->{61355405} = "Cobden";
$areanames{en}->{61355406} = "Darlington";
$areanames{en}->{61355407} = "Derrinallum";
$areanames{en}->{61355408} = "Dundonnell";
$areanames{en}->{61355409} = "Ecklin";
$areanames{en}->{61355410} = "Lismore";
$areanames{en}->{61355411} = "Mortlake";
$areanames{en}->{61355412} = "Pomborneit";
$areanames{en}->{61355413} = "South\ Purrumbete";
$areanames{en}->{61355414} = "Terang";
$areanames{en}->{61355415} = "Timboon";
$areanames{en}->{61355416} = "Casterton";
$areanames{en}->{61355417} = "Chetwynd";
$areanames{en}->{61355418} = "Dorodong";
$areanames{en}->{61355419} = "Lake\ Mundi";
$areanames{en}->{61355420} = "Strathdownie";
$areanames{en}->{61355421} = "Apsley";
$areanames{en}->{61355422} = "Benayeo";
$areanames{en}->{61355423} = "Edenhope";
$areanames{en}->{61355424} = "Ozenkadnook";
$areanames{en}->{61355425} = "Poolaijelo";
$areanames{en}->{61355426} = "Balmoral";
$areanames{en}->{61355427} = "Bessiebelle";
$areanames{en}->{61355428} = "Coleraine";
$areanames{en}->{61355429} = "Coojar";
$areanames{en}->{61355430} = "Dunkeld";
$areanames{en}->{61355431} = "Glenthompson";
$areanames{en}->{61355432} = "Harrow";
$areanames{en}->{61355433} = "Macarthur";
$areanames{en}->{61355434} = "Merino";
$areanames{en}->{61355435} = "Penshurst";
$areanames{en}->{61355436} = "Tahara";
$areanames{en}->{61355437} = "Victoria\ Valley";
$areanames{en}->{61355438} = "Wallacedale";
$areanames{en}->{61355439} = "Wombelano";
$areanames{en}->{61355440} = "Woodhouse";
$areanames{en}->{61355441} = "Dartmoor";
$areanames{en}->{61355442} = "Mount\ Richmond";
$areanames{en}->{61355443} = "Tyrendarra";
$areanames{en}->{61355444} = "Hawkesdale";
$areanames{en}->{61355445} = "Nirranda";
$areanames{en}->{61355446} = "Panmure";
$areanames{en}->{61355447} = "Port\ Fairy";
$areanames{en}->{61355448} = "Woolsthorpe";
$areanames{en}->{61355449} = "Edenhope";
$areanames{en}->{61355450} = "Portland";
$areanames{en}->{61355451} = "Heywood";
$areanames{en}->{61355452} = "Hamilton";
$areanames{en}->{61355453} = "Warrnambool";
$areanames{en}->{61355454} = "Caramut";
$areanames{en}->{61355455} = "Caramut";
$areanames{en}->{61355456} = "Cobden";
$areanames{en}->{61355457} = "Cobden";
$areanames{en}->{61355458} = "Darlington";
$areanames{en}->{61355459} = "Darlington";
$areanames{en}->{61355460} = "Derrinallum";
$areanames{en}->{61355461} = "Derrinallum";
$areanames{en}->{61355462} = "Dundonnell";
$areanames{en}->{61355463} = "Dundonnell";
$areanames{en}->{61355464} = "Ecklin";
$areanames{en}->{61355465} = "Ecklin";
$areanames{en}->{61355466} = "Lismore";
$areanames{en}->{61355467} = "Lismore";
$areanames{en}->{61355468} = "Mortlake";
$areanames{en}->{61355469} = "Mortlake";
$areanames{en}->{61355470} = "Pomborneit";
$areanames{en}->{61355471} = "Pomborneit";
$areanames{en}->{61355472} = "South\ Purrumbete";
$areanames{en}->{61355473} = "South\ Purrumbete";
$areanames{en}->{61355474} = "Terang";
$areanames{en}->{61355475} = "Terang";
$areanames{en}->{61355476} = "Timboon";
$areanames{en}->{61355477} = "Timboon";
$areanames{en}->{61355478} = "Casterton";
$areanames{en}->{61355479} = "Casterton";
$areanames{en}->{61355480} = "Strathdownie";
$areanames{en}->{61355481} = "Strathdownie";
$areanames{en}->{61355482} = "Heywood";
$areanames{en}->{61355483} = "Heywood";
$areanames{en}->{61355484} = "Portland";
$areanames{en}->{61355485} = "Portland";
$areanames{en}->{61355486} = "Tyrendarra";
$areanames{en}->{61355487} = "Tyrendarra";
$areanames{en}->{61355488} = "Tyrendarra";
$areanames{en}->{61355489} = "Tyrendarra";
$areanames{en}->{61355490} = "Edenhope";
$areanames{en}->{61355491} = "Edenhope";
$areanames{en}->{61355492} = "Apsley";
$areanames{en}->{61355493} = "Apsley";
$areanames{en}->{61355494} = "Bessiebelle";
$areanames{en}->{61355495} = "Bessiebelle";
$areanames{en}->{61355496} = "Cavendish";
$areanames{en}->{61355497} = "Cavendish";
$areanames{en}->{61355498} = "Coleraine";
$areanames{en}->{61355499} = "Coleraine";
$areanames{en}->{6135551} = "Hamilton";
$areanames{en}->{61355520} = "Cavendish";
$areanames{en}->{61355521} = "Victoria\ Valley";
$areanames{en}->{61355522} = "Macarthur";
$areanames{en}->{61355523} = "Penshurst";
$areanames{en}->{61355524} = "Dunkeld";
$areanames{en}->{61355525} = "Glenthompson";
$areanames{en}->{61355526} = "Bessiebelle";
$areanames{en}->{61355527} = "Woodhouse";
$areanames{en}->{61355528} = "Wallacedale";
$areanames{en}->{61355529} = "Balmoral";
$areanames{en}->{6135553} = "Coleraine";
$areanames{en}->{61355537} = "Tahara";
$areanames{en}->{61355538} = "Coojar";
$areanames{en}->{61355539} = "Merino";
$areanames{en}->{6135554} = "Casterton";
$areanames{en}->{61355546} = "Chetwynd";
$areanames{en}->{61355547} = "Dorodong";
$areanames{en}->{61355548} = "Lake\ Mundi";
$areanames{en}->{61355549} = "Strathdownie";
$areanames{en}->{6135555} = "Apsley";
$areanames{en}->{61355560} = "Edenhope";
$areanames{en}->{61355561} = "Coojar";
$areanames{en}->{61355562} = "Coojar";
$areanames{en}->{61355563} = "Dunkeld";
$areanames{en}->{61355564} = "Dunkeld";
$areanames{en}->{61355565} = "Glenthompson";
$areanames{en}->{61355566} = "Glenthompson";
$areanames{en}->{61355567} = "Dorodong";
$areanames{en}->{61355568} = "Dorodong";
$areanames{en}->{61355569} = "Warrnambool";
$areanames{en}->{6135557} = "Camperdown";
$areanames{en}->{61355578} = "Terang";
$areanames{en}->{61355579} = "Ecklin";
$areanames{en}->{61355580} = "South\ Purrumbete";
$areanames{en}->{61355581} = "Pomborneit";
$areanames{en}->{61355582} = "Cobden";
$areanames{en}->{61355583} = "Lismore";
$areanames{en}->{61355584} = "Derrinallum";
$areanames{en}->{61355585} = "Darlington";
$areanames{en}->{61355586} = "Timboon";
$areanames{en}->{61355587} = "Mortlake";
$areanames{en}->{61355588} = "Caramut";
$areanames{en}->{61355589} = "Dundonnell";
$areanames{en}->{6135559} = "Warrnambool";
$areanames{en}->{61355600} = "Warrnambool";
$areanames{en}->{61355601} = "Warrnambool";
$areanames{en}->{61355602} = "Warrnambool";
$areanames{en}->{61355603} = "Warrnambool";
$areanames{en}->{61355604} = "Lismore";
$areanames{en}->{61355605} = "Warrnambool";
$areanames{en}->{61355606} = "Hawkesdale";
$areanames{en}->{61355607} = "Hawkesdale";
$areanames{en}->{61355608} = "Hawkesdale";
$areanames{en}->{61355609} = "Hawkesdale";
$areanames{en}->{6135561} = "Warrnambool";
$areanames{en}->{6135562} = "Warrnambool";
$areanames{en}->{61355630} = "Warrnambool";
$areanames{en}->{61355631} = "Warrnambool";
$areanames{en}->{61355632} = "Warrnambool";
$areanames{en}->{61355633} = "Warrnambool";
$areanames{en}->{61355634} = "Warrnambool";
$areanames{en}->{61355635} = "Nirranda";
$areanames{en}->{61355636} = "Panmure";
$areanames{en}->{61355637} = "Port\ Fairy";
$areanames{en}->{61355638} = "Woolsthorpe";
$areanames{en}->{61355639} = "Hawkesdale";
$areanames{en}->{6135564} = "Warrnambool";
$areanames{en}->{6135565} = "Warrnambool";
$areanames{en}->{6135566} = "Nirranda";
$areanames{en}->{6135567} = "Panmure";
$areanames{en}->{6135568} = "Port\ Fairy";
$areanames{en}->{6135569} = "Woolsthorpe";
$areanames{en}->{61355700} = "Tahara";
$areanames{en}->{61355701} = "Balmoral";
$areanames{en}->{61355702} = "Balmoral";
$areanames{en}->{61355703} = "Lismore";
$areanames{en}->{61355704} = "Balmoral";
$areanames{en}->{61355705} = "Macarthur";
$areanames{en}->{61355706} = "Macarthur";
$areanames{en}->{61355707} = "Lismore";
$areanames{en}->{61355708} = "Tahara";
$areanames{en}->{61355709} = "Tahara";
$areanames{en}->{6135571} = "Hamilton";
$areanames{en}->{6135572} = "Hamilton";
$areanames{en}->{6135573} = "Hamilton";
$areanames{en}->{61355740} = "Victoria\ Valley";
$areanames{en}->{61355741} = "Cavendish";
$areanames{en}->{61355742} = "Cavendish";
$areanames{en}->{61355743} = "Cavendish";
$areanames{en}->{61355744} = "Hamilton";
$areanames{en}->{61355745} = "Hamilton";
$areanames{en}->{61355746} = "Cavendish";
$areanames{en}->{61355747} = "Victoria\ Valley";
$areanames{en}->{61355748} = "Cavendish";
$areanames{en}->{61355749} = "Victoria\ Valley";
$areanames{en}->{6135575} = "Coleraine";
$areanames{en}->{61355760} = "Apsley";
$areanames{en}->{61355761} = "Macarthur";
$areanames{en}->{61355762} = "Macarthur";
$areanames{en}->{61355763} = "Macarthur";
$areanames{en}->{61355764} = "Macarthur";
$areanames{en}->{61355765} = "Penshurst";
$areanames{en}->{61355766} = "Penshurst";
$areanames{en}->{61355767} = "Penshurst";
$areanames{en}->{61355768} = "Macarthur";
$areanames{en}->{61355769} = "Penshurst";
$areanames{en}->{61355770} = "Hamilton";
$areanames{en}->{61355771} = "Dunkeld";
$areanames{en}->{61355772} = "Dunkeld";
$areanames{en}->{61355773} = "Glenthompson";
$areanames{en}->{61355774} = "Glenthompson";
$areanames{en}->{61355775} = "Bessiebelle";
$areanames{en}->{61355776} = "Bessiebelle";
$areanames{en}->{61355777} = "Woodhouse";
$areanames{en}->{61355778} = "Woodhouse";
$areanames{en}->{61355779} = "Woodhouse";
$areanames{en}->{6135578} = "Wallacedale";
$areanames{en}->{61355790} = "Coojar";
$areanames{en}->{61355791} = "Merino";
$areanames{en}->{61355792} = "Merino";
$areanames{en}->{61355793} = "Merino";
$areanames{en}->{61355794} = "Tahara";
$areanames{en}->{61355795} = "Hamilton";
$areanames{en}->{61355796} = "Coojar";
$areanames{en}->{61355797} = "Coojar";
$areanames{en}->{61355798} = "Coojar";
$areanames{en}->{61355799} = "Portland";
$areanames{en}->{61355800} = "Warrnambool";
$areanames{en}->{6135581} = "Casterton";
$areanames{en}->{6135582} = "Casterton";
$areanames{en}->{6135583} = "Chetwynd";
$areanames{en}->{61355838} = "Dorodong";
$areanames{en}->{61355839} = "Dorodong";
$areanames{en}->{6135584} = "Lake\ Mundi";
$areanames{en}->{61355847} = "Strathdownie";
$areanames{en}->{61355848} = "Strathdownie";
$areanames{en}->{61355849} = "Strathdownie";
$areanames{en}->{6135585} = "Edenhope";
$areanames{en}->{6135586} = "Apsley";
$areanames{en}->{61355867} = "Poolaijelo";
$areanames{en}->{61355868} = "Poolaijelo";
$areanames{en}->{61355869} = "Poolaijelo";
$areanames{en}->{6135587} = "Ozenkadnook";
$areanames{en}->{61355876} = "Benayeo";
$areanames{en}->{61355877} = "Benayeo";
$areanames{en}->{61355878} = "Benayeo";
$areanames{en}->{61355879} = "Benayeo";
$areanames{en}->{61355880} = "Wombelano";
$areanames{en}->{61355881} = "Harrow";
$areanames{en}->{61355882} = "Harrow";
$areanames{en}->{61355883} = "Harrow";
$areanames{en}->{61355884} = "Harrow";
$areanames{en}->{61355885} = "Harrow";
$areanames{en}->{61355886} = "Wombelano";
$areanames{en}->{61355887} = "Wombelano";
$areanames{en}->{61355888} = "Wombelano";
$areanames{en}->{61355889} = "Wombelano";
$areanames{en}->{6135590} = "Dundonnell";
$areanames{en}->{6135591} = "Terang";
$areanames{en}->{61355910} = "Ecklin";
$areanames{en}->{61355917} = "Ecklin";
$areanames{en}->{61355918} = "Ecklin";
$areanames{en}->{6135592} = "Terang";
$areanames{en}->{6135593} = "Camperdown";
$areanames{en}->{61355940} = "Merino";
$areanames{en}->{61355941} = "Merino";
$areanames{en}->{61355943} = "South\ Purrumbete";
$areanames{en}->{61355944} = "South\ Purrumbete";
$areanames{en}->{61355945} = "South\ Purrumbete";
$areanames{en}->{61355946} = "South\ Purrumbete";
$areanames{en}->{61355947} = "Pomborneit";
$areanames{en}->{61355948} = "Pomborneit";
$areanames{en}->{61355949} = "Pomborneit";
$areanames{en}->{6135595} = "Cobden";
$areanames{en}->{6135596} = "Lismore";
$areanames{en}->{61355970} = "Darlington";
$areanames{en}->{61355971} = "Darlington";
$areanames{en}->{61355972} = "Penshurst";
$areanames{en}->{61355973} = "Penshurst";
$areanames{en}->{61355974} = "Hamilton";
$areanames{en}->{61355975} = "Derrinallum";
$areanames{en}->{61355976} = "Derrinallum";
$areanames{en}->{61355977} = "Derrinallum";
$areanames{en}->{61355978} = "Derrinallum";
$areanames{en}->{61355979} = "Darlington";
$areanames{en}->{6135598} = "Timboon";
$areanames{en}->{61355990} = "Hamilton";
$areanames{en}->{61355991} = "Mortlake";
$areanames{en}->{61355992} = "Mortlake";
$areanames{en}->{61355993} = "Mortlake";
$areanames{en}->{61355994} = "Mortlake";
$areanames{en}->{61355995} = "Mortlake";
$areanames{en}->{61355996} = "Caramut";
$areanames{en}->{61355997} = "Caramut";
$areanames{en}->{61355998} = "Caramut";
$areanames{en}->{61355999} = "Hamilton";
$areanames{en}->{61356000} = "Buffalo";
$areanames{en}->{61356001} = "Buffalo";
$areanames{en}->{61356002} = "Buffalo";
$areanames{en}->{61356003} = "Bunyip";
$areanames{en}->{61356004} = "Bunyip";
$areanames{en}->{61356005} = "Bunyip";
$areanames{en}->{61356006} = "Foster";
$areanames{en}->{61356007} = "Foster";
$areanames{en}->{61356008} = "Foster";
$areanames{en}->{61356009} = "Foster";
$areanames{en}->{61356010} = "Hill\ End";
$areanames{en}->{61356011} = "Hill\ End";
$areanames{en}->{61356012} = "Hill\ End";
$areanames{en}->{61356013} = "Icy\ Creek";
$areanames{en}->{61356014} = "Icy\ Creek";
$areanames{en}->{61356015} = "Icy\ Creek";
$areanames{en}->{61356016} = "Korumburra";
$areanames{en}->{61356017} = "Korumburra";
$areanames{en}->{61356018} = "Korumburra";
$areanames{en}->{61356019} = "Tidal\ River";
$areanames{en}->{61356020} = "Leongatha";
$areanames{en}->{61356021} = "Leongatha";
$areanames{en}->{61356022} = "Leongatha";
$areanames{en}->{61356023} = "Mirboo\ North";
$areanames{en}->{61356024} = "Mirboo\ North";
$areanames{en}->{61356025} = "Mirboo\ North";
$areanames{en}->{61356026} = "Neerim\ South";
$areanames{en}->{61356027} = "Neerim\ South";
$areanames{en}->{61356028} = "Neerim\ South";
$areanames{en}->{61356029} = "Toora";
$areanames{en}->{61356030} = "Poowong";
$areanames{en}->{61356031} = "Poowong";
$areanames{en}->{61356032} = "Poowong";
$areanames{en}->{61356033} = "San\ Remo";
$areanames{en}->{61356034} = "San\ Remo";
$areanames{en}->{61356035} = "San\ Remo";
$areanames{en}->{61356036} = "Tidal\ River";
$areanames{en}->{61356037} = "Tidal\ River";
$areanames{en}->{61356038} = "Tidal\ River";
$areanames{en}->{61356039} = "Buffalo";
$areanames{en}->{61356040} = "Toora";
$areanames{en}->{61356041} = "Toora";
$areanames{en}->{61356042} = "Toora";
$areanames{en}->{61356043} = "Trafalgar";
$areanames{en}->{61356044} = "Trafalgar";
$areanames{en}->{61356045} = "Trafalgar";
$areanames{en}->{61356046} = "Warragul";
$areanames{en}->{61356047} = "Warragul";
$areanames{en}->{61356048} = "Warragul";
$areanames{en}->{61356049} = "Warragul";
$areanames{en}->{61356050} = "Wonthaggi";
$areanames{en}->{61356051} = "Wonthaggi";
$areanames{en}->{61356052} = "Wonthaggi";
$areanames{en}->{61356053} = "Bunyip";
$areanames{en}->{61356054} = "Hill\ End";
$areanames{en}->{61356055} = "Icy\ Creek";
$areanames{en}->{61356056} = "Neerim\ South";
$areanames{en}->{61356057} = "Trafalgar";
$areanames{en}->{61356058} = "Warragul";
$areanames{en}->{61356059} = "Foster";
$areanames{en}->{61356060} = "Tidal\ River";
$areanames{en}->{61356061} = "Toora";
$areanames{en}->{61356062} = "Buffalo";
$areanames{en}->{61356063} = "Korumburra";
$areanames{en}->{61356064} = "Leongatha";
$areanames{en}->{61356065} = "Mirboo\ North";
$areanames{en}->{61356066} = "Poowong";
$areanames{en}->{61356067} = "San\ Remo";
$areanames{en}->{61356068} = "Wonthaggi";
$areanames{en}->{61356069} = "Korumburra";
$areanames{en}->{61356070} = "Leongatha";
$areanames{en}->{61356071} = "Mirboo\ North";
$areanames{en}->{61356072} = "Poowong";
$areanames{en}->{61356073} = "San\ Remo";
$areanames{en}->{61356074} = "Wonthaggi";
$areanames{en}->{61356075} = "Bunyip";
$areanames{en}->{61356076} = "Hill\ End";
$areanames{en}->{61356077} = "Icy\ Creek";
$areanames{en}->{61356078} = "Neerim\ South";
$areanames{en}->{61356079} = "Trafalgar";
$areanames{en}->{61356080} = "Warragul";
$areanames{en}->{61356081} = "Foster";
$areanames{en}->{61356082} = "Tidal\ River";
$areanames{en}->{61356083} = "Toora";
$areanames{en}->{61356084} = "Buffalo";
$areanames{en}->{61356085} = "Korumburra";
$areanames{en}->{61356086} = "Leongatha";
$areanames{en}->{61356087} = "Mirboo\ North";
$areanames{en}->{61356088} = "Poowong";
$areanames{en}->{61356089} = "San\ Remo";
$areanames{en}->{61356090} = "Wonthaggi";
$areanames{en}->{61356091} = "Bunyip";
$areanames{en}->{61356092} = "Hill\ End";
$areanames{en}->{61356093} = "Icy\ Creek";
$areanames{en}->{61356094} = "Neerim\ South";
$areanames{en}->{61356095} = "Trafalgar";
$areanames{en}->{61356096} = "Warragul";
$areanames{en}->{61356097} = "Buffalo";
$areanames{en}->{61356098} = "Bunyip";
$areanames{en}->{61356099} = "Foster";
$areanames{en}->{61356100} = "Hill\ End";
$areanames{en}->{61356101} = "Icy\ Creek";
$areanames{en}->{61356102} = "Korumburra";
$areanames{en}->{61356103} = "Leongatha";
$areanames{en}->{61356104} = "Mirboo\ North";
$areanames{en}->{61356105} = "Neerim\ South";
$areanames{en}->{61356106} = "Poowong";
$areanames{en}->{61356107} = "San\ Remo";
$areanames{en}->{61356108} = "Tidal\ River";
$areanames{en}->{61356109} = "Toora";
$areanames{en}->{61356110} = "Warragul";
$areanames{en}->{61356111} = "Warragul";
$areanames{en}->{61356112} = "Trafalgar";
$areanames{en}->{61356113} = "Warragul";
$areanames{en}->{61356114} = "Wonthaggi";
$areanames{en}->{61356115} = "Trafalgar";
$areanames{en}->{61356116} = "Hill\ End";
$areanames{en}->{61356117} = "Foster";
$areanames{en}->{61356118} = "Tidal\ River";
$areanames{en}->{61356119} = "Foster";
$areanames{en}->{61356120} = "Tidal\ River";
$areanames{en}->{61356121} = "Toora";
$areanames{en}->{61356122} = "Buffalo";
$areanames{en}->{61356123} = "Korumburra";
$areanames{en}->{61356124} = "Leongatha";
$areanames{en}->{61356125} = "Mirboo\ North";
$areanames{en}->{61356126} = "Poowong";
$areanames{en}->{61356127} = "San\ Remo";
$areanames{en}->{61356128} = "Wonthaggi";
$areanames{en}->{61356129} = "Bunyip";
$areanames{en}->{61356130} = "Icy\ Creek";
$areanames{en}->{61356131} = "Neerim\ South";
$areanames{en}->{61356132} = "Toora";
$areanames{en}->{61356133} = "Buffalo";
$areanames{en}->{61356134} = "Korumburra";
$areanames{en}->{61356135} = "Leongatha";
$areanames{en}->{61356136} = "Mirboo\ North";
$areanames{en}->{61356137} = "Poowong";
$areanames{en}->{61356138} = "San\ Remo";
$areanames{en}->{61356139} = "Wonthaggi";
$areanames{en}->{61356140} = "Bunyip";
$areanames{en}->{61356141} = "Hill\ End";
$areanames{en}->{61356142} = "Icy\ Creek";
$areanames{en}->{61356143} = "Neerim\ South";
$areanames{en}->{61356144} = "Trafalgar";
$areanames{en}->{61356145} = "Warragul";
$areanames{en}->{61356146} = "Foster";
$areanames{en}->{61356147} = "Tidal\ River";
$areanames{en}->{61356148} = "Toora";
$areanames{en}->{61356149} = "Buffalo";
$areanames{en}->{61356150} = "Korumburra";
$areanames{en}->{61356151} = "Leongatha";
$areanames{en}->{61356152} = "Mirboo\ North";
$areanames{en}->{61356153} = "Poowong";
$areanames{en}->{61356154} = "San\ Remo";
$areanames{en}->{61356155} = "Wonthaggi";
$areanames{en}->{61356156} = "Bunyip";
$areanames{en}->{61356157} = "Hill\ End";
$areanames{en}->{61356158} = "Icy\ Creek";
$areanames{en}->{61356159} = "Neerim\ South";
$areanames{en}->{61356160} = "Trafalgar";
$areanames{en}->{61356161} = "Warragul";
$areanames{en}->{61356162} = "Warragul";
$areanames{en}->{61356163} = "Buffalo";
$areanames{en}->{61356164} = "Toora";
$areanames{en}->{61356165} = "Bunyip";
$areanames{en}->{61356166} = "Foster";
$areanames{en}->{61356167} = "Leongatha";
$areanames{en}->{61356168} = "Mirboo\ North";
$areanames{en}->{61356169} = "Poowong";
$areanames{en}->{61356170} = "San\ Remo";
$areanames{en}->{61356171} = "Wonthaggi";
$areanames{en}->{61356172} = "Bunyip";
$areanames{en}->{61356173} = "Hill\ End";
$areanames{en}->{61356174} = "Icy\ Creek";
$areanames{en}->{61356175} = "Korumburra";
$areanames{en}->{61356176} = "Leongatha";
$areanames{en}->{61356177} = "Warragul";
$areanames{en}->{61356178} = "Bunyip";
$areanames{en}->{61356179} = "Bunyip";
$areanames{en}->{61356180} = "Leongatha";
$areanames{en}->{61356181} = "Wonthaggi";
$areanames{en}->{61356182} = "Warragul";
$areanames{en}->{61356183} = "Warragul";
$areanames{en}->{61356184} = "Tidal\ River";
$areanames{en}->{61356185} = "Tidal\ River";
$areanames{en}->{61356186} = "Warragul";
$areanames{en}->{61356187} = "Wonthaggi";
$areanames{en}->{61356188} = "Trafalgar";
$areanames{en}->{61356189} = "Warragul";
$areanames{en}->{61356190} = "Warragul";
$areanames{en}->{61356191} = "Toora";
$areanames{en}->{61356192} = "Wonthaggi";
$areanames{en}->{61356193} = "Neerim\ South";
$areanames{en}->{61356194} = "Bunyip";
$areanames{en}->{61356195} = "Buffalo";
$areanames{en}->{61356196} = "Poowong";
$areanames{en}->{61356197} = "Warragul";
$areanames{en}->{61356198} = "San\ Remo";
$areanames{en}->{61356199} = "Mirboo\ North";
$areanames{en}->{61356200} = "Neerim\ South";
$areanames{en}->{61356201} = "Hill\ End";
$areanames{en}->{61356202} = "Mirboo\ North";
$areanames{en}->{61356203} = "Leongatha";
$areanames{en}->{61356204} = "Tidal\ River";
$areanames{en}->{61356205} = "Foster";
$areanames{en}->{61356206} = "Korumburra";
$areanames{en}->{61356207} = "Toora";
$areanames{en}->{61356208} = "Icy\ Creek";
$areanames{en}->{61356209} = "Poowong";
$areanames{en}->{6135621} = "Icy\ Creek";
$areanames{en}->{6135624} = "Warragul";
$areanames{en}->{61356247} = "Icy\ Creek";
$areanames{en}->{61356248} = "Neerim\ South";
$areanames{en}->{61356249} = "Bunyip";
$areanames{en}->{6135625} = "Warragul";
$areanames{en}->{6135626} = "Warragul";
$areanames{en}->{6135627} = "Warragul";
$areanames{en}->{6135628} = "Neerim\ South";
$areanames{en}->{61356286} = "Warragul";
$areanames{en}->{6135629} = "Bunyip";
$areanames{en}->{61356300} = "San\ Remo";
$areanames{en}->{61356301} = "Warragul";
$areanames{en}->{61356302} = "Wonthaggi";
$areanames{en}->{61356303} = "Trafalgar";
$areanames{en}->{61356304} = "Neerim\ South";
$areanames{en}->{61356305} = "Bunyip";
$areanames{en}->{61356306} = "Buffalo";
$areanames{en}->{61356307} = "Poowong";
$areanames{en}->{61356308} = "Warragul";
$areanames{en}->{61356309} = "Tidal\ River";
$areanames{en}->{61356310} = "Toora";
$areanames{en}->{61356311} = "San\ Remo";
$areanames{en}->{61356312} = "Hill\ End";
$areanames{en}->{61356313} = "Mirboo\ North";
$areanames{en}->{61356314} = "Leongatha";
$areanames{en}->{61356315} = "Tidal\ River";
$areanames{en}->{61356316} = "Foster";
$areanames{en}->{61356317} = "Korumburra";
$areanames{en}->{61356318} = "Toora";
$areanames{en}->{61356319} = "Trafalgar";
$areanames{en}->{61356320} = "Warragul";
$areanames{en}->{61356321} = "Icy\ Creek";
$areanames{en}->{61356322} = "Bunyip";
$areanames{en}->{61356323} = "Wonthaggi";
$areanames{en}->{61356324} = "Trafalgar";
$areanames{en}->{61356325} = "Neerim\ South";
$areanames{en}->{61356326} = "Buffalo";
$areanames{en}->{61356327} = "Poowong";
$areanames{en}->{61356328} = "San\ Remo";
$areanames{en}->{61356329} = "Tidal\ River";
$areanames{en}->{6135633} = "Trafalgar";
$areanames{en}->{6135634} = "Trafalgar";
$areanames{en}->{6135635} = "Hill\ End";
$areanames{en}->{61356360} = "Hill\ End";
$areanames{en}->{61356361} = "Hill\ End";
$areanames{en}->{61356362} = "Icy\ Creek";
$areanames{en}->{61356363} = "Icy\ Creek";
$areanames{en}->{61356364} = "Warragul";
$areanames{en}->{61356365} = "Warragul";
$areanames{en}->{61356366} = "Neerim\ South";
$areanames{en}->{61356367} = "Neerim\ South";
$areanames{en}->{61356368} = "Trafalgar";
$areanames{en}->{61356369} = "Trafalgar";
$areanames{en}->{6135637} = "Trafalgar";
$areanames{en}->{61356380} = "Buffalo";
$areanames{en}->{61356381} = "Buffalo";
$areanames{en}->{61356382} = "Korumburra";
$areanames{en}->{61356383} = "Korumburra";
$areanames{en}->{61356384} = "Leongatha";
$areanames{en}->{61356385} = "Leongatha";
$areanames{en}->{61356386} = "Mirboo\ North";
$areanames{en}->{61356387} = "Mirboo\ North";
$areanames{en}->{61356388} = "Poowong";
$areanames{en}->{61356389} = "Poowong";
$areanames{en}->{61356390} = "San\ Remo";
$areanames{en}->{61356391} = "San\ Remo";
$areanames{en}->{61356392} = "Wonthaggi";
$areanames{en}->{61356393} = "Wonthaggi";
$areanames{en}->{61356394} = "Foster";
$areanames{en}->{61356395} = "Foster";
$areanames{en}->{61356396} = "Toora";
$areanames{en}->{61356397} = "Toora";
$areanames{en}->{61356398} = "Hill\ End";
$areanames{en}->{61356399} = "Leongatha";
$areanames{en}->{61356400} = "Wonthaggi";
$areanames{en}->{61356401} = "Mirboo\ North";
$areanames{en}->{61356402} = "Leongatha";
$areanames{en}->{61356403} = "Tidal\ River";
$areanames{en}->{61356404} = "Foster";
$areanames{en}->{61356405} = "Korumburra";
$areanames{en}->{61356406} = "Toora";
$areanames{en}->{61356407} = "Icy\ Creek";
$areanames{en}->{61356408} = "Wonthaggi";
$areanames{en}->{61356409} = "Hill\ End";
$areanames{en}->{61356410} = "Buffalo";
$areanames{en}->{61356411} = "Bunyip";
$areanames{en}->{61356412} = "Foster";
$areanames{en}->{61356413} = "Hill\ End";
$areanames{en}->{61356414} = "Icy\ Creek";
$areanames{en}->{61356415} = "Korumburra";
$areanames{en}->{61356416} = "Leongatha";
$areanames{en}->{61356417} = "Mirboo\ North";
$areanames{en}->{61356418} = "Neerim\ South";
$areanames{en}->{61356419} = "Poowong";
$areanames{en}->{61356420} = "San\ Remo";
$areanames{en}->{61356421} = "Tidal\ River";
$areanames{en}->{61356422} = "Toora";
$areanames{en}->{61356423} = "Trafalgar";
$areanames{en}->{61356424} = "Warragul";
$areanames{en}->{61356425} = "Wonthaggi";
$areanames{en}->{61356426} = "Warragul";
$areanames{en}->{61356427} = "Buffalo";
$areanames{en}->{61356428} = "Bunyip";
$areanames{en}->{61356429} = "Foster";
$areanames{en}->{61356430} = "Hill\ End";
$areanames{en}->{61356431} = "Icy\ Creek";
$areanames{en}->{61356432} = "Korumburra";
$areanames{en}->{61356433} = "Leongatha";
$areanames{en}->{61356434} = "Mirboo\ North";
$areanames{en}->{61356435} = "Neerim\ South";
$areanames{en}->{61356436} = "Poowong";
$areanames{en}->{61356437} = "San\ Remo";
$areanames{en}->{61356438} = "Tidal\ River";
$areanames{en}->{61356439} = "Toora";
$areanames{en}->{61356440} = "Trafalgar";
$areanames{en}->{61356441} = "Warragul";
$areanames{en}->{61356442} = "Wonthaggi";
$areanames{en}->{61356443} = "Warragul";
$areanames{en}->{61356444} = "Warragul";
$areanames{en}->{61356445} = "Warragul";
$areanames{en}->{61356446} = "Foster";
$areanames{en}->{61356447} = "Foster";
$areanames{en}->{61356448} = "Foster";
$areanames{en}->{61356449} = "Buffalo";
$areanames{en}->{61356450} = "Bunyip";
$areanames{en}->{61356451} = "Foster";
$areanames{en}->{61356452} = "Hill\ End";
$areanames{en}->{61356453} = "Icy\ Creek";
$areanames{en}->{61356454} = "Korumburra";
$areanames{en}->{61356455} = "Leongatha";
$areanames{en}->{61356456} = "Mirboo\ North";
$areanames{en}->{61356457} = "Neerim\ South";
$areanames{en}->{61356458} = "Poowong";
$areanames{en}->{61356459} = "San\ Remo";
$areanames{en}->{61356460} = "Tidal\ River";
$areanames{en}->{61356461} = "Toora";
$areanames{en}->{61356462} = "Buffalo";
$areanames{en}->{61356463} = "Bunyip";
$areanames{en}->{61356464} = "Foster";
$areanames{en}->{61356465} = "Hill\ End";
$areanames{en}->{61356466} = "Icy\ Creek";
$areanames{en}->{61356467} = "Korumburra";
$areanames{en}->{61356468} = "Leongatha";
$areanames{en}->{61356469} = "Mirboo\ North";
$areanames{en}->{61356470} = "Neerim\ South";
$areanames{en}->{61356471} = "Poowong";
$areanames{en}->{61356472} = "San\ Remo";
$areanames{en}->{61356473} = "Tidal\ River";
$areanames{en}->{61356474} = "Toora";
$areanames{en}->{61356475} = "Trafalgar";
$areanames{en}->{61356476} = "Warragul";
$areanames{en}->{61356477} = "Wonthaggi";
$areanames{en}->{61356478} = "Trafalgar";
$areanames{en}->{61356479} = "Warragul";
$areanames{en}->{61356480} = "Wonthaggi";
$areanames{en}->{61356481} = "Buffalo";
$areanames{en}->{61356482} = "Bunyip";
$areanames{en}->{61356483} = "Foster";
$areanames{en}->{61356484} = "Hill\ End";
$areanames{en}->{61356485} = "Icy\ Creek";
$areanames{en}->{61356486} = "Korumburra";
$areanames{en}->{61356487} = "Leongatha";
$areanames{en}->{61356488} = "Mirboo\ North";
$areanames{en}->{61356489} = "Neerim\ South";
$areanames{en}->{61356490} = "Poowong";
$areanames{en}->{61356491} = "San\ Remo";
$areanames{en}->{61356492} = "Tidal\ River";
$areanames{en}->{61356493} = "Toora";
$areanames{en}->{61356494} = "Trafalgar";
$areanames{en}->{61356495} = "Warragul";
$areanames{en}->{61356496} = "Wonthaggi";
$areanames{en}->{61356497} = "Buffalo";
$areanames{en}->{61356498} = "Bunyip";
$areanames{en}->{61356499} = "Foster";
$areanames{en}->{61356500} = "Hill\ End";
$areanames{en}->{61356501} = "Icy\ Creek";
$areanames{en}->{61356502} = "Korumburra";
$areanames{en}->{61356503} = "Leongatha";
$areanames{en}->{61356504} = "Mirboo\ North";
$areanames{en}->{61356505} = "Neerim\ South";
$areanames{en}->{61356506} = "Poowong";
$areanames{en}->{61356507} = "San\ Remo";
$areanames{en}->{61356508} = "Tidal\ River";
$areanames{en}->{61356509} = "Toora";
$areanames{en}->{61356510} = "Trafalgar";
$areanames{en}->{61356511} = "Warragul";
$areanames{en}->{61356512} = "Wonthaggi";
$areanames{en}->{61356513} = "Buffalo";
$areanames{en}->{61356514} = "Bunyip";
$areanames{en}->{61356515} = "Foster";
$areanames{en}->{61356516} = "Hill\ End";
$areanames{en}->{61356517} = "Icy\ Creek";
$areanames{en}->{61356518} = "Korumburra";
$areanames{en}->{61356519} = "Leongatha";
$areanames{en}->{61356520} = "Mirboo\ North";
$areanames{en}->{61356521} = "Neerim\ South";
$areanames{en}->{61356522} = "Poowong";
$areanames{en}->{61356523} = "San\ Remo";
$areanames{en}->{61356524} = "Tidal\ River";
$areanames{en}->{61356525} = "Toora";
$areanames{en}->{61356526} = "Trafalgar";
$areanames{en}->{61356527} = "Warragul";
$areanames{en}->{61356528} = "Wonthaggi";
$areanames{en}->{6135654} = "Korumburra";
$areanames{en}->{61356549} = "Poowong";
$areanames{en}->{6135655} = "Korumburra";
$areanames{en}->{6135656} = "Warragul";
$areanames{en}->{6135657} = "Korumburra";
$areanames{en}->{6135658} = "Korumburra";
$areanames{en}->{6135659} = "Poowong";
$areanames{en}->{6135662} = "Leongatha";
$areanames{en}->{6135663} = "Buffalo";
$areanames{en}->{6135664} = "Leongatha";
$areanames{en}->{6135667} = "Leongatha";
$areanames{en}->{61356678} = "Buffalo";
$areanames{en}->{61356679} = "Mirboo\ North";
$areanames{en}->{6135668} = "Mirboo\ North";
$areanames{en}->{6135671} = "Wonthaggi";
$areanames{en}->{61356719} = "San\ Remo";
$areanames{en}->{6135672} = "Wonthaggi";
$areanames{en}->{6135673} = "Warragul";
$areanames{en}->{61356730} = "Bunyip";
$areanames{en}->{61356731} = "Hill\ End";
$areanames{en}->{6135674} = "Wonthaggi";
$areanames{en}->{6135678} = "San\ Remo";
$areanames{en}->{6135680} = "Tidal\ River";
$areanames{en}->{6135681} = "Toora";
$areanames{en}->{6135682} = "Foster";
$areanames{en}->{6135683} = "Foster";
$areanames{en}->{6135684} = "Foster";
$areanames{en}->{6135685} = "Foster";
$areanames{en}->{61356858} = "Toora";
$areanames{en}->{61356859} = "Tidal\ River";
$areanames{en}->{61356860} = "Toora";
$areanames{en}->{61356861} = "Toora";
$areanames{en}->{61356862} = "Toora";
$areanames{en}->{61356863} = "Toora";
$areanames{en}->{61356864} = "Warragul";
$areanames{en}->{61356865} = "Warragul";
$areanames{en}->{61356866} = "Warragul";
$areanames{en}->{61356867} = "Poowong";
$areanames{en}->{6135687} = "Foster";
$areanames{en}->{6135688} = "Toora";
$areanames{en}->{6135689} = "Foster";
$areanames{en}->{61357000} = "Alexandra";
$areanames{en}->{61357001} = "Alexandra";
$areanames{en}->{61357002} = "Alexandra";
$areanames{en}->{61357003} = "Beechworth";
$areanames{en}->{61357004} = "Beechworth";
$areanames{en}->{61357005} = "Beechworth";
$areanames{en}->{61357006} = "Benalla";
$areanames{en}->{61357007} = "Benalla";
$areanames{en}->{61357008} = "Benalla";
$areanames{en}->{61357009} = "Mount\ Buller";
$areanames{en}->{61357010} = "Bonnie\ Doon";
$areanames{en}->{61357011} = "Bonnie\ Doon";
$areanames{en}->{61357012} = "Bonnie\ Doon";
$areanames{en}->{61357013} = "Bright";
$areanames{en}->{61357014} = "Bright";
$areanames{en}->{61357015} = "Bright";
$areanames{en}->{61357016} = "Broadford";
$areanames{en}->{61357017} = "Broadford";
$areanames{en}->{61357018} = "Broadford";
$areanames{en}->{61357019} = "Taggerty";
$areanames{en}->{61357020} = "Buffalo\ River";
$areanames{en}->{61357021} = "Buffalo\ River";
$areanames{en}->{61357022} = "Buffalo\ River";
$areanames{en}->{61357023} = "Cheshunt";
$areanames{en}->{61357024} = "Cheshunt";
$areanames{en}->{61357025} = "Cheshunt";
$areanames{en}->{61357026} = "Chiltern";
$areanames{en}->{61357027} = "Chiltern";
$areanames{en}->{61357028} = "Chiltern";
$areanames{en}->{61357029} = "Woods\ Point";
$areanames{en}->{61357030} = "Creightons\ Creek";
$areanames{en}->{61357031} = "Creightons\ Creek";
$areanames{en}->{61357032} = "Creightons\ Creek";
$areanames{en}->{61357033} = "Devlins\ Bridge";
$areanames{en}->{61357034} = "Devlins\ Bridge";
$areanames{en}->{61357035} = "Devlins\ Bridge";
$areanames{en}->{61357036} = "Eildon";
$areanames{en}->{61357037} = "Eildon";
$areanames{en}->{61357038} = "Eildon";
$areanames{en}->{61357039} = "Yarck";
$areanames{en}->{61357040} = "Euroa";
$areanames{en}->{61357041} = "Euroa";
$areanames{en}->{61357042} = "Euroa";
$areanames{en}->{61357043} = "Falls\ Creek";
$areanames{en}->{61357044} = "Falls\ Creek";
$areanames{en}->{61357045} = "Falls\ Creek";
$areanames{en}->{61357046} = "Flowerdale";
$areanames{en}->{61357047} = "Flowerdale";
$areanames{en}->{61357048} = "Flowerdale";
$areanames{en}->{61357049} = "Mansfield";
$areanames{en}->{61357050} = "Graytown";
$areanames{en}->{61357051} = "Graytown";
$areanames{en}->{61357052} = "Graytown";
$areanames{en}->{61357053} = "Harrietville";
$areanames{en}->{61357054} = "Harrietville";
$areanames{en}->{61357055} = "Harrietville";
$areanames{en}->{61357056} = "Jamieson";
$areanames{en}->{61357057} = "Jamieson";
$areanames{en}->{61357058} = "Jamieson";
$areanames{en}->{61357059} = "Eildon";
$areanames{en}->{61357060} = "Killawarra";
$areanames{en}->{61357061} = "Killawarra";
$areanames{en}->{61357062} = "Killawarra";
$areanames{en}->{61357063} = "Kilmore";
$areanames{en}->{61357064} = "Kilmore";
$areanames{en}->{61357065} = "Kilmore";
$areanames{en}->{61357066} = "King\ Valley";
$areanames{en}->{61357067} = "King\ Valley";
$areanames{en}->{61357068} = "King\ Valley";
$areanames{en}->{61357069} = "Jamieson";
$areanames{en}->{61357070} = "Kinglake";
$areanames{en}->{61357071} = "Kinglake";
$areanames{en}->{61357072} = "Kinglake";
$areanames{en}->{61357073} = "Kobyboyn";
$areanames{en}->{61357074} = "Kobyboyn";
$areanames{en}->{61357075} = "Kobyboyn";
$areanames{en}->{61357076} = "Longwood";
$areanames{en}->{61357077} = "Longwood";
$areanames{en}->{61357078} = "Longwood";
$areanames{en}->{61357079} = "Bonnie\ Doon";
$areanames{en}->{61357080} = "Mansfield";
$areanames{en}->{61357081} = "Mansfield";
$areanames{en}->{61357082} = "Mansfield";
$areanames{en}->{61357083} = "Mount\ Beauty";
$areanames{en}->{61357084} = "Mount\ Beauty";
$areanames{en}->{61357085} = "Mount\ Beauty";
$areanames{en}->{61357086} = "Mount\ Buller";
$areanames{en}->{61357087} = "Mount\ Buller";
$areanames{en}->{61357088} = "Mount\ Buller";
$areanames{en}->{61357089} = "Alexandra";
$areanames{en}->{61357090} = "Moyhu";
$areanames{en}->{61357091} = "Moyhu";
$areanames{en}->{61357092} = "Moyhu";
$areanames{en}->{61357093} = "Myrtleford";
$areanames{en}->{61357094} = "Myrtleford";
$areanames{en}->{61357095} = "Myrtleford";
$areanames{en}->{61357096} = "Nagambie";
$areanames{en}->{61357097} = "Nagambie";
$areanames{en}->{61357098} = "Nagambie";
$areanames{en}->{61357099} = "Bright";
$areanames{en}->{61357100} = "Puckapunyal";
$areanames{en}->{61357101} = "Puckapunyal";
$areanames{en}->{61357102} = "Puckapunyal";
$areanames{en}->{61357103} = "Pyalong";
$areanames{en}->{61357104} = "Pyalong";
$areanames{en}->{61357105} = "Pyalong";
$areanames{en}->{61357106} = "Seymour";
$areanames{en}->{61357107} = "Seymour";
$areanames{en}->{61357108} = "Seymour";
$areanames{en}->{61357109} = "Buffalo\ River";
$areanames{en}->{61357110} = "St\ James";
$areanames{en}->{61357111} = "St\ James";
$areanames{en}->{61357112} = "St\ James";
$areanames{en}->{61357113} = "Strathbogie";
$areanames{en}->{61357114} = "Strathbogie";
$areanames{en}->{61357115} = "Strathbogie";
$areanames{en}->{61357116} = "Swanpool";
$areanames{en}->{61357117} = "Swanpool";
$areanames{en}->{61357118} = "Swanpool";
$areanames{en}->{61357119} = "Falls\ Creek";
$areanames{en}->{61357120} = "Taggerty";
$areanames{en}->{61357121} = "Taggerty";
$areanames{en}->{61357122} = "Taggerty";
$areanames{en}->{61357123} = "Tatong";
$areanames{en}->{61357124} = "Tatong";
$areanames{en}->{61357125} = "Tatong";
$areanames{en}->{61357126} = "Thoona";
$areanames{en}->{61357127} = "Thoona";
$areanames{en}->{61357128} = "Thoona";
$areanames{en}->{61357129} = "Harrietville";
$areanames{en}->{61357130} = "Tungamah";
$areanames{en}->{61357131} = "Tungamah";
$areanames{en}->{61357132} = "Tungamah";
$areanames{en}->{61357133} = "Violet\ Town";
$areanames{en}->{61357134} = "Violet\ Town";
$areanames{en}->{61357135} = "Violet\ Town";
$areanames{en}->{61357136} = "Wangaratta";
$areanames{en}->{61357137} = "Wangaratta";
$areanames{en}->{61357138} = "Wangaratta";
$areanames{en}->{61357139} = "Wangaratta";
$areanames{en}->{61357140} = "Whorouly";
$areanames{en}->{61357141} = "Whorouly";
$areanames{en}->{61357142} = "Whorouly";
$areanames{en}->{61357143} = "Winton";
$areanames{en}->{61357144} = "Winton";
$areanames{en}->{61357145} = "Winton";
$areanames{en}->{61357146} = "Woods\ Point";
$areanames{en}->{61357147} = "Woods\ Point";
$areanames{en}->{61357148} = "Woods\ Point";
$areanames{en}->{61357149} = "Mount\ Beauty";
$areanames{en}->{61357150} = "Yarck";
$areanames{en}->{61357151} = "Yarck";
$areanames{en}->{61357152} = "Yarck";
$areanames{en}->{61357153} = "Yarrawonga";
$areanames{en}->{61357154} = "Yarrawonga";
$areanames{en}->{61357155} = "Yarrawonga";
$areanames{en}->{61357156} = "Yea";
$areanames{en}->{61357157} = "Yea";
$areanames{en}->{61357158} = "Yea";
$areanames{en}->{61357159} = "Myrtleford";
$areanames{en}->{61357160} = "Violet\ Town";
$areanames{en}->{61357161} = "Yea";
$areanames{en}->{61357162} = "Graytown";
$areanames{en}->{61357163} = "Kilmore";
$areanames{en}->{61357164} = "Kinglake";
$areanames{en}->{61357165} = "Kobyboyn";
$areanames{en}->{61357166} = "Longwood";
$areanames{en}->{61357167} = "Nagambie";
$areanames{en}->{61357168} = "Puckapunyal";
$areanames{en}->{61357169} = "Pyalong";
$areanames{en}->{61357170} = "Seymour";
$areanames{en}->{61357171} = "Strathbogie";
$areanames{en}->{61357172} = "Broadford";
$areanames{en}->{61357173} = "Creightons\ Creek";
$areanames{en}->{61357174} = "Devlins\ Bridge";
$areanames{en}->{61357175} = "Euroa";
$areanames{en}->{61357176} = "Flowerdale";
$areanames{en}->{61357177} = "Yarrawonga";
$areanames{en}->{61357178} = "Swanpool";
$areanames{en}->{61357179} = "Tatong";
$areanames{en}->{6135718} = "Wangaratta";
$areanames{en}->{61357190} = "Thoona";
$areanames{en}->{61357191} = "Tungamah";
$areanames{en}->{61357192} = "Wangaratta";
$areanames{en}->{61357193} = "Whorouly";
$areanames{en}->{61357194} = "Beechworth";
$areanames{en}->{61357195} = "Benalla";
$areanames{en}->{61357196} = "Cheshunt";
$areanames{en}->{61357197} = "Chiltern";
$areanames{en}->{61357198} = "Killawarra";
$areanames{en}->{61357199} = "King\ Valley";
$areanames{en}->{61357200} = "Wangaratta";
$areanames{en}->{61357201} = "Wangaratta";
$areanames{en}->{61357202} = "Wangaratta";
$areanames{en}->{61357203} = "Chiltern";
$areanames{en}->{61357204} = "Killawarra";
$areanames{en}->{61357205} = "Whorouly";
$areanames{en}->{61357206} = "Moyhu";
$areanames{en}->{61357207} = "Beechworth";
$areanames{en}->{61357208} = "Beechworth";
$areanames{en}->{61357209} = "Cheshunt";
$areanames{en}->{61357230} = "Wangaratta";
$areanames{en}->{61357231} = "Wangaratta";
$areanames{en}->{61357232} = "Wangaratta";
$areanames{en}->{61357233} = "Wangaratta";
$areanames{en}->{61357234} = "Wangaratta";
$areanames{en}->{613572350} = "Falls\ Creek";
$areanames{en}->{613572351} = "Falls\ Creek";
$areanames{en}->{613572352} = "Falls\ Creek";
$areanames{en}->{613572353} = "Falls\ Creek";
$areanames{en}->{613572356} = "Falls\ Creek";
$areanames{en}->{61357236} = "Wangaratta";
$areanames{en}->{61357237} = "Wangaratta";
$areanames{en}->{61357238} = "Wangaratta";
$areanames{en}->{61357239} = "Kilmore";
$areanames{en}->{61357240} = "Moyhu";
$areanames{en}->{61357241} = "St\ James";
$areanames{en}->{61357242} = "Winton";
$areanames{en}->{613572430} = "Alexandra";
$areanames{en}->{613572431} = "Alexandra";
$areanames{en}->{613572432} = "Alexandra";
$areanames{en}->{613572433} = "Alexandra";
$areanames{en}->{613572434} = "Alexandra";
$areanames{en}->{613572435} = "Alexandra";
$areanames{en}->{613572436} = "Alexandra";
$areanames{en}->{613572438} = "Alexandra";
$areanames{en}->{613572439} = "Wangaratta";
$areanames{en}->{613572440} = "Bonnie\ Doon";
$areanames{en}->{613572441} = "Bonnie\ Doon";
$areanames{en}->{613572442} = "Bonnie\ Doon";
$areanames{en}->{613572443} = "Bonnie\ Doon";
$areanames{en}->{613572446} = "Bonnie\ Doon";
$areanames{en}->{61357245} = "Eildon";
$areanames{en}->{613572455} = "Seymour";
$areanames{en}->{613572456} = "Benalla";
$areanames{en}->{613572460} = "Jamieson";
$areanames{en}->{613572461} = "Jamieson";
$areanames{en}->{613572462} = "Jamieson";
$areanames{en}->{613572463} = "Jamieson";
$areanames{en}->{613572466} = "Jamieson";
$areanames{en}->{613572470} = "Mansfield";
$areanames{en}->{613572471} = "Mansfield";
$areanames{en}->{613572472} = "Mansfield";
$areanames{en}->{613572473} = "Mansfield";
$areanames{en}->{613572474} = "Mansfield";
$areanames{en}->{613572475} = "Mansfield";
$areanames{en}->{613572476} = "Mansfield";
$areanames{en}->{613572477} = "Mansfield";
$areanames{en}->{613572480} = "Mount\ Buller";
$areanames{en}->{613572481} = "Mount\ Buller";
$areanames{en}->{613572482} = "Mount\ Buller";
$areanames{en}->{613572483} = "Mount\ Buller";
$areanames{en}->{613572486} = "Mount\ Buller";
$areanames{en}->{613572490} = "Taggerty";
$areanames{en}->{613572491} = "Taggerty";
$areanames{en}->{613572492} = "Taggerty";
$areanames{en}->{613572493} = "Taggerty";
$areanames{en}->{613572494} = "Taggerty";
$areanames{en}->{613572495} = "Taggerty";
$areanames{en}->{613572496} = "Taggerty";
$areanames{en}->{613572497} = "Taggerty";
$areanames{en}->{61357250} = "Alexandra";
$areanames{en}->{61357251} = "Wangaratta";
$areanames{en}->{61357252} = "Wangaratta";
$areanames{en}->{61357253} = "Wangaratta";
$areanames{en}->{61357254} = "Alexandra";
$areanames{en}->{61357255} = "Alexandra";
$areanames{en}->{61357256} = "Myrtleford";
$areanames{en}->{61357257} = "Wangaratta";
$areanames{en}->{61357258} = "Alexandra";
$areanames{en}->{61357259} = "Bonnie\ Doon";
$areanames{en}->{61357260} = "Chiltern";
$areanames{en}->{61357261} = "Chiltern";
$areanames{en}->{613572620} = "Woods\ Point";
$areanames{en}->{613572621} = "Woods\ Point";
$areanames{en}->{613572622} = "Woods\ Point";
$areanames{en}->{613572623} = "Woods\ Point";
$areanames{en}->{613572624} = "Woods\ Point";
$areanames{en}->{613572625} = "Woods\ Point";
$areanames{en}->{613572626} = "Woods\ Point";
$areanames{en}->{613572627} = "Woods\ Point";
$areanames{en}->{613572630} = "Yarck";
$areanames{en}->{613572631} = "Yarck";
$areanames{en}->{613572632} = "Yarck";
$areanames{en}->{613572633} = "Yarck";
$areanames{en}->{613572636} = "Yarck";
$areanames{en}->{613572640} = "Bright";
$areanames{en}->{613572641} = "Bright";
$areanames{en}->{613572642} = "Bright";
$areanames{en}->{613572643} = "Bright";
$areanames{en}->{613572644} = "Bright";
$areanames{en}->{613572645} = "Bright";
$areanames{en}->{613572646} = "Bright";
$areanames{en}->{613572647} = "Bright";
$areanames{en}->{61357265} = "Chiltern";
$areanames{en}->{613572660} = "Buffalo\ River";
$areanames{en}->{613572661} = "Buffalo\ River";
$areanames{en}->{613572662} = "Buffalo\ River";
$areanames{en}->{613572663} = "Buffalo\ River";
$areanames{en}->{613572666} = "Buffalo\ River";
$areanames{en}->{61357267} = "Killawarra";
$areanames{en}->{61357268} = "Killawarra";
$areanames{en}->{61357269} = "Killawarra";
$areanames{en}->{61357270} = "Whorouly";
$areanames{en}->{61357271} = "Whorouly";
$areanames{en}->{61357272} = "Whorouly";
$areanames{en}->{61357273} = "Whorouly";
$areanames{en}->{61357274} = "Whorouly";
$areanames{en}->{613572750} = "Harrietville";
$areanames{en}->{613572751} = "Harrietville";
$areanames{en}->{613572752} = "Harrietville";
$areanames{en}->{613572753} = "Harrietville";
$areanames{en}->{613572756} = "Harrietville";
$areanames{en}->{61357276} = "Moyhu";
$areanames{en}->{613572770} = "Mount\ Beauty";
$areanames{en}->{613572771} = "Mount\ Beauty";
$areanames{en}->{613572772} = "Mount\ Beauty";
$areanames{en}->{613572773} = "Mount\ Beauty";
$areanames{en}->{613572774} = "Mount\ Beauty";
$areanames{en}->{613572775} = "Mount\ Beauty";
$areanames{en}->{613572776} = "Mount\ Beauty";
$areanames{en}->{613572777} = "Mount\ Beauty";
$areanames{en}->{61357278} = "Moyhu";
$areanames{en}->{61357279} = "Moyhu";
$areanames{en}->{6135728} = "Beechworth";
$areanames{en}->{613572900} = "Myrtleford";
$areanames{en}->{613572901} = "Myrtleford";
$areanames{en}->{613572902} = "Myrtleford";
$areanames{en}->{613572903} = "Myrtleford";
$areanames{en}->{613572906} = "Myrtleford";
$areanames{en}->{613572910} = "Broadford";
$areanames{en}->{613572911} = "Broadford";
$areanames{en}->{613572912} = "Broadford";
$areanames{en}->{613572913} = "Broadford";
$areanames{en}->{613572914} = "Broadford";
$areanames{en}->{613572915} = "Broadford";
$areanames{en}->{613572916} = "Broadford";
$areanames{en}->{613572917} = "Broadford";
$areanames{en}->{613572920} = "Creightons\ Creek";
$areanames{en}->{613572921} = "Creightons\ Creek";
$areanames{en}->{613572922} = "Creightons\ Creek";
$areanames{en}->{613572923} = "Creightons\ Creek";
$areanames{en}->{613572924} = "Creightons\ Creek";
$areanames{en}->{613572925} = "Creightons\ Creek";
$areanames{en}->{613572926} = "Creightons\ Creek";
$areanames{en}->{613572927} = "Creightons\ Creek";
$areanames{en}->{61357293} = "King\ Valley";
$areanames{en}->{61357294} = "King\ Valley";
$areanames{en}->{61357295} = "King\ Valley";
$areanames{en}->{61357296} = "Yarrawonga";
$areanames{en}->{61357297} = "Cheshunt";
$areanames{en}->{61357298} = "Cheshunt";
$areanames{en}->{61357299} = "Cheshunt";
$areanames{en}->{61357300} = "Bright";
$areanames{en}->{613573010} = "Devlins\ Bridge";
$areanames{en}->{613573011} = "Devlins\ Bridge";
$areanames{en}->{613573012} = "Devlins\ Bridge";
$areanames{en}->{613573013} = "Devlins\ Bridge";
$areanames{en}->{613573014} = "Devlins\ Bridge";
$areanames{en}->{613573015} = "Devlins\ Bridge";
$areanames{en}->{613573016} = "Devlins\ Bridge";
$areanames{en}->{613573017} = "Devlins\ Bridge";
$areanames{en}->{613573020} = "Euroa";
$areanames{en}->{613573021} = "Euroa";
$areanames{en}->{613573022} = "Euroa";
$areanames{en}->{613573023} = "Euroa";
$areanames{en}->{613573024} = "Euroa";
$areanames{en}->{613573025} = "Euroa";
$areanames{en}->{613573026} = "Euroa";
$areanames{en}->{613573027} = "Euroa";
$areanames{en}->{613573030} = "Flowerdale";
$areanames{en}->{613573031} = "Flowerdale";
$areanames{en}->{613573032} = "Flowerdale";
$areanames{en}->{613573033} = "Flowerdale";
$areanames{en}->{613573034} = "Flowerdale";
$areanames{en}->{613573035} = "Flowerdale";
$areanames{en}->{613573036} = "Flowerdale";
$areanames{en}->{613573037} = "Flowerdale";
$areanames{en}->{613573040} = "Graytown";
$areanames{en}->{613573041} = "Graytown";
$areanames{en}->{613573042} = "Graytown";
$areanames{en}->{613573043} = "Graytown";
$areanames{en}->{613573044} = "Graytown";
$areanames{en}->{613573045} = "Graytown";
$areanames{en}->{613573046} = "Graytown";
$areanames{en}->{613573047} = "Graytown";
$areanames{en}->{613573050} = "Kilmore";
$areanames{en}->{613573051} = "Kilmore";
$areanames{en}->{613573052} = "Kilmore";
$areanames{en}->{613573053} = "Kilmore";
$areanames{en}->{613573054} = "Kilmore";
$areanames{en}->{613573055} = "Kilmore";
$areanames{en}->{613573056} = "Kilmore";
$areanames{en}->{613573057} = "Kilmore";
$areanames{en}->{613573060} = "Kinglake";
$areanames{en}->{613573061} = "Kinglake";
$areanames{en}->{613573062} = "Kinglake";
$areanames{en}->{613573063} = "Kinglake";
$areanames{en}->{613573064} = "Kinglake";
$areanames{en}->{613573065} = "Kinglake";
$areanames{en}->{613573066} = "Kinglake";
$areanames{en}->{613573067} = "Kinglake";
$areanames{en}->{613573070} = "Kobyboyn";
$areanames{en}->{613573071} = "Kobyboyn";
$areanames{en}->{613573072} = "Kobyboyn";
$areanames{en}->{613573073} = "Kobyboyn";
$areanames{en}->{613573074} = "Kobyboyn";
$areanames{en}->{613573075} = "Kobyboyn";
$areanames{en}->{613573076} = "Kobyboyn";
$areanames{en}->{613573077} = "Kobyboyn";
$areanames{en}->{613573080} = "Longwood";
$areanames{en}->{613573081} = "Longwood";
$areanames{en}->{613573082} = "Longwood";
$areanames{en}->{613573083} = "Longwood";
$areanames{en}->{613573084} = "Longwood";
$areanames{en}->{613573085} = "Longwood";
$areanames{en}->{613573086} = "Longwood";
$areanames{en}->{613573087} = "Longwood";
$areanames{en}->{613573090} = "Nagambie";
$areanames{en}->{613573091} = "Nagambie";
$areanames{en}->{613573092} = "Nagambie";
$areanames{en}->{613573093} = "Nagambie";
$areanames{en}->{613573094} = "Nagambie";
$areanames{en}->{613573095} = "Nagambie";
$areanames{en}->{613573096} = "Nagambie";
$areanames{en}->{613573097} = "Nagambie";
$areanames{en}->{61357310} = "Myrtleford";
$areanames{en}->{61357311} = "Myrtleford";
$areanames{en}->{61357312} = "Myrtleford";
$areanames{en}->{61357313} = "Myrtleford";
$areanames{en}->{61357314} = "Eildon";
$areanames{en}->{61357315} = "Jamieson";
$areanames{en}->{61357316} = "Mansfield";
$areanames{en}->{61357317} = "Mount\ Buller";
$areanames{en}->{61357318} = "Taggerty";
$areanames{en}->{61357319} = "Woods\ Point";
$areanames{en}->{61357320} = "Bright";
$areanames{en}->{61357321} = "Bright";
$areanames{en}->{61357322} = "Bright";
$areanames{en}->{61357323} = "Bright";
$areanames{en}->{61357324} = "Yarck";
$areanames{en}->{61357325} = "Bright";
$areanames{en}->{61357326} = "Buffalo\ River";
$areanames{en}->{61357327} = "Mount\ Beauty";
$areanames{en}->{61357328} = "Falls\ Creek";
$areanames{en}->{61357329} = "Harrietville";
$areanames{en}->{61357330} = "Mansfield";
$areanames{en}->{61357331} = "Mansfield";
$areanames{en}->{61357332} = "Mansfield";
$areanames{en}->{61357333} = "Mansfield";
$areanames{en}->{61357334} = "Buffalo\ River";
$areanames{en}->{61357335} = "Falls\ Creek";
$areanames{en}->{61357336} = "Jamieson";
$areanames{en}->{61357337} = "Mount\ Buller";
$areanames{en}->{61357338} = "Woods\ Point";
$areanames{en}->{61357339} = "Harrietville";
$areanames{en}->{61357340} = "Kilmore";
$areanames{en}->{61357341} = "Kilmore";
$areanames{en}->{61357342} = "Kilmore";
$areanames{en}->{61357343} = "Kilmore";
$areanames{en}->{61357344} = "Mount\ Beauty";
$areanames{en}->{61357345} = "Myrtleford";
$areanames{en}->{61357346} = "Broadford";
$areanames{en}->{61357347} = "Broadford";
$areanames{en}->{61357348} = "Kinglake";
$areanames{en}->{61357349} = "Flowerdale";
$areanames{en}->{6135735} = "Seymour";
$areanames{en}->{61357356} = "Puckapunyal";
$areanames{en}->{61357357} = "Puckapunyal";
$areanames{en}->{61357359} = "Devlins\ Bridge";
$areanames{en}->{61357360} = "Yea";
$areanames{en}->{61357361} = "Puckapunyal";
$areanames{en}->{61357362} = "Nagambie";
$areanames{en}->{61357363} = "Graytown";
$areanames{en}->{61357364} = "Euroa";
$areanames{en}->{61357365} = "Kobyboyn";
$areanames{en}->{61357366} = "Violet\ Town";
$areanames{en}->{61357367} = "Longwood";
$areanames{en}->{61357368} = "Creightons\ Creek";
$areanames{en}->{61357369} = "Strathbogie";
$areanames{en}->{61357370} = "Swanpool";
$areanames{en}->{61357371} = "Tatong";
$areanames{en}->{61357372} = "Thoona";
$areanames{en}->{61357373} = "Tungamah";
$areanames{en}->{61357374} = "Wangaratta";
$areanames{en}->{61357375} = "Whorouly";
$areanames{en}->{61357376} = "Violet\ Town";
$areanames{en}->{61357377} = "Yea";
$areanames{en}->{61357378} = "Beechworth";
$areanames{en}->{61357379} = "Benalla";
$areanames{en}->{61357380} = "Cheshunt";
$areanames{en}->{61357381} = "Chiltern";
$areanames{en}->{61357382} = "Killawarra";
$areanames{en}->{61357383} = "King\ Valley";
$areanames{en}->{61357384} = "Moyhu";
$areanames{en}->{61357385} = "St\ James";
$areanames{en}->{61357386} = "Graytown";
$areanames{en}->{61357387} = "Kilmore";
$areanames{en}->{61357388} = "Kinglake";
$areanames{en}->{61357389} = "Kobyboyn";
$areanames{en}->{61357390} = "Longwood";
$areanames{en}->{61357391} = "Nagambie";
$areanames{en}->{61357392} = "Puckapunyal";
$areanames{en}->{61357393} = "Pyalong";
$areanames{en}->{61357394} = "Seymour";
$areanames{en}->{61357395} = "Strathbogie";
$areanames{en}->{61357396} = "Broadford";
$areanames{en}->{61357397} = "Creightons\ Creek";
$areanames{en}->{61357398} = "Devlins\ Bridge";
$areanames{en}->{61357399} = "Euroa";
$areanames{en}->{61357400} = "Flowerdale";
$areanames{en}->{61357401} = "Mount\ Buller";
$areanames{en}->{61357402} = "Taggerty";
$areanames{en}->{61357403} = "Woods\ Point";
$areanames{en}->{61357404} = "Yarck";
$areanames{en}->{61357405} = "Bright";
$areanames{en}->{61357406} = "Buffalo\ River";
$areanames{en}->{61357407} = "Falls\ Creek";
$areanames{en}->{61357408} = "Harrietville";
$areanames{en}->{61357409} = "Mount\ Beauty";
$areanames{en}->{61357410} = "Myrtleford";
$areanames{en}->{61357411} = "Mansfield";
$areanames{en}->{61357412} = "Eildon";
$areanames{en}->{61357413} = "Jamieson";
$areanames{en}->{61357414} = "Bonnie\ Doon";
$areanames{en}->{61357415} = "Alexandra";
$areanames{en}->{61357416} = "Winton";
$areanames{en}->{613574170} = "Puckapunyal";
$areanames{en}->{613574171} = "Puckapunyal";
$areanames{en}->{613574172} = "Puckapunyal";
$areanames{en}->{613574173} = "Puckapunyal";
$areanames{en}->{613574174} = "Puckapunyal";
$areanames{en}->{613574175} = "Puckapunyal";
$areanames{en}->{613574176} = "Puckapunyal";
$areanames{en}->{613574177} = "Puckapunyal";
$areanames{en}->{613574180} = "Pyalong";
$areanames{en}->{613574181} = "Pyalong";
$areanames{en}->{613574182} = "Pyalong";
$areanames{en}->{613574183} = "Pyalong";
$areanames{en}->{613574184} = "Pyalong";
$areanames{en}->{613574185} = "Pyalong";
$areanames{en}->{613574186} = "Pyalong";
$areanames{en}->{613574187} = "Pyalong";
$areanames{en}->{613574190} = "Seymour";
$areanames{en}->{613574191} = "Seymour";
$areanames{en}->{613574192} = "Seymour";
$areanames{en}->{613574193} = "Seymour";
$areanames{en}->{613574194} = "Seymour";
$areanames{en}->{61357420} = "Yarrawonga";
$areanames{en}->{61357421} = "Yarrawonga";
$areanames{en}->{61357422} = "Yarrawonga";
$areanames{en}->{61357423} = "Creightons\ Creek";
$areanames{en}->{61357424} = "Devlins\ Bridge";
$areanames{en}->{61357425} = "Euroa";
$areanames{en}->{61357426} = "Flowerdale";
$areanames{en}->{61357427} = "Graytown";
$areanames{en}->{61357428} = "Kilmore";
$areanames{en}->{61357429} = "Tungamah";
$areanames{en}->{61357430} = "Kinglake";
$areanames{en}->{61357431} = "Yarrawonga";
$areanames{en}->{61357432} = "Yarrawonga";
$areanames{en}->{61357433} = "Yarrawonga";
$areanames{en}->{61357434} = "Kobyboyn";
$areanames{en}->{61357435} = "Longwood";
$areanames{en}->{61357436} = "Nagambie";
$areanames{en}->{61357437} = "Puckapunyal";
$areanames{en}->{61357438} = "Yarrawonga";
$areanames{en}->{61357439} = "Yarrawonga";
$areanames{en}->{61357440} = "Yarrawonga";
$areanames{en}->{61357441} = "Yarrawonga";
$areanames{en}->{61357442} = "Yarrawonga";
$areanames{en}->{61357443} = "Yarrawonga";
$areanames{en}->{61357444} = "Pyalong";
$areanames{en}->{61357445} = "Strathbogie";
$areanames{en}->{61357446} = "Yea";
$areanames{en}->{61357447} = "Chiltern";
$areanames{en}->{61357448} = "Killawarra";
$areanames{en}->{61357449} = "Yarrawonga";
$areanames{en}->{61357450} = "King\ Valley";
$areanames{en}->{61357451} = "Moyhu";
$areanames{en}->{61357452} = "St\ James";
$areanames{en}->{61357453} = "Swanpool";
$areanames{en}->{61357454} = "Tatong";
$areanames{en}->{61357455} = "Thoona";
$areanames{en}->{61357456} = "Tungamah";
$areanames{en}->{61357457} = "Whorouly";
$areanames{en}->{61357458} = "Yarrawonga";
$areanames{en}->{61357459} = "Yarrawonga";
$areanames{en}->{613574600} = "Strathbogie";
$areanames{en}->{613574601} = "Strathbogie";
$areanames{en}->{613574602} = "Strathbogie";
$areanames{en}->{613574603} = "Strathbogie";
$areanames{en}->{613574604} = "Strathbogie";
$areanames{en}->{613574605} = "Strathbogie";
$areanames{en}->{613574606} = "Strathbogie";
$areanames{en}->{613574607} = "Strathbogie";
$areanames{en}->{613574610} = "Violet\ Town";
$areanames{en}->{613574611} = "Violet\ Town";
$areanames{en}->{613574612} = "Violet\ Town";
$areanames{en}->{613574613} = "Violet\ Town";
$areanames{en}->{613574614} = "Violet\ Town";
$areanames{en}->{613574615} = "Violet\ Town";
$areanames{en}->{613574616} = "Violet\ Town";
$areanames{en}->{613574617} = "Violet\ Town";
$areanames{en}->{613574620} = "Yea";
$areanames{en}->{613574621} = "Yea";
$areanames{en}->{613574622} = "Yea";
$areanames{en}->{613574623} = "Yea";
$areanames{en}->{613574624} = "Yea";
$areanames{en}->{613574625} = "Yea";
$areanames{en}->{613574626} = "Yea";
$areanames{en}->{613574627} = "Yea";
$areanames{en}->{613574630} = "Beechworth";
$areanames{en}->{613574631} = "Beechworth";
$areanames{en}->{613574632} = "Beechworth";
$areanames{en}->{613574633} = "Beechworth";
$areanames{en}->{613574634} = "Beechworth";
$areanames{en}->{613574635} = "Beechworth";
$areanames{en}->{613574636} = "Beechworth";
$areanames{en}->{613574637} = "Beechworth";
$areanames{en}->{613574640} = "Benalla";
$areanames{en}->{613574641} = "Benalla";
$areanames{en}->{613574642} = "Benalla";
$areanames{en}->{613574643} = "Benalla";
$areanames{en}->{613574644} = "Benalla";
$areanames{en}->{613574650} = "Cheshunt";
$areanames{en}->{613574651} = "Cheshunt";
$areanames{en}->{613574652} = "Cheshunt";
$areanames{en}->{613574653} = "Cheshunt";
$areanames{en}->{613574656} = "Cheshunt";
$areanames{en}->{613574660} = "Chiltern";
$areanames{en}->{613574661} = "Chiltern";
$areanames{en}->{613574662} = "Chiltern";
$areanames{en}->{613574663} = "Chiltern";
$areanames{en}->{613574666} = "Chiltern";
$areanames{en}->{613574670} = "Killawarra";
$areanames{en}->{613574671} = "Killawarra";
$areanames{en}->{613574672} = "Killawarra";
$areanames{en}->{613574673} = "Killawarra";
$areanames{en}->{613574674} = "Killawarra";
$areanames{en}->{613574675} = "Killawarra";
$areanames{en}->{613574676} = "Killawarra";
$areanames{en}->{613574677} = "Killawarra";
$areanames{en}->{613574680} = "King\ Valley";
$areanames{en}->{613574681} = "King\ Valley";
$areanames{en}->{613574682} = "King\ Valley";
$areanames{en}->{613574683} = "King\ Valley";
$areanames{en}->{613574686} = "King\ Valley";
$areanames{en}->{613574690} = "Moyhu";
$areanames{en}->{613574691} = "Moyhu";
$areanames{en}->{613574692} = "Moyhu";
$areanames{en}->{613574693} = "Moyhu";
$areanames{en}->{613574694} = "Moyhu";
$areanames{en}->{613574695} = "Moyhu";
$areanames{en}->{613574696} = "Moyhu";
$areanames{en}->{613574697} = "Moyhu";
$areanames{en}->{613574700} = "St\ James";
$areanames{en}->{613574701} = "St\ James";
$areanames{en}->{613574702} = "St\ James";
$areanames{en}->{613574703} = "St\ James";
$areanames{en}->{613574706} = "St\ James";
$areanames{en}->{613574710} = "Swanpool";
$areanames{en}->{613574711} = "Swanpool";
$areanames{en}->{613574712} = "Swanpool";
$areanames{en}->{613574713} = "Swanpool";
$areanames{en}->{613574716} = "Swanpool";
$areanames{en}->{613574720} = "Tatong";
$areanames{en}->{613574721} = "Tatong";
$areanames{en}->{613574722} = "Tatong";
$areanames{en}->{613574723} = "Tatong";
$areanames{en}->{613574726} = "Tatong";
$areanames{en}->{613574730} = "Thoona";
$areanames{en}->{613574731} = "Thoona";
$areanames{en}->{613574732} = "Thoona";
$areanames{en}->{613574733} = "Thoona";
$areanames{en}->{613574736} = "Thoona";
$areanames{en}->{613574740} = "Tungamah";
$areanames{en}->{613574741} = "Tungamah";
$areanames{en}->{613574742} = "Tungamah";
$areanames{en}->{613574743} = "Tungamah";
$areanames{en}->{613574746} = "Tungamah";
$areanames{en}->{613574750} = "Wangaratta";
$areanames{en}->{613574751} = "Wangaratta";
$areanames{en}->{613574752} = "Wangaratta";
$areanames{en}->{613574753} = "Wangaratta";
$areanames{en}->{613574760} = "Whorouly";
$areanames{en}->{613574761} = "Whorouly";
$areanames{en}->{613574762} = "Whorouly";
$areanames{en}->{613574763} = "Whorouly";
$areanames{en}->{613574766} = "Whorouly";
$areanames{en}->{613574770} = "Winton";
$areanames{en}->{613574771} = "Winton";
$areanames{en}->{613574772} = "Winton";
$areanames{en}->{613574773} = "Winton";
$areanames{en}->{613574776} = "Winton";
$areanames{en}->{613574780} = "Yarrawonga";
$areanames{en}->{613574781} = "Yarrawonga";
$areanames{en}->{613574782} = "Yarrawonga";
$areanames{en}->{613574783} = "Yarrawonga";
$areanames{en}->{613574784} = "Yarrawonga";
$areanames{en}->{613574785} = "Yarrawonga";
$areanames{en}->{613574786} = "Yarrawonga";
$areanames{en}->{613574787} = "Yarrawonga";
$areanames{en}->{61357479} = "Seymour";
$areanames{en}->{6135748} = "Tungamah";
$areanames{en}->{61357490} = "Winton";
$areanames{en}->{61357491} = "Yarrawonga";
$areanames{en}->{61357492} = "Bright";
$areanames{en}->{61357493} = "Euroa";
$areanames{en}->{61357494} = "Benalla";
$areanames{en}->{61357495} = "Yarrawonga";
$areanames{en}->{61357496} = "Yarck";
$areanames{en}->{61357497} = "Yarck";
$areanames{en}->{61357498} = "Bright";
$areanames{en}->{61357499} = "Bright";
$areanames{en}->{61357500} = "Yarrawonga";
$areanames{en}->{61357501} = "Bright";
$areanames{en}->{61357502} = "Yea";
$areanames{en}->{61357503} = "Yea";
$areanames{en}->{61357504} = "Killawarra";
$areanames{en}->{61357505} = "Killawarra";
$areanames{en}->{61357506} = "King\ Valley";
$areanames{en}->{61357507} = "King\ Valley";
$areanames{en}->{61357508} = "Moyhu";
$areanames{en}->{61357509} = "Moyhu";
$areanames{en}->{61357510} = "Alexandra";
$areanames{en}->{61357511} = "Myrtleford";
$areanames{en}->{61357512} = "Myrtleford";
$areanames{en}->{61357513} = "Mount\ Beauty";
$areanames{en}->{61357514} = "Mount\ Beauty";
$areanames{en}->{61357515} = "Myrtleford";
$areanames{en}->{61357516} = "Myrtleford";
$areanames{en}->{61357517} = "Broadford";
$areanames{en}->{61357518} = "Broadford";
$areanames{en}->{61357519} = "Myrtleford";
$areanames{en}->{61357520} = "Myrtleford";
$areanames{en}->{61357521} = "Myrtleford";
$areanames{en}->{61357522} = "Myrtleford";
$areanames{en}->{61357523} = "Eildon";
$areanames{en}->{61357524} = "Eildon";
$areanames{en}->{61357525} = "Wangaratta";
$areanames{en}->{61357526} = "Myrtleford";
$areanames{en}->{61357527} = "Buffalo\ River";
$areanames{en}->{61357528} = "Buffalo\ River";
$areanames{en}->{61357529} = "Puckapunyal";
$areanames{en}->{61357530} = "Puckapunyal";
$areanames{en}->{61357531} = "Jamieson";
$areanames{en}->{61357532} = "Jamieson";
$areanames{en}->{61357533} = "Benalla";
$areanames{en}->{61357534} = "Myrtleford";
$areanames{en}->{61357535} = "Myrtleford";
$areanames{en}->{61357536} = "Mansfield";
$areanames{en}->{61357537} = "Mansfield";
$areanames{en}->{61357538} = "Taggerty";
$areanames{en}->{61357539} = "Taggerty";
$areanames{en}->{6135754} = "Mount\ Beauty";
$areanames{en}->{61357542} = "Buffalo\ River";
$areanames{en}->{61357550} = "Bright";
$areanames{en}->{61357551} = "Bright";
$areanames{en}->{61357552} = "Bright";
$areanames{en}->{61357553} = "Bonnie\ Doon";
$areanames{en}->{61357554} = "Bonnie\ Doon";
$areanames{en}->{61357555} = "Bright";
$areanames{en}->{61357556} = "Falls\ Creek";
$areanames{en}->{61357557} = "Falls\ Creek";
$areanames{en}->{61357558} = "Harrietville";
$areanames{en}->{61357559} = "Harrietville";
$areanames{en}->{61357561} = "Bright";
$areanames{en}->{61357562} = "Bright";
$areanames{en}->{61357563} = "Seymour";
$areanames{en}->{61357564} = "Seymour";
$areanames{en}->{61357565} = "Strathbogie";
$areanames{en}->{61357566} = "Strathbogie";
$areanames{en}->{61357567} = "Violet\ Town";
$areanames{en}->{61357568} = "Violet\ Town";
$areanames{en}->{61357569} = "Wangaratta";
$areanames{en}->{61357570} = "Wangaratta";
$areanames{en}->{61357571} = "Wangaratta";
$areanames{en}->{61357572} = "Wangaratta";
$areanames{en}->{61357573} = "Wangaratta";
$areanames{en}->{61357575} = "Wangaratta";
$areanames{en}->{61357576} = "Wangaratta";
$areanames{en}->{61357577} = "Mount\ Buller";
$areanames{en}->{61357578} = "Mount\ Buller";
$areanames{en}->{6135758} = "Falls\ Creek";
$areanames{en}->{6135759} = "Harrietville";
$areanames{en}->{61357600} = "Benalla";
$areanames{en}->{61357601} = "Benalla";
$areanames{en}->{61357602} = "Benalla";
$areanames{en}->{61357603} = "Benalla";
$areanames{en}->{61357604} = "Benalla";
$areanames{en}->{61357605} = "Creightons\ Creek";
$areanames{en}->{61357606} = "Creightons\ Creek";
$areanames{en}->{61357607} = "Winton";
$areanames{en}->{61357608} = "Devlins\ Bridge";
$areanames{en}->{61357609} = "Devlins\ Bridge";
$areanames{en}->{61357610} = "Benalla";
$areanames{en}->{61357611} = "Benalla";
$areanames{en}->{61357612} = "Benalla";
$areanames{en}->{61357613} = "Benalla";
$areanames{en}->{61357614} = "Benalla";
$areanames{en}->{61357615} = "Flowerdale";
$areanames{en}->{61357616} = "Flowerdale";
$areanames{en}->{61357617} = "Wangaratta";
$areanames{en}->{61357618} = "Wangaratta";
$areanames{en}->{61357619} = "Wangaratta";
$areanames{en}->{6135762} = "Benalla";
$areanames{en}->{61357630} = "Woods\ Point";
$areanames{en}->{61357631} = "Woods\ Point";
$areanames{en}->{61357632} = "Benalla";
$areanames{en}->{61357633} = "Benalla";
$areanames{en}->{61357634} = "Cheshunt";
$areanames{en}->{61357635} = "Cheshunt";
$areanames{en}->{61357636} = "Kinglake";
$areanames{en}->{61357637} = "Kinglake";
$areanames{en}->{61357638} = "Longwood";
$areanames{en}->{61357639} = "Longwood";
$areanames{en}->{61357641} = "St\ James";
$areanames{en}->{61357642} = "St\ James";
$areanames{en}->{61357644} = "St\ James";
$areanames{en}->{61357645} = "St\ James";
$areanames{en}->{61357646} = "St\ James";
$areanames{en}->{61357647} = "Benalla";
$areanames{en}->{61357648} = "Benalla";
$areanames{en}->{61357649} = "Benalla";
$areanames{en}->{61357651} = "Thoona";
$areanames{en}->{61357652} = "Thoona";
$areanames{en}->{61357653} = "Thoona";
$areanames{en}->{61357654} = "Kilmore";
$areanames{en}->{61357655} = "Kilmore";
$areanames{en}->{61357656} = "Kilmore";
$areanames{en}->{61357657} = "Alexandra";
$areanames{en}->{61357658} = "Alexandra";
$areanames{en}->{61357659} = "Alexandra";
$areanames{en}->{6135766} = "Winton";
$areanames{en}->{61357671} = "Tatong";
$areanames{en}->{61357672} = "Tatong";
$areanames{en}->{61357681} = "Swanpool";
$areanames{en}->{61357682} = "Swanpool";
$areanames{en}->{61357685} = "Euroa";
$areanames{en}->{61357686} = "Euroa";
$areanames{en}->{61357689} = "Graytown";
$areanames{en}->{61357690} = "Graytown";
$areanames{en}->{61357691} = "Kilmore";
$areanames{en}->{61357692} = "Kilmore";
$areanames{en}->{61357700} = "Alexandra";
$areanames{en}->{61357701} = "Alexandra";
$areanames{en}->{61357702} = "Alexandra";
$areanames{en}->{61357703} = "Alexandra";
$areanames{en}->{61357704} = "Alexandra";
$areanames{en}->{61357705} = "Kobyboyn";
$areanames{en}->{61357706} = "Kobyboyn";
$areanames{en}->{61357707} = "Yarck";
$areanames{en}->{61357708} = "Eildon";
$areanames{en}->{61357709} = "Taggerty";
$areanames{en}->{61357711} = "Seymour";
$areanames{en}->{61357712} = "Violet\ Town";
$areanames{en}->{61357713} = "Beechworth";
$areanames{en}->{61357714} = "Benalla";
$areanames{en}->{61357715} = "Cheshunt";
$areanames{en}->{61357716} = "Cheshunt";
$areanames{en}->{61357717} = "Wangaratta";
$areanames{en}->{61357718} = "Wangaratta";
$areanames{en}->{61357719} = "Wangaratta";
$areanames{en}->{61357720} = "Alexandra";
$areanames{en}->{61357721} = "Alexandra";
$areanames{en}->{61357722} = "Alexandra";
$areanames{en}->{61357723} = "Alexandra";
$areanames{en}->{61357724} = "Alexandra";
$areanames{en}->{61357732} = "Alexandra";
$areanames{en}->{61357734} = "Yarck";
$areanames{en}->{61357735} = "Yarck";
$areanames{en}->{61357736} = "Yarck";
$areanames{en}->{61357737} = "Yarck";
$areanames{en}->{61357738} = "Yarck";
$areanames{en}->{61357739} = "Yarck";
$areanames{en}->{6135774} = "Eildon";
$areanames{en}->{61357747} = "Taggerty";
$areanames{en}->{61357748} = "Taggerty";
$areanames{en}->{61357749} = "Taggerty";
$areanames{en}->{61357750} = "Mansfield";
$areanames{en}->{61357751} = "Mansfield";
$areanames{en}->{61357752} = "Mansfield";
$areanames{en}->{61357753} = "Mansfield";
$areanames{en}->{61357754} = "Wangaratta";
$areanames{en}->{61357755} = "Wangaratta";
$areanames{en}->{61357756} = "Wangaratta";
$areanames{en}->{61357757} = "Mansfield";
$areanames{en}->{61357758} = "Mansfield";
$areanames{en}->{61357762} = "Mansfield";
$areanames{en}->{61357763} = "Mansfield";
$areanames{en}->{61357764} = "Mansfield";
$areanames{en}->{61357769} = "Mansfield";
$areanames{en}->{6135777} = "Jamieson";
$areanames{en}->{61357776} = "Mount\ Buller";
$areanames{en}->{61357777} = "Mount\ Buller";
$areanames{en}->{61357778} = "Woods\ Point";
$areanames{en}->{61357779} = "Mount\ Buller";
$areanames{en}->{61357787} = "Bonnie\ Doon";
$areanames{en}->{61357788} = "Bonnie\ Doon";
$areanames{en}->{61357789} = "Bonnie\ Doon";
$areanames{en}->{61357791} = "Mansfield";
$areanames{en}->{6135780} = "Flowerdale";
$areanames{en}->{61357810} = "Kilmore";
$areanames{en}->{61357811} = "Kilmore";
$areanames{en}->{61357812} = "Winton";
$areanames{en}->{61357813} = "Winton";
$areanames{en}->{61357814} = "Yarrawonga";
$areanames{en}->{61357815} = "Yarrawonga";
$areanames{en}->{61357830} = "Kilmore";
$areanames{en}->{61357831} = "Kilmore";
$areanames{en}->{61357832} = "Kilmore";
$areanames{en}->{61357833} = "Kilmore";
$areanames{en}->{61357834} = "Kilmore";
$areanames{en}->{61357835} = "Kilmore";
$areanames{en}->{61357836} = "Whorouly";
$areanames{en}->{61357837} = "Whorouly";
$areanames{en}->{61357838} = "Kilmore";
$areanames{en}->{6135784} = "Broadford";
$areanames{en}->{61357851} = "Pyalong";
$areanames{en}->{61357852} = "Pyalong";
$areanames{en}->{61357853} = "Seymour";
$areanames{en}->{61357854} = "Seymour";
$areanames{en}->{61357855} = "Seymour";
$areanames{en}->{6135786} = "Kinglake";
$areanames{en}->{61357870} = "Kilmore";
$areanames{en}->{61357871} = "Kilmore";
$areanames{en}->{61357872} = "Kilmore";
$areanames{en}->{61357879} = "Nagambie";
$areanames{en}->{61357880} = "Nagambie";
$areanames{en}->{61357883} = "Pyalong";
$areanames{en}->{61357884} = "Pyalong";
$areanames{en}->{61357890} = "Kilmore";
$areanames{en}->{61357891} = "Kilmore";
$areanames{en}->{61357896} = "Beechworth";
$areanames{en}->{61357897} = "Beechworth";
$areanames{en}->{61357898} = "Benalla";
$areanames{en}->{61357899} = "Benalla";
$areanames{en}->{61357900} = "Chiltern";
$areanames{en}->{61357901} = "Chiltern";
$areanames{en}->{61357903} = "Creightons\ Creek";
$areanames{en}->{61357904} = "Creightons\ Creek";
$areanames{en}->{61357905} = "Strathbogie";
$areanames{en}->{61357906} = "Strathbogie";
$areanames{en}->{61357908} = "Strathbogie";
$areanames{en}->{6135791} = "Wangaratta";
$areanames{en}->{6135792} = "Seymour";
$areanames{en}->{61357926} = "Thoona";
$areanames{en}->{61357927} = "Thoona";
$areanames{en}->{61357928} = "Tungamah";
$areanames{en}->{61357929} = "Tungamah";
$areanames{en}->{61357930} = "Puckapunyal";
$areanames{en}->{61357931} = "Puckapunyal";
$areanames{en}->{61357932} = "Puckapunyal";
$areanames{en}->{61357933} = "Wangaratta";
$areanames{en}->{61357934} = "Wangaratta";
$areanames{en}->{61357936} = "Seymour";
$areanames{en}->{61357937} = "Puckapunyal";
$areanames{en}->{61357938} = "Puckapunyal";
$areanames{en}->{61357939} = "Puckapunyal";
$areanames{en}->{6135794} = "Nagambie";
$areanames{en}->{61357943} = "Graytown";
$areanames{en}->{61357944} = "Graytown";
$areanames{en}->{61357949} = "Graytown";
$areanames{en}->{6135795} = "Euroa";
$areanames{en}->{61357961} = "Seymour";
$areanames{en}->{61357962} = "Seymour";
$areanames{en}->{61357965} = "Tatong";
$areanames{en}->{61357966} = "Tatong";
$areanames{en}->{61357967} = "Swanpool";
$areanames{en}->{61357968} = "Swanpool";
$areanames{en}->{61357969} = "Kobyboyn";
$areanames{en}->{6135797} = "Yea";
$areanames{en}->{61357977} = "Devlins\ Bridge";
$areanames{en}->{61357978} = "Devlins\ Bridge";
$areanames{en}->{61357979} = "Devlins\ Bridge";
$areanames{en}->{61357981} = "Violet\ Town";
$areanames{en}->{61357982} = "Violet\ Town";
$areanames{en}->{61357983} = "Wangaratta";
$areanames{en}->{61357985} = "Longwood";
$areanames{en}->{61357987} = "Longwood";
$areanames{en}->{61357989} = "Euroa";
$areanames{en}->{6135799} = "Seymour";
$areanames{en}->{61358000} = "Shepparton";
$areanames{en}->{61358001} = "Shepparton";
$areanames{en}->{61358002} = "Shepparton";
$areanames{en}->{61358003} = "Berrigan";
$areanames{en}->{61358004} = "Berrigan";
$areanames{en}->{61358005} = "Berrigan";
$areanames{en}->{61358006} = "Blighty";
$areanames{en}->{61358007} = "Blighty";
$areanames{en}->{61358008} = "Blighty";
$areanames{en}->{61358009} = "Logie\ Brae";
$areanames{en}->{61358010} = "Brassi";
$areanames{en}->{61358011} = "Brassi";
$areanames{en}->{61358012} = "Brassi";
$areanames{en}->{61358013} = "Caldwell";
$areanames{en}->{61358014} = "Caldwell";
$areanames{en}->{61358015} = "Caldwell";
$areanames{en}->{61358016} = "Cobram";
$areanames{en}->{61358017} = "Cobram";
$areanames{en}->{61358018} = "Cobram";
$areanames{en}->{61358019} = "Mabins\ Well";
$areanames{en}->{61358020} = "Conargo";
$areanames{en}->{61358021} = "Conargo";
$areanames{en}->{61358022} = "Conargo";
$areanames{en}->{61358023} = "Cornalla";
$areanames{en}->{61358024} = "Cornalla";
$areanames{en}->{61358025} = "Cornalla";
$areanames{en}->{61358026} = "Deniliquin";
$areanames{en}->{61358027} = "Deniliquin";
$areanames{en}->{61358028} = "Deniliquin";
$areanames{en}->{61358029} = "Mathoura";
$areanames{en}->{61358030} = "Dookie";
$areanames{en}->{61358031} = "Dookie";
$areanames{en}->{61358032} = "Dookie";
$areanames{en}->{61358033} = "Finley";
$areanames{en}->{61358034} = "Finley";
$areanames{en}->{61358035} = "Finley";
$areanames{en}->{61358036} = "Jerilderie";
$areanames{en}->{61358037} = "Jerilderie";
$areanames{en}->{61358038} = "Jerilderie";
$areanames{en}->{61358039} = "Moulamein";
$areanames{en}->{61358040} = "Jimaringle";
$areanames{en}->{61358041} = "Jimaringle";
$areanames{en}->{61358042} = "Jimaringle";
$areanames{en}->{61358043} = "Katamatite";
$areanames{en}->{61358044} = "Katamatite";
$areanames{en}->{61358045} = "Katamatite";
$areanames{en}->{61358046} = "Katandra\ West";
$areanames{en}->{61358047} = "Katandra\ West";
$areanames{en}->{61358048} = "Katandra\ West";
$areanames{en}->{61358049} = "Wakool";
$areanames{en}->{61358050} = "Kialla\ East";
$areanames{en}->{61358051} = "Kialla\ East";
$areanames{en}->{61358052} = "Kialla\ East";
$areanames{en}->{61358053} = "Kyabram";
$areanames{en}->{61358054} = "Kyabram";
$areanames{en}->{61358055} = "Kyabram";
$areanames{en}->{61358056} = "Lalalty";
$areanames{en}->{61358057} = "Lalalty";
$areanames{en}->{61358058} = "Lalalty";
$areanames{en}->{61358059} = "Berrigan";
$areanames{en}->{61358060} = "Logie\ Brae";
$areanames{en}->{61358061} = "Logie\ Brae";
$areanames{en}->{61358062} = "Logie\ Brae";
$areanames{en}->{61358063} = "Mabins\ Well";
$areanames{en}->{61358064} = "Mabins\ Well";
$areanames{en}->{61358065} = "Mabins\ Well";
$areanames{en}->{61358066} = "Mathoura";
$areanames{en}->{61358067} = "Mathoura";
$areanames{en}->{61358068} = "Mathoura";
$areanames{en}->{61358069} = "Blighty";
$areanames{en}->{61358070} = "Moulamein";
$areanames{en}->{61358071} = "Moulamein";
$areanames{en}->{61358072} = "Moulamein";
$areanames{en}->{61358073} = "Nathalia";
$areanames{en}->{61358074} = "Nathalia";
$areanames{en}->{61358075} = "Nathalia";
$areanames{en}->{61358076} = "Numurkah";
$areanames{en}->{61358077} = "Numurkah";
$areanames{en}->{61358078} = "Numurkah";
$areanames{en}->{61358079} = "Brassi";
$areanames{en}->{61358080} = "Picola";
$areanames{en}->{61358081} = "Picola";
$areanames{en}->{61358082} = "Picola";
$areanames{en}->{61358083} = "Rushworth";
$areanames{en}->{61358084} = "Rushworth";
$areanames{en}->{61358085} = "Rushworth";
$areanames{en}->{61358086} = "Tatura";
$areanames{en}->{61358087} = "Tatura";
$areanames{en}->{61358088} = "Tatura";
$areanames{en}->{61358089} = "Caldwell";
$areanames{en}->{61358090} = "Tocumwal";
$areanames{en}->{61358091} = "Tocumwal";
$areanames{en}->{61358092} = "Tocumwal";
$areanames{en}->{61358093} = "Tongala";
$areanames{en}->{61358094} = "Tongala";
$areanames{en}->{61358095} = "Tongala";
$areanames{en}->{61358096} = "Undera";
$areanames{en}->{61358097} = "Undera";
$areanames{en}->{61358098} = "Undera";
$areanames{en}->{61358099} = "Conargo";
$areanames{en}->{61358100} = "Wakool";
$areanames{en}->{61358101} = "Wakool";
$areanames{en}->{61358102} = "Wakool";
$areanames{en}->{61358103} = "Wanganella";
$areanames{en}->{61358104} = "Wanganella";
$areanames{en}->{61358105} = "Wanganella";
$areanames{en}->{61358106} = "Yalca";
$areanames{en}->{61358107} = "Yalca";
$areanames{en}->{61358108} = "Yalca";
$areanames{en}->{61358109} = "Logie\ Brae";
$areanames{en}->{61358110} = "Mabins\ Well";
$areanames{en}->{61358111} = "Mathoura";
$areanames{en}->{61358112} = "Moulamein";
$areanames{en}->{61358113} = "Wakool";
$areanames{en}->{61358114} = "Berrigan";
$areanames{en}->{61358115} = "Blighty";
$areanames{en}->{61358116} = "Brassi";
$areanames{en}->{61358117} = "Caldwell";
$areanames{en}->{61358118} = "Conargo";
$areanames{en}->{61358119} = "Cornalla";
$areanames{en}->{61358120} = "Deniliquin";
$areanames{en}->{61358121} = "Finley";
$areanames{en}->{61358122} = "Cornalla";
$areanames{en}->{61358123} = "Jerilderie";
$areanames{en}->{61358124} = "Jimaringle";
$areanames{en}->{61358125} = "Katandra\ West";
$areanames{en}->{61358126} = "Kialla\ East";
$areanames{en}->{61358127} = "Kyabram";
$areanames{en}->{61358128} = "Rushworth";
$areanames{en}->{61358129} = "Shepparton";
$areanames{en}->{61358130} = "Tatura";
$areanames{en}->{61358131} = "Tongala";
$areanames{en}->{61358132} = "Undera";
$areanames{en}->{61358133} = "Wanganella";
$areanames{en}->{61358134} = "Cobram";
$areanames{en}->{61358135} = "Katamatite";
$areanames{en}->{61358136} = "Lalalty";
$areanames{en}->{61358137} = "Nathalia";
$areanames{en}->{61358138} = "Numurkah";
$areanames{en}->{61358139} = "Picola";
$areanames{en}->{61358140} = "Tocumwal";
$areanames{en}->{61358141} = "Yalca";
$areanames{en}->{61358142} = "Dookie";
$areanames{en}->{61358143} = "Shepparton";
$areanames{en}->{61358144} = "Shepparton";
$areanames{en}->{61358145} = "Shepparton";
$areanames{en}->{61358146} = "Deniliquin";
$areanames{en}->{61358147} = "Finley";
$areanames{en}->{61358148} = "Jerilderie";
$areanames{en}->{61358149} = "Jimaringle";
$areanames{en}->{61358150} = "Wanganella";
$areanames{en}->{61358151} = "Cobram";
$areanames{en}->{61358152} = "Katamatite";
$areanames{en}->{61358153} = "Lalalty";
$areanames{en}->{61358154} = "Nathalia";
$areanames{en}->{61358155} = "Numurkah";
$areanames{en}->{61358156} = "Picola";
$areanames{en}->{61358157} = "Tocumwal";
$areanames{en}->{61358158} = "Yalca";
$areanames{en}->{61358159} = "Katandra\ West";
$areanames{en}->{61358160} = "Kialla\ East";
$areanames{en}->{61358161} = "Kyabram";
$areanames{en}->{61358162} = "Rushworth";
$areanames{en}->{61358163} = "Shepparton";
$areanames{en}->{61358164} = "Tatura";
$areanames{en}->{61358165} = "Tongala";
$areanames{en}->{61358166} = "Undera";
$areanames{en}->{61358167} = "Dookie";
$areanames{en}->{61358168} = "Berrigan";
$areanames{en}->{61358169} = "Blighty";
$areanames{en}->{61358170} = "Brassi";
$areanames{en}->{61358171} = "Caldwell";
$areanames{en}->{61358172} = "Conargo";
$areanames{en}->{61358173} = "Cornalla";
$areanames{en}->{61358174} = "Deniliquin";
$areanames{en}->{61358175} = "Finley";
$areanames{en}->{61358176} = "Jerilderie";
$areanames{en}->{61358177} = "Jimaringle";
$areanames{en}->{61358178} = "Logie\ Brae";
$areanames{en}->{61358179} = "Mabins\ Well";
$areanames{en}->{61358180} = "Mathoura";
$areanames{en}->{61358181} = "Moulamein";
$areanames{en}->{61358182} = "Wakool";
$areanames{en}->{61358183} = "Wanganella";
$areanames{en}->{61358184} = "Cobram";
$areanames{en}->{61358185} = "Katamatite";
$areanames{en}->{61358186} = "Lalalty";
$areanames{en}->{61358187} = "Nathalia";
$areanames{en}->{61358188} = "Numurkah";
$areanames{en}->{61358189} = "Picola";
$areanames{en}->{61358190} = "Tocumwal";
$areanames{en}->{61358191} = "Yalca";
$areanames{en}->{61358192} = "Dookie";
$areanames{en}->{61358193} = "Katandra\ West";
$areanames{en}->{61358194} = "Kialla\ East";
$areanames{en}->{61358195} = "Kyabram";
$areanames{en}->{61358196} = "Rushworth";
$areanames{en}->{61358197} = "Shepparton";
$areanames{en}->{61358198} = "Tatura";
$areanames{en}->{61358199} = "Tongala";
$areanames{en}->{613582} = "Shepparton";
$areanames{en}->{6135824} = "Tatura";
$areanames{en}->{6135826} = "Tatura";
$areanames{en}->{61358260} = "Undera";
$areanames{en}->{61358264} = "Undera";
$areanames{en}->{61358268} = "Undera";
$areanames{en}->{61358269} = "Undera";
$areanames{en}->{6135827} = "Kialla\ East";
$areanames{en}->{61358280} = "Berrigan";
$areanames{en}->{61358281} = "Blighty";
$areanames{en}->{61358282} = "Brassi";
$areanames{en}->{61358283} = "Katandra\ West";
$areanames{en}->{61358284} = "Katandra\ West";
$areanames{en}->{61358285} = "Katandra\ West";
$areanames{en}->{61358286} = "Dookie";
$areanames{en}->{61358287} = "Dookie";
$areanames{en}->{61358288} = "Dookie";
$areanames{en}->{61358289} = "Dookie";
$areanames{en}->{61358300} = "Caldwell";
$areanames{en}->{61358301} = "Conargo";
$areanames{en}->{61358302} = "Cornalla";
$areanames{en}->{61358303} = "Deniliquin";
$areanames{en}->{61358304} = "Finley";
$areanames{en}->{61358305} = "Jerilderie";
$areanames{en}->{61358306} = "Jimaringle";
$areanames{en}->{61358307} = "Logie\ Brae";
$areanames{en}->{61358308} = "Mabins\ Well";
$areanames{en}->{61358309} = "Mathoura";
$areanames{en}->{6135831} = "Shepparton";
$areanames{en}->{6135832} = "Shepparton";
$areanames{en}->{61358330} = "Shepparton";
$areanames{en}->{61358331} = "Shepparton";
$areanames{en}->{61358332} = "Shepparton";
$areanames{en}->{61358333} = "Shepparton";
$areanames{en}->{61358334} = "Shepparton";
$areanames{en}->{61358335} = "Tatura";
$areanames{en}->{61358336} = "Undera";
$areanames{en}->{61358337} = "Kialla\ East";
$areanames{en}->{61358338} = "Katandra\ West";
$areanames{en}->{61358339} = "Dookie";
$areanames{en}->{61358340} = "Moulamein";
$areanames{en}->{61358341} = "Wakool";
$areanames{en}->{61358342} = "Wanganella";
$areanames{en}->{61358343} = "Cobram";
$areanames{en}->{61358344} = "Katamatite";
$areanames{en}->{61358345} = "Lalalty";
$areanames{en}->{61358346} = "Nathalia";
$areanames{en}->{61358347} = "Numurkah";
$areanames{en}->{61358348} = "Picola";
$areanames{en}->{61358349} = "Tocumwal";
$areanames{en}->{61358350} = "Yalca";
$areanames{en}->{61358351} = "Dookie";
$areanames{en}->{61358352} = "Katandra\ West";
$areanames{en}->{61358353} = "Kialla\ East";
$areanames{en}->{61358354} = "Kyabram";
$areanames{en}->{61358355} = "Rushworth";
$areanames{en}->{61358356} = "Shepparton";
$areanames{en}->{61358357} = "Tatura";
$areanames{en}->{61358358} = "Tongala";
$areanames{en}->{61358359} = "Undera";
$areanames{en}->{61358360} = "Berrigan";
$areanames{en}->{61358361} = "Blighty";
$areanames{en}->{61358362} = "Brassi";
$areanames{en}->{61358363} = "Caldwell";
$areanames{en}->{61358364} = "Conargo";
$areanames{en}->{61358365} = "Cornalla";
$areanames{en}->{61358366} = "Deniliquin";
$areanames{en}->{61358367} = "Finley";
$areanames{en}->{61358368} = "Jerilderie";
$areanames{en}->{61358369} = "Jimaringle";
$areanames{en}->{61358370} = "Logie\ Brae";
$areanames{en}->{61358371} = "Mabins\ Well";
$areanames{en}->{61358372} = "Mathoura";
$areanames{en}->{61358373} = "Moulamein";
$areanames{en}->{61358374} = "Wakool";
$areanames{en}->{61358375} = "Wanganella";
$areanames{en}->{61358376} = "Cobram";
$areanames{en}->{61358377} = "Katamatite";
$areanames{en}->{61358378} = "Lalalty";
$areanames{en}->{61358379} = "Nathalia";
$areanames{en}->{61358380} = "Numurkah";
$areanames{en}->{61358381} = "Picola";
$areanames{en}->{61358382} = "Tocumwal";
$areanames{en}->{61358383} = "Yalca";
$areanames{en}->{61358384} = "Dookie";
$areanames{en}->{61358385} = "Katandra\ West";
$areanames{en}->{61358386} = "Kialla\ East";
$areanames{en}->{61358387} = "Kyabram";
$areanames{en}->{61358388} = "Rushworth";
$areanames{en}->{61358389} = "Tatura";
$areanames{en}->{61358390} = "Tongala";
$areanames{en}->{61358391} = "Undera";
$areanames{en}->{61358392} = "Berrigan";
$areanames{en}->{61358393} = "Blighty";
$areanames{en}->{61358394} = "Brassi";
$areanames{en}->{61358395} = "Caldwell";
$areanames{en}->{61358396} = "Conargo";
$areanames{en}->{61358397} = "Cornalla";
$areanames{en}->{61358398} = "Deniliquin";
$areanames{en}->{61358399} = "Finley";
$areanames{en}->{61358400} = "Jerilderie";
$areanames{en}->{61358401} = "Jimaringle";
$areanames{en}->{61358402} = "Logie\ Brae";
$areanames{en}->{61358403} = "Mabins\ Well";
$areanames{en}->{61358404} = "Mathoura";
$areanames{en}->{61358405} = "Moulamein";
$areanames{en}->{61358406} = "Wakool";
$areanames{en}->{61358407} = "Wanganella";
$areanames{en}->{61358408} = "Cobram";
$areanames{en}->{61358409} = "Katamatite";
$areanames{en}->{61358410} = "Lalalty";
$areanames{en}->{61358411} = "Nathalia";
$areanames{en}->{61358412} = "Numurkah";
$areanames{en}->{61358413} = "Picola";
$areanames{en}->{61358414} = "Tocumwal";
$areanames{en}->{61358415} = "Yalca";
$areanames{en}->{61358416} = "Dookie";
$areanames{en}->{61358417} = "Katandra\ West";
$areanames{en}->{61358418} = "Kialla\ East";
$areanames{en}->{61358419} = "Kyabram";
$areanames{en}->{61358420} = "Rushworth";
$areanames{en}->{61358421} = "Tatura";
$areanames{en}->{61358422} = "Tongala";
$areanames{en}->{61358423} = "Undera";
$areanames{en}->{61358424} = "Berrigan";
$areanames{en}->{61358425} = "Blighty";
$areanames{en}->{61358426} = "Brassi";
$areanames{en}->{61358427} = "Caldwell";
$areanames{en}->{61358428} = "Conargo";
$areanames{en}->{61358429} = "Cornalla";
$areanames{en}->{61358430} = "Deniliquin";
$areanames{en}->{61358431} = "Finley";
$areanames{en}->{61358432} = "Jerilderie";
$areanames{en}->{61358433} = "Jimaringle";
$areanames{en}->{61358434} = "Logie\ Brae";
$areanames{en}->{61358435} = "Mabins\ Well";
$areanames{en}->{61358436} = "Mathoura";
$areanames{en}->{61358437} = "Moulamein";
$areanames{en}->{61358438} = "Wakool";
$areanames{en}->{61358439} = "Wanganella";
$areanames{en}->{61358440} = "Cobram";
$areanames{en}->{61358441} = "Katamatite";
$areanames{en}->{61358442} = "Lalalty";
$areanames{en}->{61358443} = "Nathalia";
$areanames{en}->{61358444} = "Numurkah";
$areanames{en}->{61358445} = "Picola";
$areanames{en}->{61358446} = "Tocumwal";
$areanames{en}->{61358447} = "Yalca";
$areanames{en}->{61358448} = "Dookie";
$areanames{en}->{61358449} = "Katandra\ West";
$areanames{en}->{61358450} = "Kialla\ East";
$areanames{en}->{61358451} = "Kyabram";
$areanames{en}->{61358452} = "Rushworth";
$areanames{en}->{61358453} = "Shepparton";
$areanames{en}->{61358454} = "Tatura";
$areanames{en}->{61358455} = "Tongala";
$areanames{en}->{61358456} = "Undera";
$areanames{en}->{61358457} = "Berrigan";
$areanames{en}->{61358458} = "Logie\ Brae";
$areanames{en}->{61358459} = "Katamatite";
$areanames{en}->{61358460} = "Cornalla";
$areanames{en}->{61358461} = "Tocumwal";
$areanames{en}->{61358462} = "Nathalia";
$areanames{en}->{61358463} = "Deniliquin";
$areanames{en}->{61358464} = "Wanganella";
$areanames{en}->{61358465} = "Tongala";
$areanames{en}->{61358466} = "Undera";
$areanames{en}->{61358467} = "Wakool";
$areanames{en}->{61358468} = "Shepparton";
$areanames{en}->{61358469} = "Berrigan";
$areanames{en}->{61358470} = "Deniliquin";
$areanames{en}->{61358471} = "Blighty";
$areanames{en}->{61358472} = "Berrigan";
$areanames{en}->{61358473} = "Cobram";
$areanames{en}->{61358474} = "Dookie";
$areanames{en}->{61358475} = "Finley";
$areanames{en}->{61358476} = "Caldwell";
$areanames{en}->{61358477} = "Numurkah";
$areanames{en}->{61358478} = "Mathoura";
$areanames{en}->{61358479} = "Tocumwal";
$areanames{en}->{61358480} = "Blighty";
$areanames{en}->{61358481} = "Tatura";
$areanames{en}->{61358482} = "Brassi";
$areanames{en}->{61358483} = "Rushworth";
$areanames{en}->{61358484} = "Kyabram";
$areanames{en}->{61358485} = "Jimaringle";
$areanames{en}->{61358486} = "Shepparton";
$areanames{en}->{61358487} = "Tatura";
$areanames{en}->{61358488} = "Tongala";
$areanames{en}->{61358489} = "Brassi";
$areanames{en}->{61358490} = "Kyabram";
$areanames{en}->{61358491} = "Shepparton";
$areanames{en}->{61358492} = "Shepparton";
$areanames{en}->{61358493} = "Finley";
$areanames{en}->{61358494} = "Shepparton";
$areanames{en}->{61358495} = "Caldwell";
$areanames{en}->{61358496} = "Mathoura";
$areanames{en}->{61358497} = "Wanganella";
$areanames{en}->{61358498} = "Jimaringle";
$areanames{en}->{61358499} = "Conargo";
$areanames{en}->{613585} = "Kyabram";
$areanames{en}->{61358500} = "Jerilderie";
$areanames{en}->{61358501} = "Moulamein";
$areanames{en}->{61358502} = "Blighty";
$areanames{en}->{61358503} = "Logie\ Brae";
$areanames{en}->{61358504} = "Wakool";
$areanames{en}->{61358505} = "Cornalla";
$areanames{en}->{61358506} = "Mabins\ Well";
$areanames{en}->{61358507} = "Conargo";
$areanames{en}->{61358508} = "Berrigan";
$areanames{en}->{61358509} = "Kialla\ East";
$areanames{en}->{61358518} = "Rushworth";
$areanames{en}->{61358519} = "Tongala";
$areanames{en}->{6135856} = "Rushworth";
$areanames{en}->{6135858} = "Shepparton";
$areanames{en}->{6135859} = "Tongala";
$areanames{en}->{61358600} = "Picola";
$areanames{en}->{61358601} = "Picola";
$areanames{en}->{61358602} = "Katandra\ West";
$areanames{en}->{61358603} = "Katandra\ West";
$areanames{en}->{61358604} = "Kialla\ East";
$areanames{en}->{61358605} = "Kialla\ East";
$areanames{en}->{61358606} = "Kyabram";
$areanames{en}->{61358607} = "Kyabram";
$areanames{en}->{61358608} = "Rushworth";
$areanames{en}->{61358609} = "Rushworth";
$areanames{en}->{6135861} = "Numurkah";
$areanames{en}->{61358616} = "Katamatite";
$areanames{en}->{61358617} = "Nathalia";
$areanames{en}->{61358618} = "Yalca";
$areanames{en}->{61358619} = "Picola";
$areanames{en}->{6135862} = "Numurkah";
$areanames{en}->{61358630} = "Shepparton";
$areanames{en}->{61358631} = "Shepparton";
$areanames{en}->{61358632} = "Tocumwal";
$areanames{en}->{61358633} = "Tocumwal";
$areanames{en}->{61358634} = "Tongala";
$areanames{en}->{61358635} = "Tongala";
$areanames{en}->{61358636} = "Undera";
$areanames{en}->{61358637} = "Undera";
$areanames{en}->{61358638} = "Blighty";
$areanames{en}->{61358639} = "Blighty";
$areanames{en}->{6135864} = "Numurkah";
$areanames{en}->{6135865} = "Katamatite";
$areanames{en}->{6135866} = "Nathalia";
$areanames{en}->{6135867} = "Nathalia";
$areanames{en}->{6135868} = "Yalca";
$areanames{en}->{6135869} = "Picola";
$areanames{en}->{61358700} = "Lalalty";
$areanames{en}->{61358701} = "Lalalty";
$areanames{en}->{61358702} = "Nathalia";
$areanames{en}->{61358703} = "Nathalia";
$areanames{en}->{61358704} = "Numurkah";
$areanames{en}->{61358705} = "Numurkah";
$areanames{en}->{61358706} = "Yalca";
$areanames{en}->{61358707} = "Yalca";
$areanames{en}->{61358708} = "Brassi";
$areanames{en}->{61358709} = "Brassi";
$areanames{en}->{6135871} = "Cobram";
$areanames{en}->{6135872} = "Cobram";
$areanames{en}->{6135873} = "Cobram";
$areanames{en}->{6135874} = "Tocumwal";
$areanames{en}->{6135875} = "Cobram";
$areanames{en}->{61358758} = "Tocumwal";
$areanames{en}->{61358759} = "Lalalty";
$areanames{en}->{6135876} = "Lalalty";
$areanames{en}->{61358770} = "Dookie";
$areanames{en}->{61358771} = "Dookie";
$areanames{en}->{61358772} = "Shepparton";
$areanames{en}->{61358773} = "Blighty";
$areanames{en}->{61358774} = "Blighty";
$areanames{en}->{61358775} = "Blighty";
$areanames{en}->{61358776} = "Jerilderie";
$areanames{en}->{61358777} = "Deniliquin";
$areanames{en}->{61358778} = "Brassi";
$areanames{en}->{61358779} = "Kyabram";
$areanames{en}->{61358780} = "Lalalty";
$areanames{en}->{61358781} = "Shepparton";
$areanames{en}->{61358782} = "Tatura";
$areanames{en}->{61358783} = "Tatura";
$areanames{en}->{61358784} = "Berrigan";
$areanames{en}->{61358785} = "Berrigan";
$areanames{en}->{61358786} = "Cornalla";
$areanames{en}->{61358787} = "Cornalla";
$areanames{en}->{61358788} = "Deniliquin";
$areanames{en}->{61358789} = "Deniliquin";
$areanames{en}->{61358790} = "Finley";
$areanames{en}->{61358791} = "Finley";
$areanames{en}->{61358792} = "Jerilderie";
$areanames{en}->{61358793} = "Jerilderie";
$areanames{en}->{61358794} = "Mathoura";
$areanames{en}->{61358795} = "Mathoura";
$areanames{en}->{61358796} = "Cobram";
$areanames{en}->{61358797} = "Cobram";
$areanames{en}->{61358798} = "Katamatite";
$areanames{en}->{61358799} = "Katamatite";
$areanames{en}->{61358800} = "Wakool";
$areanames{en}->{61358801} = "Deniliquin";
$areanames{en}->{61358802} = "Deniliquin";
$areanames{en}->{61358803} = "Mathoura";
$areanames{en}->{61358804} = "Cornalla";
$areanames{en}->{61358805} = "Blighty";
$areanames{en}->{61358806} = "Conargo";
$areanames{en}->{61358807} = "Wanganella";
$areanames{en}->{61358808} = "Brassi";
$areanames{en}->{61358809} = "Caldwell";
$areanames{en}->{6135881} = "Deniliquin";
$areanames{en}->{6135882} = "Blighty";
$areanames{en}->{61358820} = "Cornalla";
$areanames{en}->{61358821} = "Cornalla";
$areanames{en}->{61358822} = "Deniliquin";
$areanames{en}->{61358823} = "Deniliquin";
$areanames{en}->{6135883} = "Finley";
$areanames{en}->{61358840} = "Brassi";
$areanames{en}->{61358841} = "Brassi";
$areanames{en}->{61358842} = "Caldwell";
$areanames{en}->{61358843} = "Mathoura";
$areanames{en}->{61358844} = "Mathoura";
$areanames{en}->{61358845} = "Mathoura";
$areanames{en}->{61358846} = "Conargo";
$areanames{en}->{61358847} = "Wanganella";
$areanames{en}->{61358848} = "Wanganella";
$areanames{en}->{61358849} = "Wanganella";
$areanames{en}->{6135885} = "Berrigan";
$areanames{en}->{61358856} = "Jerilderie";
$areanames{en}->{61358857} = "Jerilderie";
$areanames{en}->{61358859} = "Logie\ Brae";
$areanames{en}->{6135886} = "Jerilderie";
$areanames{en}->{61358867} = "Mabins\ Well";
$areanames{en}->{6135887} = "Moulamein";
$areanames{en}->{61358870} = "Wakool";
$areanames{en}->{61358871} = "Wakool";
$areanames{en}->{61358872} = "Wakool";
$areanames{en}->{61358873} = "Jimaringle";
$areanames{en}->{61358880} = "Berrigan";
$areanames{en}->{61358881} = "Jimaringle";
$areanames{en}->{61358882} = "Finley";
$areanames{en}->{61358883} = "Finley";
$areanames{en}->{61358884} = "Finley";
$areanames{en}->{61358885} = "Berrigan";
$areanames{en}->{61358886} = "Jerilderie";
$areanames{en}->{61358887} = "Logie\ Brae";
$areanames{en}->{61358888} = "Mabins\ Well";
$areanames{en}->{61358889} = "Moulamein";
$areanames{en}->{6135889} = "Mathoura";
$areanames{en}->{61358900} = "Caldwell";
$areanames{en}->{61358901} = "Deniliquin";
$areanames{en}->{61358902} = "Deniliquin";
$areanames{en}->{61358903} = "Deniliquin";
$areanames{en}->{61358904} = "Deniliquin";
$areanames{en}->{61358905} = "Deniliquin";
$areanames{en}->{61358906} = "Finley";
$areanames{en}->{61358907} = "Finley";
$areanames{en}->{61358908} = "Finley";
$areanames{en}->{61358909} = "Wakool";
$areanames{en}->{61358910} = "Shepparton";
$areanames{en}->{61358911} = "Shepparton";
$areanames{en}->{61358912} = "Shepparton";
$areanames{en}->{61358913} = "Katandra\ West";
$areanames{en}->{61358914} = "Cobram";
$areanames{en}->{61358915} = "Tatura";
$areanames{en}->{61358916} = "Tocumwal";
$areanames{en}->{61358917} = "Nathalia";
$areanames{en}->{61358918} = "Katamatite";
$areanames{en}->{61358919} = "Mabins\ Well";
$areanames{en}->{61358920} = "Moulamein";
$areanames{en}->{61358921} = "Picola";
$areanames{en}->{61358922} = "Kyabram";
$areanames{en}->{61358923} = "Rushworth";
$areanames{en}->{61358924} = "Dookie";
$areanames{en}->{61358925} = "Kialla\ East";
$areanames{en}->{61358926} = "Lalalty";
$areanames{en}->{61358927} = "Yalca";
$areanames{en}->{61358928} = "Undera";
$areanames{en}->{61358929} = "Numurkah";
$areanames{en}->{61358930} = "Yalca";
$areanames{en}->{61358931} = "Shepparton";
$areanames{en}->{61358932} = "Tongala";
$areanames{en}->{61358933} = "Numurkah";
$areanames{en}->{61358934} = "Finley";
$areanames{en}->{61358935} = "Caldwell";
$areanames{en}->{61358936} = "Mathoura";
$areanames{en}->{61358937} = "Wanganella";
$areanames{en}->{61358938} = "Jimaringle";
$areanames{en}->{61358939} = "Caldwell";
$areanames{en}->{61358940} = "Conargo";
$areanames{en}->{61358941} = "Moulamein";
$areanames{en}->{61358942} = "Blighty";
$areanames{en}->{61358943} = "Logie\ Brae";
$areanames{en}->{61358944} = "Wakool";
$areanames{en}->{61358945} = "Cornalla";
$areanames{en}->{61358946} = "Mabins\ Well";
$areanames{en}->{61358947} = "Conargo";
$areanames{en}->{61358948} = "Berrigan";
$areanames{en}->{61358949} = "Cornalla";
$areanames{en}->{61358950} = "Deniliquin";
$areanames{en}->{61358951} = "Jerilderie";
$areanames{en}->{61358952} = "Deniliquin";
$areanames{en}->{61358953} = "Brassi";
$areanames{en}->{61358954} = "Shepparton";
$areanames{en}->{61358955} = "Dookie";
$areanames{en}->{61358956} = "Dookie";
$areanames{en}->{61358957} = "Dookie";
$areanames{en}->{61358958} = "Dookie";
$areanames{en}->{61358959} = "Finley";
$areanames{en}->{61358960} = "Jerilderie";
$areanames{en}->{61358961} = "Katandra\ West";
$areanames{en}->{61358962} = "Cobram";
$areanames{en}->{61358963} = "Tatura";
$areanames{en}->{61358964} = "Tocumwal";
$areanames{en}->{61358965} = "Nathalia";
$areanames{en}->{61358966} = "Katamatite";
$areanames{en}->{61358967} = "Picola";
$areanames{en}->{61358968} = "Kyabram";
$areanames{en}->{61358969} = "Jimaringle";
$areanames{en}->{61358970} = "Logie\ Brae";
$areanames{en}->{61358971} = "Rushworth";
$areanames{en}->{61358972} = "Dookie";
$areanames{en}->{61358973} = "Kialla\ East";
$areanames{en}->{61358974} = "Lalalty";
$areanames{en}->{61358975} = "Yalca";
$areanames{en}->{61358976} = "Undera";
$areanames{en}->{61358977} = "Shepparton";
$areanames{en}->{61358978} = "Tongala";
$areanames{en}->{61358979} = "Mabins\ Well";
$areanames{en}->{61358980} = "Deniliquin";
$areanames{en}->{61358981} = "Deniliquin";
$areanames{en}->{61358982} = "Deniliquin";
$areanames{en}->{61358983} = "Deniliquin";
$areanames{en}->{61358984} = "Deniliquin";
$areanames{en}->{61358985} = "Caldwell";
$areanames{en}->{61358986} = "Caldwell";
$areanames{en}->{61358987} = "Conargo";
$areanames{en}->{61358988} = "Conargo";
$areanames{en}->{61358989} = "Logie\ Brae";
$areanames{en}->{61358990} = "Logie\ Brae";
$areanames{en}->{61358991} = "Mabins\ Well";
$areanames{en}->{61358992} = "Mabins\ Well";
$areanames{en}->{61358993} = "Wakool";
$areanames{en}->{61358994} = "Wakool";
$areanames{en}->{61358995} = "Jimaringle";
$areanames{en}->{61358996} = "Jimaringle";
$areanames{en}->{61358997} = "Numurkah";
$areanames{en}->{61358998} = "Katandra\ West";
$areanames{en}->{61358999} = "Shepparton";
$areanames{en}->{61359000} = "Cowes";
$areanames{en}->{61359001} = "Cowes";
$areanames{en}->{61359002} = "Cowes";
$areanames{en}->{61359003} = "Cranbourne";
$areanames{en}->{61359004} = "Cranbourne";
$areanames{en}->{61359005} = "Cranbourne";
$areanames{en}->{61359006} = "Emerald";
$areanames{en}->{61359007} = "Emerald";
$areanames{en}->{61359008} = "Emerald";
$areanames{en}->{61359009} = "Red\ Hill";
$areanames{en}->{61359010} = "Healesville";
$areanames{en}->{61359011} = "Healesville";
$areanames{en}->{61359012} = "Healesville";
$areanames{en}->{61359013} = "Koo\ Wee\ Rup";
$areanames{en}->{61359014} = "Koo\ Wee\ Rup";
$areanames{en}->{61359015} = "Koo\ Wee\ Rup";
$areanames{en}->{61359016} = "Marysville";
$areanames{en}->{61359017} = "Marysville";
$areanames{en}->{61359018} = "Marysville";
$areanames{en}->{61359019} = "Cowes";
$areanames{en}->{61359020} = "Mornington";
$areanames{en}->{61359021} = "Mornington";
$areanames{en}->{61359022} = "Mornington";
$areanames{en}->{61359023} = "Pakenham";
$areanames{en}->{61359024} = "Pakenham";
$areanames{en}->{61359025} = "Pakenham";
$areanames{en}->{61359026} = "Mornington";
$areanames{en}->{61359027} = "Cranbourne";
$areanames{en}->{61359028} = "Mornington";
$areanames{en}->{61359029} = "Rosebud";
$areanames{en}->{61359030} = "Red\ Hill";
$areanames{en}->{61359031} = "Red\ Hill";
$areanames{en}->{61359032} = "Red\ Hill";
$areanames{en}->{61359033} = "Rosebud";
$areanames{en}->{61359034} = "Rosebud";
$areanames{en}->{61359035} = "Rosebud";
$areanames{en}->{61359036} = "Tankerton";
$areanames{en}->{61359037} = "Tankerton";
$areanames{en}->{61359038} = "Tankerton";
$areanames{en}->{61359039} = "Tankerton";
$areanames{en}->{61359040} = "Warburton";
$areanames{en}->{61359041} = "Warburton";
$areanames{en}->{61359042} = "Warburton";
$areanames{en}->{61359043} = "Warburton";
$areanames{en}->{61359044} = "Red\ Hill";
$areanames{en}->{61359045} = "Cowes";
$areanames{en}->{61359046} = "Mornington";
$areanames{en}->{61359047} = "Rosebud";
$areanames{en}->{61359048} = "Tankerton";
$areanames{en}->{61359049} = "Cranbourne";
$areanames{en}->{61359050} = "Warburton";
$areanames{en}->{61359051} = "Cranbourne";
$areanames{en}->{61359052} = "Emerald";
$areanames{en}->{61359053} = "Healesville";
$areanames{en}->{61359054} = "Koo\ Wee\ Rup";
$areanames{en}->{61359055} = "Marysville";
$areanames{en}->{61359056} = "Pakenham";
$areanames{en}->{61359057} = "Cowes";
$areanames{en}->{61359058} = "Mornington";
$areanames{en}->{61359059} = "Red\ Hill";
$areanames{en}->{61359060} = "Emerald";
$areanames{en}->{61359061} = "Healesville";
$areanames{en}->{61359062} = "Koo\ Wee\ Rup";
$areanames{en}->{61359063} = "Marysville";
$areanames{en}->{61359064} = "Pakenham";
$areanames{en}->{61359065} = "Mornington";
$areanames{en}->{61359066} = "Red\ Hill";
$areanames{en}->{61359067} = "Rosebud";
$areanames{en}->{61359068} = "Tankerton";
$areanames{en}->{61359069} = "Cranbourne";
$areanames{en}->{61359070} = "Emerald";
$areanames{en}->{61359071} = "Healesville";
$areanames{en}->{61359072} = "Koo\ Wee\ Rup";
$areanames{en}->{61359073} = "Marysville";
$areanames{en}->{61359074} = "Pakenham";
$areanames{en}->{61359075} = "Warburton";
$areanames{en}->{61359076} = "Cowes";
$areanames{en}->{61359077} = "Cranbourne";
$areanames{en}->{61359078} = "Emerald";
$areanames{en}->{61359079} = "Healesville";
$areanames{en}->{61359080} = "Koo\ Wee\ Rup";
$areanames{en}->{61359081} = "Marysville";
$areanames{en}->{61359082} = "Pakenham";
$areanames{en}->{61359083} = "Red\ Hill";
$areanames{en}->{61359084} = "Rosebud";
$areanames{en}->{61359085} = "Tankerton";
$areanames{en}->{61359086} = "Warburton";
$areanames{en}->{61359087} = "Cowes";
$areanames{en}->{61359088} = "Koo\ Wee\ Rup";
$areanames{en}->{61359089} = "Pakenham";
$areanames{en}->{61359090} = "Cowes";
$areanames{en}->{61359091} = "Tankerton";
$areanames{en}->{61359092} = "Emerald";
$areanames{en}->{61359093} = "Healesville";
$areanames{en}->{61359094} = "Koo\ Wee\ Rup";
$areanames{en}->{61359095} = "Marysville";
$areanames{en}->{61359096} = "Pakenham";
$areanames{en}->{61359097} = "Warburton";
$areanames{en}->{61359098} = "Mornington";
$areanames{en}->{61359099} = "Cowes";
$areanames{en}->{61359100} = "Rosebud";
$areanames{en}->{61359101} = "Mornington";
$areanames{en}->{61359102} = "Red\ Hill";
$areanames{en}->{61359103} = "Rosebud";
$areanames{en}->{61359104} = "Tankerton";
$areanames{en}->{61359105} = "Cranbourne";
$areanames{en}->{61359106} = "Emerald";
$areanames{en}->{61359107} = "Healesville";
$areanames{en}->{61359108} = "Koo\ Wee\ Rup";
$areanames{en}->{61359109} = "Marysville";
$areanames{en}->{61359110} = "Pakenham";
$areanames{en}->{61359111} = "Warburton";
$areanames{en}->{61359112} = "Cranbourne";
$areanames{en}->{61359113} = "Healesville";
$areanames{en}->{61359114} = "Marysville";
$areanames{en}->{61359115} = "Cranbourne";
$areanames{en}->{61359116} = "Healesville";
$areanames{en}->{61359117} = "Mornington";
$areanames{en}->{61359118} = "Rosebud";
$areanames{en}->{61359119} = "Cranbourne";
$areanames{en}->{6135912} = "Rosebud";
$areanames{en}->{61359130} = "Rosebud";
$areanames{en}->{61359131} = "Mornington";
$areanames{en}->{61359132} = "Red\ Hill";
$areanames{en}->{61359133} = "Emerald";
$areanames{en}->{61359134} = "Emerald";
$areanames{en}->{61359135} = "Emerald";
$areanames{en}->{61359136} = "Emerald";
$areanames{en}->{61359137} = "Healesville";
$areanames{en}->{61359138} = "Healesville";
$areanames{en}->{61359139} = "Cowes";
$areanames{en}->{61359140} = "Mornington";
$areanames{en}->{61359141} = "Red\ Hill";
$areanames{en}->{61359142} = "Rosebud";
$areanames{en}->{61359143} = "Tankerton";
$areanames{en}->{61359144} = "Cranbourne";
$areanames{en}->{61359145} = "Emerald";
$areanames{en}->{61359146} = "Healesville";
$areanames{en}->{61359147} = "Koo\ Wee\ Rup";
$areanames{en}->{61359148} = "Marysville";
$areanames{en}->{61359149} = "Pakenham";
$areanames{en}->{61359150} = "Warburton";
$areanames{en}->{61359151} = "Pakenham";
$areanames{en}->{61359152} = "Mornington";
$areanames{en}->{61359153} = "Koo\ Wee\ Rup";
$areanames{en}->{61359154} = "Koo\ Wee\ Rup";
$areanames{en}->{61359155} = "Warburton";
$areanames{en}->{61359156} = "Warburton";
$areanames{en}->{61359157} = "Marysville";
$areanames{en}->{61359158} = "Marysville";
$areanames{en}->{61359159} = "Cranbourne";
$areanames{en}->{6135916} = "Mornington";
$areanames{en}->{6135917} = "Cranbourne";
$areanames{en}->{6135918} = "Pakenham";
$areanames{en}->{61359190} = "Cowes";
$areanames{en}->{61359191} = "Red\ Hill";
$areanames{en}->{61359192} = "Emerald";
$areanames{en}->{61359193} = "Healesville";
$areanames{en}->{61359194} = "Warburton";
$areanames{en}->{61359195} = "Emerald";
$areanames{en}->{61359196} = "Pakenham";
$areanames{en}->{61359197} = "Rosebud";
$areanames{en}->{61359198} = "Rosebud";
$areanames{en}->{61359199} = "Rosebud";
$areanames{en}->{6135920} = "Cranbourne";
$areanames{en}->{6135921} = "Mornington";
$areanames{en}->{61359220} = "Red\ Hill";
$areanames{en}->{61359221} = "Pakenham";
$areanames{en}->{61359222} = "Pakenham";
$areanames{en}->{61359223} = "Koo\ Wee\ Rup";
$areanames{en}->{61359224} = "Pakenham";
$areanames{en}->{61359225} = "Red\ Hill";
$areanames{en}->{61359226} = "Rosebud";
$areanames{en}->{61359227} = "Marysville";
$areanames{en}->{61359228} = "Red\ Hill";
$areanames{en}->{61359229} = "Cowes";
$areanames{en}->{61359230} = "Mornington";
$areanames{en}->{61359231} = "Rosebud";
$areanames{en}->{61359232} = "Tankerton";
$areanames{en}->{61359233} = "Cranbourne";
$areanames{en}->{61359234} = "Healesville";
$areanames{en}->{61359235} = "Koo\ Wee\ Rup";
$areanames{en}->{61359236} = "Warburton";
$areanames{en}->{61359237} = "Emerald";
$areanames{en}->{61359238} = "Cowes";
$areanames{en}->{61359239} = "Red\ Hill";
$areanames{en}->{61359240} = "Rosebud";
$areanames{en}->{61359241} = "Mornington";
$areanames{en}->{61359242} = "Cranbourne";
$areanames{en}->{61359243} = "Pakenham";
$areanames{en}->{61359244} = "Marysville";
$areanames{en}->{61359245} = "Red\ Hill";
$areanames{en}->{61359246} = "Rosebud";
$areanames{en}->{61359247} = "Tankerton";
$areanames{en}->{61359248} = "Cranbourne";
$areanames{en}->{61359249} = "Tankerton";
$areanames{en}->{61359250} = "Koo\ Wee\ Rup";
$areanames{en}->{61359251} = "Healesville";
$areanames{en}->{61359252} = "Koo\ Wee\ Rup";
$areanames{en}->{61359253} = "Warburton";
$areanames{en}->{61359254} = "Emerald";
$areanames{en}->{61359255} = "Cowes";
$areanames{en}->{61359256} = "Mornington";
$areanames{en}->{61359257} = "Pakenham";
$areanames{en}->{61359258} = "Marysville";
$areanames{en}->{61359259} = "Mornington";
$areanames{en}->{61359260} = "Cranbourne";
$areanames{en}->{61359261} = "Red\ Hill";
$areanames{en}->{61359262} = "Tankerton";
$areanames{en}->{61359263} = "Koo\ Wee\ Rup";
$areanames{en}->{61359264} = "Warburton";
$areanames{en}->{61359265} = "Emerald";
$areanames{en}->{61359266} = "Cowes";
$areanames{en}->{61359267} = "Cowes";
$areanames{en}->{61359268} = "Cranbourne";
$areanames{en}->{61359269} = "Emerald";
$areanames{en}->{61359270} = "Healesville";
$areanames{en}->{61359271} = "Koo\ Wee\ Rup";
$areanames{en}->{61359272} = "Marysville";
$areanames{en}->{61359273} = "Mornington";
$areanames{en}->{61359274} = "Pakenham";
$areanames{en}->{61359275} = "Red\ Hill";
$areanames{en}->{61359276} = "Rosebud";
$areanames{en}->{61359277} = "Tankerton";
$areanames{en}->{61359278} = "Warburton";
$areanames{en}->{61359279} = "Cowes";
$areanames{en}->{61359280} = "Cranbourne";
$areanames{en}->{61359281} = "Emerald";
$areanames{en}->{61359282} = "Healesville";
$areanames{en}->{61359283} = "Koo\ Wee\ Rup";
$areanames{en}->{61359284} = "Marysville";
$areanames{en}->{61359285} = "Mornington";
$areanames{en}->{61359286} = "Pakenham";
$areanames{en}->{61359287} = "Red\ Hill";
$areanames{en}->{61359288} = "Rosebud";
$areanames{en}->{61359289} = "Tankerton";
$areanames{en}->{61359290} = "Warburton";
$areanames{en}->{61359291} = "Cowes";
$areanames{en}->{61359292} = "Cranbourne";
$areanames{en}->{61359293} = "Emerald";
$areanames{en}->{61359294} = "Healesville";
$areanames{en}->{61359295} = "Koo\ Wee\ Rup";
$areanames{en}->{61359296} = "Marysville";
$areanames{en}->{61359297} = "Mornington";
$areanames{en}->{61359298} = "Pakenham";
$areanames{en}->{61359299} = "Red\ Hill";
$areanames{en}->{61359300} = "Rosebud";
$areanames{en}->{61359301} = "Tankerton";
$areanames{en}->{61359302} = "Warburton";
$areanames{en}->{61359303} = "Cranbourne";
$areanames{en}->{61359304} = "Cranbourne";
$areanames{en}->{61359305} = "Cranbourne";
$areanames{en}->{61359306} = "Cranbourne";
$areanames{en}->{61359307} = "Cranbourne";
$areanames{en}->{61359308} = "Pakenham";
$areanames{en}->{61359309} = "Pakenham";
$areanames{en}->{6135931} = "Red\ Hill";
$areanames{en}->{61359320} = "Cowes";
$areanames{en}->{61359321} = "Cowes";
$areanames{en}->{61359322} = "Tankerton";
$areanames{en}->{61359323} = "Tankerton";
$areanames{en}->{61359324} = "Mornington";
$areanames{en}->{61359325} = "Mornington";
$areanames{en}->{61359326} = "Mornington";
$areanames{en}->{61359327} = "Mornington";
$areanames{en}->{61359328} = "Mornington";
$areanames{en}->{61359329} = "Cranbourne";
$areanames{en}->{6135933} = "Cranbourne";
$areanames{en}->{6135934} = "Mornington";
$areanames{en}->{61359350} = "Mornington";
$areanames{en}->{61359351} = "Rosebud";
$areanames{en}->{61359352} = "Cowes";
$areanames{en}->{61359353} = "Cranbourne";
$areanames{en}->{61359354} = "Emerald";
$areanames{en}->{61359355} = "Healesville";
$areanames{en}->{61359356} = "Koo\ Wee\ Rup";
$areanames{en}->{61359357} = "Marysville";
$areanames{en}->{61359358} = "Mornington";
$areanames{en}->{61359359} = "Pakenham";
$areanames{en}->{61359360} = "Cowes";
$areanames{en}->{61359361} = "Cranbourne";
$areanames{en}->{61359362} = "Emerald";
$areanames{en}->{61359363} = "Healesville";
$areanames{en}->{61359364} = "Koo\ Wee\ Rup";
$areanames{en}->{61359365} = "Marysville";
$areanames{en}->{61359366} = "Mornington";
$areanames{en}->{61359367} = "Pakenham";
$areanames{en}->{61359368} = "Red\ Hill";
$areanames{en}->{61359369} = "Rosebud";
$areanames{en}->{61359370} = "Tankerton";
$areanames{en}->{61359371} = "Warburton";
$areanames{en}->{61359372} = "Red\ Hill";
$areanames{en}->{61359373} = "Rosebud";
$areanames{en}->{61359374} = "Tankerton";
$areanames{en}->{61359375} = "Warburton";
$areanames{en}->{61359376} = "Cowes";
$areanames{en}->{61359377} = "Cranbourne";
$areanames{en}->{61359378} = "Emerald";
$areanames{en}->{61359379} = "Healesville";
$areanames{en}->{61359380} = "Koo\ Wee\ Rup";
$areanames{en}->{61359381} = "Marysville";
$areanames{en}->{61359382} = "Mornington";
$areanames{en}->{61359383} = "Pakenham";
$areanames{en}->{61359384} = "Red\ Hill";
$areanames{en}->{61359385} = "Rosebud";
$areanames{en}->{61359386} = "Tankerton";
$areanames{en}->{61359387} = "Warburton";
$areanames{en}->{61359388} = "Cowes";
$areanames{en}->{61359389} = "Cranbourne";
$areanames{en}->{61359390} = "Emerald";
$areanames{en}->{61359391} = "Healesville";
$areanames{en}->{61359392} = "Koo\ Wee\ Rup";
$areanames{en}->{61359393} = "Marysville";
$areanames{en}->{61359394} = "Mornington";
$areanames{en}->{61359395} = "Pakenham";
$areanames{en}->{61359396} = "Red\ Hill";
$areanames{en}->{61359397} = "Rosebud";
$areanames{en}->{61359398} = "Tankerton";
$areanames{en}->{61359399} = "Warburton";
$areanames{en}->{6135940} = "Pakenham";
$areanames{en}->{6135941} = "Pakenham";
$areanames{en}->{6135942} = "Pakenham";
$areanames{en}->{6135943} = "Pakenham";
$areanames{en}->{6135944} = "Emerald";
$areanames{en}->{6135945} = "Pakenham";
$areanames{en}->{61359458} = "Koo\ Wee\ Rup";
$areanames{en}->{61359459} = "Emerald";
$areanames{en}->{61359460} = "Rosebud";
$areanames{en}->{61359461} = "Tankerton";
$areanames{en}->{61359462} = "Cowes";
$areanames{en}->{61359463} = "Cranbourne";
$areanames{en}->{61359464} = "Emerald";
$areanames{en}->{61359465} = "Healesville";
$areanames{en}->{61359466} = "Koo\ Wee\ Rup";
$areanames{en}->{61359467} = "Marysville";
$areanames{en}->{61359468} = "Mornington";
$areanames{en}->{61359469} = "Pakenham";
$areanames{en}->{61359470} = "Red\ Hill";
$areanames{en}->{61359471} = "Rosebud";
$areanames{en}->{61359472} = "Tankerton";
$areanames{en}->{61359473} = "Warburton";
$areanames{en}->{6135949} = "Emerald";
$areanames{en}->{61359500} = "Rosebud";
$areanames{en}->{61359501} = "Rosebud";
$areanames{en}->{61359502} = "Rosebud";
$areanames{en}->{61359503} = "Rosebud";
$areanames{en}->{61359504} = "Rosebud";
$areanames{en}->{61359505} = "Red\ Hill";
$areanames{en}->{61359506} = "Red\ Hill";
$areanames{en}->{61359507} = "Red\ Hill";
$areanames{en}->{61359508} = "Red\ Hill";
$areanames{en}->{61359509} = "Red\ Hill";
$areanames{en}->{6135951} = "Cowes";
$areanames{en}->{6135952} = "Cowes";
$areanames{en}->{61359530} = "Pakenham";
$areanames{en}->{61359531} = "Red\ Hill";
$areanames{en}->{61359532} = "Red\ Hill";
$areanames{en}->{61359533} = "Cranbourne";
$areanames{en}->{61359534} = "Cranbourne";
$areanames{en}->{61359535} = "Cranbourne";
$areanames{en}->{6135954} = "Emerald";
$areanames{en}->{61359545} = "Warburton";
$areanames{en}->{61359546} = "Warburton";
$areanames{en}->{61359547} = "Warburton";
$areanames{en}->{61359548} = "Warburton";
$areanames{en}->{61359550} = "Emerald";
$areanames{en}->{61359551} = "Cranbourne";
$areanames{en}->{61359552} = "Mornington";
$areanames{en}->{61359553} = "Red\ Hill";
$areanames{en}->{61359554} = "Rosebud";
$areanames{en}->{61359555} = "Emerald";
$areanames{en}->{61359556} = "Warburton";
$areanames{en}->{61359557} = "Cranbourne";
$areanames{en}->{61359558} = "Red\ Hill";
$areanames{en}->{61359559} = "Pakenham";
$areanames{en}->{6135956} = "Cowes";
$areanames{en}->{61359570} = "Healesville";
$areanames{en}->{61359571} = "Healesville";
$areanames{en}->{61359572} = "Healesville";
$areanames{en}->{61359573} = "Healesville";
$areanames{en}->{61359574} = "Healesville";
$areanames{en}->{61359575} = "Marysville";
$areanames{en}->{61359576} = "Marysville";
$areanames{en}->{61359577} = "Marysville";
$areanames{en}->{61359578} = "Marysville";
$areanames{en}->{61359579} = "Marysville";
$areanames{en}->{61359580} = "Pakenham";
$areanames{en}->{61359581} = "Tankerton";
$areanames{en}->{61359582} = "Marysville";
$areanames{en}->{61359583} = "Mornington";
$areanames{en}->{61359584} = "Mornington";
$areanames{en}->{61359585} = "Mornington";
$areanames{en}->{61359586} = "Mornington";
$areanames{en}->{61359587} = "Warburton";
$areanames{en}->{6135960} = "Emerald";
$areanames{en}->{6135961} = "Emerald";
$areanames{en}->{6135962} = "Healesville";
$areanames{en}->{6135963} = "Marysville";
$areanames{en}->{6135964} = "Emerald";
$areanames{en}->{61359650} = "Warburton";
$areanames{en}->{61359651} = "Healesville";
$areanames{en}->{61359652} = "Healesville";
$areanames{en}->{61359653} = "Healesville";
$areanames{en}->{61359654} = "Healesville";
$areanames{en}->{61359655} = "Warburton";
$areanames{en}->{61359656} = "Warburton";
$areanames{en}->{61359657} = "Healesville";
$areanames{en}->{61359658} = "Warburton";
$areanames{en}->{61359659} = "Warburton";
$areanames{en}->{6135966} = "Warburton";
$areanames{en}->{6135967} = "Emerald";
$areanames{en}->{6135968} = "Emerald";
$areanames{en}->{6135969} = "Healesville";
$areanames{en}->{6135972} = "Mornington";
$areanames{en}->{613598} = "Rosebud";
$areanames{en}->{6135980} = "Tankerton";
$areanames{en}->{6135983} = "Red\ Hill";
$areanames{en}->{6135989} = "Red\ Hill";
$areanames{en}->{6135990} = "Cranbourne";
$areanames{en}->{6135991} = "Cranbourne";
$areanames{en}->{6135992} = "Cranbourne";
$areanames{en}->{6135995} = "Cranbourne";
$areanames{en}->{6135996} = "Cranbourne";
$areanames{en}->{6135997} = "Koo\ Wee\ Rup";
$areanames{en}->{6135998} = "Cranbourne";
$areanames{en}->{61359990} = "Cranbourne";
$areanames{en}->{61359991} = "Cranbourne";
$areanames{en}->{61359992} = "Cranbourne";
$areanames{en}->{61359993} = "Cranbourne";
$areanames{en}->{61359994} = "Cranbourne";
$areanames{en}->{61359995} = "Mornington";
$areanames{en}->{61359996} = "Rosebud";
$areanames{en}->{61359997} = "Rosebud";
$areanames{en}->{61359998} = "Rosebud";
$areanames{en}->{61359999} = "Healesville";
$areanames{en}->{61361000} = "Dover";
$areanames{en}->{61361001} = "Geeveston";
$areanames{en}->{61361002} = "South\ Bruny";
$areanames{en}->{61361003} = "Southwest";
$areanames{en}->{61361004} = "Brighton";
$areanames{en}->{61361005} = "Huonville";
$areanames{en}->{61361006} = "Margate";
$areanames{en}->{61361007} = "New\ Norfolk";
$areanames{en}->{61361008} = "Richmond";
$areanames{en}->{61361009} = "Sorell";
$areanames{en}->{61361010} = "Baden";
$areanames{en}->{61361011} = "Bothwell";
$areanames{en}->{61361012} = "Colebrook";
$areanames{en}->{61361013} = "Dunalley";
$areanames{en}->{61361014} = "Hermitage";
$areanames{en}->{61361015} = "Kempton";
$areanames{en}->{61361016} = "Little\ Swanport";
$areanames{en}->{61361017} = "Miena";
$areanames{en}->{61361018} = "Nubeena";
$areanames{en}->{61361019} = "Oatlands";
$areanames{en}->{61361020} = "Orford";
$areanames{en}->{61361021} = "Swansea";
$areanames{en}->{61361022} = "Woodbury";
$areanames{en}->{61361023} = "Gretna";
$areanames{en}->{61361024} = "Maydena";
$areanames{en}->{61361025} = "Ouse";
$areanames{en}->{61361026} = "Strathgordon";
$areanames{en}->{61361027} = "Tarraleah";
$areanames{en}->{61361028} = "Hermitage";
$areanames{en}->{61361029} = "Kempton";
$areanames{en}->{61361030} = "Little\ Swanport";
$areanames{en}->{61361031} = "Miena";
$areanames{en}->{61361032} = "Nubeena";
$areanames{en}->{61361033} = "Oatlands";
$areanames{en}->{61361034} = "Orford";
$areanames{en}->{61361035} = "Swansea";
$areanames{en}->{61361036} = "Woodbury";
$areanames{en}->{61361037} = "Gretna";
$areanames{en}->{61361038} = "Maydena";
$areanames{en}->{61361039} = "Ouse";
$areanames{en}->{61361040} = "Strathgordon";
$areanames{en}->{61361041} = "Tarraleah";
$areanames{en}->{61361042} = "Dover";
$areanames{en}->{61361043} = "Geeveston";
$areanames{en}->{61361044} = "South\ Bruny";
$areanames{en}->{61361045} = "Southwest";
$areanames{en}->{61361046} = "Baden";
$areanames{en}->{61361047} = "Bothwell";
$areanames{en}->{61361048} = "Colebrook";
$areanames{en}->{61361049} = "Dunalley";
$areanames{en}->{61361050} = "Hobart";
$areanames{en}->{61361051} = "Dover";
$areanames{en}->{61361052} = "Geeveston";
$areanames{en}->{61361053} = "South\ Bruny";
$areanames{en}->{61361054} = "Southwest";
$areanames{en}->{61361055} = "Brighton";
$areanames{en}->{61361056} = "Huonville";
$areanames{en}->{61361057} = "Margate";
$areanames{en}->{61361058} = "New\ Norfolk";
$areanames{en}->{61361059} = "Richmond";
$areanames{en}->{61361060} = "Sorell";
$areanames{en}->{61361061} = "Baden";
$areanames{en}->{61361062} = "Bothwell";
$areanames{en}->{61361063} = "Colebrook";
$areanames{en}->{61361064} = "Dunalley";
$areanames{en}->{61361065} = "Hermitage";
$areanames{en}->{61361066} = "Kempton";
$areanames{en}->{61361067} = "Little\ Swanport";
$areanames{en}->{61361068} = "Miena";
$areanames{en}->{61361069} = "Nubeena";
$areanames{en}->{61361070} = "Oatlands";
$areanames{en}->{61361071} = "Orford";
$areanames{en}->{61361072} = "Swansea";
$areanames{en}->{61361073} = "Woodbury";
$areanames{en}->{61361074} = "Gretna";
$areanames{en}->{61361075} = "Maydena";
$areanames{en}->{61361076} = "Ouse";
$areanames{en}->{61361077} = "Strathgordon";
$areanames{en}->{61361078} = "Tarraleah";
$areanames{en}->{61361079} = "Hobart";
$areanames{en}->{613610820} = "Hobart";
$areanames{en}->{61361090} = "Brighton";
$areanames{en}->{61361091} = "Brighton";
$areanames{en}->{61361092} = "Huonville";
$areanames{en}->{61361093} = "Huonville";
$areanames{en}->{61361094} = "Hobart";
$areanames{en}->{61361095} = "Hobart";
$areanames{en}->{61361096} = "New\ Norfolk";
$areanames{en}->{61361097} = "New\ Norfolk";
$areanames{en}->{61361098} = "Richmond";
$areanames{en}->{61361099} = "Richmond";
$areanames{en}->{61361100} = "Colebrook";
$areanames{en}->{61361101} = "Colebrook";
$areanames{en}->{61361102} = "Kempton";
$areanames{en}->{61361103} = "Kempton";
$areanames{en}->{61361104} = "Woodbury";
$areanames{en}->{61361105} = "Woodbury";
$areanames{en}->{61361106} = "Gretna";
$areanames{en}->{61361107} = "Gretna";
$areanames{en}->{61361108} = "Hobart";
$areanames{en}->{61361109} = "Hobart";
$areanames{en}->{6136111} = "Hobart";
$areanames{en}->{6136112} = "Sorell";
$areanames{en}->{6136113} = "Margate";
$areanames{en}->{61361140} = "Dover";
$areanames{en}->{61361141} = "Dover";
$areanames{en}->{61361142} = "Geeveston";
$areanames{en}->{61361143} = "Geeveston";
$areanames{en}->{61361144} = "South\ Bruny";
$areanames{en}->{61361145} = "South\ Bruny";
$areanames{en}->{61361146} = "Baden";
$areanames{en}->{61361147} = "Baden";
$areanames{en}->{61361148} = "Bothwell";
$areanames{en}->{61361149} = "Bothwell";
$areanames{en}->{61361150} = "Dunalley";
$areanames{en}->{61361151} = "Dunalley";
$areanames{en}->{61361152} = "Hermitage";
$areanames{en}->{61361153} = "Hermitage";
$areanames{en}->{61361154} = "Little\ Swanport";
$areanames{en}->{61361155} = "Little\ Swanport";
$areanames{en}->{61361156} = "Miena";
$areanames{en}->{61361157} = "Miena";
$areanames{en}->{61361158} = "Nubeena";
$areanames{en}->{61361159} = "Nubeena";
$areanames{en}->{61361160} = "Oatlands";
$areanames{en}->{61361161} = "Oatlands";
$areanames{en}->{61361162} = "Orford";
$areanames{en}->{61361163} = "Orford";
$areanames{en}->{61361164} = "Maydena";
$areanames{en}->{61361165} = "Maydena";
$areanames{en}->{61361166} = "Ouse";
$areanames{en}->{61361167} = "Ouse";
$areanames{en}->{61361168} = "Tarraleah";
$areanames{en}->{61361169} = "Tarraleah";
$areanames{en}->{6136117} = "Margate";
$areanames{en}->{61361170} = "Swansea";
$areanames{en}->{61361171} = "Swansea";
$areanames{en}->{61361180} = "Margate";
$areanames{en}->{61361181} = "Margate";
$areanames{en}->{61361182} = "Hobart";
$areanames{en}->{61361183} = "Southwest";
$areanames{en}->{61361184} = "Hobart";
$areanames{en}->{61361185} = "Nubeena";
$areanames{en}->{61361186} = "Brighton";
$areanames{en}->{61361187} = "Woodbury";
$areanames{en}->{61361188} = "Nubeena";
$areanames{en}->{61361189} = "Dover";
$areanames{en}->{6136119} = "Sorell";
$areanames{en}->{61361200} = "Geeveston";
$areanames{en}->{61361201} = "Huonville";
$areanames{en}->{61361202} = "Tarraleah";
$areanames{en}->{61361203} = "Miena";
$areanames{en}->{61361204} = "Gretna";
$areanames{en}->{61361205} = "Orford";
$areanames{en}->{61361206} = "Southwest";
$areanames{en}->{61361207} = "Little\ Swanport";
$areanames{en}->{61361208} = "Dover";
$areanames{en}->{61361209} = "South\ Bruny";
$areanames{en}->{61361210} = "Southwest";
$areanames{en}->{61361211} = "Strathgordon";
$areanames{en}->{61361212} = "Baden";
$areanames{en}->{61361213} = "Dunalley";
$areanames{en}->{61361214} = "Hobart";
$areanames{en}->{61361215} = "Bothwell";
$areanames{en}->{61361216} = "Oatlands";
$areanames{en}->{61361217} = "Geeveston";
$areanames{en}->{61361218} = "New\ Norfolk";
$areanames{en}->{61361219} = "Brighton";
$areanames{en}->{61361220} = "Hobart";
$areanames{en}->{61361221} = "Hobart";
$areanames{en}->{61361222} = "Ouse";
$areanames{en}->{61361223} = "Hermitage";
$areanames{en}->{61361224} = "Richmond";
$areanames{en}->{61361225} = "Sorell";
$areanames{en}->{61361226} = "Woodbury";
$areanames{en}->{61361227} = "Maydena";
$areanames{en}->{61361228} = "Kempton";
$areanames{en}->{61361229} = "Huonville";
$areanames{en}->{61361230} = "Margate";
$areanames{en}->{61361231} = "Brighton";
$areanames{en}->{61361232} = "South\ Bruny";
$areanames{en}->{61361233} = "Margate";
$areanames{en}->{61361234} = "Orford";
$areanames{en}->{61361235} = "Colebrook";
$areanames{en}->{61361236} = "Geeveston";
$areanames{en}->{61361237} = "New\ Norfolk";
$areanames{en}->{61361238} = "Sorell";
$areanames{en}->{61361239} = "New\ Norfolk";
$areanames{en}->{61361240} = "Richmond";
$areanames{en}->{61361241} = "Nubeena";
$areanames{en}->{61361242} = "Hobart";
$areanames{en}->{61361243} = "Dover";
$areanames{en}->{61361244} = "Maydena";
$areanames{en}->{61361245} = "Kempton";
$areanames{en}->{61361246} = "Brighton";
$areanames{en}->{61361247} = "South\ Bruny";
$areanames{en}->{61361248} = "Margate";
$areanames{en}->{61361249} = "Sorell";
$areanames{en}->{61361250} = "Baden";
$areanames{en}->{61361251} = "Huonville";
$areanames{en}->{61361252} = "Strathgordon";
$areanames{en}->{61361253} = "Tarraleah";
$areanames{en}->{61361254} = "Baden";
$areanames{en}->{61361255} = "Dunalley";
$areanames{en}->{61361256} = "Ouse";
$areanames{en}->{61361257} = "Hermitage";
$areanames{en}->{61361258} = "Bothwell";
$areanames{en}->{61361259} = "Bothwell";
$areanames{en}->{61361260} = "Colebrook";
$areanames{en}->{61361261} = "Oatlands";
$areanames{en}->{61361262} = "Orford";
$areanames{en}->{61361263} = "Richmond";
$areanames{en}->{61361264} = "Miena";
$areanames{en}->{61361265} = "Swansea";
$areanames{en}->{61361266} = "Gretna";
$areanames{en}->{61361267} = "Colebrook";
$areanames{en}->{61361268} = "Southwest";
$areanames{en}->{61361269} = "Dunalley";
$areanames{en}->{61361270} = "Hermitage";
$areanames{en}->{61361271} = "Little\ Swanport";
$areanames{en}->{61361272} = "New\ Norfolk";
$areanames{en}->{61361273} = "Brighton";
$areanames{en}->{61361274} = "Huonville";
$areanames{en}->{61361275} = "Sorell";
$areanames{en}->{61361276} = "Woodbury";
$areanames{en}->{61361277} = "Geeveston";
$areanames{en}->{61361278} = "New\ Norfolk";
$areanames{en}->{61361279} = "Kempton";
$areanames{en}->{61361280} = "Little\ Swanport";
$areanames{en}->{61361281} = "Sorell";
$areanames{en}->{61361282} = "Nubeena";
$areanames{en}->{61361283} = "Hobart";
$areanames{en}->{61361284} = "Dover";
$areanames{en}->{61361285} = "Maydena";
$areanames{en}->{61361286} = "Kempton";
$areanames{en}->{61361287} = "Brighton";
$areanames{en}->{61361288} = "South\ Bruny";
$areanames{en}->{61361289} = "Miena";
$areanames{en}->{61361290} = "Nubeena";
$areanames{en}->{61361291} = "Margate";
$areanames{en}->{61361292} = "Huonville";
$areanames{en}->{61361293} = "Strathgordon";
$areanames{en}->{61361294} = "Tarraleah";
$areanames{en}->{61361295} = "Baden";
$areanames{en}->{61361296} = "Dunalley";
$areanames{en}->{61361297} = "Ouse";
$areanames{en}->{61361298} = "Hermitage";
$areanames{en}->{61361299} = "Oatlands";
$areanames{en}->{61361300} = "Orford";
$areanames{en}->{61361301} = "Bothwell";
$areanames{en}->{61361302} = "Oatlands";
$areanames{en}->{61361303} = "Orford";
$areanames{en}->{61361304} = "Richmond";
$areanames{en}->{61361305} = "Miena";
$areanames{en}->{61361306} = "Swansea";
$areanames{en}->{61361307} = "Gretna";
$areanames{en}->{61361308} = "Colebrook";
$areanames{en}->{61361309} = "Swansea";
$areanames{en}->{61361310} = "Woodbury";
$areanames{en}->{61361311} = "Southwest";
$areanames{en}->{61361312} = "Little\ Swanport";
$areanames{en}->{61361313} = "Woodbury";
$areanames{en}->{61361314} = "Geeveston";
$areanames{en}->{61361315} = "New\ Norfolk";
$areanames{en}->{61361316} = "Sorell";
$areanames{en}->{61361317} = "Nubeena";
$areanames{en}->{61361318} = "Dover";
$areanames{en}->{61361319} = "Gretna";
$areanames{en}->{61361320} = "Maydena";
$areanames{en}->{61361321} = "Maydena";
$areanames{en}->{61361322} = "Kempton";
$areanames{en}->{61361323} = "Brighton";
$areanames{en}->{61361324} = "South\ Bruny";
$areanames{en}->{61361325} = "Margate";
$areanames{en}->{61361326} = "Huonville";
$areanames{en}->{61361327} = "Strathgordon";
$areanames{en}->{61361328} = "Tarraleah";
$areanames{en}->{61361329} = "Ouse";
$areanames{en}->{61361330} = "Strathgordon";
$areanames{en}->{61361331} = "Baden";
$areanames{en}->{61361332} = "Dunalley";
$areanames{en}->{61361333} = "Ouse";
$areanames{en}->{61361334} = "Hermitage";
$areanames{en}->{61361335} = "Bothwell";
$areanames{en}->{61361336} = "Oatlands";
$areanames{en}->{61361337} = "Orford";
$areanames{en}->{61361338} = "Richmond";
$areanames{en}->{61361339} = "Miena";
$areanames{en}->{61361340} = "Tarraleah";
$areanames{en}->{61361341} = "Miena";
$areanames{en}->{61361342} = "Swansea";
$areanames{en}->{61361343} = "Gretna";
$areanames{en}->{61361344} = "Colebrook";
$areanames{en}->{61361345} = "Southwest";
$areanames{en}->{61361346} = "Little\ Swanport";
$areanames{en}->{61361347} = "Swansea";
$areanames{en}->{61361348} = "Hobart";
$areanames{en}->{61361349} = "Hobart";
$areanames{en}->{61361350} = "Bothwell";
$areanames{en}->{61361351} = "Hobart";
$areanames{en}->{61361352} = "Hobart";
$areanames{en}->{61361353} = "Hobart";
$areanames{en}->{61361354} = "Hobart";
$areanames{en}->{61361355} = "Hobart";
$areanames{en}->{61361356} = "Baden";
$areanames{en}->{61361357} = "Bothwell";
$areanames{en}->{61361358} = "Brighton";
$areanames{en}->{61361359} = "Colebrook";
$areanames{en}->{61361360} = "Dover";
$areanames{en}->{61361361} = "Dunalley";
$areanames{en}->{61361362} = "Geeveston";
$areanames{en}->{61361363} = "Gretna";
$areanames{en}->{61361364} = "Hermitage";
$areanames{en}->{61361365} = "Hobart";
$areanames{en}->{61361366} = "Huonville";
$areanames{en}->{61361367} = "Kempton";
$areanames{en}->{61361368} = "Little\ Swanport";
$areanames{en}->{61361369} = "Margate";
$areanames{en}->{61361370} = "Maydena";
$areanames{en}->{61361371} = "Miena";
$areanames{en}->{61361372} = "New\ Norfolk";
$areanames{en}->{61361373} = "Nubeena";
$areanames{en}->{61361374} = "Oatlands";
$areanames{en}->{61361375} = "Orford";
$areanames{en}->{61361376} = "Ouse";
$areanames{en}->{61361377} = "Richmond";
$areanames{en}->{61361378} = "Sorell";
$areanames{en}->{61361379} = "South\ Bruny";
$areanames{en}->{61361380} = "Southwest";
$areanames{en}->{61361381} = "Strathgordon";
$areanames{en}->{61361382} = "Swansea";
$areanames{en}->{61361383} = "Tarraleah";
$areanames{en}->{61361384} = "Woodbury";
$areanames{en}->{61361385} = "Baden";
$areanames{en}->{61361386} = "Bothwell";
$areanames{en}->{61361387} = "Brighton";
$areanames{en}->{61361388} = "Colebrook";
$areanames{en}->{61361389} = "Dover";
$areanames{en}->{61361390} = "Dunalley";
$areanames{en}->{61361391} = "Geeveston";
$areanames{en}->{61361392} = "Gretna";
$areanames{en}->{61361393} = "Hermitage";
$areanames{en}->{61361394} = "Hobart";
$areanames{en}->{61361395} = "Huonville";
$areanames{en}->{61361396} = "Kempton";
$areanames{en}->{61361397} = "Little\ Swanport";
$areanames{en}->{61361398} = "Margate";
$areanames{en}->{61361399} = "Maydena";
$areanames{en}->{61361400} = "Miena";
$areanames{en}->{61361401} = "New\ Norfolk";
$areanames{en}->{61361402} = "Nubeena";
$areanames{en}->{61361403} = "Oatlands";
$areanames{en}->{61361404} = "Orford";
$areanames{en}->{61361405} = "Ouse";
$areanames{en}->{61361406} = "Richmond";
$areanames{en}->{61361407} = "Sorell";
$areanames{en}->{61361408} = "South\ Bruny";
$areanames{en}->{61361409} = "Southwest";
$areanames{en}->{61361410} = "Strathgordon";
$areanames{en}->{61361411} = "Swansea";
$areanames{en}->{61361412} = "Tarraleah";
$areanames{en}->{61361413} = "Woodbury";
$areanames{en}->{61361414} = "Baden";
$areanames{en}->{61361415} = "Bothwell";
$areanames{en}->{61361416} = "Brighton";
$areanames{en}->{61361417} = "Colebrook";
$areanames{en}->{61361418} = "Dover";
$areanames{en}->{61361419} = "Dunalley";
$areanames{en}->{61361420} = "Geeveston";
$areanames{en}->{61361421} = "Gretna";
$areanames{en}->{61361422} = "Hermitage";
$areanames{en}->{61361423} = "Hobart";
$areanames{en}->{61361424} = "Huonville";
$areanames{en}->{61361425} = "Kempton";
$areanames{en}->{61361426} = "Little\ Swanport";
$areanames{en}->{61361427} = "Margate";
$areanames{en}->{61361428} = "Maydena";
$areanames{en}->{61361429} = "Miena";
$areanames{en}->{61361430} = "New\ Norfolk";
$areanames{en}->{61361431} = "Nubeena";
$areanames{en}->{61361432} = "Oatlands";
$areanames{en}->{61361433} = "Orford";
$areanames{en}->{61361434} = "Ouse";
$areanames{en}->{61361435} = "Richmond";
$areanames{en}->{61361436} = "Sorell";
$areanames{en}->{61361437} = "South\ Bruny";
$areanames{en}->{61361438} = "Southwest";
$areanames{en}->{61361439} = "Strathgordon";
$areanames{en}->{6136144} = "Hobart";
$areanames{en}->{61361440} = "Swansea";
$areanames{en}->{61361441} = "Tarraleah";
$areanames{en}->{61361442} = "Woodbury";
$areanames{en}->{6136145} = "Hobart";
$areanames{en}->{61361460} = "Hobart";
$areanames{en}->{61361461} = "Hobart";
$areanames{en}->{61361462} = "Hobart";
$areanames{en}->{61361463} = "Hobart";
$areanames{en}->{61361464} = "Hobart";
$areanames{en}->{61361465} = "Sorell";
$areanames{en}->{61361466} = "Sorell";
$areanames{en}->{61361467} = "Sorell";
$areanames{en}->{61361468} = "Baden";
$areanames{en}->{61361469} = "Bothwell";
$areanames{en}->{61361470} = "Brighton";
$areanames{en}->{61361471} = "Colebrook";
$areanames{en}->{61361472} = "Dover";
$areanames{en}->{61361473} = "Dunalley";
$areanames{en}->{61361474} = "Geeveston";
$areanames{en}->{61361475} = "Gretna";
$areanames{en}->{61361476} = "Hermitage";
$areanames{en}->{61361477} = "Hobart";
$areanames{en}->{61361478} = "Huonville";
$areanames{en}->{61361479} = "Kempton";
$areanames{en}->{61361480} = "Little\ Swanport";
$areanames{en}->{61361481} = "Margate";
$areanames{en}->{61361482} = "Maydena";
$areanames{en}->{61361483} = "Miena";
$areanames{en}->{61361484} = "New\ Norfolk";
$areanames{en}->{61361485} = "Nubeena";
$areanames{en}->{61361486} = "Oatlands";
$areanames{en}->{61361487} = "Orford";
$areanames{en}->{61361488} = "Ouse";
$areanames{en}->{61361489} = "Richmond";
$areanames{en}->{61361490} = "Sorell";
$areanames{en}->{61361491} = "South\ Bruny";
$areanames{en}->{61361492} = "Southwest";
$areanames{en}->{61361493} = "Strathgordon";
$areanames{en}->{61361494} = "Baden";
$areanames{en}->{61361495} = "Bothwell";
$areanames{en}->{61361496} = "Brighton";
$areanames{en}->{61361497} = "Colebrook";
$areanames{en}->{61361498} = "Dover";
$areanames{en}->{61361499} = "Dunalley";
$areanames{en}->{61361500} = "Geeveston";
$areanames{en}->{61361501} = "Gretna";
$areanames{en}->{61361502} = "Hermitage";
$areanames{en}->{61361503} = "Hobart";
$areanames{en}->{61361504} = "Huonville";
$areanames{en}->{61361505} = "Kempton";
$areanames{en}->{61361506} = "Little\ Swanport";
$areanames{en}->{61361507} = "Margate";
$areanames{en}->{61361508} = "Maydena";
$areanames{en}->{61361509} = "Miena";
$areanames{en}->{61361510} = "New\ Norfolk";
$areanames{en}->{61361511} = "Nubeena";
$areanames{en}->{61361512} = "Oatlands";
$areanames{en}->{61361513} = "Orford";
$areanames{en}->{61361514} = "Ouse";
$areanames{en}->{61361515} = "Richmond";
$areanames{en}->{61361516} = "Sorell";
$areanames{en}->{61361517} = "South\ Bruny";
$areanames{en}->{61361518} = "Southwest";
$areanames{en}->{61361519} = "Strathgordon";
$areanames{en}->{61361520} = "Swansea";
$areanames{en}->{61361521} = "Tarraleah";
$areanames{en}->{61361522} = "Woodbury";
$areanames{en}->{61361523} = "Swansea";
$areanames{en}->{61361524} = "Tarraleah";
$areanames{en}->{61361525} = "Woodbury";
$areanames{en}->{61361526} = "Baden";
$areanames{en}->{61361527} = "Bothwell";
$areanames{en}->{61361528} = "Brighton";
$areanames{en}->{61361529} = "Colebrook";
$areanames{en}->{61361530} = "Dover";
$areanames{en}->{61361531} = "Dunalley";
$areanames{en}->{61361532} = "Geeveston";
$areanames{en}->{61361533} = "Gretna";
$areanames{en}->{61361534} = "Hermitage";
$areanames{en}->{61361535} = "Hobart";
$areanames{en}->{61361536} = "Huonville";
$areanames{en}->{61361537} = "Kempton";
$areanames{en}->{61361538} = "Little\ Swanport";
$areanames{en}->{61361539} = "Margate";
$areanames{en}->{61361540} = "Maydena";
$areanames{en}->{61361541} = "Miena";
$areanames{en}->{61361542} = "New\ Norfolk";
$areanames{en}->{61361543} = "Nubeena";
$areanames{en}->{61361544} = "Oatlands";
$areanames{en}->{61361545} = "Orford";
$areanames{en}->{61361546} = "Ouse";
$areanames{en}->{61361547} = "Richmond";
$areanames{en}->{61361548} = "Sorell";
$areanames{en}->{61361549} = "South\ Bruny";
$areanames{en}->{61361550} = "Southwest";
$areanames{en}->{61361551} = "Strathgordon";
$areanames{en}->{61361552} = "Swansea";
$areanames{en}->{61361553} = "Tarraleah";
$areanames{en}->{61361554} = "Woodbury";
$areanames{en}->{61361557} = "Baden";
$areanames{en}->{61361558} = "Bothwell";
$areanames{en}->{61361559} = "Brighton";
$areanames{en}->{61361560} = "Colebrook";
$areanames{en}->{61361561} = "Dover";
$areanames{en}->{61361562} = "Dunalley";
$areanames{en}->{61361563} = "Geeveston";
$areanames{en}->{61361564} = "Gretna";
$areanames{en}->{61361565} = "Hermitage";
$areanames{en}->{61361566} = "Hobart";
$areanames{en}->{61361567} = "Huonville";
$areanames{en}->{61361568} = "Kempton";
$areanames{en}->{61361569} = "Little\ Swanport";
$areanames{en}->{61361570} = "Margate";
$areanames{en}->{61361571} = "Maydena";
$areanames{en}->{61361572} = "Miena";
$areanames{en}->{61361573} = "New\ Norfolk";
$areanames{en}->{61361574} = "Nubeena";
$areanames{en}->{61361575} = "Oatlands";
$areanames{en}->{61361576} = "Orford";
$areanames{en}->{61361577} = "Ouse";
$areanames{en}->{61361578} = "Richmond";
$areanames{en}->{61361579} = "Sorell";
$areanames{en}->{61361580} = "South\ Bruny";
$areanames{en}->{61361581} = "Southwest";
$areanames{en}->{61361582} = "Strathgordon";
$areanames{en}->{61361583} = "Swansea";
$areanames{en}->{61361584} = "Tarraleah";
$areanames{en}->{61361585} = "Woodbury";
$areanames{en}->{61361586} = "Baden";
$areanames{en}->{61361587} = "Bothwell";
$areanames{en}->{61361588} = "Brighton";
$areanames{en}->{61361589} = "Colebrook";
$areanames{en}->{61361590} = "Dover";
$areanames{en}->{61361591} = "Dunalley";
$areanames{en}->{61361592} = "Geeveston";
$areanames{en}->{61361593} = "Gretna";
$areanames{en}->{61361594} = "Hermitage";
$areanames{en}->{61361595} = "Hobart";
$areanames{en}->{61361596} = "Huonville";
$areanames{en}->{61361597} = "Kempton";
$areanames{en}->{61361598} = "Little\ Swanport";
$areanames{en}->{61361599} = "Margate";
$areanames{en}->{61361600} = "Maydena";
$areanames{en}->{61361601} = "Miena";
$areanames{en}->{61361602} = "New\ Norfolk";
$areanames{en}->{61361603} = "Nubeena";
$areanames{en}->{61361604} = "Oatlands";
$areanames{en}->{61361605} = "Orford";
$areanames{en}->{61361606} = "Ouse";
$areanames{en}->{61361607} = "Richmond";
$areanames{en}->{61361608} = "Sorell";
$areanames{en}->{61361609} = "South\ Bruny";
$areanames{en}->{61361610} = "Southwest";
$areanames{en}->{61361611} = "Strathgordon";
$areanames{en}->{61361612} = "Swansea";
$areanames{en}->{61361613} = "Tarraleah";
$areanames{en}->{61361614} = "Woodbury";
$areanames{en}->{6136165} = "Hobart";
$areanames{en}->{6136166} = "Hobart";
$areanames{en}->{6136167} = "Hobart";
$areanames{en}->{6136168} = "Hobart";
$areanames{en}->{6136169} = "Hobart";
$areanames{en}->{6136170} = "Hobart";
$areanames{en}->{6136171} = "Hobart";
$areanames{en}->{61361730} = "Hobart";
$areanames{en}->{61361731} = "Hobart";
$areanames{en}->{61361732} = "Hobart";
$areanames{en}->{6136200} = "Hobart";
$areanames{en}->{61362010} = "Baden";
$areanames{en}->{61362011} = "Baden";
$areanames{en}->{61362012} = "Baden";
$areanames{en}->{61362013} = "Bothwell";
$areanames{en}->{61362014} = "Bothwell";
$areanames{en}->{61362015} = "Bothwell";
$areanames{en}->{61362016} = "Brighton";
$areanames{en}->{61362017} = "Brighton";
$areanames{en}->{61362018} = "Brighton";
$areanames{en}->{61362019} = "Dover";
$areanames{en}->{61362020} = "Colebrook";
$areanames{en}->{61362021} = "Colebrook";
$areanames{en}->{61362022} = "Colebrook";
$areanames{en}->{61362023} = "Dover";
$areanames{en}->{61362024} = "Dover";
$areanames{en}->{61362025} = "Dover";
$areanames{en}->{61362026} = "Dunalley";
$areanames{en}->{61362027} = "Dunalley";
$areanames{en}->{61362028} = "Dunalley";
$areanames{en}->{61362029} = "Geeveston";
$areanames{en}->{61362030} = "Geeveston";
$areanames{en}->{61362031} = "Geeveston";
$areanames{en}->{61362032} = "Geeveston";
$areanames{en}->{61362033} = "Gretna";
$areanames{en}->{61362034} = "Gretna";
$areanames{en}->{61362035} = "Gretna";
$areanames{en}->{61362036} = "Hermitage";
$areanames{en}->{61362037} = "Hermitage";
$areanames{en}->{61362038} = "Hermitage";
$areanames{en}->{61362039} = "South\ Bruny";
$areanames{en}->{61362040} = "Huonville";
$areanames{en}->{61362041} = "Huonville";
$areanames{en}->{61362042} = "Huonville";
$areanames{en}->{61362043} = "Kempton";
$areanames{en}->{61362044} = "Kempton";
$areanames{en}->{61362045} = "Kempton";
$areanames{en}->{61362046} = "Little\ Swanport";
$areanames{en}->{61362047} = "Little\ Swanport";
$areanames{en}->{61362048} = "Little\ Swanport";
$areanames{en}->{61362049} = "Dover";
$areanames{en}->{61362050} = "Margate";
$areanames{en}->{61362051} = "Margate";
$areanames{en}->{61362052} = "Margate";
$areanames{en}->{61362053} = "Maydena";
$areanames{en}->{61362054} = "Maydena";
$areanames{en}->{61362055} = "Maydena";
$areanames{en}->{61362056} = "Miena";
$areanames{en}->{61362057} = "Miena";
$areanames{en}->{61362058} = "Miena";
$areanames{en}->{61362059} = "Richmond";
$areanames{en}->{61362060} = "New\ Norfolk";
$areanames{en}->{61362061} = "New\ Norfolk";
$areanames{en}->{61362062} = "New\ Norfolk";
$areanames{en}->{61362063} = "Nubeena";
$areanames{en}->{61362064} = "Nubeena";
$areanames{en}->{61362065} = "Nubeena";
$areanames{en}->{61362066} = "Oatlands";
$areanames{en}->{61362067} = "Oatlands";
$areanames{en}->{61362068} = "Oatlands";
$areanames{en}->{61362069} = "Sorell";
$areanames{en}->{61362070} = "Orford";
$areanames{en}->{61362071} = "Orford";
$areanames{en}->{61362072} = "Orford";
$areanames{en}->{61362073} = "Ouse";
$areanames{en}->{61362074} = "Ouse";
$areanames{en}->{61362075} = "Ouse";
$areanames{en}->{61362076} = "Richmond";
$areanames{en}->{61362077} = "Richmond";
$areanames{en}->{61362078} = "Richmond";
$areanames{en}->{61362079} = "Brighton";
$areanames{en}->{6136208} = "Hobart";
$areanames{en}->{61362090} = "Hobart";
$areanames{en}->{61362091} = "Huonville";
$areanames{en}->{61362092} = "Margate";
$areanames{en}->{61362093} = "New\ Norfolk";
$areanames{en}->{61362094} = "Nubeena";
$areanames{en}->{61362095} = "Oatlands";
$areanames{en}->{61362096} = "Orford";
$areanames{en}->{61362097} = "Swansea";
$areanames{en}->{61362098} = "Woodbury";
$areanames{en}->{61362099} = "Baden";
$areanames{en}->{613621} = "Hobart";
$areanames{en}->{61362170} = "Sorell";
$areanames{en}->{61362171} = "Sorell";
$areanames{en}->{61362172} = "Sorell";
$areanames{en}->{61362173} = "South\ Bruny";
$areanames{en}->{61362174} = "South\ Bruny";
$areanames{en}->{61362175} = "South\ Bruny";
$areanames{en}->{61362176} = "Strathgordon";
$areanames{en}->{61362177} = "Strathgordon";
$areanames{en}->{61362178} = "Strathgordon";
$areanames{en}->{61362190} = "Swansea";
$areanames{en}->{61362191} = "Swansea";
$areanames{en}->{61362192} = "Swansea";
$areanames{en}->{61362193} = "Tarraleah";
$areanames{en}->{61362194} = "Tarraleah";
$areanames{en}->{61362195} = "Tarraleah";
$areanames{en}->{61362196} = "Woodbury";
$areanames{en}->{61362197} = "Woodbury";
$areanames{en}->{61362198} = "Woodbury";
$areanames{en}->{61362199} = "Geeveston";
$areanames{en}->{613622} = "Hobart";
$areanames{en}->{613623} = "Hobart";
$areanames{en}->{613624} = "Hobart";
$areanames{en}->{61362410} = "Dover";
$areanames{en}->{61362412} = "Geeveston";
$areanames{en}->{61362413} = "South\ Bruny";
$areanames{en}->{61362414} = "Southwest";
$areanames{en}->{61362415} = "Brighton";
$areanames{en}->{61362417} = "Huonville";
$areanames{en}->{61362418} = "Margate";
$areanames{en}->{61362420} = "Southwest";
$areanames{en}->{61362421} = "Dover";
$areanames{en}->{61362460} = "New\ Norfolk";
$areanames{en}->{61362461} = "Richmond";
$areanames{en}->{61362462} = "Sorell";
$areanames{en}->{61362463} = "Baden";
$areanames{en}->{6136250} = "Nubeena";
$areanames{en}->{61362505} = "Bothwell";
$areanames{en}->{61362506} = "Colebrook";
$areanames{en}->{61362507} = "Dunalley";
$areanames{en}->{61362508} = "Hermitage";
$areanames{en}->{61362510} = "South\ Bruny";
$areanames{en}->{61362511} = "Hobart";
$areanames{en}->{61362512} = "Nubeena";
$areanames{en}->{61362513} = "Hobart";
$areanames{en}->{61362514} = "Bothwell";
$areanames{en}->{61362515} = "Colebrook";
$areanames{en}->{61362516} = "Dunalley";
$areanames{en}->{61362517} = "Hermitage";
$areanames{en}->{61362518} = "Kempton";
$areanames{en}->{61362519} = "Little\ Swanport";
$areanames{en}->{61362520} = "Miena";
$areanames{en}->{61362521} = "Gretna";
$areanames{en}->{61362522} = "Maydena";
$areanames{en}->{61362523} = "Ouse";
$areanames{en}->{61362524} = "Strathgordon";
$areanames{en}->{61362525} = "Tarraleah";
$areanames{en}->{61362526} = "Southwest";
$areanames{en}->{61362527} = "Brighton";
$areanames{en}->{61362528} = "Kempton";
$areanames{en}->{61362529} = "Huonville";
$areanames{en}->{61362530} = "Little\ Swanport";
$areanames{en}->{61362531} = "Miena";
$areanames{en}->{61362532} = "Nubeena";
$areanames{en}->{61362533} = "Oatlands";
$areanames{en}->{61362534} = "Dunalley";
$areanames{en}->{61362535} = "Dunalley";
$areanames{en}->{61362536} = "Dunalley";
$areanames{en}->{61362537} = "Orford";
$areanames{en}->{61362538} = "Swansea";
$areanames{en}->{61362539} = "Dunalley";
$areanames{en}->{61362540} = "Oatlands";
$areanames{en}->{61362541} = "Oatlands";
$areanames{en}->{61362542} = "Woodbury";
$areanames{en}->{61362543} = "Oatlands";
$areanames{en}->{61362544} = "Oatlands";
$areanames{en}->{61362545} = "Oatlands";
$areanames{en}->{61362546} = "Baden";
$areanames{en}->{61362547} = "Baden";
$areanames{en}->{61362548} = "Baden";
$areanames{en}->{61362549} = "Baden";
$areanames{en}->{61362550} = "Gretna";
$areanames{en}->{61362551} = "Maydena";
$areanames{en}->{61362552} = "Woodbury";
$areanames{en}->{61362553} = "Woodbury";
$areanames{en}->{61362554} = "Woodbury";
$areanames{en}->{61362555} = "Woodbury";
$areanames{en}->{61362556} = "Ouse";
$areanames{en}->{61362557} = "Strathgordon";
$areanames{en}->{61362558} = "Tarraleah";
$areanames{en}->{61362559} = "Woodbury";
$areanames{en}->{61362560} = "Orford";
$areanames{en}->{61362561} = "Geeveston";
$areanames{en}->{61362562} = "South\ Bruny";
$areanames{en}->{61362563} = "Orford";
$areanames{en}->{61362564} = "Orford";
$areanames{en}->{61362565} = "Swansea";
$areanames{en}->{61362566} = "Swansea";
$areanames{en}->{61362567} = "Swansea";
$areanames{en}->{61362568} = "Little\ Swanport";
$areanames{en}->{61362569} = "Brighton";
$areanames{en}->{61362570} = "Swansea";
$areanames{en}->{61362571} = "Orford";
$areanames{en}->{61362572} = "Orford";
$areanames{en}->{61362573} = "Orford";
$areanames{en}->{61362574} = "Orford";
$areanames{en}->{61362575} = "Orford";
$areanames{en}->{61362576} = "Little\ Swanport";
$areanames{en}->{61362577} = "Little\ Swanport";
$areanames{en}->{61362578} = "Swansea";
$areanames{en}->{61362579} = "Swansea";
$areanames{en}->{61362580} = "Kempton";
$areanames{en}->{61362581} = "Huonville";
$areanames{en}->{61362582} = "Hermitage";
$areanames{en}->{61362583} = "Margate";
$areanames{en}->{61362584} = "Bothwell";
$areanames{en}->{61362585} = "New\ Norfolk";
$areanames{en}->{61362586} = "Colebrook";
$areanames{en}->{61362587} = "Richmond";
$areanames{en}->{61362588} = "Miena";
$areanames{en}->{61362589} = "Sorell";
$areanames{en}->{61362590} = "Miena";
$areanames{en}->{61362591} = "Kempton";
$areanames{en}->{61362592} = "Hermitage";
$areanames{en}->{61362593} = "Kempton";
$areanames{en}->{61362594} = "Bothwell";
$areanames{en}->{61362595} = "Bothwell";
$areanames{en}->{61362596} = "Hermitage";
$areanames{en}->{61362597} = "Colebrook";
$areanames{en}->{61362598} = "Miena";
$areanames{en}->{61362599} = "Colebrook";
$areanames{en}->{6136260} = "Richmond";
$areanames{en}->{61362605} = "Baden";
$areanames{en}->{61362606} = "Margate";
$areanames{en}->{61362607} = "Margate";
$areanames{en}->{6136261} = "New\ Norfolk";
$areanames{en}->{61362620} = "New\ Norfolk";
$areanames{en}->{61362621} = "New\ Norfolk";
$areanames{en}->{61362622} = "New\ Norfolk";
$areanames{en}->{61362623} = "New\ Norfolk";
$areanames{en}->{61362624} = "Bothwell";
$areanames{en}->{61362625} = "Brighton";
$areanames{en}->{61362626} = "Brighton";
$areanames{en}->{61362627} = "Brighton";
$areanames{en}->{61362628} = "Brighton";
$areanames{en}->{61362629} = "Brighton";
$areanames{en}->{6136263} = "Brighton";
$areanames{en}->{6136264} = "Huonville";
$areanames{en}->{61362645} = "Colebrook";
$areanames{en}->{61362646} = "Dunalley";
$areanames{en}->{6136265} = "Sorell";
$areanames{en}->{6136266} = "Huonville";
$areanames{en}->{61362668} = "Hermitage";
$areanames{en}->{61362669} = "Kempton";
$areanames{en}->{6136267} = "Margate";
$areanames{en}->{6136268} = "Brighton";
$areanames{en}->{61362682} = "Little\ Swanport";
$areanames{en}->{61362683} = "Miena";
$areanames{en}->{6136269} = "Sorell";
$areanames{en}->{61362697} = "Nubeena";
$areanames{en}->{61362698} = "Oatlands";
$areanames{en}->{61362699} = "Orford";
$areanames{en}->{613627} = "Hobart";
$areanames{en}->{61362760} = "Margate";
$areanames{en}->{61362761} = "New\ Norfolk";
$areanames{en}->{61362762} = "Richmond";
$areanames{en}->{61362763} = "Sorell";
$areanames{en}->{61362764} = "Baden";
$areanames{en}->{61362765} = "Bothwell";
$areanames{en}->{61362766} = "Colebrook";
$areanames{en}->{61362767} = "Dunalley";
$areanames{en}->{61362768} = "Hermitage";
$areanames{en}->{61362769} = "Kempton";
$areanames{en}->{61362800} = "Strathgordon";
$areanames{en}->{61362801} = "Strathgordon";
$areanames{en}->{61362802} = "Strathgordon";
$areanames{en}->{61362803} = "Swansea";
$areanames{en}->{61362804} = "Woodbury";
$areanames{en}->{61362805} = "Gretna";
$areanames{en}->{61362806} = "Maydena";
$areanames{en}->{61362807} = "Ouse";
$areanames{en}->{61362808} = "Strathgordon";
$areanames{en}->{61362809} = "Strathgordon";
$areanames{en}->{6136281} = "Hobart";
$areanames{en}->{6136282} = "Hobart";
$areanames{en}->{6136283} = "Hobart";
$areanames{en}->{61362836} = "Tarraleah";
$areanames{en}->{61362840} = "Little\ Swanport";
$areanames{en}->{61362841} = "Miena";
$areanames{en}->{61362842} = "Nubeena";
$areanames{en}->{61362843} = "Oatlands";
$areanames{en}->{61362844} = "Orford";
$areanames{en}->{61362845} = "Swansea";
$areanames{en}->{61362846} = "Woodbury";
$areanames{en}->{61362847} = "Gretna";
$areanames{en}->{61362848} = "Maydena";
$areanames{en}->{61362849} = "Ouse";
$areanames{en}->{6136285} = "Hobart";
$areanames{en}->{61362850} = "Strathgordon";
$areanames{en}->{61362851} = "Tarraleah";
$areanames{en}->{6136286} = "Gretna";
$areanames{en}->{61362860} = "Hobart";
$areanames{en}->{61362867} = "Hobart";
$areanames{en}->{61362868} = "Hobart";
$areanames{en}->{6136287} = "Ouse";
$areanames{en}->{61362876} = "Hobart";
$areanames{en}->{61362877} = "Hobart";
$areanames{en}->{61362878} = "Hobart";
$areanames{en}->{6136288} = "Maydena";
$areanames{en}->{61362885} = "Hobart";
$areanames{en}->{61362886} = "Hobart";
$areanames{en}->{61362887} = "Hobart";
$areanames{en}->{61362888} = "Hobart";
$areanames{en}->{6136289} = "Tarraleah";
$areanames{en}->{61362895} = "Hobart";
$areanames{en}->{61362896} = "Hobart";
$areanames{en}->{61362897} = "Hobart";
$areanames{en}->{61362898} = "Hobart";
$areanames{en}->{61362900} = "Nubeena";
$areanames{en}->{61362901} = "Oatlands";
$areanames{en}->{61362902} = "Orford";
$areanames{en}->{61362903} = "Swansea";
$areanames{en}->{61362904} = "Woodbury";
$areanames{en}->{61362905} = "Gretna";
$areanames{en}->{61362906} = "Maydena";
$areanames{en}->{61362907} = "Ouse";
$areanames{en}->{61362908} = "Strathgordon";
$areanames{en}->{61362909} = "Tarraleah";
$areanames{en}->{61362910} = "Richmond";
$areanames{en}->{61362911} = "Sorell";
$areanames{en}->{61362912} = "Baden";
$areanames{en}->{61362913} = "Bothwell";
$areanames{en}->{61362914} = "Colebrook";
$areanames{en}->{61362915} = "Dunalley";
$areanames{en}->{61362916} = "Hermitage";
$areanames{en}->{61362917} = "Kempton";
$areanames{en}->{61362918} = "Little\ Swanport";
$areanames{en}->{61362919} = "Miena";
$areanames{en}->{6136292} = "Hobart";
$areanames{en}->{61362921} = "Geeveston";
$areanames{en}->{61362922} = "Geeveston";
$areanames{en}->{61362923} = "Nubeena";
$areanames{en}->{6136293} = "South\ Bruny";
$areanames{en}->{61362934} = "Brighton";
$areanames{en}->{61362935} = "Brighton";
$areanames{en}->{61362937} = "Margate";
$areanames{en}->{61362938} = "Baden";
$areanames{en}->{61362940} = "Hobart";
$areanames{en}->{61362941} = "Dover";
$areanames{en}->{61362942} = "Geeveston";
$areanames{en}->{61362943} = "South\ Bruny";
$areanames{en}->{61362944} = "Southwest";
$areanames{en}->{61362945} = "Brighton";
$areanames{en}->{61362946} = "Hobart";
$areanames{en}->{61362947} = "Huonville";
$areanames{en}->{61362948} = "Margate";
$areanames{en}->{61362949} = "New\ Norfolk";
$areanames{en}->{6136295} = "Geeveston";
$areanames{en}->{61362953} = "Hobart";
$areanames{en}->{61362954} = "Hobart";
$areanames{en}->{61362955} = "Hobart";
$areanames{en}->{61362956} = "Hobart";
$areanames{en}->{61362960} = "Southwest";
$areanames{en}->{61362961} = "Southwest";
$areanames{en}->{61362962} = "Southwest";
$areanames{en}->{61362963} = "Bothwell";
$areanames{en}->{61362964} = "Dunalley";
$areanames{en}->{61362965} = "Hermitage";
$areanames{en}->{61362966} = "Nubeena";
$areanames{en}->{61362967} = "Orford";
$areanames{en}->{61362968} = "Richmond";
$areanames{en}->{6136297} = "Geeveston";
$areanames{en}->{61362973} = "Hobart";
$areanames{en}->{61362974} = "Hobart";
$areanames{en}->{61362975} = "Hobart";
$areanames{en}->{6136298} = "Dover";
$areanames{en}->{61362985} = "Geeveston";
$areanames{en}->{61362986} = "Geeveston";
$areanames{en}->{61362987} = "Geeveston";
$areanames{en}->{6136299} = "Hobart";
$areanames{en}->{61363000} = "Launceston";
$areanames{en}->{61363001} = "Launceston";
$areanames{en}->{61363002} = "Launceston";
$areanames{en}->{61363003} = "Avoca";
$areanames{en}->{61363004} = "Avoca";
$areanames{en}->{61363005} = "Avoca";
$areanames{en}->{61363006} = "Beaconsfield";
$areanames{en}->{61363007} = "Beaconsfield";
$areanames{en}->{61363008} = "Beaconsfield";
$areanames{en}->{61363009} = "Moltema";
$areanames{en}->{61363010} = "Bicheno";
$areanames{en}->{61363011} = "Bicheno";
$areanames{en}->{61363012} = "Bicheno";
$areanames{en}->{61363013} = "Blessington";
$areanames{en}->{61363014} = "Blessington";
$areanames{en}->{61363015} = "Blessington";
$areanames{en}->{61363016} = "Bridport";
$areanames{en}->{61363017} = "Bridport";
$areanames{en}->{61363018} = "Bridport";
$areanames{en}->{61363019} = "Launceston";
$areanames{en}->{61363020} = "Campbell\ Town";
$areanames{en}->{61363021} = "Campbell\ Town";
$areanames{en}->{61363022} = "Campbell\ Town";
$areanames{en}->{61363023} = "Deloraine";
$areanames{en}->{61363024} = "Deloraine";
$areanames{en}->{61363025} = "Deloraine";
$areanames{en}->{61363026} = "Emita";
$areanames{en}->{61363027} = "Emita";
$areanames{en}->{61363028} = "Emita";
$areanames{en}->{61363029} = "Moltema";
$areanames{en}->{61363030} = "Evandale";
$areanames{en}->{61363031} = "Evandale";
$areanames{en}->{61363032} = "Evandale";
$areanames{en}->{61363033} = "Exeter";
$areanames{en}->{61363034} = "Exeter";
$areanames{en}->{61363035} = "Exeter";
$areanames{en}->{61363036} = "Fingal";
$areanames{en}->{61363037} = "Fingal";
$areanames{en}->{61363038} = "Fingal";
$areanames{en}->{61363039} = "Deloraine";
$areanames{en}->{61363040} = "George\ Town";
$areanames{en}->{61363041} = "George\ Town";
$areanames{en}->{61363042} = "George\ Town";
$areanames{en}->{61363043} = "Gladstone";
$areanames{en}->{61363044} = "Gladstone";
$areanames{en}->{61363045} = "Gladstone";
$areanames{en}->{61363046} = "Glengarry";
$areanames{en}->{61363047} = "Glengarry";
$areanames{en}->{61363048} = "Glengarry";
$areanames{en}->{61363049} = "Mole\ Creek";
$areanames{en}->{61363050} = "Lilydale";
$areanames{en}->{61363051} = "Lilydale";
$areanames{en}->{61363052} = "Lilydale";
$areanames{en}->{61363053} = "Longford";
$areanames{en}->{61363054} = "Longford";
$areanames{en}->{61363055} = "Longford";
$areanames{en}->{61363056} = "Mathinna";
$areanames{en}->{61363057} = "Mathinna";
$areanames{en}->{61363058} = "Mathinna";
$areanames{en}->{61363059} = "Emita";
$areanames{en}->{61363060} = "Mole\ Creek";
$areanames{en}->{61363061} = "Mole\ Creek";
$areanames{en}->{61363062} = "Mole\ Creek";
$areanames{en}->{61363063} = "Moltema";
$areanames{en}->{61363064} = "Moltema";
$areanames{en}->{61363065} = "Moltema";
$areanames{en}->{61363066} = "Pyengana";
$areanames{en}->{61363067} = "Pyengana";
$areanames{en}->{61363068} = "Pyengana";
$areanames{en}->{61363069} = "Whitemark";
$areanames{en}->{61363070} = "Ringarooma";
$areanames{en}->{61363071} = "Ringarooma";
$areanames{en}->{61363072} = "Ringarooma";
$areanames{en}->{61363073} = "Rossarden";
$areanames{en}->{61363074} = "Rossarden";
$areanames{en}->{61363075} = "Rossarden";
$areanames{en}->{61363076} = "Scottsdale";
$areanames{en}->{61363077} = "Scottsdale";
$areanames{en}->{61363078} = "Scottsdale";
$areanames{en}->{61363079} = "Campbell\ Town";
$areanames{en}->{61363080} = "St\ Helens";
$areanames{en}->{61363081} = "St\ Helens";
$areanames{en}->{61363082} = "St\ Helens";
$areanames{en}->{61363083} = "St\ Marys";
$areanames{en}->{61363084} = "St\ Marys";
$areanames{en}->{61363085} = "St\ Marys";
$areanames{en}->{61363086} = "Targa";
$areanames{en}->{61363087} = "Targa";
$areanames{en}->{61363088} = "Targa";
$areanames{en}->{61363089} = "Evandale";
$areanames{en}->{61363090} = "Waterhouse";
$areanames{en}->{61363091} = "Waterhouse";
$areanames{en}->{61363092} = "Waterhouse";
$areanames{en}->{61363093} = "Westbury";
$areanames{en}->{61363094} = "Westbury";
$areanames{en}->{61363095} = "Westbury";
$areanames{en}->{61363096} = "Whitemark";
$areanames{en}->{61363097} = "Whitemark";
$areanames{en}->{61363098} = "Whitemark";
$areanames{en}->{61363099} = "Exeter";
$areanames{en}->{61363100} = "Winnaleah";
$areanames{en}->{61363101} = "Winnaleah";
$areanames{en}->{61363102} = "Winnaleah";
$areanames{en}->{61363103} = "Campbell\ Town";
$areanames{en}->{61363104} = "Evandale";
$areanames{en}->{61363105} = "Exeter";
$areanames{en}->{61363106} = "George\ Town";
$areanames{en}->{61363107} = "Glengarry";
$areanames{en}->{61363108} = "Launceston";
$areanames{en}->{61363109} = "Lilydale";
$areanames{en}->{613631100} = "Launceston";
$areanames{en}->{613631101} = "Launceston";
$areanames{en}->{613631112} = "Launceston";
$areanames{en}->{613631119} = "Launceston";
$areanames{en}->{61363112} = "Launceston";
$areanames{en}->{61363113} = "Ringarooma";
$areanames{en}->{61363114} = "Scottsdale";
$areanames{en}->{61363115} = "Waterhouse";
$areanames{en}->{61363116} = "Winnaleah";
$areanames{en}->{61363117} = "Bicheno";
$areanames{en}->{61363118} = "Fingal";
$areanames{en}->{61363119} = "Mathinna";
$areanames{en}->{61363120} = "Pyengana";
$areanames{en}->{61363121} = "St\ Helens";
$areanames{en}->{61363122} = "St\ Marys";
$areanames{en}->{61363123} = "George\ Town";
$areanames{en}->{61363124} = "Glengarry";
$areanames{en}->{61363125} = "Launceston";
$areanames{en}->{61363126} = "Lilydale";
$areanames{en}->{61363127} = "Longford";
$areanames{en}->{61363128} = "Rossarden";
$areanames{en}->{61363129} = "Targa";
$areanames{en}->{61363130} = "Westbury";
$areanames{en}->{61363131} = "Bridport";
$areanames{en}->{61363132} = "Gladstone";
$areanames{en}->{61363133} = "Deloraine";
$areanames{en}->{61363134} = "Mole\ Creek";
$areanames{en}->{61363135} = "Emita";
$areanames{en}->{61363136} = "Whitemark";
$areanames{en}->{61363137} = "Avoca";
$areanames{en}->{61363138} = "Beaconsfield";
$areanames{en}->{61363139} = "Blessington";
$areanames{en}->{61363140} = "Longford";
$areanames{en}->{61363141} = "Rossarden";
$areanames{en}->{61363142} = "Targa";
$areanames{en}->{61363143} = "Westbury";
$areanames{en}->{61363144} = "Avoca";
$areanames{en}->{61363145} = "Beaconsfield";
$areanames{en}->{61363146} = "Blessington";
$areanames{en}->{61363147} = "Ringarooma";
$areanames{en}->{61363148} = "Scottsdale";
$areanames{en}->{61363149} = "Waterhouse";
$areanames{en}->{61363150} = "Winnaleah";
$areanames{en}->{61363151} = "Bridport";
$areanames{en}->{61363152} = "Gladstone";
$areanames{en}->{61363153} = "Bicheno";
$areanames{en}->{61363154} = "Fingal";
$areanames{en}->{61363155} = "Mathinna";
$areanames{en}->{61363156} = "Pyengana";
$areanames{en}->{61363157} = "St\ Helens";
$areanames{en}->{61363158} = "St\ Marys";
$areanames{en}->{61363159} = "Deloraine";
$areanames{en}->{61363160} = "Mole\ Creek";
$areanames{en}->{61363161} = "Moltema";
$areanames{en}->{61363162} = "Emita";
$areanames{en}->{61363163} = "Whitemark";
$areanames{en}->{61363164} = "Avoca";
$areanames{en}->{61363165} = "Beaconsfield";
$areanames{en}->{61363166} = "Blessington";
$areanames{en}->{61363167} = "Campbell\ Town";
$areanames{en}->{61363168} = "Evandale";
$areanames{en}->{61363169} = "Exeter";
$areanames{en}->{61363170} = "George\ Town";
$areanames{en}->{61363171} = "Glengarry";
$areanames{en}->{61363172} = "Launceston";
$areanames{en}->{61363173} = "Lilydale";
$areanames{en}->{61363174} = "Longford";
$areanames{en}->{61363175} = "Rossarden";
$areanames{en}->{61363176} = "Targa";
$areanames{en}->{61363177} = "Westbury";
$areanames{en}->{61363178} = "Bridport";
$areanames{en}->{61363179} = "Gladstone";
$areanames{en}->{61363180} = "Ringarooma";
$areanames{en}->{61363181} = "Scottsdale";
$areanames{en}->{61363182} = "Waterhouse";
$areanames{en}->{61363183} = "Winnaleah";
$areanames{en}->{61363184} = "Bicheno";
$areanames{en}->{61363185} = "Fingal";
$areanames{en}->{61363186} = "Mathinna";
$areanames{en}->{61363187} = "Pyengana";
$areanames{en}->{61363188} = "St\ Helens";
$areanames{en}->{61363189} = "St\ Marys";
$areanames{en}->{61363190} = "Moltema";
$areanames{en}->{61363191} = "Deloraine";
$areanames{en}->{61363192} = "Mole\ Creek";
$areanames{en}->{61363193} = "Emita";
$areanames{en}->{61363194} = "Whitemark";
$areanames{en}->{61363195} = "Campbell\ Town";
$areanames{en}->{61363196} = "Evandale";
$areanames{en}->{61363197} = "Exeter";
$areanames{en}->{61363198} = "George\ Town";
$areanames{en}->{61363199} = "Glengarry";
$areanames{en}->{613632} = "Launceston";
$areanames{en}->{61363200} = "Lilydale";
$areanames{en}->{61363201} = "Avoca";
$areanames{en}->{61363202} = "Beaconsfield";
$areanames{en}->{61363203} = "Blessington";
$areanames{en}->{61363204} = "Longford";
$areanames{en}->{61363205} = "Rossarden";
$areanames{en}->{61363206} = "Targa";
$areanames{en}->{61363207} = "Westbury";
$areanames{en}->{61363208} = "Ringarooma";
$areanames{en}->{61363209} = "Scottsdale";
$areanames{en}->{61363210} = "Waterhouse";
$areanames{en}->{61363211} = "Bridport";
$areanames{en}->{61363212} = "Gladstone";
$areanames{en}->{61363213} = "Winnaleah";
$areanames{en}->{61363214} = "Bicheno";
$areanames{en}->{61363215} = "Fingal";
$areanames{en}->{61363216} = "Mathinna";
$areanames{en}->{61363217} = "Pyengana";
$areanames{en}->{61363218} = "St\ Helens";
$areanames{en}->{61363219} = "St\ Marys";
$areanames{en}->{61363220} = "Deloraine";
$areanames{en}->{61363221} = "Mole\ Creek";
$areanames{en}->{61363222} = "Moltema";
$areanames{en}->{61363223} = "Emita";
$areanames{en}->{61363224} = "Whitemark";
$areanames{en}->{61363225} = "Avoca";
$areanames{en}->{61363226} = "Beaconsfield";
$areanames{en}->{61363227} = "Blessington";
$areanames{en}->{61363228} = "Campbell\ Town";
$areanames{en}->{61363229} = "Evandale";
$areanames{en}->{61363290} = "Exeter";
$areanames{en}->{61363291} = "George\ Town";
$areanames{en}->{61363292} = "Glengarry";
$areanames{en}->{61363293} = "Lilydale";
$areanames{en}->{61363294} = "Longford";
$areanames{en}->{61363295} = "Rossarden";
$areanames{en}->{61363296} = "Targa";
$areanames{en}->{61363297} = "Westbury";
$areanames{en}->{61363298} = "Bridport";
$areanames{en}->{61363299} = "Gladstone";
$areanames{en}->{6136338} = "Launceston";
$areanames{en}->{6136339} = "Launceston";
$areanames{en}->{613634} = "Launceston";
$areanames{en}->{61363420} = "Ringarooma";
$areanames{en}->{61363421} = "Scottsdale";
$areanames{en}->{61363422} = "Waterhouse";
$areanames{en}->{61363423} = "Winnaleah";
$areanames{en}->{61363424} = "Bicheno";
$areanames{en}->{61363425} = "Fingal";
$areanames{en}->{61363426} = "Mathinna";
$areanames{en}->{61363427} = "Pyengana";
$areanames{en}->{61363428} = "St\ Helens";
$areanames{en}->{61363429} = "St\ Marys";
$areanames{en}->{61363460} = "Deloraine";
$areanames{en}->{61363461} = "Mole\ Creek";
$areanames{en}->{61363462} = "Moltema";
$areanames{en}->{61363463} = "Emita";
$areanames{en}->{61363464} = "Whitemark";
$areanames{en}->{61363465} = "Avoca";
$areanames{en}->{61363466} = "Beaconsfield";
$areanames{en}->{61363467} = "Blessington";
$areanames{en}->{61363468} = "Campbell\ Town";
$areanames{en}->{61363469} = "Evandale";
$areanames{en}->{61363470} = "Exeter";
$areanames{en}->{61363471} = "George\ Town";
$areanames{en}->{61363472} = "Glengarry";
$areanames{en}->{61363473} = "Lilydale";
$areanames{en}->{61363474} = "Longford";
$areanames{en}->{61363475} = "Rossarden";
$areanames{en}->{61363476} = "Targa";
$areanames{en}->{61363477} = "Westbury";
$areanames{en}->{61363478} = "Bridport";
$areanames{en}->{61363479} = "Gladstone";
$areanames{en}->{61363492} = "Ringarooma";
$areanames{en}->{61363493} = "Scottsdale";
$areanames{en}->{61363494} = "Waterhouse";
$areanames{en}->{61363495} = "Winnaleah";
$areanames{en}->{61363496} = "Bicheno";
$areanames{en}->{61363497} = "Fingal";
$areanames{en}->{61363498} = "Mathinna";
$areanames{en}->{61363499} = "Pyengana";
$areanames{en}->{6136350} = "Scottsdale";
$areanames{en}->{61363510} = "St\ Helens";
$areanames{en}->{61363511} = "St\ Marys";
$areanames{en}->{61363512} = "Deloraine";
$areanames{en}->{61363513} = "Mole\ Creek";
$areanames{en}->{61363514} = "Moltema";
$areanames{en}->{61363515} = "Emita";
$areanames{en}->{61363516} = "Whitemark";
$areanames{en}->{61363517} = "Avoca";
$areanames{en}->{61363518} = "Beaconsfield";
$areanames{en}->{61363519} = "Blessington";
$areanames{en}->{6136352} = "Scottsdale";
$areanames{en}->{6136353} = "Ringarooma";
$areanames{en}->{6136354} = "Winnaleah";
$areanames{en}->{6136355} = "Waterhouse";
$areanames{en}->{6136356} = "Bridport";
$areanames{en}->{6136357} = "Gladstone";
$areanames{en}->{61363580} = "Campbell\ Town";
$areanames{en}->{61363581} = "Evandale";
$areanames{en}->{61363582} = "Exeter";
$areanames{en}->{61363583} = "George\ Town";
$areanames{en}->{61363584} = "Glengarry";
$areanames{en}->{61363585} = "Launceston";
$areanames{en}->{61363586} = "Lilydale";
$areanames{en}->{61363587} = "Longford";
$areanames{en}->{61363588} = "Rossarden";
$areanames{en}->{61363589} = "Targa";
$areanames{en}->{6136359} = "Whitemark";
$areanames{en}->{61363596} = "Emita";
$areanames{en}->{61363597} = "Emita";
$areanames{en}->{61363598} = "Emita";
$areanames{en}->{61363599} = "Emita";
$areanames{en}->{61363600} = "Avoca";
$areanames{en}->{61363601} = "Beaconsfield";
$areanames{en}->{61363602} = "Bicheno";
$areanames{en}->{61363603} = "Blessington";
$areanames{en}->{61363604} = "Bridport";
$areanames{en}->{61363605} = "Campbell\ Town";
$areanames{en}->{61363606} = "Deloraine";
$areanames{en}->{61363607} = "Emita";
$areanames{en}->{61363608} = "Evandale";
$areanames{en}->{61363609} = "Exeter";
$areanames{en}->{61363610} = "Westbury";
$areanames{en}->{61363611} = "Bridport";
$areanames{en}->{61363612} = "Gladstone";
$areanames{en}->{61363613} = "Ringarooma";
$areanames{en}->{61363614} = "Scottsdale";
$areanames{en}->{61363615} = "Waterhouse";
$areanames{en}->{61363616} = "Winnaleah";
$areanames{en}->{61363617} = "Bicheno";
$areanames{en}->{61363618} = "Fingal";
$areanames{en}->{61363619} = "Mathinna";
$areanames{en}->{6136362} = "Deloraine";
$areanames{en}->{6136363} = "Mole\ Creek";
$areanames{en}->{61363640} = "Pyengana";
$areanames{en}->{61363641} = "St\ Helens";
$areanames{en}->{61363642} = "St\ Marys";
$areanames{en}->{61363643} = "Launceston";
$areanames{en}->{61363644} = "Deloraine";
$areanames{en}->{61363645} = "Mole\ Creek";
$areanames{en}->{61363646} = "Moltema";
$areanames{en}->{61363647} = "Emita";
$areanames{en}->{61363648} = "Whitemark";
$areanames{en}->{61363649} = "Avoca";
$areanames{en}->{61363650} = "Beaconsfield";
$areanames{en}->{61363651} = "Blessington";
$areanames{en}->{61363652} = "Campbell\ Town";
$areanames{en}->{61363653} = "Evandale";
$areanames{en}->{61363654} = "Exeter";
$areanames{en}->{61363655} = "George\ Town";
$areanames{en}->{61363656} = "Glengarry";
$areanames{en}->{61363657} = "Launceston";
$areanames{en}->{61363658} = "Lilydale";
$areanames{en}->{61363659} = "Longford";
$areanames{en}->{61363660} = "Rossarden";
$areanames{en}->{61363661} = "Targa";
$areanames{en}->{61363662} = "Westbury";
$areanames{en}->{61363663} = "Bridport";
$areanames{en}->{61363664} = "Gladstone";
$areanames{en}->{61363665} = "Ringarooma";
$areanames{en}->{61363666} = "Scottsdale";
$areanames{en}->{61363667} = "Waterhouse";
$areanames{en}->{61363668} = "Winnaleah";
$areanames{en}->{61363669} = "Bicheno";
$areanames{en}->{6136367} = "Mole\ Creek";
$areanames{en}->{6136368} = "Moltema";
$areanames{en}->{6136369} = "Deloraine";
$areanames{en}->{61363700} = "Fingal";
$areanames{en}->{61363701} = "Mathinna";
$areanames{en}->{61363702} = "Pyengana";
$areanames{en}->{61363703} = "St\ Helens";
$areanames{en}->{61363704} = "St\ Marys";
$areanames{en}->{61363705} = "Westbury";
$areanames{en}->{61363706} = "Westbury";
$areanames{en}->{61363707} = "Launceston";
$areanames{en}->{61363708} = "Blessington";
$areanames{en}->{61363709} = "Blessington";
$areanames{en}->{61363710} = "George\ Town";
$areanames{en}->{61363711} = "George\ Town";
$areanames{en}->{61363712} = "Longford";
$areanames{en}->{61363713} = "Longford";
$areanames{en}->{61363714} = "Rossarden";
$areanames{en}->{61363715} = "Rossarden";
$areanames{en}->{61363716} = "Bridport";
$areanames{en}->{61363717} = "Bridport";
$areanames{en}->{61363718} = "Ringarooma";
$areanames{en}->{61363719} = "Ringarooma";
$areanames{en}->{6136372} = "St\ Marys";
$areanames{en}->{6136373} = "Pyengana";
$areanames{en}->{6136374} = "Fingal";
$areanames{en}->{6136375} = "Bicheno";
$areanames{en}->{6136376} = "St\ Helens";
$areanames{en}->{6136377} = "Mathinna";
$areanames{en}->{61363780} = "Deloraine";
$areanames{en}->{61363781} = "Deloraine";
$areanames{en}->{61363782} = "Moltema";
$areanames{en}->{61363783} = "Moltema";
$areanames{en}->{61363784} = "Beaconsfield";
$areanames{en}->{61363785} = "Beaconsfield";
$areanames{en}->{61363786} = "Campbell\ Town";
$areanames{en}->{61363787} = "Campbell\ Town";
$areanames{en}->{61363788} = "Evandale";
$areanames{en}->{61363789} = "Evandale";
$areanames{en}->{61363790} = "Exeter";
$areanames{en}->{61363791} = "Exeter";
$areanames{en}->{61363792} = "Glengarry";
$areanames{en}->{61363793} = "Glengarry";
$areanames{en}->{61363794} = "Launceston";
$areanames{en}->{61363795} = "Launceston";
$areanames{en}->{61363796} = "Lilydale";
$areanames{en}->{61363797} = "Lilydale";
$areanames{en}->{61363798} = "Targa";
$areanames{en}->{61363799} = "Targa";
$areanames{en}->{6136380} = "George\ Town";
$areanames{en}->{61363806} = "Launceston";
$areanames{en}->{61363807} = "Launceston";
$areanames{en}->{61363808} = "Launceston";
$areanames{en}->{61363809} = "Launceston";
$areanames{en}->{6136381} = "Campbell\ Town";
$areanames{en}->{6136382} = "George\ Town";
$areanames{en}->{6136383} = "Beaconsfield";
$areanames{en}->{6136384} = "Avoca";
$areanames{en}->{6136385} = "Rossarden";
$areanames{en}->{61363860} = "Emita";
$areanames{en}->{61363861} = "Emita";
$areanames{en}->{61363862} = "Pyengana";
$areanames{en}->{61363863} = "Pyengana";
$areanames{en}->{61363864} = "St\ Helens";
$areanames{en}->{61363865} = "St\ Helens";
$areanames{en}->{61363866} = "St\ Marys";
$areanames{en}->{61363867} = "St\ Marys";
$areanames{en}->{61363868} = "Waterhouse";
$areanames{en}->{61363869} = "Waterhouse";
$areanames{en}->{61363870} = "Whitemark";
$areanames{en}->{61363871} = "Whitemark";
$areanames{en}->{61363872} = "Winnaleah";
$areanames{en}->{61363873} = "Winnaleah";
$areanames{en}->{61363874} = "Targa";
$areanames{en}->{61363875} = "St\ Marys";
$areanames{en}->{61363876} = "Beaconsfield";
$areanames{en}->{61363877} = "Launceston";
$areanames{en}->{61363878} = "Bicheno";
$areanames{en}->{61363879} = "Deloraine";
$areanames{en}->{61363880} = "Mole\ Creek";
$areanames{en}->{61363881} = "Launceston";
$areanames{en}->{61363882} = "Pyengana";
$areanames{en}->{61363883} = "Avoca";
$areanames{en}->{61363884} = "Campbell\ Town";
$areanames{en}->{61363885} = "Bridport";
$areanames{en}->{61363886} = "Blessington";
$areanames{en}->{61363887} = "Glengarry";
$areanames{en}->{61363888} = "Launceston";
$areanames{en}->{61363889} = "Launceston";
$areanames{en}->{61363890} = "Scottsdale";
$areanames{en}->{61363891} = "Scottsdale";
$areanames{en}->{61363892} = "Fingal";
$areanames{en}->{61363893} = "Fingal";
$areanames{en}->{61363894} = "Mathinna";
$areanames{en}->{61363895} = "Mathinna";
$areanames{en}->{61363896} = "Mole\ Creek";
$areanames{en}->{61363897} = "Mole\ Creek";
$areanames{en}->{61363898} = "Bicheno";
$areanames{en}->{61363899} = "Bicheno";
$areanames{en}->{6136390} = "Blessington";
$areanames{en}->{6136391} = "Evandale";
$areanames{en}->{61363911} = "Longford";
$areanames{en}->{61363912} = "Longford";
$areanames{en}->{61363913} = "Longford";
$areanames{en}->{61363914} = "Longford";
$areanames{en}->{6136392} = "Westbury";
$areanames{en}->{6136393} = "Westbury";
$areanames{en}->{6136394} = "Exeter";
$areanames{en}->{6136395} = "Lilydale";
$areanames{en}->{6136396} = "Glengarry";
$areanames{en}->{6136397} = "Longford";
$areanames{en}->{6136398} = "Evandale";
$areanames{en}->{6136399} = "Targa";
$areanames{en}->{61364000} = "Burnie";
$areanames{en}->{61364001} = "Burnie";
$areanames{en}->{61364002} = "Burnie";
$areanames{en}->{61364003} = "Currie";
$areanames{en}->{61364004} = "Currie";
$areanames{en}->{61364005} = "Currie";
$areanames{en}->{61364006} = "Devonport";
$areanames{en}->{61364007} = "Devonport";
$areanames{en}->{61364008} = "Devonport";
$areanames{en}->{61364009} = "Stanley";
$areanames{en}->{61364010} = "Marrawah";
$areanames{en}->{61364011} = "Marrawah";
$areanames{en}->{61364012} = "Marrawah";
$areanames{en}->{61364013} = "Queenstown";
$areanames{en}->{61364014} = "Queenstown";
$areanames{en}->{61364015} = "Queenstown";
$areanames{en}->{61364016} = "Rosebery";
$areanames{en}->{61364017} = "Rosebery";
$areanames{en}->{61364018} = "Rosebery";
$areanames{en}->{61364019} = "Smithton";
$areanames{en}->{61364020} = "Savage\ River";
$areanames{en}->{61364021} = "Savage\ River";
$areanames{en}->{61364022} = "Savage\ River";
$areanames{en}->{61364023} = "Sheffield";
$areanames{en}->{61364024} = "Sheffield";
$areanames{en}->{61364025} = "Sheffield";
$areanames{en}->{61364026} = "Smithton";
$areanames{en}->{61364027} = "Smithton";
$areanames{en}->{61364028} = "Smithton";
$areanames{en}->{61364029} = "Marrawah";
$areanames{en}->{61364030} = "Stanley";
$areanames{en}->{61364031} = "Stanley";
$areanames{en}->{61364032} = "Stanley";
$areanames{en}->{61364033} = "Ulverstone";
$areanames{en}->{61364034} = "Ulverstone";
$areanames{en}->{61364035} = "Ulverstone";
$areanames{en}->{61364036} = "Waratah";
$areanames{en}->{61364037} = "Waratah";
$areanames{en}->{61364038} = "Waratah";
$areanames{en}->{61364039} = "Rosebery";
$areanames{en}->{61364040} = "Wynyard";
$areanames{en}->{61364041} = "Wynyard";
$areanames{en}->{61364042} = "Wynyard";
$areanames{en}->{61364043} = "Yambacoona";
$areanames{en}->{61364044} = "Yambacoona";
$areanames{en}->{61364045} = "Yambacoona";
$areanames{en}->{61364046} = "Yolla";
$areanames{en}->{61364047} = "Yolla";
$areanames{en}->{61364048} = "Yolla";
$areanames{en}->{61364049} = "Queenstown";
$areanames{en}->{61364050} = "Burnie";
$areanames{en}->{61364051} = "Savage\ River";
$areanames{en}->{61364052} = "Waratah";
$areanames{en}->{61364053} = "Wynyard";
$areanames{en}->{61364054} = "Yolla";
$areanames{en}->{61364055} = "Devonport";
$areanames{en}->{61364056} = "Sheffield";
$areanames{en}->{61364057} = "Ulverstone";
$areanames{en}->{61364058} = "Currie";
$areanames{en}->{61364059} = "Yambacoona";
$areanames{en}->{61364060} = "Burnie";
$areanames{en}->{61364061} = "Savage\ River";
$areanames{en}->{61364062} = "Waratah";
$areanames{en}->{61364063} = "Wynyard";
$areanames{en}->{61364064} = "Yolla";
$areanames{en}->{61364065} = "Devonport";
$areanames{en}->{61364066} = "Sheffield";
$areanames{en}->{61364067} = "Ulverstone";
$areanames{en}->{61364068} = "Currie";
$areanames{en}->{61364069} = "Yambacoona";
$areanames{en}->{61364070} = "Rosebery";
$areanames{en}->{61364071} = "Queenstown";
$areanames{en}->{61364072} = "Stanley";
$areanames{en}->{61364073} = "Smithton";
$areanames{en}->{61364074} = "Marrawah";
$areanames{en}->{61364075} = "Burnie";
$areanames{en}->{61364076} = "Savage\ River";
$areanames{en}->{61364077} = "Waratah";
$areanames{en}->{61364078} = "Wynyard";
$areanames{en}->{61364079} = "Yolla";
$areanames{en}->{61364080} = "Burnie";
$areanames{en}->{61364081} = "Savage\ River";
$areanames{en}->{61364082} = "Waratah";
$areanames{en}->{61364083} = "Wynyard";
$areanames{en}->{61364084} = "Yolla";
$areanames{en}->{61364085} = "Devonport";
$areanames{en}->{61364086} = "Sheffield";
$areanames{en}->{61364087} = "Ulverstone";
$areanames{en}->{61364088} = "Currie";
$areanames{en}->{61364089} = "Yambacoona";
$areanames{en}->{61364090} = "Gordon";
$areanames{en}->{61364091} = "Queenstown";
$areanames{en}->{61364092} = "Rosebery";
$areanames{en}->{61364093} = "Marrawah";
$areanames{en}->{61364094} = "Smithton";
$areanames{en}->{61364095} = "Stanley";
$areanames{en}->{61364096} = "Burnie";
$areanames{en}->{61364097} = "Savage\ River";
$areanames{en}->{61364098} = "Waratah";
$areanames{en}->{61364099} = "Wynyard";
$areanames{en}->{61364100} = "Devonport";
$areanames{en}->{61364101} = "Sheffield";
$areanames{en}->{61364102} = "Ulverstone";
$areanames{en}->{61364103} = "Currie";
$areanames{en}->{61364104} = "Yambacoona";
$areanames{en}->{61364105} = "Gordon";
$areanames{en}->{61364106} = "Queenstown";
$areanames{en}->{61364107} = "Rosebery";
$areanames{en}->{61364108} = "Marrawah";
$areanames{en}->{61364109} = "Smithton";
$areanames{en}->{61364110} = "Stanley";
$areanames{en}->{61364111} = "Burnie";
$areanames{en}->{61364112} = "Savage\ River";
$areanames{en}->{61364113} = "Waratah";
$areanames{en}->{61364114} = "Wynyard";
$areanames{en}->{61364115} = "Yolla";
$areanames{en}->{61364116} = "Devonport";
$areanames{en}->{61364117} = "Sheffield";
$areanames{en}->{61364118} = "Ulverstone";
$areanames{en}->{61364119} = "Currie";
$areanames{en}->{61364120} = "Yambacoona";
$areanames{en}->{61364121} = "Queenstown";
$areanames{en}->{61364122} = "Rosebery";
$areanames{en}->{61364123} = "Marrawah";
$areanames{en}->{61364124} = "Smithton";
$areanames{en}->{61364125} = "Stanley";
$areanames{en}->{61364126} = "Yolla";
$areanames{en}->{61364127} = "Devonport";
$areanames{en}->{61364128} = "Sheffield";
$areanames{en}->{61364129} = "Ulverstone";
$areanames{en}->{61364130} = "Currie";
$areanames{en}->{61364131} = "Yambacoona";
$areanames{en}->{61364132} = "Gordon";
$areanames{en}->{61364133} = "Queenstown";
$areanames{en}->{61364134} = "Rosebery";
$areanames{en}->{61364135} = "Marrawah";
$areanames{en}->{61364136} = "Smithton";
$areanames{en}->{61364137} = "Stanley";
$areanames{en}->{61364138} = "Gordon";
$areanames{en}->{61364139} = "Gordon";
$areanames{en}->{61364140} = "Burnie";
$areanames{en}->{61364141} = "Savage\ River";
$areanames{en}->{61364142} = "Waratah";
$areanames{en}->{61364143} = "Wynyard";
$areanames{en}->{61364144} = "Yolla";
$areanames{en}->{61364145} = "Devonport";
$areanames{en}->{61364146} = "Sheffield";
$areanames{en}->{61364147} = "Ulverstone";
$areanames{en}->{61364148} = "Currie";
$areanames{en}->{61364149} = "Yambacoona";
$areanames{en}->{61364150} = "Gordon";
$areanames{en}->{61364151} = "Queenstown";
$areanames{en}->{61364152} = "Rosebery";
$areanames{en}->{61364153} = "Marrawah";
$areanames{en}->{61364154} = "Smithton";
$areanames{en}->{61364155} = "Stanley";
$areanames{en}->{61364156} = "Burnie";
$areanames{en}->{61364157} = "Devonport";
$areanames{en}->{61364158} = "Marrawah";
$areanames{en}->{61364159} = "Marrawah";
$areanames{en}->{61364160} = "Smithton";
$areanames{en}->{61364161} = "Smithton";
$areanames{en}->{61364162} = "Yolla";
$areanames{en}->{61364163} = "Yolla";
$areanames{en}->{61364164} = "Burnie";
$areanames{en}->{61364165} = "Burnie";
$areanames{en}->{61364166} = "Savage\ River";
$areanames{en}->{61364167} = "Savage\ River";
$areanames{en}->{61364168} = "Sheffield";
$areanames{en}->{61364169} = "Sheffield";
$areanames{en}->{61364170} = "Burnie";
$areanames{en}->{61364171} = "Ulverstone";
$areanames{en}->{61364172} = "Gordon";
$areanames{en}->{61364173} = "Devonport";
$areanames{en}->{61364174} = "Queenstown";
$areanames{en}->{61364175} = "Queenstown";
$areanames{en}->{61364176} = "Ulverstone";
$areanames{en}->{61364177} = "Burnie";
$areanames{en}->{61364178} = "Marrawah";
$areanames{en}->{61364179} = "Savage\ River";
$areanames{en}->{61364180} = "Waratah";
$areanames{en}->{61364181} = "Rosebery";
$areanames{en}->{61364182} = "Yolla";
$areanames{en}->{61364183} = "Savage\ River";
$areanames{en}->{61364184} = "Wynyard";
$areanames{en}->{61364185} = "Currie";
$areanames{en}->{61364186} = "Devonport";
$areanames{en}->{61364187} = "Yolla";
$areanames{en}->{61364188} = "Currie";
$areanames{en}->{61364189} = "Wynyard";
$areanames{en}->{61364190} = "Yolla";
$areanames{en}->{61364191} = "Smithton";
$areanames{en}->{61364192} = "Waratah";
$areanames{en}->{61364193} = "Stanley";
$areanames{en}->{61364194} = "Ulverstone";
$areanames{en}->{61364195} = "Savage\ River";
$areanames{en}->{61364196} = "Wynyard";
$areanames{en}->{61364197} = "Burnie";
$areanames{en}->{61364198} = "Gordon";
$areanames{en}->{61364199} = "Devonport";
$areanames{en}->{613642} = "Devonport";
$areanames{en}->{6136425} = "Ulverstone";
$areanames{en}->{6136429} = "Ulverstone";
$areanames{en}->{613643} = "Burnie";
$areanames{en}->{6136438} = "Yolla";
$areanames{en}->{6136439} = "Waratah";
$areanames{en}->{6136440} = "Burnie";
$areanames{en}->{613644100} = "Burnie";
$areanames{en}->{613644101} = "Burnie";
$areanames{en}->{61364411} = "Savage\ River";
$areanames{en}->{61364412} = "Waratah";
$areanames{en}->{61364413} = "Wynyard";
$areanames{en}->{61364414} = "Yolla";
$areanames{en}->{61364415} = "Devonport";
$areanames{en}->{61364416} = "Sheffield";
$areanames{en}->{61364417} = "Ulverstone";
$areanames{en}->{61364418} = "Currie";
$areanames{en}->{61364419} = "Yambacoona";
$areanames{en}->{6136442} = "Wynyard";
$areanames{en}->{6136443} = "Wynyard";
$areanames{en}->{61364440} = "Queenstown";
$areanames{en}->{61364441} = "Rosebery";
$areanames{en}->{61364442} = "Marrawah";
$areanames{en}->{61364443} = "Smithton";
$areanames{en}->{61364444} = "Stanley";
$areanames{en}->{61364445} = "Queenstown";
$areanames{en}->{61364446} = "Queenstown";
$areanames{en}->{61364447} = "Rosebery";
$areanames{en}->{61364448} = "Rosebery";
$areanames{en}->{61364449} = "Gordon";
$areanames{en}->{6136445} = "Wynyard";
$areanames{en}->{6136446} = "Savage\ River";
$areanames{en}->{61364470} = "Sheffield";
$areanames{en}->{61364471} = "Devonport";
$areanames{en}->{61364472} = "Yambacoona";
$areanames{en}->{61364473} = "Sheffield";
$areanames{en}->{61364474} = "Marrawah";
$areanames{en}->{61364475} = "Burnie";
$areanames{en}->{61364476} = "Rosebery";
$areanames{en}->{61364477} = "Smithton";
$areanames{en}->{61364478} = "Yambacoona";
$areanames{en}->{61364479} = "Ulverstone";
$areanames{en}->{61364480} = "Currie";
$areanames{en}->{61364481} = "Sheffield";
$areanames{en}->{61364482} = "Waratah";
$areanames{en}->{61364483} = "Stanley";
$areanames{en}->{61364484} = "Smithton";
$areanames{en}->{61364485} = "Wynyard";
$areanames{en}->{61364486} = "Ulverstone";
$areanames{en}->{61364487} = "Ulverstone";
$areanames{en}->{61364488} = "Gordon";
$areanames{en}->{61364489} = "Yambacoona";
$areanames{en}->{61364490} = "Gordon";
$areanames{en}->{61364491} = "Queenstown";
$areanames{en}->{61364492} = "Savage\ River";
$areanames{en}->{61364493} = "Wynyard";
$areanames{en}->{61364494} = "Devonport";
$areanames{en}->{61364495} = "Yolla";
$areanames{en}->{61364496} = "Currie";
$areanames{en}->{61364497} = "Marrawah";
$areanames{en}->{61364498} = "Burnie";
$areanames{en}->{61364499} = "Queenstown";
$areanames{en}->{61364500} = "Rosebery";
$areanames{en}->{61364501} = "Rosebery";
$areanames{en}->{61364502} = "Smithton";
$areanames{en}->{61364503} = "Yambacoona";
$areanames{en}->{61364504} = "Sheffield";
$areanames{en}->{61364505} = "Waratah";
$areanames{en}->{61364506} = "Stanley";
$areanames{en}->{61364507} = "Smithton";
$areanames{en}->{61364508} = "Ulverstone";
$areanames{en}->{61364509} = "Marrawah";
$areanames{en}->{61364510} = "Smithton";
$areanames{en}->{61364511} = "Gordon";
$areanames{en}->{61364512} = "Queenstown";
$areanames{en}->{61364513} = "Savage\ River";
$areanames{en}->{61364514} = "Wynyard";
$areanames{en}->{61364515} = "Devonport";
$areanames{en}->{61364516} = "Yolla";
$areanames{en}->{61364517} = "Currie";
$areanames{en}->{61364518} = "Marrawah";
$areanames{en}->{61364519} = "Stanley";
$areanames{en}->{6136452} = "Smithton";
$areanames{en}->{61364530} = "Burnie";
$areanames{en}->{61364531} = "Currie";
$areanames{en}->{61364532} = "Devonport";
$areanames{en}->{61364533} = "Gordon";
$areanames{en}->{61364534} = "Marrawah";
$areanames{en}->{61364535} = "Queenstown";
$areanames{en}->{61364536} = "Rosebery";
$areanames{en}->{61364537} = "Savage\ River";
$areanames{en}->{61364538} = "Sheffield";
$areanames{en}->{61364539} = "Smithton";
$areanames{en}->{61364540} = "Devonport";
$areanames{en}->{61364541} = "Burnie";
$areanames{en}->{61364542} = "Rosebery";
$areanames{en}->{61364543} = "Burnie";
$areanames{en}->{61364544} = "Yambacoona";
$areanames{en}->{61364545} = "Sheffield";
$areanames{en}->{61364546} = "Waratah";
$areanames{en}->{61364547} = "Stanley";
$areanames{en}->{61364548} = "Currie";
$areanames{en}->{61364549} = "Devonport";
$areanames{en}->{61364550} = "Gordon";
$areanames{en}->{61364551} = "Marrawah";
$areanames{en}->{61364552} = "Queenstown";
$areanames{en}->{61364553} = "Rosebery";
$areanames{en}->{61364554} = "Savage\ River";
$areanames{en}->{61364555} = "Sheffield";
$areanames{en}->{61364556} = "Smithton";
$areanames{en}->{61364557} = "Stanley";
$areanames{en}->{61364558} = "Ulverstone";
$areanames{en}->{61364559} = "Waratah";
$areanames{en}->{6136456} = "Smithton";
$areanames{en}->{6136457} = "Marrawah";
$areanames{en}->{6136458} = "Stanley";
$areanames{en}->{61364590} = "Devonport";
$areanames{en}->{61364591} = "Devonport";
$areanames{en}->{61364592} = "Devonport";
$areanames{en}->{61364593} = "Wynyard";
$areanames{en}->{61364594} = "Yambacoona";
$areanames{en}->{61364595} = "Yolla";
$areanames{en}->{61364596} = "Burnie";
$areanames{en}->{61364597} = "Currie";
$areanames{en}->{61364598} = "Devonport";
$areanames{en}->{61364599} = "Gordon";
$areanames{en}->{61364600} = "Marrawah";
$areanames{en}->{61364601} = "Queenstown";
$areanames{en}->{61364602} = "Rosebery";
$areanames{en}->{61364603} = "Savage\ River";
$areanames{en}->{61364604} = "Sheffield";
$areanames{en}->{61364605} = "Smithton";
$areanames{en}->{61364606} = "Stanley";
$areanames{en}->{61364607} = "Ulverstone";
$areanames{en}->{61364608} = "Waratah";
$areanames{en}->{61364609} = "Wynyard";
$areanames{en}->{6136461} = "Currie";
$areanames{en}->{6136462} = "Currie";
$areanames{en}->{6136463} = "Yambacoona";
$areanames{en}->{61364640} = "Burnie";
$areanames{en}->{61364641} = "Burnie";
$areanames{en}->{61364642} = "Burnie";
$areanames{en}->{61364643} = "Ulverstone";
$areanames{en}->{61364644} = "Yambacoona";
$areanames{en}->{61364645} = "Yolla";
$areanames{en}->{61364646} = "Stanley";
$areanames{en}->{61364647} = "Ulverstone";
$areanames{en}->{61364648} = "Waratah";
$areanames{en}->{61364649} = "Wynyard";
$areanames{en}->{61364650} = "Yambacoona";
$areanames{en}->{61364651} = "Yolla";
$areanames{en}->{61364652} = "Burnie";
$areanames{en}->{61364653} = "Currie";
$areanames{en}->{61364654} = "Devonport";
$areanames{en}->{61364655} = "Gordon";
$areanames{en}->{61364656} = "Marrawah";
$areanames{en}->{61364657} = "Queenstown";
$areanames{en}->{61364658} = "Rosebery";
$areanames{en}->{61364659} = "Savage\ River";
$areanames{en}->{61364660} = "Sheffield";
$areanames{en}->{61364661} = "Smithton";
$areanames{en}->{61364662} = "Stanley";
$areanames{en}->{61364663} = "Ulverstone";
$areanames{en}->{61364664} = "Waratah";
$areanames{en}->{61364665} = "Wynyard";
$areanames{en}->{61364666} = "Yambacoona";
$areanames{en}->{61364667} = "Yolla";
$areanames{en}->{61364668} = "Burnie";
$areanames{en}->{61364669} = "Currie";
$areanames{en}->{61364670} = "Devonport";
$areanames{en}->{61364671} = "Gordon";
$areanames{en}->{61364672} = "Marrawah";
$areanames{en}->{61364673} = "Queenstown";
$areanames{en}->{61364674} = "Rosebery";
$areanames{en}->{61364675} = "Savage\ River";
$areanames{en}->{61364676} = "Sheffield";
$areanames{en}->{61364677} = "Smithton";
$areanames{en}->{61364678} = "Stanley";
$areanames{en}->{61364679} = "Ulverstone";
$areanames{en}->{61364680} = "Waratah";
$areanames{en}->{61364681} = "Wynyard";
$areanames{en}->{61364682} = "Yambacoona";
$areanames{en}->{61364683} = "Yolla";
$areanames{en}->{61364684} = "Burnie";
$areanames{en}->{61364685} = "Currie";
$areanames{en}->{61364686} = "Devonport";
$areanames{en}->{61364687} = "Gordon";
$areanames{en}->{61364688} = "Marrawah";
$areanames{en}->{61364689} = "Queenstown";
$areanames{en}->{61364690} = "Rosebery";
$areanames{en}->{61364691} = "Savage\ River";
$areanames{en}->{61364692} = "Sheffield";
$areanames{en}->{61364693} = "Smithton";
$areanames{en}->{61364694} = "Stanley";
$areanames{en}->{61364695} = "Ulverstone";
$areanames{en}->{61364696} = "Waratah";
$areanames{en}->{61364697} = "Wynyard";
$areanames{en}->{61364698} = "Yambacoona";
$areanames{en}->{61364699} = "Yolla";
$areanames{en}->{61364700} = "Burnie";
$areanames{en}->{61364701} = "Currie";
$areanames{en}->{61364702} = "Devonport";
$areanames{en}->{61364703} = "Gordon";
$areanames{en}->{61364704} = "Marrawah";
$areanames{en}->{61364705} = "Queenstown";
$areanames{en}->{61364706} = "Rosebery";
$areanames{en}->{61364707} = "Savage\ River";
$areanames{en}->{61364708} = "Sheffield";
$areanames{en}->{61364709} = "Smithton";
$areanames{en}->{6136471} = "Queenstown";
$areanames{en}->{6136472} = "Queenstown";
$areanames{en}->{61364729} = "Gordon";
$areanames{en}->{6136473} = "Rosebery";
$areanames{en}->{61364740} = "Devonport";
$areanames{en}->{61364741} = "Devonport";
$areanames{en}->{61364742} = "Devonport";
$areanames{en}->{61364743} = "Stanley";
$areanames{en}->{61364744} = "Ulverstone";
$areanames{en}->{61364745} = "Waratah";
$areanames{en}->{61364746} = "Wynyard";
$areanames{en}->{61364747} = "Yambacoona";
$areanames{en}->{61364748} = "Yolla";
$areanames{en}->{61364749} = "Waratah";
$areanames{en}->{6136475} = "Gordon";
$areanames{en}->{61364760} = "Devonport";
$areanames{en}->{61364761} = "Devonport";
$areanames{en}->{61364762} = "Stanley";
$areanames{en}->{61364763} = "Stanley";
$areanames{en}->{61364764} = "Wynyard";
$areanames{en}->{61364765} = "Wynyard";
$areanames{en}->{61364766} = "Waratah";
$areanames{en}->{61364767} = "Waratah";
$areanames{en}->{61364768} = "Burnie";
$areanames{en}->{61364769} = "Currie";
$areanames{en}->{61364770} = "Devonport";
$areanames{en}->{61364771} = "Gordon";
$areanames{en}->{61364772} = "Marrawah";
$areanames{en}->{61364773} = "Queenstown";
$areanames{en}->{61364774} = "Rosebery";
$areanames{en}->{61364775} = "Savage\ River";
$areanames{en}->{61364776} = "Sheffield";
$areanames{en}->{61364777} = "Burnie";
$areanames{en}->{61364778} = "Burnie";
$areanames{en}->{61364779} = "Burnie";
$areanames{en}->{61364780} = "Smithton";
$areanames{en}->{61364781} = "Stanley";
$areanames{en}->{61364782} = "Ulverstone";
$areanames{en}->{61364783} = "Waratah";
$areanames{en}->{61364784} = "Devonport";
$areanames{en}->{61364785} = "Devonport";
$areanames{en}->{61364786} = "Devonport";
$areanames{en}->{61364787} = "Burnie";
$areanames{en}->{61364788} = "Burnie";
$areanames{en}->{61364789} = "Smithton";
$areanames{en}->{61364790} = "Wynyard";
$areanames{en}->{61364791} = "Yambacoona";
$areanames{en}->{61364792} = "Yolla";
$areanames{en}->{6136490} = "Ulverstone";
$areanames{en}->{6136491} = "Sheffield";
$areanames{en}->{6136492} = "Sheffield";
$areanames{en}->{61364936} = "Burnie";
$areanames{en}->{61364951} = "Queenstown";
$areanames{en}->{61364952} = "Devonport";
$areanames{en}->{61364953} = "Devonport";
$areanames{en}->{61364954} = "Devonport";
$areanames{en}->{6136496} = "Sheffield";
$areanames{en}->{6136497} = "Sheffield";
$areanames{en}->{6136498} = "Devonport";
$areanames{en}->{61364990} = "Ulverstone";
$areanames{en}->{61364991} = "Ulverstone";
$areanames{en}->{61364992} = "Currie";
$areanames{en}->{61364993} = "Currie";
$areanames{en}->{61364994} = "Yambacoona";
$areanames{en}->{61364995} = "Yambacoona";
$areanames{en}->{61364996} = "Burnie";
$areanames{en}->{61364997} = "Burnie";
$areanames{en}->{61364998} = "Burnie";
$areanames{en}->{61364999} = "Burnie";
$areanames{en}->{6136700} = "Launceston";
$areanames{en}->{61367010} = "Moltema";
$areanames{en}->{61367011} = "St\ Helens";
$areanames{en}->{61367012} = "Deloraine";
$areanames{en}->{61367013} = "Deloraine";
$areanames{en}->{61367014} = "Scottsdale";
$areanames{en}->{61367015} = "Longford";
$areanames{en}->{61367016} = "Whitemark";
$areanames{en}->{61367017} = "Lilydale";
$areanames{en}->{61367018} = "Ringarooma";
$areanames{en}->{61367019} = "Emita";
$areanames{en}->{61367020} = "Whitemark";
$areanames{en}->{61367021} = "Moltema";
$areanames{en}->{61367022} = "Winnaleah";
$areanames{en}->{61367023} = "Beaconsfield";
$areanames{en}->{61367024} = "Targa";
$areanames{en}->{61367025} = "Mathinna";
$areanames{en}->{61367026} = "George\ Town";
$areanames{en}->{61367027} = "Emita";
$areanames{en}->{61367028} = "Fingal";
$areanames{en}->{61367029} = "Avoca";
$areanames{en}->{61367030} = "Beaconsfield";
$areanames{en}->{61367031} = "Gladstone";
$areanames{en}->{61367032} = "Bridport";
$areanames{en}->{61367033} = "Blessington";
$areanames{en}->{61367034} = "Mathinna";
$areanames{en}->{61367035} = "Exeter";
$areanames{en}->{61367036} = "Waterhouse";
$areanames{en}->{61367037} = "Rossarden";
$areanames{en}->{61367038} = "Evandale";
$areanames{en}->{61367039} = "Blessington";
$areanames{en}->{61367040} = "Campbell\ Town";
$areanames{en}->{61367041} = "Westbury";
$areanames{en}->{61367042} = "Mole\ Creek";
$areanames{en}->{61367043} = "Scottsdale";
$areanames{en}->{61367044} = "St\ Marys";
$areanames{en}->{61367045} = "Exeter";
$areanames{en}->{61367046} = "Bicheno";
$areanames{en}->{61367047} = "Longford";
$areanames{en}->{61367048} = "Pyengana";
$areanames{en}->{61367049} = "Evandale";
$areanames{en}->{61367050} = "Exeter";
$areanames{en}->{61367051} = "Whitemark";
$areanames{en}->{61367052} = "Avoca";
$areanames{en}->{61367053} = "Ringarooma";
$areanames{en}->{61367054} = "Campbell\ Town";
$areanames{en}->{61367055} = "Waterhouse";
$areanames{en}->{61367056} = "Moltema";
$areanames{en}->{61367057} = "Launceston";
$areanames{en}->{61367058} = "Winnaleah";
$areanames{en}->{61367059} = "George\ Town";
$areanames{en}->{61367060} = "Glengarry";
$areanames{en}->{61367061} = "Rossarden";
$areanames{en}->{61367062} = "Evandale";
$areanames{en}->{61367063} = "Glengarry";
$areanames{en}->{61367064} = "Beaconsfield";
$areanames{en}->{61367065} = "Lilydale";
$areanames{en}->{61367066} = "Westbury";
$areanames{en}->{61367067} = "George\ Town";
$areanames{en}->{61367068} = "Emita";
$areanames{en}->{61367069} = "Launceston";
$areanames{en}->{61367070} = "Lilydale";
$areanames{en}->{61367071} = "Fingal";
$areanames{en}->{61367072} = "Mole\ Creek";
$areanames{en}->{61367073} = "Gladstone";
$areanames{en}->{61367074} = "St\ Helens";
$areanames{en}->{61367075} = "Longford";
$areanames{en}->{61367076} = "George\ Town";
$areanames{en}->{61367077} = "Bridport";
$areanames{en}->{61367078} = "Blessington";
$areanames{en}->{61367079} = "Longford";
$areanames{en}->{61367080} = "Rossarden";
$areanames{en}->{61367081} = "Deloraine";
$areanames{en}->{61367082} = "Targa";
$areanames{en}->{61367083} = "Mathinna";
$areanames{en}->{61367084} = "Scottsdale";
$areanames{en}->{61367085} = "St\ Marys";
$areanames{en}->{61367086} = "Exeter";
$areanames{en}->{61367087} = "Bicheno";
$areanames{en}->{61367088} = "Longford";
$areanames{en}->{61367089} = "Targa";
$areanames{en}->{61367090} = "Westbury";
$areanames{en}->{61367091} = "Pyengana";
$areanames{en}->{61367092} = "Whitemark";
$areanames{en}->{61367093} = "Avoca";
$areanames{en}->{61367094} = "Ringarooma";
$areanames{en}->{61367095} = "Campbell\ Town";
$areanames{en}->{61367096} = "Waterhouse";
$areanames{en}->{61367097} = "Moltema";
$areanames{en}->{61367098} = "Launceston";
$areanames{en}->{61367099} = "Bridport";
$areanames{en}->{61367100} = "Gladstone";
$areanames{en}->{61367101} = "Winnaleah";
$areanames{en}->{61367102} = "Rossarden";
$areanames{en}->{61367103} = "Evandale";
$areanames{en}->{61367104} = "Glengarry";
$areanames{en}->{61367105} = "Beaconsfield";
$areanames{en}->{61367106} = "Lilydale";
$areanames{en}->{61367107} = "Westbury";
$areanames{en}->{61367108} = "George\ Town";
$areanames{en}->{61367109} = "Ringarooma";
$areanames{en}->{61367110} = "Scottsdale";
$areanames{en}->{61367111} = "Launceston";
$areanames{en}->{61367112} = "Launceston";
$areanames{en}->{61367113} = "Launceston";
$areanames{en}->{61367114} = "Emita";
$areanames{en}->{61367115} = "Fingal";
$areanames{en}->{61367116} = "Mole\ Creek";
$areanames{en}->{61367117} = "Gladstone";
$areanames{en}->{61367118} = "St\ Helens";
$areanames{en}->{61367119} = "Waterhouse";
$areanames{en}->{61367120} = "Winnaleah";
$areanames{en}->{61367121} = "Bridport";
$areanames{en}->{61367122} = "Blessington";
$areanames{en}->{61367123} = "Deloraine";
$areanames{en}->{61367124} = "Targa";
$areanames{en}->{61367125} = "Mathinna";
$areanames{en}->{61367126} = "Scottsdale";
$areanames{en}->{61367127} = "St\ Marys";
$areanames{en}->{61367128} = "Exeter";
$areanames{en}->{61367129} = "Bicheno";
$areanames{en}->{61367130} = "Fingal";
$areanames{en}->{61367131} = "Bicheno";
$areanames{en}->{61367132} = "Longford";
$areanames{en}->{61367133} = "Pyengana";
$areanames{en}->{61367134} = "Whitemark";
$areanames{en}->{61367135} = "Avoca";
$areanames{en}->{61367136} = "Ringarooma";
$areanames{en}->{61367137} = "Campbell\ Town";
$areanames{en}->{61367138} = "Waterhouse";
$areanames{en}->{61367139} = "Mathinna";
$areanames{en}->{61367140} = "Pyengana";
$areanames{en}->{61367141} = "Moltema";
$areanames{en}->{61367142} = "Winnaleah";
$areanames{en}->{61367143} = "Rossarden";
$areanames{en}->{61367144} = "Evandale";
$areanames{en}->{61367145} = "Glengarry";
$areanames{en}->{61367146} = "Beaconsfield";
$areanames{en}->{61367147} = "Lilydale";
$areanames{en}->{61367148} = "Westbury";
$areanames{en}->{61367149} = "St\ Helens";
$areanames{en}->{61367150} = "St\ Marys";
$areanames{en}->{61367151} = "George\ Town";
$areanames{en}->{61367152} = "Emita";
$areanames{en}->{61367153} = "Fingal";
$areanames{en}->{61367154} = "Mole\ Creek";
$areanames{en}->{61367155} = "Gladstone";
$areanames{en}->{61367156} = "St\ Helens";
$areanames{en}->{61367157} = "Launceston";
$areanames{en}->{61367158} = "Launceston";
$areanames{en}->{61367159} = "Avoca";
$areanames{en}->{61367160} = "Beaconsfield";
$areanames{en}->{61367161} = "Bicheno";
$areanames{en}->{61367162} = "Blessington";
$areanames{en}->{61367163} = "Bridport";
$areanames{en}->{61367164} = "Campbell\ Town";
$areanames{en}->{61367165} = "Deloraine";
$areanames{en}->{61367166} = "Emita";
$areanames{en}->{61367167} = "Evandale";
$areanames{en}->{61367168} = "Exeter";
$areanames{en}->{61367169} = "Fingal";
$areanames{en}->{61367170} = "George\ Town";
$areanames{en}->{61367171} = "Gladstone";
$areanames{en}->{61367172} = "Glengarry";
$areanames{en}->{61367173} = "Launceston";
$areanames{en}->{61367174} = "Lilydale";
$areanames{en}->{61367175} = "Longford";
$areanames{en}->{61367176} = "Mathinna";
$areanames{en}->{61367177} = "Mole\ Creek";
$areanames{en}->{61367178} = "Moltema";
$areanames{en}->{61367179} = "Pyengana";
$areanames{en}->{61367180} = "Ringarooma";
$areanames{en}->{61367181} = "Rossarden";
$areanames{en}->{61367182} = "Scottsdale";
$areanames{en}->{61367183} = "St\ Helens";
$areanames{en}->{61367184} = "St\ Marys";
$areanames{en}->{61367185} = "Targa";
$areanames{en}->{61367186} = "Waterhouse";
$areanames{en}->{61367187} = "Westbury";
$areanames{en}->{61367188} = "Whitemark";
$areanames{en}->{61367189} = "Winnaleah";
$areanames{en}->{61367190} = "Avoca";
$areanames{en}->{61367191} = "Beaconsfield";
$areanames{en}->{61367192} = "Bicheno";
$areanames{en}->{61367193} = "Blessington";
$areanames{en}->{61367194} = "Bridport";
$areanames{en}->{61367195} = "Campbell\ Town";
$areanames{en}->{61367196} = "Deloraine";
$areanames{en}->{61367197} = "Emita";
$areanames{en}->{61367198} = "Evandale";
$areanames{en}->{61367199} = "Exeter";
$areanames{en}->{61367200} = "Fingal";
$areanames{en}->{61367201} = "George\ Town";
$areanames{en}->{61367202} = "Gladstone";
$areanames{en}->{61367203} = "Glengarry";
$areanames{en}->{61367204} = "Launceston";
$areanames{en}->{61367205} = "Lilydale";
$areanames{en}->{61367206} = "Longford";
$areanames{en}->{61367207} = "Mathinna";
$areanames{en}->{61367208} = "Mole\ Creek";
$areanames{en}->{61367209} = "Moltema";
$areanames{en}->{61367210} = "Pyengana";
$areanames{en}->{61367211} = "Ringarooma";
$areanames{en}->{61367212} = "Rossarden";
$areanames{en}->{61367213} = "Scottsdale";
$areanames{en}->{61367214} = "St\ Helens";
$areanames{en}->{61367215} = "St\ Marys";
$areanames{en}->{61367216} = "Targa";
$areanames{en}->{61367217} = "Waterhouse";
$areanames{en}->{61367218} = "Westbury";
$areanames{en}->{61367219} = "Whitemark";
$areanames{en}->{61367220} = "Winnaleah";
$areanames{en}->{61367221} = "Fingal";
$areanames{en}->{61367222} = "George\ Town";
$areanames{en}->{61367223} = "Gladstone";
$areanames{en}->{61367224} = "Glengarry";
$areanames{en}->{61367225} = "Launceston";
$areanames{en}->{61367226} = "Lilydale";
$areanames{en}->{61367227} = "Longford";
$areanames{en}->{61367228} = "Mathinna";
$areanames{en}->{61367229} = "Mole\ Creek";
$areanames{en}->{61367230} = "Moltema";
$areanames{en}->{61367231} = "Pyengana";
$areanames{en}->{61367232} = "Ringarooma";
$areanames{en}->{61367233} = "Rossarden";
$areanames{en}->{61367234} = "Scottsdale";
$areanames{en}->{61367235} = "St\ Helens";
$areanames{en}->{61367236} = "St\ Marys";
$areanames{en}->{61367237} = "Targa";
$areanames{en}->{61367238} = "Waterhouse";
$areanames{en}->{61367239} = "Westbury";
$areanames{en}->{6136724} = "Launceston";
$areanames{en}->{61367240} = "Whitemark";
$areanames{en}->{61367241} = "Winnaleah";
$areanames{en}->{6136725} = "Launceston";
$areanames{en}->{61367260} = "Launceston";
$areanames{en}->{61367261} = "Launceston";
$areanames{en}->{61367262} = "Scottsdale";
$areanames{en}->{61367263} = "Scottsdale";
$areanames{en}->{61367264} = "Scottsdale";
$areanames{en}->{61367265} = "Avoca";
$areanames{en}->{61367266} = "Beaconsfield";
$areanames{en}->{61367267} = "Bicheno";
$areanames{en}->{61367268} = "Blessington";
$areanames{en}->{61367269} = "Bridport";
$areanames{en}->{61367270} = "Campbell\ Town";
$areanames{en}->{61367271} = "Deloraine";
$areanames{en}->{61367272} = "Emita";
$areanames{en}->{61367273} = "Evandale";
$areanames{en}->{61367274} = "Exeter";
$areanames{en}->{61367275} = "Fingal";
$areanames{en}->{61367276} = "George\ Town";
$areanames{en}->{61367277} = "Gladstone";
$areanames{en}->{61367278} = "Glengarry";
$areanames{en}->{61367279} = "Launceston";
$areanames{en}->{61367280} = "Lilydale";
$areanames{en}->{61367281} = "Longford";
$areanames{en}->{61367282} = "Mathinna";
$areanames{en}->{61367283} = "Mole\ Creek";
$areanames{en}->{61367284} = "Moltema";
$areanames{en}->{61367285} = "Pyengana";
$areanames{en}->{61367286} = "Ringarooma";
$areanames{en}->{61367287} = "Rossarden";
$areanames{en}->{61367288} = "Scottsdale";
$areanames{en}->{61367289} = "St\ Helens";
$areanames{en}->{61367290} = "St\ Marys";
$areanames{en}->{61367291} = "Targa";
$areanames{en}->{61367292} = "Waterhouse";
$areanames{en}->{61367293} = "Avoca";
$areanames{en}->{61367294} = "Beaconsfield";
$areanames{en}->{61367295} = "Bicheno";
$areanames{en}->{61367296} = "Blessington";
$areanames{en}->{61367297} = "Bridport";
$areanames{en}->{61367298} = "Campbell\ Town";
$areanames{en}->{61367299} = "Deloraine";
$areanames{en}->{61367300} = "Emita";
$areanames{en}->{61367301} = "Evandale";
$areanames{en}->{61367302} = "Exeter";
$areanames{en}->{61367303} = "Fingal";
$areanames{en}->{61367304} = "George\ Town";
$areanames{en}->{61367305} = "Gladstone";
$areanames{en}->{61367306} = "Glengarry";
$areanames{en}->{61367307} = "Launceston";
$areanames{en}->{61367308} = "Lilydale";
$areanames{en}->{61367309} = "Longford";
$areanames{en}->{61367310} = "Mathinna";
$areanames{en}->{61367311} = "Mole\ Creek";
$areanames{en}->{61367312} = "Moltema";
$areanames{en}->{61367313} = "Pyengana";
$areanames{en}->{61367314} = "Ringarooma";
$areanames{en}->{61367315} = "Rossarden";
$areanames{en}->{61367316} = "Scottsdale";
$areanames{en}->{61367317} = "St\ Helens";
$areanames{en}->{61367318} = "St\ Marys";
$areanames{en}->{61367319} = "Targa";
$areanames{en}->{61367320} = "Waterhouse";
$areanames{en}->{61367321} = "Westbury";
$areanames{en}->{61367322} = "Whitemark";
$areanames{en}->{61367323} = "Winnaleah";
$areanames{en}->{61367324} = "Launceston";
$areanames{en}->{61367325} = "Launceston";
$areanames{en}->{61367326} = "Launceston";
$areanames{en}->{61367327} = "Launceston";
$areanames{en}->{61367328} = "Westbury";
$areanames{en}->{61367329} = "Whitemark";
$areanames{en}->{61367330} = "Winnaleah";
$areanames{en}->{61367331} = "Avoca";
$areanames{en}->{61367332} = "Beaconsfield";
$areanames{en}->{61367333} = "Bicheno";
$areanames{en}->{61367334} = "Blessington";
$areanames{en}->{61367335} = "Bridport";
$areanames{en}->{61367336} = "Campbell\ Town";
$areanames{en}->{61367337} = "Deloraine";
$areanames{en}->{61367338} = "Emita";
$areanames{en}->{61367339} = "Evandale";
$areanames{en}->{61367340} = "Exeter";
$areanames{en}->{61367341} = "Fingal";
$areanames{en}->{61367342} = "George\ Town";
$areanames{en}->{61367343} = "Gladstone";
$areanames{en}->{61367344} = "Glengarry";
$areanames{en}->{61367345} = "Launceston";
$areanames{en}->{61367346} = "Lilydale";
$areanames{en}->{61367347} = "Longford";
$areanames{en}->{61367348} = "Mathinna";
$areanames{en}->{61367349} = "Mole\ Creek";
$areanames{en}->{61367350} = "Moltema";
$areanames{en}->{61367351} = "Pyengana";
$areanames{en}->{61367352} = "Ringarooma";
$areanames{en}->{61367353} = "Rossarden";
$areanames{en}->{61367354} = "Scottsdale";
$areanames{en}->{61367355} = "St\ Helens";
$areanames{en}->{61367356} = "St\ Marys";
$areanames{en}->{61367357} = "Targa";
$areanames{en}->{61367358} = "Waterhouse";
$areanames{en}->{61367359} = "Westbury";
$areanames{en}->{61367360} = "Whitemark";
$areanames{en}->{61367361} = "Winnaleah";
$areanames{en}->{61367362} = "Avoca";
$areanames{en}->{61367363} = "Beaconsfield";
$areanames{en}->{61367364} = "Bicheno";
$areanames{en}->{61367365} = "Blessington";
$areanames{en}->{61367366} = "Bridport";
$areanames{en}->{61367367} = "Campbell\ Town";
$areanames{en}->{61367368} = "Deloraine";
$areanames{en}->{61367369} = "Emita";
$areanames{en}->{61367370} = "Evandale";
$areanames{en}->{61367371} = "Exeter";
$areanames{en}->{61367372} = "Fingal";
$areanames{en}->{61367373} = "George\ Town";
$areanames{en}->{61367374} = "Gladstone";
$areanames{en}->{61367375} = "Glengarry";
$areanames{en}->{61367376} = "Launceston";
$areanames{en}->{61367377} = "Lilydale";
$areanames{en}->{61367378} = "Longford";
$areanames{en}->{61367379} = "Mathinna";
$areanames{en}->{61367380} = "Mole\ Creek";
$areanames{en}->{61367381} = "Moltema";
$areanames{en}->{61367382} = "Pyengana";
$areanames{en}->{61367383} = "Ringarooma";
$areanames{en}->{61367384} = "Rossarden";
$areanames{en}->{61367385} = "Scottsdale";
$areanames{en}->{61367386} = "St\ Helens";
$areanames{en}->{61367387} = "St\ Marys";
$areanames{en}->{61367388} = "Targa";
$areanames{en}->{61367389} = "Waterhouse";
$areanames{en}->{61367390} = "Westbury";
$areanames{en}->{61367391} = "Whitemark";
$areanames{en}->{61367392} = "Winnaleah";
$areanames{en}->{61367393} = "Avoca";
$areanames{en}->{61367394} = "Beaconsfield";
$areanames{en}->{61367395} = "Bicheno";
$areanames{en}->{61367396} = "Blessington";
$areanames{en}->{61367397} = "Bridport";
$areanames{en}->{61367398} = "Campbell\ Town";
$areanames{en}->{61367399} = "Deloraine";
$areanames{en}->{61367400} = "Emita";
$areanames{en}->{61367401} = "Evandale";
$areanames{en}->{61367402} = "Exeter";
$areanames{en}->{61367403} = "Fingal";
$areanames{en}->{61367404} = "George\ Town";
$areanames{en}->{61367405} = "Gladstone";
$areanames{en}->{61367406} = "Glengarry";
$areanames{en}->{61367407} = "Launceston";
$areanames{en}->{61367408} = "Lilydale";
$areanames{en}->{61367409} = "Longford";
$areanames{en}->{61367410} = "Mathinna";
$areanames{en}->{61367411} = "Mole\ Creek";
$areanames{en}->{61367412} = "Moltema";
$areanames{en}->{61367413} = "Pyengana";
$areanames{en}->{61367414} = "Ringarooma";
$areanames{en}->{61367415} = "Rossarden";
$areanames{en}->{61367416} = "Scottsdale";
$areanames{en}->{61367417} = "St\ Helens";
$areanames{en}->{61367418} = "St\ Marys";
$areanames{en}->{61367419} = "Targa";
$areanames{en}->{61367420} = "Waterhouse";
$areanames{en}->{61367421} = "Westbury";
$areanames{en}->{61367422} = "Whitemark";
$areanames{en}->{61367423} = "Winnaleah";
$areanames{en}->{61367748} = "Campbell\ Town";
$areanames{en}->{61367749} = "Launceston";
$areanames{en}->{6136775} = "Launceston";
$areanames{en}->{6136776} = "Launceston";
$areanames{en}->{61367766} = "Campbell\ Town";
$areanames{en}->{6136777} = "Launceston";
$areanames{en}->{6136778} = "Launceston";
$areanames{en}->{61367788} = "Scottsdale";
$areanames{en}->{6136779} = "Launceston";
$areanames{en}->{61370003} = "Melbourne";
$areanames{en}->{61370007} = "Melbourne";
$areanames{en}->{61370008} = "Melbourne";
$areanames{en}->{61370009} = "Melbourne";
$areanames{en}->{6137001} = "Melbourne";
$areanames{en}->{6137002} = "Melbourne";
$areanames{en}->{61370030} = "Melbourne";
$areanames{en}->{61370031} = "Melbourne";
$areanames{en}->{61370032} = "Melbourne";
$areanames{en}->{61370033} = "Melbourne";
$areanames{en}->{61370034} = "Melbourne";
$areanames{en}->{6137004} = "Melbourne";
$areanames{en}->{6137005} = "Melbourne";
$areanames{en}->{6137006} = "Melbourne";
$areanames{en}->{6137007} = "Melbourne";
$areanames{en}->{6137010} = "Melbourne";
$areanames{en}->{6137017} = "Melbourne";
$areanames{en}->{6137020} = "Melbourne";
$areanames{en}->{6137021} = "Melbourne";
$areanames{en}->{6137022} = "Melbourne";
$areanames{en}->{61373000} = "Craigieburn";
$areanames{en}->{61373001} = "Point\ Cook";
$areanames{en}->{61373002} = "Sydenham";
$areanames{en}->{61373003} = "Craigieburn";
$areanames{en}->{61373004} = "Point\ Cook";
$areanames{en}->{61373005} = "Sydenham";
$areanames{en}->{61373006} = "Craigieburn";
$areanames{en}->{61373007} = "Point\ Cook";
$areanames{en}->{61373008} = "Sydenham";
$areanames{en}->{61373009} = "Craigieburn";
$areanames{en}->{6137301} = "Point\ Cook";
$areanames{en}->{61373011} = "Sydenham";
$areanames{en}->{61373012} = "Craigieburn";
$areanames{en}->{61373014} = "Sydenham";
$areanames{en}->{61373020} = "Craigieburn";
$areanames{en}->{61373021} = "Point\ Cook";
$areanames{en}->{61373022} = "Sydenham";
$areanames{en}->{61373023} = "Craigieburn";
$areanames{en}->{61373024} = "Point\ Cook";
$areanames{en}->{61373025} = "Sydenham";
$areanames{en}->{61373026} = "Craigieburn";
$areanames{en}->{61373027} = "Point\ Cook";
$areanames{en}->{61373028} = "Sydenham";
$areanames{en}->{61373776} = "Sydenham";
$areanames{en}->{61373777} = "Sydenham";
$areanames{en}->{61373778} = "Sydenham";
$areanames{en}->{61373779} = "Sydenham";
$areanames{en}->{6137378} = "Sydenham";
$areanames{en}->{61373790} = "Sydenham";
$areanames{en}->{61373791} = "Sydenham";
$areanames{en}->{61373792} = "Sydenham";
$areanames{en}->{61373793} = "Sydenham";
$areanames{en}->{61373794} = "Craigieburn";
$areanames{en}->{61373795} = "Craigieburn";
$areanames{en}->{61373796} = "Craigieburn";
$areanames{en}->{61373797} = "Point\ Cook";
$areanames{en}->{61373798} = "Point\ Cook";
$areanames{en}->{61373799} = "Point\ Cook";
$areanames{en}->{61375000} = "Clayton";
$areanames{en}->{61375001} = "Clayton";
$areanames{en}->{61375002} = "Clayton";
$areanames{en}->{61375003} = "Clayton";
$areanames{en}->{61375004} = "Clayton";
$areanames{en}->{61375005} = "Clayton";
$areanames{en}->{61375006} = "Clayton";
$areanames{en}->{61375007} = "Clayton";
$areanames{en}->{6137505} = "Clayton";
$areanames{en}->{6138000} = "Melbourne";
$areanames{en}->{61380010} = "Sunbury";
$areanames{en}->{61380011} = "Werribee";
$areanames{en}->{61380012} = "Werribee";
$areanames{en}->{61380013} = "Werribee";
$areanames{en}->{61380014} = "Sunbury";
$areanames{en}->{61380015} = "Werribee";
$areanames{en}->{61380016} = "Sunbury";
$areanames{en}->{61380017} = "Werribee";
$areanames{en}->{61380018} = "Sunbury";
$areanames{en}->{61380019} = "Sunbury";
$areanames{en}->{6138002} = "Sunbury";
$areanames{en}->{6138003} = "Werribee";
$areanames{en}->{6138004} = "Sunbury";
$areanames{en}->{6138005} = "Werribee";
$areanames{en}->{6138006} = "Werribee";
$areanames{en}->{61380061} = "Sunbury";
$areanames{en}->{61380063} = "Sunbury";
$areanames{en}->{61380066} = "Sunbury";
$areanames{en}->{61380068} = "Sunbury";
$areanames{en}->{61380070} = "Sunbury";
$areanames{en}->{61380071} = "Werribee";
$areanames{en}->{61380072} = "Sunbury";
$areanames{en}->{61380073} = "Werribee";
$areanames{en}->{61380150} = "Werribee";
$areanames{en}->{61380151} = "Werribee";
$areanames{en}->{61380152} = "Werribee";
$areanames{en}->{61380153} = "Werribee";
$areanames{en}->{61380154} = "Werribee";
$areanames{en}->{61380155} = "Sunbury";
$areanames{en}->{61380156} = "Sunbury";
$areanames{en}->{61380157} = "Sunbury";
$areanames{en}->{61380158} = "Sunbury";
$areanames{en}->{6138060} = "Melbourne";
$areanames{en}->{61380655} = "Sunbury";
$areanames{en}->{61380656} = "Werribee";
$areanames{en}->{61380657} = "Werribee";
$areanames{en}->{61380658} = "Werribee";
$areanames{en}->{6138080} = "Melbourne";
$areanames{en}->{6138086} = "Werribee";
$areanames{en}->{6138087} = "Werribee";
$areanames{en}->{6138088} = "Sunbury";
$areanames{en}->{6138089} = "Sunbury";
$areanames{en}->{61380994} = "Sunbury";
$areanames{en}->{61380995} = "Sunbury";
$areanames{en}->{61380996} = "Sunbury";
$areanames{en}->{61380997} = "Sunbury";
$areanames{en}->{61380998} = "Sunbury";
$areanames{en}->{61380999} = "Sunbury";
$areanames{en}->{6138100} = "Kalkallo";
$areanames{en}->{6138101} = "Whittlesea";
$areanames{en}->{6138102} = "Melbourne";
$areanames{en}->{6138103} = "Whittlesea";
$areanames{en}->{61381033} = "Kalkallo";
$areanames{en}->{61381034} = "Kalkallo";
$areanames{en}->{61381037} = "Kalkallo";
$areanames{en}->{61381039} = "Kalkallo";
$areanames{en}->{6138104} = "Whittlesea";
$areanames{en}->{61381041} = "Kalkallo";
$areanames{en}->{61381043} = "Kalkallo";
$areanames{en}->{61381047} = "Kalkallo";
$areanames{en}->{61381050} = "Kalkallo";
$areanames{en}->{61381051} = "Whittlesea";
$areanames{en}->{61381052} = "Kalkallo";
$areanames{en}->{61381053} = "Whittlesea";
$areanames{en}->{61381186} = "Kalkallo";
$areanames{en}->{61381187} = "Whittlesea";
$areanames{en}->{61381188} = "Kalkallo";
$areanames{en}->{61381189} = "Kalkallo";
$areanames{en}->{61381190} = "Kalkallo";
$areanames{en}->{61381191} = "Kalkallo";
$areanames{en}->{61381192} = "Kalkallo";
$areanames{en}->{6138187} = "Whittlesea";
$areanames{en}->{6138188} = "Whittlesea";
$areanames{en}->{6138189} = "Kalkallo";
$areanames{en}->{6138190} = "Kalkallo";
$areanames{en}->{6138199} = "Melbourne";
$areanames{en}->{6138200} = "Croydon";
$areanames{en}->{6138201} = "Croydon";
$areanames{en}->{61382028} = "Croydon";
$areanames{en}->{61382029} = "Croydon";
$areanames{en}->{61382030} = "Croydon";
$areanames{en}->{61382031} = "Croydon";
$areanames{en}->{61382032} = "Croydon";
$areanames{en}->{61382033} = "Croydon";
$areanames{en}->{61382034} = "Croydon";
$areanames{en}->{61382035} = "Croydon";
$areanames{en}->{61382036} = "Croydon";
$areanames{en}->{61382037} = "Croydon";
$areanames{en}->{61382157} = "Croydon";
$areanames{en}->{61382158} = "Croydon";
$areanames{en}->{61382159} = "Croydon";
$areanames{en}->{6138256} = "Melbourne";
$areanames{en}->{61382563} = "Melbourne\/Point\ Cook\/Melbourne";
$areanames{en}->{61382605} = "Croydon";
$areanames{en}->{6138288} = "Croydon";
$areanames{en}->{6138290} = "Melbourne";
$areanames{en}->{613830} = "Melbourne";
$areanames{en}->{6138303} = "Point\ Cook";
$areanames{en}->{6138304} = "Sydenham";
$areanames{en}->{6138305} = "Craigieburn";
$areanames{en}->{6138308} = "Sydenham";
$areanames{en}->{613831} = "Melbourne";
$areanames{en}->{6138313} = "Craigieburn";
$areanames{en}->{6138314} = "Craigieburn";
$areanames{en}->{6138315} = "Sydenham";
$areanames{en}->{6138316} = "Point\ Cook";
$areanames{en}->{613832} = "Melbourne";
$areanames{en}->{6138322} = "Sydenham";
$areanames{en}->{6138323} = "Point\ Cook";
$areanames{en}->{6138324} = "Craigieburn";
$areanames{en}->{6138330} = "Melbourne";
$areanames{en}->{6138331} = "Melbourne";
$areanames{en}->{6138332} = "Melbourne";
$areanames{en}->{6138333} = "Craigieburn";
$areanames{en}->{6138334} = "Point\ Cook";
$areanames{en}->{6138335} = "Melbourne";
$areanames{en}->{6138336} = "Melbourne";
$areanames{en}->{6138337} = "Sydenham";
$areanames{en}->{61383380} = "Craigieburn";
$areanames{en}->{61383381} = "Craigieburn";
$areanames{en}->{61383382} = "Point\ Cook";
$areanames{en}->{61383383} = "Craigieburn";
$areanames{en}->{61383384} = "Sydenham";
$areanames{en}->{61383385} = "Craigieburn";
$areanames{en}->{61383386} = "Sydenham";
$areanames{en}->{61383387} = "Point\ Cook";
$areanames{en}->{61383388} = "Sydenham";
$areanames{en}->{61383389} = "Point\ Cook";
$areanames{en}->{6138339} = "Craigieburn";
$areanames{en}->{613834} = "Melbourne";
$areanames{en}->{6138343} = "Point\ Cook";
$areanames{en}->{61383480} = "Craigieburn";
$areanames{en}->{61383481} = "Point\ Cook";
$areanames{en}->{61383482} = "Sydenham";
$areanames{en}->{61383483} = "Sydenham";
$areanames{en}->{61383484} = "Sydenham";
$areanames{en}->{61383485} = "Sydenham";
$areanames{en}->{61383486} = "Point\ Cook";
$areanames{en}->{61383487} = "Point\ Cook";
$areanames{en}->{61383488} = "Point\ Cook";
$areanames{en}->{61383489} = "Point\ Cook";
$areanames{en}->{6138349} = "Craigieburn";
$areanames{en}->{6138350} = "Point\ Cook";
$areanames{en}->{61383510} = "Point\ Cook";
$areanames{en}->{61383511} = "Sydenham";
$areanames{en}->{61383512} = "Craigieburn";
$areanames{en}->{61383513} = "Point\ Cook";
$areanames{en}->{61383514} = "Sydenham";
$areanames{en}->{61383515} = "Craigieburn";
$areanames{en}->{61383516} = "Point\ Cook";
$areanames{en}->{61383517} = "Sydenham";
$areanames{en}->{61383518} = "Craigieburn";
$areanames{en}->{61383519} = "Craigieburn";
$areanames{en}->{6138352} = "Melbourne";
$areanames{en}->{61383520} = "Sydenham";
$areanames{en}->{6138353} = "Point\ Cook";
$areanames{en}->{61383530} = "Melbourne";
$areanames{en}->{6138354} = "Melbourne";
$areanames{en}->{6138355} = "Craigieburn";
$areanames{en}->{6138356} = "Sydenham";
$areanames{en}->{6138357} = "Sydenham";
$areanames{en}->{6138358} = "Sydenham";
$areanames{en}->{61383586} = "Craigieburn";
$areanames{en}->{61383587} = "Craigieburn";
$areanames{en}->{61383588} = "Craigieburn";
$areanames{en}->{61383589} = "Craigieburn";
$areanames{en}->{6138359} = "Melbourne";
$areanames{en}->{6138360} = "Melbourne";
$areanames{en}->{6138361} = "Sydenham";
$areanames{en}->{61383620} = "Craigieburn";
$areanames{en}->{61383621} = "Craigieburn";
$areanames{en}->{61383622} = "Point\ Cook";
$areanames{en}->{61383623} = "Melbourne";
$areanames{en}->{61383624} = "Point\ Cook";
$areanames{en}->{61383625} = "Sydenham";
$areanames{en}->{61383626} = "Sydenham";
$areanames{en}->{61383627} = "Craigieburn";
$areanames{en}->{61383628} = "Sydenham";
$areanames{en}->{61383629} = "Craigieburn";
$areanames{en}->{6138363} = "Sydenham";
$areanames{en}->{6138364} = "Craigieburn";
$areanames{en}->{6138365} = "Craigieburn";
$areanames{en}->{6138366} = "Point\ Cook";
$areanames{en}->{6138367} = "Point\ Cook";
$areanames{en}->{6138368} = "Melbourne";
$areanames{en}->{6138369} = "Melbourne";
$areanames{en}->{613837} = "Melbourne";
$areanames{en}->{6138372} = "Sydenham";
$areanames{en}->{61383722} = "Point\ Cook";
$areanames{en}->{61383723} = "Craigieburn";
$areanames{en}->{61383740} = "Point\ Cook";
$areanames{en}->{61383741} = "Sydenham";
$areanames{en}->{61383742} = "Craigieburn";
$areanames{en}->{61383744} = "Point\ Cook";
$areanames{en}->{61383745} = "Sydenham";
$areanames{en}->{61383749} = "Craigieburn";
$areanames{en}->{61383750} = "Point\ Cook";
$areanames{en}->{61383751} = "Point\ Cook";
$areanames{en}->{61383752} = "Point\ Cook";
$areanames{en}->{61383753} = "Point\ Cook";
$areanames{en}->{61383763} = "Point\ Cook";
$areanames{en}->{61383764} = "Point\ Cook";
$areanames{en}->{61383765} = "Point\ Cook";
$areanames{en}->{6138377} = "Craigieburn";
$areanames{en}->{6138380} = "Point\ Cook";
$areanames{en}->{6138381} = "Point\ Cook";
$areanames{en}->{6138382} = "Sydenham";
$areanames{en}->{6138383} = "Melbourne";
$areanames{en}->{6138384} = "Craigieburn";
$areanames{en}->{6138385} = "Sydenham";
$areanames{en}->{6138386} = "Point\ Cook";
$areanames{en}->{6138387} = "Melbourne";
$areanames{en}->{6138388} = "Melbourne";
$areanames{en}->{6138389} = "Craigieburn";
$areanames{en}->{6138390} = "Sydenham";
$areanames{en}->{6138391} = "Melbourne";
$areanames{en}->{6138392} = "Melbourne";
$areanames{en}->{6138393} = "Melbourne";
$areanames{en}->{6138396} = "Melbourne";
$areanames{en}->{6138397} = "Melbourne";
$areanames{en}->{6138398} = "Melbourne";
$areanames{en}->{6138399} = "Melbourne";
$areanames{en}->{6138400} = "Eltham";
$areanames{en}->{61384004} = "Melbourne";
$areanames{en}->{61384007} = "Melbourne";
$areanames{en}->{6138401} = "Eltham";
$areanames{en}->{6138402} = "Eltham";
$areanames{en}->{6138403} = "Melbourne";
$areanames{en}->{6138404} = "Eltham";
$areanames{en}->{6138405} = "Eltham";
$areanames{en}->{6138406} = "Eltham";
$areanames{en}->{61384070} = "Eltham";
$areanames{en}->{61384071} = "Eltham";
$areanames{en}->{61384072} = "Eltham";
$areanames{en}->{61384073} = "Eltham";
$areanames{en}->{61384074} = "Eltham";
$areanames{en}->{61384077} = "Eltham";
$areanames{en}->{61384078} = "Eltham";
$areanames{en}->{61384079} = "Eltham";
$areanames{en}->{61384080} = "Eltham";
$areanames{en}->{61384081} = "Eltham";
$areanames{en}->{61384082} = "Eltham";
$areanames{en}->{61384083} = "Eltham";
$areanames{en}->{6138412} = "Melbourne";
$areanames{en}->{6138413} = "Melbourne";
$areanames{en}->{6138414} = "Melbourne";
$areanames{en}->{6138415} = "Melbourne";
$areanames{en}->{6138416} = "Melbourne";
$areanames{en}->{6138417} = "Melbourne";
$areanames{en}->{6138418} = "Eltham";
$areanames{en}->{6138419} = "Melbourne";
$areanames{en}->{6138420} = "Melbourne";
$areanames{en}->{61384272} = "Eltham";
$areanames{en}->{61384273} = "Eltham";
$areanames{en}->{6138430} = "Melbourne";
$areanames{en}->{6138431} = "Eltham";
$areanames{en}->{6138432} = "Eltham";
$areanames{en}->{6138436} = "Melbourne";
$areanames{en}->{6138456} = "Melbourne";
$areanames{en}->{6138457} = "Eltham";
$areanames{en}->{6138458} = "Melbourne";
$areanames{en}->{6138459} = "Melbourne";
$areanames{en}->{6138461} = "Melbourne";
$areanames{en}->{6138467} = "Melbourne";
$areanames{en}->{6138468} = "Eltham";
$areanames{en}->{6138470} = "Melbourne";
$areanames{en}->{6138480} = "Melbourne";
$areanames{en}->{6138481} = "Melbourne";
$areanames{en}->{6138486} = "Melbourne";
$areanames{en}->{61384880} = "Eltham";
$areanames{en}->{61384881} = "Eltham";
$areanames{en}->{61384882} = "Eltham";
$areanames{en}->{61384886} = "Melbourne";
$areanames{en}->{61384887} = "Melbourne";
$areanames{en}->{61384888} = "Melbourne";
$areanames{en}->{61384889} = "Melbourne";
$areanames{en}->{613850} = "Melbourne";
$areanames{en}->{6138501} = "Clayton";
$areanames{en}->{6138505} = "Clayton";
$areanames{en}->{613851} = "Clayton";
$areanames{en}->{6138515} = "Melbourne";
$areanames{en}->{6138517} = "Melbourne";
$areanames{en}->{61385184} = "Melbourne";
$areanames{en}->{61385187} = "Melbourne";
$areanames{en}->{6138519} = "Melbourne";
$areanames{en}->{6138520} = "Melbourne";
$areanames{en}->{61385211} = "Clayton";
$areanames{en}->{61385212} = "Clayton";
$areanames{en}->{61385213} = "Clayton";
$areanames{en}->{61385214} = "Clayton";
$areanames{en}->{6138522} = "Clayton";
$areanames{en}->{6138523} = "Clayton";
$areanames{en}->{6138524} = "Clayton";
$areanames{en}->{6138525} = "Melbourne";
$areanames{en}->{6138526} = "Clayton";
$areanames{en}->{6138527} = "Melbourne";
$areanames{en}->{6138528} = "Melbourne";
$areanames{en}->{6138529} = "Melbourne";
$areanames{en}->{613853} = "Melbourne";
$areanames{en}->{613854} = "Clayton";
$areanames{en}->{6138547} = "Melbourne";
$areanames{en}->{6138548} = "Melbourne";
$areanames{en}->{6138550} = "Clayton";
$areanames{en}->{6138551} = "Clayton";
$areanames{en}->{6138552} = "Melbourne";
$areanames{en}->{6138553} = "Clayton";
$areanames{en}->{6138554} = "Melbourne";
$areanames{en}->{6138555} = "Clayton";
$areanames{en}->{6138556} = "Melbourne";
$areanames{en}->{6138557} = "Melbourne";
$areanames{en}->{6138558} = "Clayton";
$areanames{en}->{6138559} = "Melbourne";
$areanames{en}->{6138560} = "Melbourne";
$areanames{en}->{6138561} = "Clayton";
$areanames{en}->{6138562} = "Clayton";
$areanames{en}->{6138563} = "Melbourne";
$areanames{en}->{6138564} = "Melbourne";
$areanames{en}->{6138565} = "Clayton";
$areanames{en}->{6138566} = "Clayton";
$areanames{en}->{61385666} = "Melbourne";
$areanames{en}->{61385667} = "Melbourne";
$areanames{en}->{61385668} = "Melbourne";
$areanames{en}->{61385669} = "Melbourne";
$areanames{en}->{6138567} = "Melbourne";
$areanames{en}->{6138568} = "Melbourne";
$areanames{en}->{6138569} = "Clayton";
$areanames{en}->{6138571} = "Clayton";
$areanames{en}->{6138572} = "Clayton";
$areanames{en}->{6138573} = "Melbourne";
$areanames{en}->{6138574} = "Melbourne";
$areanames{en}->{6138575} = "Melbourne";
$areanames{en}->{6138576} = "Melbourne";
$areanames{en}->{6138577} = "Clayton";
$areanames{en}->{61385778} = "Melbourne";
$areanames{en}->{61385779} = "Melbourne";
$areanames{en}->{6138578} = "Melbourne";
$areanames{en}->{6138579} = "Melbourne";
$areanames{en}->{61385800} = "Melbourne";
$areanames{en}->{61385801} = "Melbourne";
$areanames{en}->{61385802} = "Melbourne";
$areanames{en}->{61385803} = "Melbourne";
$areanames{en}->{61385804} = "Melbourne";
$areanames{en}->{61385805} = "Melbourne";
$areanames{en}->{61385806} = "Melbourne";
$areanames{en}->{61385807} = "Melbourne";
$areanames{en}->{6138581} = "Clayton";
$areanames{en}->{6138582} = "Melbourne";
$areanames{en}->{61385830} = "Melbourne";
$areanames{en}->{6138585} = "Clayton";
$areanames{en}->{6138586} = "Clayton";
$areanames{en}->{6138587} = "Clayton";
$areanames{en}->{6138588} = "Clayton";
$areanames{en}->{6138589} = "Melbourne";
$areanames{en}->{6138590} = "Melbourne";
$areanames{en}->{6138591} = "Melbourne";
$areanames{en}->{6138604} = "Melbourne";
$areanames{en}->{6138607} = "Melbourne";
$areanames{en}->{6138608} = "Melbourne";
$areanames{en}->{6138609} = "Melbourne";
$areanames{en}->{6138619} = "Melbourne";
$areanames{en}->{6138640} = "Melbourne";
$areanames{en}->{6138641} = "Melbourne";
$areanames{en}->{6138642} = "Melbourne";
$areanames{en}->{6138643} = "Melbourne";
$areanames{en}->{6138644} = "Melbourne";
$areanames{en}->{6138648} = "Melbourne";
$areanames{en}->{61386490} = "Melbourne";
$areanames{en}->{6138650} = "Melbourne";
$areanames{en}->{6138651} = "Melbourne";
$areanames{en}->{61386521} = "Melbourne";
$areanames{en}->{61386522} = "Melbourne";
$areanames{en}->{61386523} = "Melbourne";
$areanames{en}->{61386524} = "Melbourne";
$areanames{en}->{61386525} = "Melbourne";
$areanames{en}->{6138653} = "Melbourne";
$areanames{en}->{6138654} = "Melbourne";
$areanames{en}->{6138655} = "Melbourne";
$areanames{en}->{6138656} = "Melbourne";
$areanames{en}->{6138657} = "Melbourne";
$areanames{en}->{6138658} = "Melbourne";
$areanames{en}->{6138659} = "Melbourne";
$areanames{en}->{6138666} = "Melbourne";
$areanames{en}->{61386691} = "Melbourne";
$areanames{en}->{6138671} = "Melbourne";
$areanames{en}->{6138672} = "Melbourne";
$areanames{en}->{6138673} = "Melbourne";
$areanames{en}->{6138690} = "Melbourne";
$areanames{en}->{6138693} = "Melbourne";
$areanames{en}->{6138700} = "Werribee";
$areanames{en}->{6138701} = "Sunbury";
$areanames{en}->{6138702} = "Kalkallo";
$areanames{en}->{6138703} = "Whittlesea";
$areanames{en}->{6138704} = "Croydon";
$areanames{en}->{6138705} = "Dandenong";
$areanames{en}->{6138706} = "Croydon";
$areanames{en}->{6138707} = "Dandenong";
$areanames{en}->{6138708} = "Kalkallo";
$areanames{en}->{61387089} = "Melbourne";
$areanames{en}->{6138709} = "Croydon";
$areanames{en}->{6138710} = "Dandenong";
$areanames{en}->{6138711} = "Croydon";
$areanames{en}->{6138712} = "Dandenong";
$areanames{en}->{6138713} = "Kalkallo";
$areanames{en}->{6138714} = "Werribee";
$areanames{en}->{6138715} = "Whittlesea";
$areanames{en}->{6138716} = "Sunbury";
$areanames{en}->{6138717} = "Croydon";
$areanames{en}->{6138718} = "Dandenong";
$areanames{en}->{6138719} = "Croydon";
$areanames{en}->{6138720} = "Croydon";
$areanames{en}->{6138721} = "Werribee";
$areanames{en}->{6138722} = "Sunbury";
$areanames{en}->{6138723} = "Kalkallo";
$areanames{en}->{6138724} = "Whittlesea";
$areanames{en}->{6138725} = "Dandenong";
$areanames{en}->{6138726} = "Dandenong";
$areanames{en}->{6138727} = "Croydon";
$areanames{en}->{6138728} = "Dandenong";
$areanames{en}->{6138729} = "Werribee";
$areanames{en}->{6138730} = "Croydon";
$areanames{en}->{6138731} = "Werribee";
$areanames{en}->{6138732} = "Sunbury";
$areanames{en}->{6138733} = "Kalkallo";
$areanames{en}->{6138734} = "Werribee";
$areanames{en}->{6138735} = "Whittlesea";
$areanames{en}->{6138736} = "Croydon";
$areanames{en}->{6138737} = "Werribee";
$areanames{en}->{6138738} = "Dandenong";
$areanames{en}->{6138739} = "Croydon";
$areanames{en}->{61387400} = "Croydon";
$areanames{en}->{61387401} = "Croydon";
$areanames{en}->{61387402} = "Dandenong";
$areanames{en}->{61387403} = "Croydon";
$areanames{en}->{61387404} = "Werribee";
$areanames{en}->{61387405} = "Sunbury";
$areanames{en}->{61387406} = "Kalkallo";
$areanames{en}->{61387407} = "Whittlesea";
$areanames{en}->{61387408} = "Croydon";
$areanames{en}->{61387409} = "Dandenong";
$areanames{en}->{6138741} = "Croydon";
$areanames{en}->{6138742} = "Werribee";
$areanames{en}->{6138743} = "Dandenong";
$areanames{en}->{6138744} = "Werribee";
$areanames{en}->{61387443} = "Werribee\/Point\ Cook";
$areanames{en}->{6138745} = "Sunbury";
$areanames{en}->{6138746} = "Sunbury";
$areanames{en}->{6138747} = "Sunbury";
$areanames{en}->{6138748} = "Whittlesea";
$areanames{en}->{6138749} = "Kalkallo";
$areanames{en}->{61387500} = "Croydon";
$areanames{en}->{61387501} = "Kalkallo";
$areanames{en}->{61387502} = "Sunbury";
$areanames{en}->{61387503} = "Werribee";
$areanames{en}->{61387504} = "Whittlesea";
$areanames{en}->{61387505} = "Croydon";
$areanames{en}->{61387506} = "Dandenong";
$areanames{en}->{61387507} = "Kalkallo";
$areanames{en}->{61387508} = "Sunbury";
$areanames{en}->{61387509} = "Werribee";
$areanames{en}->{6138751} = "Dandenong";
$areanames{en}->{61387510} = "Whittlesea";
$areanames{en}->{6138752} = "Dandenong";
$areanames{en}->{61387525} = "Whittlesea";
$areanames{en}->{6138753} = "Dandenong";
$areanames{en}->{6138754} = "Werribee";
$areanames{en}->{6138755} = "Werribee";
$areanames{en}->{6138756} = "Croydon";
$areanames{en}->{6138757} = "Kalkallo";
$areanames{en}->{6138758} = "Dandenong";
$areanames{en}->{6138759} = "Dandenong";
$areanames{en}->{613876} = "Dandenong";
$areanames{en}->{61387602} = "Kalkallo";
$areanames{en}->{61387603} = "Sunbury";
$areanames{en}->{61387604} = "Werribee";
$areanames{en}->{61387605} = "Whittlesea";
$areanames{en}->{61387607} = "Kalkallo";
$areanames{en}->{61387608} = "Sunbury";
$areanames{en}->{61387609} = "Werribee";
$areanames{en}->{6138761} = "Croydon";
$areanames{en}->{61387630} = "Werribee";
$areanames{en}->{61387631} = "Werribee";
$areanames{en}->{61387632} = "Werribee";
$areanames{en}->{61387641} = "Kalkallo";
$areanames{en}->{61387642} = "Sunbury";
$areanames{en}->{61387643} = "Werribee";
$areanames{en}->{61387644} = "Whittlesea";
$areanames{en}->{6138767} = "Whittlesea";
$areanames{en}->{6138770} = "Dandenong";
$areanames{en}->{61387710} = "Werribee";
$areanames{en}->{61387711} = "Sunbury";
$areanames{en}->{61387712} = "Kalkallo";
$areanames{en}->{61387713} = "Whittlesea";
$areanames{en}->{61387714} = "Croydon";
$areanames{en}->{61387715} = "Dandenong";
$areanames{en}->{61387716} = "Werribee";
$areanames{en}->{61387717} = "Sunbury";
$areanames{en}->{61387718} = "Kalkallo";
$areanames{en}->{61387719} = "Whittlesea";
$areanames{en}->{6138772} = "Dandenong";
$areanames{en}->{61387720} = "Croydon";
$areanames{en}->{61387723} = "Whittlesea";
$areanames{en}->{61387724} = "Werribee";
$areanames{en}->{6138773} = "Dandenong";
$areanames{en}->{6138774} = "Dandenong";
$areanames{en}->{6138775} = "Whittlesea";
$areanames{en}->{6138776} = "Whittlesea";
$areanames{en}->{6138777} = "Croydon";
$areanames{en}->{6138778} = "Kalkallo";
$areanames{en}->{61387795} = "Dandenong\/Melbourne\/Dandenong";
$areanames{en}->{6138780} = "Dandenong";
$areanames{en}->{61387801} = "Kalkallo";
$areanames{en}->{61387802} = "Sunbury";
$areanames{en}->{61387809} = "Werribee";
$areanames{en}->{6138781} = "Dandenong";
$areanames{en}->{6138782} = "Dandenong";
$areanames{en}->{61387824} = "Croydon";
$areanames{en}->{61387825} = "Croydon";
$areanames{en}->{61387826} = "Croydon";
$areanames{en}->{6138783} = "Dandenong";
$areanames{en}->{61387840} = "Dandenong";
$areanames{en}->{61387841} = "Dandenong";
$areanames{en}->{61387842} = "Dandenong";
$areanames{en}->{61387843} = "Dandenong";
$areanames{en}->{61387844} = "Dandenong";
$areanames{en}->{61387845} = "Dandenong";
$areanames{en}->{61387846} = "Dandenong";
$areanames{en}->{61387848} = "Dandenong";
$areanames{en}->{61387849} = "Kalkallo";
$areanames{en}->{6138785} = "Dandenong";
$areanames{en}->{6138786} = "Dandenong";
$areanames{en}->{6138787} = "Dandenong";
$areanames{en}->{6138788} = "Dandenong";
$areanames{en}->{6138789} = "Dandenong";
$areanames{en}->{613879} = "Dandenong";
$areanames{en}->{6138798} = "Sunbury";
$areanames{en}->{6138799} = "Croydon";
$areanames{en}->{6138800} = "Melbourne";
$areanames{en}->{6138801} = "Ringwood";
$areanames{en}->{6138802} = "Melbourne";
$areanames{en}->{61388030} = "Melbourne";
$areanames{en}->{61388031} = "Melbourne";
$areanames{en}->{61388032} = "Melbourne";
$areanames{en}->{61388033} = "Melbourne";
$areanames{en}->{61388034} = "Melbourne";
$areanames{en}->{613880357} = "Croydon";
$areanames{en}->{61388036} = "Melbourne";
$areanames{en}->{61388037} = "Melbourne";
$areanames{en}->{61388038} = "Melbourne";
$areanames{en}->{61388039} = "Melbourne";
$areanames{en}->{6138804} = "Melbourne";
$areanames{en}->{6138805} = "Ringwood";
$areanames{en}->{6138806} = "Ringwood";
$areanames{en}->{6138807} = "Melbourne";
$areanames{en}->{6138808} = "Melbourne";
$areanames{en}->{6138809} = "Melbourne";
$areanames{en}->{613881} = "Ringwood";
$areanames{en}->{6138810} = "Melbourne";
$areanames{en}->{6138815} = "Melbourne";
$areanames{en}->{6138816} = "Melbourne";
$areanames{en}->{6138817} = "Melbourne";
$areanames{en}->{6138820} = "Ringwood";
$areanames{en}->{61388205} = "Melbourne";
$areanames{en}->{61388207} = "Melbourne";
$areanames{en}->{6138821} = "Ringwood";
$areanames{en}->{61388221} = "Ringwood";
$areanames{en}->{61388222} = "Ringwood";
$areanames{en}->{61388228} = "Ringwood";
$areanames{en}->{61388229} = "Ringwood";
$areanames{en}->{6138823} = "Melbourne";
$areanames{en}->{6138824} = "Ringwood";
$areanames{en}->{6138825} = "Melbourne";
$areanames{en}->{6138826} = "Ringwood";
$areanames{en}->{61388270} = "Ringwood";
$areanames{en}->{61388271} = "Ringwood";
$areanames{en}->{61388272} = "Ringwood";
$areanames{en}->{61388273} = "Ringwood";
$areanames{en}->{61388274} = "Ringwood";
$areanames{en}->{61388275} = "Ringwood";
$areanames{en}->{6138831} = "Melbourne";
$areanames{en}->{6138832} = "Melbourne";
$areanames{en}->{6138833} = "Ringwood";
$areanames{en}->{6138838} = "Ringwood";
$areanames{en}->{61388390} = "Ringwood";
$areanames{en}->{61388391} = "Ringwood";
$areanames{en}->{61388392} = "Ringwood";
$areanames{en}->{61388393} = "Ringwood";
$areanames{en}->{61388394} = "Ringwood";
$areanames{en}->{61388395} = "Ringwood";
$areanames{en}->{61388396} = "Ringwood";
$areanames{en}->{61388397} = "Ringwood";
$areanames{en}->{613884} = "Melbourne";
$areanames{en}->{6138841} = "Ringwood";
$areanames{en}->{6138845} = "Ringwood";
$areanames{en}->{6138846} = "Ringwood";
$areanames{en}->{6138847} = "Ringwood";
$areanames{en}->{6138850} = "Melbourne";
$areanames{en}->{6138851} = "Melbourne";
$areanames{en}->{6138855} = "Melbourne";
$areanames{en}->{6138862} = "Melbourne";
$areanames{en}->{6138863} = "Ringwood";
$areanames{en}->{6138864} = "Ringwood";
$areanames{en}->{6138866} = "Melbourne";
$areanames{en}->{6138870} = "Ringwood";
$areanames{en}->{6138871} = "Ringwood";
$areanames{en}->{6138872} = "Ringwood";
$areanames{en}->{6138873} = "Ringwood";
$areanames{en}->{61388744} = "Ringwood";
$areanames{en}->{6138877} = "Ringwood";
$areanames{en}->{6138878} = "Ringwood";
$areanames{en}->{6138888} = "Melbourne";
$areanames{en}->{6138892} = "Melbourne";
$areanames{en}->{61388996} = "Melbourne";
$areanames{en}->{61388997} = "Melbourne";
$areanames{en}->{61388998} = "Melbourne";
$areanames{en}->{61388999} = "Melbourne";
$areanames{en}->{6138902} = "Dandenong";
$areanames{en}->{61389030} = "Dandenong";
$areanames{en}->{61389031} = "Dandenong";
$areanames{en}->{61389032} = "Dandenong";
$areanames{en}->{6139000} = "Melbourne";
$areanames{en}->{6139001} = "Melbourne";
$areanames{en}->{6139002} = "Melbourne";
$areanames{en}->{6139003} = "Melbourne";
$areanames{en}->{6139004} = "Melbourne";
$areanames{en}->{6139005} = "Melbourne";
$areanames{en}->{6139006} = "Melbourne";
$areanames{en}->{61390070} = "Eltham";
$areanames{en}->{61390071} = "Melbourne";
$areanames{en}->{61390072} = "Melbourne";
$areanames{en}->{61390073} = "Melbourne";
$areanames{en}->{61390074} = "Melbourne";
$areanames{en}->{61390075} = "Melbourne";
$areanames{en}->{61390076} = "Melbourne";
$areanames{en}->{6139008} = "Melbourne";
$areanames{en}->{6139009} = "Melbourne";
$areanames{en}->{61390090} = "Eltham";
$areanames{en}->{61390091} = "Eltham";
$areanames{en}->{61390092} = "Eltham";
$areanames{en}->{61390130} = "Melbourne";
$areanames{en}->{61390154} = "Melbourne";
$areanames{en}->{61390163} = "Melbourne";
$areanames{en}->{6139022} = "Melbourne";
$areanames{en}->{6139023} = "Melbourne";
$areanames{en}->{6139024} = "Melbourne";
$areanames{en}->{6139029} = "Melbourne";
$areanames{en}->{6139034} = "Melbourne";
$areanames{en}->{6139035} = "Melbourne";
$areanames{en}->{6139036} = "Melbourne";
$areanames{en}->{6139048} = "Melbourne";
$areanames{en}->{6139049} = "Melbourne";
$areanames{en}->{6139050} = "Melbourne";
$areanames{en}->{6139051} = "Melbourne";
$areanames{en}->{6139052} = "Melbourne";
$areanames{en}->{6139055} = "Melbourne";
$areanames{en}->{6139058} = "Melbourne";
$areanames{en}->{61390635} = "Melbourne";
$areanames{en}->{61390636} = "Melbourne";
$areanames{en}->{61390637} = "Melbourne";
$areanames{en}->{61390638} = "Melbourne";
$areanames{en}->{61390639} = "Melbourne";
$areanames{en}->{6139064} = "Melbourne";
$areanames{en}->{6139065} = "Melbourne";
$areanames{en}->{6139066} = "Melbourne";
$areanames{en}->{6139067} = "Melbourne";
$areanames{en}->{6139068} = "Melbourne";
$areanames{en}->{6139069} = "Melbourne";
$areanames{en}->{61390710} = "Melbourne";
$areanames{en}->{61390711} = "Melbourne";
$areanames{en}->{61390712} = "Melbourne";
$areanames{en}->{61390713} = "Melbourne";
$areanames{en}->{61390714} = "Melbourne";
$areanames{en}->{6139076} = "Melbourne";
$areanames{en}->{6139077} = "Melbourne";
$areanames{en}->{6139078} = "Melbourne";
$areanames{en}->{6139079} = "Melbourne";
$areanames{en}->{613908} = "Melbourne";
$areanames{en}->{61390990} = "Melbourne";
$areanames{en}->{6139100} = "Melbourne";
$areanames{en}->{61391011} = "Melbourne";
$areanames{en}->{61391012} = "Melbourne";
$areanames{en}->{61391013} = "Melbourne";
$areanames{en}->{61391014} = "Melbourne";
$areanames{en}->{61391015} = "Melbourne";
$areanames{en}->{61391016} = "Melbourne";
$areanames{en}->{61391017} = "Melbourne";
$areanames{en}->{61391018} = "Melbourne";
$areanames{en}->{61391019} = "Melbourne";
$areanames{en}->{6139102} = "Melbourne";
$areanames{en}->{61391030} = "Melbourne";
$areanames{en}->{61391031} = "Melbourne";
$areanames{en}->{61391032} = "Melbourne";
$areanames{en}->{61391058} = "Melbourne";
$areanames{en}->{61391059} = "Melbourne";
$areanames{en}->{6139106} = "Melbourne";
$areanames{en}->{6139107} = "Melbourne";
$areanames{en}->{6139108} = "Melbourne";
$areanames{en}->{6139109} = "Melbourne";
$areanames{en}->{6139110} = "Melbourne";
$areanames{en}->{6139130} = "Melbourne";
$areanames{en}->{6139131} = "Melbourne";
$areanames{en}->{6139132} = "Melbourne";
$areanames{en}->{6139133} = "Melbourne";
$areanames{en}->{6139134} = "Melbourne";
$areanames{en}->{6139135} = "Melbourne";
$areanames{en}->{6139136} = "Melbourne";
$areanames{en}->{61391735} = "Melbourne";
$areanames{en}->{61391736} = "Melbourne";
$areanames{en}->{61391737} = "Melbourne";
$areanames{en}->{61391738} = "Melbourne";
$areanames{en}->{6139188} = "Melbourne";
$areanames{en}->{6139189} = "Melbourne";
$areanames{en}->{6139200} = "Melbourne";
$areanames{en}->{6139201} = "Melbourne";
$areanames{en}->{6139202} = "Werribee";
$areanames{en}->{6139203} = "Melbourne";
$areanames{en}->{6139204} = "Melbourne";
$areanames{en}->{6139205} = "Melbourne";
$areanames{en}->{6139206} = "Melbourne";
$areanames{en}->{6139207} = "Melbourne";
$areanames{en}->{6139208} = "Melbourne";
$areanames{en}->{61392098} = "Melbourne";
$areanames{en}->{6139210} = "Ringwood";
$areanames{en}->{61392102} = "Melbourne";
$areanames{en}->{6139211} = "Melbourne";
$areanames{en}->{61392117} = "Clayton";
$areanames{en}->{61392120} = "Croydon";
$areanames{en}->{61392121} = "Dandenong";
$areanames{en}->{61392122} = "Dandenong";
$areanames{en}->{61392123} = "Dandenong";
$areanames{en}->{61392124} = "Dandenong";
$areanames{en}->{61392125} = "Dandenong";
$areanames{en}->{61392126} = "Croydon";
$areanames{en}->{61392127} = "Croydon";
$areanames{en}->{61392128} = "Croydon";
$areanames{en}->{61392129} = "Croydon";
$areanames{en}->{61392130} = "Croydon";
$areanames{en}->{61392131} = "Dandenong";
$areanames{en}->{61392132} = "Dandenong";
$areanames{en}->{61392133} = "Dandenong";
$areanames{en}->{61392134} = "Dandenong";
$areanames{en}->{61392135} = "Dandenong";
$areanames{en}->{61392136} = "Croydon";
$areanames{en}->{61392137} = "Croydon";
$areanames{en}->{61392138} = "Croydon";
$areanames{en}->{61392139} = "Croydon";
$areanames{en}->{6139214} = "Melbourne";
$areanames{en}->{61392150} = "Croydon";
$areanames{en}->{61392151} = "Dandenong";
$areanames{en}->{61392152} = "Dandenong";
$areanames{en}->{61392153} = "Dandenong";
$areanames{en}->{61392154} = "Dandenong";
$areanames{en}->{61392155} = "Dandenong";
$areanames{en}->{61392156} = "Croydon";
$areanames{en}->{61392157} = "Croydon";
$areanames{en}->{61392158} = "Croydon";
$areanames{en}->{61392159} = "Croydon";
$areanames{en}->{61392160} = "Werribee";
$areanames{en}->{61392161} = "Whittlesea";
$areanames{en}->{61392162} = "Whittlesea";
$areanames{en}->{61392163} = "Kalkallo";
$areanames{en}->{61392164} = "Kalkallo";
$areanames{en}->{61392165} = "Sunbury";
$areanames{en}->{61392166} = "Sunbury";
$areanames{en}->{61392167} = "Werribee";
$areanames{en}->{61392168} = "Werribee";
$areanames{en}->{61392169} = "Sunbury";
$areanames{en}->{61392170} = "Eltham";
$areanames{en}->{61392171} = "Eltham";
$areanames{en}->{61392172} = "Eltham";
$areanames{en}->{61392173} = "Craigieburn";
$areanames{en}->{61392174} = "Craigieburn";
$areanames{en}->{61392175} = "Melbourne";
$areanames{en}->{61392176} = "Sydenham";
$areanames{en}->{61392177} = "Point\ Cook";
$areanames{en}->{61392178} = "Sydenham";
$areanames{en}->{61392179} = "Sydenham";
$areanames{en}->{61392180} = "Whittlesea";
$areanames{en}->{61392181} = "Whittlesea";
$areanames{en}->{61392182} = "Kalkallo";
$areanames{en}->{61392183} = "Sunbury";
$areanames{en}->{61392184} = "Werribee";
$areanames{en}->{61392185} = "Sunbury";
$areanames{en}->{61392186} = "Sunbury";
$areanames{en}->{61392187} = "Sunbury";
$areanames{en}->{61392188} = "Werribee";
$areanames{en}->{61392189} = "Sunbury";
$areanames{en}->{61392190} = "Craigieburn";
$areanames{en}->{61392191} = "Eltham";
$areanames{en}->{61392192} = "Craigieburn";
$areanames{en}->{61392193} = "Sydenham";
$areanames{en}->{61392194} = "Point\ Cook";
$areanames{en}->{61392195} = "Craigieburn";
$areanames{en}->{61392196} = "Craigieburn";
$areanames{en}->{61392197} = "Sydenham";
$areanames{en}->{61392198} = "Eltham";
$areanames{en}->{61392199} = "Eltham";
$areanames{en}->{613922} = "Melbourne";
$areanames{en}->{6139230} = "Melbourne";
$areanames{en}->{6139231} = "Melbourne";
$areanames{en}->{6139232} = "Melbourne";
$areanames{en}->{6139233} = "Melbourne";
$areanames{en}->{61392345} = "Melbourne";
$areanames{en}->{6139235} = "Melbourne";
$areanames{en}->{6139237} = "Croydon";
$areanames{en}->{6139238} = "Dandenong";
$areanames{en}->{6139239} = "Clayton";
$areanames{en}->{6139240} = "Melbourne";
$areanames{en}->{6139241} = "Melbourne";
$areanames{en}->{6139244} = "Melbourne";
$areanames{en}->{61392447} = "Clayton";
$areanames{en}->{6139249} = "Melbourne";
$areanames{en}->{6139250} = "Melbourne";
$areanames{en}->{6139251} = "Melbourne";
$areanames{en}->{6139252} = "Melbourne";
$areanames{en}->{6139253} = "Clayton";
$areanames{en}->{6139254} = "Melbourne";
$areanames{en}->{6139255} = "Melbourne";
$areanames{en}->{61392566} = "Melbourne";
$areanames{en}->{6139257} = "Melbourne";
$areanames{en}->{6139258} = "Melbourne";
$areanames{en}->{6139259} = "Ringwood";
$areanames{en}->{6139260} = "Melbourne";
$areanames{en}->{6139261} = "Melbourne";
$areanames{en}->{61392620} = "Ringwood";
$areanames{en}->{61392621} = "Clayton";
$areanames{en}->{61392622} = "Clayton";
$areanames{en}->{61392623} = "Clayton";
$areanames{en}->{61392624} = "Melbourne";
$areanames{en}->{61392625} = "Clayton";
$areanames{en}->{61392626} = "Ringwood";
$areanames{en}->{61392627} = "Ringwood";
$areanames{en}->{61392628} = "Ringwood";
$areanames{en}->{61392629} = "Melbourne";
$areanames{en}->{6139263} = "Clayton";
$areanames{en}->{61392636} = "Melbourne";
$areanames{en}->{61392640} = "Clayton";
$areanames{en}->{61392641} = "Melbourne";
$areanames{en}->{61392642} = "Melbourne";
$areanames{en}->{61392643} = "Clayton";
$areanames{en}->{61392644} = "Melbourne";
$areanames{en}->{61392645} = "Melbourne";
$areanames{en}->{61392646} = "Ringwood";
$areanames{en}->{61392647} = "Ringwood";
$areanames{en}->{61392648} = "Ringwood";
$areanames{en}->{61392649} = "Clayton";
$areanames{en}->{6139265} = "Clayton";
$areanames{en}->{61392658} = "Melbourne";
$areanames{en}->{6139266} = "Sydenham";
$areanames{en}->{6139267} = "Melbourne";
$areanames{en}->{6139268} = "Melbourne";
$areanames{en}->{6139269} = "Melbourne";
$areanames{en}->{613927} = "Melbourne";
$areanames{en}->{6139271} = "Clayton";
$areanames{en}->{613929} = "Melbourne";
$areanames{en}->{6139293} = "Dandenong";
$areanames{en}->{6139294} = "Croydon";
$areanames{en}->{6139298} = "Ringwood";
$areanames{en}->{613930} = "Melbourne";
$areanames{en}->{6139303} = "Craigieburn";
$areanames{en}->{6139305} = "Craigieburn";
$areanames{en}->{6139307} = "Sydenham";
$areanames{en}->{6139308} = "Craigieburn";
$areanames{en}->{613932} = "Melbourne";
$areanames{en}->{6139323} = "Craigieburn";
$areanames{en}->{6139324} = "Sydenham";
$areanames{en}->{613933} = "Melbourne";
$areanames{en}->{6139333} = "Craigieburn";
$areanames{en}->{6139343} = "Melbourne";
$areanames{en}->{6139346} = "Melbourne";
$areanames{en}->{6139352} = "Melbourne";
$areanames{en}->{613936} = "Melbourne";
$areanames{en}->{61393604} = "Sydenham";
$areanames{en}->{61393605} = "Sydenham";
$areanames{en}->{6139361} = "Sydenham";
$areanames{en}->{6139363} = "Sydenham";
$areanames{en}->{6139378} = "Melbourne";
$areanames{en}->{6139379} = "Melbourne";
$areanames{en}->{6139382} = "Melbourne";
$areanames{en}->{613939} = "Melbourne";
$areanames{en}->{6139390} = "Sydenham";
$areanames{en}->{6139394} = "Point\ Cook";
$areanames{en}->{6139395} = "Point\ Cook";
$areanames{en}->{613940} = "Eltham";
$areanames{en}->{6139400} = "Dandenong";
$areanames{en}->{6139403} = "Melbourne";
$areanames{en}->{6139405} = "Melbourne";
$areanames{en}->{6139406} = "Melbourne";
$areanames{en}->{61394074} = "Melbourne";
$areanames{en}->{61394080} = "Melbourne";
$areanames{en}->{61394082} = "Melbourne";
$areanames{en}->{6139410} = "Melbourne";
$areanames{en}->{613942} = "Melbourne";
$areanames{en}->{6139422} = "Eltham";
$areanames{en}->{6139423} = "Eltham";
$areanames{en}->{6139424} = "Eltham";
$areanames{en}->{613943} = "Eltham";
$areanames{en}->{613944} = "Melbourne";
$areanames{en}->{6139444} = "Eltham";
$areanames{en}->{6139449} = "Sydenham";
$areanames{en}->{613945} = "Melbourne";
$areanames{en}->{6139451} = "Eltham";
$areanames{en}->{613946} = "Melbourne";
$areanames{en}->{6139461} = "Eltham";
$areanames{en}->{6139470} = "Melbourne";
$areanames{en}->{6139471} = "Melbourne";
$areanames{en}->{6139472} = "Melbourne";
$areanames{en}->{6139473} = "Melbourne";
$areanames{en}->{6139474} = "Melbourne";
$areanames{en}->{61394750} = "Melbourne";
$areanames{en}->{61394751} = "Eltham";
$areanames{en}->{61394752} = "Eltham";
$areanames{en}->{61394753} = "Eltham";
$areanames{en}->{6139478} = "Melbourne";
$areanames{en}->{6139479} = "Melbourne";
$areanames{en}->{613948} = "Melbourne";
$areanames{en}->{6139490} = "Melbourne";
$areanames{en}->{6139494} = "Eltham";
$areanames{en}->{6139495} = "Melbourne";
$areanames{en}->{6139496} = "Melbourne";
$areanames{en}->{6139497} = "Melbourne";
$areanames{en}->{6139498} = "Melbourne";
$areanames{en}->{6139499} = "Melbourne";
$areanames{en}->{613950} = "Melbourne";
$areanames{en}->{6139501} = "Clayton";
$areanames{en}->{6139510} = "Melbourne";
$areanames{en}->{6139511} = "Clayton";
$areanames{en}->{6139512} = "Clayton";
$areanames{en}->{6139513} = "Melbourne";
$areanames{en}->{6139514} = "Melbourne";
$areanames{en}->{6139516} = "Melbourne";
$areanames{en}->{6139517} = "Melbourne";
$areanames{en}->{6139518} = "Clayton";
$areanames{en}->{61395182} = "Melbourne";
$areanames{en}->{6139519} = "Melbourne";
$areanames{en}->{613952} = "Melbourne";
$areanames{en}->{613953} = "Melbourne";
$areanames{en}->{6139535} = "Clayton";
$areanames{en}->{6139538} = "Clayton";
$areanames{en}->{613954} = "Clayton";
$areanames{en}->{6139550} = "Clayton";
$areanames{en}->{6139551} = "Clayton";
$areanames{en}->{6139552} = "Clayton";
$areanames{en}->{6139553} = "Melbourne";
$areanames{en}->{6139554} = "Dandenong";
$areanames{en}->{6139555} = "Melbourne";
$areanames{en}->{6139556} = "Melbourne";
$areanames{en}->{6139557} = "Melbourne";
$areanames{en}->{6139558} = "Clayton";
$areanames{en}->{6139559} = "Melbourne";
$areanames{en}->{6139560} = "Clayton";
$areanames{en}->{6139561} = "Clayton";
$areanames{en}->{6139562} = "Clayton";
$areanames{en}->{6139563} = "Melbourne";
$areanames{en}->{6139564} = "Melbourne";
$areanames{en}->{6139565} = "Clayton";
$areanames{en}->{6139566} = "Clayton";
$areanames{en}->{6139567} = "Melbourne";
$areanames{en}->{6139568} = "Melbourne";
$areanames{en}->{6139569} = "Melbourne";
$areanames{en}->{613957} = "Melbourne";
$areanames{en}->{6139574} = "Clayton";
$areanames{en}->{613958} = "Clayton";
$areanames{en}->{613959} = "Melbourne";
$areanames{en}->{6139590} = "Clayton";
$areanames{en}->{6139594} = "Clayton";
$areanames{en}->{6139636} = "Melbourne";
$areanames{en}->{6139677} = "Melbourne";
$areanames{en}->{613970} = "Dandenong";
$areanames{en}->{613971} = "Whittlesea";
$areanames{en}->{6139711} = "Dandenong";
$areanames{en}->{6139713} = "Dandenong";
$areanames{en}->{613972} = "Croydon";
$areanames{en}->{613973} = "Croydon";
$areanames{en}->{6139731} = "Werribee";
$areanames{en}->{6139732} = "Sunbury";
$areanames{en}->{6139734} = "Werribee";
$areanames{en}->{6139740} = "Sunbury";
$areanames{en}->{6139741} = "Werribee";
$areanames{en}->{6139742} = "Werribee";
$areanames{en}->{6139743} = "Sunbury";
$areanames{en}->{6139744} = "Sunbury";
$areanames{en}->{6139745} = "Kalkallo";
$areanames{en}->{6139746} = "Sunbury";
$areanames{en}->{6139747} = "Sunbury";
$areanames{en}->{6139748} = "Werribee";
$areanames{en}->{6139749} = "Werribee";
$areanames{en}->{613975} = "Croydon";
$areanames{en}->{6139750} = "Dandenong";
$areanames{en}->{613976} = "Croydon";
$areanames{en}->{6139766} = "Dandenong";
$areanames{en}->{6139767} = "Dandenong";
$areanames{en}->{6139768} = "Dandenong";
$areanames{en}->{6139769} = "Dandenong";
$areanames{en}->{613977} = "Dandenong";
$areanames{en}->{6139777} = "Croydon";
$areanames{en}->{6139778} = "Croydon";
$areanames{en}->{6139779} = "Croydon";
$areanames{en}->{613978} = "Dandenong";
$areanames{en}->{6139780} = "Croydon";
$areanames{en}->{613980} = "Melbourne";
$areanames{en}->{6139800} = "Ringwood";
$areanames{en}->{6139801} = "Ringwood";
$areanames{en}->{6139802} = "Ringwood";
$areanames{en}->{6139803} = "Ringwood";
$areanames{en}->{613981} = "Melbourne";
$areanames{en}->{6139812} = "Ringwood";
$areanames{en}->{6139814} = "Ringwood";
$areanames{en}->{613983} = "Melbourne";
$areanames{en}->{6139837} = "Ringwood";
$areanames{en}->{6139839} = "Croydon";
$areanames{en}->{6139840} = "Melbourne";
$areanames{en}->{6139841} = "Ringwood";
$areanames{en}->{61398411} = "Melbourne";
$areanames{en}->{6139843} = "Melbourne";
$areanames{en}->{6139844} = "Ringwood";
$areanames{en}->{6139845} = "Ringwood";
$areanames{en}->{6139846} = "Ringwood";
$areanames{en}->{61398460} = "Melbourne";
$areanames{en}->{6139847} = "Ringwood";
$areanames{en}->{6139848} = "Melbourne";
$areanames{en}->{6139849} = "Melbourne";
$areanames{en}->{6139858} = "Melbourne";
$areanames{en}->{6139859} = "Melbourne";
$areanames{en}->{613987} = "Ringwood";
$areanames{en}->{6139875} = "Melbourne";
$areanames{en}->{6139880} = "Melbourne";
$areanames{en}->{6139881} = "Melbourne";
$areanames{en}->{61398810} = "Ringwood";
$areanames{en}->{61398817} = "Ringwood";
$areanames{en}->{61398819} = "Ringwood";
$areanames{en}->{6139882} = "Melbourne";
$areanames{en}->{6139883} = "Melbourne";
$areanames{en}->{6139884} = "Ringwood";
$areanames{en}->{6139886} = "Ringwood";
$areanames{en}->{61398860} = "Melbourne";
$areanames{en}->{61398869} = "Melbourne";
$areanames{en}->{6139887} = "Ringwood";
$areanames{en}->{6139888} = "Melbourne";
$areanames{en}->{6139889} = "Melbourne";
$areanames{en}->{613989} = "Melbourne";
$areanames{en}->{6139893} = "Ringwood";
$areanames{en}->{6139894} = "Ringwood";
$areanames{en}->{613990} = "Melbourne";
$areanames{en}->{6139902} = "Clayton";
$areanames{en}->{6139904} = "Dandenong";
$areanames{en}->{6139905} = "Clayton";
$areanames{en}->{6139910} = "Melbourne";
$areanames{en}->{6139911} = "Melbourne";
$areanames{en}->{6139912} = "Melbourne";
$areanames{en}->{6139913} = "Melbourne";
$areanames{en}->{6139914} = "Melbourne";
$areanames{en}->{613991500} = "Melbourne";
$areanames{en}->{613991501} = "Clayton";
$areanames{en}->{613991510} = "Melbourne";
$areanames{en}->{613991511} = "Croydon";
$areanames{en}->{61399152} = "Melbourne";
$areanames{en}->{61399153} = "Melbourne";
$areanames{en}->{61399154} = "Melbourne";
$areanames{en}->{613991567} = "Ringwood";
$areanames{en}->{61399157} = "Melbourne";
$areanames{en}->{61399158} = "Melbourne";
$areanames{en}->{61399159} = "Melbourne";
$areanames{en}->{6139916} = "Melbourne";
$areanames{en}->{61399170} = "Melbourne";
$areanames{en}->{61399171} = "Melbourne";
$areanames{en}->{61399172} = "Melbourne";
$areanames{en}->{6139918} = "Melbourne";
$areanames{en}->{6139919} = "Melbourne";
$areanames{en}->{6139923} = "Melbourne";
$areanames{en}->{613993} = "Melbourne";
$areanames{en}->{6139930} = "Craigieburn";
$areanames{en}->{6139941} = "Melbourne";
$areanames{en}->{6139944} = "Melbourne";
$areanames{en}->{6139950} = "Melbourne";
$areanames{en}->{6139951} = "Melbourne";
$areanames{en}->{6139952} = "Melbourne";
$areanames{en}->{6139953} = "Melbourne";
$areanames{en}->{6139954} = "Melbourne";
$areanames{en}->{6139955} = "Ringwood";
$areanames{en}->{6139956} = "Melbourne";
$areanames{en}->{6139963} = "Melbourne";
$areanames{en}->{6139964} = "Melbourne";
$areanames{en}->{6139965} = "Melbourne";
$areanames{en}->{6139966} = "Melbourne";
$areanames{en}->{6139971} = "Sunbury";
$areanames{en}->{6139972} = "Melbourne";
$areanames{en}->{61399720} = "Sydenham";
$areanames{en}->{6139973} = "Melbourne";
$areanames{en}->{6139974} = "Werribee";
$areanames{en}->{6139975} = "Melbourne";
$areanames{en}->{6139976} = "Melbourne";
$areanames{en}->{6139977} = "Melbourne";
$areanames{en}->{6139978} = "Melbourne";
$areanames{en}->{6139981} = "Melbourne";
$areanames{en}->{6139982} = "Melbourne";
$areanames{en}->{61399830} = "Melbourne";
$areanames{en}->{61399831} = "Melbourne";
$areanames{en}->{61399832} = "Melbourne";
$areanames{en}->{61399833} = "Melbourne";
$areanames{en}->{61399834} = "Melbourne";
$areanames{en}->{6139988} = "Melbourne";
$areanames{en}->{6139989} = "Melbourne";
$areanames{en}->{6139993} = "Melbourne";
$areanames{en}->{6139994} = "Melbourne";
$areanames{en}->{61399940} = "Point\ Cook";
$areanames{en}->{61399941} = "Craigieburn";
$areanames{en}->{6139995} = "Melbourne";
$areanames{en}->{61399960} = "Melbourne";
$areanames{en}->{61399961} = "Melbourne";
$areanames{en}->{61399966} = "Melbourne";
$areanames{en}->{6139998} = "Melbourne";
$areanames{en}->{6139999} = "Melbourne";
$areanames{en}->{61720000} = "Redcliffe";
$areanames{en}->{61720001} = "Samford";
$areanames{en}->{61720002} = "Redcliffe";
$areanames{en}->{61720003} = "Samford";
$areanames{en}->{61720004} = "Redcliffe";
$areanames{en}->{61720005} = "Samford";
$areanames{en}->{61720006} = "Redcliffe";
$areanames{en}->{61720007} = "Samford";
$areanames{en}->{61720008} = "Redcliffe";
$areanames{en}->{61720009} = "Samford";
$areanames{en}->{61721000} = "Brisbane";
$areanames{en}->{61721001} = "Brisbane";
$areanames{en}->{61721002} = "Brisbane";
$areanames{en}->{61721003} = "Brisbane";
$areanames{en}->{6172101} = "Brisbane";
$areanames{en}->{6172102} = "Brisbane";
$areanames{en}->{6172103} = "Brisbane";
$areanames{en}->{6172104} = "Brisbane";
$areanames{en}->{61728000} = "Beenleigh";
$areanames{en}->{61728001} = "Cleveland";
$areanames{en}->{61728002} = "Ipswich";
$areanames{en}->{61728003} = "Beenleigh";
$areanames{en}->{61728004} = "Cleveland";
$areanames{en}->{61728005} = "Ipswich";
$areanames{en}->{61728006} = "Beenleigh";
$areanames{en}->{61728007} = "Cleveland";
$areanames{en}->{61728008} = "Ipswich";
$areanames{en}->{61728009} = "Beenleigh";
$areanames{en}->{61728010} = "Cleveland";
$areanames{en}->{61728011} = "Ipswich";
$areanames{en}->{61728012} = "Beenleigh";
$areanames{en}->{61728013} = "Cleveland";
$areanames{en}->{61728014} = "Ipswich";
$areanames{en}->{61728015} = "Beenleigh";
$areanames{en}->{61728016} = "Cleveland";
$areanames{en}->{61728017} = "Ipswich";
$areanames{en}->{61728018} = "Beenleigh";
$areanames{en}->{61728019} = "Cleveland";
$areanames{en}->{61728020} = "Ipswich";
$areanames{en}->{61728021} = "Beenleigh";
$areanames{en}->{61728022} = "Cleveland";
$areanames{en}->{61728023} = "Ipswich";
$areanames{en}->{6172889} = "Beenleigh";
$areanames{en}->{6172891} = "Beenleigh";
$areanames{en}->{6173018} = "Brisbane";
$areanames{en}->{6173019} = "Brisbane";
$areanames{en}->{617303} = "Brisbane";
$areanames{en}->{61730380} = "Samford";
$areanames{en}->{61730381} = "Cleveland";
$areanames{en}->{61730382} = "Beenleigh";
$areanames{en}->{61730385} = "Beenleigh";
$areanames{en}->{61730386} = "Cleveland";
$areanames{en}->{61730387} = "Ipswich";
$areanames{en}->{61730388} = "Redcliffe";
$areanames{en}->{61730389} = "Samford";
$areanames{en}->{61730396} = "Ipswich";
$areanames{en}->{61730397} = "Ipswich";
$areanames{en}->{61730398} = "Redcliffe";
$areanames{en}->{61730399} = "Redcliffe";
$areanames{en}->{6173040} = "Brisbane";
$areanames{en}->{6173041} = "Brisbane";
$areanames{en}->{6173042} = "Cleveland";
$areanames{en}->{6173043} = "Beenleigh";
$areanames{en}->{6173044} = "Ipswich";
$areanames{en}->{6173045} = "Redcliffe";
$areanames{en}->{6173046} = "Brisbane";
$areanames{en}->{6173047} = "Cleveland";
$areanames{en}->{6173048} = "Redcliffe";
$areanames{en}->{6173049} = "Redcliffe";
$areanames{en}->{617305} = "Brisbane";
$areanames{en}->{61730500} = "Beenleigh";
$areanames{en}->{61730501} = "Redcliffe";
$areanames{en}->{61730502} = "Ipswich";
$areanames{en}->{61730503} = "Cleveland";
$areanames{en}->{61730504} = "Ipswich";
$areanames{en}->{61730505} = "Beenleigh";
$areanames{en}->{61730506} = "Samford";
$areanames{en}->{61730507} = "Ipswich";
$areanames{en}->{61730508} = "Cleveland";
$areanames{en}->{61730509} = "Cleveland";
$areanames{en}->{61730530} = "Cleveland";
$areanames{en}->{61730531} = "Cleveland";
$areanames{en}->{61730532} = "Cleveland";
$areanames{en}->{61730533} = "Redcliffe";
$areanames{en}->{61730534} = "Beenleigh";
$areanames{en}->{61730536} = "Ipswich";
$areanames{en}->{61730537} = "Cleveland";
$areanames{en}->{61730539} = "Beenleigh";
$areanames{en}->{61730590} = "Beenleigh";
$areanames{en}->{61730591} = "Beenleigh";
$areanames{en}->{61730592} = "Beenleigh";
$areanames{en}->{61730593} = "Redcliffe";
$areanames{en}->{61730594} = "Samford";
$areanames{en}->{61730595} = "Beenleigh";
$areanames{en}->{61730597} = "Ipswich";
$areanames{en}->{61730600} = "Brisbane";
$areanames{en}->{61730601} = "Samford";
$areanames{en}->{61730602} = "Redcliffe";
$areanames{en}->{61730603} = "Cleveland";
$areanames{en}->{61730604} = "Ipswich";
$areanames{en}->{61730605} = "Beenleigh";
$areanames{en}->{61730606} = "Samford";
$areanames{en}->{61730607} = "Redcliffe";
$areanames{en}->{61730608} = "Cleveland";
$areanames{en}->{61730609} = "Ipswich";
$areanames{en}->{6173061} = "Brisbane";
$areanames{en}->{61730610} = "Redcliffe";
$areanames{en}->{61730611} = "Samford";
$areanames{en}->{61730640} = "Brisbane";
$areanames{en}->{61730641} = "Brisbane";
$areanames{en}->{61730642} = "Bribie\ Island";
$areanames{en}->{61730643} = "Brisbane";
$areanames{en}->{61730644} = "Dayboro";
$areanames{en}->{61730645} = "Dunwich";
$areanames{en}->{61730646} = "Kooringal";
$areanames{en}->{61730647} = "Redcliffe";
$areanames{en}->{61730648} = "Russell\ Island";
$areanames{en}->{61730649} = "Samford";
$areanames{en}->{61730650} = "Bribie\ Island";
$areanames{en}->{61730651} = "Brisbane";
$areanames{en}->{61730652} = "Dayboro";
$areanames{en}->{61730653} = "Dunwich";
$areanames{en}->{61730654} = "Kooringal";
$areanames{en}->{61730655} = "Redcliffe";
$areanames{en}->{61730656} = "Russell\ Island";
$areanames{en}->{61730657} = "Samford";
$areanames{en}->{61730658} = "Bribie\ Island";
$areanames{en}->{61730659} = "Brisbane";
$areanames{en}->{6173066} = "Brisbane";
$areanames{en}->{6173067} = "Brisbane";
$areanames{en}->{6173068} = "Brisbane";
$areanames{en}->{6173069} = "Brisbane";
$areanames{en}->{6173070} = "Brisbane";
$areanames{en}->{6173071} = "Brisbane";
$areanames{en}->{6173072} = "Brisbane";
$areanames{en}->{6173073} = "Brisbane";
$areanames{en}->{6173074} = "Brisbane";
$areanames{en}->{6173077} = "Brisbane";
$areanames{en}->{61730775} = "Dayboro";
$areanames{en}->{6173078} = "Beenleigh";
$areanames{en}->{6173079} = "Brisbane";
$areanames{en}->{617308} = "Brisbane";
$areanames{en}->{6173080} = "Beenleigh";
$areanames{en}->{61730800} = "Dunwich";
$areanames{en}->{61730801} = "Kooringal";
$areanames{en}->{6173081} = "Beenleigh";
$areanames{en}->{61730810} = "Russell\ Island";
$areanames{en}->{61730811} = "Bribie\ Island";
$areanames{en}->{61730819} = "Bribie\ Island";
$areanames{en}->{6173086} = "Beenleigh";
$areanames{en}->{61730860} = "Cleveland";
$areanames{en}->{61730861} = "Cleveland";
$areanames{en}->{61730880} = "Dayboro";
$areanames{en}->{6173089} = "Beenleigh";
$areanames{en}->{6173090} = "Beenleigh";
$areanames{en}->{6173091} = "Ipswich";
$areanames{en}->{61730920} = "Redcliffe";
$areanames{en}->{61730921} = "Redcliffe";
$areanames{en}->{61730922} = "Redcliffe";
$areanames{en}->{61730923} = "Brisbane";
$areanames{en}->{61730924} = "Dunwich";
$areanames{en}->{61730925} = "Kooringal";
$areanames{en}->{61730926} = "Redcliffe";
$areanames{en}->{61730927} = "Russell\ Island";
$areanames{en}->{61730928} = "Samford";
$areanames{en}->{61730929} = "Redcliffe";
$areanames{en}->{6173093} = "Redcliffe";
$areanames{en}->{61730937} = "Bribie\ Island";
$areanames{en}->{61730938} = "Brisbane";
$areanames{en}->{61730939} = "Dayboro";
$areanames{en}->{61730940} = "Redcliffe";
$areanames{en}->{61730941} = "Redcliffe";
$areanames{en}->{61730942} = "Redcliffe";
$areanames{en}->{61730943} = "Redcliffe";
$areanames{en}->{61730944} = "Redcliffe";
$areanames{en}->{61730945} = "Beenleigh";
$areanames{en}->{61730946} = "Beenleigh";
$areanames{en}->{61730947} = "Beenleigh";
$areanames{en}->{61730948} = "Beenleigh";
$areanames{en}->{61730949} = "Beenleigh";
$areanames{en}->{6173095} = "Ipswich";
$areanames{en}->{6173096} = "Brisbane";
$areanames{en}->{6173097} = "Brisbane";
$areanames{en}->{6173098} = "Ipswich";
$areanames{en}->{61730992} = "Brisbane";
$areanames{en}->{61731023} = "Brisbane";
$areanames{en}->{6173105} = "Brisbane";
$areanames{en}->{6173106} = "Brisbane";
$areanames{en}->{6173109} = "Brisbane";
$areanames{en}->{617311} = "Brisbane";
$areanames{en}->{61731131} = "Sandgate";
$areanames{en}->{61731132} = "Sandgate";
$areanames{en}->{6173122} = "Brisbane";
$areanames{en}->{6173123} = "Brisbane";
$areanames{en}->{6173124} = "Brisbane";
$areanames{en}->{6173128} = "Brisbane";
$areanames{en}->{6173129} = "Brisbane";
$areanames{en}->{617313} = "Brisbane";
$areanames{en}->{6173133} = "Beenleigh";
$areanames{en}->{6173134} = "Cleveland";
$areanames{en}->{617314} = "Brisbane";
$areanames{en}->{6173140} = "Sandgate";
$areanames{en}->{6173141} = "Samford";
$areanames{en}->{6173142} = "Redcliffe";
$areanames{en}->{6173143} = "Ipswich";
$areanames{en}->{61731500} = "Brisbane";
$areanames{en}->{61731501} = "Brisbane";
$areanames{en}->{61731502} = "Sandgate";
$areanames{en}->{61731503} = "Sandgate";
$areanames{en}->{61731504} = "Sandgate";
$areanames{en}->{61731505} = "Dunwich";
$areanames{en}->{61731506} = "Sandgate";
$areanames{en}->{61731507} = "Brisbane";
$areanames{en}->{61731508} = "Brisbane";
$areanames{en}->{61731509} = "Brisbane";
$areanames{en}->{6173151} = "Brisbane";
$areanames{en}->{6173152} = "Brisbane";
$areanames{en}->{61731522} = "Ipswich";
$areanames{en}->{6173155} = "Brisbane";
$areanames{en}->{61731558} = "Kooringal";
$areanames{en}->{61731559} = "Russell\ Island";
$areanames{en}->{6173156} = "Brisbane";
$areanames{en}->{6173157} = "Brisbane";
$areanames{en}->{6173158} = "Brisbane";
$areanames{en}->{6173159} = "Brisbane";
$areanames{en}->{61731592} = "Bribie\ Island";
$areanames{en}->{61731594} = "Dayboro";
$areanames{en}->{6173160} = "Brisbane";
$areanames{en}->{617317} = "Brisbane";
$areanames{en}->{61731790} = "Dunwich";
$areanames{en}->{61731796} = "Kooringal";
$areanames{en}->{61731797} = "Russell\ Island";
$areanames{en}->{61731798} = "Bribie\ Island";
$areanames{en}->{617318} = "Brisbane";
$areanames{en}->{61731870} = "Dayboro";
$areanames{en}->{61731871} = "Dunwich";
$areanames{en}->{61731872} = "Kooringal";
$areanames{en}->{61731873} = "Russell\ Island";
$areanames{en}->{61731874} = "Bribie\ Island";
$areanames{en}->{61731876} = "Dayboro";
$areanames{en}->{61731877} = "Dunwich";
$areanames{en}->{61731878} = "Kooringal";
$areanames{en}->{6173190} = "Brisbane";
$areanames{en}->{6173191} = "Brisbane";
$areanames{en}->{6173192} = "Brisbane";
$areanames{en}->{6173193} = "Brisbane";
$areanames{en}->{6173196} = "Brisbane";
$areanames{en}->{6173197} = "Brisbane";
$areanames{en}->{6173200} = "Beenleigh";
$areanames{en}->{6173201} = "Ipswich";
$areanames{en}->{6173202} = "Ipswich";
$areanames{en}->{6173203} = "Redcliffe";
$areanames{en}->{6173204} = "Redcliffe";
$areanames{en}->{6173205} = "Redcliffe";
$areanames{en}->{6173206} = "Cleveland";
$areanames{en}->{6173207} = "Cleveland";
$areanames{en}->{6173208} = "Beenleigh";
$areanames{en}->{6173209} = "Beenleigh";
$areanames{en}->{617322} = "Brisbane";
$areanames{en}->{617323} = "Brisbane";
$areanames{en}->{617326} = "Brisbane";
$areanames{en}->{6173261} = "Sandgate";
$areanames{en}->{6173269} = "Sandgate";
$areanames{en}->{6173280} = "Ipswich";
$areanames{en}->{6173281} = "Ipswich";
$areanames{en}->{6173282} = "Ipswich";
$areanames{en}->{6173283} = "Redcliffe";
$areanames{en}->{6173284} = "Redcliffe";
$areanames{en}->{6173285} = "Redcliffe";
$areanames{en}->{6173286} = "Cleveland";
$areanames{en}->{6173287} = "Beenleigh";
$areanames{en}->{6173288} = "Ipswich";
$areanames{en}->{6173289} = "Samford";
$areanames{en}->{6173290} = "Beenleigh";
$areanames{en}->{6173291} = "Brisbane";
$areanames{en}->{6173292} = "Brisbane";
$areanames{en}->{6173293} = "Redcliffe";
$areanames{en}->{6173294} = "Ipswich";
$areanames{en}->{6173295} = "Brisbane";
$areanames{en}->{6173296} = "Brisbane";
$areanames{en}->{6173297} = "Beenleigh";
$areanames{en}->{6173298} = "Samford";
$areanames{en}->{6173299} = "Beenleigh";
$areanames{en}->{6173300} = "Brisbane";
$areanames{en}->{61733095} = "Brisbane";
$areanames{en}->{61733099} = "Brisbane";
$areanames{en}->{6173316} = "Brisbane";
$areanames{en}->{6173319} = "Brisbane";
$areanames{en}->{6173322} = "Brisbane";
$areanames{en}->{6173330} = "Brisbane";
$areanames{en}->{6173333} = "Brisbane";
$areanames{en}->{6173342} = "Brisbane";
$areanames{en}->{617335} = "Brisbane";
$areanames{en}->{617336} = "Brisbane";
$areanames{en}->{6173380} = "Beenleigh";
$areanames{en}->{6173381} = "Ipswich";
$areanames{en}->{6173382} = "Beenleigh";
$areanames{en}->{6173383} = "Cleveland";
$areanames{en}->{6173384} = "Redcliffe";
$areanames{en}->{6173385} = "Redcliffe";
$areanames{en}->{6173386} = "Beenleigh";
$areanames{en}->{6173387} = "Beenleigh";
$areanames{en}->{6173388} = "Beenleigh";
$areanames{en}->{6173389} = "Ipswich";
$areanames{en}->{61733898} = "Beenleigh";
$areanames{en}->{61733899} = "Beenleigh";
$areanames{en}->{61734000} = "Kooringal";
$areanames{en}->{61734001} = "Kooringal";
$areanames{en}->{61734002} = "Kooringal";
$areanames{en}->{61734003} = "Kooringal";
$areanames{en}->{61734004} = "Dayboro";
$areanames{en}->{61734005} = "Dayboro";
$areanames{en}->{61734006} = "Dunwich";
$areanames{en}->{61734007} = "Dunwich";
$areanames{en}->{61734008} = "Russell\ Island";
$areanames{en}->{61734009} = "Russell\ Island";
$areanames{en}->{6173401} = "Cleveland";
$areanames{en}->{6173402} = "Beenleigh";
$areanames{en}->{6173403} = "Brisbane";
$areanames{en}->{6173404} = "Brisbane";
$areanames{en}->{6173405} = "Brisbane";
$areanames{en}->{6173406} = "Brisbane";
$areanames{en}->{6173407} = "Brisbane";
$areanames{en}->{6173408} = "Bribie\ Island";
$areanames{en}->{61734090} = "Kooringal";
$areanames{en}->{61734091} = "Russell\ Island";
$areanames{en}->{61734092} = "Russell\ Island";
$areanames{en}->{61734093} = "Kooringal";
$areanames{en}->{61734094} = "Russell\ Island";
$areanames{en}->{61734095} = "Russell\ Island";
$areanames{en}->{61734096} = "Dunwich";
$areanames{en}->{61734097} = "Dunwich";
$areanames{en}->{61734098} = "Dunwich";
$areanames{en}->{61734099} = "Dunwich";
$areanames{en}->{6173410} = "Bribie\ Island";
$areanames{en}->{6173411} = "Brisbane";
$areanames{en}->{6173412} = "Beenleigh";
$areanames{en}->{6173413} = "Ipswich";
$areanames{en}->{6173414} = "Brisbane";
$areanames{en}->{61734150} = "Dunwich";
$areanames{en}->{61734151} = "Dunwich";
$areanames{en}->{61734152} = "Dunwich";
$areanames{en}->{61734153} = "Dunwich";
$areanames{en}->{61734154} = "Kooringal";
$areanames{en}->{61734155} = "Kooringal";
$areanames{en}->{61734156} = "Russell\ Island";
$areanames{en}->{61734157} = "Russell\ Island";
$areanames{en}->{61734158} = "Russell\ Island";
$areanames{en}->{61734159} = "Russell\ Island";
$areanames{en}->{6173416} = "Beenleigh";
$areanames{en}->{6173417} = "Cleveland";
$areanames{en}->{6173418} = "Ipswich";
$areanames{en}->{6173419} = "Redcliffe";
$areanames{en}->{617342} = "Brisbane";
$areanames{en}->{6173424} = "Ipswich";
$areanames{en}->{6173425} = "Dayboro";
$areanames{en}->{6173427} = "Beenleigh";
$areanames{en}->{6173428} = "Ipswich";
$areanames{en}->{6173430} = "Samford";
$areanames{en}->{6173431} = "Samford";
$areanames{en}->{6173432} = "Ipswich";
$areanames{en}->{6173433} = "Cleveland";
$areanames{en}->{6173434} = "Brisbane";
$areanames{en}->{6173435} = "Brisbane";
$areanames{en}->{6173436} = "Ipswich";
$areanames{en}->{6173437} = "Ipswich";
$areanames{en}->{61734380} = "Bribie\ Island";
$areanames{en}->{61734381} = "Bribie\ Island";
$areanames{en}->{61734382} = "Bribie\ Island";
$areanames{en}->{61734383} = "Dayboro";
$areanames{en}->{61734384} = "Dayboro";
$areanames{en}->{61734385} = "Dayboro";
$areanames{en}->{61734386} = "Dunwich";
$areanames{en}->{61734387} = "Dunwich";
$areanames{en}->{61734388} = "Dunwich";
$areanames{en}->{61734389} = "Beenleigh";
$areanames{en}->{61734390} = "Kooringal";
$areanames{en}->{61734391} = "Kooringal";
$areanames{en}->{61734392} = "Kooringal";
$areanames{en}->{61734393} = "Russell\ Island";
$areanames{en}->{61734394} = "Russell\ Island";
$areanames{en}->{61734395} = "Russell\ Island";
$areanames{en}->{61734396} = "Beenleigh";
$areanames{en}->{61734397} = "Beenleigh";
$areanames{en}->{61734398} = "Beenleigh";
$areanames{en}->{61734399} = "Cleveland";
$areanames{en}->{6173440} = "Beenleigh";
$areanames{en}->{6173441} = "Beenleigh";
$areanames{en}->{6173442} = "Beenleigh";
$areanames{en}->{6173443} = "Brisbane";
$areanames{en}->{61734440} = "Beenleigh";
$areanames{en}->{61734441} = "Ipswich";
$areanames{en}->{61734442} = "Ipswich";
$areanames{en}->{61734443} = "Ipswich";
$areanames{en}->{61734444} = "Ipswich";
$areanames{en}->{61734445} = "Bribie\ Island";
$areanames{en}->{61734446} = "Beenleigh";
$areanames{en}->{61734447} = "Beenleigh";
$areanames{en}->{61734448} = "Beenleigh";
$areanames{en}->{61734449} = "Russell\ Island";
$areanames{en}->{6173445} = "Beenleigh";
$areanames{en}->{6173446} = "Cleveland";
$areanames{en}->{6173447} = "Ipswich";
$areanames{en}->{6173448} = "Redcliffe";
$areanames{en}->{6173449} = "Samford";
$areanames{en}->{61734500} = "Bribie\ Island";
$areanames{en}->{61734501} = "Dunwich";
$areanames{en}->{61734502} = "Kooringal";
$areanames{en}->{61734503} = "Russell\ Island";
$areanames{en}->{61734504} = "Bribie\ Island";
$areanames{en}->{61734505} = "Dunwich";
$areanames{en}->{61734506} = "Kooringal";
$areanames{en}->{61734507} = "Russell\ Island";
$areanames{en}->{61734508} = "Dayboro";
$areanames{en}->{61734509} = "Ipswich";
$areanames{en}->{6173451} = "Beenleigh";
$areanames{en}->{6173452} = "Brisbane";
$areanames{en}->{6173453} = "Redcliffe";
$areanames{en}->{6173454} = "Ipswich";
$areanames{en}->{6173455} = "Brisbane";
$areanames{en}->{6173456} = "Brisbane";
$areanames{en}->{6173457} = "Brisbane";
$areanames{en}->{6173458} = "Beenleigh";
$areanames{en}->{6173459} = "Cleveland";
$areanames{en}->{6173460} = "Brisbane";
$areanames{en}->{6173461} = "Cleveland";
$areanames{en}->{6173462} = "Beenleigh";
$areanames{en}->{6173463} = "Ipswich";
$areanames{en}->{6173464} = "Samford";
$areanames{en}->{6173465} = "Redcliffe";
$areanames{en}->{6173466} = "Ipswich";
$areanames{en}->{6173467} = "Redcliffe";
$areanames{en}->{6173468} = "Samford";
$areanames{en}->{61734690} = "Bribie\ Island";
$areanames{en}->{61734691} = "Dunwich";
$areanames{en}->{61734692} = "Kooringal";
$areanames{en}->{61734693} = "Russell\ Island";
$areanames{en}->{61734694} = "Dayboro";
$areanames{en}->{61734695} = "Bribie\ Island";
$areanames{en}->{61734696} = "Dunwich";
$areanames{en}->{61734697} = "Kooringal";
$areanames{en}->{61734698} = "Russell\ Island";
$areanames{en}->{61734699} = "Dayboro";
$areanames{en}->{6173470} = "Ipswich";
$areanames{en}->{61734710} = "Bribie\ Island";
$areanames{en}->{61734711} = "Dunwich";
$areanames{en}->{61734712} = "Kooringal";
$areanames{en}->{61734713} = "Russell\ Island";
$areanames{en}->{61734714} = "Dayboro";
$areanames{en}->{61734715} = "Bribie\ Island";
$areanames{en}->{61734716} = "Dunwich";
$areanames{en}->{61734717} = "Kooringal";
$areanames{en}->{61734718} = "Russell\ Island";
$areanames{en}->{61734719} = "Dayboro";
$areanames{en}->{61734720} = "Beenleigh";
$areanames{en}->{61734721} = "Cleveland";
$areanames{en}->{61734722} = "Ipswich";
$areanames{en}->{61734723} = "Redcliffe";
$areanames{en}->{61734724} = "Samford";
$areanames{en}->{61734725} = "Beenleigh";
$areanames{en}->{61734726} = "Beenleigh";
$areanames{en}->{61734727} = "Cleveland";
$areanames{en}->{61734728} = "Ipswich";
$areanames{en}->{61734729} = "Redcliffe";
$areanames{en}->{61734730} = "Samford";
$areanames{en}->{61734731} = "Bribie\ Island";
$areanames{en}->{61734732} = "Dunwich";
$areanames{en}->{61734733} = "Kooringal";
$areanames{en}->{61734734} = "Russell\ Island";
$areanames{en}->{61734735} = "Dayboro";
$areanames{en}->{61734736} = "Russell\ Island";
$areanames{en}->{61734737} = "Bribie\ Island";
$areanames{en}->{61734738} = "Dunwich";
$areanames{en}->{61734739} = "Kooringal";
$areanames{en}->{61734740} = "Russell\ Island";
$areanames{en}->{61734741} = "Dayboro";
$areanames{en}->{61734742} = "Bribie\ Island";
$areanames{en}->{61734743} = "Kooringal";
$areanames{en}->{61734744} = "Samford";
$areanames{en}->{61734745} = "Redcliffe";
$areanames{en}->{61734746} = "Ipswich";
$areanames{en}->{61734747} = "Bribie\ Island";
$areanames{en}->{61734748} = "Bribie\ Island";
$areanames{en}->{61734749} = "Dunwich";
$areanames{en}->{61734750} = "Dunwich";
$areanames{en}->{61734751} = "Russell\ Island";
$areanames{en}->{61734752} = "Dunwich";
$areanames{en}->{61734753} = "Bribie\ Island";
$areanames{en}->{61734754} = "Bribie\ Island";
$areanames{en}->{61734755} = "Dunwich";
$areanames{en}->{61734756} = "Kooringal";
$areanames{en}->{61734757} = "Russell\ Island";
$areanames{en}->{61734758} = "Dayboro";
$areanames{en}->{61734759} = "Bribie\ Island";
$areanames{en}->{6173476} = "Samford";
$areanames{en}->{61734770} = "Kooringal";
$areanames{en}->{61734771} = "Kooringal";
$areanames{en}->{61734772} = "Samford";
$areanames{en}->{61734773} = "Samford";
$areanames{en}->{61734774} = "Samford";
$areanames{en}->{61734775} = "Russell\ Island";
$areanames{en}->{61734776} = "Dayboro";
$areanames{en}->{61734777} = "Kooringal";
$areanames{en}->{61734778} = "Bribie\ Island";
$areanames{en}->{61734781} = "Russell\ Island";
$areanames{en}->{61734782} = "Kooringal";
$areanames{en}->{61734783} = "Dunwich";
$areanames{en}->{61734785} = "Dunwich";
$areanames{en}->{61734786} = "Dunwich";
$areanames{en}->{61734787} = "Kooringal";
$areanames{en}->{61734788} = "Dunwich";
$areanames{en}->{61734789} = "Bribie\ Island";
$areanames{en}->{6173479} = "Cleveland";
$areanames{en}->{6173480} = "Redcliffe";
$areanames{en}->{6173481} = "Redcliffe";
$areanames{en}->{6173482} = "Redcliffe";
$areanames{en}->{6173483} = "Cleveland";
$areanames{en}->{6173484} = "Beenleigh";
$areanames{en}->{6173485} = "Ipswich";
$areanames{en}->{6173486} = "Samford";
$areanames{en}->{6173487} = "Redcliffe";
$areanames{en}->{6173488} = "Cleveland";
$areanames{en}->{6173489} = "Beenleigh";
$areanames{en}->{6173490} = "Redcliffe";
$areanames{en}->{6173491} = "Redcliffe";
$areanames{en}->{61734920} = "Redcliffe";
$areanames{en}->{61734921} = "Redcliffe";
$areanames{en}->{61734922} = "Redcliffe";
$areanames{en}->{61734923} = "Samford";
$areanames{en}->{61734924} = "Bribie\ Island";
$areanames{en}->{61734925} = "Dunwich";
$areanames{en}->{61734926} = "Kooringal";
$areanames{en}->{61734927} = "Russell\ Island";
$areanames{en}->{61734928} = "Dayboro";
$areanames{en}->{61734929} = "Ipswich";
$areanames{en}->{6173493} = "Brisbane";
$areanames{en}->{6173494} = "Samford";
$areanames{en}->{61734950} = "Redcliffe";
$areanames{en}->{61734951} = "Cleveland";
$areanames{en}->{61734952} = "Ipswich";
$areanames{en}->{61734953} = "Redcliffe";
$areanames{en}->{61734954} = "Samford";
$areanames{en}->{61734955} = "Beenleigh";
$areanames{en}->{61734956} = "Cleveland";
$areanames{en}->{61734957} = "Ipswich";
$areanames{en}->{61734958} = "Redcliffe";
$areanames{en}->{61734959} = "Samford";
$areanames{en}->{61734960} = "Cleveland";
$areanames{en}->{61734961} = "Ipswich";
$areanames{en}->{61734962} = "Redcliffe";
$areanames{en}->{61734963} = "Dayboro";
$areanames{en}->{61734964} = "Dayboro";
$areanames{en}->{61734965} = "Russell\ Island";
$areanames{en}->{61734966} = "Russell\ Island";
$areanames{en}->{61734967} = "Ipswich";
$areanames{en}->{61734968} = "Ipswich";
$areanames{en}->{61734971} = "Dayboro";
$areanames{en}->{61734972} = "Dayboro";
$areanames{en}->{61734973} = "Brisbane";
$areanames{en}->{61734974} = "Brisbane";
$areanames{en}->{61734975} = "Brisbane";
$areanames{en}->{61734976} = "Brisbane";
$areanames{en}->{61734977} = "Cleveland";
$areanames{en}->{61734978} = "Ipswich";
$areanames{en}->{61734979} = "Ipswich";
$areanames{en}->{61734980} = "Ipswich";
$areanames{en}->{61734981} = "Redcliffe";
$areanames{en}->{61734982} = "Redcliffe";
$areanames{en}->{61734983} = "Redcliffe";
$areanames{en}->{61734984} = "Redcliffe";
$areanames{en}->{61734985} = "Redcliffe";
$areanames{en}->{61734986} = "Beenleigh";
$areanames{en}->{61734987} = "Beenleigh";
$areanames{en}->{61734988} = "Samford";
$areanames{en}->{61734989} = "Cleveland";
$areanames{en}->{6173499} = "Samford";
$areanames{en}->{6173500} = "Sandgate";
$areanames{en}->{6173501} = "Brisbane";
$areanames{en}->{6173502} = "Brisbane";
$areanames{en}->{6173503} = "Brisbane";
$areanames{en}->{6173504} = "Brisbane";
$areanames{en}->{6173505} = "Brisbane";
$areanames{en}->{61735060} = "Brisbane";
$areanames{en}->{61735061} = "Brisbane";
$areanames{en}->{61735062} = "Brisbane";
$areanames{en}->{61735063} = "Brisbane";
$areanames{en}->{61735064} = "Brisbane";
$areanames{en}->{61735065} = "Brisbane";
$areanames{en}->{61735066} = "Brisbane";
$areanames{en}->{61735067} = "Brisbane";
$areanames{en}->{6173530} = "Brisbane";
$areanames{en}->{6173531} = "Brisbane";
$areanames{en}->{6173532} = "Brisbane";
$areanames{en}->{6173533} = "Brisbane";
$areanames{en}->{6173534} = "Brisbane";
$areanames{en}->{6173535} = "Brisbane";
$areanames{en}->{6173536} = "Brisbane";
$areanames{en}->{6173538} = "Brisbane";
$areanames{en}->{6173539} = "Brisbane";
$areanames{en}->{6173540} = "Brisbane";
$areanames{en}->{6173546} = "Brisbane";
$areanames{en}->{6173547} = "Brisbane";
$areanames{en}->{6173548} = "Brisbane";
$areanames{en}->{6173550} = "Brisbane";
$areanames{en}->{6173551} = "Brisbane";
$areanames{en}->{6173552} = "Brisbane";
$areanames{en}->{6173553} = "Brisbane";
$areanames{en}->{6173554} = "Brisbane";
$areanames{en}->{61735550} = "Brisbane";
$areanames{en}->{61735551} = "Brisbane";
$areanames{en}->{61735553} = "Brisbane";
$areanames{en}->{61735555} = "Brisbane";
$areanames{en}->{61735556} = "Brisbane";
$areanames{en}->{61735557} = "Brisbane";
$areanames{en}->{61735558} = "Brisbane";
$areanames{en}->{61735559} = "Brisbane";
$areanames{en}->{6173556} = "Brisbane";
$areanames{en}->{6173557} = "Brisbane";
$areanames{en}->{6173558} = "Brisbane";
$areanames{en}->{61735590} = "Brisbane";
$areanames{en}->{61735591} = "Brisbane";
$areanames{en}->{61735592} = "Brisbane";
$areanames{en}->{61735593} = "Brisbane";
$areanames{en}->{61735594} = "Brisbane";
$areanames{en}->{61735595} = "Brisbane";
$areanames{en}->{61735596} = "Brisbane";
$areanames{en}->{61735597} = "Brisbane";
$areanames{en}->{61735598} = "Brisbane";
$areanames{en}->{61735678} = "Brisbane";
$areanames{en}->{6173600} = "Brisbane";
$areanames{en}->{6173601} = "Brisbane";
$areanames{en}->{6173602} = "Brisbane";
$areanames{en}->{6173603} = "Sandgate";
$areanames{en}->{6173604} = "Brisbane";
$areanames{en}->{6173605} = "Sandgate";
$areanames{en}->{6173606} = "Brisbane";
$areanames{en}->{6173607} = "Brisbane";
$areanames{en}->{61736080} = "Sandgate";
$areanames{en}->{61736081} = "Sandgate";
$areanames{en}->{61736082} = "Brisbane";
$areanames{en}->{61736083} = "Sandgate";
$areanames{en}->{61736084} = "Brisbane";
$areanames{en}->{61736085} = "Brisbane";
$areanames{en}->{61736086} = "Brisbane";
$areanames{en}->{61736087} = "Brisbane";
$areanames{en}->{61736088} = "Sandgate";
$areanames{en}->{61736089} = "Sandgate";
$areanames{en}->{61736090} = "Sandgate";
$areanames{en}->{61736091} = "Sandgate";
$areanames{en}->{61736092} = "Sandgate";
$areanames{en}->{61736093} = "Sandgate";
$areanames{en}->{61736094} = "Sandgate";
$areanames{en}->{61736095} = "Sandgate";
$areanames{en}->{61736096} = "Sandgate";
$areanames{en}->{61736097} = "Sandgate";
$areanames{en}->{61736110} = "Sandgate";
$areanames{en}->{61736111} = "Sandgate";
$areanames{en}->{6173612} = "Sandgate";
$areanames{en}->{6173613} = "Brisbane";
$areanames{en}->{6173614} = "Sandgate";
$areanames{en}->{6173620} = "Brisbane";
$areanames{en}->{6173621} = "Brisbane";
$areanames{en}->{6173622} = "Brisbane";
$areanames{en}->{6173623} = "Brisbane";
$areanames{en}->{6173624} = "Brisbane";
$areanames{en}->{6173625} = "Brisbane";
$areanames{en}->{617363} = "Brisbane";
$areanames{en}->{6173631} = "Sandgate";
$areanames{en}->{6173639} = "Sandgate";
$areanames{en}->{61736404} = "Brisbane";
$areanames{en}->{61736405} = "Brisbane";
$areanames{en}->{61736406} = "Brisbane";
$areanames{en}->{61736409} = "Brisbane";
$areanames{en}->{61736442} = "Sandgate";
$areanames{en}->{61736443} = "Sandgate";
$areanames{en}->{61736444} = "Sandgate";
$areanames{en}->{6173646} = "Brisbane";
$areanames{en}->{6173647} = "Brisbane";
$areanames{en}->{6173648} = "Brisbane";
$areanames{en}->{6173664} = "Sandgate";
$areanames{en}->{6173666} = "Brisbane";
$areanames{en}->{61736670} = "Sandgate";
$areanames{en}->{61736671} = "Sandgate";
$areanames{en}->{61736672} = "Sandgate";
$areanames{en}->{61736673} = "Sandgate";
$areanames{en}->{61736674} = "Sandgate";
$areanames{en}->{61736676} = "Sandgate";
$areanames{en}->{61736677} = "Brisbane";
$areanames{en}->{61736678} = "Brisbane";
$areanames{en}->{61736679} = "Brisbane";
$areanames{en}->{61736680} = "Brisbane";
$areanames{en}->{6173700} = "Brisbane";
$areanames{en}->{6173701} = "Brisbane";
$areanames{en}->{6173702} = "Brisbane";
$areanames{en}->{61737031} = "Brisbane";
$areanames{en}->{61737032} = "Brisbane";
$areanames{en}->{61737033} = "Brisbane";
$areanames{en}->{61737034} = "Brisbane";
$areanames{en}->{61737035} = "Brisbane";
$areanames{en}->{61737036} = "Brisbane";
$areanames{en}->{61737037} = "Brisbane";
$areanames{en}->{61737038} = "Brisbane";
$areanames{en}->{61737039} = "Brisbane";
$areanames{en}->{6173704} = "Brisbane";
$areanames{en}->{6173705} = "Brisbane";
$areanames{en}->{6173706} = "Brisbane";
$areanames{en}->{6173707} = "Brisbane";
$areanames{en}->{6173708} = "Brisbane";
$areanames{en}->{6173709} = "Brisbane";
$areanames{en}->{617371} = "Brisbane";
$areanames{en}->{6173720} = "Brisbane";
$areanames{en}->{6173721} = "Brisbane";
$areanames{en}->{6173722} = "Brisbane";
$areanames{en}->{6173723} = "Brisbane";
$areanames{en}->{6173724} = "Brisbane";
$areanames{en}->{6173725} = "Brisbane";
$areanames{en}->{6173726} = "Brisbane";
$areanames{en}->{6173727} = "Brisbane";
$areanames{en}->{61737280} = "Brisbane";
$areanames{en}->{61737281} = "Brisbane";
$areanames{en}->{61737282} = "Brisbane";
$areanames{en}->{61737283} = "Brisbane";
$areanames{en}->{61737284} = "Brisbane";
$areanames{en}->{6173732} = "Brisbane";
$areanames{en}->{61737330} = "Brisbane";
$areanames{en}->{61737331} = "Brisbane";
$areanames{en}->{61737332} = "Brisbane";
$areanames{en}->{61737333} = "Brisbane";
$areanames{en}->{6173734} = "Brisbane";
$areanames{en}->{6173735} = "Brisbane";
$areanames{en}->{6173736} = "Brisbane";
$areanames{en}->{6173737} = "Brisbane";
$areanames{en}->{6173738} = "Brisbane";
$areanames{en}->{6173748} = "Brisbane";
$areanames{en}->{6173777} = "Brisbane";
$areanames{en}->{61737788} = "Brisbane";
$areanames{en}->{617380} = "Beenleigh";
$areanames{en}->{6173810} = "Ipswich";
$areanames{en}->{6173811} = "Brisbane";
$areanames{en}->{6173812} = "Ipswich";
$areanames{en}->{6173813} = "Ipswich";
$areanames{en}->{6173814} = "Ipswich";
$areanames{en}->{6173815} = "Brisbane";
$areanames{en}->{61738170} = "Ipswich";
$areanames{en}->{61738171} = "Ipswich";
$areanames{en}->{61738172} = "Ipswich";
$areanames{en}->{61738173} = "Ipswich";
$areanames{en}->{61738174} = "Ipswich";
$areanames{en}->{61738175} = "Redcliffe";
$areanames{en}->{61738176} = "Redcliffe";
$areanames{en}->{61738177} = "Redcliffe";
$areanames{en}->{61738178} = "Redcliffe";
$areanames{en}->{61738179} = "Redcliffe";
$areanames{en}->{6173818} = "Ipswich";
$areanames{en}->{6173819} = "Ipswich";
$areanames{en}->{617382} = "Cleveland";
$areanames{en}->{6173823} = "Brisbane";
$areanames{en}->{6173826} = "Beenleigh";
$areanames{en}->{61738275} = "Beenleigh";
$areanames{en}->{61738276} = "Beenleigh";
$areanames{en}->{61738277} = "Beenleigh";
$areanames{en}->{61738278} = "Beenleigh";
$areanames{en}->{61738279} = "Beenleigh";
$areanames{en}->{6173828} = "Brisbane";
$areanames{en}->{61738348} = "Brisbane";
$areanames{en}->{61738359} = "Brisbane";
$areanames{en}->{6173869} = "Sandgate";
$areanames{en}->{617388} = "Redcliffe";
$areanames{en}->{61738840} = "Samford";
$areanames{en}->{61738842} = "Beenleigh";
$areanames{en}->{61738843} = "Cleveland";
$areanames{en}->{61738844} = "Cleveland";
$areanames{en}->{61738845} = "Ipswich";
$areanames{en}->{61738846} = "Ipswich";
$areanames{en}->{61738847} = "Beenleigh";
$areanames{en}->{61738848} = "Beenleigh";
$areanames{en}->{61738849} = "Beenleigh";
$areanames{en}->{6173887} = "Brisbane";
$areanames{en}->{617389} = "Brisbane";
$areanames{en}->{6173894} = "Ipswich";
$areanames{en}->{6173897} = "Redcliffe";
$areanames{en}->{61738979} = "Samford";
$areanames{en}->{6173900} = "Brisbane";
$areanames{en}->{6173901} = "Brisbane";
$areanames{en}->{6173904} = "Brisbane";
$areanames{en}->{6173905} = "Brisbane";
$areanames{en}->{6173910} = "Brisbane";
$areanames{en}->{61739110} = "Brisbane";
$areanames{en}->{61739111} = "Brisbane";
$areanames{en}->{61739112} = "Brisbane";
$areanames{en}->{6173914} = "Brisbane";
$areanames{en}->{6173915} = "Brisbane";
$areanames{en}->{61739160} = "Brisbane";
$areanames{en}->{61739161} = "Brisbane";
$areanames{en}->{6173917} = "Brisbane";
$areanames{en}->{6173918} = "Brisbane";
$areanames{en}->{6173922} = "Brisbane";
$areanames{en}->{6173924} = "Brisbane";
$areanames{en}->{61739475} = "Brisbane";
$areanames{en}->{61739993} = "Brisbane";
$areanames{en}->{61739994} = "Brisbane";
$areanames{en}->{61739995} = "Brisbane";
$areanames{en}->{61739996} = "Brisbane";
$areanames{en}->{61739997} = "Brisbane";
$areanames{en}->{61739998} = "Brisbane";
$areanames{en}->{61739999} = "Brisbane";
$areanames{en}->{6174000} = "Cairns";
$areanames{en}->{61740010} = "Atherton";
$areanames{en}->{61740011} = "Atherton";
$areanames{en}->{61740012} = "Atherton";
$areanames{en}->{61740013} = "Aurukun";
$areanames{en}->{61740014} = "Aurukun";
$areanames{en}->{61740015} = "Aurukun";
$areanames{en}->{61740016} = "Babinda";
$areanames{en}->{61740017} = "Babinda";
$areanames{en}->{61740018} = "Babinda";
$areanames{en}->{61740019} = "Babinda";
$areanames{en}->{61740020} = "Bloomfield";
$areanames{en}->{61740021} = "Bloomfield";
$areanames{en}->{61740022} = "Bloomfield";
$areanames{en}->{61740023} = "Chillagoe";
$areanames{en}->{61740024} = "Chillagoe";
$areanames{en}->{61740025} = "Chillagoe";
$areanames{en}->{61740026} = "Coen";
$areanames{en}->{61740027} = "Coen";
$areanames{en}->{61740028} = "Coen";
$areanames{en}->{61740029} = "Cooktown";
$areanames{en}->{61740030} = "Cooktown";
$areanames{en}->{61740031} = "Cooktown";
$areanames{en}->{61740032} = "Cooktown";
$areanames{en}->{61740033} = "Daintree";
$areanames{en}->{61740034} = "Daintree";
$areanames{en}->{61740035} = "Daintree";
$areanames{en}->{61740036} = "Dimbulah";
$areanames{en}->{61740037} = "Dimbulah";
$areanames{en}->{61740038} = "Dimbulah";
$areanames{en}->{61740039} = "Daintree";
$areanames{en}->{61740040} = "Edward\ River";
$areanames{en}->{61740041} = "Edward\ River";
$areanames{en}->{61740042} = "Edward\ River";
$areanames{en}->{61740043} = "Etheridge";
$areanames{en}->{61740044} = "Etheridge";
$areanames{en}->{61740045} = "Etheridge";
$areanames{en}->{61740046} = "Euramo";
$areanames{en}->{61740047} = "Euramo";
$areanames{en}->{61740048} = "Euramo";
$areanames{en}->{61740049} = "Atherton";
$areanames{en}->{61740050} = "Georgetown";
$areanames{en}->{61740051} = "Georgetown";
$areanames{en}->{61740052} = "Georgetown";
$areanames{en}->{61740053} = "Gordonvale";
$areanames{en}->{61740054} = "Gordonvale";
$areanames{en}->{61740055} = "Gordonvale";
$areanames{en}->{61740056} = "Herberton";
$areanames{en}->{61740057} = "Herberton";
$areanames{en}->{61740058} = "Herberton";
$areanames{en}->{61740059} = "Thursday\ Island";
$areanames{en}->{61740060} = "Peninsula";
$areanames{en}->{61740061} = "Peninsula";
$areanames{en}->{61740062} = "Peninsula";
$areanames{en}->{61740063} = "Innisfail";
$areanames{en}->{61740064} = "Innisfail";
$areanames{en}->{61740065} = "Innisfail";
$areanames{en}->{61740066} = "Innot\ Hot\ Springs";
$areanames{en}->{61740067} = "Innot\ Hot\ Springs";
$areanames{en}->{61740068} = "Innot\ Hot\ Springs";
$areanames{en}->{61740069} = "Torres";
$areanames{en}->{61740070} = "Kidston";
$areanames{en}->{61740071} = "Kidston";
$areanames{en}->{61740072} = "Kidston";
$areanames{en}->{61740073} = "Kowanyama";
$areanames{en}->{61740074} = "Kowanyama";
$areanames{en}->{61740075} = "Kowanyama";
$areanames{en}->{61740076} = "Kuranda";
$areanames{en}->{61740077} = "Kuranda";
$areanames{en}->{61740078} = "Kuranda";
$areanames{en}->{61740079} = "Tully";
$areanames{en}->{61740080} = "Lakeland";
$areanames{en}->{61740081} = "Lakeland";
$areanames{en}->{61740082} = "Lakeland";
$areanames{en}->{61740083} = "Lockhart\ River";
$areanames{en}->{61740084} = "Lockhart\ River";
$areanames{en}->{61740085} = "Lockhart\ River";
$areanames{en}->{61740086} = "Malanda";
$areanames{en}->{61740087} = "Malanda";
$areanames{en}->{61740088} = "Malanda";
$areanames{en}->{61740089} = "Walsh\ River";
$areanames{en}->{61740090} = "Mareeba";
$areanames{en}->{61740091} = "Mareeba";
$areanames{en}->{61740092} = "Mareeba";
$areanames{en}->{61740093} = "Maryfarms";
$areanames{en}->{61740094} = "Maryfarms";
$areanames{en}->{61740095} = "Maryfarms";
$areanames{en}->{61740096} = "Millaa\ Millaa";
$areanames{en}->{61740097} = "Millaa\ Millaa";
$areanames{en}->{61740098} = "Millaa\ Millaa";
$areanames{en}->{61740099} = "Weipa";
$areanames{en}->{61740100} = "Minnamoolka";
$areanames{en}->{61740101} = "Minnamoolka";
$areanames{en}->{61740102} = "Minnamoolka";
$areanames{en}->{61740103} = "Molloy";
$areanames{en}->{61740104} = "Molloy";
$areanames{en}->{61740105} = "Molloy";
$areanames{en}->{61740106} = "Mossman";
$areanames{en}->{61740107} = "Mossman";
$areanames{en}->{61740108} = "Mossman";
$areanames{en}->{61740109} = "Mossman";
$areanames{en}->{61740110} = "Mount\ Garnet";
$areanames{en}->{61740111} = "Mount\ Garnet";
$areanames{en}->{61740112} = "Mount\ Garnet";
$areanames{en}->{61740113} = "Etheridge";
$areanames{en}->{61740114} = "Mount\ Surprise";
$areanames{en}->{61740115} = "Mount\ Surprise";
$areanames{en}->{61740116} = "Mutchilba";
$areanames{en}->{61740117} = "Mutchilba";
$areanames{en}->{61740118} = "Mutchilba";
$areanames{en}->{61740119} = "Minnamoolka";
$areanames{en}->{61740120} = "Peninsula";
$areanames{en}->{61740121} = "Peninsula";
$areanames{en}->{61740122} = "Peninsula";
$areanames{en}->{61740123} = "Ravenshoe";
$areanames{en}->{61740124} = "Ravenshoe";
$areanames{en}->{61740125} = "Ravenshoe";
$areanames{en}->{61740126} = "Silkwood";
$areanames{en}->{61740127} = "Silkwood";
$areanames{en}->{61740128} = "Silkwood";
$areanames{en}->{61740129} = "Molloy";
$areanames{en}->{61740130} = "South\ Johnstone";
$areanames{en}->{61740131} = "South\ Johnstone";
$areanames{en}->{61740132} = "South\ Johnstone";
$areanames{en}->{61740133} = "Thursday\ Island";
$areanames{en}->{61740134} = "Thursday\ Island";
$areanames{en}->{61740135} = "Thursday\ Island";
$areanames{en}->{61740136} = "Torres";
$areanames{en}->{61740137} = "Torres";
$areanames{en}->{61740138} = "Torres";
$areanames{en}->{61740139} = "Tully";
$areanames{en}->{61740140} = "Tully";
$areanames{en}->{61740141} = "Tully";
$areanames{en}->{61740142} = "Tully";
$areanames{en}->{61740143} = "Walsh\ River";
$areanames{en}->{61740144} = "Walsh\ River";
$areanames{en}->{61740145} = "Walsh\ River";
$areanames{en}->{61740146} = "Weipa";
$areanames{en}->{61740147} = "Weipa";
$areanames{en}->{61740148} = "Weipa";
$areanames{en}->{61740149} = "Atherton";
$areanames{en}->{61740150} = "Cairns";
$areanames{en}->{61740151} = "Cairns";
$areanames{en}->{61740152} = "Cairns";
$areanames{en}->{61740153} = "Cairns";
$areanames{en}->{61740154} = "Atherton";
$areanames{en}->{61740155} = "Mossman";
$areanames{en}->{61740156} = "Mount\ Garnet";
$areanames{en}->{61740157} = "Mount\ Surprise";
$areanames{en}->{61740158} = "Mutchilba";
$areanames{en}->{61740159} = "Peninsula";
$areanames{en}->{61740160} = "Innisfail";
$areanames{en}->{61740161} = "Innisfail";
$areanames{en}->{61740162} = "Innisfail";
$areanames{en}->{61740163} = "Ravenshoe";
$areanames{en}->{61740164} = "Silkwood";
$areanames{en}->{61740165} = "South\ Johnstone";
$areanames{en}->{61740166} = "Innot\ Hot\ Springs";
$areanames{en}->{61740167} = "Kidston";
$areanames{en}->{61740168} = "Kowanyama";
$areanames{en}->{61740169} = "Kuranda";
$areanames{en}->{61740170} = "Mareeba";
$areanames{en}->{61740171} = "Mareeba";
$areanames{en}->{61740172} = "Mareeba";
$areanames{en}->{61740173} = "Lakeland";
$areanames{en}->{61740174} = "Lockhart\ River";
$areanames{en}->{61740175} = "Malanda";
$areanames{en}->{61740176} = "Mareeba";
$areanames{en}->{61740177} = "Maryfarms";
$areanames{en}->{61740178} = "Millaa\ Millaa";
$areanames{en}->{61740179} = "Daintree";
$areanames{en}->{61740180} = "Dimbulah";
$areanames{en}->{61740181} = "Edward\ River";
$areanames{en}->{61740182} = "Etheridge";
$areanames{en}->{61740183} = "Euramo";
$areanames{en}->{61740184} = "Georgetown";
$areanames{en}->{61740185} = "Gordonvale";
$areanames{en}->{61740186} = "Herberton";
$areanames{en}->{61740187} = "Hopevale";
$areanames{en}->{61740188} = "Innisfail";
$areanames{en}->{61740189} = "Aurukun";
$areanames{en}->{61740190} = "Babinda";
$areanames{en}->{61740191} = "Bloomfield";
$areanames{en}->{61740192} = "Cairns";
$areanames{en}->{61740193} = "Chillagoe";
$areanames{en}->{61740194} = "Coen";
$areanames{en}->{61740195} = "Cooktown";
$areanames{en}->{61740196} = "Cairns";
$areanames{en}->{61740197} = "Atherton";
$areanames{en}->{61740198} = "Aurukun";
$areanames{en}->{61740199} = "Babinda";
$areanames{en}->{61740200} = "Bloomfield";
$areanames{en}->{61740201} = "Cairns";
$areanames{en}->{61740202} = "Chillagoe";
$areanames{en}->{61740203} = "Coen";
$areanames{en}->{61740204} = "Cooktown";
$areanames{en}->{61740205} = "Daintree";
$areanames{en}->{61740206} = "Dimbulah";
$areanames{en}->{61740207} = "Edward\ River";
$areanames{en}->{61740208} = "Etheridge";
$areanames{en}->{61740209} = "Euramo";
$areanames{en}->{61740210} = "Georgetown";
$areanames{en}->{61740211} = "Gordonvale";
$areanames{en}->{61740212} = "Herberton";
$areanames{en}->{61740213} = "Hopevale";
$areanames{en}->{61740214} = "Innisfail";
$areanames{en}->{61740215} = "Innot\ Hot\ Springs";
$areanames{en}->{61740216} = "Kidston";
$areanames{en}->{61740217} = "Kowanyama";
$areanames{en}->{61740218} = "Kuranda";
$areanames{en}->{61740219} = "Lakeland";
$areanames{en}->{61740220} = "Lockhart\ River";
$areanames{en}->{61740221} = "Malanda";
$areanames{en}->{61740222} = "Mareeba";
$areanames{en}->{61740223} = "Maryfarms";
$areanames{en}->{61740224} = "Millaa\ Millaa";
$areanames{en}->{61740225} = "Minnamoolka";
$areanames{en}->{61740226} = "Molloy";
$areanames{en}->{61740227} = "Mossman";
$areanames{en}->{61740228} = "Mount\ Garnet";
$areanames{en}->{61740229} = "Mount\ Surprise";
$areanames{en}->{61740230} = "Mutchilba";
$areanames{en}->{61740231} = "Peninsula";
$areanames{en}->{61740232} = "Ravenshoe";
$areanames{en}->{61740233} = "Silkwood";
$areanames{en}->{61740234} = "South\ Johnstone";
$areanames{en}->{61740235} = "Thursday\ Island";
$areanames{en}->{61740236} = "Torres";
$areanames{en}->{61740237} = "Tully";
$areanames{en}->{61740238} = "Walsh\ River";
$areanames{en}->{61740239} = "Weipa";
$areanames{en}->{61740240} = "Atherton";
$areanames{en}->{61740241} = "Thursday\ Island";
$areanames{en}->{61740242} = "Torres";
$areanames{en}->{61740243} = "Tully";
$areanames{en}->{61740244} = "Walsh\ River";
$areanames{en}->{61740245} = "Weipa";
$areanames{en}->{61740246} = "Minnamoolka";
$areanames{en}->{61740247} = "Molloy";
$areanames{en}->{61740248} = "Mossman";
$areanames{en}->{61740249} = "Mount\ Garnet";
$areanames{en}->{61740250} = "Mount\ Surprise";
$areanames{en}->{61740251} = "Mutchilba";
$areanames{en}->{61740252} = "Peninsula";
$areanames{en}->{61740253} = "Innot\ Hot\ Springs";
$areanames{en}->{61740254} = "Kidston";
$areanames{en}->{61740255} = "Kowanyama";
$areanames{en}->{61740256} = "Kuranda";
$areanames{en}->{61740257} = "Ravenshoe";
$areanames{en}->{61740258} = "Silkwood";
$areanames{en}->{61740259} = "South\ Johnstone";
$areanames{en}->{61740260} = "Daintree";
$areanames{en}->{61740261} = "Lakeland";
$areanames{en}->{61740262} = "Lockhart\ River";
$areanames{en}->{61740263} = "Malanda";
$areanames{en}->{61740264} = "Mareeba";
$areanames{en}->{61740265} = "Maryfarms";
$areanames{en}->{61740266} = "Millaa\ Millaa";
$areanames{en}->{61740267} = "Aurukun";
$areanames{en}->{61740268} = "Dimbulah";
$areanames{en}->{61740269} = "Edward\ River";
$areanames{en}->{61740270} = "Etheridge";
$areanames{en}->{61740271} = "Euramo";
$areanames{en}->{61740272} = "Georgetown";
$areanames{en}->{61740273} = "Gordonvale";
$areanames{en}->{61740274} = "Herberton";
$areanames{en}->{61740275} = "Hopevale";
$areanames{en}->{61740276} = "Innisfail";
$areanames{en}->{61740277} = "Babinda";
$areanames{en}->{61740278} = "Bloomfield";
$areanames{en}->{61740279} = "Cairns";
$areanames{en}->{61740280} = "Chillagoe";
$areanames{en}->{61740281} = "Coen";
$areanames{en}->{61740282} = "Cooktown";
$areanames{en}->{61740283} = "Cairns";
$areanames{en}->{61740284} = "Atherton";
$areanames{en}->{61740285} = "Atherton";
$areanames{en}->{61740286} = "Aurukun";
$areanames{en}->{61740287} = "Babinda";
$areanames{en}->{61740288} = "Bloomfield";
$areanames{en}->{61740289} = "Chillagoe";
$areanames{en}->{61740290} = "Coen";
$areanames{en}->{61740291} = "Cooktown";
$areanames{en}->{61740292} = "Daintree";
$areanames{en}->{61740293} = "Dimbulah";
$areanames{en}->{61740294} = "Edward\ River";
$areanames{en}->{61740295} = "Etheridge";
$areanames{en}->{61740296} = "Euramo";
$areanames{en}->{61740297} = "Georgetown";
$areanames{en}->{61740298} = "Gordonvale";
$areanames{en}->{61740299} = "Herberton";
$areanames{en}->{61740300} = "Cairns";
$areanames{en}->{61740301} = "Cairns";
$areanames{en}->{61740302} = "Innisfail";
$areanames{en}->{61740303} = "Mareeba";
$areanames{en}->{61740304} = "Mossman";
$areanames{en}->{61740305} = "Atherton";
$areanames{en}->{61740306} = "Thursday\ Island";
$areanames{en}->{61740307} = "Cairns";
$areanames{en}->{61740308} = "Cairns";
$areanames{en}->{61740309} = "Weipa";
$areanames{en}->{6174039} = "Cairns";
$areanames{en}->{61740396} = "Aurukun";
$areanames{en}->{61740397} = "Babinda";
$areanames{en}->{617404} = "Cairns";
$areanames{en}->{61740430} = "Cooktown";
$areanames{en}->{61740431} = "Peninsula";
$areanames{en}->{61740432} = "Babinda";
$areanames{en}->{61740433} = "Gordonvale";
$areanames{en}->{61740434} = "Mareeba";
$areanames{en}->{61740435} = "Ravenshoe";
$areanames{en}->{61740436} = "Malanda";
$areanames{en}->{61740437} = "Bloomfield";
$areanames{en}->{61740438} = "Innisfail";
$areanames{en}->{61740439} = "Tully";
$areanames{en}->{61740471} = "Chillagoe";
$areanames{en}->{61740472} = "Coen";
$areanames{en}->{61740473} = "Cooktown";
$areanames{en}->{61740483} = "Innisfail";
$areanames{en}->{61740484} = "Mareeba";
$areanames{en}->{61740485} = "Tully";
$areanames{en}->{61740486} = "Thursday\ Island";
$areanames{en}->{61740494} = "Thursday\ Island";
$areanames{en}->{61740495} = "Torres";
$areanames{en}->{61740496} = "Tully";
$areanames{en}->{61740497} = "Walsh\ River";
$areanames{en}->{61740498} = "Weipa";
$areanames{en}->{61740499} = "Weipa";
$areanames{en}->{6174056} = "Gordonvale";
$areanames{en}->{61740560} = "Cairns";
$areanames{en}->{61740567} = "Cairns";
$areanames{en}->{61740568} = "Cairns";
$areanames{en}->{61740569} = "Cairns";
$areanames{en}->{6174058} = "Cairns";
$areanames{en}->{61740586} = "Daintree";
$areanames{en}->{61740587} = "Dimbulah";
$areanames{en}->{61740588} = "Edward\ River";
$areanames{en}->{6174059} = "Cairns";
$areanames{en}->{61740596} = "Etheridge";
$areanames{en}->{61740597} = "Euramo";
$areanames{en}->{61740600} = "Lakeland";
$areanames{en}->{61740601} = "Coen";
$areanames{en}->{61740602} = "Peninsula";
$areanames{en}->{61740603} = "Peninsula";
$areanames{en}->{61740604} = "Edward\ River";
$areanames{en}->{61740605} = "Kowanyama";
$areanames{en}->{61740606} = "Aurukun";
$areanames{en}->{61740607} = "Peninsula";
$areanames{en}->{61740608} = "Bloomfield";
$areanames{en}->{61740609} = "Hopevale";
$areanames{en}->{6174061} = "Innisfail";
$areanames{en}->{61740620} = "Georgetown";
$areanames{en}->{61740621} = "Georgetown";
$areanames{en}->{61740622} = "Etheridge";
$areanames{en}->{61740623} = "Mount\ Surprise";
$areanames{en}->{61740624} = "Kidston";
$areanames{en}->{61740625} = "Etheridge";
$areanames{en}->{61740626} = "Etheridge";
$areanames{en}->{61740627} = "Etheridge";
$areanames{en}->{61740628} = "Kidston";
$areanames{en}->{61740629} = "Mount\ Surprise";
$areanames{en}->{6174063} = "Innisfail";
$areanames{en}->{61740636} = "Euramo";
$areanames{en}->{61740637} = "Euramo";
$areanames{en}->{61740638} = "Georgetown";
$areanames{en}->{61740639} = "Gordonvale";
$areanames{en}->{6174064} = "South\ Johnstone";
$areanames{en}->{61740649} = "Herberton";
$areanames{en}->{6174065} = "Silkwood";
$areanames{en}->{61740658} = "Hopevale";
$areanames{en}->{6174066} = "Euramo";
$areanames{en}->{6174067} = "Babinda";
$areanames{en}->{6174068} = "Tully";
$areanames{en}->{61740690} = "Thursday\ Island";
$areanames{en}->{61740691} = "Thursday\ Island";
$areanames{en}->{61740692} = "Thursday\ Island";
$areanames{en}->{61740693} = "Thursday\ Island";
$areanames{en}->{61740694} = "Torres";
$areanames{en}->{61740695} = "Cooktown";
$areanames{en}->{61740696} = "Cooktown";
$areanames{en}->{61740697} = "Weipa";
$areanames{en}->{61740698} = "Weipa";
$areanames{en}->{61740699} = "Weipa";
$areanames{en}->{61740700} = "Hopevale";
$areanames{en}->{61740701} = "Innot\ Hot\ Springs";
$areanames{en}->{61740702} = "Kidston";
$areanames{en}->{61740703} = "Kowanyama";
$areanames{en}->{61740704} = "Kuranda";
$areanames{en}->{61740705} = "Lakeland";
$areanames{en}->{61740706} = "Lockhart\ River";
$areanames{en}->{61740707} = "Malanda";
$areanames{en}->{61740708} = "Maryfarms";
$areanames{en}->{61740709} = "Millaa\ Millaa";
$areanames{en}->{61740710} = "Minnamoolka";
$areanames{en}->{61740711} = "Molloy";
$areanames{en}->{61740712} = "Mossman";
$areanames{en}->{61740713} = "Mount\ Garnet";
$areanames{en}->{61740714} = "Mount\ Surprise";
$areanames{en}->{61740715} = "Mutchilba";
$areanames{en}->{61740716} = "Peninsula";
$areanames{en}->{61740717} = "Ravenshoe";
$areanames{en}->{61740718} = "Silkwood";
$areanames{en}->{61740719} = "South\ Johnstone";
$areanames{en}->{61740720} = "Thursday\ Island";
$areanames{en}->{61740721} = "Torres";
$areanames{en}->{61740722} = "Tully";
$areanames{en}->{61740723} = "Walsh\ River";
$areanames{en}->{61740724} = "Weipa";
$areanames{en}->{61740725} = "Innisfail";
$areanames{en}->{61740726} = "Innot\ Hot\ Springs";
$areanames{en}->{61740727} = "Kidston";
$areanames{en}->{61740728} = "Kowanyama";
$areanames{en}->{61740729} = "Kuranda";
$areanames{en}->{61740730} = "Lakeland";
$areanames{en}->{61740731} = "Lockhart\ River";
$areanames{en}->{61740732} = "Malanda";
$areanames{en}->{61740733} = "Mareeba";
$areanames{en}->{61740734} = "Maryfarms";
$areanames{en}->{61740735} = "Millaa\ Millaa";
$areanames{en}->{61740736} = "Minnamoolka";
$areanames{en}->{61740737} = "Molloy";
$areanames{en}->{61740738} = "Mossman";
$areanames{en}->{61740739} = "Mount\ Garnet";
$areanames{en}->{61740740} = "Mount\ Surprise";
$areanames{en}->{61740741} = "Mutchilba";
$areanames{en}->{61740742} = "Peninsula";
$areanames{en}->{61740743} = "Ravenshoe";
$areanames{en}->{61740744} = "Silkwood";
$areanames{en}->{61740745} = "South\ Johnstone";
$areanames{en}->{61740746} = "Thursday\ Island";
$areanames{en}->{61740747} = "Torres";
$areanames{en}->{61740748} = "Tully";
$areanames{en}->{61740749} = "Walsh\ River";
$areanames{en}->{61740750} = "Minnamoolka";
$areanames{en}->{61740751} = "Molloy";
$areanames{en}->{61740752} = "Mossman";
$areanames{en}->{61740753} = "Mount\ Garnet";
$areanames{en}->{61740754} = "Mount\ Surprise";
$areanames{en}->{61740755} = "Mutchilba";
$areanames{en}->{61740756} = "Peninsula";
$areanames{en}->{61740757} = "Ravenshoe";
$areanames{en}->{61740758} = "Silkwood";
$areanames{en}->{61740759} = "South\ Johnstone";
$areanames{en}->{61740760} = "Innot\ Hot\ Springs";
$areanames{en}->{61740761} = "Kidston";
$areanames{en}->{61740762} = "Kowanyama";
$areanames{en}->{61740763} = "Kuranda";
$areanames{en}->{61740764} = "Lakeland";
$areanames{en}->{61740765} = "Lockhart\ River";
$areanames{en}->{61740766} = "Malanda";
$areanames{en}->{61740767} = "Mareeba";
$areanames{en}->{61740768} = "Maryfarms";
$areanames{en}->{61740769} = "Millaa\ Millaa";
$areanames{en}->{61740770} = "Daintree";
$areanames{en}->{61740771} = "Dimbulah";
$areanames{en}->{61740772} = "Edward\ River";
$areanames{en}->{61740773} = "Etheridge";
$areanames{en}->{61740774} = "Euramo";
$areanames{en}->{61740775} = "Georgetown";
$areanames{en}->{61740776} = "Gordonvale";
$areanames{en}->{61740777} = "Herberton";
$areanames{en}->{61740778} = "Hopevale";
$areanames{en}->{61740779} = "Innisfail";
$areanames{en}->{61740780} = "Innisfail";
$areanames{en}->{61740781} = "Innisfail";
$areanames{en}->{61740782} = "Innisfail";
$areanames{en}->{61740783} = "Aurukun";
$areanames{en}->{61740784} = "Babinda";
$areanames{en}->{61740785} = "Bloomfield";
$areanames{en}->{61740786} = "Cairns";
$areanames{en}->{61740787} = "Chillagoe";
$areanames{en}->{61740788} = "Coen";
$areanames{en}->{61740789} = "Cooktown";
$areanames{en}->{61740790} = "Weipa";
$areanames{en}->{61740791} = "Atherton";
$areanames{en}->{61740792} = "Cairns";
$areanames{en}->{61740793} = "Babinda";
$areanames{en}->{61740794} = "Atherton";
$areanames{en}->{61740795} = "Cairns";
$areanames{en}->{61740796} = "Aurukun";
$areanames{en}->{61740797} = "Babinda";
$areanames{en}->{61740798} = "Bloomfield";
$areanames{en}->{61740799} = "Georgetown";
$areanames{en}->{6174080} = "Cairns";
$areanames{en}->{6174081} = "Cairns";
$areanames{en}->{61740820} = "Cooktown";
$areanames{en}->{61740821} = "Cooktown";
$areanames{en}->{61740822} = "Cooktown";
$areanames{en}->{61740823} = "Weipa";
$areanames{en}->{61740824} = "Weipa";
$areanames{en}->{61740825} = "Peninsula";
$areanames{en}->{61740826} = "Peninsula";
$areanames{en}->{61740827} = "Cairns";
$areanames{en}->{61740828} = "Chillagoe";
$areanames{en}->{61740829} = "Peninsula";
$areanames{en}->{61740830} = "Thursday\ Island";
$areanames{en}->{61740831} = "Thursday\ Island";
$areanames{en}->{61740832} = "Torres";
$areanames{en}->{61740833} = "Lockhart\ River";
$areanames{en}->{61740834} = "Aurukun";
$areanames{en}->{61740835} = "Coen";
$areanames{en}->{61740836} = "Edward\ River";
$areanames{en}->{61740837} = "Kowanyama";
$areanames{en}->{61740838} = "Hopevale";
$areanames{en}->{61740839} = "Bloomfield";
$areanames{en}->{61740840} = "Cairns";
$areanames{en}->{61740841} = "Mossman";
$areanames{en}->{61740842} = "Mossman";
$areanames{en}->{61740843} = "Mossman";
$areanames{en}->{61740844} = "Mossman";
$areanames{en}->{61740845} = "Ravenshoe";
$areanames{en}->{61740846} = "Ravenshoe";
$areanames{en}->{61740847} = "Millaa\ Millaa";
$areanames{en}->{61740848} = "Weipa";
$areanames{en}->{61740849} = "Daintree";
$areanames{en}->{6174085} = "Kuranda";
$areanames{en}->{61740858} = "Coen";
$areanames{en}->{61740859} = "Cooktown";
$areanames{en}->{6174086} = "Mareeba";
$areanames{en}->{61740860} = "Daintree";
$areanames{en}->{61740861} = "Gordonvale";
$areanames{en}->{61740870} = "Mossman";
$areanames{en}->{61740871} = "Mossman";
$areanames{en}->{61740872} = "Mossman";
$areanames{en}->{61740873} = "Innot\ Hot\ Springs";
$areanames{en}->{61740874} = "Maryfarms";
$areanames{en}->{61740875} = "Minnamoolka";
$areanames{en}->{61740876} = "Chillagoe";
$areanames{en}->{61740877} = "Mutchilba";
$areanames{en}->{61740878} = "Dimbulah";
$areanames{en}->{61740879} = "Edward\ River";
$areanames{en}->{6174088} = "Tully";
$areanames{en}->{61740881} = "Cairns";
$areanames{en}->{61740882} = "Innisfail";
$areanames{en}->{61740883} = "Etheridge";
$areanames{en}->{6174089} = "Atherton";
$areanames{en}->{61740890} = "Euramo";
$areanames{en}->{61740891} = "Georgetown";
$areanames{en}->{61740898} = "Malanda";
$areanames{en}->{61740899} = "Malanda";
$areanames{en}->{61740900} = "Torres";
$areanames{en}->{61740901} = "Torres";
$areanames{en}->{61740902} = "Thursday\ Island";
$areanames{en}->{61740903} = "Thursday\ Island";
$areanames{en}->{61740904} = "Thursday\ Island";
$areanames{en}->{61740905} = "Weipa";
$areanames{en}->{61740906} = "Weipa";
$areanames{en}->{61740907} = "Daintree";
$areanames{en}->{61740908} = "Daintree";
$areanames{en}->{61740909} = "Peninsula";
$areanames{en}->{6174091} = "Atherton";
$areanames{en}->{6174092} = "Mareeba";
$areanames{en}->{61740930} = "Kuranda";
$areanames{en}->{61740931} = "Mutchilba";
$areanames{en}->{61740932} = "Mareeba";
$areanames{en}->{61740933} = "Mareeba";
$areanames{en}->{61740934} = "Mutchilba";
$areanames{en}->{61740935} = "Dimbulah";
$areanames{en}->{61740936} = "Dimbulah";
$areanames{en}->{61740937} = "Kuranda";
$areanames{en}->{61740938} = "Kuranda";
$areanames{en}->{61740939} = "Kuranda";
$areanames{en}->{61740940} = "Molloy";
$areanames{en}->{61740941} = "Molloy";
$areanames{en}->{61740942} = "Molloy";
$areanames{en}->{61740943} = "Maryfarms";
$areanames{en}->{61740944} = "Dimbulah";
$areanames{en}->{61740945} = "Dimbulah";
$areanames{en}->{61740946} = "Dimbulah";
$areanames{en}->{61740947} = "Chillagoe";
$areanames{en}->{61740948} = "Walsh\ River";
$areanames{en}->{61740949} = "Walsh\ River";
$areanames{en}->{6174095} = "Atherton";
$areanames{en}->{61740950} = "Malanda";
$areanames{en}->{61740951} = "Malanda";
$areanames{en}->{61740960} = "Herberton";
$areanames{en}->{61740961} = "Herberton";
$areanames{en}->{61740962} = "Herberton";
$areanames{en}->{61740963} = "Herberton";
$areanames{en}->{61740964} = "Herberton";
$areanames{en}->{61740965} = "Malanda";
$areanames{en}->{61740966} = "Malanda";
$areanames{en}->{61740967} = "Malanda";
$areanames{en}->{61740968} = "Malanda";
$areanames{en}->{61740969} = "Malanda";
$areanames{en}->{61740970} = "Innot\ Hot\ Springs";
$areanames{en}->{61740971} = "Minnamoolka";
$areanames{en}->{61740972} = "Millaa\ Millaa";
$areanames{en}->{61740973} = "Millaa\ Millaa";
$areanames{en}->{61740974} = "Mount\ Garnet";
$areanames{en}->{61740975} = "Ravenshoe";
$areanames{en}->{61740976} = "Ravenshoe";
$areanames{en}->{61740977} = "Ravenshoe";
$areanames{en}->{61740978} = "Ravenshoe";
$areanames{en}->{61740979} = "Mount\ Garnet";
$areanames{en}->{6174098} = "Mossman";
$areanames{en}->{61740980} = "Daintree";
$areanames{en}->{61740986} = "Daintree";
$areanames{en}->{61740989} = "Daintree";
$areanames{en}->{6174099} = "Mossman";
$areanames{en}->{61741000} = "Bundaberg";
$areanames{en}->{61741001} = "Bundaberg";
$areanames{en}->{61741002} = "Bundaberg";
$areanames{en}->{61741003} = "Maryborough";
$areanames{en}->{61741004} = "Maryborough";
$areanames{en}->{61741005} = "Maryborough";
$areanames{en}->{61741006} = "Biggenden";
$areanames{en}->{61741007} = "Biggenden";
$areanames{en}->{61741008} = "Biggenden";
$areanames{en}->{61741009} = "Bundaberg";
$areanames{en}->{61741010} = "Blackbutt";
$areanames{en}->{61741011} = "Blackbutt";
$areanames{en}->{61741012} = "Blackbutt";
$areanames{en}->{61741013} = "Boondooma";
$areanames{en}->{61741014} = "Boondooma";
$areanames{en}->{61741015} = "Boondooma";
$areanames{en}->{61741016} = "Booyal";
$areanames{en}->{61741017} = "Booyal";
$areanames{en}->{61741018} = "Booyal";
$areanames{en}->{61741019} = "Bunker";
$areanames{en}->{61741020} = "Brooklands";
$areanames{en}->{61741021} = "Brooklands";
$areanames{en}->{61741022} = "Brooklands";
$areanames{en}->{61741023} = "Brooweena";
$areanames{en}->{61741024} = "Brooweena";
$areanames{en}->{61741025} = "Brooweena";
$areanames{en}->{61741026} = "Bunker";
$areanames{en}->{61741027} = "Bunker";
$areanames{en}->{61741028} = "Bunker";
$areanames{en}->{61741029} = "Gaeta";
$areanames{en}->{61741030} = "Burnett";
$areanames{en}->{61741031} = "Burnett";
$areanames{en}->{61741032} = "Burnett";
$areanames{en}->{61741033} = "Chahpingah";
$areanames{en}->{61741034} = "Chahpingah";
$areanames{en}->{61741035} = "Chahpingah";
$areanames{en}->{61741036} = "Childers";
$areanames{en}->{61741037} = "Childers";
$areanames{en}->{61741038} = "Childers";
$areanames{en}->{61741039} = "Gin\ Gin";
$areanames{en}->{61741040} = "Eidsvold";
$areanames{en}->{61741041} = "Eidsvold";
$areanames{en}->{61741042} = "Eidsvold";
$areanames{en}->{61741043} = "Farnsfield";
$areanames{en}->{61741044} = "Farnsfield";
$areanames{en}->{61741045} = "Farnsfield";
$areanames{en}->{61741046} = "Fraser\ Island";
$areanames{en}->{61741047} = "Fraser\ Island";
$areanames{en}->{61741048} = "Fraser\ Island";
$areanames{en}->{61741049} = "Lowmead";
$areanames{en}->{61741050} = "Gaeta";
$areanames{en}->{61741051} = "Gaeta";
$areanames{en}->{61741052} = "Gaeta";
$areanames{en}->{61741053} = "Gayndah";
$areanames{en}->{61741054} = "Gayndah";
$areanames{en}->{61741055} = "Gayndah";
$areanames{en}->{61741056} = "Gin\ Gin";
$areanames{en}->{61741057} = "Gin\ Gin";
$areanames{en}->{61741058} = "Gin\ Gin";
$areanames{en}->{61741059} = "Mount\ Perry";
$areanames{en}->{61741060} = "Gooroolba";
$areanames{en}->{61741061} = "Gooroolba";
$areanames{en}->{61741062} = "Gooroolba";
$areanames{en}->{61741063} = "Howard";
$areanames{en}->{61741064} = "Howard";
$areanames{en}->{61741065} = "Howard";
$areanames{en}->{61741066} = "Johnstown\ West";
$areanames{en}->{61741067} = "Johnstown\ West";
$areanames{en}->{61741068} = "Johnstown\ West";
$areanames{en}->{61741069} = "Rosedale";
$areanames{en}->{61741070} = "Kingaroy";
$areanames{en}->{61741071} = "Kingaroy";
$areanames{en}->{61741072} = "Kingaroy";
$areanames{en}->{61741073} = "Kumbia";
$areanames{en}->{61741074} = "Kumbia";
$areanames{en}->{61741075} = "Kumbia";
$areanames{en}->{61741076} = "Lowmead";
$areanames{en}->{61741077} = "Lowmead";
$areanames{en}->{61741078} = "Lowmead";
$areanames{en}->{61741079} = "Yandaran";
$areanames{en}->{61741080} = "Maidenwell";
$areanames{en}->{61741081} = "Maidenwell";
$areanames{en}->{61741082} = "Maidenwell";
$areanames{en}->{61741083} = "Manumbar";
$areanames{en}->{61741084} = "Manumbar";
$areanames{en}->{61741085} = "Manumbar";
$areanames{en}->{61741086} = "Monogorilby";
$areanames{en}->{61741087} = "Monogorilby";
$areanames{en}->{61741088} = "Monogorilby";
$areanames{en}->{61741089} = "Gayndah";
$areanames{en}->{61741090} = "Monto";
$areanames{en}->{61741091} = "Monto";
$areanames{en}->{61741092} = "Monto";
$areanames{en}->{61741093} = "Moonford";
$areanames{en}->{61741094} = "Moonford";
$areanames{en}->{61741095} = "Moonford";
$areanames{en}->{61741096} = "Mount\ Perry";
$areanames{en}->{61741097} = "Mount\ Perry";
$areanames{en}->{61741098} = "Mount\ Perry";
$areanames{en}->{61741099} = "Gooroolba";
$areanames{en}->{61741100} = "Mulgildie";
$areanames{en}->{61741101} = "Mulgildie";
$areanames{en}->{61741102} = "Mulgildie";
$areanames{en}->{61741103} = "Mundubbera";
$areanames{en}->{61741104} = "Mundubbera";
$areanames{en}->{61741105} = "Mundubbera";
$areanames{en}->{61741106} = "Murgon";
$areanames{en}->{61741107} = "Murgon";
$areanames{en}->{61741108} = "Murgon";
$areanames{en}->{61741109} = "Bundaberg";
$areanames{en}->{6174111} = "Bundaberg";
$areanames{en}->{61741120} = "Nanango";
$areanames{en}->{61741121} = "Nanango";
$areanames{en}->{61741122} = "Nanango";
$areanames{en}->{61741123} = "Pialba";
$areanames{en}->{61741124} = "Pialba";
$areanames{en}->{61741125} = "Pialba";
$areanames{en}->{61741126} = "Proston";
$areanames{en}->{61741127} = "Proston";
$areanames{en}->{61741128} = "Proston";
$areanames{en}->{61741129} = "Monogorilby";
$areanames{en}->{61741130} = "Redridge";
$areanames{en}->{61741131} = "Redridge";
$areanames{en}->{61741132} = "Redridge";
$areanames{en}->{61741133} = "Rosedale";
$areanames{en}->{61741134} = "Rosedale";
$areanames{en}->{61741135} = "Rosedale";
$areanames{en}->{61741136} = "Tandora";
$areanames{en}->{61741137} = "Tandora";
$areanames{en}->{61741138} = "Tandora";
$areanames{en}->{61741139} = "Maryborough";
$areanames{en}->{61741140} = "Maryborough";
$areanames{en}->{61741141} = "Maryborough";
$areanames{en}->{61741142} = "Maryborough";
$areanames{en}->{61741143} = "Tansey";
$areanames{en}->{61741144} = "Tansey";
$areanames{en}->{61741145} = "Tansey";
$areanames{en}->{61741146} = "Tiaro";
$areanames{en}->{61741147} = "Tiaro";
$areanames{en}->{61741148} = "Tiaro";
$areanames{en}->{61741149} = "Monto";
$areanames{en}->{61741150} = "Windera";
$areanames{en}->{61741151} = "Windera";
$areanames{en}->{61741152} = "Windera";
$areanames{en}->{61741153} = "Wondai";
$areanames{en}->{61741154} = "Wondai";
$areanames{en}->{61741155} = "Wondai";
$areanames{en}->{61741156} = "Yandaran";
$areanames{en}->{61741157} = "Yandaran";
$areanames{en}->{61741158} = "Yandaran";
$areanames{en}->{61741159} = "Moonford";
$areanames{en}->{61741160} = "Yarraman";
$areanames{en}->{61741161} = "Yarraman";
$areanames{en}->{61741162} = "Yarraman";
$areanames{en}->{61741163} = "Murgon";
$areanames{en}->{61741164} = "Proston";
$areanames{en}->{61741165} = "Tansey";
$areanames{en}->{61741166} = "Windera";
$areanames{en}->{61741167} = "Wondai";
$areanames{en}->{61741168} = "Mulgildie";
$areanames{en}->{61741169} = "Mundubbera";
$areanames{en}->{61741170} = "Childers";
$areanames{en}->{61741171} = "Farnsfield";
$areanames{en}->{61741172} = "Fraser\ Island";
$areanames{en}->{61741173} = "Howard";
$areanames{en}->{61741174} = "Maryborough";
$areanames{en}->{61741175} = "Pialba";
$areanames{en}->{61741176} = "Redridge";
$areanames{en}->{61741177} = "Tiaro";
$areanames{en}->{61741178} = "Boondooma";
$areanames{en}->{61741179} = "Manumbar";
$areanames{en}->{61741180} = "Chahpingah";
$areanames{en}->{61741181} = "Johnstown\ West";
$areanames{en}->{61741182} = "Kingaroy";
$areanames{en}->{61741183} = "Kumbia";
$areanames{en}->{61741184} = "Maidenwell";
$areanames{en}->{61741185} = "Nanango";
$areanames{en}->{61741186} = "Yarraman";
$areanames{en}->{61741187} = "Biggenden";
$areanames{en}->{61741188} = "Booyal";
$areanames{en}->{61741189} = "Brooweena";
$areanames{en}->{61741190} = "Gayndah";
$areanames{en}->{61741191} = "Gooroolba";
$areanames{en}->{61741192} = "Monogorilby";
$areanames{en}->{61741193} = "Monto";
$areanames{en}->{61741194} = "Moonford";
$areanames{en}->{61741195} = "Mulgildie";
$areanames{en}->{61741196} = "Mundubbera";
$areanames{en}->{61741197} = "Tandora";
$areanames{en}->{61741198} = "Blackbutt";
$areanames{en}->{61741199} = "Brooklands";
$areanames{en}->{6174120} = "Maryborough";
$areanames{en}->{61741201} = "Pialba";
$areanames{en}->{61741203} = "Fraser\ Island";
$areanames{en}->{61741206} = "Pialba";
$areanames{en}->{61741207} = "Bundaberg";
$areanames{en}->{6174121} = "Maryborough";
$areanames{en}->{6174122} = "Maryborough";
$areanames{en}->{6174123} = "Maryborough";
$areanames{en}->{6174124} = "Pialba";
$areanames{en}->{6174125} = "Pialba";
$areanames{en}->{61741260} = "Booyal";
$areanames{en}->{61741261} = "Childers";
$areanames{en}->{61741262} = "Childers";
$areanames{en}->{61741263} = "Childers";
$areanames{en}->{61741264} = "Childers";
$areanames{en}->{61741265} = "Redridge";
$areanames{en}->{61741266} = "Childers";
$areanames{en}->{61741267} = "Redridge";
$areanames{en}->{61741268} = "Redridge";
$areanames{en}->{61741269} = "Farnsfield";
$areanames{en}->{61741270} = "Fraser\ Island";
$areanames{en}->{61741271} = "Biggenden";
$areanames{en}->{61741272} = "Biggenden";
$areanames{en}->{61741273} = "Bunker";
$areanames{en}->{61741274} = "Gaeta";
$areanames{en}->{61741275} = "Biggenden";
$areanames{en}->{61741276} = "Biggenden";
$areanames{en}->{61741277} = "Biggenden";
$areanames{en}->{61741278} = "Redridge";
$areanames{en}->{61741279} = "Fraser\ Island";
$areanames{en}->{6174128} = "Pialba";
$areanames{en}->{61741290} = "Howard";
$areanames{en}->{61741291} = "Howard";
$areanames{en}->{61741292} = "Tiaro";
$areanames{en}->{61741293} = "Tiaro";
$areanames{en}->{61741294} = "Howard";
$areanames{en}->{61741295} = "Howard";
$areanames{en}->{61741296} = "Maryborough";
$areanames{en}->{61741297} = "Maryborough";
$areanames{en}->{61741298} = "Tiaro";
$areanames{en}->{61741299} = "Brooweena";
$areanames{en}->{6174130} = "Bundaberg";
$areanames{en}->{6174131} = "Bundaberg";
$areanames{en}->{61741320} = "Lowmead";
$areanames{en}->{61741321} = "Rosedale";
$areanames{en}->{61741322} = "Gin\ Gin";
$areanames{en}->{61741323} = "Lowmead";
$areanames{en}->{61741324} = "Yandaran";
$areanames{en}->{61741325} = "Bundaberg";
$areanames{en}->{61741326} = "Bundaberg";
$areanames{en}->{61741327} = "Bundaberg";
$areanames{en}->{61741328} = "Bundaberg";
$areanames{en}->{61741329} = "Mount\ Perry";
$areanames{en}->{61741330} = "Mount\ Perry";
$areanames{en}->{61741331} = "Rosedale";
$areanames{en}->{61741332} = "Gin\ Gin";
$areanames{en}->{61741333} = "Yandaran";
$areanames{en}->{61741334} = "Burnett";
$areanames{en}->{61741335} = "Eidsvold";
$areanames{en}->{61741336} = "Gin\ Gin";
$areanames{en}->{61741337} = "Gin\ Gin";
$areanames{en}->{61741338} = "Gin\ Gin";
$areanames{en}->{61741339} = "Gin\ Gin";
$areanames{en}->{61741340} = "Bundaberg";
$areanames{en}->{61741341} = "Bunker";
$areanames{en}->{61741342} = "Gaeta";
$areanames{en}->{61741343} = "Gin\ Gin";
$areanames{en}->{61741344} = "Lowmead";
$areanames{en}->{61741345} = "Mount\ Perry";
$areanames{en}->{61741346} = "Rosedale";
$areanames{en}->{61741347} = "Yandaran";
$areanames{en}->{61741348} = "Burnett";
$areanames{en}->{61741349} = "Eidsvold";
$areanames{en}->{61741350} = "Tandora";
$areanames{en}->{61741351} = "Burnett";
$areanames{en}->{61741352} = "Eidsvold";
$areanames{en}->{61741353} = "Chahpingah";
$areanames{en}->{61741354} = "Johnstown\ West";
$areanames{en}->{61741355} = "Kingaroy";
$areanames{en}->{61741356} = "Kumbia";
$areanames{en}->{61741357} = "Maidenwell";
$areanames{en}->{61741358} = "Nanango";
$areanames{en}->{61741359} = "Yarraman";
$areanames{en}->{61741360} = "Blackbutt";
$areanames{en}->{61741361} = "Brooklands";
$areanames{en}->{61741362} = "Childers";
$areanames{en}->{61741363} = "Farnsfield";
$areanames{en}->{61741364} = "Fraser\ Island";
$areanames{en}->{61741365} = "Howard";
$areanames{en}->{61741366} = "Maryborough";
$areanames{en}->{61741367} = "Pialba";
$areanames{en}->{61741368} = "Redridge";
$areanames{en}->{61741369} = "Tiaro";
$areanames{en}->{61741370} = "Biggenden";
$areanames{en}->{61741371} = "Booyal";
$areanames{en}->{61741372} = "Brooweena";
$areanames{en}->{61741373} = "Murgon";
$areanames{en}->{61741374} = "Proston";
$areanames{en}->{61741375} = "Tansey";
$areanames{en}->{61741376} = "Windera";
$areanames{en}->{61741377} = "Wondai";
$areanames{en}->{61741378} = "Boondooma";
$areanames{en}->{61741379} = "Manumbar";
$areanames{en}->{61741380} = "Bundaberg";
$areanames{en}->{61741381} = "Bunker";
$areanames{en}->{61741382} = "Gaeta";
$areanames{en}->{61741383} = "Gin\ Gin";
$areanames{en}->{61741384} = "Lowmead";
$areanames{en}->{61741385} = "Mount\ Perry";
$areanames{en}->{61741386} = "Rosedale";
$areanames{en}->{61741387} = "Yandaran";
$areanames{en}->{61741388} = "Burnett";
$areanames{en}->{61741389} = "Eidsvold";
$areanames{en}->{61741390} = "Gayndah";
$areanames{en}->{61741391} = "Gooroolba";
$areanames{en}->{61741392} = "Monogorilby";
$areanames{en}->{61741393} = "Monto";
$areanames{en}->{61741394} = "Moonford";
$areanames{en}->{61741395} = "Mulgildie";
$areanames{en}->{61741396} = "Mundubbera";
$areanames{en}->{61741397} = "Tandora";
$areanames{en}->{61741398} = "Blackbutt";
$areanames{en}->{61741399} = "Brooklands";
$areanames{en}->{61741400} = "Gayndah";
$areanames{en}->{61741401} = "Gooroolba";
$areanames{en}->{61741402} = "Monogorilby";
$areanames{en}->{61741403} = "Monto";
$areanames{en}->{61741404} = "Moonford";
$areanames{en}->{61741405} = "Mulgildie";
$areanames{en}->{61741406} = "Mundubbera";
$areanames{en}->{61741407} = "Tandora";
$areanames{en}->{61741408} = "Gayndah";
$areanames{en}->{61741409} = "Gayndah";
$areanames{en}->{61741410} = "Brooklands";
$areanames{en}->{61741411} = "Chahpingah";
$areanames{en}->{61741412} = "Johnstown\ West";
$areanames{en}->{61741413} = "Kingaroy";
$areanames{en}->{61741414} = "Kumbia";
$areanames{en}->{61741415} = "Maidenwell";
$areanames{en}->{61741416} = "Nanango";
$areanames{en}->{61741417} = "Yarraman";
$areanames{en}->{61741418} = "Biggenden";
$areanames{en}->{61741419} = "Booyal";
$areanames{en}->{61741420} = "Brooweena";
$areanames{en}->{61741421} = "Childers";
$areanames{en}->{61741422} = "Farnsfield";
$areanames{en}->{61741423} = "Fraser\ Island";
$areanames{en}->{61741424} = "Howard";
$areanames{en}->{61741425} = "Maryborough";
$areanames{en}->{61741426} = "Mundubbera";
$areanames{en}->{61741427} = "Pialba";
$areanames{en}->{61741428} = "Redridge";
$areanames{en}->{61741429} = "Tandora";
$areanames{en}->{61741430} = "Chahpingah";
$areanames{en}->{61741431} = "Johnstown\ West";
$areanames{en}->{61741432} = "Kingaroy";
$areanames{en}->{61741433} = "Kumbia";
$areanames{en}->{61741434} = "Maidenwell";
$areanames{en}->{61741435} = "Nanango";
$areanames{en}->{61741436} = "Yarraman";
$areanames{en}->{61741437} = "Biggenden";
$areanames{en}->{61741438} = "Booyal";
$areanames{en}->{61741439} = "Brooweena";
$areanames{en}->{61741440} = "Childers";
$areanames{en}->{61741441} = "Farnsfield";
$areanames{en}->{61741442} = "Fraser\ Island";
$areanames{en}->{61741443} = "Howard";
$areanames{en}->{61741444} = "Maryborough";
$areanames{en}->{61741445} = "Pialba";
$areanames{en}->{61741446} = "Redridge";
$areanames{en}->{61741447} = "Tiaro";
$areanames{en}->{61741448} = "Boondooma";
$areanames{en}->{61741449} = "Manumbar";
$areanames{en}->{61741450} = "Murgon";
$areanames{en}->{61741451} = "Proston";
$areanames{en}->{61741452} = "Tansey";
$areanames{en}->{61741453} = "Windera";
$areanames{en}->{61741454} = "Wondai";
$areanames{en}->{61741455} = "Bundaberg";
$areanames{en}->{61741456} = "Bunker";
$areanames{en}->{61741457} = "Gaeta";
$areanames{en}->{61741458} = "Gin\ Gin";
$areanames{en}->{61741459} = "Lowmead";
$areanames{en}->{61741460} = "Mount\ Perry";
$areanames{en}->{61741461} = "Rosedale";
$areanames{en}->{61741462} = "Yandaran";
$areanames{en}->{61741463} = "Gayndah";
$areanames{en}->{61741464} = "Gooroolba";
$areanames{en}->{61741465} = "Monogorilby";
$areanames{en}->{61741466} = "Monto";
$areanames{en}->{61741467} = "Moonford";
$areanames{en}->{61741468} = "Mulgildie";
$areanames{en}->{61741469} = "Mundubbera";
$areanames{en}->{61741470} = "Burnett";
$areanames{en}->{61741471} = "Eidsvold";
$areanames{en}->{61741472} = "Tandora";
$areanames{en}->{61741473} = "Chahpingah";
$areanames{en}->{61741474} = "Johnstown\ West";
$areanames{en}->{61741475} = "Kingaroy";
$areanames{en}->{61741476} = "Kumbia";
$areanames{en}->{61741477} = "Maidenwell";
$areanames{en}->{61741478} = "Nanango";
$areanames{en}->{61741479} = "Yarraman";
$areanames{en}->{61741480} = "Blackbutt";
$areanames{en}->{61741481} = "Brooklands";
$areanames{en}->{61741482} = "Childers";
$areanames{en}->{61741483} = "Farnsfield";
$areanames{en}->{61741484} = "Fraser\ Island";
$areanames{en}->{61741485} = "Howard";
$areanames{en}->{61741486} = "Maryborough";
$areanames{en}->{61741487} = "Pialba";
$areanames{en}->{61741488} = "Redridge";
$areanames{en}->{61741489} = "Tiaro";
$areanames{en}->{61741490} = "Biggenden";
$areanames{en}->{61741491} = "Booyal";
$areanames{en}->{61741492} = "Brooweena";
$areanames{en}->{61741493} = "Boondooma";
$areanames{en}->{61741494} = "Manumbar";
$areanames{en}->{61741495} = "Murgon";
$areanames{en}->{61741496} = "Proston";
$areanames{en}->{61741497} = "Tansey";
$areanames{en}->{61741498} = "Windera";
$areanames{en}->{61741499} = "Wondai";
$areanames{en}->{617415} = "Bundaberg";
$areanames{en}->{61741509} = "Gin\ Gin";
$areanames{en}->{61741560} = "Yandaran";
$areanames{en}->{61741561} = "Yandaran";
$areanames{en}->{61741562} = "Mount\ Perry";
$areanames{en}->{61741563} = "Mount\ Perry";
$areanames{en}->{61741564} = "Bunker";
$areanames{en}->{61741565} = "Rosedale";
$areanames{en}->{61741566} = "Rosedale";
$areanames{en}->{61741567} = "Gaeta";
$areanames{en}->{61741568} = "Rosedale";
$areanames{en}->{61741569} = "Lowmead";
$areanames{en}->{6174157} = "Gin\ Gin";
$areanames{en}->{61741580} = "Tiaro";
$areanames{en}->{61741581} = "Boondooma";
$areanames{en}->{61741582} = "Manumbar";
$areanames{en}->{61741583} = "Murgon";
$areanames{en}->{61741584} = "Proston";
$areanames{en}->{61741585} = "Tansey";
$areanames{en}->{61741586} = "Windera";
$areanames{en}->{61741587} = "Wondai";
$areanames{en}->{61741588} = "Blackbutt";
$areanames{en}->{61741600} = "Kingaroy";
$areanames{en}->{61741601} = "Monto";
$areanames{en}->{61741602} = "Mundubbera";
$areanames{en}->{61741603} = "Gayndah";
$areanames{en}->{61741604} = "Kingaroy";
$areanames{en}->{61741605} = "Wondai";
$areanames{en}->{61741606} = "Bundaberg";
$areanames{en}->{61741607} = "Nanango";
$areanames{en}->{61741608} = "Bundaberg";
$areanames{en}->{61741609} = "Nanango";
$areanames{en}->{6174161} = "Gayndah";
$areanames{en}->{61741616} = "Gooroolba";
$areanames{en}->{61741617} = "Burnett";
$areanames{en}->{61741618} = "Burnett";
$areanames{en}->{61741619} = "Gooroolba";
$areanames{en}->{6174162} = "Kingaroy";
$areanames{en}->{61741630} = "Blackbutt";
$areanames{en}->{61741631} = "Nanango";
$areanames{en}->{61741632} = "Nanango";
$areanames{en}->{61741633} = "Nanango";
$areanames{en}->{61741634} = "Nanango";
$areanames{en}->{61741635} = "Johnstown\ West";
$areanames{en}->{61741636} = "Kingaroy";
$areanames{en}->{61741637} = "Nanango";
$areanames{en}->{61741638} = "Yarraman";
$areanames{en}->{61741639} = "Yarraman";
$areanames{en}->{61741640} = "Kingaroy";
$areanames{en}->{61741641} = "Kingaroy";
$areanames{en}->{61741642} = "Kingaroy";
$areanames{en}->{61741643} = "Kingaroy";
$areanames{en}->{61741644} = "Kumbia";
$areanames{en}->{61741645} = "Kumbia";
$areanames{en}->{61741646} = "Maidenwell";
$areanames{en}->{61741647} = "Brooklands";
$areanames{en}->{61741648} = "Chahpingah";
$areanames{en}->{61741649} = "Kingaroy";
$areanames{en}->{61741650} = "Tandora";
$areanames{en}->{61741651} = "Eidsvold";
$areanames{en}->{61741652} = "Eidsvold";
$areanames{en}->{61741653} = "Mundubbera";
$areanames{en}->{61741654} = "Mundubbera";
$areanames{en}->{61741655} = "Mundubbera";
$areanames{en}->{61741656} = "Mundubbera";
$areanames{en}->{61741657} = "Eidsvold";
$areanames{en}->{61741658} = "Monogorilby";
$areanames{en}->{61741659} = "Mundubbera";
$areanames{en}->{6174166} = "Monto";
$areanames{en}->{61741660} = "Monogorilby";
$areanames{en}->{61741670} = "Bundaberg";
$areanames{en}->{61741671} = "Gin\ Gin";
$areanames{en}->{61741672} = "Mulgildie";
$areanames{en}->{61741673} = "Bunker";
$areanames{en}->{61741674} = "Gaeta";
$areanames{en}->{61741675} = "Mulgildie";
$areanames{en}->{61741676} = "Gin\ Gin";
$areanames{en}->{61741677} = "Lowmead";
$areanames{en}->{61741678} = "Moonford";
$areanames{en}->{61741679} = "Moonford";
$areanames{en}->{61741680} = "Boondooma";
$areanames{en}->{61741681} = "Murgon";
$areanames{en}->{61741682} = "Murgon";
$areanames{en}->{61741683} = "Murgon";
$areanames{en}->{61741684} = "Murgon";
$areanames{en}->{61741685} = "Wondai";
$areanames{en}->{61741686} = "Windera";
$areanames{en}->{61741687} = "Tansey";
$areanames{en}->{61741688} = "Manumbar";
$areanames{en}->{61741689} = "Proston";
$areanames{en}->{61741690} = "Wondai";
$areanames{en}->{61741691} = "Wondai";
$areanames{en}->{61741692} = "Wondai";
$areanames{en}->{61741693} = "Proston";
$areanames{en}->{61741694} = "Proston";
$areanames{en}->{61741695} = "Murgon";
$areanames{en}->{61741696} = "Murgon";
$areanames{en}->{61741697} = "Murgon";
$areanames{en}->{61741698} = "Murgon";
$areanames{en}->{61741699} = "Murgon";
$areanames{en}->{61741700} = "Blackbutt";
$areanames{en}->{61741701} = "Blackbutt";
$areanames{en}->{61741702} = "Blackbutt";
$areanames{en}->{61741703} = "Mount\ Perry";
$areanames{en}->{61741704} = "Brooklands";
$areanames{en}->{61741705} = "Rosedale";
$areanames{en}->{61741706} = "Yandaran";
$areanames{en}->{61741707} = "Chahpingah";
$areanames{en}->{61741708} = "Burnett";
$areanames{en}->{61741709} = "Eidsvold";
$areanames{en}->{61741710} = "Nanango";
$areanames{en}->{61741711} = "Nanango";
$areanames{en}->{61741712} = "Nanango";
$areanames{en}->{61741713} = "Nanango";
$areanames{en}->{61741714} = "Gayndah";
$areanames{en}->{61741715} = "Gooroolba";
$areanames{en}->{61741716} = "Nanango";
$areanames{en}->{61741717} = "Johnstown\ West";
$areanames{en}->{61741718} = "Monogorilby";
$areanames{en}->{61741719} = "Monto";
$areanames{en}->{61741720} = "Moonford";
$areanames{en}->{61741721} = "Blackbutt";
$areanames{en}->{61741722} = "Mulgildie";
$areanames{en}->{61741723} = "Mundubbera";
$areanames{en}->{61741724} = "Tandora";
$areanames{en}->{61741725} = "Kingaroy";
$areanames{en}->{61741726} = "Blackbutt";
$areanames{en}->{61741727} = "Maidenwell";
$areanames{en}->{61741728} = "Kingaroy";
$areanames{en}->{61741729} = "Kingaroy";
$areanames{en}->{61741730} = "Nanango";
$areanames{en}->{61741731} = "Kumbia";
$areanames{en}->{61741732} = "Kumbia";
$areanames{en}->{61741733} = "Maidenwell";
$areanames{en}->{61741734} = "Brooklands";
$areanames{en}->{61741735} = "Chahpingah";
$areanames{en}->{61741736} = "Johnstown\ West";
$areanames{en}->{61741737} = "Yarraman";
$areanames{en}->{61741738} = "Yarraman";
$areanames{en}->{61741739} = "Yarraman";
$areanames{en}->{61741740} = "Bunker";
$areanames{en}->{61741741} = "Gaeta";
$areanames{en}->{61741742} = "Gin\ Gin";
$areanames{en}->{61741743} = "Lowmead";
$areanames{en}->{61741744} = "Mount\ Perry";
$areanames{en}->{61741745} = "Rosedale";
$areanames{en}->{61741746} = "Yandaran";
$areanames{en}->{61741747} = "Burnett";
$areanames{en}->{61741748} = "Eidsvold";
$areanames{en}->{61741749} = "Gayndah";
$areanames{en}->{61741750} = "Gooroolba";
$areanames{en}->{61741751} = "Monogorilby";
$areanames{en}->{61741752} = "Monto";
$areanames{en}->{61741753} = "Moonford";
$areanames{en}->{61741754} = "Mulgildie";
$areanames{en}->{61741755} = "Mundubbera";
$areanames{en}->{61741756} = "Tandora";
$areanames{en}->{61741757} = "Blackbutt";
$areanames{en}->{61741758} = "Brooklands";
$areanames{en}->{61741759} = "Chahpingah";
$areanames{en}->{61741760} = "Johnstown\ West";
$areanames{en}->{61741761} = "Kumbia";
$areanames{en}->{61741762} = "Maidenwell";
$areanames{en}->{61741763} = "Nanango";
$areanames{en}->{61741764} = "Yarraman";
$areanames{en}->{61741765} = "Biggenden";
$areanames{en}->{61741766} = "Booyal";
$areanames{en}->{61741767} = "Brooweena";
$areanames{en}->{61741768} = "Childers";
$areanames{en}->{61741769} = "Farnsfield";
$areanames{en}->{61741770} = "Fraser\ Island";
$areanames{en}->{61741771} = "Howard";
$areanames{en}->{61741772} = "Redridge";
$areanames{en}->{61741773} = "Tiaro";
$areanames{en}->{61741774} = "Boondooma";
$areanames{en}->{61741775} = "Manumbar";
$areanames{en}->{61741776} = "Murgon";
$areanames{en}->{61741777} = "Proston";
$areanames{en}->{61741778} = "Tansey";
$areanames{en}->{61741779} = "Windera";
$areanames{en}->{61741780} = "Wondai";
$areanames{en}->{61741781} = "Bunker";
$areanames{en}->{61741782} = "Gaeta";
$areanames{en}->{61741783} = "Gin\ Gin";
$areanames{en}->{61741784} = "Lowmead";
$areanames{en}->{61741785} = "Mount\ Perry";
$areanames{en}->{61741786} = "Rosedale";
$areanames{en}->{61741787} = "Yandaran";
$areanames{en}->{61741788} = "Burnett";
$areanames{en}->{61741789} = "Eidsvold";
$areanames{en}->{61741790} = "Kingaroy";
$areanames{en}->{61741791} = "Childers";
$areanames{en}->{61741792} = "Kumbia";
$areanames{en}->{61741793} = "Maidenwell";
$areanames{en}->{61741794} = "Howard";
$areanames{en}->{61741795} = "Murgon";
$areanames{en}->{61741796} = "Murgon";
$areanames{en}->{61741797} = "Murgon";
$areanames{en}->{61741798} = "Murgon";
$areanames{en}->{61741799} = "Murgon";
$areanames{en}->{61741800} = "Gayndah";
$areanames{en}->{61741801} = "Gooroolba";
$areanames{en}->{61741802} = "Monogorilby";
$areanames{en}->{61741803} = "Monto";
$areanames{en}->{61741804} = "Moonford";
$areanames{en}->{61741805} = "Mulgildie";
$areanames{en}->{61741806} = "Mundubbera";
$areanames{en}->{61741807} = "Tandora";
$areanames{en}->{61741808} = "Blackbutt";
$areanames{en}->{61741809} = "Brooklands";
$areanames{en}->{61741810} = "Bundaberg";
$areanames{en}->{61741811} = "Bundaberg";
$areanames{en}->{61741812} = "Bundaberg";
$areanames{en}->{61741813} = "Maryborough";
$areanames{en}->{61741814} = "Pialba";
$areanames{en}->{61741815} = "Redridge";
$areanames{en}->{61741816} = "Tiaro";
$areanames{en}->{61741817} = "Nanango";
$areanames{en}->{61741818} = "Yarraman";
$areanames{en}->{61741819} = "Murgon";
$areanames{en}->{61741820} = "Kingaroy";
$areanames{en}->{61741821} = "Kingaroy";
$areanames{en}->{61741822} = "Chahpingah";
$areanames{en}->{61741823} = "Johnstown\ West";
$areanames{en}->{61741824} = "Kingaroy";
$areanames{en}->{61741825} = "Kumbia";
$areanames{en}->{61741826} = "Maidenwell";
$areanames{en}->{61741827} = "Nanango";
$areanames{en}->{61741828} = "Yarraman";
$areanames{en}->{61741829} = "Biggenden";
$areanames{en}->{61741830} = "Maryborough";
$areanames{en}->{61741831} = "Maryborough";
$areanames{en}->{61741832} = "Biggenden";
$areanames{en}->{61741833} = "Booyal";
$areanames{en}->{61741834} = "Brooweena";
$areanames{en}->{61741835} = "Childers";
$areanames{en}->{61741836} = "Kingaroy";
$areanames{en}->{61741837} = "Pialba";
$areanames{en}->{61741838} = "Pialba";
$areanames{en}->{61741839} = "Pialba";
$areanames{en}->{61741840} = "Pialba";
$areanames{en}->{61741841} = "Pialba";
$areanames{en}->{61741842} = "Pialba";
$areanames{en}->{61741843} = "Booyal";
$areanames{en}->{61741844} = "Brooweena";
$areanames{en}->{61741845} = "Childers";
$areanames{en}->{61741846} = "Farnsfield";
$areanames{en}->{61741847} = "Fraser\ Island";
$areanames{en}->{61741848} = "Howard";
$areanames{en}->{61741849} = "Maryborough";
$areanames{en}->{61741850} = "Redridge";
$areanames{en}->{61741851} = "Tiaro";
$areanames{en}->{61741852} = "Boondooma";
$areanames{en}->{61741853} = "Manumbar";
$areanames{en}->{61741854} = "Murgon";
$areanames{en}->{61741855} = "Proston";
$areanames{en}->{61741856} = "Tansey";
$areanames{en}->{61741857} = "Windera";
$areanames{en}->{61741858} = "Wondai";
$areanames{en}->{61741859} = "Booyal";
$areanames{en}->{61741860} = "Booyal";
$areanames{en}->{61741861} = "Brooweena";
$areanames{en}->{61741862} = "Brooweena";
$areanames{en}->{61741863} = "Childers";
$areanames{en}->{61741864} = "Childers";
$areanames{en}->{61741865} = "Farnsfield";
$areanames{en}->{61741866} = "Farnsfield";
$areanames{en}->{61741867} = "Howard";
$areanames{en}->{61741868} = "Howard";
$areanames{en}->{61741869} = "Bundaberg";
$areanames{en}->{61741870} = "Bundaberg";
$areanames{en}->{61741871} = "Tiaro";
$areanames{en}->{61741872} = "Tiaro";
$areanames{en}->{61741873} = "Mulgildie";
$areanames{en}->{61741874} = "Mulgildie";
$areanames{en}->{61741875} = "Monto";
$areanames{en}->{61741876} = "Monto";
$areanames{en}->{61741877} = "Gooroolba";
$areanames{en}->{61741878} = "Gooroolba";
$areanames{en}->{61741879} = "Gayndah";
$areanames{en}->{61741880} = "Gayndah";
$areanames{en}->{61741881} = "Yandaran";
$areanames{en}->{61741882} = "Yandaran";
$areanames{en}->{61741883} = "Rosedale";
$areanames{en}->{61741884} = "Rosedale";
$areanames{en}->{61741885} = "Mount\ Perry";
$areanames{en}->{61741886} = "Mount\ Perry";
$areanames{en}->{61741887} = "Lowmead";
$areanames{en}->{61741888} = "Lowmead";
$areanames{en}->{61741889} = "Gin\ Gin";
$areanames{en}->{61741890} = "Gin\ Gin";
$areanames{en}->{61741891} = "Gaeta";
$areanames{en}->{61741892} = "Gaeta";
$areanames{en}->{61741893} = "Bundaberg";
$areanames{en}->{61741894} = "Bundaberg";
$areanames{en}->{61741895} = "Kingaroy";
$areanames{en}->{61741896} = "Kingaroy";
$areanames{en}->{61741897} = "Biggenden";
$areanames{en}->{61741898} = "Biggenden";
$areanames{en}->{61741899} = "Kingaroy";
$areanames{en}->{6174190} = "Maryborough";
$areanames{en}->{61741906} = "Booyal";
$areanames{en}->{61741907} = "Kingaroy";
$areanames{en}->{61741908} = "Brooweena";
$areanames{en}->{61741909} = "Brooweena";
$areanames{en}->{61741910} = "Maryborough";
$areanames{en}->{61741911} = "Maryborough";
$areanames{en}->{61741912} = "Pialba";
$areanames{en}->{61741913} = "Pialba";
$areanames{en}->{61741914} = "Pialba";
$areanames{en}->{61741915} = "Bundaberg";
$areanames{en}->{61741916} = "Maryborough";
$areanames{en}->{61741917} = "Murgon";
$areanames{en}->{61741918} = "Murgon";
$areanames{en}->{61741919} = "Bundaberg";
$areanames{en}->{61741920} = "Childers";
$areanames{en}->{61741921} = "Childers";
$areanames{en}->{61741922} = "Fraser\ Island";
$areanames{en}->{61741923} = "Fraser\ Island";
$areanames{en}->{61741924} = "Childers";
$areanames{en}->{61741925} = "Childers";
$areanames{en}->{61741926} = "Farnsfield";
$areanames{en}->{61741927} = "Pialba";
$areanames{en}->{61741928} = "Pialba";
$areanames{en}->{61741929} = "Childers";
$areanames{en}->{61741930} = "Howard";
$areanames{en}->{61741931} = "Howard";
$areanames{en}->{61741932} = "Howard";
$areanames{en}->{61741933} = "Howard";
$areanames{en}->{61741934} = "Howard";
$areanames{en}->{61741935} = "Tiaro";
$areanames{en}->{61741936} = "Tiaro";
$areanames{en}->{61741937} = "Tiaro";
$areanames{en}->{61741938} = "Tiaro";
$areanames{en}->{61741939} = "Tiaro";
$areanames{en}->{6174194} = "Pialba";
$areanames{en}->{61741950} = "Proston";
$areanames{en}->{61741951} = "Proston";
$areanames{en}->{61741952} = "Tansey";
$areanames{en}->{61741953} = "Tansey";
$areanames{en}->{61741954} = "Windera";
$areanames{en}->{61741955} = "Windera";
$areanames{en}->{61741956} = "Wondai";
$areanames{en}->{61741957} = "Wondai";
$areanames{en}->{61741958} = "Redridge";
$areanames{en}->{61741959} = "Redridge";
$areanames{en}->{61741960} = "Bundaberg";
$areanames{en}->{61741961} = "Brooklands";
$areanames{en}->{61741962} = "Brooklands";
$areanames{en}->{61741963} = "Blackbutt";
$areanames{en}->{61741964} = "Blackbutt";
$areanames{en}->{61741965} = "Maryborough";
$areanames{en}->{61741966} = "Maryborough";
$areanames{en}->{61741967} = "Pialba";
$areanames{en}->{61741968} = "Pialba";
$areanames{en}->{61741969} = "Pialba";
$areanames{en}->{6174197} = "Pialba";
$areanames{en}->{6174198} = "Bundaberg";
$areanames{en}->{61741990} = "Yarraman";
$areanames{en}->{61741991} = "Yarraman";
$areanames{en}->{61741992} = "Nanango";
$areanames{en}->{61741993} = "Nanango";
$areanames{en}->{61741994} = "Maidenwell";
$areanames{en}->{61741995} = "Maidenwell";
$areanames{en}->{61741996} = "Bundaberg";
$areanames{en}->{61741997} = "Bundaberg";
$areanames{en}->{61741998} = "Johnstown\ West";
$areanames{en}->{61741999} = "Johnstown\ West";
$areanames{en}->{61742000} = "Aurukun";
$areanames{en}->{61742001} = "Bloomfield";
$areanames{en}->{61742002} = "Chillagoe";
$areanames{en}->{61742003} = "Coen";
$areanames{en}->{61742004} = "Dimbulah";
$areanames{en}->{61742005} = "Edward\ River";
$areanames{en}->{61742006} = "Etheridge";
$areanames{en}->{61742007} = "Euramo";
$areanames{en}->{61742008} = "Georgetown";
$areanames{en}->{61742009} = "Gordonvale";
$areanames{en}->{61742010} = "Herberton";
$areanames{en}->{61742011} = "Hopevale";
$areanames{en}->{61742012} = "Innot\ Hot\ Springs";
$areanames{en}->{61742013} = "Kidston";
$areanames{en}->{61742014} = "Kowanyama";
$areanames{en}->{61742015} = "Kuranda";
$areanames{en}->{61742016} = "Lakeland";
$areanames{en}->{61742017} = "Lockhart\ River";
$areanames{en}->{61742018} = "Malanda";
$areanames{en}->{61742019} = "Maryfarms";
$areanames{en}->{61742020} = "Millaa\ Millaa";
$areanames{en}->{61742021} = "Minnamoolka";
$areanames{en}->{61742022} = "Molloy";
$areanames{en}->{61742023} = "Mount\ Garnet";
$areanames{en}->{61742024} = "Mount\ Surprise";
$areanames{en}->{61742025} = "Mutchilba";
$areanames{en}->{61742026} = "Peninsula";
$areanames{en}->{61742027} = "Ravenshoe";
$areanames{en}->{61742028} = "Silkwood";
$areanames{en}->{61742029} = "South\ Johnstone";
$areanames{en}->{61742030} = "Thursday\ Island";
$areanames{en}->{61742031} = "Torres";
$areanames{en}->{61742032} = "Walsh\ River";
$areanames{en}->{61742033} = "Gordonvale";
$areanames{en}->{61742034} = "Herberton";
$areanames{en}->{61742035} = "Hopevale";
$areanames{en}->{61742036} = "Innisfail";
$areanames{en}->{61742037} = "Mareeba";
$areanames{en}->{61742038} = "Innot\ Hot\ Springs";
$areanames{en}->{61742039} = "Kidston";
$areanames{en}->{61742040} = "Kowanyama";
$areanames{en}->{61742041} = "Molloy";
$areanames{en}->{61742042} = "Mossman";
$areanames{en}->{61742043} = "Kuranda";
$areanames{en}->{61742044} = "Lakeland";
$areanames{en}->{61742045} = "Lockhart\ River";
$areanames{en}->{61742046} = "Malanda";
$areanames{en}->{61742047} = "Mareeba";
$areanames{en}->{61742048} = "Silkwood";
$areanames{en}->{61742049} = "South\ Johnstone";
$areanames{en}->{61742050} = "Maryfarms";
$areanames{en}->{61742051} = "Millaa\ Millaa";
$areanames{en}->{61742052} = "Tully";
$areanames{en}->{61742053} = "Minnamoolka";
$areanames{en}->{61742054} = "Weipa";
$areanames{en}->{61742055} = "Innisfail";
$areanames{en}->{61742056} = "Kuranda";
$areanames{en}->{61742057} = "Kuranda";
$areanames{en}->{61742058} = "Molloy";
$areanames{en}->{61742059} = "Molloy";
$areanames{en}->{6174206} = "Cairns";
$areanames{en}->{61742070} = "Hopevale";
$areanames{en}->{61742071} = "Hopevale";
$areanames{en}->{61742072} = "Bloomfield";
$areanames{en}->{61742073} = "Bloomfield";
$areanames{en}->{61742074} = "Chillagoe";
$areanames{en}->{61742075} = "Chillagoe";
$areanames{en}->{61742076} = "Lakeland";
$areanames{en}->{61742077} = "Lakeland";
$areanames{en}->{61742078} = "Minnamoolka";
$areanames{en}->{61742079} = "Minnamoolka";
$areanames{en}->{61742080} = "Peninsula";
$areanames{en}->{61742081} = "Peninsula";
$areanames{en}->{61742082} = "Walsh\ River";
$areanames{en}->{61742083} = "Walsh\ River";
$areanames{en}->{61742084} = "Cooktown";
$areanames{en}->{61742085} = "Cooktown";
$areanames{en}->{61742086} = "Daintree";
$areanames{en}->{61742087} = "Daintree";
$areanames{en}->{61742088} = "Gordonvale";
$areanames{en}->{61742089} = "Gordonvale";
$areanames{en}->{61742090} = "Innot\ Hot\ Springs";
$areanames{en}->{61742091} = "Innot\ Hot\ Springs";
$areanames{en}->{61742092} = "Malanda";
$areanames{en}->{61742093} = "Malanda";
$areanames{en}->{61742094} = "Maryfarms";
$areanames{en}->{61742095} = "Maryfarms";
$areanames{en}->{61742096} = "Millaa\ Millaa";
$areanames{en}->{61742097} = "Millaa\ Millaa";
$areanames{en}->{61742098} = "Mount\ Garnet";
$areanames{en}->{61742099} = "Mount\ Garnet";
$areanames{en}->{61742100} = "Ravenshoe";
$areanames{en}->{61742101} = "Ravenshoe";
$areanames{en}->{61742102} = "Silkwood";
$areanames{en}->{61742103} = "Silkwood";
$areanames{en}->{61742104} = "South\ Johnstone";
$areanames{en}->{61742105} = "South\ Johnstone";
$areanames{en}->{61742106} = "Tully";
$areanames{en}->{61742107} = "Tully";
$areanames{en}->{61742108} = "Weipa";
$areanames{en}->{61742109} = "Weipa";
$areanames{en}->{6174211} = "Cairns";
$areanames{en}->{61742120} = "Thursday\ Island";
$areanames{en}->{61742121} = "Thursday\ Island";
$areanames{en}->{61742122} = "Thursday\ Island";
$areanames{en}->{61742123} = "Thursday\ Island";
$areanames{en}->{61742124} = "Cairns";
$areanames{en}->{61742125} = "Kowanyama";
$areanames{en}->{61742126} = "Lockhart\ River";
$areanames{en}->{61742127} = "Coen";
$areanames{en}->{61742128} = "Hopevale";
$areanames{en}->{61742129} = "Torres";
$areanames{en}->{61742130} = "Thursday\ Island";
$areanames{en}->{61742131} = "Cairns";
$areanames{en}->{61742132} = "Mossman";
$areanames{en}->{61742133} = "Mossman";
$areanames{en}->{61742134} = "Tully";
$areanames{en}->{61742135} = "Innisfail";
$areanames{en}->{61742136} = "Weipa";
$areanames{en}->{61742137} = "Babinda";
$areanames{en}->{61742138} = "Mossman";
$areanames{en}->{61742139} = "Mossman";
$areanames{en}->{61742140} = "Cairns";
$areanames{en}->{61742141} = "Mareeba";
$areanames{en}->{61742142} = "Daintree";
$areanames{en}->{61742143} = "Atherton";
$areanames{en}->{61742144} = "Cooktown";
$areanames{en}->{61742145} = "Cairns";
$areanames{en}->{61742146} = "Weipa";
$areanames{en}->{61742147} = "Torres";
$areanames{en}->{61742148} = "Torres";
$areanames{en}->{61742149} = "Torres";
$areanames{en}->{61742150} = "Molloy";
$areanames{en}->{61742151} = "Weipa";
$areanames{en}->{61742152} = "Kidston";
$areanames{en}->{61742153} = "Peninsula";
$areanames{en}->{61742154} = "Innisfail";
$areanames{en}->{61742155} = "Mount\ Garnet";
$areanames{en}->{61742156} = "Torres";
$areanames{en}->{61742157} = "Tully";
$areanames{en}->{61742158} = "Euramo";
$areanames{en}->{61742159} = "Mossman";
$areanames{en}->{61742160} = "Mount\ Garnet";
$areanames{en}->{61742161} = "Aurukun";
$areanames{en}->{61742162} = "Kuranda";
$areanames{en}->{61742163} = "Minnamoolka";
$areanames{en}->{61742164} = "Chillagoe";
$areanames{en}->{61742165} = "Bloomfield";
$areanames{en}->{61742166} = "Cairns";
$areanames{en}->{61742167} = "Coen";
$areanames{en}->{61742168} = "Gordonvale";
$areanames{en}->{61742169} = "Peninsula";
$areanames{en}->{61742170} = "Mount\ Surprise";
$areanames{en}->{61742171} = "Hopevale";
$areanames{en}->{61742172} = "Malanda";
$areanames{en}->{61742173} = "Georgetown";
$areanames{en}->{61742174} = "Innot\ Hot\ Springs";
$areanames{en}->{61742175} = "Edward\ River";
$areanames{en}->{61742176} = "Herberton";
$areanames{en}->{61742177} = "Babinda";
$areanames{en}->{61742178} = "South\ Johnstone";
$areanames{en}->{61742179} = "Mutchilba";
$areanames{en}->{61742180} = "Peninsula";
$areanames{en}->{61742181} = "Ravenshoe";
$areanames{en}->{61742182} = "Molloy";
$areanames{en}->{61742183} = "Maryfarms";
$areanames{en}->{61742184} = "Mutchilba";
$areanames{en}->{61742185} = "Millaa\ Millaa";
$areanames{en}->{61742186} = "Walsh\ River";
$areanames{en}->{61742187} = "Mareeba";
$areanames{en}->{61742188} = "Etheridge";
$areanames{en}->{61742189} = "Ravenshoe";
$areanames{en}->{61742190} = "Silkwood";
$areanames{en}->{61742191} = "Thursday\ Island";
$areanames{en}->{61742192} = "Mount\ Surprise";
$areanames{en}->{61742193} = "Silkwood";
$areanames{en}->{61742194} = "Kowanyama";
$areanames{en}->{61742195} = "Daintree";
$areanames{en}->{61742196} = "Atherton";
$areanames{en}->{61742197} = "Mossman";
$areanames{en}->{61742198} = "Lakeland";
$areanames{en}->{61742199} = "South\ Johnstone";
$areanames{en}->{61742200} = "Thursday\ Island";
$areanames{en}->{61742201} = "Dimbulah";
$areanames{en}->{61742202} = "Lockhart\ River";
$areanames{en}->{61742203} = "Cooktown";
$areanames{en}->{61742204} = "South\ Johnstone";
$areanames{en}->{61742205} = "Tully";
$areanames{en}->{61742206} = "Aurukun";
$areanames{en}->{61742207} = "Aurukun";
$areanames{en}->{61742208} = "Aurukun";
$areanames{en}->{61742209} = "Cairns";
$areanames{en}->{6174221} = "Cairns";
$areanames{en}->{6174222} = "Cairns";
$areanames{en}->{61742230} = "Innisfail";
$areanames{en}->{61742231} = "Mareeba";
$areanames{en}->{61742232} = "Mutchilba";
$areanames{en}->{61742233} = "Mutchilba";
$areanames{en}->{61742234} = "Mossman";
$areanames{en}->{61742235} = "Mossman";
$areanames{en}->{61742236} = "Mareeba";
$areanames{en}->{61742237} = "Mareeba";
$areanames{en}->{61742238} = "Innisfail";
$areanames{en}->{61742239} = "Innisfail";
$areanames{en}->{61742240} = "Herberton";
$areanames{en}->{61742241} = "Herberton";
$areanames{en}->{61742242} = "Euramo";
$areanames{en}->{61742243} = "Euramo";
$areanames{en}->{61742244} = "Dimbulah";
$areanames{en}->{61742245} = "Dimbulah";
$areanames{en}->{61742246} = "Cairns";
$areanames{en}->{61742247} = "Cairns";
$areanames{en}->{61742248} = "Babinda";
$areanames{en}->{61742249} = "Babinda";
$areanames{en}->{61742250} = "Atherton";
$areanames{en}->{61742251} = "Atherton";
$areanames{en}->{61742252} = "Cairns";
$areanames{en}->{61742253} = "Cairns";
$areanames{en}->{61742254} = "Cairns";
$areanames{en}->{61742255} = "Cairns";
$areanames{en}->{61742256} = "Mount\ Surprise";
$areanames{en}->{61742257} = "Mount\ Surprise";
$areanames{en}->{61742258} = "Thursday\ Island";
$areanames{en}->{61742259} = "Thursday\ Island";
$areanames{en}->{6174226} = "Cairns";
$areanames{en}->{61742270} = "Torres";
$areanames{en}->{61742271} = "Aurukun";
$areanames{en}->{61742272} = "Euramo";
$areanames{en}->{61742273} = "Kuranda";
$areanames{en}->{61742274} = "Chillagoe";
$areanames{en}->{61742275} = "Minnamoolka";
$areanames{en}->{61742276} = "Hopevale";
$areanames{en}->{61742277} = "Innot\ Hot\ Springs";
$areanames{en}->{61742278} = "Edward\ River";
$areanames{en}->{61742279} = "Tully";
$areanames{en}->{61742280} = "Walsh\ River";
$areanames{en}->{61742281} = "Babinda";
$areanames{en}->{61742282} = "South\ Johnstone";
$areanames{en}->{61742283} = "Ravenshoe";
$areanames{en}->{61742284} = "Molloy";
$areanames{en}->{61742285} = "Mutchilba";
$areanames{en}->{61742286} = "Millaa\ Millaa";
$areanames{en}->{61742287} = "Walsh\ River";
$areanames{en}->{61742288} = "Mareeba";
$areanames{en}->{61742289} = "Weipa";
$areanames{en}->{61742290} = "Cairns";
$areanames{en}->{61742291} = "Etheridge";
$areanames{en}->{61742292} = "Thursday\ Island";
$areanames{en}->{61742293} = "Silkwood";
$areanames{en}->{61742294} = "Kowanyama";
$areanames{en}->{61742295} = "Atherton";
$areanames{en}->{61742296} = "Lockhart\ River";
$areanames{en}->{61742297} = "Weipa";
$areanames{en}->{61742298} = "Kidston";
$areanames{en}->{61742299} = "Cairns";
$areanames{en}->{61742300} = "Cairns";
$areanames{en}->{61742301} = "Peninsula";
$areanames{en}->{61742302} = "Innisfail";
$areanames{en}->{61742303} = "Mount\ Garnet";
$areanames{en}->{61742304} = "Torres";
$areanames{en}->{61742305} = "Tully";
$areanames{en}->{61742306} = "Bloomfield";
$areanames{en}->{61742307} = "Cairns";
$areanames{en}->{61742308} = "Coen";
$areanames{en}->{61742309} = "Mareeba";
$areanames{en}->{61742310} = "Atherton";
$areanames{en}->{61742311} = "Gordonvale";
$areanames{en}->{61742312} = "Malanda";
$areanames{en}->{61742313} = "Georgetown";
$areanames{en}->{61742314} = "Herberton";
$areanames{en}->{61742315} = "Maryfarms";
$areanames{en}->{61742316} = "Mount\ Surprise";
$areanames{en}->{61742317} = "Daintree";
$areanames{en}->{61742318} = "Mossman";
$areanames{en}->{61742319} = "Cairns";
$areanames{en}->{61742320} = "Aurukun";
$areanames{en}->{61742321} = "Cairns";
$areanames{en}->{61742322} = "Cairns";
$areanames{en}->{61742323} = "Cairns";
$areanames{en}->{61742324} = "Cairns";
$areanames{en}->{61742325} = "Cairns";
$areanames{en}->{61742326} = "Innisfail";
$areanames{en}->{61742327} = "Innisfail";
$areanames{en}->{61742328} = "Innisfail";
$areanames{en}->{61742329} = "Innisfail";
$areanames{en}->{61742330} = "Babinda";
$areanames{en}->{61742331} = "Lakeland";
$areanames{en}->{61742332} = "Dimbulah";
$areanames{en}->{61742333} = "Cooktown";
$areanames{en}->{61742334} = "Aurukun";
$areanames{en}->{61742335} = "Euramo";
$areanames{en}->{61742336} = "Kuranda";
$areanames{en}->{61742337} = "Chillagoe";
$areanames{en}->{61742338} = "Minnamoolka";
$areanames{en}->{61742339} = "Bloomfield";
$areanames{en}->{61742340} = "Cairns";
$areanames{en}->{61742341} = "Hopevale";
$areanames{en}->{61742342} = "Innot\ Hot\ Springs";
$areanames{en}->{61742343} = "Edward\ River";
$areanames{en}->{61742344} = "Babinda";
$areanames{en}->{61742345} = "South\ Johnstone";
$areanames{en}->{61742346} = "Ravenshoe";
$areanames{en}->{61742347} = "Molloy";
$areanames{en}->{61742348} = "Mutchilba";
$areanames{en}->{61742349} = "Chillagoe";
$areanames{en}->{61742350} = "Coen";
$areanames{en}->{61742351} = "Millaa\ Millaa";
$areanames{en}->{61742352} = "Walsh\ River";
$areanames{en}->{61742353} = "Etheridge";
$areanames{en}->{61742354} = "Thursday\ Island";
$areanames{en}->{61742355} = "Silkwood";
$areanames{en}->{61742356} = "Kowanyama";
$areanames{en}->{61742357} = "Atherton";
$areanames{en}->{61742358} = "Lockhart\ River";
$areanames{en}->{61742359} = "Cooktown";
$areanames{en}->{61742360} = "Daintree";
$areanames{en}->{61742361} = "Weipa";
$areanames{en}->{61742362} = "Kidston";
$areanames{en}->{61742363} = "Peninsula";
$areanames{en}->{61742364} = "Mount\ Garnet";
$areanames{en}->{61742365} = "Torres";
$areanames{en}->{61742366} = "Tully";
$areanames{en}->{61742367} = "Bloomfield";
$areanames{en}->{61742368} = "Coen";
$areanames{en}->{61742369} = "Dimbulah";
$areanames{en}->{61742370} = "Edward\ River";
$areanames{en}->{61742371} = "Gordonvale";
$areanames{en}->{61742372} = "Malanda";
$areanames{en}->{61742373} = "Georgetown";
$areanames{en}->{61742374} = "Herberton";
$areanames{en}->{61742375} = "Maryfarms";
$areanames{en}->{61742376} = "Mount\ Surprise";
$areanames{en}->{61742377} = "Daintree";
$areanames{en}->{61742378} = "Mossman";
$areanames{en}->{61742379} = "Etheridge";
$areanames{en}->{61742380} = "Euramo";
$areanames{en}->{61742381} = "Lakeland";
$areanames{en}->{61742382} = "Dimbulah";
$areanames{en}->{61742383} = "Cooktown";
$areanames{en}->{61742384} = "Georgetown";
$areanames{en}->{61742385} = "Gordonvale";
$areanames{en}->{61742386} = "Herberton";
$areanames{en}->{61742387} = "Hopevale";
$areanames{en}->{61742388} = "Innisfail";
$areanames{en}->{61742389} = "Edward\ River";
$areanames{en}->{61742390} = "Innot\ Hot\ Springs";
$areanames{en}->{61742391} = "Kidston";
$areanames{en}->{61742392} = "Kowanyama";
$areanames{en}->{61742393} = "Kuranda";
$areanames{en}->{61742394} = "Lakeland";
$areanames{en}->{61742395} = "Lockhart\ River";
$areanames{en}->{61742396} = "Malanda";
$areanames{en}->{61742397} = "Mareeba";
$areanames{en}->{61742398} = "Maryfarms";
$areanames{en}->{61742399} = "Millaa\ Millaa";
$areanames{en}->{61742400} = "Minnamoolka";
$areanames{en}->{61742401} = "Molloy";
$areanames{en}->{61742402} = "Mossman";
$areanames{en}->{61742403} = "Mount\ Garnet";
$areanames{en}->{61742404} = "Mount\ Surprise";
$areanames{en}->{61742405} = "Mutchilba";
$areanames{en}->{61742406} = "Peninsula";
$areanames{en}->{61742407} = "Ravenshoe";
$areanames{en}->{61742408} = "Silkwood";
$areanames{en}->{61742409} = "South\ Johnstone";
$areanames{en}->{6174241} = "Cairns";
$areanames{en}->{6174242} = "Cairns";
$areanames{en}->{61742420} = "Thursday\ Island";
$areanames{en}->{61742426} = "Torres";
$areanames{en}->{61742427} = "Torres";
$areanames{en}->{61742429} = "Torres";
$areanames{en}->{6174243} = "Cairns";
$areanames{en}->{61742430} = "Tully";
$areanames{en}->{61742431} = "Walsh\ River";
$areanames{en}->{61742432} = "Weipa";
$areanames{en}->{61742440} = "Cairns";
$areanames{en}->{61742441} = "Cairns";
$areanames{en}->{61742442} = "Cairns";
$areanames{en}->{61742443} = "Atherton";
$areanames{en}->{61742444} = "Aurukun";
$areanames{en}->{61742445} = "Babinda";
$areanames{en}->{61742446} = "Bloomfield";
$areanames{en}->{61742447} = "Cairns";
$areanames{en}->{61742448} = "Chillagoe";
$areanames{en}->{61742449} = "Coen";
$areanames{en}->{61742450} = "Cooktown";
$areanames{en}->{61742451} = "Daintree";
$areanames{en}->{61742452} = "Dimbulah";
$areanames{en}->{61742453} = "Edward\ River";
$areanames{en}->{61742454} = "Etheridge";
$areanames{en}->{61742455} = "Euramo";
$areanames{en}->{61742456} = "Georgetown";
$areanames{en}->{61742457} = "Gordonvale";
$areanames{en}->{61742458} = "Cairns";
$areanames{en}->{61742459} = "Cairns";
$areanames{en}->{61742460} = "Herberton";
$areanames{en}->{61742461} = "Hopevale";
$areanames{en}->{61742462} = "Innisfail";
$areanames{en}->{61742463} = "Innot\ Hot\ Springs";
$areanames{en}->{61742464} = "Kidston";
$areanames{en}->{61742465} = "Kowanyama";
$areanames{en}->{61742466} = "Kuranda";
$areanames{en}->{61742467} = "Lakeland";
$areanames{en}->{61742468} = "Lockhart\ River";
$areanames{en}->{61742469} = "Malanda";
$areanames{en}->{61742470} = "Mareeba";
$areanames{en}->{61742471} = "Maryfarms";
$areanames{en}->{61742472} = "Millaa\ Millaa";
$areanames{en}->{61742473} = "Minnamoolka";
$areanames{en}->{61742474} = "Molloy";
$areanames{en}->{61742475} = "Mossman";
$areanames{en}->{61742476} = "Mount\ Garnet";
$areanames{en}->{61742477} = "Mount\ Surprise";
$areanames{en}->{61742478} = "Mutchilba";
$areanames{en}->{61742479} = "Peninsula";
$areanames{en}->{61742480} = "Ravenshoe";
$areanames{en}->{61742481} = "Silkwood";
$areanames{en}->{61742482} = "South\ Johnstone";
$areanames{en}->{61742483} = "Thursday\ Island";
$areanames{en}->{61742484} = "Torres";
$areanames{en}->{61742485} = "Tully";
$areanames{en}->{61742486} = "Walsh\ River";
$areanames{en}->{61742487} = "Weipa";
$areanames{en}->{61742488} = "Cairns";
$areanames{en}->{61742489} = "Atherton";
$areanames{en}->{61742490} = "Aurukun";
$areanames{en}->{61742491} = "Babinda";
$areanames{en}->{61742492} = "Bloomfield";
$areanames{en}->{61742493} = "Cairns";
$areanames{en}->{61742494} = "Chillagoe";
$areanames{en}->{61742495} = "Coen";
$areanames{en}->{61742496} = "Cooktown";
$areanames{en}->{61742497} = "Daintree";
$areanames{en}->{61742498} = "Dimbulah";
$areanames{en}->{61742499} = "Edward\ River";
$areanames{en}->{61742500} = "Etheridge";
$areanames{en}->{61742501} = "Euramo";
$areanames{en}->{61742502} = "Georgetown";
$areanames{en}->{61742503} = "Gordonvale";
$areanames{en}->{61742504} = "Herberton";
$areanames{en}->{61742505} = "Hopevale";
$areanames{en}->{61742506} = "Innisfail";
$areanames{en}->{61742507} = "Innot\ Hot\ Springs";
$areanames{en}->{61742508} = "Kidston";
$areanames{en}->{61742509} = "Kowanyama";
$areanames{en}->{61742510} = "Kuranda";
$areanames{en}->{61742511} = "Lakeland";
$areanames{en}->{61742512} = "Lockhart\ River";
$areanames{en}->{61742513} = "Malanda";
$areanames{en}->{61742514} = "Mareeba";
$areanames{en}->{61742515} = "Maryfarms";
$areanames{en}->{61742516} = "Millaa\ Millaa";
$areanames{en}->{61742517} = "Minnamoolka";
$areanames{en}->{61742518} = "Molloy";
$areanames{en}->{61742519} = "Mossman";
$areanames{en}->{6174252} = "Cairns";
$areanames{en}->{61742520} = "Mount\ Garnet";
$areanames{en}->{61742521} = "Georgetown";
$areanames{en}->{6174253} = "Cairns";
$areanames{en}->{61742530} = "Mount\ Surprise";
$areanames{en}->{61742531} = "Mutchilba";
$areanames{en}->{61742532} = "Peninsula";
$areanames{en}->{6174254} = "Cairns";
$areanames{en}->{61742546} = "Herberton";
$areanames{en}->{61742547} = "Herberton";
$areanames{en}->{61742548} = "Mareeba";
$areanames{en}->{61742549} = "Mareeba";
$areanames{en}->{61742550} = "Ravenshoe";
$areanames{en}->{61742551} = "Silkwood";
$areanames{en}->{61742552} = "South\ Johnstone";
$areanames{en}->{61742553} = "Thursday\ Island";
$areanames{en}->{61742554} = "Torres";
$areanames{en}->{61742555} = "Cairns";
$areanames{en}->{61742556} = "Cairns";
$areanames{en}->{61742557} = "Cairns";
$areanames{en}->{61742558} = "Cairns";
$areanames{en}->{61742559} = "Cairns";
$areanames{en}->{6174256} = "Cairns";
$areanames{en}->{61742569} = "Tully";
$areanames{en}->{61742570} = "Walsh\ River";
$areanames{en}->{61742571} = "Weipa";
$areanames{en}->{61742572} = "Atherton";
$areanames{en}->{61742573} = "Atherton";
$areanames{en}->{61742574} = "Atherton";
$areanames{en}->{61742575} = "Cairns";
$areanames{en}->{61742576} = "Atherton";
$areanames{en}->{61742577} = "Aurukun";
$areanames{en}->{61742578} = "Babinda";
$areanames{en}->{61742579} = "Bloomfield";
$areanames{en}->{61742580} = "Cairns";
$areanames{en}->{61742581} = "Chillagoe";
$areanames{en}->{61742582} = "Coen";
$areanames{en}->{61742583} = "Cooktown";
$areanames{en}->{61742584} = "Gordonvale";
$areanames{en}->{61742585} = "Gordonvale";
$areanames{en}->{61742586} = "Gordonvale";
$areanames{en}->{61742587} = "Mossman";
$areanames{en}->{61742588} = "Mossman";
$areanames{en}->{61742589} = "Atherton";
$areanames{en}->{61742590} = "Aurukun";
$areanames{en}->{61742591} = "Babinda";
$areanames{en}->{61742592} = "Bloomfield";
$areanames{en}->{61742593} = "Cairns";
$areanames{en}->{61742594} = "Chillagoe";
$areanames{en}->{61742595} = "Coen";
$areanames{en}->{61742596} = "Cooktown";
$areanames{en}->{61742597} = "Daintree";
$areanames{en}->{61742598} = "Dimbulah";
$areanames{en}->{61742599} = "Edward\ River";
$areanames{en}->{61742600} = "Etheridge";
$areanames{en}->{61742601} = "Euramo";
$areanames{en}->{61742602} = "Georgetown";
$areanames{en}->{61742603} = "Gordonvale";
$areanames{en}->{61742604} = "Herberton";
$areanames{en}->{61742605} = "Hopevale";
$areanames{en}->{61742606} = "Innisfail";
$areanames{en}->{61742607} = "Innot\ Hot\ Springs";
$areanames{en}->{61742608} = "Kidston";
$areanames{en}->{61742609} = "Kowanyama";
$areanames{en}->{61742610} = "Kuranda";
$areanames{en}->{61742611} = "Lakeland";
$areanames{en}->{61742612} = "Lockhart\ River";
$areanames{en}->{61742613} = "Malanda";
$areanames{en}->{61742614} = "Mareeba";
$areanames{en}->{61742615} = "Maryfarms";
$areanames{en}->{61742616} = "Millaa\ Millaa";
$areanames{en}->{61742617} = "Minnamoolka";
$areanames{en}->{61742618} = "Molloy";
$areanames{en}->{61742619} = "Mossman";
$areanames{en}->{61742620} = "Mount\ Garnet";
$areanames{en}->{61742621} = "Mount\ Surprise";
$areanames{en}->{61742622} = "Mutchilba";
$areanames{en}->{61742623} = "Peninsula";
$areanames{en}->{61742624} = "Ravenshoe";
$areanames{en}->{61742625} = "Silkwood";
$areanames{en}->{61742626} = "South\ Johnstone";
$areanames{en}->{61742627} = "Thursday\ Island";
$areanames{en}->{61742628} = "Torres";
$areanames{en}->{61742629} = "Tully";
$areanames{en}->{61742630} = "Walsh\ River";
$areanames{en}->{61742631} = "Weipa";
$areanames{en}->{61742632} = "Babinda";
$areanames{en}->{61742633} = "Cooktown";
$areanames{en}->{61742634} = "Cooktown";
$areanames{en}->{61742635} = "Cooktown";
$areanames{en}->{61742636} = "Cooktown";
$areanames{en}->{61742637} = "Atherton";
$areanames{en}->{61742638} = "Atherton";
$areanames{en}->{61742639} = "Atherton";
$areanames{en}->{61742640} = "Daintree";
$areanames{en}->{61742641} = "Dimbulah";
$areanames{en}->{61742642} = "Edward\ River";
$areanames{en}->{61742643} = "Etheridge";
$areanames{en}->{61742644} = "Euramo";
$areanames{en}->{61742645} = "Georgetown";
$areanames{en}->{61742646} = "Gordonvale";
$areanames{en}->{61742647} = "Herberton";
$areanames{en}->{61742648} = "Hopevale";
$areanames{en}->{61742649} = "Innisfail";
$areanames{en}->{61742650} = "Innot\ Hot\ Springs";
$areanames{en}->{61742651} = "Kidston";
$areanames{en}->{61742652} = "Kowanyama";
$areanames{en}->{61742653} = "Kuranda";
$areanames{en}->{61742654} = "Lakeland";
$areanames{en}->{61742655} = "Lockhart\ River";
$areanames{en}->{61742656} = "Malanda";
$areanames{en}->{61742657} = "Mareeba";
$areanames{en}->{61742658} = "Maryfarms";
$areanames{en}->{61742659} = "Millaa\ Millaa";
$areanames{en}->{61742660} = "Minnamoolka";
$areanames{en}->{61742661} = "Molloy";
$areanames{en}->{61742662} = "Mossman";
$areanames{en}->{61742663} = "Mount\ Garnet";
$areanames{en}->{61742664} = "Mount\ Surprise";
$areanames{en}->{61742665} = "Mutchilba";
$areanames{en}->{61742666} = "Peninsula";
$areanames{en}->{61742667} = "Ravenshoe";
$areanames{en}->{61742668} = "Silkwood";
$areanames{en}->{61742669} = "South\ Johnstone";
$areanames{en}->{61742670} = "Thursday\ Island";
$areanames{en}->{61742671} = "Torres";
$areanames{en}->{61742672} = "Tully";
$areanames{en}->{61742673} = "Walsh\ River";
$areanames{en}->{61742674} = "Weipa";
$areanames{en}->{61742675} = "Atherton";
$areanames{en}->{61742676} = "Aurukun";
$areanames{en}->{61742677} = "Babinda";
$areanames{en}->{61742678} = "Bloomfield";
$areanames{en}->{61742679} = "Cairns";
$areanames{en}->{61742680} = "Chillagoe";
$areanames{en}->{61742681} = "Coen";
$areanames{en}->{61742682} = "Cooktown";
$areanames{en}->{61742683} = "Daintree";
$areanames{en}->{61742684} = "Dimbulah";
$areanames{en}->{61742685} = "Edward\ River";
$areanames{en}->{61742686} = "Etheridge";
$areanames{en}->{61742687} = "Euramo";
$areanames{en}->{61742688} = "Georgetown";
$areanames{en}->{61742689} = "Gordonvale";
$areanames{en}->{61742690} = "Herberton";
$areanames{en}->{61742691} = "Hopevale";
$areanames{en}->{61742692} = "Innisfail";
$areanames{en}->{61742693} = "Innot\ Hot\ Springs";
$areanames{en}->{61742694} = "Kidston";
$areanames{en}->{61742695} = "Kowanyama";
$areanames{en}->{61742696} = "Kuranda";
$areanames{en}->{61742697} = "Lakeland";
$areanames{en}->{61742698} = "Lockhart\ River";
$areanames{en}->{61742699} = "Malanda";
$areanames{en}->{61742700} = "Mareeba";
$areanames{en}->{61742701} = "Maryfarms";
$areanames{en}->{61742702} = "Millaa\ Millaa";
$areanames{en}->{61742703} = "Minnamoolka";
$areanames{en}->{61742704} = "Molloy";
$areanames{en}->{61742705} = "Mossman";
$areanames{en}->{61742706} = "Mount\ Garnet";
$areanames{en}->{61742707} = "Mount\ Surprise";
$areanames{en}->{61742708} = "Mutchilba";
$areanames{en}->{61742709} = "Peninsula";
$areanames{en}->{61742710} = "Ravenshoe";
$areanames{en}->{61742711} = "Silkwood";
$areanames{en}->{61742712} = "South\ Johnstone";
$areanames{en}->{61742713} = "Thursday\ Island";
$areanames{en}->{61742714} = "Torres";
$areanames{en}->{61742715} = "Tully";
$areanames{en}->{61742716} = "Walsh\ River";
$areanames{en}->{61742717} = "Weipa";
$areanames{en}->{61742718} = "Atherton";
$areanames{en}->{61742719} = "Aurukun";
$areanames{en}->{61742720} = "Babinda";
$areanames{en}->{61742721} = "Bloomfield";
$areanames{en}->{61742722} = "Cairns";
$areanames{en}->{61742723} = "Chillagoe";
$areanames{en}->{61742724} = "Coen";
$areanames{en}->{61742725} = "Cooktown";
$areanames{en}->{61742726} = "Daintree";
$areanames{en}->{61742727} = "Dimbulah";
$areanames{en}->{61742728} = "Edward\ River";
$areanames{en}->{61742729} = "Etheridge";
$areanames{en}->{61742730} = "Euramo";
$areanames{en}->{61742731} = "Georgetown";
$areanames{en}->{61742732} = "Gordonvale";
$areanames{en}->{61742733} = "Herberton";
$areanames{en}->{61742734} = "Hopevale";
$areanames{en}->{61742735} = "Innisfail";
$areanames{en}->{61742736} = "Innot\ Hot\ Springs";
$areanames{en}->{61742737} = "Kidston";
$areanames{en}->{61742738} = "Kowanyama";
$areanames{en}->{61742739} = "Kuranda";
$areanames{en}->{61742740} = "Lakeland";
$areanames{en}->{61742741} = "Lockhart\ River";
$areanames{en}->{61742742} = "Malanda";
$areanames{en}->{61742743} = "Mareeba";
$areanames{en}->{61742744} = "Maryfarms";
$areanames{en}->{61742745} = "Millaa\ Millaa";
$areanames{en}->{61742746} = "Minnamoolka";
$areanames{en}->{61742747} = "Molloy";
$areanames{en}->{61742748} = "Mossman";
$areanames{en}->{61742749} = "Mount\ Garnet";
$areanames{en}->{61742750} = "Mount\ Surprise";
$areanames{en}->{61742751} = "Mutchilba";
$areanames{en}->{61742752} = "Peninsula";
$areanames{en}->{61742753} = "Ravenshoe";
$areanames{en}->{61742754} = "Silkwood";
$areanames{en}->{61742755} = "South\ Johnstone";
$areanames{en}->{61742756} = "Thursday\ Island";
$areanames{en}->{61742757} = "Torres";
$areanames{en}->{61742758} = "Tully";
$areanames{en}->{61742759} = "Walsh\ River";
$areanames{en}->{61742760} = "Weipa";
$areanames{en}->{61742761} = "Cairns";
$areanames{en}->{61742762} = "Atherton";
$areanames{en}->{61742763} = "Aurukun";
$areanames{en}->{61742764} = "Babinda";
$areanames{en}->{61742765} = "Bloomfield";
$areanames{en}->{61742766} = "Cairns";
$areanames{en}->{61742767} = "Chillagoe";
$areanames{en}->{61742768} = "Coen";
$areanames{en}->{61742769} = "Cooktown";
$areanames{en}->{61742770} = "Daintree";
$areanames{en}->{61742771} = "Dimbulah";
$areanames{en}->{61742772} = "Edward\ River";
$areanames{en}->{61742773} = "Etheridge";
$areanames{en}->{61742774} = "Euramo";
$areanames{en}->{61742775} = "Georgetown";
$areanames{en}->{61742776} = "Gordonvale";
$areanames{en}->{61742777} = "Herberton";
$areanames{en}->{61742778} = "Hopevale";
$areanames{en}->{61742779} = "Innisfail";
$areanames{en}->{61742780} = "Innot\ Hot\ Springs";
$areanames{en}->{61742781} = "Kidston";
$areanames{en}->{61742782} = "Kowanyama";
$areanames{en}->{61742783} = "Kuranda";
$areanames{en}->{61742784} = "Lakeland";
$areanames{en}->{61742785} = "Lockhart\ River";
$areanames{en}->{61742786} = "Malanda";
$areanames{en}->{61742787} = "Mareeba";
$areanames{en}->{61742788} = "Maryfarms";
$areanames{en}->{61742789} = "Millaa\ Millaa";
$areanames{en}->{61742790} = "Minnamoolka";
$areanames{en}->{61742791} = "Molloy";
$areanames{en}->{61742792} = "Mossman";
$areanames{en}->{61742793} = "Mount\ Garnet";
$areanames{en}->{61742794} = "Mount\ Surprise";
$areanames{en}->{61742795} = "Mutchilba";
$areanames{en}->{61742796} = "Peninsula";
$areanames{en}->{61742797} = "Ravenshoe";
$areanames{en}->{61742798} = "Silkwood";
$areanames{en}->{61742799} = "South\ Johnstone";
$areanames{en}->{61742800} = "Thursday\ Island";
$areanames{en}->{61742801} = "Torres";
$areanames{en}->{61742802} = "Tully";
$areanames{en}->{61742803} = "Walsh\ River";
$areanames{en}->{61742804} = "Weipa";
$areanames{en}->{61742810} = "Cairns";
$areanames{en}->{61742999} = "Lakeland";
$areanames{en}->{61743000} = "Burnett";
$areanames{en}->{61743001} = "Burnett";
$areanames{en}->{61743002} = "Monogorilby";
$areanames{en}->{61743003} = "Monogorilby";
$areanames{en}->{61743004} = "Eidsvold";
$areanames{en}->{61743005} = "Eidsvold";
$areanames{en}->{61743006} = "Moonford";
$areanames{en}->{61743007} = "Moonford";
$areanames{en}->{61743008} = "Mundubbera";
$areanames{en}->{61743009} = "Mundubbera";
$areanames{en}->{61743010} = "Bunker";
$areanames{en}->{61743011} = "Bunker";
$areanames{en}->{61743012} = "Tandora";
$areanames{en}->{61743013} = "Tandora";
$areanames{en}->{61743014} = "Chahpingah";
$areanames{en}->{61743015} = "Chahpingah";
$areanames{en}->{61743016} = "Kumbia";
$areanames{en}->{61743017} = "Kumbia";
$areanames{en}->{61743018} = "Maryborough";
$areanames{en}->{61743019} = "Maryborough";
$areanames{en}->{61743020} = "Redridge";
$areanames{en}->{61743021} = "Redridge";
$areanames{en}->{61743022} = "Boondooma";
$areanames{en}->{61743023} = "Boondooma";
$areanames{en}->{61743024} = "Manumbar";
$areanames{en}->{61743025} = "Manumbar";
$areanames{en}->{61743026} = "Rosedale";
$areanames{en}->{61743027} = "Rosedale";
$areanames{en}->{61743028} = "Maryborough";
$areanames{en}->{61743029} = "Maryborough";
$areanames{en}->{61743030} = "Maryborough";
$areanames{en}->{61743031} = "Pialba";
$areanames{en}->{61743032} = "Pialba";
$areanames{en}->{61743033} = "Bundaberg";
$areanames{en}->{61743034} = "Pialba";
$areanames{en}->{61743035} = "Gin\ Gin";
$areanames{en}->{61743036} = "Murgon";
$areanames{en}->{61743037} = "Bundaberg";
$areanames{en}->{61743038} = "Bundaberg";
$areanames{en}->{61743039} = "Bundaberg";
$areanames{en}->{61743040} = "Farnsfield";
$areanames{en}->{61743041} = "Maryborough";
$areanames{en}->{61743042} = "Pialba";
$areanames{en}->{61743043} = "Yarraman";
$areanames{en}->{61743044} = "Tandora";
$areanames{en}->{61743045} = "Gooroolba";
$areanames{en}->{61743046} = "Gayndah";
$areanames{en}->{61743047} = "Monogorilby";
$areanames{en}->{61743048} = "Bundaberg";
$areanames{en}->{61743049} = "Fraser\ Island";
$areanames{en}->{61743050} = "Howard";
$areanames{en}->{61743051} = "Bunker";
$areanames{en}->{61743052} = "Mount\ Perry";
$areanames{en}->{61743053} = "Monto";
$areanames{en}->{61743054} = "Burnett";
$areanames{en}->{61743055} = "Gaeta";
$areanames{en}->{61743056} = "Mundubbera";
$areanames{en}->{61743057} = "Mulgildie";
$areanames{en}->{61743058} = "Eidsvold";
$areanames{en}->{61743059} = "Maryborough";
$areanames{en}->{61743060} = "Pialba";
$areanames{en}->{61743061} = "Yandaran";
$areanames{en}->{61743062} = "Rosedale";
$areanames{en}->{61743063} = "Moonford";
$areanames{en}->{61743064} = "Lowmead";
$areanames{en}->{61743065} = "Proston";
$areanames{en}->{61743066} = "Gayndah";
$areanames{en}->{61743067} = "Bundaberg";
$areanames{en}->{61743068} = "Monogorilby";
$areanames{en}->{61743069} = "Redridge";
$areanames{en}->{61743070} = "Tiaro";
$areanames{en}->{61743071} = "Murgon";
$areanames{en}->{61743072} = "Windera";
$areanames{en}->{61743073} = "Wondai";
$areanames{en}->{61743074} = "Bunker";
$areanames{en}->{61743075} = "Maidenwell";
$areanames{en}->{61743076} = "Maryborough";
$areanames{en}->{61743077} = "Boondooma";
$areanames{en}->{61743078} = "Mundubbera";
$areanames{en}->{61743079} = "Boondooma";
$areanames{en}->{61743080} = "Manumbar";
$areanames{en}->{61743081} = "Eidsvold";
$areanames{en}->{61743082} = "Yandaran";
$areanames{en}->{61743083} = "Johnstown\ West";
$areanames{en}->{61743084} = "Kingaroy";
$areanames{en}->{61743085} = "Brooklands";
$areanames{en}->{61743086} = "Blackbutt";
$areanames{en}->{61743087} = "Redridge";
$areanames{en}->{61743088} = "Gin\ Gin";
$areanames{en}->{61743089} = "Murgon";
$areanames{en}->{61743090} = "Proston";
$areanames{en}->{61743091} = "Tandora";
$areanames{en}->{61743092} = "Brooweena";
$areanames{en}->{61743093} = "Gooroolba";
$areanames{en}->{61743094} = "Yarraman";
$areanames{en}->{61743095} = "Pialba";
$areanames{en}->{61743096} = "Chahpingah";
$areanames{en}->{61743097} = "Kumbia";
$areanames{en}->{61743098} = "Fraser\ Island";
$areanames{en}->{61743099} = "Tansey";
$areanames{en}->{61743100} = "Windera";
$areanames{en}->{61743101} = "Childers";
$areanames{en}->{61743102} = "Manumbar";
$areanames{en}->{61743103} = "Mount\ Perry";
$areanames{en}->{61743104} = "Howard";
$areanames{en}->{61743105} = "Booyal";
$areanames{en}->{61743106} = "Tansey";
$areanames{en}->{61743107} = "Monto";
$areanames{en}->{61743108} = "Biggenden";
$areanames{en}->{61743109} = "Wondai";
$areanames{en}->{61743110} = "Biggenden";
$areanames{en}->{61743111} = "Burnett";
$areanames{en}->{61743112} = "Gaeta";
$areanames{en}->{61743113} = "Mulgildie";
$areanames{en}->{61743114} = "Farnsfield";
$areanames{en}->{61743115} = "Tiaro";
$areanames{en}->{61743116} = "Rosedale";
$areanames{en}->{61743117} = "Nanango";
$areanames{en}->{61743118} = "Moonford";
$areanames{en}->{61743119} = "Blackbutt";
$areanames{en}->{61743120} = "Boondooma";
$areanames{en}->{61743121} = "Lowmead";
$areanames{en}->{61743122} = "Tansey";
$areanames{en}->{61743123} = "Biggenden";
$areanames{en}->{61743124} = "Maryborough";
$areanames{en}->{61743125} = "Proston";
$areanames{en}->{61743126} = "Brooweena";
$areanames{en}->{61743127} = "Yarraman";
$areanames{en}->{61743128} = "Boondooma";
$areanames{en}->{61743129} = "Booyal";
$areanames{en}->{61743130} = "Brooklands";
$areanames{en}->{61743131} = "Pialba";
$areanames{en}->{61743132} = "Chahpingah";
$areanames{en}->{61743133} = "Murgon";
$areanames{en}->{61743134} = "Kumbia";
$areanames{en}->{61743135} = "Farnsfield";
$areanames{en}->{61743136} = "Windera";
$areanames{en}->{61743137} = "Wondai";
$areanames{en}->{61743138} = "Fraser\ Island";
$areanames{en}->{61743139} = "Brooweena";
$areanames{en}->{61743140} = "Bundaberg";
$areanames{en}->{61743141} = "Tiaro";
$areanames{en}->{61743142} = "Johnstown\ West";
$areanames{en}->{61743143} = "Maidenwell";
$areanames{en}->{61743144} = "Childers";
$areanames{en}->{61743145} = "Manumbar";
$areanames{en}->{61743146} = "Nanango";
$areanames{en}->{61743147} = "Kingaroy";
$areanames{en}->{61743148} = "Brooklands";
$areanames{en}->{61743149} = "Bunker";
$areanames{en}->{61743150} = "Burnett";
$areanames{en}->{61743151} = "Blackbutt";
$areanames{en}->{61743152} = "Howard";
$areanames{en}->{61743153} = "Booyal";
$areanames{en}->{61743154} = "Redridge";
$areanames{en}->{61743155} = "Gin\ Gin";
$areanames{en}->{61743156} = "Pialba";
$areanames{en}->{61743157} = "Proston";
$areanames{en}->{61743158} = "Gayndah";
$areanames{en}->{61743159} = "Chahpingah";
$areanames{en}->{61743160} = "Childers";
$areanames{en}->{61743161} = "Monogorilby";
$areanames{en}->{61743162} = "Murgon";
$areanames{en}->{61743163} = "Windera";
$areanames{en}->{61743164} = "Wondai";
$areanames{en}->{61743165} = "Bunker";
$areanames{en}->{61743166} = "Maidenwell";
$areanames{en}->{61743167} = "Boondooma";
$areanames{en}->{61743168} = "Mundubbera";
$areanames{en}->{61743169} = "Eidsvold";
$areanames{en}->{61743170} = "Farnsfield";
$areanames{en}->{61743171} = "Eidsvold";
$areanames{en}->{61743172} = "Yandaran";
$areanames{en}->{61743173} = "Johnstown\ West";
$areanames{en}->{61743174} = "Pialba";
$areanames{en}->{61743175} = "Brooklands";
$areanames{en}->{61743176} = "Blackbutt";
$areanames{en}->{61743177} = "Redridge";
$areanames{en}->{61743178} = "Tandora";
$areanames{en}->{61743179} = "Fraser\ Island";
$areanames{en}->{61743180} = "Gaeta";
$areanames{en}->{61743181} = "Brooweena";
$areanames{en}->{61743182} = "Gooroolba";
$areanames{en}->{61743183} = "Yarraman";
$areanames{en}->{61743184} = "Chahpingah";
$areanames{en}->{61743185} = "Kumbia";
$areanames{en}->{61743186} = "Fraser\ Island";
$areanames{en}->{61743187} = "Childers";
$areanames{en}->{61743188} = "Manumbar";
$areanames{en}->{61743189} = "Gayndah";
$areanames{en}->{61743190} = "Gin\ Gin";
$areanames{en}->{61743191} = "Mount\ Perry";
$areanames{en}->{61743192} = "Howard";
$areanames{en}->{61743193} = "Booyal";
$areanames{en}->{61743194} = "Tansey";
$areanames{en}->{61743195} = "Monto";
$areanames{en}->{61743196} = "Biggenden";
$areanames{en}->{61743197} = "Burnett";
$areanames{en}->{61743198} = "Gaeta";
$areanames{en}->{61743199} = "Gooroolba";
$areanames{en}->{61743200} = "Howard";
$areanames{en}->{61743201} = "Mulgildie";
$areanames{en}->{61743202} = "Farnsfield";
$areanames{en}->{61743203} = "Tiaro";
$areanames{en}->{61743204} = "Rosedale";
$areanames{en}->{61743205} = "Nanango";
$areanames{en}->{61743206} = "Moonford";
$areanames{en}->{61743207} = "Lowmead";
$areanames{en}->{61743208} = "Johnstown\ West";
$areanames{en}->{61743209} = "Kingaroy";
$areanames{en}->{61743210} = "Kumbia";
$areanames{en}->{61743211} = "Lowmead";
$areanames{en}->{61743212} = "Maidenwell";
$areanames{en}->{61743213} = "Manumbar";
$areanames{en}->{61743214} = "Maryborough";
$areanames{en}->{61743215} = "Monogorilby";
$areanames{en}->{61743216} = "Monto";
$areanames{en}->{61743217} = "Moonford";
$areanames{en}->{61743218} = "Mount\ Perry";
$areanames{en}->{61743219} = "Mulgildie";
$areanames{en}->{61743220} = "Mundubbera";
$areanames{en}->{61743221} = "Murgon";
$areanames{en}->{61743222} = "Nanango";
$areanames{en}->{61743223} = "Pialba";
$areanames{en}->{61743224} = "Proston";
$areanames{en}->{61743225} = "Redridge";
$areanames{en}->{61743226} = "Rosedale";
$areanames{en}->{61743227} = "Tandora";
$areanames{en}->{61743228} = "Tansey";
$areanames{en}->{61743229} = "Tiaro";
$areanames{en}->{61743230} = "Windera";
$areanames{en}->{61743231} = "Wondai";
$areanames{en}->{61743232} = "Yandaran";
$areanames{en}->{61743233} = "Yarraman";
$areanames{en}->{61743234} = "Pialba";
$areanames{en}->{61743235} = "Pialba";
$areanames{en}->{61743236} = "Biggenden";
$areanames{en}->{61743237} = "Blackbutt";
$areanames{en}->{61743238} = "Boondooma";
$areanames{en}->{61743239} = "Booyal";
$areanames{en}->{61743240} = "Brooklands";
$areanames{en}->{61743241} = "Brooweena";
$areanames{en}->{61743242} = "Bundaberg";
$areanames{en}->{61743243} = "Bunker";
$areanames{en}->{61743244} = "Burnett";
$areanames{en}->{61743245} = "Chahpingah";
$areanames{en}->{61743246} = "Childers";
$areanames{en}->{61743247} = "Eidsvold";
$areanames{en}->{61743248} = "Maryborough";
$areanames{en}->{61743249} = "Maryborough";
$areanames{en}->{61743250} = "Farnsfield";
$areanames{en}->{61743251} = "Pialba";
$areanames{en}->{61743252} = "Fraser\ Island";
$areanames{en}->{61743253} = "Pialba";
$areanames{en}->{61743254} = "Pialba";
$areanames{en}->{61743255} = "Pialba";
$areanames{en}->{61743256} = "Pialba";
$areanames{en}->{61743257} = "Brooweena";
$areanames{en}->{61743258} = "Booyal";
$areanames{en}->{61743259} = "Biggenden";
$areanames{en}->{6174326} = "Bundaberg";
$areanames{en}->{61743260} = "Gaeta";
$areanames{en}->{61743267} = "Gayndah";
$areanames{en}->{61743268} = "Gin\ Gin";
$areanames{en}->{61743269} = "Gooroolba";
$areanames{en}->{61743270} = "Howard";
$areanames{en}->{61743271} = "Johnstown\ West";
$areanames{en}->{61743272} = "Kingaroy";
$areanames{en}->{61743273} = "Kumbia";
$areanames{en}->{61743274} = "Lowmead";
$areanames{en}->{61743275} = "Maidenwell";
$areanames{en}->{61743276} = "Manumbar";
$areanames{en}->{61743277} = "Maryborough";
$areanames{en}->{61743278} = "Monogorilby";
$areanames{en}->{61743279} = "Monto";
$areanames{en}->{61743280} = "Moonford";
$areanames{en}->{61743281} = "Mount\ Perry";
$areanames{en}->{61743282} = "Mulgildie";
$areanames{en}->{61743283} = "Mundubbera";
$areanames{en}->{61743284} = "Murgon";
$areanames{en}->{61743285} = "Nanango";
$areanames{en}->{61743286} = "Pialba";
$areanames{en}->{61743287} = "Proston";
$areanames{en}->{61743288} = "Redridge";
$areanames{en}->{61743289} = "Rosedale";
$areanames{en}->{61743290} = "Tandora";
$areanames{en}->{61743291} = "Tansey";
$areanames{en}->{61743292} = "Tiaro";
$areanames{en}->{61743293} = "Windera";
$areanames{en}->{61743294} = "Wondai";
$areanames{en}->{61743295} = "Yandaran";
$areanames{en}->{61743296} = "Yarraman";
$areanames{en}->{61743297} = "Biggenden";
$areanames{en}->{61743298} = "Blackbutt";
$areanames{en}->{61743299} = "Boondooma";
$areanames{en}->{61743300} = "Booyal";
$areanames{en}->{61743301} = "Brooklands";
$areanames{en}->{61743302} = "Brooweena";
$areanames{en}->{61743303} = "Bundaberg";
$areanames{en}->{61743304} = "Bunker";
$areanames{en}->{61743305} = "Burnett";
$areanames{en}->{61743306} = "Chahpingah";
$areanames{en}->{61743307} = "Childers";
$areanames{en}->{61743308} = "Eidsvold";
$areanames{en}->{61743309} = "Farnsfield";
$areanames{en}->{6174331} = "Bundaberg";
$areanames{en}->{61743312} = "Bunker";
$areanames{en}->{61743313} = "Gaeta";
$areanames{en}->{61743314} = "Mount\ Perry";
$areanames{en}->{61743319} = "Fraser\ Island";
$areanames{en}->{61743320} = "Gaeta";
$areanames{en}->{61743321} = "Gayndah";
$areanames{en}->{61743322} = "Gin\ Gin";
$areanames{en}->{61743323} = "Gooroolba";
$areanames{en}->{61743324} = "Howard";
$areanames{en}->{61743325} = "Johnstown\ West";
$areanames{en}->{61743326} = "Kingaroy";
$areanames{en}->{61743327} = "Kumbia";
$areanames{en}->{61743328} = "Lowmead";
$areanames{en}->{61743329} = "Maidenwell";
$areanames{en}->{61743330} = "Manumbar";
$areanames{en}->{61743331} = "Maryborough";
$areanames{en}->{61743332} = "Monogorilby";
$areanames{en}->{61743333} = "Monto";
$areanames{en}->{61743334} = "Moonford";
$areanames{en}->{61743335} = "Mount\ Perry";
$areanames{en}->{61743336} = "Mulgildie";
$areanames{en}->{61743337} = "Mundubbera";
$areanames{en}->{61743338} = "Murgon";
$areanames{en}->{61743339} = "Nanango";
$areanames{en}->{61743340} = "Pialba";
$areanames{en}->{61743341} = "Proston";
$areanames{en}->{61743342} = "Redridge";
$areanames{en}->{61743343} = "Rosedale";
$areanames{en}->{61743344} = "Tandora";
$areanames{en}->{61743345} = "Tansey";
$areanames{en}->{61743346} = "Tiaro";
$areanames{en}->{61743347} = "Windera";
$areanames{en}->{61743348} = "Wondai";
$areanames{en}->{61743349} = "Yandaran";
$areanames{en}->{6174335} = "Bundaberg";
$areanames{en}->{61743350} = "Yarraman";
$areanames{en}->{61743357} = "Pialba";
$areanames{en}->{61743358} = "Maryborough";
$areanames{en}->{61743359} = "Maryborough";
$areanames{en}->{61743360} = "Maryborough";
$areanames{en}->{61743361} = "Maryborough";
$areanames{en}->{61743362} = "Kingaroy";
$areanames{en}->{61743363} = "Kingaroy";
$areanames{en}->{61743364} = "Biggenden";
$areanames{en}->{61743365} = "Pialba";
$areanames{en}->{61743366} = "Pialba";
$areanames{en}->{61743367} = "Pialba";
$areanames{en}->{61743368} = "Murgon";
$areanames{en}->{61743369} = "Murgon";
$areanames{en}->{61743370} = "Bundaberg";
$areanames{en}->{61743371} = "Maryborough";
$areanames{en}->{61743372} = "Mundubbera";
$areanames{en}->{61743373} = "Mundubbera";
$areanames{en}->{61743374} = "Mundubbera";
$areanames{en}->{61743375} = "Blackbutt";
$areanames{en}->{61743376} = "Boondooma";
$areanames{en}->{61743377} = "Booyal";
$areanames{en}->{61743378} = "Brooklands";
$areanames{en}->{61743379} = "Brooweena";
$areanames{en}->{61743380} = "Bundaberg";
$areanames{en}->{61743381} = "Bunker";
$areanames{en}->{61743382} = "Burnett";
$areanames{en}->{61743383} = "Chahpingah";
$areanames{en}->{61743384} = "Childers";
$areanames{en}->{61743385} = "Pialba";
$areanames{en}->{61743386} = "Pialba";
$areanames{en}->{61743387} = "Pialba";
$areanames{en}->{61743388} = "Pialba";
$areanames{en}->{61743389} = "Pialba";
$areanames{en}->{6174339} = "Bundaberg";
$areanames{en}->{61743390} = "Eidsvold";
$areanames{en}->{61743400} = "Farnsfield";
$areanames{en}->{61743401} = "Fraser\ Island";
$areanames{en}->{61743402} = "Gaeta";
$areanames{en}->{61743403} = "Gayndah";
$areanames{en}->{61743404} = "Biggenden";
$areanames{en}->{61743405} = "Blackbutt";
$areanames{en}->{61743406} = "Boondooma";
$areanames{en}->{61743407} = "Booyal";
$areanames{en}->{61743408} = "Brooklands";
$areanames{en}->{61743409} = "Brooweena";
$areanames{en}->{61743410} = "Bundaberg";
$areanames{en}->{61743411} = "Bunker";
$areanames{en}->{61743412} = "Burnett";
$areanames{en}->{61743413} = "Chahpingah";
$areanames{en}->{61743414} = "Childers";
$areanames{en}->{61743415} = "Eidsvold";
$areanames{en}->{61743416} = "Farnsfield";
$areanames{en}->{61743417} = "Fraser\ Island";
$areanames{en}->{61743418} = "Gaeta";
$areanames{en}->{61743419} = "Gayndah";
$areanames{en}->{61743420} = "Gin\ Gin";
$areanames{en}->{61743421} = "Gooroolba";
$areanames{en}->{61743422} = "Howard";
$areanames{en}->{61743423} = "Johnstown\ West";
$areanames{en}->{61743424} = "Kingaroy";
$areanames{en}->{61743425} = "Kumbia";
$areanames{en}->{61743426} = "Lowmead";
$areanames{en}->{61743427} = "Maidenwell";
$areanames{en}->{61743428} = "Manumbar";
$areanames{en}->{61743429} = "Maryborough";
$areanames{en}->{61743430} = "Monogorilby";
$areanames{en}->{61743431} = "Monto";
$areanames{en}->{61743432} = "Moonford";
$areanames{en}->{61743433} = "Mount\ Perry";
$areanames{en}->{61743434} = "Mulgildie";
$areanames{en}->{61743435} = "Mundubbera";
$areanames{en}->{61743436} = "Murgon";
$areanames{en}->{61743437} = "Nanango";
$areanames{en}->{61743438} = "Pialba";
$areanames{en}->{61743439} = "Proston";
$areanames{en}->{61743440} = "Redridge";
$areanames{en}->{61743441} = "Rosedale";
$areanames{en}->{61743442} = "Tandora";
$areanames{en}->{61743443} = "Tansey";
$areanames{en}->{61743444} = "Tiaro";
$areanames{en}->{61743445} = "Windera";
$areanames{en}->{61743446} = "Wondai";
$areanames{en}->{61743447} = "Yandaran";
$areanames{en}->{61743448} = "Yarraman";
$areanames{en}->{61743449} = "Gin\ Gin";
$areanames{en}->{61743450} = "Gooroolba";
$areanames{en}->{61743451} = "Howard";
$areanames{en}->{61743452} = "Johnstown\ West";
$areanames{en}->{61743453} = "Kingaroy";
$areanames{en}->{61743454} = "Kumbia";
$areanames{en}->{61743455} = "Lowmead";
$areanames{en}->{61743456} = "Maidenwell";
$areanames{en}->{61743457} = "Manumbar";
$areanames{en}->{61743458} = "Maryborough";
$areanames{en}->{61743459} = "Monogorilby";
$areanames{en}->{61743460} = "Monto";
$areanames{en}->{61743461} = "Moonford";
$areanames{en}->{61743462} = "Mount\ Perry";
$areanames{en}->{61743463} = "Mulgildie";
$areanames{en}->{61743464} = "Mundubbera";
$areanames{en}->{61743465} = "Murgon";
$areanames{en}->{61743466} = "Nanango";
$areanames{en}->{61743467} = "Pialba";
$areanames{en}->{61743468} = "Proston";
$areanames{en}->{61743469} = "Redridge";
$areanames{en}->{61743470} = "Rosedale";
$areanames{en}->{61743471} = "Tandora";
$areanames{en}->{61743472} = "Tansey";
$areanames{en}->{61743473} = "Tiaro";
$areanames{en}->{61743474} = "Windera";
$areanames{en}->{61743475} = "Wondai";
$areanames{en}->{61743476} = "Yandaran";
$areanames{en}->{61743477} = "Yarraman";
$areanames{en}->{61743478} = "Biggenden";
$areanames{en}->{61743479} = "Blackbutt";
$areanames{en}->{61743480} = "Boondooma";
$areanames{en}->{61743481} = "Booyal";
$areanames{en}->{61743482} = "Brooklands";
$areanames{en}->{61743483} = "Brooweena";
$areanames{en}->{61743484} = "Bundaberg";
$areanames{en}->{61743485} = "Bunker";
$areanames{en}->{61743486} = "Burnett";
$areanames{en}->{61743487} = "Chahpingah";
$areanames{en}->{61743488} = "Childers";
$areanames{en}->{61743489} = "Eidsvold";
$areanames{en}->{61743490} = "Farnsfield";
$areanames{en}->{61743491} = "Fraser\ Island";
$areanames{en}->{61743492} = "Gaeta";
$areanames{en}->{61743493} = "Gayndah";
$areanames{en}->{61743494} = "Gin\ Gin";
$areanames{en}->{61743495} = "Gooroolba";
$areanames{en}->{61743496} = "Howard";
$areanames{en}->{61743497} = "Johnstown\ West";
$areanames{en}->{61743498} = "Kingaroy";
$areanames{en}->{61743499} = "Kumbia";
$areanames{en}->{61743500} = "Lowmead";
$areanames{en}->{61743501} = "Maidenwell";
$areanames{en}->{61743502} = "Manumbar";
$areanames{en}->{61743503} = "Maryborough";
$areanames{en}->{61743504} = "Monogorilby";
$areanames{en}->{61743505} = "Monto";
$areanames{en}->{61743506} = "Moonford";
$areanames{en}->{61743507} = "Mount\ Perry";
$areanames{en}->{61743508} = "Mulgildie";
$areanames{en}->{61743509} = "Mundubbera";
$areanames{en}->{61743510} = "Murgon";
$areanames{en}->{61743511} = "Nanango";
$areanames{en}->{61743512} = "Pialba";
$areanames{en}->{61743513} = "Proston";
$areanames{en}->{61743514} = "Redridge";
$areanames{en}->{61743515} = "Rosedale";
$areanames{en}->{61743516} = "Tandora";
$areanames{en}->{61743517} = "Tansey";
$areanames{en}->{61743518} = "Tiaro";
$areanames{en}->{61743519} = "Windera";
$areanames{en}->{61743520} = "Wondai";
$areanames{en}->{61743521} = "Yandaran";
$areanames{en}->{61743522} = "Yarraman";
$areanames{en}->{61743523} = "Biggenden";
$areanames{en}->{61743524} = "Blackbutt";
$areanames{en}->{61743525} = "Boondooma";
$areanames{en}->{61743526} = "Booyal";
$areanames{en}->{61743527} = "Brooklands";
$areanames{en}->{61743528} = "Brooweena";
$areanames{en}->{61743529} = "Bundaberg";
$areanames{en}->{61743530} = "Bunker";
$areanames{en}->{61743531} = "Burnett";
$areanames{en}->{61743532} = "Chahpingah";
$areanames{en}->{61743533} = "Childers";
$areanames{en}->{61743534} = "Eidsvold";
$areanames{en}->{61743535} = "Farnsfield";
$areanames{en}->{61743536} = "Fraser\ Island";
$areanames{en}->{61743537} = "Gaeta";
$areanames{en}->{61743538} = "Gayndah";
$areanames{en}->{61743539} = "Gin\ Gin";
$areanames{en}->{61743540} = "Gooroolba";
$areanames{en}->{61743541} = "Howard";
$areanames{en}->{61743542} = "Johnstown\ West";
$areanames{en}->{61743543} = "Kingaroy";
$areanames{en}->{61743544} = "Kumbia";
$areanames{en}->{61743545} = "Lowmead";
$areanames{en}->{61743546} = "Maidenwell";
$areanames{en}->{61743547} = "Manumbar";
$areanames{en}->{61743548} = "Maryborough";
$areanames{en}->{61743549} = "Monogorilby";
$areanames{en}->{61743550} = "Monto";
$areanames{en}->{61743551} = "Moonford";
$areanames{en}->{61743552} = "Mount\ Perry";
$areanames{en}->{61743553} = "Mulgildie";
$areanames{en}->{61743554} = "Mundubbera";
$areanames{en}->{61743555} = "Murgon";
$areanames{en}->{61743556} = "Nanango";
$areanames{en}->{61743557} = "Pialba";
$areanames{en}->{61743558} = "Proston";
$areanames{en}->{61743559} = "Redridge";
$areanames{en}->{61743560} = "Rosedale";
$areanames{en}->{61743561} = "Tandora";
$areanames{en}->{61743562} = "Tansey";
$areanames{en}->{61743563} = "Tiaro";
$areanames{en}->{61743564} = "Windera";
$areanames{en}->{61743565} = "Wondai";
$areanames{en}->{61743566} = "Yandaran";
$areanames{en}->{61743567} = "Yarraman";
$areanames{en}->{61743568} = "Biggenden";
$areanames{en}->{61743569} = "Blackbutt";
$areanames{en}->{61743570} = "Boondooma";
$areanames{en}->{61743571} = "Booyal";
$areanames{en}->{61743572} = "Brooklands";
$areanames{en}->{61743573} = "Brooweena";
$areanames{en}->{61743574} = "Bundaberg";
$areanames{en}->{61743575} = "Bunker";
$areanames{en}->{61743576} = "Burnett";
$areanames{en}->{61743577} = "Chahpingah";
$areanames{en}->{61743578} = "Childers";
$areanames{en}->{61743579} = "Eidsvold";
$areanames{en}->{61743580} = "Farnsfield";
$areanames{en}->{61743581} = "Fraser\ Island";
$areanames{en}->{61743582} = "Gaeta";
$areanames{en}->{61743583} = "Gayndah";
$areanames{en}->{61743584} = "Gin\ Gin";
$areanames{en}->{61743585} = "Gooroolba";
$areanames{en}->{61743586} = "Howard";
$areanames{en}->{61743587} = "Johnstown\ West";
$areanames{en}->{61743588} = "Kingaroy";
$areanames{en}->{61743589} = "Kumbia";
$areanames{en}->{61743590} = "Lowmead";
$areanames{en}->{61743591} = "Maidenwell";
$areanames{en}->{61743592} = "Manumbar";
$areanames{en}->{61743593} = "Maryborough";
$areanames{en}->{61743594} = "Monogorilby";
$areanames{en}->{61743595} = "Monto";
$areanames{en}->{61743596} = "Moonford";
$areanames{en}->{61743597} = "Mount\ Perry";
$areanames{en}->{61743598} = "Mulgildie";
$areanames{en}->{61743599} = "Mundubbera";
$areanames{en}->{61743600} = "Murgon";
$areanames{en}->{61743601} = "Nanango";
$areanames{en}->{61743602} = "Pialba";
$areanames{en}->{61743603} = "Proston";
$areanames{en}->{61743604} = "Redridge";
$areanames{en}->{61743605} = "Rosedale";
$areanames{en}->{61743606} = "Tandora";
$areanames{en}->{61743607} = "Tansey";
$areanames{en}->{61743608} = "Tiaro";
$areanames{en}->{61743609} = "Windera";
$areanames{en}->{61743610} = "Wondai";
$areanames{en}->{61743611} = "Yandaran";
$areanames{en}->{61743612} = "Yarraman";
$areanames{en}->{61744000} = "Barkly";
$areanames{en}->{61744001} = "Boulia";
$areanames{en}->{61744002} = "Burketown";
$areanames{en}->{61744003} = "Camooweal";
$areanames{en}->{61744004} = "Croydon";
$areanames{en}->{61744005} = "Doomadgee";
$areanames{en}->{61744006} = "Eddington";
$areanames{en}->{61744007} = "Georgina";
$areanames{en}->{61744008} = "Gulf";
$areanames{en}->{61744009} = "Pentland";
$areanames{en}->{61744010} = "Upper\ Stone";
$areanames{en}->{61744011} = "Ravenswood";
$areanames{en}->{61744012} = "Rollingstone";
$areanames{en}->{61744013} = "Woodstock";
$areanames{en}->{61744014} = "Yabulu";
$areanames{en}->{61744015} = "Townsville";
$areanames{en}->{61744016} = "Yabulu";
$areanames{en}->{61744017} = "Townsville";
$areanames{en}->{61744018} = "Townsville";
$areanames{en}->{61744019} = "Briaba";
$areanames{en}->{61744020} = "Mount\ Isa";
$areanames{en}->{61744021} = "Bowen";
$areanames{en}->{61744022} = "Bambaroo";
$areanames{en}->{61744023} = "Bambaroo";
$areanames{en}->{61744024} = "Townsville";
$areanames{en}->{61744025} = "Townsville";
$areanames{en}->{61744026} = "Briaba";
$areanames{en}->{61744027} = "Briaba";
$areanames{en}->{61744028} = "Townsville";
$areanames{en}->{61744029} = "Ayr";
$areanames{en}->{61744030} = "Ayr";
$areanames{en}->{61744031} = "Barkly";
$areanames{en}->{61744032} = "Barkly";
$areanames{en}->{61744033} = "Eddington";
$areanames{en}->{61744034} = "Eddington";
$areanames{en}->{61744035} = "Kalkadoon";
$areanames{en}->{61744036} = "Kalkadoon";
$areanames{en}->{61744037} = "Hughenden";
$areanames{en}->{61744038} = "Hughenden";
$areanames{en}->{61744039} = "Townsville";
$areanames{en}->{6174404} = "Townsville";
$areanames{en}->{61744050} = "Burdekin";
$areanames{en}->{61744051} = "Burdekin";
$areanames{en}->{61744052} = "Cape\ River";
$areanames{en}->{61744053} = "Cape\ River";
$areanames{en}->{61744054} = "Kirk";
$areanames{en}->{61744055} = "Kirk";
$areanames{en}->{61744056} = "Leichhardt\ Range";
$areanames{en}->{61744057} = "Leichhardt\ Range";
$areanames{en}->{61744058} = "Charters\ Towers";
$areanames{en}->{61744059} = "Charters\ Towers";
$areanames{en}->{61744060} = "Dalbeg";
$areanames{en}->{61744061} = "Dalbeg";
$areanames{en}->{61744062} = "Halifax";
$areanames{en}->{61744063} = "Halifax";
$areanames{en}->{61744064} = "Long\ Pocket";
$areanames{en}->{61744065} = "Long\ Pocket";
$areanames{en}->{61744066} = "Millaroo";
$areanames{en}->{61744067} = "Millaroo";
$areanames{en}->{61744068} = "Mount\ Fox";
$areanames{en}->{61744069} = "Mount\ Fox";
$areanames{en}->{61744070} = "Mutarnee";
$areanames{en}->{61744071} = "Mutarnee";
$areanames{en}->{61744072} = "Palm\ Island";
$areanames{en}->{61744073} = "Palm\ Island";
$areanames{en}->{61744074} = "Ravenswood";
$areanames{en}->{61744075} = "Ravenswood";
$areanames{en}->{61744076} = "Upper\ Stone";
$areanames{en}->{61744077} = "Upper\ Stone";
$areanames{en}->{61744078} = "Julia\ Creek";
$areanames{en}->{61744079} = "Julia\ Creek";
$areanames{en}->{6174408} = "Townsville";
$areanames{en}->{61744090} = "Charters\ Towers";
$areanames{en}->{61744091} = "Townsville";
$areanames{en}->{61744092} = "Townsville";
$areanames{en}->{61744093} = "Mount\ Isa";
$areanames{en}->{61744094} = "Mount\ Isa";
$areanames{en}->{61744095} = "Bowen";
$areanames{en}->{61744096} = "Ayr";
$areanames{en}->{61744097} = "Charters\ Towers";
$areanames{en}->{61744098} = "Ingham";
$areanames{en}->{61744099} = "Palm\ Island";
$areanames{en}->{61744100} = "Richmond";
$areanames{en}->{61744101} = "Ravenswood";
$areanames{en}->{61744102} = "Cloncurry";
$areanames{en}->{61744103} = "Townsville";
$areanames{en}->{61744104} = "Cloncurry";
$areanames{en}->{61744105} = "Bowen";
$areanames{en}->{61744106} = "Ayr";
$areanames{en}->{61744107} = "Ingham";
$areanames{en}->{61744108} = "Mount\ Isa";
$areanames{en}->{61744109} = "Townsville";
$areanames{en}->{6174411} = "Townsville";
$areanames{en}->{6174412} = "Townsville";
$areanames{en}->{61744130} = "Ayr";
$areanames{en}->{61744131} = "Cape\ River";
$areanames{en}->{61744132} = "Townsville";
$areanames{en}->{61744133} = "Cloncurry";
$areanames{en}->{61744134} = "Mount\ Isa";
$areanames{en}->{61744135} = "Hughenden";
$areanames{en}->{61744136} = "Ayr";
$areanames{en}->{61744137} = "Townsville";
$areanames{en}->{617441380} = "Ayr";
$areanames{en}->{617441381} = "Bambaroo";
$areanames{en}->{617441382} = "Barkly";
$areanames{en}->{617441383} = "Boulia";
$areanames{en}->{617441384} = "Bowen";
$areanames{en}->{617441385} = "Briaba";
$areanames{en}->{617441386} = "Burdekin";
$areanames{en}->{617441387} = "Burketown";
$areanames{en}->{617441388} = "Camooweal";
$areanames{en}->{617441389} = "Cape\ River";
$areanames{en}->{617441390} = "Charters\ Towers";
$areanames{en}->{617441391} = "Clarke";
$areanames{en}->{617441392} = "Cloncurry";
$areanames{en}->{617441393} = "Collinsville";
$areanames{en}->{617441394} = "Croydon";
$areanames{en}->{617441395} = "Dalbeg";
$areanames{en}->{617441396} = "Doomadgee";
$areanames{en}->{617441397} = "Eddington";
$areanames{en}->{617441398} = "Flinders";
$areanames{en}->{617441399} = "Georgina";
$areanames{en}->{617441400} = "Giru";
$areanames{en}->{617441401} = "Greenvale";
$areanames{en}->{617441402} = "Gulf";
$areanames{en}->{617441403} = "Gumlu";
$areanames{en}->{617441404} = "Gunpowder";
$areanames{en}->{617441405} = "Gununa";
$areanames{en}->{617441406} = "Halifax";
$areanames{en}->{617441407} = "Home\ Hill";
$areanames{en}->{617441408} = "Hughenden";
$areanames{en}->{617441409} = "Ingham";
$areanames{en}->{617441410} = "Julia\ Creek";
$areanames{en}->{617441411} = "Kalkadoon";
$areanames{en}->{617441412} = "Karumba";
$areanames{en}->{617441413} = "Kirk";
$areanames{en}->{617441414} = "Leichhardt\ Range";
$areanames{en}->{617441415} = "Long\ Pocket";
$areanames{en}->{617441416} = "Millaroo";
$areanames{en}->{617441417} = "Mount\ Fox";
$areanames{en}->{617441418} = "Mount\ Isa";
$areanames{en}->{617441419} = "Mutarnee";
$areanames{en}->{617441420} = "Normanton";
$areanames{en}->{617441421} = "Palm\ Island";
$areanames{en}->{617441422} = "Pentland";
$areanames{en}->{617441423} = "Prairie";
$areanames{en}->{617441424} = "Ravenswood";
$areanames{en}->{617441425} = "Richmond";
$areanames{en}->{617441426} = "Rollingstone";
$areanames{en}->{617441427} = "The\ Monument";
$areanames{en}->{617441428} = "Townsville";
$areanames{en}->{617441429} = "Upper\ Stone";
$areanames{en}->{617441430} = "Walker";
$areanames{en}->{617441431} = "Woodstock";
$areanames{en}->{617441432} = "Yabulu";
$areanames{en}->{617441433} = "Ayr";
$areanames{en}->{617441434} = "Bambaroo";
$areanames{en}->{617441435} = "Barkly";
$areanames{en}->{617441436} = "Boulia";
$areanames{en}->{617441437} = "Bowen";
$areanames{en}->{617441438} = "Briaba";
$areanames{en}->{617441439} = "Burdekin";
$areanames{en}->{61744144} = "Bambaroo";
$areanames{en}->{61744145} = "Barkly";
$areanames{en}->{61744146} = "Boulia";
$areanames{en}->{61744147} = "Briaba";
$areanames{en}->{61744148} = "Burdekin";
$areanames{en}->{61744149} = "Camooweal";
$areanames{en}->{61744150} = "Croydon";
$areanames{en}->{61744151} = "Doomadgee";
$areanames{en}->{61744152} = "Eddington";
$areanames{en}->{61744153} = "Georgina";
$areanames{en}->{61744154} = "Giru";
$areanames{en}->{61744155} = "Greenvale";
$areanames{en}->{61744156} = "Gulf";
$areanames{en}->{61744157} = "Gumlu";
$areanames{en}->{61744158} = "Gunpowder";
$areanames{en}->{61744159} = "Gununa";
$areanames{en}->{61744160} = "Kalkadoon";
$areanames{en}->{61744161} = "Karumba";
$areanames{en}->{61744162} = "Kirk";
$areanames{en}->{61744163} = "Leichhardt\ Range";
$areanames{en}->{61744164} = "Long\ Pocket";
$areanames{en}->{61744165} = "Millaroo";
$areanames{en}->{61744166} = "Mount\ Fox";
$areanames{en}->{61744167} = "Mutarnee";
$areanames{en}->{61744168} = "Pentland";
$areanames{en}->{61744169} = "Prairie";
$areanames{en}->{6174417} = "Townsville";
$areanames{en}->{61744170} = "Bowen";
$areanames{en}->{61744180} = "Ravenswood";
$areanames{en}->{61744181} = "Richmond";
$areanames{en}->{61744182} = "Rollingstone";
$areanames{en}->{61744183} = "The\ Monument";
$areanames{en}->{61744184} = "Upper\ Stone";
$areanames{en}->{61744185} = "Walker";
$areanames{en}->{61744186} = "Woodstock";
$areanames{en}->{61744187} = "Halifax";
$areanames{en}->{617441880} = "Burketown";
$areanames{en}->{617441881} = "Camooweal";
$areanames{en}->{617441882} = "Cape\ River";
$areanames{en}->{617441883} = "Charters\ Towers";
$areanames{en}->{617441884} = "Clarke";
$areanames{en}->{617441885} = "Cloncurry";
$areanames{en}->{617441886} = "Collinsville";
$areanames{en}->{617441887} = "Croydon";
$areanames{en}->{617441888} = "Dalbeg";
$areanames{en}->{617441889} = "Doomadgee";
$areanames{en}->{617441890} = "Eddington";
$areanames{en}->{617441891} = "Flinders";
$areanames{en}->{617441892} = "Georgina";
$areanames{en}->{617441893} = "Giru";
$areanames{en}->{617441894} = "Greenvale";
$areanames{en}->{617441895} = "Gulf";
$areanames{en}->{617441896} = "Gumlu";
$areanames{en}->{617441897} = "Gunpowder";
$areanames{en}->{617441898} = "Gununa";
$areanames{en}->{617441899} = "Halifax";
$areanames{en}->{617441900} = "Home\ Hill";
$areanames{en}->{617441901} = "Hughenden";
$areanames{en}->{617441902} = "Ingham";
$areanames{en}->{617441903} = "Julia\ Creek";
$areanames{en}->{617441904} = "Kalkadoon";
$areanames{en}->{617441905} = "Karumba";
$areanames{en}->{617441906} = "Kirk";
$areanames{en}->{617441907} = "Leichhardt\ Range";
$areanames{en}->{617441908} = "Long\ Pocket";
$areanames{en}->{617441909} = "Millaroo";
$areanames{en}->{617441910} = "Mount\ Fox";
$areanames{en}->{617441911} = "Mount\ Isa";
$areanames{en}->{617441912} = "Mutarnee";
$areanames{en}->{617441913} = "Normanton";
$areanames{en}->{617441914} = "Palm\ Island";
$areanames{en}->{617441915} = "Pentland";
$areanames{en}->{617441916} = "Prairie";
$areanames{en}->{617441917} = "Ravenswood";
$areanames{en}->{617441918} = "Richmond";
$areanames{en}->{617441919} = "Rollingstone";
$areanames{en}->{617441920} = "The\ Monument";
$areanames{en}->{617441921} = "Townsville";
$areanames{en}->{617441922} = "Upper\ Stone";
$areanames{en}->{617441923} = "Walker";
$areanames{en}->{617441924} = "Woodstock";
$areanames{en}->{617441925} = "Yabulu";
$areanames{en}->{617441926} = "Ayr";
$areanames{en}->{617441927} = "Bambaroo";
$areanames{en}->{617441928} = "Barkly";
$areanames{en}->{617441929} = "Boulia";
$areanames{en}->{617441930} = "Bowen";
$areanames{en}->{617441931} = "Briaba";
$areanames{en}->{617441932} = "Burdekin";
$areanames{en}->{617441933} = "Burketown";
$areanames{en}->{617441934} = "Camooweal";
$areanames{en}->{617441935} = "Cape\ River";
$areanames{en}->{617441936} = "Charters\ Towers";
$areanames{en}->{617441937} = "Clarke";
$areanames{en}->{617441938} = "Cloncurry";
$areanames{en}->{617441939} = "Collinsville";
$areanames{en}->{617441940} = "Croydon";
$areanames{en}->{617441941} = "Dalbeg";
$areanames{en}->{617441942} = "Doomadgee";
$areanames{en}->{617441943} = "Eddington";
$areanames{en}->{617441944} = "Flinders";
$areanames{en}->{617441945} = "Georgina";
$areanames{en}->{617441946} = "Giru";
$areanames{en}->{617441947} = "Greenvale";
$areanames{en}->{617441948} = "Gulf";
$areanames{en}->{617441949} = "Gumlu";
$areanames{en}->{617441950} = "Gunpowder";
$areanames{en}->{617441951} = "Gununa";
$areanames{en}->{617441952} = "Halifax";
$areanames{en}->{617441953} = "Home\ Hill";
$areanames{en}->{617441954} = "Hughenden";
$areanames{en}->{617441955} = "Ingham";
$areanames{en}->{617441956} = "Julia\ Creek";
$areanames{en}->{617441957} = "Kalkadoon";
$areanames{en}->{617441958} = "Karumba";
$areanames{en}->{617441959} = "Kirk";
$areanames{en}->{617441960} = "Leichhardt\ Range";
$areanames{en}->{617441961} = "Long\ Pocket";
$areanames{en}->{617441962} = "Millaroo";
$areanames{en}->{617441963} = "Mount\ Fox";
$areanames{en}->{617441964} = "Mount\ Isa";
$areanames{en}->{617441965} = "Mutarnee";
$areanames{en}->{617441966} = "Normanton";
$areanames{en}->{617441967} = "Palm\ Island";
$areanames{en}->{617441968} = "Pentland";
$areanames{en}->{617441969} = "Prairie";
$areanames{en}->{617441970} = "Ravenswood";
$areanames{en}->{617441971} = "Richmond";
$areanames{en}->{617441972} = "Rollingstone";
$areanames{en}->{617441973} = "The\ Monument";
$areanames{en}->{617441974} = "Townsville";
$areanames{en}->{617441975} = "Upper\ Stone";
$areanames{en}->{617441976} = "Walker";
$areanames{en}->{617441977} = "Woodstock";
$areanames{en}->{617441978} = "Yabulu";
$areanames{en}->{617441979} = "Ayr";
$areanames{en}->{61744198} = "Ayr";
$areanames{en}->{61744199} = "Bowen";
$areanames{en}->{6174420} = "Townsville";
$areanames{en}->{6174421} = "Townsville";
$areanames{en}->{61744210} = "Rollingstone";
$areanames{en}->{61744211} = "Rollingstone";
$areanames{en}->{61744220} = "Townsville";
$areanames{en}->{61744221} = "Clarke";
$areanames{en}->{61744222} = "Clarke";
$areanames{en}->{61744223} = "Yabulu";
$areanames{en}->{61744224} = "Yabulu";
$areanames{en}->{61744225} = "Giru";
$areanames{en}->{61744226} = "Giru";
$areanames{en}->{61744227} = "Townsville";
$areanames{en}->{61744228} = "Townsville";
$areanames{en}->{61744229} = "Bowen";
$areanames{en}->{61744230} = "Bowen";
$areanames{en}->{61744231} = "Collinsville";
$areanames{en}->{61744232} = "Collinsville";
$areanames{en}->{61744233} = "Gumlu";
$areanames{en}->{61744234} = "Gumlu";
$areanames{en}->{61744235} = "Home\ Hill";
$areanames{en}->{61744236} = "Home\ Hill";
$areanames{en}->{61744237} = "Ingham";
$areanames{en}->{61744238} = "Ingham";
$areanames{en}->{61744239} = "Townsville";
$areanames{en}->{61744240} = "Townsville";
$areanames{en}->{61744241} = "Woodstock";
$areanames{en}->{61744242} = "Woodstock";
$areanames{en}->{61744243} = "Cloncurry";
$areanames{en}->{61744244} = "Cloncurry";
$areanames{en}->{61744245} = "Mount\ Isa";
$areanames{en}->{61744246} = "Mount\ Isa";
$areanames{en}->{61744247} = "Flinders";
$areanames{en}->{61744248} = "Flinders";
$areanames{en}->{61744249} = "Charters\ Towers";
$areanames{en}->{61744250} = "Yabulu";
$areanames{en}->{617442510} = "Bambaroo";
$areanames{en}->{617442511} = "Barkly";
$areanames{en}->{617442512} = "Boulia";
$areanames{en}->{617442513} = "Bowen";
$areanames{en}->{617442514} = "Briaba";
$areanames{en}->{617442515} = "Burdekin";
$areanames{en}->{617442516} = "Burketown";
$areanames{en}->{617442517} = "Camooweal";
$areanames{en}->{617442518} = "Cape\ River";
$areanames{en}->{617442519} = "Charters\ Towers";
$areanames{en}->{61744252} = "Barkly";
$areanames{en}->{617442530} = "Clarke";
$areanames{en}->{617442531} = "Cloncurry";
$areanames{en}->{617442532} = "Ayr";
$areanames{en}->{617442533} = "Bambaroo";
$areanames{en}->{617442534} = "Barkly";
$areanames{en}->{617442535} = "Boulia";
$areanames{en}->{617442536} = "Bowen";
$areanames{en}->{617442537} = "Briaba";
$areanames{en}->{617442538} = "Burdekin";
$areanames{en}->{617442539} = "Burketown";
$areanames{en}->{617442540} = "Camooweal";
$areanames{en}->{617442541} = "Cape\ River";
$areanames{en}->{617442542} = "Charters\ Towers";
$areanames{en}->{617442543} = "Clarke";
$areanames{en}->{617442544} = "Cloncurry";
$areanames{en}->{617442545} = "Collinsville";
$areanames{en}->{617442546} = "Croydon";
$areanames{en}->{617442547} = "Dalbeg";
$areanames{en}->{617442548} = "Doomadgee";
$areanames{en}->{617442549} = "Eddington";
$areanames{en}->{617442550} = "Flinders";
$areanames{en}->{617442551} = "Georgina";
$areanames{en}->{617442552} = "Giru";
$areanames{en}->{617442553} = "Greenvale";
$areanames{en}->{617442554} = "Gulf";
$areanames{en}->{617442555} = "Gumlu";
$areanames{en}->{617442556} = "Gunpowder";
$areanames{en}->{617442557} = "Gununa";
$areanames{en}->{617442558} = "Halifax";
$areanames{en}->{617442559} = "Home\ Hill";
$areanames{en}->{617442560} = "Hughenden";
$areanames{en}->{617442561} = "Ingham";
$areanames{en}->{617442562} = "Julia\ Creek";
$areanames{en}->{617442563} = "Kalkadoon";
$areanames{en}->{617442564} = "Karumba";
$areanames{en}->{617442565} = "Kirk";
$areanames{en}->{617442566} = "Leichhardt\ Range";
$areanames{en}->{617442567} = "Long\ Pocket";
$areanames{en}->{617442568} = "Millaroo";
$areanames{en}->{617442569} = "Mount\ Fox";
$areanames{en}->{617442570} = "Mount\ Isa";
$areanames{en}->{617442571} = "Mutarnee";
$areanames{en}->{617442572} = "Normanton";
$areanames{en}->{617442573} = "Palm\ Island";
$areanames{en}->{617442574} = "Pentland";
$areanames{en}->{617442575} = "Prairie";
$areanames{en}->{617442576} = "Ravenswood";
$areanames{en}->{617442577} = "Richmond";
$areanames{en}->{617442578} = "Rollingstone";
$areanames{en}->{617442579} = "The\ Monument";
$areanames{en}->{617442580} = "Townsville";
$areanames{en}->{617442581} = "Upper\ Stone";
$areanames{en}->{617442582} = "Walker";
$areanames{en}->{617442583} = "Woodstock";
$areanames{en}->{617442584} = "Yabulu";
$areanames{en}->{617442585} = "Collinsville";
$areanames{en}->{617442586} = "Croydon";
$areanames{en}->{617442587} = "Dalbeg";
$areanames{en}->{617442588} = "Doomadgee";
$areanames{en}->{617442589} = "Eddington";
$areanames{en}->{61744259} = "Burdekin";
$areanames{en}->{6174426} = "Townsville";
$areanames{en}->{617442600} = "Flinders";
$areanames{en}->{617442601} = "Georgina";
$areanames{en}->{617442602} = "Giru";
$areanames{en}->{617442603} = "Greenvale";
$areanames{en}->{617442604} = "Gulf";
$areanames{en}->{617442605} = "Gumlu";
$areanames{en}->{617442606} = "Gunpowder";
$areanames{en}->{617442607} = "Gununa";
$areanames{en}->{617442608} = "Halifax";
$areanames{en}->{617442609} = "Home\ Hill";
$areanames{en}->{6174427} = "Townsville";
$areanames{en}->{61744277} = "Bowen";
$areanames{en}->{61744278} = "Bowen";
$areanames{en}->{61744279} = "Bowen";
$areanames{en}->{617442800} = "Hughenden";
$areanames{en}->{617442801} = "Ingham";
$areanames{en}->{617442802} = "Julia\ Creek";
$areanames{en}->{617442803} = "Kalkadoon";
$areanames{en}->{617442804} = "Karumba";
$areanames{en}->{617442805} = "Kirk";
$areanames{en}->{617442806} = "Leichhardt\ Range";
$areanames{en}->{617442807} = "Long\ Pocket";
$areanames{en}->{617442808} = "Millaroo";
$areanames{en}->{617442809} = "Mount\ Fox";
$areanames{en}->{617442810} = "Mount\ Isa";
$areanames{en}->{617442811} = "Mutarnee";
$areanames{en}->{617442812} = "Normanton";
$areanames{en}->{617442813} = "Palm\ Island";
$areanames{en}->{617442814} = "Pentland";
$areanames{en}->{617442815} = "Prairie";
$areanames{en}->{617442816} = "Ravenswood";
$areanames{en}->{617442817} = "Richmond";
$areanames{en}->{617442818} = "Rollingstone";
$areanames{en}->{617442819} = "The\ Monument";
$areanames{en}->{617442820} = "Townsville";
$areanames{en}->{617442821} = "Upper\ Stone";
$areanames{en}->{617442822} = "Walker";
$areanames{en}->{617442823} = "Woodstock";
$areanames{en}->{617442824} = "Yabulu";
$areanames{en}->{617442825} = "Ayr";
$areanames{en}->{617442826} = "Bambaroo";
$areanames{en}->{617442827} = "Barkly";
$areanames{en}->{617442828} = "Boulia";
$areanames{en}->{617442829} = "Bowen";
$areanames{en}->{617442830} = "Briaba";
$areanames{en}->{617442831} = "Burdekin";
$areanames{en}->{617442832} = "Burketown";
$areanames{en}->{617442833} = "Camooweal";
$areanames{en}->{617442834} = "Cape\ River";
$areanames{en}->{617442835} = "Charters\ Towers";
$areanames{en}->{617442836} = "Clarke";
$areanames{en}->{617442837} = "Cloncurry";
$areanames{en}->{617442838} = "Collinsville";
$areanames{en}->{617442839} = "Croydon";
$areanames{en}->{617442840} = "Dalbeg";
$areanames{en}->{617442841} = "Doomadgee";
$areanames{en}->{617442842} = "Eddington";
$areanames{en}->{617442843} = "Flinders";
$areanames{en}->{617442844} = "Georgina";
$areanames{en}->{617442845} = "Giru";
$areanames{en}->{617442846} = "Greenvale";
$areanames{en}->{617442847} = "Gulf";
$areanames{en}->{617442848} = "Gumlu";
$areanames{en}->{617442849} = "Gunpowder";
$areanames{en}->{617442850} = "Gununa";
$areanames{en}->{617442851} = "Halifax";
$areanames{en}->{617442852} = "Home\ Hill";
$areanames{en}->{617442853} = "Hughenden";
$areanames{en}->{617442854} = "Ingham";
$areanames{en}->{617442855} = "Julia\ Creek";
$areanames{en}->{617442856} = "Kalkadoon";
$areanames{en}->{617442857} = "Karumba";
$areanames{en}->{617442858} = "Kirk";
$areanames{en}->{617442859} = "Leichhardt\ Range";
$areanames{en}->{617442860} = "Long\ Pocket";
$areanames{en}->{617442861} = "Millaroo";
$areanames{en}->{617442862} = "Mount\ Fox";
$areanames{en}->{617442863} = "Mount\ Isa";
$areanames{en}->{617442864} = "Mutarnee";
$areanames{en}->{617442865} = "Normanton";
$areanames{en}->{617442866} = "Palm\ Island";
$areanames{en}->{617442867} = "Pentland";
$areanames{en}->{617442868} = "Prairie";
$areanames{en}->{617442869} = "Ravenswood";
$areanames{en}->{617442870} = "Richmond";
$areanames{en}->{617442871} = "Rollingstone";
$areanames{en}->{617442872} = "The\ Monument";
$areanames{en}->{617442873} = "Townsville";
$areanames{en}->{617442874} = "Upper\ Stone";
$areanames{en}->{617442875} = "Walker";
$areanames{en}->{617442876} = "Woodstock";
$areanames{en}->{617442877} = "Yabulu";
$areanames{en}->{617442878} = "Ayr";
$areanames{en}->{617442879} = "Bambaroo";
$areanames{en}->{617442880} = "Barkly";
$areanames{en}->{617442881} = "Boulia";
$areanames{en}->{617442882} = "Bowen";
$areanames{en}->{617442883} = "Briaba";
$areanames{en}->{617442884} = "Burdekin";
$areanames{en}->{617442885} = "Burketown";
$areanames{en}->{617442886} = "Camooweal";
$areanames{en}->{617442887} = "Cape\ River";
$areanames{en}->{617442888} = "Charters\ Towers";
$areanames{en}->{617442889} = "Clarke";
$areanames{en}->{617442890} = "Cloncurry";
$areanames{en}->{617442891} = "Collinsville";
$areanames{en}->{617442892} = "Croydon";
$areanames{en}->{617442893} = "Dalbeg";
$areanames{en}->{617442894} = "Doomadgee";
$areanames{en}->{617442895} = "Eddington";
$areanames{en}->{617442896} = "Flinders";
$areanames{en}->{617442897} = "Georgina";
$areanames{en}->{617442898} = "Giru";
$areanames{en}->{617442899} = "Greenvale";
$areanames{en}->{617442900} = "Gulf";
$areanames{en}->{617442901} = "Gumlu";
$areanames{en}->{617442902} = "Gunpowder";
$areanames{en}->{617442903} = "Gununa";
$areanames{en}->{617442904} = "Halifax";
$areanames{en}->{617442905} = "Home\ Hill";
$areanames{en}->{617442906} = "Hughenden";
$areanames{en}->{617442907} = "Ingham";
$areanames{en}->{617442908} = "Julia\ Creek";
$areanames{en}->{617442909} = "Kalkadoon";
$areanames{en}->{617442910} = "Karumba";
$areanames{en}->{617442911} = "Kirk";
$areanames{en}->{617442912} = "Leichhardt\ Range";
$areanames{en}->{617442913} = "Long\ Pocket";
$areanames{en}->{617442914} = "Millaroo";
$areanames{en}->{617442915} = "Mount\ Fox";
$areanames{en}->{617442916} = "Mount\ Isa";
$areanames{en}->{617442917} = "Mutarnee";
$areanames{en}->{617442918} = "Normanton";
$areanames{en}->{617442919} = "Palm\ Island";
$areanames{en}->{617442920} = "Pentland";
$areanames{en}->{617442921} = "Prairie";
$areanames{en}->{617442922} = "Ravenswood";
$areanames{en}->{617442923} = "Richmond";
$areanames{en}->{617442924} = "Rollingstone";
$areanames{en}->{617442925} = "The\ Monument";
$areanames{en}->{617442926} = "Townsville";
$areanames{en}->{617442927} = "Upper\ Stone";
$areanames{en}->{617442928} = "Walker";
$areanames{en}->{617442929} = "Woodstock";
$areanames{en}->{617442930} = "Yabulu";
$areanames{en}->{617442931} = "Ayr";
$areanames{en}->{617442932} = "Bambaroo";
$areanames{en}->{617442933} = "Barkly";
$areanames{en}->{617442934} = "Boulia";
$areanames{en}->{617442935} = "Bowen";
$areanames{en}->{617442936} = "Briaba";
$areanames{en}->{617442937} = "Burdekin";
$areanames{en}->{617442938} = "Burketown";
$areanames{en}->{617442939} = "Camooweal";
$areanames{en}->{617442940} = "Cape\ River";
$areanames{en}->{617442941} = "Charters\ Towers";
$areanames{en}->{617442942} = "Clarke";
$areanames{en}->{617442943} = "Cloncurry";
$areanames{en}->{617442944} = "Collinsville";
$areanames{en}->{617442945} = "Croydon";
$areanames{en}->{617442946} = "Dalbeg";
$areanames{en}->{617442947} = "Doomadgee";
$areanames{en}->{617442948} = "Eddington";
$areanames{en}->{617442949} = "Flinders";
$areanames{en}->{617442950} = "Georgina";
$areanames{en}->{617442951} = "Giru";
$areanames{en}->{617442952} = "Greenvale";
$areanames{en}->{617442953} = "Gulf";
$areanames{en}->{617442954} = "Gumlu";
$areanames{en}->{617442955} = "Gunpowder";
$areanames{en}->{617442956} = "Gununa";
$areanames{en}->{617442957} = "Halifax";
$areanames{en}->{617442958} = "Home\ Hill";
$areanames{en}->{617442959} = "Hughenden";
$areanames{en}->{617442960} = "Ingham";
$areanames{en}->{617442961} = "Julia\ Creek";
$areanames{en}->{617442962} = "Kalkadoon";
$areanames{en}->{617442963} = "Karumba";
$areanames{en}->{617442964} = "Kirk";
$areanames{en}->{617442965} = "Leichhardt\ Range";
$areanames{en}->{617442966} = "Long\ Pocket";
$areanames{en}->{617442967} = "Millaroo";
$areanames{en}->{617442968} = "Mount\ Fox";
$areanames{en}->{617442969} = "Mount\ Isa";
$areanames{en}->{617442970} = "Mutarnee";
$areanames{en}->{617442971} = "Normanton";
$areanames{en}->{617442972} = "Palm\ Island";
$areanames{en}->{617442973} = "Pentland";
$areanames{en}->{617442974} = "Prairie";
$areanames{en}->{617442975} = "Ravenswood";
$areanames{en}->{617442976} = "Richmond";
$areanames{en}->{617442977} = "Rollingstone";
$areanames{en}->{617442978} = "The\ Monument";
$areanames{en}->{617442979} = "Townsville";
$areanames{en}->{617442980} = "Upper\ Stone";
$areanames{en}->{617442981} = "Walker";
$areanames{en}->{617442982} = "Woodstock";
$areanames{en}->{617442983} = "Yabulu";
$areanames{en}->{61744299} = "Ravenswood";
$areanames{en}->{6174430} = "Townsville";
$areanames{en}->{61744310} = "Townsville";
$areanames{en}->{61744311} = "Townsville";
$areanames{en}->{61744312} = "Townsville";
$areanames{en}->{61744313} = "Karumba";
$areanames{en}->{61744314} = "Karumba";
$areanames{en}->{61744315} = "Normanton";
$areanames{en}->{61744316} = "Normanton";
$areanames{en}->{61744317} = "Prairie";
$areanames{en}->{61744318} = "Prairie";
$areanames{en}->{61744319} = "Richmond";
$areanames{en}->{61744320} = "Richmond";
$areanames{en}->{61744321} = "The\ Monument";
$areanames{en}->{61744322} = "The\ Monument";
$areanames{en}->{61744323} = "Walker";
$areanames{en}->{61744324} = "Walker";
$areanames{en}->{61744325} = "Charters\ Towers";
$areanames{en}->{61744326} = "Charters\ Towers";
$areanames{en}->{61744327} = "Charters\ Towers";
$areanames{en}->{61744328} = "Townsville";
$areanames{en}->{61744329} = "Townsville";
$areanames{en}->{6174433} = "Townsville";
$areanames{en}->{6174434} = "Townsville";
$areanames{en}->{61744359} = "Dalbeg";
$areanames{en}->{61744368} = "Croydon";
$areanames{en}->{61744369} = "Townsville";
$areanames{en}->{61744370} = "Mount\ Isa";
$areanames{en}->{61744371} = "Mount\ Isa";
$areanames{en}->{61744372} = "Mount\ Isa";
$areanames{en}->{61744373} = "Mount\ Isa";
$areanames{en}->{61744374} = "Mount\ Isa";
$areanames{en}->{61744375} = "Yabulu";
$areanames{en}->{61744376} = "Townsville";
$areanames{en}->{61744377} = "Barkly";
$areanames{en}->{61744378} = "Barkly";
$areanames{en}->{61744379} = "Barkly";
$areanames{en}->{61744389} = "Yabulu";
$areanames{en}->{61744420} = "Cloncurry";
$areanames{en}->{61744421} = "Cloncurry";
$areanames{en}->{61744422} = "Cloncurry";
$areanames{en}->{61744423} = "Karumba";
$areanames{en}->{61744424} = "Karumba";
$areanames{en}->{61744425} = "Boulia";
$areanames{en}->{61744426} = "Gulf";
$areanames{en}->{61744427} = "Camooweal";
$areanames{en}->{61744428} = "Gununa";
$areanames{en}->{61744429} = "Charters\ Towers";
$areanames{en}->{61744430} = "Charters\ Towers";
$areanames{en}->{61744431} = "Charters\ Towers";
$areanames{en}->{61744432} = "Cape\ River";
$areanames{en}->{61744433} = "Dalbeg";
$areanames{en}->{61744434} = "Greenvale";
$areanames{en}->{61744435} = "Halifax";
$areanames{en}->{61744436} = "Kirk";
$areanames{en}->{61744437} = "Leichhardt\ Range";
$areanames{en}->{61744438} = "Long\ Pocket";
$areanames{en}->{61744439} = "Millaroo";
$areanames{en}->{61744440} = "Ayr";
$areanames{en}->{61744441} = "Mount\ Fox";
$areanames{en}->{61744442} = "Mutarnee";
$areanames{en}->{61744443} = "Palm\ Island";
$areanames{en}->{61744444} = "Townsville";
$areanames{en}->{61744445} = "Townsville";
$areanames{en}->{61744446} = "Gunpowder";
$areanames{en}->{61744447} = "Gunpowder";
$areanames{en}->{61744448} = "Gununa";
$areanames{en}->{61744449} = "Gununa";
$areanames{en}->{61744450} = "Normanton";
$areanames{en}->{61744451} = "Normanton";
$areanames{en}->{61744452} = "Townsville";
$areanames{en}->{61744453} = "Townsville";
$areanames{en}->{61744454} = "Palm\ Island";
$areanames{en}->{61744455} = "Townsville";
$areanames{en}->{61744456} = "Mount\ Isa";
$areanames{en}->{61744457} = "Mount\ Isa";
$areanames{en}->{61744458} = "Mount\ Isa";
$areanames{en}->{61744459} = "Upper\ Stone";
$areanames{en}->{61744471} = "Townsville";
$areanames{en}->{61744472} = "Ayr";
$areanames{en}->{61744473} = "Ayr";
$areanames{en}->{61744474} = "Ayr";
$areanames{en}->{61744475} = "Kalkadoon";
$areanames{en}->{61744476} = "Prairie";
$areanames{en}->{61744477} = "Townsville";
$areanames{en}->{61744478} = "Townsville";
$areanames{en}->{61744479} = "Townsville";
$areanames{en}->{61744480} = "Yabulu";
$areanames{en}->{61744481} = "Yabulu";
$areanames{en}->{61744482} = "Doomadgee";
$areanames{en}->{61744483} = "Townsville";
$areanames{en}->{61744484} = "Townsville";
$areanames{en}->{61744485} = "Townsville";
$areanames{en}->{61744486} = "Townsville";
$areanames{en}->{61744487} = "Townsville";
$areanames{en}->{61744488} = "Townsville";
$areanames{en}->{61745000} = "Bowenville";
$areanames{en}->{61745001} = "Brigalow";
$areanames{en}->{61745002} = "Bunya\ Mountains";
$areanames{en}->{61745003} = "Cecil\ Plains";
$areanames{en}->{61745004} = "Chinchilla";
$areanames{en}->{61745005} = "Coondarra";
$areanames{en}->{61745006} = "Dalby";
$areanames{en}->{61745007} = "Darr\ Creek";
$areanames{en}->{61745008} = "Augathella";
$areanames{en}->{61745009} = "Charleville";
$areanames{en}->{61745010} = "Cunnamulla";
$areanames{en}->{61745011} = "Haddon";
$areanames{en}->{61745012} = "Morven";
$areanames{en}->{61745013} = "Paroo";
$areanames{en}->{61745014} = "Quilpie";
$areanames{en}->{61745015} = "Tambo";
$areanames{en}->{61745016} = "Thargomindah";
$areanames{en}->{61745017} = "Warrego";
$areanames{en}->{61745018} = "Millmerran";
$areanames{en}->{61745019} = "Mount\ Tyson";
$areanames{en}->{61745020} = "Haddon";
$areanames{en}->{61745021} = "Morven";
$areanames{en}->{61745022} = "Paroo";
$areanames{en}->{61745023} = "Quilpie";
$areanames{en}->{61745024} = "Tambo";
$areanames{en}->{61745025} = "Thargomindah";
$areanames{en}->{61745026} = "Warrego";
$areanames{en}->{61745027} = "Bowenville";
$areanames{en}->{61745028} = "Brigalow";
$areanames{en}->{61745029} = "Bunya\ Mountains";
$areanames{en}->{61745030} = "Cecil\ Plains";
$areanames{en}->{61745031} = "Chinchilla";
$areanames{en}->{61745032} = "Coondarra";
$areanames{en}->{61745033} = "Dalby";
$areanames{en}->{61745034} = "Darr\ Creek";
$areanames{en}->{61745035} = "Meandarra";
$areanames{en}->{61745036} = "Moonie";
$areanames{en}->{61745037} = "Southwood";
$areanames{en}->{61745038} = "Tara";
$areanames{en}->{61745039} = "Teelba";
$areanames{en}->{61745040} = "The\ Gums";
$areanames{en}->{61745041} = "Tipton";
$areanames{en}->{61745042} = "Warra";
$areanames{en}->{61745043} = "Westmar";
$areanames{en}->{61745044} = "Diamondy";
$areanames{en}->{61745045} = "Dunmore";
$areanames{en}->{61745046} = "Eschol";
$areanames{en}->{61745047} = "Glenhope";
$areanames{en}->{61745048} = "Goombi";
$areanames{en}->{61745049} = "Jandowae";
$areanames{en}->{61745050} = "Roma";
$areanames{en}->{61745051} = "Roma";
$areanames{en}->{61745052} = "Jimbour";
$areanames{en}->{61745053} = "Kumbarilla";
$areanames{en}->{61745054} = "Kupunn";
$areanames{en}->{61745055} = "Macalister";
$areanames{en}->{61745056} = "Auburn";
$areanames{en}->{61745057} = "Bell";
$areanames{en}->{61745058} = "Bollon";
$areanames{en}->{61745059} = "Culgoa";
$areanames{en}->{61745060} = "Dirranbandi";
$areanames{en}->{61745061} = "St\ George";
$areanames{en}->{61745062} = "Thallon";
$areanames{en}->{61745063} = "Balonne";
$areanames{en}->{61745064} = "Wyaga";
$areanames{en}->{61745065} = "Yelarbon";
$areanames{en}->{61745066} = "Yetman";
$areanames{en}->{61745067} = "Billa\ Billa";
$areanames{en}->{61745068} = "Goondiwindi";
$areanames{en}->{61745069} = "North\ Star";
$areanames{en}->{61745070} = "Talwood";
$areanames{en}->{61745071} = "Toobeah";
$areanames{en}->{61745072} = "Atholwood";
$areanames{en}->{61745073} = "Beebo";
$areanames{en}->{61745074} = "Bonshaw";
$areanames{en}->{61745075} = "Inglewood";
$areanames{en}->{61745076} = "Omanama";
$areanames{en}->{61745077} = "Texas";
$areanames{en}->{61745078} = "Thomson";
$areanames{en}->{61745079} = "Winton";
$areanames{en}->{61745080} = "Barcaldine";
$areanames{en}->{61745081} = "Barcoo";
$areanames{en}->{61745082} = "Blackall";
$areanames{en}->{61745083} = "Diamantina";
$areanames{en}->{61745084} = "Galilee";
$areanames{en}->{61745085} = "Isisford";
$areanames{en}->{61745086} = "Jericho";
$areanames{en}->{61745087} = "Jundah";
$areanames{en}->{61745088} = "Longreach";
$areanames{en}->{61745089} = "Muttaburra";
$areanames{en}->{61745090} = "Aramac";
$areanames{en}->{61745091} = "Dulacca";
$areanames{en}->{61745092} = "Guluguba";
$areanames{en}->{61745093} = "Kilbeggan";
$areanames{en}->{61745094} = "Lynd\ Range";
$areanames{en}->{61745095} = "Miamba";
$areanames{en}->{61745096} = "Miles";
$areanames{en}->{61745097} = "Robinson\ Gorge";
$areanames{en}->{61745098} = "Taroom";
$areanames{en}->{61745099} = "Wandoan";
$areanames{en}->{61745100} = "Bimbadeen";
$areanames{en}->{61745101} = "Cockatoo";
$areanames{en}->{61745102} = "Condamine";
$areanames{en}->{61745103} = "Yuleba";
$areanames{en}->{61745104} = "Durham\ Downs";
$areanames{en}->{61745105} = "Injune";
$areanames{en}->{61745106} = "Maranoa";
$areanames{en}->{61745107} = "Mitchell";
$areanames{en}->{61745108} = "Roma";
$areanames{en}->{61745109} = "Surat";
$areanames{en}->{61745110} = "Tabers";
$areanames{en}->{61745111} = "Valley\ Downs";
$areanames{en}->{61745112} = "Wallumbilla";
$areanames{en}->{61745113} = "Westgrove";
$areanames{en}->{61745114} = "Arcadia\ Valley";
$areanames{en}->{61745115} = "Ballandean";
$areanames{en}->{61745116} = "Cottonvale";
$areanames{en}->{61745117} = "Liston";
$areanames{en}->{61745118} = "Pikedale";
$areanames{en}->{61745119} = "Stanthorpe";
$areanames{en}->{61745120} = "Millmerran";
$areanames{en}->{61745121} = "Mount\ Tyson";
$areanames{en}->{61745122} = "Nobby";
$areanames{en}->{61745123} = "Oakey";
$areanames{en}->{61745124} = "Pittsworth";
$areanames{en}->{61745125} = "Ravensbourne";
$areanames{en}->{61745126} = "Toowoomba";
$areanames{en}->{61745127} = "Jondaryan";
$areanames{en}->{61745128} = "Leyburn";
$areanames{en}->{61745129} = "Clifton";
$areanames{en}->{61745130} = "Cooyar";
$areanames{en}->{61745131} = "Crows\ Nest";
$areanames{en}->{61745132} = "Goombungee";
$areanames{en}->{61745133} = "Greenmount";
$areanames{en}->{61745134} = "Haden";
$areanames{en}->{61745135} = "Helidon";
$areanames{en}->{61745136} = "Bringalily";
$areanames{en}->{61745137} = "Brookstead";
$areanames{en}->{61745138} = "Brymaroo";
$areanames{en}->{61745139} = "Cambooya";
$areanames{en}->{61745140} = "Allora";
$areanames{en}->{61745141} = "Cunningham";
$areanames{en}->{61745142} = "Elbow\ Valley";
$areanames{en}->{61745143} = "Freestone";
$areanames{en}->{61745144} = "Killarney";
$areanames{en}->{61745145} = "Legume";
$areanames{en}->{61745146} = "Warwick";
$areanames{en}->{61745147} = "Augathella";
$areanames{en}->{617451479} = "Allora";
$areanames{en}->{61745148} = "Charleville";
$areanames{en}->{617451489} = "Aramac";
$areanames{en}->{61745149} = "Cunnamulla";
$areanames{en}->{617451499} = "Arcadia\ Valley";
$areanames{en}->{61745150} = "Haddon";
$areanames{en}->{617451509} = "Atholwood";
$areanames{en}->{61745151} = "Morven";
$areanames{en}->{617451519} = "Auburn";
$areanames{en}->{61745152} = "Paroo";
$areanames{en}->{617451529} = "Augathella";
$areanames{en}->{61745153} = "Quilpie";
$areanames{en}->{617451539} = "Ballandean";
$areanames{en}->{61745154} = "Tambo";
$areanames{en}->{617451549} = "Balonne";
$areanames{en}->{61745155} = "Thargomindah";
$areanames{en}->{617451559} = "Barcaldine";
$areanames{en}->{61745156} = "Warrego";
$areanames{en}->{617451569} = "Barcoo";
$areanames{en}->{61745157} = "Auburn";
$areanames{en}->{617451579} = "Beebo";
$areanames{en}->{61745158} = "Bell";
$areanames{en}->{61745159} = "Bowenville";
$areanames{en}->{617451599} = "Billa\ Billa";
$areanames{en}->{61745160} = "Brigalow";
$areanames{en}->{617451609} = "Bimbadeen";
$areanames{en}->{61745161} = "Bunya\ Mountains";
$areanames{en}->{617451619} = "Blackall";
$areanames{en}->{61745162} = "Cecil\ Plains";
$areanames{en}->{617451629} = "Bollon";
$areanames{en}->{61745163} = "Chinchilla";
$areanames{en}->{617451639} = "Bonshaw";
$areanames{en}->{61745164} = "Coondarra";
$areanames{en}->{617451649} = "Bowenville";
$areanames{en}->{61745165} = "Dalby";
$areanames{en}->{61745166} = "Darr\ Creek";
$areanames{en}->{617451669} = "Brigalow";
$areanames{en}->{61745167} = "Diamondy";
$areanames{en}->{617451679} = "Bringalily";
$areanames{en}->{61745168} = "Dunmore";
$areanames{en}->{617451689} = "Brookstead";
$areanames{en}->{61745169} = "Eschol";
$areanames{en}->{617451699} = "Brymaroo";
$areanames{en}->{61745170} = "Glenhope";
$areanames{en}->{617451709} = "Bunya\ Mountains";
$areanames{en}->{61745171} = "Goombi";
$areanames{en}->{617451719} = "Cambooya";
$areanames{en}->{61745172} = "Jandowae";
$areanames{en}->{617451729} = "Cecil\ Plains";
$areanames{en}->{61745173} = "Jimbour";
$areanames{en}->{617451739} = "Charleville";
$areanames{en}->{61745174} = "Kumbarilla";
$areanames{en}->{617451749} = "Chinchilla";
$areanames{en}->{61745175} = "Kupunn";
$areanames{en}->{617451759} = "Clifton";
$areanames{en}->{61745176} = "Macalister";
$areanames{en}->{617451769} = "Cockatoo";
$areanames{en}->{61745177} = "Meandarra";
$areanames{en}->{617451779} = "Condamine";
$areanames{en}->{61745178} = "Moonie";
$areanames{en}->{617451789} = "Coondarra";
$areanames{en}->{61745179} = "Southwood";
$areanames{en}->{617451799} = "Cooyar";
$areanames{en}->{61745180} = "Tara";
$areanames{en}->{617451809} = "Cottonvale";
$areanames{en}->{61745181} = "Teelba";
$areanames{en}->{617451819} = "Crows\ Nest";
$areanames{en}->{61745182} = "The\ Gums";
$areanames{en}->{617451829} = "Culgoa";
$areanames{en}->{61745183} = "Tipton";
$areanames{en}->{617451839} = "Cunnamulla";
$areanames{en}->{61745184} = "Warra";
$areanames{en}->{617451849} = "Cunningham";
$areanames{en}->{61745185} = "Westmar";
$areanames{en}->{617451859} = "Dalby";
$areanames{en}->{61745186} = "Balonne";
$areanames{en}->{617451869} = "Darr\ Creek";
$areanames{en}->{61745187} = "Bollon";
$areanames{en}->{617451879} = "Diamantina";
$areanames{en}->{61745188} = "Culgoa";
$areanames{en}->{617451889} = "Diamondy";
$areanames{en}->{61745189} = "Dirranbandi";
$areanames{en}->{61745190} = "St\ George";
$areanames{en}->{617451909} = "Dulacca";
$areanames{en}->{61745191} = "Thallon";
$areanames{en}->{617451919} = "Dunmore";
$areanames{en}->{61745192} = "Billa\ Billa";
$areanames{en}->{617451929} = "Durham\ Downs";
$areanames{en}->{61745193} = "Goondiwindi";
$areanames{en}->{617451939} = "Elbow\ Valley";
$areanames{en}->{61745194} = "North\ Star";
$areanames{en}->{617451949} = "Eschol";
$areanames{en}->{61745195} = "Talwood";
$areanames{en}->{617451959} = "Freestone";
$areanames{en}->{61745196} = "Toobeah";
$areanames{en}->{617451969} = "Galilee";
$areanames{en}->{61745197} = "Wyaga";
$areanames{en}->{617451979} = "Glenhope";
$areanames{en}->{61745198} = "Yelarbon";
$areanames{en}->{617451989} = "Goombi";
$areanames{en}->{61745199} = "Yetman";
$areanames{en}->{617451999} = "Goombungee";
$areanames{en}->{61745200} = "Atholwood";
$areanames{en}->{617452009} = "Goondiwindi";
$areanames{en}->{61745201} = "Beebo";
$areanames{en}->{617452019} = "Greenmount";
$areanames{en}->{61745202} = "Bonshaw";
$areanames{en}->{617452029} = "Guluguba";
$areanames{en}->{61745203} = "Inglewood";
$areanames{en}->{617452039} = "Haddon";
$areanames{en}->{61745204} = "Omanama";
$areanames{en}->{617452049} = "Haden";
$areanames{en}->{61745205} = "Texas";
$areanames{en}->{617452059} = "Helidon";
$areanames{en}->{61745206} = "Aramac";
$areanames{en}->{617452068} = "Inglewood";
$areanames{en}->{617452069} = "Injune";
$areanames{en}->{61745207} = "Barcaldine";
$areanames{en}->{617452078} = "Isisford";
$areanames{en}->{617452079} = "Jandowae";
$areanames{en}->{61745208} = "Barcoo";
$areanames{en}->{617452088} = "Jericho";
$areanames{en}->{617452089} = "Jimbour";
$areanames{en}->{61745209} = "Blackall";
$areanames{en}->{617452098} = "Jondaryan";
$areanames{en}->{617452099} = "Jundah";
$areanames{en}->{61745210} = "Diamantina";
$areanames{en}->{617452108} = "Kilbeggan";
$areanames{en}->{617452109} = "Killarney";
$areanames{en}->{61745211} = "Galilee";
$areanames{en}->{617452118} = "Kumbarilla";
$areanames{en}->{617452119} = "Kupunn";
$areanames{en}->{61745212} = "Isisford";
$areanames{en}->{617452128} = "Legume";
$areanames{en}->{617452129} = "Leyburn";
$areanames{en}->{61745213} = "Jericho";
$areanames{en}->{617452138} = "Liston";
$areanames{en}->{617452139} = "Longreach";
$areanames{en}->{61745214} = "Jundah";
$areanames{en}->{617452148} = "Lynd\ Range";
$areanames{en}->{617452149} = "Macalister";
$areanames{en}->{61745215} = "Longreach";
$areanames{en}->{617452158} = "Maranoa";
$areanames{en}->{617452159} = "Meandarra";
$areanames{en}->{61745216} = "Muttaburra";
$areanames{en}->{617452168} = "Miamba";
$areanames{en}->{617452169} = "Miles";
$areanames{en}->{61745217} = "Thomson";
$areanames{en}->{617452178} = "Millmerran";
$areanames{en}->{617452179} = "Mitchell";
$areanames{en}->{61745218} = "Winton";
$areanames{en}->{617452188} = "Moonie";
$areanames{en}->{617452189} = "Morven";
$areanames{en}->{61745219} = "Bimbadeen";
$areanames{en}->{617452199} = "Mount\ Tyson";
$areanames{en}->{61745220} = "Cockatoo";
$areanames{en}->{617452209} = "Muttaburra";
$areanames{en}->{61745221} = "Condamine";
$areanames{en}->{617452219} = "Nobby";
$areanames{en}->{61745222} = "Dulacca";
$areanames{en}->{617452229} = "North\ Star";
$areanames{en}->{61745223} = "Guluguba";
$areanames{en}->{617452239} = "Oakey";
$areanames{en}->{61745224} = "Kilbeggan";
$areanames{en}->{617452249} = "Omanama";
$areanames{en}->{61745225} = "Lynd\ Range";
$areanames{en}->{617452259} = "Paroo";
$areanames{en}->{61745226} = "Miamba";
$areanames{en}->{617452269} = "Pikedale";
$areanames{en}->{61745227} = "Miles";
$areanames{en}->{617452279} = "Pittsworth";
$areanames{en}->{61745228} = "Robinson\ Gorge";
$areanames{en}->{617452289} = "Quilpie";
$areanames{en}->{61745229} = "Taroom";
$areanames{en}->{617452299} = "Ravensbourne";
$areanames{en}->{61745230} = "Wandoan";
$areanames{en}->{617452309} = "Robinson\ Gorge";
$areanames{en}->{61745231} = "Arcadia\ Valley";
$areanames{en}->{617452319} = "Roma";
$areanames{en}->{61745232} = "Durham\ Downs";
$areanames{en}->{617452329} = "Southwood";
$areanames{en}->{61745233} = "Injune";
$areanames{en}->{617452339} = "St\ George";
$areanames{en}->{61745234} = "Maranoa";
$areanames{en}->{617452349} = "Stanthorpe";
$areanames{en}->{61745235} = "Mitchell";
$areanames{en}->{617452359} = "Surat";
$areanames{en}->{617452360} = "Roma";
$areanames{en}->{617452361} = "Roma";
$areanames{en}->{617452362} = "Roma";
$areanames{en}->{617452363} = "Roma";
$areanames{en}->{617452364} = "Roma";
$areanames{en}->{617452365} = "Roma";
$areanames{en}->{617452368} = "Tabers";
$areanames{en}->{617452369} = "Talwood";
$areanames{en}->{61745237} = "Surat";
$areanames{en}->{617452379} = "Tambo";
$areanames{en}->{61745238} = "Tabers";
$areanames{en}->{617452389} = "Tara";
$areanames{en}->{61745239} = "Valley\ Downs";
$areanames{en}->{617452399} = "Taroom";
$areanames{en}->{617452400} = "Wallumbilla";
$areanames{en}->{617452401} = "Wallumbilla";
$areanames{en}->{617452402} = "Wallumbilla";
$areanames{en}->{617452403} = "Wallumbilla";
$areanames{en}->{617452404} = "Wallumbilla";
$areanames{en}->{617452405} = "Wallumbilla";
$areanames{en}->{617452408} = "Teelba";
$areanames{en}->{617452409} = "Texas";
$areanames{en}->{61745241} = "Westgrove";
$areanames{en}->{617452419} = "Thallon";
$areanames{en}->{61745242} = "Yuleba";
$areanames{en}->{617452429} = "Thargomindah";
$areanames{en}->{61745243} = "Ballandean";
$areanames{en}->{617452439} = "The\ Gums";
$areanames{en}->{61745244} = "Cottonvale";
$areanames{en}->{617452449} = "Thomson";
$areanames{en}->{61745245} = "Liston";
$areanames{en}->{617452459} = "Tipton";
$areanames{en}->{61745246} = "Pikedale";
$areanames{en}->{617452469} = "Toobeah";
$areanames{en}->{61745247} = "Stanthorpe";
$areanames{en}->{617452479} = "Toowoomba";
$areanames{en}->{617452480} = "Bringalily";
$areanames{en}->{617452481} = "Bringalily";
$areanames{en}->{617452482} = "Bringalily";
$areanames{en}->{617452483} = "Bringalily";
$areanames{en}->{617452484} = "Bringalily";
$areanames{en}->{617452485} = "Bringalily";
$areanames{en}->{617452488} = "Bringalily";
$areanames{en}->{617452489} = "Valley\ Downs";
$areanames{en}->{617452490} = "Brookstead";
$areanames{en}->{617452491} = "Brookstead";
$areanames{en}->{617452492} = "Brookstead";
$areanames{en}->{617452493} = "Brookstead";
$areanames{en}->{617452494} = "Brookstead";
$areanames{en}->{617452495} = "Brookstead";
$areanames{en}->{617452498} = "Brookstead";
$areanames{en}->{617452499} = "Wallumbilla";
$areanames{en}->{617452500} = "Brymaroo";
$areanames{en}->{617452501} = "Brymaroo";
$areanames{en}->{617452502} = "Brymaroo";
$areanames{en}->{617452503} = "Brymaroo";
$areanames{en}->{617452504} = "Brymaroo";
$areanames{en}->{617452505} = "Brymaroo";
$areanames{en}->{617452508} = "Brymaroo";
$areanames{en}->{617452509} = "Wandoan";
$areanames{en}->{617452510} = "Cambooya";
$areanames{en}->{617452511} = "Cambooya";
$areanames{en}->{617452512} = "Cambooya";
$areanames{en}->{617452513} = "Cambooya";
$areanames{en}->{617452514} = "Cambooya";
$areanames{en}->{617452515} = "Cambooya";
$areanames{en}->{617452518} = "Cambooya";
$areanames{en}->{617452519} = "Warra";
$areanames{en}->{617452520} = "Clifton";
$areanames{en}->{617452521} = "Clifton";
$areanames{en}->{617452522} = "Clifton";
$areanames{en}->{617452523} = "Clifton";
$areanames{en}->{617452524} = "Clifton";
$areanames{en}->{617452525} = "Clifton";
$areanames{en}->{617452528} = "Clifton";
$areanames{en}->{617452529} = "Warrego";
$areanames{en}->{617452530} = "Cooyar";
$areanames{en}->{617452531} = "Cooyar";
$areanames{en}->{617452532} = "Cooyar";
$areanames{en}->{617452533} = "Cooyar";
$areanames{en}->{617452534} = "Cooyar";
$areanames{en}->{617452535} = "Cooyar";
$areanames{en}->{617452538} = "Cooyar";
$areanames{en}->{617452539} = "Warwick";
$areanames{en}->{617452540} = "Crows\ Nest";
$areanames{en}->{617452541} = "Crows\ Nest";
$areanames{en}->{617452542} = "Crows\ Nest";
$areanames{en}->{617452543} = "Crows\ Nest";
$areanames{en}->{617452544} = "Crows\ Nest";
$areanames{en}->{617452545} = "Crows\ Nest";
$areanames{en}->{617452548} = "Crows\ Nest";
$areanames{en}->{617452549} = "Westgrove";
$areanames{en}->{617452550} = "Goombungee";
$areanames{en}->{617452551} = "Goombungee";
$areanames{en}->{617452552} = "Goombungee";
$areanames{en}->{617452553} = "Goombungee";
$areanames{en}->{617452554} = "Goombungee";
$areanames{en}->{617452555} = "Goombungee";
$areanames{en}->{617452558} = "Goombungee";
$areanames{en}->{617452559} = "Goombungee";
$areanames{en}->{617452560} = "Greenmount";
$areanames{en}->{617452561} = "Greenmount";
$areanames{en}->{617452562} = "Greenmount";
$areanames{en}->{617452563} = "Greenmount";
$areanames{en}->{617452564} = "Greenmount";
$areanames{en}->{617452565} = "Greenmount";
$areanames{en}->{617452568} = "Greenmount";
$areanames{en}->{617452569} = "Westmar";
$areanames{en}->{617452570} = "Haden";
$areanames{en}->{617452571} = "Haden";
$areanames{en}->{617452572} = "Haden";
$areanames{en}->{617452573} = "Haden";
$areanames{en}->{617452574} = "Haden";
$areanames{en}->{617452575} = "Haden";
$areanames{en}->{617452578} = "Haden";
$areanames{en}->{617452579} = "Winton";
$areanames{en}->{617452580} = "Helidon";
$areanames{en}->{617452581} = "Helidon";
$areanames{en}->{617452582} = "Helidon";
$areanames{en}->{617452583} = "Helidon";
$areanames{en}->{617452584} = "Helidon";
$areanames{en}->{617452585} = "Helidon";
$areanames{en}->{617452588} = "Helidon";
$areanames{en}->{617452589} = "Wyaga";
$areanames{en}->{617452590} = "Jondaryan";
$areanames{en}->{617452591} = "Jondaryan";
$areanames{en}->{617452592} = "Jondaryan";
$areanames{en}->{617452593} = "Jondaryan";
$areanames{en}->{617452594} = "Jondaryan";
$areanames{en}->{617452595} = "Jondaryan";
$areanames{en}->{617452598} = "Jondaryan";
$areanames{en}->{617452599} = "Yelarbon";
$areanames{en}->{617452600} = "Leyburn";
$areanames{en}->{617452601} = "Leyburn";
$areanames{en}->{617452602} = "Leyburn";
$areanames{en}->{617452603} = "Leyburn";
$areanames{en}->{617452604} = "Leyburn";
$areanames{en}->{617452605} = "Leyburn";
$areanames{en}->{617452608} = "Leyburn";
$areanames{en}->{617452609} = "Yetman";
$areanames{en}->{617452610} = "Millmerran";
$areanames{en}->{617452611} = "Millmerran";
$areanames{en}->{617452612} = "Millmerran";
$areanames{en}->{617452613} = "Millmerran";
$areanames{en}->{617452614} = "Millmerran";
$areanames{en}->{617452615} = "Millmerran";
$areanames{en}->{617452618} = "Millmerran";
$areanames{en}->{617452619} = "Yuleba";
$areanames{en}->{617452620} = "Mount\ Tyson";
$areanames{en}->{617452621} = "Mount\ Tyson";
$areanames{en}->{617452622} = "Mount\ Tyson";
$areanames{en}->{617452623} = "Mount\ Tyson";
$areanames{en}->{617452624} = "Mount\ Tyson";
$areanames{en}->{617452625} = "Mount\ Tyson";
$areanames{en}->{617452628} = "Mount\ Tyson";
$areanames{en}->{617452629} = "Allora";
$areanames{en}->{617452630} = "Nobby";
$areanames{en}->{617452631} = "Nobby";
$areanames{en}->{617452632} = "Nobby";
$areanames{en}->{617452633} = "Nobby";
$areanames{en}->{617452634} = "Nobby";
$areanames{en}->{617452635} = "Nobby";
$areanames{en}->{617452638} = "Nobby";
$areanames{en}->{617452639} = "Aramac";
$areanames{en}->{617452640} = "Oakey";
$areanames{en}->{617452641} = "Oakey";
$areanames{en}->{617452642} = "Oakey";
$areanames{en}->{617452643} = "Oakey";
$areanames{en}->{617452644} = "Oakey";
$areanames{en}->{617452645} = "Oakey";
$areanames{en}->{617452648} = "Oakey";
$areanames{en}->{617452649} = "Arcadia\ Valley";
$areanames{en}->{617452650} = "Pittsworth";
$areanames{en}->{617452651} = "Pittsworth";
$areanames{en}->{617452652} = "Pittsworth";
$areanames{en}->{617452653} = "Pittsworth";
$areanames{en}->{617452654} = "Pittsworth";
$areanames{en}->{617452655} = "Pittsworth";
$areanames{en}->{617452658} = "Pittsworth";
$areanames{en}->{617452659} = "Atholwood";
$areanames{en}->{617452660} = "Ravensbourne";
$areanames{en}->{617452661} = "Ravensbourne";
$areanames{en}->{617452662} = "Ravensbourne";
$areanames{en}->{617452663} = "Ravensbourne";
$areanames{en}->{617452664} = "Ravensbourne";
$areanames{en}->{617452665} = "Ravensbourne";
$areanames{en}->{617452668} = "Ravensbourne";
$areanames{en}->{617452669} = "Auburn";
$areanames{en}->{617452670} = "Toowoomba";
$areanames{en}->{617452671} = "Toowoomba";
$areanames{en}->{617452672} = "Toowoomba";
$areanames{en}->{617452673} = "Toowoomba";
$areanames{en}->{617452676} = "Augathella";
$areanames{en}->{617452677} = "Ballandean";
$areanames{en}->{617452678} = "Balonne";
$areanames{en}->{617452679} = "Barcaldine";
$areanames{en}->{617452680} = "Allora";
$areanames{en}->{617452681} = "Allora";
$areanames{en}->{617452682} = "Allora";
$areanames{en}->{617452683} = "Allora";
$areanames{en}->{617452684} = "Allora";
$areanames{en}->{617452685} = "Allora";
$areanames{en}->{617452688} = "Allora";
$areanames{en}->{617452689} = "Barcoo";
$areanames{en}->{617452690} = "Cunningham";
$areanames{en}->{617452691} = "Cunningham";
$areanames{en}->{617452692} = "Cunningham";
$areanames{en}->{617452693} = "Cunningham";
$areanames{en}->{617452694} = "Cunningham";
$areanames{en}->{617452695} = "Cunningham";
$areanames{en}->{617452698} = "Cunningham";
$areanames{en}->{617452699} = "Beebo";
$areanames{en}->{617452700} = "Elbow\ Valley";
$areanames{en}->{617452701} = "Elbow\ Valley";
$areanames{en}->{617452702} = "Elbow\ Valley";
$areanames{en}->{617452703} = "Elbow\ Valley";
$areanames{en}->{617452704} = "Elbow\ Valley";
$areanames{en}->{617452705} = "Elbow\ Valley";
$areanames{en}->{617452708} = "Elbow\ Valley";
$areanames{en}->{617452709} = "Bell";
$areanames{en}->{617452710} = "Freestone";
$areanames{en}->{617452711} = "Freestone";
$areanames{en}->{617452712} = "Freestone";
$areanames{en}->{617452713} = "Freestone";
$areanames{en}->{617452714} = "Freestone";
$areanames{en}->{617452715} = "Freestone";
$areanames{en}->{617452718} = "Freestone";
$areanames{en}->{617452719} = "Billa\ Billa";
$areanames{en}->{617452720} = "Killarney";
$areanames{en}->{617452721} = "Killarney";
$areanames{en}->{617452722} = "Killarney";
$areanames{en}->{617452723} = "Killarney";
$areanames{en}->{617452724} = "Killarney";
$areanames{en}->{617452725} = "Killarney";
$areanames{en}->{617452728} = "Killarney";
$areanames{en}->{617452729} = "Bimbadeen";
$areanames{en}->{617452730} = "Legume";
$areanames{en}->{617452731} = "Legume";
$areanames{en}->{617452732} = "Legume";
$areanames{en}->{617452733} = "Legume";
$areanames{en}->{617452734} = "Legume";
$areanames{en}->{617452735} = "Legume";
$areanames{en}->{617452738} = "Legume";
$areanames{en}->{617452739} = "Blackall";
$areanames{en}->{61745274} = "Warwick";
$areanames{en}->{617452749} = "Bollon";
$areanames{en}->{61745275} = "Wallumbilla";
$areanames{en}->{61745276} = "Toowoomba";
$areanames{en}->{61745277} = "Toowoomba";
$areanames{en}->{61745278} = "Warrego";
$areanames{en}->{61745279} = "Warrego";
$areanames{en}->{61745280} = "Goondiwindi";
$areanames{en}->{61745281} = "Stanthorpe";
$areanames{en}->{61745282} = "Toowoomba";
$areanames{en}->{61745283} = "Warwick";
$areanames{en}->{61745284} = "Goombungee";
$areanames{en}->{61745285} = "Goombungee";
$areanames{en}->{61745286} = "Warwick";
$areanames{en}->{61745287} = "Warwick";
$areanames{en}->{61745288} = "Yelarbon";
$areanames{en}->{61745289} = "Yelarbon";
$areanames{en}->{6174529} = "Toowoomba";
$areanames{en}->{61745300} = "Augathella";
$areanames{en}->{61745301} = "Charleville";
$areanames{en}->{61745302} = "Cunnamulla";
$areanames{en}->{61745303} = "Haddon";
$areanames{en}->{61745304} = "Morven";
$areanames{en}->{61745305} = "Paroo";
$areanames{en}->{61745306} = "Quilpie";
$areanames{en}->{61745307} = "Tambo";
$areanames{en}->{61745308} = "Thargomindah";
$areanames{en}->{61745309} = "Warrego";
$areanames{en}->{61745310} = "Auburn";
$areanames{en}->{61745311} = "Bell";
$areanames{en}->{61745312} = "Bowenville";
$areanames{en}->{61745313} = "Brigalow";
$areanames{en}->{61745314} = "Bunya\ Mountains";
$areanames{en}->{61745315} = "Cecil\ Plains";
$areanames{en}->{61745316} = "Chinchilla";
$areanames{en}->{61745317} = "Coondarra";
$areanames{en}->{61745318} = "Dalby";
$areanames{en}->{61745319} = "Darr\ Creek";
$areanames{en}->{61745320} = "Diamondy";
$areanames{en}->{61745321} = "Dunmore";
$areanames{en}->{61745322} = "Eschol";
$areanames{en}->{61745323} = "Glenhope";
$areanames{en}->{61745324} = "Goombi";
$areanames{en}->{61745325} = "Jandowae";
$areanames{en}->{61745326} = "Jimbour";
$areanames{en}->{61745327} = "Kumbarilla";
$areanames{en}->{61745328} = "Kupunn";
$areanames{en}->{61745329} = "Macalister";
$areanames{en}->{61745330} = "Meandarra";
$areanames{en}->{61745331} = "Moonie";
$areanames{en}->{61745332} = "Southwood";
$areanames{en}->{61745333} = "Tara";
$areanames{en}->{61745334} = "Teelba";
$areanames{en}->{61745335} = "The\ Gums";
$areanames{en}->{61745336} = "Tipton";
$areanames{en}->{61745337} = "Warra";
$areanames{en}->{61745338} = "Westmar";
$areanames{en}->{61745339} = "Balonne";
$areanames{en}->{61745340} = "Bollon";
$areanames{en}->{61745341} = "Culgoa";
$areanames{en}->{61745342} = "Dirranbandi";
$areanames{en}->{61745343} = "St\ George";
$areanames{en}->{61745344} = "Thallon";
$areanames{en}->{61745345} = "Billa\ Billa";
$areanames{en}->{61745346} = "Goondiwindi";
$areanames{en}->{61745347} = "North\ Star";
$areanames{en}->{61745348} = "Talwood";
$areanames{en}->{61745349} = "Toobeah";
$areanames{en}->{61745350} = "Wyaga";
$areanames{en}->{61745351} = "Yelarbon";
$areanames{en}->{61745352} = "Yetman";
$areanames{en}->{61745353} = "Atholwood";
$areanames{en}->{61745354} = "Beebo";
$areanames{en}->{61745355} = "Bonshaw";
$areanames{en}->{61745356} = "Inglewood";
$areanames{en}->{61745357} = "Omanama";
$areanames{en}->{61745358} = "Texas";
$areanames{en}->{61745359} = "Aramac";
$areanames{en}->{61745360} = "Barcaldine";
$areanames{en}->{61745361} = "Barcoo";
$areanames{en}->{61745362} = "Blackall";
$areanames{en}->{61745363} = "Diamantina";
$areanames{en}->{61745364} = "Galilee";
$areanames{en}->{61745365} = "Isisford";
$areanames{en}->{61745366} = "Jericho";
$areanames{en}->{61745367} = "Jundah";
$areanames{en}->{61745368} = "Longreach";
$areanames{en}->{61745369} = "Muttaburra";
$areanames{en}->{61745370} = "Thomson";
$areanames{en}->{61745371} = "Winton";
$areanames{en}->{61745372} = "Bimbadeen";
$areanames{en}->{61745373} = "Cockatoo";
$areanames{en}->{61745374} = "Condamine";
$areanames{en}->{61745375} = "Dulacca";
$areanames{en}->{61745376} = "Guluguba";
$areanames{en}->{61745377} = "Kilbeggan";
$areanames{en}->{61745378} = "Lynd\ Range";
$areanames{en}->{61745379} = "Miamba";
$areanames{en}->{61745380} = "Miles";
$areanames{en}->{61745381} = "Robinson\ Gorge";
$areanames{en}->{61745382} = "Taroom";
$areanames{en}->{61745383} = "Wandoan";
$areanames{en}->{61745384} = "Arcadia\ Valley";
$areanames{en}->{61745385} = "Durham\ Downs";
$areanames{en}->{61745386} = "Injune";
$areanames{en}->{61745387} = "Maranoa";
$areanames{en}->{61745388} = "Mitchell";
$areanames{en}->{61745389} = "Roma";
$areanames{en}->{61745390} = "Surat";
$areanames{en}->{61745391} = "Tabers";
$areanames{en}->{61745392} = "Valley\ Downs";
$areanames{en}->{61745393} = "Wallumbilla";
$areanames{en}->{61745394} = "Westgrove";
$areanames{en}->{61745395} = "Yuleba";
$areanames{en}->{61745396} = "Ballandean";
$areanames{en}->{61745397} = "Cottonvale";
$areanames{en}->{61745398} = "Liston";
$areanames{en}->{61745399} = "Pikedale";
$areanames{en}->{61745400} = "Stanthorpe";
$areanames{en}->{61745401} = "Bringalily";
$areanames{en}->{61745402} = "Brookstead";
$areanames{en}->{61745403} = "Brymaroo";
$areanames{en}->{61745404} = "Cambooya";
$areanames{en}->{61745405} = "Clifton";
$areanames{en}->{61745406} = "Cooyar";
$areanames{en}->{61745407} = "Crows\ Nest";
$areanames{en}->{61745408} = "Goombungee";
$areanames{en}->{61745409} = "Greenmount";
$areanames{en}->{61745410} = "Haden";
$areanames{en}->{61745411} = "Helidon";
$areanames{en}->{61745412} = "Jondaryan";
$areanames{en}->{61745413} = "Leyburn";
$areanames{en}->{61745414} = "Millmerran";
$areanames{en}->{61745415} = "Mount\ Tyson";
$areanames{en}->{61745416} = "Nobby";
$areanames{en}->{61745417} = "Oakey";
$areanames{en}->{61745418} = "Pittsworth";
$areanames{en}->{61745419} = "Ravensbourne";
$areanames{en}->{61745420} = "Allora";
$areanames{en}->{61745421} = "Cunningham";
$areanames{en}->{61745422} = "Elbow\ Valley";
$areanames{en}->{61745423} = "Freestone";
$areanames{en}->{61745424} = "Killarney";
$areanames{en}->{61745425} = "Legume";
$areanames{en}->{61745426} = "Warwick";
$areanames{en}->{61745427} = "Toowoomba";
$areanames{en}->{61745428} = "Mount\ Tyson";
$areanames{en}->{61745429} = "Mount\ Tyson";
$areanames{en}->{61745430} = "Cunningham";
$areanames{en}->{61745431} = "Cunningham";
$areanames{en}->{61745432} = "Elbow\ Valley";
$areanames{en}->{61745433} = "Elbow\ Valley";
$areanames{en}->{61745434} = "Killarney";
$areanames{en}->{61745435} = "Killarney";
$areanames{en}->{61745436} = "Inglewood";
$areanames{en}->{61745437} = "Inglewood";
$areanames{en}->{61745438} = "Ravensbourne";
$areanames{en}->{61745439} = "Ravensbourne";
$areanames{en}->{61745440} = "Bell";
$areanames{en}->{61745441} = "Bell";
$areanames{en}->{61745442} = "Bowenville";
$areanames{en}->{61745443} = "Bowenville";
$areanames{en}->{61745444} = "Brigalow";
$areanames{en}->{61745445} = "Brigalow";
$areanames{en}->{61745446} = "Bunya\ Mountains";
$areanames{en}->{61745447} = "Bunya\ Mountains";
$areanames{en}->{61745448} = "Dalby";
$areanames{en}->{61745449} = "Dalby";
$areanames{en}->{61745450} = "Eschol";
$areanames{en}->{61745451} = "Eschol";
$areanames{en}->{61745452} = "Glenhope";
$areanames{en}->{61745453} = "Glenhope";
$areanames{en}->{61745454} = "Jandowae";
$areanames{en}->{61745455} = "Jandowae";
$areanames{en}->{61745456} = "Jimbour";
$areanames{en}->{61745457} = "Jimbour";
$areanames{en}->{61745458} = "Kupunn";
$areanames{en}->{61745459} = "Kupunn";
$areanames{en}->{61745460} = "Macalister";
$areanames{en}->{61745461} = "Macalister";
$areanames{en}->{61745462} = "Texas";
$areanames{en}->{61745463} = "Texas";
$areanames{en}->{61745464} = "St\ George";
$areanames{en}->{61745465} = "St\ George";
$areanames{en}->{61745466} = "Goondiwindi";
$areanames{en}->{61745467} = "Goondiwindi";
$areanames{en}->{61745468} = "Wyaga";
$areanames{en}->{61745469} = "Wyaga";
$areanames{en}->{61745470} = "Yetman";
$areanames{en}->{61745471} = "Yetman";
$areanames{en}->{61745472} = "Charleville";
$areanames{en}->{61745473} = "Charleville";
$areanames{en}->{61745474} = "Cunnamulla";
$areanames{en}->{61745475} = "Cunnamulla";
$areanames{en}->{61745476} = "Cunnamulla";
$areanames{en}->{61745477} = "Cunnamulla";
$areanames{en}->{61745478} = "Chinchilla";
$areanames{en}->{61745479} = "Chinchilla";
$areanames{en}->{61745480} = "Toowoomba";
$areanames{en}->{61745481} = "Coondarra";
$areanames{en}->{61745482} = "Coondarra";
$areanames{en}->{61745483} = "Darr\ Creek";
$areanames{en}->{61745484} = "Darr\ Creek";
$areanames{en}->{61745485} = "Bringalily";
$areanames{en}->{61745486} = "Bringalily";
$areanames{en}->{61745487} = "Millmerran";
$areanames{en}->{61745488} = "Millmerran";
$areanames{en}->{61745489} = "Warwick";
$areanames{en}->{6174549} = "Toowoomba";
$areanames{en}->{61745500} = "Cecil\ Plains";
$areanames{en}->{61745501} = "Cecil\ Plains";
$areanames{en}->{61745502} = "Nobby";
$areanames{en}->{61745503} = "Nobby";
$areanames{en}->{61745504} = "Pittsworth";
$areanames{en}->{61745505} = "Pittsworth";
$areanames{en}->{61745506} = "North\ Star";
$areanames{en}->{61745507} = "North\ Star";
$areanames{en}->{61745508} = "Toobeah";
$areanames{en}->{61745509} = "Toobeah";
$areanames{en}->{61745510} = "Inglewood";
$areanames{en}->{61745511} = "Inglewood";
$areanames{en}->{61745512} = "Atholwood";
$areanames{en}->{61745513} = "Atholwood";
$areanames{en}->{61745514} = "Beebo";
$areanames{en}->{61745515} = "Beebo";
$areanames{en}->{61745516} = "Bonshaw";
$areanames{en}->{61745517} = "Bonshaw";
$areanames{en}->{61745518} = "Omanama";
$areanames{en}->{61745519} = "Omanama";
$areanames{en}->{61745520} = "Galilee";
$areanames{en}->{61745521} = "Galilee";
$areanames{en}->{61745522} = "Muttaburra";
$areanames{en}->{61745523} = "Muttaburra";
$areanames{en}->{61745524} = "Thomson";
$areanames{en}->{61745525} = "Thomson";
$areanames{en}->{61745526} = "Barcaldine";
$areanames{en}->{61745527} = "Barcaldine";
$areanames{en}->{61745528} = "Robinson\ Gorge";
$areanames{en}->{61745529} = "Robinson\ Gorge";
$areanames{en}->{61745530} = "Allora";
$areanames{en}->{61745531} = "Allora";
$areanames{en}->{61745532} = "Condamine";
$areanames{en}->{61745533} = "Condamine";
$areanames{en}->{61745534} = "Guluguba";
$areanames{en}->{61745535} = "Guluguba";
$areanames{en}->{61745536} = "Miamba";
$areanames{en}->{61745537} = "Miamba";
$areanames{en}->{61745538} = "Taroom";
$areanames{en}->{61745539} = "Taroom";
$areanames{en}->{61745540} = "Freestone";
$areanames{en}->{61745541} = "Freestone";
$areanames{en}->{61745542} = "Legume";
$areanames{en}->{61745543} = "Legume";
$areanames{en}->{61745544} = "Mitchell";
$areanames{en}->{61745545} = "Mitchell";
$areanames{en}->{61745546} = "Durham\ Downs";
$areanames{en}->{61745547} = "Durham\ Downs";
$areanames{en}->{61745548} = "Roma";
$areanames{en}->{61745549} = "Roma";
$areanames{en}->{61745550} = "Tabers";
$areanames{en}->{61745551} = "Tabers";
$areanames{en}->{61745552} = "Balonne";
$areanames{en}->{61745553} = "Balonne";
$areanames{en}->{61745554} = "Valley\ Downs";
$areanames{en}->{61745555} = "Valley\ Downs";
$areanames{en}->{61745556} = "Cottonvale";
$areanames{en}->{61745557} = "Cottonvale";
$areanames{en}->{61745558} = "Liston";
$areanames{en}->{61745559} = "Liston";
$areanames{en}->{61745560} = "Pikedale";
$areanames{en}->{61745561} = "Pikedale";
$areanames{en}->{61745562} = "Paroo";
$areanames{en}->{61745563} = "Paroo";
$areanames{en}->{61745564} = "Diamondy";
$areanames{en}->{61745565} = "Diamondy";
$areanames{en}->{61745566} = "Dunmore";
$areanames{en}->{61745567} = "Dunmore";
$areanames{en}->{61745568} = "Goombi";
$areanames{en}->{61745569} = "Goombi";
$areanames{en}->{61745570} = "Kumbarilla";
$areanames{en}->{61745571} = "Kumbarilla";
$areanames{en}->{61745572} = "Tara";
$areanames{en}->{61745573} = "Tara";
$areanames{en}->{61745574} = "Tipton";
$areanames{en}->{61745575} = "Tipton";
$areanames{en}->{61745576} = "Warra";
$areanames{en}->{61745577} = "Warra";
$areanames{en}->{61745578} = "Billa\ Billa";
$areanames{en}->{61745579} = "Billa\ Billa";
$areanames{en}->{61745580} = "Miles";
$areanames{en}->{61745581} = "Miles";
$areanames{en}->{61745582} = "Miles";
$areanames{en}->{61745583} = "Wandoan";
$areanames{en}->{61745584} = "Taroom";
$areanames{en}->{61745585} = "Bimbadeen";
$areanames{en}->{61745586} = "Condamine";
$areanames{en}->{61745587} = "Condamine";
$areanames{en}->{61745588} = "Guluguba";
$areanames{en}->{61745589} = "Cockatoo";
$areanames{en}->{61745590} = "Miamba";
$areanames{en}->{61745591} = "Robinson\ Gorge";
$areanames{en}->{61745592} = "Kilbeggan";
$areanames{en}->{61745593} = "Lynd\ Range";
$areanames{en}->{61745594} = "Dulacca";
$areanames{en}->{61745595} = "Aramac";
$areanames{en}->{61745596} = "Aramac";
$areanames{en}->{61745597} = "Auburn";
$areanames{en}->{61745598} = "Auburn";
$areanames{en}->{61745599} = "Augathella";
$areanames{en}->{61745600} = "Augathella";
$areanames{en}->{61745601} = "Barcoo";
$areanames{en}->{61745602} = "Barcoo";
$areanames{en}->{61745603} = "Blackall";
$areanames{en}->{61745604} = "Blackall";
$areanames{en}->{61745605} = "Bollon";
$areanames{en}->{61745606} = "Bollon";
$areanames{en}->{61745607} = "Culgoa";
$areanames{en}->{61745608} = "Culgoa";
$areanames{en}->{61745609} = "Diamantina";
$areanames{en}->{61745610} = "Diamantina";
$areanames{en}->{61745611} = "Dirranbandi";
$areanames{en}->{61745612} = "Dirranbandi";
$areanames{en}->{61745613} = "Haddon";
$areanames{en}->{61745614} = "Haddon";
$areanames{en}->{61745615} = "Injune";
$areanames{en}->{61745616} = "Injune";
$areanames{en}->{61745617} = "Isisford";
$areanames{en}->{61745618} = "Isisford";
$areanames{en}->{61745619} = "Jericho";
$areanames{en}->{61745620} = "Jericho";
$areanames{en}->{61745621} = "Jundah";
$areanames{en}->{61745622} = "Jundah";
$areanames{en}->{61745623} = "Maranoa";
$areanames{en}->{61745624} = "Maranoa";
$areanames{en}->{61745625} = "Morven";
$areanames{en}->{61745626} = "Morven";
$areanames{en}->{61745627} = "Quilpie";
$areanames{en}->{61745628} = "Quilpie";
$areanames{en}->{61745629} = "Talwood";
$areanames{en}->{61745630} = "Talwood";
$areanames{en}->{61745631} = "Tambo";
$areanames{en}->{61745632} = "Tambo";
$areanames{en}->{61745633} = "Thallon";
$areanames{en}->{61745634} = "Thallon";
$areanames{en}->{61745635} = "Thargomindah";
$areanames{en}->{61745636} = "Thargomindah";
$areanames{en}->{61745637} = "Arcadia\ Valley";
$areanames{en}->{61745638} = "Arcadia\ Valley";
$areanames{en}->{61745639} = "Tambo";
$areanames{en}->{61745640} = "Tambo";
$areanames{en}->{61745641} = "Tambo";
$areanames{en}->{61745642} = "Haddon";
$areanames{en}->{61745643} = "Cunnamulla";
$areanames{en}->{61745644} = "Paroo";
$areanames{en}->{61745645} = "Quilpie";
$areanames{en}->{61745646} = "Warrego";
$areanames{en}->{61745647} = "Dalby";
$areanames{en}->{61745648} = "Toowoomba";
$areanames{en}->{61745649} = "Toowoomba";
$areanames{en}->{61745650} = "Westmar";
$areanames{en}->{61745651} = "Westmar";
$areanames{en}->{61745652} = "Meandarra";
$areanames{en}->{61745653} = "Moonie";
$areanames{en}->{61745654} = "Jandowae";
$areanames{en}->{61745655} = "Warra";
$areanames{en}->{61745656} = "Bowenville";
$areanames{en}->{61745657} = "Glenhope";
$areanames{en}->{61745658} = "Goombi";
$areanames{en}->{61745659} = "Jimbour";
$areanames{en}->{61745660} = "Toowoomba";
$areanames{en}->{61745661} = "Toowoomba";
$areanames{en}->{61745662} = "Toowoomba";
$areanames{en}->{61745663} = "Miles";
$areanames{en}->{61745664} = "Miles";
$areanames{en}->{61745665} = "Miles";
$areanames{en}->{61745666} = "Miles";
$areanames{en}->{61745667} = "Goombungee";
$areanames{en}->{61745668} = "Goombungee";
$areanames{en}->{61745669} = "Goombungee";
$areanames{en}->{61745670} = "Kupunn";
$areanames{en}->{61745671} = "The\ Gums";
$areanames{en}->{61745672} = "Coondarra";
$areanames{en}->{61745673} = "Darr\ Creek";
$areanames{en}->{61745674} = "Dunmore";
$areanames{en}->{61745675} = "Southwood";
$areanames{en}->{61745676} = "Brigalow";
$areanames{en}->{61745677} = "Cecil\ Plains";
$areanames{en}->{61745678} = "Kumbarilla";
$areanames{en}->{61745679} = "Bunya\ Mountains";
$areanames{en}->{61745680} = "Isisford";
$areanames{en}->{61745681} = "Isisford";
$areanames{en}->{61745682} = "Muttaburra";
$areanames{en}->{61745683} = "Galilee";
$areanames{en}->{61745684} = "Aramac";
$areanames{en}->{61745685} = "Jundah";
$areanames{en}->{61745686} = "Jericho";
$areanames{en}->{61745687} = "Barcoo";
$areanames{en}->{61745688} = "Diamantina";
$areanames{en}->{61745689} = "Longreach";
$areanames{en}->{61745690} = "Blackall";
$areanames{en}->{61745691} = "Blackall";
$areanames{en}->{61745692} = "Jundah";
$areanames{en}->{61745693} = "Cecil\ Plains";
$areanames{en}->{61745694} = "Pittsworth";
$areanames{en}->{61745695} = "Wallumbilla";
$areanames{en}->{61745696} = "Toowoomba";
$areanames{en}->{61745697} = "Longreach";
$areanames{en}->{61745698} = "Longreach";
$areanames{en}->{61745699} = "Galilee";
$areanames{en}->{61745700} = "Chinchilla";
$areanames{en}->{61745701} = "Roma";
$areanames{en}->{61745702} = "Chinchilla";
$areanames{en}->{61745703} = "Chinchilla";
$areanames{en}->{61745704} = "Dalby";
$areanames{en}->{61745705} = "St\ George";
$areanames{en}->{61745706} = "Longreach";
$areanames{en}->{61745707} = "St\ George";
$areanames{en}->{61745708} = "Yuleba";
$areanames{en}->{61745709} = "St\ George";
$areanames{en}->{61745710} = "Clifton";
$areanames{en}->{61745711} = "Greenmount";
$areanames{en}->{61745712} = "Toowoomba";
$areanames{en}->{61745713} = "Toowoomba";
$areanames{en}->{61745714} = "Toowoomba";
$areanames{en}->{61745715} = "Helidon";
$areanames{en}->{61745716} = "Millmerran";
$areanames{en}->{61745717} = "Toowoomba";
$areanames{en}->{61745718} = "Oakey";
$areanames{en}->{61745719} = "Brookstead";
$areanames{en}->{61745720} = "Ballandean";
$areanames{en}->{61745721} = "Stanthorpe";
$areanames{en}->{61745722} = "Tabers";
$areanames{en}->{61745723} = "Toowoomba";
$areanames{en}->{61745724} = "Westgrove";
$areanames{en}->{61745725} = "Westgrove";
$areanames{en}->{61745726} = "Roma";
$areanames{en}->{61745727} = "Surat";
$areanames{en}->{61745728} = "Wallumbilla";
$areanames{en}->{61745729} = "Yuleba";
$areanames{en}->{61745730} = "Allora";
$areanames{en}->{61745731} = "Roma";
$areanames{en}->{61745732} = "Meandarra";
$areanames{en}->{61745733} = "Jandowae";
$areanames{en}->{61745734} = "Toowoomba";
$areanames{en}->{61745735} = "Charleville";
$areanames{en}->{61745736} = "Chinchilla";
$areanames{en}->{61745737} = "Dalby";
$areanames{en}->{61745738} = "Goondiwindi";
$areanames{en}->{61745739} = "Chinchilla";
$areanames{en}->{61745740} = "Inglewood";
$areanames{en}->{61745741} = "Barcaldine";
$areanames{en}->{61745742} = "Longreach";
$areanames{en}->{61745743} = "Roma";
$areanames{en}->{61745744} = "Warwick";
$areanames{en}->{61745745} = "Toowoomba";
$areanames{en}->{61745746} = "Tipton";
$areanames{en}->{61745747} = "Atholwood";
$areanames{en}->{61745748} = "Auburn";
$areanames{en}->{61745749} = "Augathella";
$areanames{en}->{61745750} = "Ballandean";
$areanames{en}->{61745751} = "Barcaldine";
$areanames{en}->{61745752} = "Barcoo";
$areanames{en}->{61745753} = "Bell";
$areanames{en}->{61745754} = "Billa\ Billa";
$areanames{en}->{61745755} = "Bimbadeen";
$areanames{en}->{61745756} = "Bollon";
$areanames{en}->{61745757} = "Brigalow";
$areanames{en}->{61745758} = "Bringalily";
$areanames{en}->{61745759} = "Brymaroo";
$areanames{en}->{61745760} = "Cambooya";
$areanames{en}->{61745761} = "Cecil\ Plains";
$areanames{en}->{61745762} = "Cockatoo";
$areanames{en}->{61745763} = "Condamine";
$areanames{en}->{61745764} = "Coondarra";
$areanames{en}->{61745765} = "Cottonvale";
$areanames{en}->{61745766} = "Crows\ Nest";
$areanames{en}->{61745767} = "Culgoa";
$areanames{en}->{61745768} = "Cunningham";
$areanames{en}->{61745769} = "Diamantina";
$areanames{en}->{61745770} = "Diamondy";
$areanames{en}->{61745771} = "Dirranbandi";
$areanames{en}->{61745772} = "Dulacca";
$areanames{en}->{61745773} = "Dunmore";
$areanames{en}->{61745774} = "Elbow\ Valley";
$areanames{en}->{61745775} = "Eschol";
$areanames{en}->{61745776} = "Freestone";
$areanames{en}->{61745777} = "Oakey";
$areanames{en}->{61745778} = "Oakey";
$areanames{en}->{61745779} = "Oakey";
$areanames{en}->{61745780} = "Roma";
$areanames{en}->{61745781} = "Arcadia\ Valley";
$areanames{en}->{61745782} = "Goondiwindi";
$areanames{en}->{61745783} = "Roma";
$areanames{en}->{61745784} = "Roma";
$areanames{en}->{61745785} = "Roma";
$areanames{en}->{61745786} = "Wallumbilla";
$areanames{en}->{61745787} = "Wallumbilla";
$areanames{en}->{61745788} = "Roma";
$areanames{en}->{61745789} = "Glenhope";
$areanames{en}->{61745790} = "Goombungee";
$areanames{en}->{61745791} = "Wandoan";
$areanames{en}->{61745792} = "Wandoan";
$areanames{en}->{61745793} = "Greenmount";
$areanames{en}->{61745794} = "Guluguba";
$areanames{en}->{61745795} = "Durham\ Downs";
$areanames{en}->{61745796} = "Durham\ Downs";
$areanames{en}->{61745797} = "Allora";
$areanames{en}->{61745798} = "Wallumbilla";
$areanames{en}->{61745799} = "Wallumbilla";
$areanames{en}->{61745800} = "Toowoomba";
$areanames{en}->{61745801} = "Toowoomba";
$areanames{en}->{61745802} = "Toowoomba";
$areanames{en}->{61745803} = "Toowoomba";
$areanames{en}->{61745804} = "Toowoomba";
$areanames{en}->{61745805} = "Haden";
$areanames{en}->{61745806} = "Helidon";
$areanames{en}->{61745807} = "Isisford";
$areanames{en}->{61745808} = "Jandowae";
$areanames{en}->{61745809} = "Jericho";
$areanames{en}->{61745810} = "Jimbour";
$areanames{en}->{61745811} = "Jondaryan";
$areanames{en}->{61745812} = "Jundah";
$areanames{en}->{61745813} = "Kilbeggan";
$areanames{en}->{61745814} = "Killarney";
$areanames{en}->{61745815} = "Kumbarilla";
$areanames{en}->{61745816} = "Kupunn";
$areanames{en}->{61745817} = "Legume";
$areanames{en}->{61745818} = "Leyburn";
$areanames{en}->{61745819} = "Liston";
$areanames{en}->{61745820} = "Lynd\ Range";
$areanames{en}->{61745821} = "Maranoa";
$areanames{en}->{61745822} = "Meandarra";
$areanames{en}->{61745823} = "Miles";
$areanames{en}->{61745824} = "Millmerran";
$areanames{en}->{61745825} = "Moonie";
$areanames{en}->{61745826} = "Morven";
$areanames{en}->{61745827} = "Mount\ Tyson";
$areanames{en}->{61745828} = "Muttaburra";
$areanames{en}->{61745829} = "Nobby";
$areanames{en}->{61745830} = "North\ Star";
$areanames{en}->{61745831} = "Omanama";
$areanames{en}->{61745832} = "Paroo";
$areanames{en}->{61745833} = "Pikedale";
$areanames{en}->{61745834} = "Pittsworth";
$areanames{en}->{61745835} = "Quilpie";
$areanames{en}->{61745836} = "Ravensbourne";
$areanames{en}->{61745837} = "Robinson\ Gorge";
$areanames{en}->{61745838} = "Surat";
$areanames{en}->{61745839} = "Tabers";
$areanames{en}->{61745840} = "Talwood";
$areanames{en}->{61745841} = "Tambo";
$areanames{en}->{61745842} = "Teelba";
$areanames{en}->{61745843} = "Texas";
$areanames{en}->{61745844} = "Thallon";
$areanames{en}->{61745845} = "Thargomindah";
$areanames{en}->{61745846} = "The\ Gums";
$areanames{en}->{61745847} = "Thomson";
$areanames{en}->{61745848} = "Tipton";
$areanames{en}->{61745849} = "Toobeah";
$areanames{en}->{61745850} = "Wallumbilla";
$areanames{en}->{61745851} = "Warra";
$areanames{en}->{61745852} = "Warrego";
$areanames{en}->{61745853} = "Westgrove";
$areanames{en}->{61745854} = "Westmar";
$areanames{en}->{61745855} = "Wyaga";
$areanames{en}->{61745856} = "Yelarbon";
$areanames{en}->{61745857} = "Yetman";
$areanames{en}->{61745858} = "Yuleba";
$areanames{en}->{617458590} = "Bonshaw";
$areanames{en}->{617458591} = "Bowenville";
$areanames{en}->{617458592} = "Brigalow";
$areanames{en}->{617458593} = "Bringalily";
$areanames{en}->{617458594} = "Brookstead";
$areanames{en}->{617458595} = "Brymaroo";
$areanames{en}->{617458596} = "Bunya\ Mountains";
$areanames{en}->{617458597} = "Cambooya";
$areanames{en}->{617458598} = "Cecil\ Plains";
$areanames{en}->{617458599} = "Charleville";
$areanames{en}->{617458600} = "Chinchilla";
$areanames{en}->{617458601} = "Clifton";
$areanames{en}->{617458602} = "Cockatoo";
$areanames{en}->{617458603} = "Condamine";
$areanames{en}->{617458604} = "Coondarra";
$areanames{en}->{617458605} = "Cooyar";
$areanames{en}->{617458606} = "Cottonvale";
$areanames{en}->{617458607} = "Crows\ Nest";
$areanames{en}->{617458608} = "Culgoa";
$areanames{en}->{617458609} = "Cunnamulla";
$areanames{en}->{617458610} = "Cunningham";
$areanames{en}->{617458611} = "Dalby";
$areanames{en}->{617458612} = "Darr\ Creek";
$areanames{en}->{617458613} = "Diamantina";
$areanames{en}->{617458614} = "Diamondy";
$areanames{en}->{617458615} = "Dirranbandi";
$areanames{en}->{617458616} = "Dulacca";
$areanames{en}->{617458617} = "Dunmore";
$areanames{en}->{617458618} = "Durham\ Downs";
$areanames{en}->{617458619} = "Elbow\ Valley";
$areanames{en}->{617458620} = "Eschol";
$areanames{en}->{617458621} = "Freestone";
$areanames{en}->{617458622} = "Galilee";
$areanames{en}->{617458623} = "Glenhope";
$areanames{en}->{617458624} = "Goombi";
$areanames{en}->{617458625} = "Goombungee";
$areanames{en}->{617458626} = "Goondiwindi";
$areanames{en}->{617458627} = "Greenmount";
$areanames{en}->{617458628} = "Guluguba";
$areanames{en}->{617458629} = "Haddon";
$areanames{en}->{617458630} = "Haden";
$areanames{en}->{617458631} = "Helidon";
$areanames{en}->{617458632} = "Inglewood";
$areanames{en}->{617458633} = "Injune";
$areanames{en}->{617458634} = "Isisford";
$areanames{en}->{617458635} = "Jandowae";
$areanames{en}->{617458636} = "Jericho";
$areanames{en}->{617458637} = "Jimbour";
$areanames{en}->{617458638} = "Jondaryan";
$areanames{en}->{617458639} = "Jundah";
$areanames{en}->{617458640} = "Kilbeggan";
$areanames{en}->{617458641} = "Killarney";
$areanames{en}->{617458642} = "Kumbarilla";
$areanames{en}->{617458643} = "Kupunn";
$areanames{en}->{617458644} = "Legume";
$areanames{en}->{617458645} = "Leyburn";
$areanames{en}->{617458646} = "Liston";
$areanames{en}->{617458647} = "Longreach";
$areanames{en}->{617458648} = "Lynd\ Range";
$areanames{en}->{617458649} = "Macalister";
$areanames{en}->{617458650} = "Maranoa";
$areanames{en}->{617458651} = "Meandarra";
$areanames{en}->{617458652} = "Miamba";
$areanames{en}->{617458653} = "Miles";
$areanames{en}->{617458654} = "Millmerran";
$areanames{en}->{617458655} = "Mitchell";
$areanames{en}->{617458656} = "Moonie";
$areanames{en}->{617458657} = "Morven";
$areanames{en}->{617458658} = "Mount\ Tyson";
$areanames{en}->{617458659} = "Muttaburra";
$areanames{en}->{617458660} = "Nobby";
$areanames{en}->{617458661} = "North\ Star";
$areanames{en}->{617458662} = "Oakey";
$areanames{en}->{617458663} = "Omanama";
$areanames{en}->{617458664} = "Paroo";
$areanames{en}->{617458665} = "Pikedale";
$areanames{en}->{617458666} = "Pittsworth";
$areanames{en}->{617458667} = "Quilpie";
$areanames{en}->{617458668} = "Ravensbourne";
$areanames{en}->{617458669} = "Robinson\ Gorge";
$areanames{en}->{617458670} = "Roma";
$areanames{en}->{617458671} = "Southwood";
$areanames{en}->{617458672} = "St\ George";
$areanames{en}->{617458673} = "Stanthorpe";
$areanames{en}->{617458674} = "Surat";
$areanames{en}->{617458675} = "Tabers";
$areanames{en}->{617458676} = "Talwood";
$areanames{en}->{617458677} = "Tambo";
$areanames{en}->{617458678} = "Tara";
$areanames{en}->{617458679} = "Taroom";
$areanames{en}->{617458680} = "Teelba";
$areanames{en}->{617458681} = "Texas";
$areanames{en}->{617458682} = "Thallon";
$areanames{en}->{617458683} = "Thargomindah";
$areanames{en}->{617458684} = "The\ Gums";
$areanames{en}->{617458685} = "Thomson";
$areanames{en}->{617458686} = "Tipton";
$areanames{en}->{617458687} = "Toobeah";
$areanames{en}->{617458688} = "Toowoomba";
$areanames{en}->{617458689} = "Valley\ Downs";
$areanames{en}->{617458690} = "Wallumbilla";
$areanames{en}->{617458691} = "Wandoan";
$areanames{en}->{617458692} = "Warra";
$areanames{en}->{617458693} = "Warrego";
$areanames{en}->{617458694} = "Warwick";
$areanames{en}->{617458695} = "Westgrove";
$areanames{en}->{617458696} = "Westmar";
$areanames{en}->{617458697} = "Winton";
$areanames{en}->{617458698} = "Wyaga";
$areanames{en}->{617458699} = "Yelarbon";
$areanames{en}->{617458700} = "Yetman";
$areanames{en}->{617458701} = "Yuleba";
$areanames{en}->{617458702} = "Allora";
$areanames{en}->{617458703} = "Aramac";
$areanames{en}->{617458704} = "Arcadia\ Valley";
$areanames{en}->{617458705} = "Atholwood";
$areanames{en}->{617458706} = "Auburn";
$areanames{en}->{617458707} = "Augathella";
$areanames{en}->{617458708} = "Ballandean";
$areanames{en}->{617458709} = "Balonne";
$areanames{en}->{61745871} = "Goondiwindi";
$areanames{en}->{61745872} = "Goondiwindi";
$areanames{en}->{61745873} = "Goondiwindi";
$areanames{en}->{61745874} = "Goondiwindi";
$areanames{en}->{61745875} = "Goondiwindi";
$areanames{en}->{617458760} = "Barcaldine";
$areanames{en}->{617458761} = "Barcoo";
$areanames{en}->{617458762} = "Beebo";
$areanames{en}->{617458763} = "Bell";
$areanames{en}->{617458764} = "Billa\ Billa";
$areanames{en}->{617458765} = "Bimbadeen";
$areanames{en}->{617458766} = "Blackall";
$areanames{en}->{617458767} = "Bollon";
$areanames{en}->{617458768} = "Bonshaw";
$areanames{en}->{617458769} = "Bowenville";
$areanames{en}->{617458770} = "Brigalow";
$areanames{en}->{617458771} = "Bringalily";
$areanames{en}->{617458772} = "Brookstead";
$areanames{en}->{617458773} = "Brymaroo";
$areanames{en}->{617458774} = "Bunya\ Mountains";
$areanames{en}->{617458775} = "Cambooya";
$areanames{en}->{617458776} = "Cecil\ Plains";
$areanames{en}->{617458777} = "Charleville";
$areanames{en}->{617458778} = "Chinchilla";
$areanames{en}->{617458779} = "Clifton";
$areanames{en}->{617458780} = "Cockatoo";
$areanames{en}->{617458781} = "Condamine";
$areanames{en}->{617458782} = "Coondarra";
$areanames{en}->{617458783} = "Cooyar";
$areanames{en}->{617458784} = "Cottonvale";
$areanames{en}->{617458785} = "Crows\ Nest";
$areanames{en}->{617458786} = "Culgoa";
$areanames{en}->{617458787} = "Cunnamulla";
$areanames{en}->{617458788} = "Cunningham";
$areanames{en}->{617458789} = "Dalby";
$areanames{en}->{617458790} = "Darr\ Creek";
$areanames{en}->{617458791} = "Diamantina";
$areanames{en}->{617458792} = "Diamondy";
$areanames{en}->{617458793} = "Dirranbandi";
$areanames{en}->{617458794} = "Dulacca";
$areanames{en}->{617458795} = "Dunmore";
$areanames{en}->{617458796} = "Durham\ Downs";
$areanames{en}->{617458797} = "Elbow\ Valley";
$areanames{en}->{617458798} = "Eschol";
$areanames{en}->{617458799} = "Freestone";
$areanames{en}->{6174588} = "Toowoomba";
$areanames{en}->{617458800} = "Galilee";
$areanames{en}->{617458801} = "Glenhope";
$areanames{en}->{617458802} = "Goombi";
$areanames{en}->{617458803} = "Goombungee";
$areanames{en}->{617458804} = "Goondiwindi";
$areanames{en}->{617458805} = "Greenmount";
$areanames{en}->{617458806} = "Guluguba";
$areanames{en}->{617458807} = "Haddon";
$areanames{en}->{617458808} = "Haden";
$areanames{en}->{617458809} = "Helidon";
$areanames{en}->{617458810} = "Inglewood";
$areanames{en}->{617458811} = "Injune";
$areanames{en}->{617458812} = "Isisford";
$areanames{en}->{617458813} = "Jandowae";
$areanames{en}->{617458814} = "Jericho";
$areanames{en}->{617458815} = "Jimbour";
$areanames{en}->{617458816} = "Jondaryan";
$areanames{en}->{617458817} = "Jundah";
$areanames{en}->{617458818} = "Kilbeggan";
$areanames{en}->{617458819} = "Killarney";
$areanames{en}->{617458820} = "Kumbarilla";
$areanames{en}->{617458821} = "Kupunn";
$areanames{en}->{617458822} = "Legume";
$areanames{en}->{617458823} = "Leyburn";
$areanames{en}->{617458824} = "Liston";
$areanames{en}->{617458825} = "Longreach";
$areanames{en}->{617458826} = "Lynd\ Range";
$areanames{en}->{617458827} = "Macalister";
$areanames{en}->{617458828} = "Maranoa";
$areanames{en}->{617458829} = "Meandarra";
$areanames{en}->{617458830} = "Miamba";
$areanames{en}->{617458831} = "Miles";
$areanames{en}->{617458832} = "Millmerran";
$areanames{en}->{617458833} = "Mitchell";
$areanames{en}->{617458834} = "Moonie";
$areanames{en}->{617458835} = "Morven";
$areanames{en}->{617458836} = "Mount\ Tyson";
$areanames{en}->{617458837} = "Muttaburra";
$areanames{en}->{617458838} = "Nobby";
$areanames{en}->{617458839} = "North\ Star";
$areanames{en}->{61745890} = "Toowoomba";
$areanames{en}->{61745891} = "Toowoomba";
$areanames{en}->{617458920} = "Oakey";
$areanames{en}->{617458921} = "Omanama";
$areanames{en}->{617458922} = "Paroo";
$areanames{en}->{617458923} = "Pikedale";
$areanames{en}->{617458924} = "Pittsworth";
$areanames{en}->{617458925} = "Quilpie";
$areanames{en}->{617458926} = "Ravensbourne";
$areanames{en}->{617458927} = "Robinson\ Gorge";
$areanames{en}->{617458928} = "Roma";
$areanames{en}->{617458929} = "Southwood";
$areanames{en}->{617458930} = "St\ George";
$areanames{en}->{617458931} = "Stanthorpe";
$areanames{en}->{617458932} = "Surat";
$areanames{en}->{617458933} = "Tabers";
$areanames{en}->{617458934} = "Talwood";
$areanames{en}->{617458935} = "Tambo";
$areanames{en}->{617458936} = "Tara";
$areanames{en}->{617458937} = "Taroom";
$areanames{en}->{617458938} = "Teelba";
$areanames{en}->{617458939} = "Texas";
$areanames{en}->{617458940} = "Thallon";
$areanames{en}->{617458941} = "Thargomindah";
$areanames{en}->{617458942} = "The\ Gums";
$areanames{en}->{617458943} = "Thomson";
$areanames{en}->{617458944} = "Tipton";
$areanames{en}->{617458945} = "Toobeah";
$areanames{en}->{617458946} = "Toowoomba";
$areanames{en}->{617458947} = "Valley\ Downs";
$areanames{en}->{617458948} = "Wallumbilla";
$areanames{en}->{617458949} = "Wandoan";
$areanames{en}->{617458950} = "Warra";
$areanames{en}->{617458951} = "Warrego";
$areanames{en}->{617458952} = "Warwick";
$areanames{en}->{617458953} = "Westgrove";
$areanames{en}->{617458954} = "Westmar";
$areanames{en}->{617458955} = "Winton";
$areanames{en}->{617458956} = "Wyaga";
$areanames{en}->{617458957} = "Yelarbon";
$areanames{en}->{617458958} = "Allora";
$areanames{en}->{617458959} = "Aramac";
$areanames{en}->{617458960} = "Arcadia\ Valley";
$areanames{en}->{617458961} = "Atholwood";
$areanames{en}->{617458962} = "Auburn";
$areanames{en}->{617458963} = "Augathella";
$areanames{en}->{617458964} = "Ballandean";
$areanames{en}->{617458965} = "Balonne";
$areanames{en}->{617458966} = "Barcaldine";
$areanames{en}->{617458967} = "Barcoo";
$areanames{en}->{617458968} = "Beebo";
$areanames{en}->{617458969} = "Bell";
$areanames{en}->{617458970} = "Billa\ Billa";
$areanames{en}->{617458971} = "Bimbadeen";
$areanames{en}->{617458972} = "Blackall";
$areanames{en}->{617458973} = "Bollon";
$areanames{en}->{617458974} = "Bonshaw";
$areanames{en}->{617458975} = "Bowenville";
$areanames{en}->{617458976} = "Brigalow";
$areanames{en}->{617458977} = "Bringalily";
$areanames{en}->{617458978} = "Brookstead";
$areanames{en}->{617458979} = "Brymaroo";
$areanames{en}->{617458980} = "Bunya\ Mountains";
$areanames{en}->{617458981} = "Cambooya";
$areanames{en}->{617458982} = "Cecil\ Plains";
$areanames{en}->{617458983} = "Charleville";
$areanames{en}->{617458984} = "Chinchilla";
$areanames{en}->{617458985} = "Clifton";
$areanames{en}->{617458986} = "Cockatoo";
$areanames{en}->{617458987} = "Condamine";
$areanames{en}->{617458988} = "Coondarra";
$areanames{en}->{617458989} = "Cooyar";
$areanames{en}->{617458990} = "Cottonvale";
$areanames{en}->{617458991} = "Crows\ Nest";
$areanames{en}->{617458992} = "Culgoa";
$areanames{en}->{617458993} = "Cunnamulla";
$areanames{en}->{617458994} = "Cunningham";
$areanames{en}->{617458995} = "Dalby";
$areanames{en}->{617458996} = "Darr\ Creek";
$areanames{en}->{617458997} = "Diamantina";
$areanames{en}->{617458998} = "Diamondy";
$areanames{en}->{617458999} = "Dirranbandi";
$areanames{en}->{617459000} = "Dulacca";
$areanames{en}->{617459001} = "Dunmore";
$areanames{en}->{617459002} = "Durham\ Downs";
$areanames{en}->{617459003} = "Elbow\ Valley";
$areanames{en}->{617459004} = "Eschol";
$areanames{en}->{617459005} = "Freestone";
$areanames{en}->{617459006} = "Galilee";
$areanames{en}->{617459007} = "Glenhope";
$areanames{en}->{617459008} = "Goombi";
$areanames{en}->{617459009} = "Goombungee";
$areanames{en}->{617459010} = "Goondiwindi";
$areanames{en}->{617459011} = "Greenmount";
$areanames{en}->{617459012} = "Guluguba";
$areanames{en}->{617459013} = "Haddon";
$areanames{en}->{617459014} = "Haden";
$areanames{en}->{617459015} = "Helidon";
$areanames{en}->{617459016} = "Inglewood";
$areanames{en}->{617459017} = "Injune";
$areanames{en}->{617459018} = "Isisford";
$areanames{en}->{617459019} = "Jandowae";
$areanames{en}->{617459020} = "Jericho";
$areanames{en}->{617459021} = "Jimbour";
$areanames{en}->{617459022} = "Jondaryan";
$areanames{en}->{617459023} = "Jundah";
$areanames{en}->{617459024} = "Kilbeggan";
$areanames{en}->{617459025} = "Killarney";
$areanames{en}->{617459026} = "Kumbarilla";
$areanames{en}->{617459027} = "Kupunn";
$areanames{en}->{617459028} = "Legume";
$areanames{en}->{617459029} = "Leyburn";
$areanames{en}->{617459030} = "Liston";
$areanames{en}->{617459031} = "Longreach";
$areanames{en}->{617459032} = "Lynd\ Range";
$areanames{en}->{617459033} = "Macalister";
$areanames{en}->{617459034} = "Maranoa";
$areanames{en}->{617459035} = "Meandarra";
$areanames{en}->{617459036} = "Miamba";
$areanames{en}->{617459037} = "Miles";
$areanames{en}->{617459038} = "Millmerran";
$areanames{en}->{617459039} = "Mitchell";
$areanames{en}->{617459040} = "Moonie";
$areanames{en}->{617459041} = "Morven";
$areanames{en}->{617459042} = "Mount\ Tyson";
$areanames{en}->{617459043} = "Muttaburra";
$areanames{en}->{617459044} = "Nobby";
$areanames{en}->{617459045} = "North\ Star";
$areanames{en}->{617459046} = "Oakey";
$areanames{en}->{617459047} = "Omanama";
$areanames{en}->{617459048} = "Paroo";
$areanames{en}->{617459049} = "Pikedale";
$areanames{en}->{617459050} = "Pittsworth";
$areanames{en}->{617459051} = "Quilpie";
$areanames{en}->{617459052} = "Ravensbourne";
$areanames{en}->{617459053} = "Robinson\ Gorge";
$areanames{en}->{617459054} = "Roma";
$areanames{en}->{617459055} = "Southwood";
$areanames{en}->{617459056} = "St\ George";
$areanames{en}->{617459057} = "Stanthorpe";
$areanames{en}->{617459058} = "Surat";
$areanames{en}->{617459059} = "Tabers";
$areanames{en}->{617459060} = "Talwood";
$areanames{en}->{617459061} = "Tambo";
$areanames{en}->{617459062} = "Tara";
$areanames{en}->{617459063} = "Taroom";
$areanames{en}->{617459064} = "Teelba";
$areanames{en}->{617459065} = "Texas";
$areanames{en}->{617459066} = "Thallon";
$areanames{en}->{617459067} = "Thargomindah";
$areanames{en}->{617459068} = "The\ Gums";
$areanames{en}->{617459069} = "Thomson";
$areanames{en}->{617459070} = "Tipton";
$areanames{en}->{617459071} = "Toobeah";
$areanames{en}->{617459072} = "Toowoomba";
$areanames{en}->{617459073} = "Valley\ Downs";
$areanames{en}->{617459074} = "Wallumbilla";
$areanames{en}->{617459075} = "Wandoan";
$areanames{en}->{617459076} = "Warra";
$areanames{en}->{617459077} = "Warrego";
$areanames{en}->{617459078} = "Warwick";
$areanames{en}->{617459079} = "Westgrove";
$areanames{en}->{617459080} = "Westmar";
$areanames{en}->{617459081} = "Winton";
$areanames{en}->{617459082} = "Wyaga";
$areanames{en}->{617459083} = "Yelarbon";
$areanames{en}->{617459084} = "Yetman";
$areanames{en}->{617459085} = "Yuleba";
$areanames{en}->{617459086} = "Yetman";
$areanames{en}->{617459087} = "Yuleba";
$areanames{en}->{617459088} = "Allora";
$areanames{en}->{617459089} = "Aramac";
$areanames{en}->{61745909} = "Warwick";
$areanames{en}->{6174591} = "Toowoomba";
$areanames{en}->{6174592} = "Toowoomba";
$areanames{en}->{61745920} = "Roma";
$areanames{en}->{61745921} = "Roma";
$areanames{en}->{61745922} = "Goombungee";
$areanames{en}->{61745930} = "Toowoomba";
$areanames{en}->{617459310} = "Arcadia\ Valley";
$areanames{en}->{617459311} = "Atholwood";
$areanames{en}->{617459312} = "Auburn";
$areanames{en}->{617459313} = "Augathella";
$areanames{en}->{617459314} = "Ballandean";
$areanames{en}->{617459315} = "Balonne";
$areanames{en}->{617459316} = "Barcaldine";
$areanames{en}->{617459317} = "Barcoo";
$areanames{en}->{617459318} = "Beebo";
$areanames{en}->{617459319} = "Bell";
$areanames{en}->{61745932} = "Charleville";
$areanames{en}->{61745933} = "Dalby";
$areanames{en}->{61745934} = "Kupunn";
$areanames{en}->{61745935} = "Chinchilla";
$areanames{en}->{61745936} = "Dalby";
$areanames{en}->{61745937} = "Dalby";
$areanames{en}->{61745938} = "Dalby";
$areanames{en}->{61745939} = "Dalby";
$areanames{en}->{617459400} = "Billa\ Billa";
$areanames{en}->{617459401} = "Bimbadeen";
$areanames{en}->{617459402} = "Blackall";
$areanames{en}->{617459403} = "Bollon";
$areanames{en}->{617459404} = "Bonshaw";
$areanames{en}->{617459405} = "Bowenville";
$areanames{en}->{617459406} = "Brigalow";
$areanames{en}->{617459407} = "Bringalily";
$areanames{en}->{617459408} = "Brookstead";
$areanames{en}->{617459409} = "Brymaroo";
$areanames{en}->{617459410} = "Bunya\ Mountains";
$areanames{en}->{617459411} = "Cambooya";
$areanames{en}->{617459412} = "Cecil\ Plains";
$areanames{en}->{617459413} = "Charleville";
$areanames{en}->{617459414} = "Chinchilla";
$areanames{en}->{617459415} = "Clifton";
$areanames{en}->{617459416} = "Cockatoo";
$areanames{en}->{617459417} = "Condamine";
$areanames{en}->{617459418} = "Coondarra";
$areanames{en}->{617459419} = "Cooyar";
$areanames{en}->{61745942} = "Roma";
$areanames{en}->{61745943} = "Wandoan";
$areanames{en}->{61745944} = "Moonie";
$areanames{en}->{61745945} = "Dalby";
$areanames{en}->{61745946} = "Dalby";
$areanames{en}->{61745947} = "Dalby";
$areanames{en}->{61745948} = "Dalby";
$areanames{en}->{61745949} = "Dalby";
$areanames{en}->{617459500} = "Cottonvale";
$areanames{en}->{617459501} = "Crows\ Nest";
$areanames{en}->{617459502} = "Culgoa";
$areanames{en}->{617459503} = "Cunnamulla";
$areanames{en}->{617459504} = "Cunningham";
$areanames{en}->{617459505} = "Dalby";
$areanames{en}->{617459506} = "Darr\ Creek";
$areanames{en}->{617459507} = "Diamantina";
$areanames{en}->{617459508} = "Diamondy";
$areanames{en}->{617459509} = "Dirranbandi";
$areanames{en}->{61745951} = "Toowoomba";
$areanames{en}->{61745952} = "Toowoomba";
$areanames{en}->{61745953} = "Roma";
$areanames{en}->{61745954} = "Roma";
$areanames{en}->{61745955} = "Roma";
$areanames{en}->{61745956} = "Kupunn";
$areanames{en}->{61745957} = "Kupunn";
$areanames{en}->{61745958} = "Kupunn";
$areanames{en}->{61745959} = "Roma";
$areanames{en}->{61745960} = "Cambooya";
$areanames{en}->{61745961} = "Toowoomba";
$areanames{en}->{61745962} = "Goombungee";
$areanames{en}->{61745963} = "Goombungee";
$areanames{en}->{61745964} = "Goombungee";
$areanames{en}->{61745965} = "Aramac";
$areanames{en}->{61745966} = "Toowoomba";
$areanames{en}->{61745967} = "Tara";
$areanames{en}->{61745968} = "Dalby";
$areanames{en}->{61745969} = "Dalby";
$areanames{en}->{6174597} = "Toowoomba";
$areanames{en}->{61745980} = "Toowoomba";
$areanames{en}->{61745981} = "Toowoomba";
$areanames{en}->{61745982} = "Warwick";
$areanames{en}->{61745983} = "Warwick";
$areanames{en}->{617459840} = "Dulacca";
$areanames{en}->{617459841} = "Dunmore";
$areanames{en}->{617459842} = "Durham\ Downs";
$areanames{en}->{617459843} = "Elbow\ Valley";
$areanames{en}->{617459844} = "Eschol";
$areanames{en}->{617459845} = "Freestone";
$areanames{en}->{617459846} = "Galilee";
$areanames{en}->{617459847} = "Glenhope";
$areanames{en}->{617459848} = "Goombi";
$areanames{en}->{617459849} = "Goombungee";
$areanames{en}->{617459850} = "Goondiwindi";
$areanames{en}->{617459851} = "Greenmount";
$areanames{en}->{617459852} = "Guluguba";
$areanames{en}->{617459853} = "Haddon";
$areanames{en}->{617459854} = "Haden";
$areanames{en}->{617459855} = "Helidon";
$areanames{en}->{617459856} = "Inglewood";
$areanames{en}->{617459857} = "Injune";
$areanames{en}->{617459858} = "Isisford";
$areanames{en}->{617459859} = "Jandowae";
$areanames{en}->{617459860} = "Jericho";
$areanames{en}->{617459861} = "Jimbour";
$areanames{en}->{617459862} = "Jondaryan";
$areanames{en}->{617459863} = "Jundah";
$areanames{en}->{617459864} = "Kilbeggan";
$areanames{en}->{617459865} = "Killarney";
$areanames{en}->{617459866} = "Kumbarilla";
$areanames{en}->{617459867} = "Kupunn";
$areanames{en}->{617459868} = "Legume";
$areanames{en}->{617459869} = "Leyburn";
$areanames{en}->{617459870} = "Liston";
$areanames{en}->{617459871} = "Longreach";
$areanames{en}->{617459872} = "Lynd\ Range";
$areanames{en}->{617459873} = "Macalister";
$areanames{en}->{617459874} = "Maranoa";
$areanames{en}->{617459875} = "Meandarra";
$areanames{en}->{617459876} = "Miamba";
$areanames{en}->{617459877} = "Miles";
$areanames{en}->{617459878} = "Millmerran";
$areanames{en}->{617459879} = "Mitchell";
$areanames{en}->{617459880} = "Moonie";
$areanames{en}->{617459881} = "Morven";
$areanames{en}->{617459882} = "Mount\ Tyson";
$areanames{en}->{617459883} = "Muttaburra";
$areanames{en}->{617459884} = "Nobby";
$areanames{en}->{617459885} = "North\ Star";
$areanames{en}->{617459886} = "Oakey";
$areanames{en}->{617459887} = "Omanama";
$areanames{en}->{617459888} = "Paroo";
$areanames{en}->{617459889} = "Pikedale";
$areanames{en}->{617459890} = "Pittsworth";
$areanames{en}->{617459891} = "Quilpie";
$areanames{en}->{617459892} = "Ravensbourne";
$areanames{en}->{617459893} = "Robinson\ Gorge";
$areanames{en}->{617459894} = "Roma";
$areanames{en}->{617459895} = "Southwood";
$areanames{en}->{617459896} = "St\ George";
$areanames{en}->{617459897} = "Stanthorpe";
$areanames{en}->{617459898} = "Surat";
$areanames{en}->{617459899} = "Tabers";
$areanames{en}->{617459900} = "Talwood";
$areanames{en}->{617459901} = "Tambo";
$areanames{en}->{617459902} = "Tara";
$areanames{en}->{617459903} = "Taroom";
$areanames{en}->{617459904} = "Teelba";
$areanames{en}->{617459905} = "Texas";
$areanames{en}->{617459906} = "Thallon";
$areanames{en}->{617459907} = "Thargomindah";
$areanames{en}->{617459908} = "The\ Gums";
$areanames{en}->{617459909} = "Thomson";
$areanames{en}->{617459910} = "Tipton";
$areanames{en}->{617459911} = "Toobeah";
$areanames{en}->{617459912} = "Toowoomba";
$areanames{en}->{617459913} = "Valley\ Downs";
$areanames{en}->{617459914} = "Wallumbilla";
$areanames{en}->{617459915} = "Wandoan";
$areanames{en}->{617459916} = "Warra";
$areanames{en}->{617459917} = "Warrego";
$areanames{en}->{617459918} = "Warwick";
$areanames{en}->{617459919} = "Westgrove";
$areanames{en}->{617459920} = "Westmar";
$areanames{en}->{617459921} = "Winton";
$areanames{en}->{617459922} = "Wyaga";
$areanames{en}->{617459923} = "Yelarbon";
$areanames{en}->{617459924} = "Yetman";
$areanames{en}->{617459925} = "Yuleba";
$areanames{en}->{617459926} = "Allora";
$areanames{en}->{617459927} = "Aramac";
$areanames{en}->{617459928} = "Arcadia\ Valley";
$areanames{en}->{617459929} = "Atholwood";
$areanames{en}->{617459930} = "Auburn";
$areanames{en}->{617459931} = "Augathella";
$areanames{en}->{617459932} = "Ballandean";
$areanames{en}->{617459933} = "Balonne";
$areanames{en}->{617459934} = "Barcaldine";
$areanames{en}->{617459935} = "Barcoo";
$areanames{en}->{617459936} = "Beebo";
$areanames{en}->{617459937} = "Bell";
$areanames{en}->{617459938} = "Billa\ Billa";
$areanames{en}->{617459939} = "Bimbadeen";
$areanames{en}->{617459940} = "Blackall";
$areanames{en}->{617459941} = "Bollon";
$areanames{en}->{617459942} = "Bonshaw";
$areanames{en}->{617459943} = "Bowenville";
$areanames{en}->{617459944} = "Brigalow";
$areanames{en}->{617459945} = "Bringalily";
$areanames{en}->{617459946} = "Brookstead";
$areanames{en}->{617459947} = "Brymaroo";
$areanames{en}->{617459948} = "Bunya\ Mountains";
$areanames{en}->{617459949} = "Cambooya";
$areanames{en}->{617459950} = "Cecil\ Plains";
$areanames{en}->{617459951} = "Charleville";
$areanames{en}->{617459952} = "Chinchilla";
$areanames{en}->{617459953} = "Clifton";
$areanames{en}->{617459954} = "Cockatoo";
$areanames{en}->{617459955} = "Condamine";
$areanames{en}->{617459956} = "Coondarra";
$areanames{en}->{617459957} = "Cooyar";
$areanames{en}->{617459958} = "Cottonvale";
$areanames{en}->{617459959} = "Crows\ Nest";
$areanames{en}->{617459960} = "Culgoa";
$areanames{en}->{617459961} = "Cunnamulla";
$areanames{en}->{617459962} = "Cunningham";
$areanames{en}->{617459963} = "Dalby";
$areanames{en}->{617459964} = "Darr\ Creek";
$areanames{en}->{617459965} = "Diamantina";
$areanames{en}->{617459966} = "Diamondy";
$areanames{en}->{617459967} = "Dirranbandi";
$areanames{en}->{617459968} = "Dulacca";
$areanames{en}->{617459969} = "Dunmore";
$areanames{en}->{617459970} = "Durham\ Downs";
$areanames{en}->{617459971} = "Elbow\ Valley";
$areanames{en}->{617459972} = "Eschol";
$areanames{en}->{617459973} = "Freestone";
$areanames{en}->{617459974} = "Galilee";
$areanames{en}->{617459975} = "Glenhope";
$areanames{en}->{617459976} = "Goombi";
$areanames{en}->{617459977} = "Goombungee";
$areanames{en}->{617459978} = "Goondiwindi";
$areanames{en}->{617459979} = "Greenmount";
$areanames{en}->{617459980} = "Guluguba";
$areanames{en}->{617459981} = "Haddon";
$areanames{en}->{617459982} = "Haden";
$areanames{en}->{617459983} = "Helidon";
$areanames{en}->{617459984} = "Inglewood";
$areanames{en}->{617459985} = "Injune";
$areanames{en}->{617459986} = "Isisford";
$areanames{en}->{617459987} = "Jandowae";
$areanames{en}->{617459988} = "Jericho";
$areanames{en}->{617459989} = "Jimbour";
$areanames{en}->{61745999} = "Toowoomba";
$areanames{en}->{6174600} = "Toowoomba";
$areanames{en}->{61746010} = "Allora";
$areanames{en}->{61746011} = "Aramac";
$areanames{en}->{61746012} = "Arcadia\ Valley";
$areanames{en}->{61746013} = "Atholwood";
$areanames{en}->{61746014} = "Auburn";
$areanames{en}->{61746015} = "Augathella";
$areanames{en}->{61746016} = "Ballandean";
$areanames{en}->{61746017} = "Balonne";
$areanames{en}->{61746018} = "Barcaldine";
$areanames{en}->{61746019} = "Barcoo";
$areanames{en}->{6174602} = "Toowoomba";
$areanames{en}->{61746030} = "Beebo";
$areanames{en}->{61746031} = "Bell";
$areanames{en}->{61746032} = "Billa\ Billa";
$areanames{en}->{61746033} = "Bimbadeen";
$areanames{en}->{61746034} = "Blackall";
$areanames{en}->{61746035} = "Bollon";
$areanames{en}->{61746036} = "Bonshaw";
$areanames{en}->{61746037} = "Bowenville";
$areanames{en}->{61746038} = "Brigalow";
$areanames{en}->{61746039} = "Bringalily";
$areanames{en}->{61746040} = "Brookstead";
$areanames{en}->{61746041} = "Brymaroo";
$areanames{en}->{61746042} = "Bunya\ Mountains";
$areanames{en}->{61746043} = "Cambooya";
$areanames{en}->{61746044} = "Cecil\ Plains";
$areanames{en}->{61746045} = "Charleville";
$areanames{en}->{61746046} = "Chinchilla";
$areanames{en}->{61746047} = "Clifton";
$areanames{en}->{61746048} = "Cockatoo";
$areanames{en}->{61746049} = "Condamine";
$areanames{en}->{61746050} = "Coondarra";
$areanames{en}->{61746051} = "Cooyar";
$areanames{en}->{61746052} = "Cottonvale";
$areanames{en}->{61746053} = "Crows\ Nest";
$areanames{en}->{61746054} = "Culgoa";
$areanames{en}->{61746055} = "Cunnamulla";
$areanames{en}->{61746056} = "Cunningham";
$areanames{en}->{61746057} = "Dalby";
$areanames{en}->{61746058} = "Darr\ Creek";
$areanames{en}->{61746059} = "Diamantina";
$areanames{en}->{61746060} = "Diamondy";
$areanames{en}->{61746061} = "Dirranbandi";
$areanames{en}->{61746062} = "Dulacca";
$areanames{en}->{61746063} = "Dunmore";
$areanames{en}->{61746064} = "Durham\ Downs";
$areanames{en}->{61746065} = "Elbow\ Valley";
$areanames{en}->{61746066} = "Eschol";
$areanames{en}->{61746067} = "Freestone";
$areanames{en}->{61746068} = "Galilee";
$areanames{en}->{61746069} = "Glenhope";
$areanames{en}->{61746070} = "Goombi";
$areanames{en}->{61746071} = "Goombungee";
$areanames{en}->{61746072} = "Goondiwindi";
$areanames{en}->{61746073} = "Greenmount";
$areanames{en}->{61746074} = "Guluguba";
$areanames{en}->{61746075} = "Haddon";
$areanames{en}->{61746076} = "Haden";
$areanames{en}->{61746077} = "Helidon";
$areanames{en}->{61746078} = "Inglewood";
$areanames{en}->{61746079} = "Injune";
$areanames{en}->{61746080} = "Isisford";
$areanames{en}->{61746081} = "Jandowae";
$areanames{en}->{61746082} = "Jericho";
$areanames{en}->{61746083} = "Jimbour";
$areanames{en}->{61746084} = "Jondaryan";
$areanames{en}->{61746085} = "Jundah";
$areanames{en}->{61746086} = "Kilbeggan";
$areanames{en}->{61746087} = "Killarney";
$areanames{en}->{61746088} = "Kumbarilla";
$areanames{en}->{61746089} = "Kupunn";
$areanames{en}->{61746090} = "Legume";
$areanames{en}->{61746091} = "Leyburn";
$areanames{en}->{61746092} = "Liston";
$areanames{en}->{61746093} = "Longreach";
$areanames{en}->{61746094} = "Lynd\ Range";
$areanames{en}->{61746095} = "Macalister";
$areanames{en}->{61746096} = "Maranoa";
$areanames{en}->{61746097} = "Meandarra";
$areanames{en}->{61746098} = "Miamba";
$areanames{en}->{61746099} = "Miles";
$areanames{en}->{61746100} = "Millmerran";
$areanames{en}->{61746101} = "Mitchell";
$areanames{en}->{61746102} = "Moonie";
$areanames{en}->{61746103} = "Morven";
$areanames{en}->{61746104} = "Mount\ Tyson";
$areanames{en}->{61746105} = "Muttaburra";
$areanames{en}->{61746106} = "Nobby";
$areanames{en}->{61746107} = "North\ Star";
$areanames{en}->{61746108} = "Oakey";
$areanames{en}->{61746109} = "Omanama";
$areanames{en}->{61746110} = "Paroo";
$areanames{en}->{61746111} = "Pikedale";
$areanames{en}->{61746112} = "Pittsworth";
$areanames{en}->{61746113} = "Quilpie";
$areanames{en}->{61746114} = "Ravensbourne";
$areanames{en}->{61746115} = "Robinson\ Gorge";
$areanames{en}->{61746116} = "Roma";
$areanames{en}->{61746117} = "Southwood";
$areanames{en}->{61746118} = "St\ George";
$areanames{en}->{61746119} = "Stanthorpe";
$areanames{en}->{61746120} = "Bringalily";
$areanames{en}->{61746121} = "Brookstead";
$areanames{en}->{61746122} = "Cambooya";
$areanames{en}->{61746123} = "Clifton";
$areanames{en}->{61746124} = "Clifton";
$areanames{en}->{61746125} = "Cooyar";
$areanames{en}->{61746126} = "Goombungee";
$areanames{en}->{61746127} = "Goombungee";
$areanames{en}->{61746128} = "Haden";
$areanames{en}->{61746129} = "Helidon";
$areanames{en}->{6174613} = "Toowoomba";
$areanames{en}->{6174614} = "Toowoomba";
$areanames{en}->{6174615} = "Toowoomba";
$areanames{en}->{61746156} = "Wallumbilla";
$areanames{en}->{61746157} = "Wallumbilla";
$areanames{en}->{61746158} = "Yuleba";
$areanames{en}->{61746159} = "Yuleba";
$areanames{en}->{6174616} = "Toowoomba";
$areanames{en}->{61746170} = "Brookstead";
$areanames{en}->{61746171} = "Brookstead";
$areanames{en}->{61746172} = "Brymaroo";
$areanames{en}->{61746173} = "Brymaroo";
$areanames{en}->{61746174} = "Cambooya";
$areanames{en}->{61746175} = "Cambooya";
$areanames{en}->{61746176} = "Toowoomba";
$areanames{en}->{61746177} = "Toowoomba";
$areanames{en}->{61746178} = "Toowoomba";
$areanames{en}->{61746179} = "Toowoomba";
$areanames{en}->{61746180} = "Surat";
$areanames{en}->{61746181} = "Tabers";
$areanames{en}->{61746182} = "Talwood";
$areanames{en}->{61746183} = "Tambo";
$areanames{en}->{61746184} = "Tara";
$areanames{en}->{61746185} = "Taroom";
$areanames{en}->{61746186} = "Teelba";
$areanames{en}->{61746187} = "Texas";
$areanames{en}->{61746188} = "Thallon";
$areanames{en}->{61746189} = "Thargomindah";
$areanames{en}->{61746190} = "Jondaryan";
$areanames{en}->{61746191} = "Leyburn";
$areanames{en}->{61746192} = "Mount\ Tyson";
$areanames{en}->{61746193} = "Nobby";
$areanames{en}->{61746194} = "Oakey";
$areanames{en}->{61746195} = "Oakey";
$areanames{en}->{61746196} = "Oakey";
$areanames{en}->{61746197} = "Oakey";
$areanames{en}->{61746198} = "Pittsworth";
$areanames{en}->{61746199} = "Ravensbourne";
$areanames{en}->{61746200} = "Toowoomba";
$areanames{en}->{61746201} = "Roma";
$areanames{en}->{61746202} = "St\ George";
$areanames{en}->{61746203} = "St\ George";
$areanames{en}->{61746204} = "Roma";
$areanames{en}->{61746205} = "Dirranbandi";
$areanames{en}->{61746206} = "Balonne";
$areanames{en}->{61746207} = "Dirranbandi";
$areanames{en}->{61746208} = "St\ George";
$areanames{en}->{61746209} = "Dirranbandi";
$areanames{en}->{61746210} = "Augathella";
$areanames{en}->{61746211} = "Augathella";
$areanames{en}->{61746212} = "Charleville";
$areanames{en}->{61746213} = "Cunnamulla";
$areanames{en}->{61746214} = "Morven";
$areanames{en}->{61746215} = "Quilpie";
$areanames{en}->{61746216} = "Tambo";
$areanames{en}->{61746217} = "Tambo";
$areanames{en}->{61746218} = "Thargomindah";
$areanames{en}->{61746219} = "Thargomindah";
$areanames{en}->{6174622} = "Roma";
$areanames{en}->{61746230} = "Durham\ Downs";
$areanames{en}->{61746231} = "Mitchell";
$areanames{en}->{61746232} = "Maranoa";
$areanames{en}->{61746233} = "Tabers";
$areanames{en}->{61746234} = "Wallumbilla";
$areanames{en}->{61746235} = "Yuleba";
$areanames{en}->{61746236} = "Mitchell";
$areanames{en}->{61746237} = "Mitchell";
$areanames{en}->{61746238} = "Mitchell";
$areanames{en}->{61746239} = "Maranoa";
$areanames{en}->{6174624} = "Roma";
$areanames{en}->{61746246} = "Mitchell";
$areanames{en}->{61746247} = "Mitchell";
$areanames{en}->{61746248} = "Injune";
$areanames{en}->{61746249} = "Culgoa";
$areanames{en}->{61746250} = "Culgoa";
$areanames{en}->{61746251} = "St\ George";
$areanames{en}->{61746252} = "St\ George";
$areanames{en}->{61746253} = "St\ George";
$areanames{en}->{61746254} = "St\ George";
$areanames{en}->{61746255} = "St\ George";
$areanames{en}->{61746256} = "Bollon";
$areanames{en}->{61746257} = "Balonne";
$areanames{en}->{61746258} = "Dirranbandi";
$areanames{en}->{61746259} = "Thallon";
$areanames{en}->{61746260} = "Injune";
$areanames{en}->{61746261} = "Injune";
$areanames{en}->{61746262} = "Westgrove";
$areanames{en}->{61746263} = "Westgrove";
$areanames{en}->{61746264} = "Surat";
$areanames{en}->{61746265} = "Surat";
$areanames{en}->{61746266} = "Surat";
$areanames{en}->{61746267} = "Arcadia\ Valley";
$areanames{en}->{61746268} = "Valley\ Downs";
$areanames{en}->{61746269} = "Valley\ Downs";
$areanames{en}->{61746270} = "Lynd\ Range";
$areanames{en}->{61746271} = "Miles";
$areanames{en}->{61746272} = "Miles";
$areanames{en}->{61746273} = "Taroom";
$areanames{en}->{61746274} = "Wandoan";
$areanames{en}->{61746275} = "Wandoan";
$areanames{en}->{61746276} = "Dulacca";
$areanames{en}->{61746277} = "Condamine";
$areanames{en}->{61746278} = "Cockatoo";
$areanames{en}->{61746279} = "Robinson\ Gorge";
$areanames{en}->{61746280} = "Miles";
$areanames{en}->{61746281} = "Miamba";
$areanames{en}->{61746282} = "Guluguba";
$areanames{en}->{61746283} = "Bimbadeen";
$areanames{en}->{61746284} = "Kilbeggan";
$areanames{en}->{61746285} = "Miles";
$areanames{en}->{61746286} = "Taroom";
$areanames{en}->{61746287} = "Dulacca";
$areanames{en}->{61746288} = "Wandoan";
$areanames{en}->{61746289} = "Taroom";
$areanames{en}->{61746290} = "St\ George";
$areanames{en}->{61746291} = "St\ George";
$areanames{en}->{61746292} = "Thallon";
$areanames{en}->{61746293} = "Dirranbandi";
$areanames{en}->{61746294} = "Bollon";
$areanames{en}->{61746295} = "Arcadia\ Valley";
$areanames{en}->{61746296} = "Durham\ Downs";
$areanames{en}->{61746297} = "Tabers";
$areanames{en}->{61746298} = "Wallumbilla";
$areanames{en}->{61746299} = "Yuleba";
$areanames{en}->{617463} = "Toowoomba";
$areanames{en}->{61746400} = "The\ Gums";
$areanames{en}->{61746401} = "Thomson";
$areanames{en}->{61746402} = "Tipton";
$areanames{en}->{61746403} = "Toobeah";
$areanames{en}->{61746404} = "Valley\ Downs";
$areanames{en}->{61746405} = "Wallumbilla";
$areanames{en}->{61746406} = "Wandoan";
$areanames{en}->{61746407} = "Warra";
$areanames{en}->{61746408} = "Warrego";
$areanames{en}->{61746409} = "Warwick";
$areanames{en}->{61746410} = "Westgrove";
$areanames{en}->{61746411} = "Westmar";
$areanames{en}->{61746412} = "Winton";
$areanames{en}->{61746413} = "Wyaga";
$areanames{en}->{61746414} = "Yelarbon";
$areanames{en}->{61746415} = "Yetman";
$areanames{en}->{61746416} = "Yuleba";
$areanames{en}->{61746417} = "Toowoomba";
$areanames{en}->{61746418} = "Nobby";
$areanames{en}->{61746419} = "Oakey";
$areanames{en}->{61746420} = "Toowoomba";
$areanames{en}->{61746421} = "Toowoomba";
$areanames{en}->{61746422} = "Toowoomba";
$areanames{en}->{61746423} = "Pittsworth";
$areanames{en}->{61746424} = "Ravensbourne";
$areanames{en}->{61746425} = "Toowoomba";
$areanames{en}->{61746426} = "Allora";
$areanames{en}->{61746427} = "Cunningham";
$areanames{en}->{61746428} = "Elbow\ Valley";
$areanames{en}->{61746429} = "Freestone";
$areanames{en}->{61746430} = "Killarney";
$areanames{en}->{61746431} = "Legume";
$areanames{en}->{61746432} = "Warwick";
$areanames{en}->{61746433} = "Jondaryan";
$areanames{en}->{61746434} = "Leyburn";
$areanames{en}->{61746435} = "Clifton";
$areanames{en}->{61746436} = "Cooyar";
$areanames{en}->{61746437} = "Crows\ Nest";
$areanames{en}->{61746438} = "Goombungee";
$areanames{en}->{61746439} = "Greenmount";
$areanames{en}->{61746440} = "Haden";
$areanames{en}->{61746441} = "Helidon";
$areanames{en}->{61746442} = "Yuleba";
$areanames{en}->{61746443} = "Ballandean";
$areanames{en}->{61746444} = "Cottonvale";
$areanames{en}->{61746445} = "Liston";
$areanames{en}->{61746446} = "Pikedale";
$areanames{en}->{61746447} = "Stanthorpe";
$areanames{en}->{61746448} = "Bringalily";
$areanames{en}->{61746449} = "Brookstead";
$areanames{en}->{61746450} = "Brymaroo";
$areanames{en}->{61746451} = "Cambooya";
$areanames{en}->{61746452} = "Durham\ Downs";
$areanames{en}->{61746453} = "Injune";
$areanames{en}->{61746454} = "Maranoa";
$areanames{en}->{61746455} = "Mitchell";
$areanames{en}->{61746456} = "Roma";
$areanames{en}->{61746457} = "Surat";
$areanames{en}->{61746458} = "Tabers";
$areanames{en}->{61746459} = "Valley\ Downs";
$areanames{en}->{61746460} = "Toowoomba";
$areanames{en}->{61746461} = "Toowoomba";
$areanames{en}->{61746462} = "Toowoomba";
$areanames{en}->{61746463} = "Toowoomba";
$areanames{en}->{61746464} = "Toowoomba";
$areanames{en}->{61746465} = "Augathella";
$areanames{en}->{61746466} = "Charleville";
$areanames{en}->{61746467} = "Cunnamulla";
$areanames{en}->{61746468} = "Paroo";
$areanames{en}->{61746469} = "Wallumbilla";
$areanames{en}->{61746470} = "Westgrove";
$areanames{en}->{61746471} = "Dulacca";
$areanames{en}->{61746472} = "Guluguba";
$areanames{en}->{61746473} = "Kilbeggan";
$areanames{en}->{61746474} = "Lynd\ Range";
$areanames{en}->{61746475} = "Miamba";
$areanames{en}->{61746476} = "Miles";
$areanames{en}->{61746477} = "Robinson\ Gorge";
$areanames{en}->{61746478} = "Taroom";
$areanames{en}->{61746479} = "Wandoan";
$areanames{en}->{61746480} = "Arcadia\ Valley";
$areanames{en}->{61746481} = "Thomson";
$areanames{en}->{61746482} = "Winton";
$areanames{en}->{61746483} = "Bimbadeen";
$areanames{en}->{61746484} = "Cockatoo";
$areanames{en}->{61746485} = "Condamine";
$areanames{en}->{61746486} = "Barcaldine";
$areanames{en}->{61746487} = "Barcoo";
$areanames{en}->{61746488} = "Blackall";
$areanames{en}->{61746489} = "Diamantina";
$areanames{en}->{61746490} = "Galilee";
$areanames{en}->{61746491} = "Isisford";
$areanames{en}->{61746492} = "Jericho";
$areanames{en}->{61746493} = "Jundah";
$areanames{en}->{61746494} = "Longreach";
$areanames{en}->{61746495} = "Muttaburra";
$areanames{en}->{61746496} = "Wyaga";
$areanames{en}->{61746497} = "Yelarbon";
$areanames{en}->{61746498} = "Yetman";
$areanames{en}->{61746499} = "Atholwood";
$areanames{en}->{61746500} = "Quilpie";
$areanames{en}->{61746501} = "Longreach";
$areanames{en}->{61746502} = "Winton";
$areanames{en}->{61746503} = "Thomson";
$areanames{en}->{61746504} = "Barcaldine";
$areanames{en}->{61746505} = "Charleville";
$areanames{en}->{61746506} = "Cunnamulla";
$areanames{en}->{61746507} = "Blackall";
$areanames{en}->{61746508} = "Charleville";
$areanames{en}->{61746509} = "Beebo";
$areanames{en}->{61746510} = "Galilee";
$areanames{en}->{61746511} = "Barcaldine";
$areanames{en}->{61746512} = "Barcaldine";
$areanames{en}->{61746513} = "Aramac";
$areanames{en}->{61746514} = "Jericho";
$areanames{en}->{61746515} = "Barcaldine";
$areanames{en}->{61746516} = "Barcaldine";
$areanames{en}->{61746517} = "Barcaldine";
$areanames{en}->{61746518} = "Thomson";
$areanames{en}->{61746519} = "Longreach";
$areanames{en}->{61746520} = "Inglewood";
$areanames{en}->{61746521} = "Inglewood";
$areanames{en}->{61746522} = "Inglewood";
$areanames{en}->{61746523} = "Omanama";
$areanames{en}->{61746524} = "Omanama";
$areanames{en}->{61746525} = "Longreach";
$areanames{en}->{61746526} = "Longreach";
$areanames{en}->{61746527} = "Longreach";
$areanames{en}->{61746528} = "Longreach";
$areanames{en}->{61746529} = "Aramac";
$areanames{en}->{61746530} = "Texas";
$areanames{en}->{61746531} = "Texas";
$areanames{en}->{61746532} = "Texas";
$areanames{en}->{61746533} = "Texas";
$areanames{en}->{61746534} = "Bonshaw";
$areanames{en}->{61746535} = "Bonshaw";
$areanames{en}->{61746536} = "Beebo";
$areanames{en}->{61746537} = "Beebo";
$areanames{en}->{61746538} = "Atholwood";
$areanames{en}->{61746539} = "Atholwood";
$areanames{en}->{61746540} = "Warrego";
$areanames{en}->{61746541} = "Charleville";
$areanames{en}->{61746542} = "Charleville";
$areanames{en}->{61746543} = "Charleville";
$areanames{en}->{61746544} = "Charleville";
$areanames{en}->{61746545} = "Augathella";
$areanames{en}->{61746546} = "Tambo";
$areanames{en}->{61746547} = "Charleville";
$areanames{en}->{61746548} = "Morven";
$areanames{en}->{61746549} = "Warrego";
$areanames{en}->{61746550} = "Cunnamulla";
$areanames{en}->{61746551} = "Cunnamulla";
$areanames{en}->{61746552} = "Cunnamulla";
$areanames{en}->{61746553} = "Thargomindah";
$areanames{en}->{61746554} = "Paroo";
$areanames{en}->{61746555} = "Paroo";
$areanames{en}->{61746556} = "Paroo";
$areanames{en}->{61746557} = "Paroo";
$areanames{en}->{61746558} = "Cunnamulla";
$areanames{en}->{61746559} = "Cunnamulla";
$areanames{en}->{61746560} = "Quilpie";
$areanames{en}->{61746561} = "Quilpie";
$areanames{en}->{61746562} = "Quilpie";
$areanames{en}->{61746563} = "Haddon";
$areanames{en}->{61746564} = "Haddon";
$areanames{en}->{61746565} = "Charleville";
$areanames{en}->{61746566} = "Haddon";
$areanames{en}->{61746567} = "Augathella";
$areanames{en}->{61746568} = "Charleville";
$areanames{en}->{61746569} = "Charleville";
$areanames{en}->{61746570} = "Winton";
$areanames{en}->{61746571} = "Winton";
$areanames{en}->{61746572} = "Winton";
$areanames{en}->{61746573} = "Diamantina";
$areanames{en}->{61746574} = "Blackall";
$areanames{en}->{61746575} = "Barcoo";
$areanames{en}->{61746576} = "Blackall";
$areanames{en}->{61746577} = "Blackall";
$areanames{en}->{61746578} = "Blackall";
$areanames{en}->{61746579} = "Winton";
$areanames{en}->{61746580} = "Longreach";
$areanames{en}->{61746581} = "Longreach";
$areanames{en}->{61746582} = "Longreach";
$areanames{en}->{61746583} = "Longreach";
$areanames{en}->{61746584} = "Longreach";
$areanames{en}->{61746585} = "Thomson";
$areanames{en}->{61746586} = "Jundah";
$areanames{en}->{61746587} = "Muttaburra";
$areanames{en}->{61746588} = "Isisford";
$areanames{en}->{61746589} = "Thomson";
$areanames{en}->{6174659} = "Toowoomba";
$areanames{en}->{61746600} = "Dalby";
$areanames{en}->{61746601} = "Warwick";
$areanames{en}->{61746602} = "Warwick";
$areanames{en}->{61746603} = "Warwick";
$areanames{en}->{61746604} = "Warwick";
$areanames{en}->{61746605} = "Warwick";
$areanames{en}->{61746606} = "Dalby";
$areanames{en}->{61746607} = "Chinchilla";
$areanames{en}->{61746608} = "Dalby";
$areanames{en}->{61746609} = "Cecil\ Plains";
$areanames{en}->{6174661} = "Warwick";
$areanames{en}->{6174662} = "Dalby";
$areanames{en}->{61746627} = "Chinchilla";
$areanames{en}->{61746628} = "Chinchilla";
$areanames{en}->{61746629} = "Southwood";
$areanames{en}->{61746630} = "Westmar";
$areanames{en}->{61746631} = "Bell";
$areanames{en}->{61746632} = "Tipton";
$areanames{en}->{61746633} = "Dalby";
$areanames{en}->{61746634} = "Bell";
$areanames{en}->{61746635} = "Macalister";
$areanames{en}->{61746636} = "Jimbour";
$areanames{en}->{61746637} = "Bowenville";
$areanames{en}->{61746638} = "Kupunn";
$areanames{en}->{61746639} = "Dalby";
$areanames{en}->{6174664} = "Killarney";
$areanames{en}->{61746640} = "Legume";
$areanames{en}->{61746649} = "Elbow\ Valley";
$areanames{en}->{61746650} = "Moonie";
$areanames{en}->{61746651} = "Coondarra";
$areanames{en}->{61746652} = "Brigalow";
$areanames{en}->{61746653} = "Tara";
$areanames{en}->{61746654} = "Glenhope";
$areanames{en}->{61746655} = "Chinchilla";
$areanames{en}->{61746656} = "Meandarra";
$areanames{en}->{61746657} = "Eschol";
$areanames{en}->{61746658} = "Goombi";
$areanames{en}->{61746659} = "The\ Gums";
$areanames{en}->{61746660} = "Freestone";
$areanames{en}->{61746661} = "Freestone";
$areanames{en}->{61746662} = "Allora";
$areanames{en}->{61746663} = "Allora";
$areanames{en}->{61746664} = "Legume";
$areanames{en}->{61746665} = "Legume";
$areanames{en}->{61746666} = "Allora";
$areanames{en}->{61746667} = "Allora";
$areanames{en}->{61746668} = "Cunningham";
$areanames{en}->{61746669} = "Warwick";
$areanames{en}->{6174667} = "Warwick";
$areanames{en}->{61746674} = "Cunningham";
$areanames{en}->{61746679} = "Elbow\ Valley";
$areanames{en}->{61746680} = "Cecil\ Plains";
$areanames{en}->{61746681} = "Warra";
$areanames{en}->{61746682} = "Kumbarilla";
$areanames{en}->{61746683} = "Bunya\ Mountains";
$areanames{en}->{61746684} = "Jandowae";
$areanames{en}->{61746685} = "Jandowae";
$areanames{en}->{61746686} = "Diamondy";
$areanames{en}->{61746687} = "Dunmore";
$areanames{en}->{61746688} = "Darr\ Creek";
$areanames{en}->{61746689} = "Chinchilla";
$areanames{en}->{61746690} = "Dalby";
$areanames{en}->{61746691} = "Chinchilla";
$areanames{en}->{61746692} = "Tara";
$areanames{en}->{61746693} = "Auburn";
$areanames{en}->{61746694} = "Tara";
$areanames{en}->{61746695} = "Teelba";
$areanames{en}->{61746696} = "Dalby";
$areanames{en}->{61746697} = "Dalby";
$areanames{en}->{61746698} = "Dalby";
$areanames{en}->{61746699} = "Dalby";
$areanames{en}->{61746700} = "Goondiwindi";
$areanames{en}->{61746701} = "Haden";
$areanames{en}->{61746702} = "Haden";
$areanames{en}->{61746703} = "Helidon";
$areanames{en}->{61746704} = "Helidon";
$areanames{en}->{61746705} = "Jondaryan";
$areanames{en}->{61746706} = "Jondaryan";
$areanames{en}->{61746707} = "Leyburn";
$areanames{en}->{61746708} = "Leyburn";
$areanames{en}->{61746709} = "Toowoomba";
$areanames{en}->{6174671} = "Goondiwindi";
$areanames{en}->{6174672} = "Dalby";
$areanames{en}->{61746726} = "Chinchilla";
$areanames{en}->{61746727} = "Chinchilla";
$areanames{en}->{61746728} = "Chinchilla";
$areanames{en}->{61746729} = "Chinchilla";
$areanames{en}->{61746730} = "Warwick";
$areanames{en}->{61746731} = "Warwick";
$areanames{en}->{61746732} = "Beebo";
$areanames{en}->{61746733} = "Bonshaw";
$areanames{en}->{61746734} = "Inglewood";
$areanames{en}->{61746735} = "Omanama";
$areanames{en}->{61746736} = "Texas";
$areanames{en}->{61746737} = "Aramac";
$areanames{en}->{61746738} = "Bollon";
$areanames{en}->{61746739} = "Culgoa";
$areanames{en}->{61746740} = "Dirranbandi";
$areanames{en}->{61746741} = "St\ George";
$areanames{en}->{61746742} = "Thallon";
$areanames{en}->{61746743} = "Billa\ Billa";
$areanames{en}->{61746744} = "Goondiwindi";
$areanames{en}->{61746745} = "North\ Star";
$areanames{en}->{61746746} = "Talwood";
$areanames{en}->{61746747} = "Toobeah";
$areanames{en}->{61746748} = "Meandarra";
$areanames{en}->{61746749} = "Moonie";
$areanames{en}->{61746750} = "Yelarbon";
$areanames{en}->{61746751} = "Yelarbon";
$areanames{en}->{61746752} = "Yetman";
$areanames{en}->{61746753} = "Yetman";
$areanames{en}->{61746754} = "Wyaga";
$areanames{en}->{61746755} = "Yetman";
$areanames{en}->{61746756} = "Inglewood";
$areanames{en}->{61746757} = "Inglewood";
$areanames{en}->{61746758} = "Longreach";
$areanames{en}->{61746759} = "Longreach";
$areanames{en}->{61746760} = "Wyaga";
$areanames{en}->{61746761} = "Billa\ Billa";
$areanames{en}->{61746762} = "Goondiwindi";
$areanames{en}->{61746763} = "North\ Star";
$areanames{en}->{61746764} = "Toobeah";
$areanames{en}->{61746765} = "North\ Star";
$areanames{en}->{61746766} = "Goondiwindi";
$areanames{en}->{61746767} = "Goondiwindi";
$areanames{en}->{61746768} = "Toowoomba";
$areanames{en}->{61746769} = "Toowoomba";
$areanames{en}->{61746770} = "Talwood";
$areanames{en}->{61746771} = "Talwood";
$areanames{en}->{61746772} = "North\ Star";
$areanames{en}->{61746773} = "Billa\ Billa";
$areanames{en}->{61746774} = "Toobeah";
$areanames{en}->{61746775} = "Toobeah";
$areanames{en}->{61746776} = "Talwood";
$areanames{en}->{61746777} = "Goondiwindi";
$areanames{en}->{61746778} = "Goondiwindi";
$areanames{en}->{61746779} = "Goondiwindi";
$areanames{en}->{61746780} = "Brigalow";
$areanames{en}->{61746781} = "Cecil\ Plains";
$areanames{en}->{61746782} = "Diamondy";
$areanames{en}->{61746783} = "Eschol";
$areanames{en}->{61746784} = "Kumbarilla";
$areanames{en}->{61746785} = "Meandarra";
$areanames{en}->{61746786} = "Moonie";
$areanames{en}->{61746787} = "Tara";
$areanames{en}->{61746788} = "Tipton";
$areanames{en}->{61746789} = "Warra";
$areanames{en}->{61746790} = "Macalister";
$areanames{en}->{61746791} = "Bunya\ Mountains";
$areanames{en}->{61746792} = "Bell";
$areanames{en}->{61746793} = "Bowenville";
$areanames{en}->{61746794} = "Dalby";
$areanames{en}->{61746795} = "Dalby";
$areanames{en}->{61746796} = "Dulacca";
$areanames{en}->{61746797} = "Dulacca";
$areanames{en}->{61746798} = "Dalby";
$areanames{en}->{61746799} = "Dalby";
$areanames{en}->{61746800} = "Stanthorpe";
$areanames{en}->{61746801} = "Miles";
$areanames{en}->{61746802} = "Miles";
$areanames{en}->{61746803} = "Auburn";
$areanames{en}->{61746804} = "Tara";
$areanames{en}->{61746805} = "Teelba";
$areanames{en}->{61746806} = "Cottonvale";
$areanames{en}->{61746807} = "Ballandean";
$areanames{en}->{61746808} = "Pikedale";
$areanames{en}->{61746809} = "Liston";
$areanames{en}->{6174681} = "Stanthorpe";
$areanames{en}->{61746820} = "Southwood";
$areanames{en}->{61746821} = "Tara";
$areanames{en}->{61746822} = "Teelba";
$areanames{en}->{61746823} = "The\ Gums";
$areanames{en}->{61746824} = "Tipton";
$areanames{en}->{61746825} = "Warra";
$areanames{en}->{61746826} = "Westmar";
$areanames{en}->{61746827} = "Balonne";
$areanames{en}->{61746828} = "Diamondy";
$areanames{en}->{61746829} = "Dunmore";
$areanames{en}->{6174683} = "Stanthorpe";
$areanames{en}->{617468300} = "Roma";
$areanames{en}->{617468301} = "Jondaryan";
$areanames{en}->{617468302} = "Jundah";
$areanames{en}->{617468303} = "Kilbeggan";
$areanames{en}->{617468304} = "Killarney";
$areanames{en}->{617468305} = "Warwick";
$areanames{en}->{617468306} = "Kumbarilla";
$areanames{en}->{617468307} = "Kupunn";
$areanames{en}->{617468308} = "Legume";
$areanames{en}->{617468309} = "Leyburn";
$areanames{en}->{61746838} = "Wandoan";
$areanames{en}->{61746839} = "Wandoan";
$areanames{en}->{6174684} = "Ballandean";
$areanames{en}->{61746840} = "Stanthorpe";
$areanames{en}->{61746848} = "Stanthorpe";
$areanames{en}->{61746849} = "Stanthorpe";
$areanames{en}->{61746850} = "Cottonvale";
$areanames{en}->{61746851} = "Cottonvale";
$areanames{en}->{61746852} = "Cottonvale";
$areanames{en}->{61746853} = "Cottonvale";
$areanames{en}->{61746854} = "Miles";
$areanames{en}->{61746855} = "Stanthorpe";
$areanames{en}->{61746856} = "Pikedale";
$areanames{en}->{61746857} = "Cottonvale";
$areanames{en}->{61746858} = "Stanthorpe";
$areanames{en}->{61746859} = "Miles";
$areanames{en}->{61746860} = "Liston";
$areanames{en}->{61746861} = "Liston";
$areanames{en}->{61746862} = "Clifton";
$areanames{en}->{61746863} = "Clifton";
$areanames{en}->{61746864} = "Cooyar";
$areanames{en}->{61746865} = "Cooyar";
$areanames{en}->{61746866} = "Crows\ Nest";
$areanames{en}->{61746867} = "Crows\ Nest";
$areanames{en}->{61746868} = "Greenmount";
$areanames{en}->{61746869} = "Greenmount";
$areanames{en}->{6174687} = "Toowoomba";
$areanames{en}->{6174688} = "Toowoomba";
$areanames{en}->{61746890} = "Eschol";
$areanames{en}->{61746891} = "Glenhope";
$areanames{en}->{61746892} = "Goombi";
$areanames{en}->{61746893} = "Jandowae";
$areanames{en}->{61746894} = "Jimbour";
$areanames{en}->{61746895} = "Kumbarilla";
$areanames{en}->{61746896} = "Kupunn";
$areanames{en}->{61746897} = "Macalister";
$areanames{en}->{61746898} = "Auburn";
$areanames{en}->{61746899} = "Bell";
$areanames{en}->{6174690} = "Toowoomba";
$areanames{en}->{61746908} = "Helidon";
$areanames{en}->{6174691} = "Oakey";
$areanames{en}->{61746910} = "Cambooya";
$areanames{en}->{61746920} = "Oakey";
$areanames{en}->{61746921} = "Brymaroo";
$areanames{en}->{61746922} = "Jondaryan";
$areanames{en}->{61746923} = "Jondaryan";
$areanames{en}->{61746924} = "Jondaryan";
$areanames{en}->{61746925} = "Oakey";
$areanames{en}->{61746926} = "Cooyar";
$areanames{en}->{61746927} = "Brymaroo";
$areanames{en}->{61746928} = "Brymaroo";
$areanames{en}->{61746929} = "Brymaroo";
$areanames{en}->{6174693} = "Pittsworth";
$areanames{en}->{61746930} = "Brookstead";
$areanames{en}->{61746937} = "Mount\ Tyson";
$areanames{en}->{61746938} = "Mount\ Tyson";
$areanames{en}->{61746939} = "Brookstead";
$areanames{en}->{61746940} = "Toowoomba";
$areanames{en}->{61746941} = "Toowoomba";
$areanames{en}->{61746942} = "Pittsworth";
$areanames{en}->{61746943} = "Pittsworth";
$areanames{en}->{61746944} = "Pittsworth";
$areanames{en}->{61746945} = "Crows\ Nest";
$areanames{en}->{61746946} = "Goombungee";
$areanames{en}->{61746947} = "Oakey";
$areanames{en}->{61746948} = "Oakey";
$areanames{en}->{61746949} = "Toowoomba";
$areanames{en}->{61746950} = "Leyburn";
$areanames{en}->{61746951} = "Millmerran";
$areanames{en}->{61746952} = "Millmerran";
$areanames{en}->{61746953} = "Millmerran";
$areanames{en}->{61746954} = "Millmerran";
$areanames{en}->{61746955} = "Millmerran";
$areanames{en}->{61746956} = "Bringalily";
$areanames{en}->{61746957} = "Bringalily";
$areanames{en}->{61746958} = "Nobby";
$areanames{en}->{61746959} = "Nobby";
$areanames{en}->{61746960} = "Cambooya";
$areanames{en}->{61746961} = "Cambooya";
$areanames{en}->{61746962} = "Cambooya";
$areanames{en}->{61746963} = "Nobby";
$areanames{en}->{61746964} = "Clifton";
$areanames{en}->{61746965} = "Goombungee";
$areanames{en}->{61746966} = "Goombungee";
$areanames{en}->{61746967} = "Goombungee";
$areanames{en}->{61746968} = "Toowoomba";
$areanames{en}->{61746969} = "Goombungee";
$areanames{en}->{61746970} = "Greenmount";
$areanames{en}->{61746971} = "Greenmount";
$areanames{en}->{61746972} = "Greenmount";
$areanames{en}->{61746973} = "Clifton";
$areanames{en}->{61746974} = "Clifton";
$areanames{en}->{61746975} = "Helidon";
$areanames{en}->{61746976} = "Helidon";
$areanames{en}->{61746977} = "Helidon";
$areanames{en}->{61746978} = "Ravensbourne";
$areanames{en}->{61746979} = "Ravensbourne";
$areanames{en}->{61746980} = "Crows\ Nest";
$areanames{en}->{61746981} = "Crows\ Nest";
$areanames{en}->{61746982} = "Crows\ Nest";
$areanames{en}->{61746983} = "Crows\ Nest";
$areanames{en}->{61746984} = "Crows\ Nest";
$areanames{en}->{61746985} = "Toowoomba";
$areanames{en}->{61746986} = "Toowoomba";
$areanames{en}->{61746987} = "Toowoomba";
$areanames{en}->{61746988} = "Haden";
$areanames{en}->{61746989} = "Toowoomba";
$areanames{en}->{6174699} = "Toowoomba";
$areanames{en}->{6174700} = "Townsville";
$areanames{en}->{61747010} = "Ayr";
$areanames{en}->{61747011} = "Ayr";
$areanames{en}->{61747012} = "Ayr";
$areanames{en}->{61747013} = "Bambaroo";
$areanames{en}->{61747014} = "Bambaroo";
$areanames{en}->{61747015} = "Bambaroo";
$areanames{en}->{61747016} = "Barkly";
$areanames{en}->{61747017} = "Barkly";
$areanames{en}->{61747018} = "Barkly";
$areanames{en}->{61747019} = "Yabulu";
$areanames{en}->{61747020} = "Boulia";
$areanames{en}->{61747021} = "Boulia";
$areanames{en}->{61747022} = "Boulia";
$areanames{en}->{61747023} = "Bowen";
$areanames{en}->{61747024} = "Bowen";
$areanames{en}->{61747025} = "Bowen";
$areanames{en}->{61747026} = "Briaba";
$areanames{en}->{61747027} = "Briaba";
$areanames{en}->{61747028} = "Briaba";
$areanames{en}->{61747029} = "Gununa";
$areanames{en}->{61747030} = "Burdekin";
$areanames{en}->{61747031} = "Burdekin";
$areanames{en}->{61747032} = "Burdekin";
$areanames{en}->{61747033} = "Burketown";
$areanames{en}->{61747034} = "Burketown";
$areanames{en}->{61747035} = "Burketown";
$areanames{en}->{61747036} = "Camooweal";
$areanames{en}->{61747037} = "Camooweal";
$areanames{en}->{61747038} = "Camooweal";
$areanames{en}->{61747039} = "Burketown";
$areanames{en}->{61747040} = "Cape\ River";
$areanames{en}->{61747041} = "Cape\ River";
$areanames{en}->{61747042} = "Cape\ River";
$areanames{en}->{61747043} = "Charters\ Towers";
$areanames{en}->{61747044} = "Charters\ Towers";
$areanames{en}->{61747045} = "Charters\ Towers";
$areanames{en}->{61747046} = "Clarke";
$areanames{en}->{61747047} = "Clarke";
$areanames{en}->{61747048} = "Clarke";
$areanames{en}->{61747049} = "Julia\ Creek";
$areanames{en}->{61747050} = "Cloncurry";
$areanames{en}->{61747051} = "Cloncurry";
$areanames{en}->{61747052} = "Cloncurry";
$areanames{en}->{61747053} = "Collinsville";
$areanames{en}->{61747054} = "Collinsville";
$areanames{en}->{61747055} = "Collinsville";
$areanames{en}->{61747056} = "Croydon";
$areanames{en}->{61747057} = "Croydon";
$areanames{en}->{61747058} = "Croydon";
$areanames{en}->{61747059} = "Kalkadoon";
$areanames{en}->{61747060} = "Dalbeg";
$areanames{en}->{61747061} = "Dalbeg";
$areanames{en}->{61747062} = "Dalbeg";
$areanames{en}->{61747063} = "Doomadgee";
$areanames{en}->{61747064} = "Doomadgee";
$areanames{en}->{61747065} = "Doomadgee";
$areanames{en}->{61747066} = "Eddington";
$areanames{en}->{61747067} = "Eddington";
$areanames{en}->{61747068} = "Eddington";
$areanames{en}->{61747069} = "Karumba";
$areanames{en}->{61747070} = "Flinders";
$areanames{en}->{61747071} = "Flinders";
$areanames{en}->{61747072} = "Flinders";
$areanames{en}->{61747073} = "Georgina";
$areanames{en}->{61747074} = "Georgina";
$areanames{en}->{61747075} = "Georgina";
$areanames{en}->{61747076} = "Giru";
$areanames{en}->{61747077} = "Giru";
$areanames{en}->{61747078} = "Giru";
$areanames{en}->{61747079} = "Mount\ Isa";
$areanames{en}->{61747080} = "Greenvale";
$areanames{en}->{61747081} = "Greenvale";
$areanames{en}->{61747082} = "Greenvale";
$areanames{en}->{61747083} = "Gulf";
$areanames{en}->{61747084} = "Gulf";
$areanames{en}->{61747085} = "Gulf";
$areanames{en}->{61747086} = "Gumlu";
$areanames{en}->{61747087} = "Gumlu";
$areanames{en}->{61747088} = "Gumlu";
$areanames{en}->{61747089} = "Normanton";
$areanames{en}->{61747090} = "Gunpowder";
$areanames{en}->{61747091} = "Gunpowder";
$areanames{en}->{61747092} = "Gunpowder";
$areanames{en}->{61747093} = "Gununa";
$areanames{en}->{61747094} = "Gununa";
$areanames{en}->{61747095} = "Gununa";
$areanames{en}->{61747096} = "Halifax";
$areanames{en}->{61747097} = "Halifax";
$areanames{en}->{61747098} = "Halifax";
$areanames{en}->{61747099} = "The\ Monument";
$areanames{en}->{61747100} = "Home\ Hill";
$areanames{en}->{61747101} = "Home\ Hill";
$areanames{en}->{61747102} = "Home\ Hill";
$areanames{en}->{61747103} = "Hughenden";
$areanames{en}->{61747104} = "Hughenden";
$areanames{en}->{61747105} = "Hughenden";
$areanames{en}->{61747106} = "Ingham";
$areanames{en}->{61747107} = "Ingham";
$areanames{en}->{61747108} = "Ingham";
$areanames{en}->{61747109} = "Ingham";
$areanames{en}->{61747110} = "Julia\ Creek";
$areanames{en}->{61747111} = "Julia\ Creek";
$areanames{en}->{61747112} = "Julia\ Creek";
$areanames{en}->{61747113} = "Kalkadoon";
$areanames{en}->{61747114} = "Kalkadoon";
$areanames{en}->{61747115} = "Kalkadoon";
$areanames{en}->{61747116} = "Karumba";
$areanames{en}->{61747117} = "Karumba";
$areanames{en}->{61747118} = "Karumba";
$areanames{en}->{61747119} = "Julia\ Creek";
$areanames{en}->{61747120} = "Kirk";
$areanames{en}->{61747121} = "Kirk";
$areanames{en}->{61747122} = "Kirk";
$areanames{en}->{61747123} = "Leichhardt\ Range";
$areanames{en}->{61747124} = "Leichhardt\ Range";
$areanames{en}->{61747125} = "Leichhardt\ Range";
$areanames{en}->{61747126} = "Long\ Pocket";
$areanames{en}->{61747127} = "Long\ Pocket";
$areanames{en}->{61747128} = "Long\ Pocket";
$areanames{en}->{61747129} = "Barkly";
$areanames{en}->{61747130} = "Millaroo";
$areanames{en}->{61747131} = "Millaroo";
$areanames{en}->{61747132} = "Millaroo";
$areanames{en}->{61747133} = "Mount\ Fox";
$areanames{en}->{61747134} = "Mount\ Fox";
$areanames{en}->{61747135} = "Mount\ Fox";
$areanames{en}->{61747136} = "Mount\ Isa";
$areanames{en}->{61747137} = "Mount\ Isa";
$areanames{en}->{61747138} = "Mount\ Isa";
$areanames{en}->{61747139} = "Mount\ Isa";
$areanames{en}->{61747140} = "Mutarnee";
$areanames{en}->{61747141} = "Mutarnee";
$areanames{en}->{61747142} = "Mutarnee";
$areanames{en}->{61747143} = "Normanton";
$areanames{en}->{61747144} = "Normanton";
$areanames{en}->{61747145} = "Normanton";
$areanames{en}->{61747146} = "Palm\ Island";
$areanames{en}->{61747147} = "Palm\ Island";
$areanames{en}->{61747148} = "Palm\ Island";
$areanames{en}->{61747149} = "Normanton";
$areanames{en}->{61747150} = "Pentland";
$areanames{en}->{61747151} = "Pentland";
$areanames{en}->{61747152} = "Pentland";
$areanames{en}->{61747153} = "Prairie";
$areanames{en}->{61747154} = "Prairie";
$areanames{en}->{61747155} = "Prairie";
$areanames{en}->{61747156} = "Ravenswood";
$areanames{en}->{61747157} = "Ravenswood";
$areanames{en}->{61747158} = "Ravenswood";
$areanames{en}->{61747159} = "Boulia";
$areanames{en}->{61747160} = "Richmond";
$areanames{en}->{61747161} = "Richmond";
$areanames{en}->{61747162} = "Richmond";
$areanames{en}->{61747163} = "Rollingstone";
$areanames{en}->{61747164} = "Rollingstone";
$areanames{en}->{61747165} = "Rollingstone";
$areanames{en}->{61747166} = "The\ Monument";
$areanames{en}->{61747167} = "The\ Monument";
$areanames{en}->{61747168} = "The\ Monument";
$areanames{en}->{61747169} = "Burketown";
$areanames{en}->{61747170} = "Upper\ Stone";
$areanames{en}->{61747171} = "Upper\ Stone";
$areanames{en}->{61747172} = "Upper\ Stone";
$areanames{en}->{61747173} = "Walker";
$areanames{en}->{61747174} = "Walker";
$areanames{en}->{61747175} = "Walker";
$areanames{en}->{61747176} = "Woodstock";
$areanames{en}->{61747177} = "Woodstock";
$areanames{en}->{61747178} = "Woodstock";
$areanames{en}->{61747179} = "Camooweal";
$areanames{en}->{61747180} = "Yabulu";
$areanames{en}->{61747181} = "Yabulu";
$areanames{en}->{61747182} = "Yabulu";
$areanames{en}->{61747183} = "Cloncurry";
$areanames{en}->{61747184} = "Doomadgee";
$areanames{en}->{61747185} = "Eddington";
$areanames{en}->{61747186} = "Georgina";
$areanames{en}->{61747187} = "Gulf";
$areanames{en}->{61747188} = "Gunpowder";
$areanames{en}->{61747189} = "Croydon";
$areanames{en}->{61747190} = "Richmond";
$areanames{en}->{61747191} = "Walker";
$areanames{en}->{61747192} = "Flinders";
$areanames{en}->{61747193} = "Hughenden";
$areanames{en}->{61747194} = "Prairie";
$areanames{en}->{61747195} = "Yabulu";
$areanames{en}->{61747196} = "Millaroo";
$areanames{en}->{61747197} = "Mount\ Fox";
$areanames{en}->{61747198} = "Mutarnee";
$areanames{en}->{61747199} = "Palm\ Island";
$areanames{en}->{617472} = "Townsville";
$areanames{en}->{61747202} = "Giru";
$areanames{en}->{61747203} = "Ingham";
$areanames{en}->{61747204} = "Bowen";
$areanames{en}->{61747205} = "Ayr";
$areanames{en}->{61747206} = "Yabulu";
$areanames{en}->{61747209} = "Collinsville";
$areanames{en}->{61747300} = "Mount\ Isa";
$areanames{en}->{61747301} = "Mount\ Isa";
$areanames{en}->{61747302} = "Mount\ Isa";
$areanames{en}->{61747303} = "Mount\ Isa";
$areanames{en}->{61747304} = "Millaroo";
$areanames{en}->{61747305} = "Mount\ Fox";
$areanames{en}->{61747306} = "Mutarnee";
$areanames{en}->{61747307} = "Palm\ Island";
$areanames{en}->{61747308} = "Pentland";
$areanames{en}->{61747309} = "Ravenswood";
$areanames{en}->{61747310} = "Rollingstone";
$areanames{en}->{61747311} = "Townsville";
$areanames{en}->{61747312} = "Upper\ Stone";
$areanames{en}->{61747313} = "Woodstock";
$areanames{en}->{61747314} = "Dalbeg";
$areanames{en}->{61747315} = "Giru";
$areanames{en}->{61747316} = "Greenvale";
$areanames{en}->{61747317} = "Gumlu";
$areanames{en}->{61747318} = "Halifax";
$areanames{en}->{61747319} = "Home\ Hill";
$areanames{en}->{61747320} = "Ingham";
$areanames{en}->{61747321} = "Kirk";
$areanames{en}->{61747322} = "Leichhardt\ Range";
$areanames{en}->{61747323} = "Long\ Pocket";
$areanames{en}->{61747324} = "Collinsville";
$areanames{en}->{61747325} = "Richmond";
$areanames{en}->{61747326} = "Walker";
$areanames{en}->{61747327} = "Ayr";
$areanames{en}->{61747328} = "Bambaroo";
$areanames{en}->{61747329} = "Bowen";
$areanames{en}->{61747330} = "Briaba";
$areanames{en}->{61747331} = "Burdekin";
$areanames{en}->{61747332} = "Cape\ River";
$areanames{en}->{61747333} = "Charters\ Towers";
$areanames{en}->{61747334} = "Clarke";
$areanames{en}->{61747335} = "Gununa";
$areanames{en}->{61747336} = "Julia\ Creek";
$areanames{en}->{61747337} = "Kalkadoon";
$areanames{en}->{61747338} = "Karumba";
$areanames{en}->{61747339} = "Mount\ Isa";
$areanames{en}->{61747340} = "Normanton";
$areanames{en}->{61747341} = "The\ Monument";
$areanames{en}->{61747342} = "Flinders";
$areanames{en}->{61747343} = "Hughenden";
$areanames{en}->{61747344} = "Prairie";
$areanames{en}->{61747345} = "Barkly";
$areanames{en}->{61747346} = "Boulia";
$areanames{en}->{61747347} = "Burketown";
$areanames{en}->{61747348} = "Camooweal";
$areanames{en}->{61747349} = "Cloncurry";
$areanames{en}->{61747350} = "Doomadgee";
$areanames{en}->{61747351} = "Eddington";
$areanames{en}->{61747352} = "Georgina";
$areanames{en}->{61747353} = "Gulf";
$areanames{en}->{61747354} = "Gunpowder";
$areanames{en}->{61747355} = "Pentland";
$areanames{en}->{61747356} = "Ravenswood";
$areanames{en}->{61747357} = "Rollingstone";
$areanames{en}->{61747358} = "Townsville";
$areanames{en}->{61747359} = "Cloncurry";
$areanames{en}->{61747360} = "Upper\ Stone";
$areanames{en}->{61747361} = "Woodstock";
$areanames{en}->{61747362} = "Dalbeg";
$areanames{en}->{61747363} = "Giru";
$areanames{en}->{61747364} = "Greenvale";
$areanames{en}->{61747365} = "Gumlu";
$areanames{en}->{61747366} = "Halifax";
$areanames{en}->{61747367} = "Home\ Hill";
$areanames{en}->{61747368} = "Ingham";
$areanames{en}->{61747369} = "Kirk";
$areanames{en}->{61747370} = "Leichhardt\ Range";
$areanames{en}->{61747371} = "Long\ Pocket";
$areanames{en}->{61747372} = "Collinsville";
$areanames{en}->{61747373} = "Ayr";
$areanames{en}->{61747374} = "Bambaroo";
$areanames{en}->{61747375} = "Bowen";
$areanames{en}->{61747376} = "Briaba";
$areanames{en}->{61747377} = "Burdekin";
$areanames{en}->{61747378} = "Cape\ River";
$areanames{en}->{61747379} = "Charters\ Towers";
$areanames{en}->{61747380} = "Clarke";
$areanames{en}->{617473810} = "Barkly";
$areanames{en}->{617473811} = "Barkly";
$areanames{en}->{617473812} = "Barkly";
$areanames{en}->{617473813} = "Barkly";
$areanames{en}->{617473814} = "Barkly";
$areanames{en}->{617473815} = "Barkly";
$areanames{en}->{617473816} = "Barkly";
$areanames{en}->{617473817} = "Barkly";
$areanames{en}->{617473820} = "Boulia";
$areanames{en}->{617473821} = "Boulia";
$areanames{en}->{617473822} = "Boulia";
$areanames{en}->{617473823} = "Boulia";
$areanames{en}->{617473824} = "Boulia";
$areanames{en}->{617473825} = "Boulia";
$areanames{en}->{617473826} = "Boulia";
$areanames{en}->{617473827} = "Boulia";
$areanames{en}->{617473830} = "Burketown";
$areanames{en}->{617473831} = "Burketown";
$areanames{en}->{617473832} = "Burketown";
$areanames{en}->{617473833} = "Burketown";
$areanames{en}->{617473834} = "Burketown";
$areanames{en}->{617473835} = "Burketown";
$areanames{en}->{617473836} = "Burketown";
$areanames{en}->{617473840} = "Camooweal";
$areanames{en}->{617473841} = "Camooweal";
$areanames{en}->{617473842} = "Camooweal";
$areanames{en}->{617473843} = "Camooweal";
$areanames{en}->{617473844} = "Camooweal";
$areanames{en}->{617473845} = "Camooweal";
$areanames{en}->{617473846} = "Camooweal";
$areanames{en}->{617473847} = "Camooweal";
$areanames{en}->{617473850} = "Cloncurry";
$areanames{en}->{617473851} = "Cloncurry";
$areanames{en}->{617473852} = "Cloncurry";
$areanames{en}->{617473853} = "Cloncurry";
$areanames{en}->{617473854} = "Cloncurry";
$areanames{en}->{617473855} = "Cloncurry";
$areanames{en}->{617473856} = "Cloncurry";
$areanames{en}->{617473859} = "Cloncurry";
$areanames{en}->{617473860} = "Doomadgee";
$areanames{en}->{617473861} = "Doomadgee";
$areanames{en}->{617473862} = "Doomadgee";
$areanames{en}->{617473863} = "Doomadgee";
$areanames{en}->{617473864} = "Doomadgee";
$areanames{en}->{617473865} = "Doomadgee";
$areanames{en}->{617473866} = "Doomadgee";
$areanames{en}->{617473867} = "Doomadgee";
$areanames{en}->{617473870} = "Eddington";
$areanames{en}->{617473871} = "Eddington";
$areanames{en}->{617473872} = "Eddington";
$areanames{en}->{617473873} = "Eddington";
$areanames{en}->{617473874} = "Eddington";
$areanames{en}->{617473875} = "Eddington";
$areanames{en}->{617473876} = "Eddington";
$areanames{en}->{617473877} = "Eddington";
$areanames{en}->{617473880} = "Georgina";
$areanames{en}->{617473881} = "Georgina";
$areanames{en}->{617473882} = "Georgina";
$areanames{en}->{617473883} = "Georgina";
$areanames{en}->{617473884} = "Georgina";
$areanames{en}->{617473885} = "Georgina";
$areanames{en}->{617473886} = "Georgina";
$areanames{en}->{617473887} = "Georgina";
$areanames{en}->{617473890} = "Gulf";
$areanames{en}->{617473891} = "Gulf";
$areanames{en}->{617473892} = "Gulf";
$areanames{en}->{617473893} = "Gulf";
$areanames{en}->{617473894} = "Gulf";
$areanames{en}->{617473895} = "Gulf";
$areanames{en}->{617473896} = "Gulf";
$areanames{en}->{617473897} = "Gulf";
$areanames{en}->{617473900} = "Gunpowder";
$areanames{en}->{617473901} = "Gunpowder";
$areanames{en}->{617473902} = "Gunpowder";
$areanames{en}->{617473903} = "Gunpowder";
$areanames{en}->{617473904} = "Gunpowder";
$areanames{en}->{617473905} = "Gunpowder";
$areanames{en}->{617473906} = "Gunpowder";
$areanames{en}->{617473907} = "Gunpowder";
$areanames{en}->{617473910} = "Gununa";
$areanames{en}->{617473911} = "Gununa";
$areanames{en}->{617473912} = "Gununa";
$areanames{en}->{617473913} = "Gununa";
$areanames{en}->{617473914} = "Gununa";
$areanames{en}->{617473915} = "Gununa";
$areanames{en}->{617473916} = "Gununa";
$areanames{en}->{617473917} = "Gununa";
$areanames{en}->{617473920} = "Julia\ Creek";
$areanames{en}->{617473921} = "Julia\ Creek";
$areanames{en}->{617473922} = "Julia\ Creek";
$areanames{en}->{617473923} = "Julia\ Creek";
$areanames{en}->{617473924} = "Julia\ Creek";
$areanames{en}->{617473925} = "Julia\ Creek";
$areanames{en}->{617473926} = "Julia\ Creek";
$areanames{en}->{617473930} = "Kalkadoon";
$areanames{en}->{617473931} = "Kalkadoon";
$areanames{en}->{617473932} = "Kalkadoon";
$areanames{en}->{617473933} = "Kalkadoon";
$areanames{en}->{617473934} = "Kalkadoon";
$areanames{en}->{617473935} = "Kalkadoon";
$areanames{en}->{617473936} = "Kalkadoon";
$areanames{en}->{617473937} = "Kalkadoon";
$areanames{en}->{617473940} = "Karumba";
$areanames{en}->{617473941} = "Karumba";
$areanames{en}->{617473942} = "Karumba";
$areanames{en}->{617473943} = "Karumba";
$areanames{en}->{617473944} = "Karumba";
$areanames{en}->{617473945} = "Karumba";
$areanames{en}->{617473946} = "Karumba";
$areanames{en}->{617473947} = "Karumba";
$areanames{en}->{617473950} = "Mount\ Isa";
$areanames{en}->{617473951} = "Mount\ Isa";
$areanames{en}->{617473952} = "Mount\ Isa";
$areanames{en}->{617473953} = "Mount\ Isa";
$areanames{en}->{617473954} = "Mount\ Isa";
$areanames{en}->{617473960} = "Normanton";
$areanames{en}->{617473961} = "Normanton";
$areanames{en}->{617473962} = "Normanton";
$areanames{en}->{617473963} = "Normanton";
$areanames{en}->{617473964} = "Normanton";
$areanames{en}->{617473965} = "Normanton";
$areanames{en}->{617473966} = "Normanton";
$areanames{en}->{617473970} = "The\ Monument";
$areanames{en}->{617473971} = "The\ Monument";
$areanames{en}->{617473972} = "The\ Monument";
$areanames{en}->{617473973} = "The\ Monument";
$areanames{en}->{617473974} = "The\ Monument";
$areanames{en}->{617473975} = "The\ Monument";
$areanames{en}->{617473976} = "The\ Monument";
$areanames{en}->{617473977} = "The\ Monument";
$areanames{en}->{617473980} = "Flinders";
$areanames{en}->{617473981} = "Flinders";
$areanames{en}->{617473982} = "Flinders";
$areanames{en}->{617473983} = "Flinders";
$areanames{en}->{617473984} = "Flinders";
$areanames{en}->{617473985} = "Flinders";
$areanames{en}->{617473986} = "Flinders";
$areanames{en}->{617473987} = "Flinders";
$areanames{en}->{617473990} = "Hughenden";
$areanames{en}->{617473991} = "Hughenden";
$areanames{en}->{617473992} = "Hughenden";
$areanames{en}->{617473993} = "Hughenden";
$areanames{en}->{617473994} = "Hughenden";
$areanames{en}->{617473995} = "Hughenden";
$areanames{en}->{617473996} = "Hughenden";
$areanames{en}->{617473997} = "Hughenden";
$areanames{en}->{617473998} = "Hughenden";
$areanames{en}->{61747400} = "Mount\ Isa";
$areanames{en}->{61747401} = "Mount\ Isa";
$areanames{en}->{61747402} = "Mount\ Isa";
$areanames{en}->{61747403} = "Mount\ Isa";
$areanames{en}->{61747404} = "Townsville";
$areanames{en}->{61747405} = "Charters\ Towers";
$areanames{en}->{61747406} = "Clarke";
$areanames{en}->{61747407} = "Hughenden";
$areanames{en}->{61747408} = "Collinsville";
$areanames{en}->{61747409} = "Dalbeg";
$areanames{en}->{61747410} = "Hughenden";
$areanames{en}->{61747411} = "Hughenden";
$areanames{en}->{61747412} = "Hughenden";
$areanames{en}->{61747413} = "Richmond";
$areanames{en}->{61747414} = "Richmond";
$areanames{en}->{61747415} = "Prairie";
$areanames{en}->{61747416} = "Richmond";
$areanames{en}->{61747417} = "Walker";
$areanames{en}->{61747418} = "Flinders";
$areanames{en}->{61747419} = "Hughenden";
$areanames{en}->{6174742} = "Cloncurry";
$areanames{en}->{61747425} = "Kalkadoon";
$areanames{en}->{61747426} = "Kalkadoon";
$areanames{en}->{61747427} = "Kalkadoon";
$areanames{en}->{61747429} = "Doomadgee";
$areanames{en}->{61747440} = "Mount\ Isa";
$areanames{en}->{61747441} = "Mount\ Isa";
$areanames{en}->{61747442} = "Mount\ Isa";
$areanames{en}->{61747443} = "Mount\ Isa";
$areanames{en}->{61747444} = "Mount\ Isa";
$areanames{en}->{61747445} = "Mount\ Isa";
$areanames{en}->{61747446} = "Mount\ Isa";
$areanames{en}->{617474470} = "Barkly";
$areanames{en}->{61747448} = "Mount\ Isa";
$areanames{en}->{61747449} = "Mount\ Isa";
$areanames{en}->{61747450} = "Mount\ Isa";
$areanames{en}->{61747451} = "Normanton";
$areanames{en}->{61747452} = "Normanton";
$areanames{en}->{61747453} = "Gulf";
$areanames{en}->{61747454} = "Mount\ Isa";
$areanames{en}->{61747455} = "Burketown";
$areanames{en}->{61747456} = "Croydon";
$areanames{en}->{61747457} = "Gununa";
$areanames{en}->{61747458} = "Doomadgee";
$areanames{en}->{61747459} = "Karumba";
$areanames{en}->{61747460} = "Georgina";
$areanames{en}->{61747461} = "Georgina";
$areanames{en}->{61747462} = "Boulia";
$areanames{en}->{61747463} = "Boulia";
$areanames{en}->{61747464} = "Julia\ Creek";
$areanames{en}->{61747465} = "Julia\ Creek";
$areanames{en}->{61747466} = "Julia\ Creek";
$areanames{en}->{61747467} = "Julia\ Creek";
$areanames{en}->{61747468} = "Eddington";
$areanames{en}->{61747469} = "Eddington";
$areanames{en}->{61747470} = "The\ Monument";
$areanames{en}->{61747471} = "The\ Monument";
$areanames{en}->{61747472} = "Mount\ Isa";
$areanames{en}->{61747473} = "Mount\ Isa";
$areanames{en}->{61747474} = "Eddington";
$areanames{en}->{61747475} = "Gulf";
$areanames{en}->{61747476} = "Karumba";
$areanames{en}->{61747477} = "Karumba";
$areanames{en}->{61747478} = "Normanton";
$areanames{en}->{61747479} = "Gununa";
$areanames{en}->{61747480} = "Barkly";
$areanames{en}->{61747481} = "Camooweal";
$areanames{en}->{61747482} = "Camooweal";
$areanames{en}->{61747483} = "Barkly";
$areanames{en}->{61747484} = "Barkly";
$areanames{en}->{61747485} = "Barkly";
$areanames{en}->{61747486} = "Burketown";
$areanames{en}->{61747487} = "Croydon";
$areanames{en}->{61747488} = "Gunpowder";
$areanames{en}->{61747489} = "Gunpowder";
$areanames{en}->{6174749} = "Mount\ Isa";
$areanames{en}->{6174750} = "Townsville";
$areanames{en}->{6174751} = "Yabulu";
$areanames{en}->{61747520} = "Charters\ Towers";
$areanames{en}->{61747521} = "Townsville";
$areanames{en}->{61747522} = "Townsville";
$areanames{en}->{61747523} = "Ravenswood";
$areanames{en}->{61747524} = "Home\ Hill";
$areanames{en}->{61747525} = "Palm\ Island";
$areanames{en}->{61747526} = "Ayr";
$areanames{en}->{61747527} = "Halifax";
$areanames{en}->{61747528} = "Ingham";
$areanames{en}->{61747529} = "Cape\ River";
$areanames{en}->{6174753} = "Townsville";
$areanames{en}->{61747540} = "Burdekin";
$areanames{en}->{61747541} = "Clarke";
$areanames{en}->{61747542} = "Greenvale";
$areanames{en}->{61747543} = "Cape\ River";
$areanames{en}->{61747544} = "Pentland";
$areanames{en}->{61747545} = "Charters\ Towers";
$areanames{en}->{61747546} = "Charters\ Towers";
$areanames{en}->{61747547} = "Charters\ Towers";
$areanames{en}->{61747548} = "Kirk";
$areanames{en}->{61747549} = "Ravenswood";
$areanames{en}->{6174755} = "Townsville";
$areanames{en}->{61747560} = "Charters\ Towers";
$areanames{en}->{61747561} = "Charters\ Towers";
$areanames{en}->{61747562} = "Charters\ Towers";
$areanames{en}->{61747563} = "Briaba";
$areanames{en}->{61747564} = "Giru";
$areanames{en}->{61747565} = "Greenvale";
$areanames{en}->{61747566} = "Collinsville";
$areanames{en}->{61747567} = "Woodstock";
$areanames{en}->{61747568} = "Woodstock";
$areanames{en}->{61747569} = "Woodstock";
$areanames{en}->{61747570} = "Gumlu";
$areanames{en}->{61747571} = "Halifax";
$areanames{en}->{61747572} = "Home\ Hill";
$areanames{en}->{61747573} = "Ingham";
$areanames{en}->{61747574} = "Kirk";
$areanames{en}->{61747575} = "Leichhardt\ Range";
$areanames{en}->{61747576} = "Yabulu";
$areanames{en}->{61747577} = "Yabulu";
$areanames{en}->{61747578} = "Yabulu";
$areanames{en}->{61747579} = "Yabulu";
$areanames{en}->{6174758} = "Townsville";
$areanames{en}->{6174759} = "Townsville";
$areanames{en}->{6174760} = "Townsville";
$areanames{en}->{61747610} = "Ayr";
$areanames{en}->{61747611} = "Ayr";
$areanames{en}->{61747612} = "Ayr";
$areanames{en}->{61747613} = "Bowen";
$areanames{en}->{61747614} = "Bowen";
$areanames{en}->{61747615} = "Charters\ Towers";
$areanames{en}->{61747616} = "Charters\ Towers";
$areanames{en}->{61747617} = "Ingham";
$areanames{en}->{61747618} = "Townsville";
$areanames{en}->{61747619} = "Townsville";
$areanames{en}->{61747620} = "Eddington";
$areanames{en}->{61747621} = "Eddington";
$areanames{en}->{61747622} = "Eddington";
$areanames{en}->{61747623} = "Kalkadoon";
$areanames{en}->{61747624} = "Kalkadoon";
$areanames{en}->{61747625} = "Barkly";
$areanames{en}->{61747626} = "Barkly";
$areanames{en}->{61747627} = "Townsville";
$areanames{en}->{61747628} = "Gulf";
$areanames{en}->{61747629} = "Gulf";
$areanames{en}->{61747630} = "Ayr";
$areanames{en}->{61747631} = "Ayr";
$areanames{en}->{61747632} = "Ayr";
$areanames{en}->{617476330} = "Prairie";
$areanames{en}->{617476331} = "Prairie";
$areanames{en}->{617476332} = "Prairie";
$areanames{en}->{617476333} = "Prairie";
$areanames{en}->{617476334} = "Prairie";
$areanames{en}->{617476335} = "Prairie";
$areanames{en}->{617476336} = "Prairie";
$areanames{en}->{617476337} = "Prairie";
$areanames{en}->{617476338} = "Prairie";
$areanames{en}->{61747634} = "Bowen";
$areanames{en}->{617476350} = "Richmond";
$areanames{en}->{617476351} = "Richmond";
$areanames{en}->{617476352} = "Richmond";
$areanames{en}->{617476353} = "Richmond";
$areanames{en}->{617476354} = "Richmond";
$areanames{en}->{617476355} = "Richmond";
$areanames{en}->{617476356} = "Richmond";
$areanames{en}->{617476357} = "Richmond";
$areanames{en}->{617476358} = "Richmond";
$areanames{en}->{617476360} = "Walker";
$areanames{en}->{617476361} = "Walker";
$areanames{en}->{617476362} = "Walker";
$areanames{en}->{617476363} = "Walker";
$areanames{en}->{617476364} = "Walker";
$areanames{en}->{617476365} = "Walker";
$areanames{en}->{617476366} = "Walker";
$areanames{en}->{617476367} = "Walker";
$areanames{en}->{617476368} = "Walker";
$areanames{en}->{617476370} = "Ayr";
$areanames{en}->{617476371} = "Ayr";
$areanames{en}->{617476372} = "Ayr";
$areanames{en}->{617476373} = "Ayr";
$areanames{en}->{617476374} = "Ayr";
$areanames{en}->{617476380} = "Bambaroo";
$areanames{en}->{617476381} = "Bambaroo";
$areanames{en}->{617476382} = "Bambaroo";
$areanames{en}->{617476383} = "Bambaroo";
$areanames{en}->{617476384} = "Bambaroo";
$areanames{en}->{617476385} = "Bambaroo";
$areanames{en}->{617476388} = "Bambaroo";
$areanames{en}->{617476390} = "Bowen";
$areanames{en}->{617476391} = "Bowen";
$areanames{en}->{617476392} = "Bowen";
$areanames{en}->{617476393} = "Bowen";
$areanames{en}->{617476394} = "Bowen";
$areanames{en}->{617476397} = "Bowen";
$areanames{en}->{61747640} = "Mount\ Isa";
$areanames{en}->{61747641} = "Mount\ Isa";
$areanames{en}->{617476420} = "Briaba";
$areanames{en}->{617476421} = "Briaba";
$areanames{en}->{617476422} = "Briaba";
$areanames{en}->{617476423} = "Briaba";
$areanames{en}->{617476424} = "Briaba";
$areanames{en}->{617476425} = "Briaba";
$areanames{en}->{617476428} = "Briaba";
$areanames{en}->{617476430} = "Burdekin";
$areanames{en}->{617476431} = "Burdekin";
$areanames{en}->{617476432} = "Burdekin";
$areanames{en}->{617476433} = "Burdekin";
$areanames{en}->{617476434} = "Burdekin";
$areanames{en}->{617476435} = "Burdekin";
$areanames{en}->{617476438} = "Burdekin";
$areanames{en}->{617476440} = "Cape\ River";
$areanames{en}->{617476441} = "Cape\ River";
$areanames{en}->{617476442} = "Cape\ River";
$areanames{en}->{617476443} = "Cape\ River";
$areanames{en}->{617476444} = "Cape\ River";
$areanames{en}->{617476445} = "Cape\ River";
$areanames{en}->{617476448} = "Cape\ River";
$areanames{en}->{617476450} = "Charters\ Towers";
$areanames{en}->{617476451} = "Charters\ Towers";
$areanames{en}->{617476452} = "Charters\ Towers";
$areanames{en}->{617476453} = "Charters\ Towers";
$areanames{en}->{617476454} = "Charters\ Towers";
$areanames{en}->{617476457} = "Charters\ Towers";
$areanames{en}->{617476460} = "Clarke";
$areanames{en}->{617476461} = "Clarke";
$areanames{en}->{617476462} = "Clarke";
$areanames{en}->{617476463} = "Clarke";
$areanames{en}->{617476464} = "Clarke";
$areanames{en}->{617476465} = "Clarke";
$areanames{en}->{617476468} = "Clarke";
$areanames{en}->{617476470} = "Collinsville";
$areanames{en}->{617476471} = "Collinsville";
$areanames{en}->{617476472} = "Collinsville";
$areanames{en}->{617476473} = "Collinsville";
$areanames{en}->{617476474} = "Collinsville";
$areanames{en}->{617476475} = "Collinsville";
$areanames{en}->{617476478} = "Collinsville";
$areanames{en}->{617476480} = "Dalbeg";
$areanames{en}->{617476481} = "Dalbeg";
$areanames{en}->{617476482} = "Dalbeg";
$areanames{en}->{617476483} = "Dalbeg";
$areanames{en}->{617476484} = "Dalbeg";
$areanames{en}->{617476485} = "Dalbeg";
$areanames{en}->{617476488} = "Dalbeg";
$areanames{en}->{617476490} = "Giru";
$areanames{en}->{617476491} = "Giru";
$areanames{en}->{617476492} = "Giru";
$areanames{en}->{617476493} = "Giru";
$areanames{en}->{617476494} = "Giru";
$areanames{en}->{617476495} = "Giru";
$areanames{en}->{617476498} = "Giru";
$areanames{en}->{617476500} = "Greenvale";
$areanames{en}->{617476501} = "Greenvale";
$areanames{en}->{617476502} = "Greenvale";
$areanames{en}->{617476503} = "Greenvale";
$areanames{en}->{617476504} = "Greenvale";
$areanames{en}->{617476505} = "Greenvale";
$areanames{en}->{617476508} = "Greenvale";
$areanames{en}->{617476510} = "Gumlu";
$areanames{en}->{617476511} = "Gumlu";
$areanames{en}->{617476512} = "Gumlu";
$areanames{en}->{617476513} = "Gumlu";
$areanames{en}->{617476514} = "Gumlu";
$areanames{en}->{617476515} = "Gumlu";
$areanames{en}->{617476518} = "Gumlu";
$areanames{en}->{617476520} = "Halifax";
$areanames{en}->{617476521} = "Halifax";
$areanames{en}->{617476522} = "Halifax";
$areanames{en}->{617476523} = "Halifax";
$areanames{en}->{617476524} = "Halifax";
$areanames{en}->{617476525} = "Halifax";
$areanames{en}->{617476528} = "Halifax";
$areanames{en}->{617476530} = "Home\ Hill";
$areanames{en}->{617476531} = "Home\ Hill";
$areanames{en}->{617476532} = "Home\ Hill";
$areanames{en}->{617476533} = "Home\ Hill";
$areanames{en}->{617476534} = "Home\ Hill";
$areanames{en}->{617476535} = "Home\ Hill";
$areanames{en}->{617476538} = "Home\ Hill";
$areanames{en}->{617476540} = "Ingham";
$areanames{en}->{617476541} = "Ingham";
$areanames{en}->{617476542} = "Ingham";
$areanames{en}->{617476543} = "Ingham";
$areanames{en}->{617476544} = "Ingham";
$areanames{en}->{617476547} = "Ingham";
$areanames{en}->{617476550} = "Kirk";
$areanames{en}->{617476551} = "Kirk";
$areanames{en}->{617476552} = "Kirk";
$areanames{en}->{617476553} = "Kirk";
$areanames{en}->{617476554} = "Kirk";
$areanames{en}->{617476555} = "Kirk";
$areanames{en}->{617476558} = "Kirk";
$areanames{en}->{617476560} = "Leichhardt\ Range";
$areanames{en}->{617476561} = "Leichhardt\ Range";
$areanames{en}->{617476562} = "Leichhardt\ Range";
$areanames{en}->{617476563} = "Leichhardt\ Range";
$areanames{en}->{617476564} = "Leichhardt\ Range";
$areanames{en}->{617476565} = "Leichhardt\ Range";
$areanames{en}->{617476568} = "Leichhardt\ Range";
$areanames{en}->{617476570} = "Long\ Pocket";
$areanames{en}->{617476571} = "Long\ Pocket";
$areanames{en}->{617476572} = "Long\ Pocket";
$areanames{en}->{617476573} = "Long\ Pocket";
$areanames{en}->{617476574} = "Long\ Pocket";
$areanames{en}->{617476575} = "Long\ Pocket";
$areanames{en}->{617476578} = "Long\ Pocket";
$areanames{en}->{617476580} = "Millaroo";
$areanames{en}->{617476581} = "Millaroo";
$areanames{en}->{617476582} = "Millaroo";
$areanames{en}->{617476583} = "Millaroo";
$areanames{en}->{617476584} = "Millaroo";
$areanames{en}->{617476585} = "Millaroo";
$areanames{en}->{617476588} = "Millaroo";
$areanames{en}->{617476590} = "Mount\ Fox";
$areanames{en}->{617476591} = "Mount\ Fox";
$areanames{en}->{617476592} = "Mount\ Fox";
$areanames{en}->{617476593} = "Mount\ Fox";
$areanames{en}->{617476594} = "Mount\ Fox";
$areanames{en}->{617476595} = "Mount\ Fox";
$areanames{en}->{617476598} = "Mount\ Fox";
$areanames{en}->{6174766} = "Townsville";
$areanames{en}->{61747670} = "Mutarnee";
$areanames{en}->{617476705} = "Ayr";
$areanames{en}->{617476710} = "Palm\ Island";
$areanames{en}->{617476711} = "Palm\ Island";
$areanames{en}->{617476712} = "Palm\ Island";
$areanames{en}->{617476713} = "Palm\ Island";
$areanames{en}->{617476714} = "Palm\ Island";
$areanames{en}->{617476715} = "Palm\ Island";
$areanames{en}->{617476718} = "Palm\ Island";
$areanames{en}->{617476720} = "Pentland";
$areanames{en}->{617476721} = "Pentland";
$areanames{en}->{617476722} = "Pentland";
$areanames{en}->{617476723} = "Pentland";
$areanames{en}->{617476724} = "Pentland";
$areanames{en}->{617476725} = "Pentland";
$areanames{en}->{617476728} = "Pentland";
$areanames{en}->{617476730} = "Ravenswood";
$areanames{en}->{617476731} = "Ravenswood";
$areanames{en}->{617476732} = "Ravenswood";
$areanames{en}->{617476733} = "Ravenswood";
$areanames{en}->{617476734} = "Ravenswood";
$areanames{en}->{617476735} = "Ravenswood";
$areanames{en}->{617476738} = "Ravenswood";
$areanames{en}->{617476740} = "Rollingstone";
$areanames{en}->{617476741} = "Rollingstone";
$areanames{en}->{617476742} = "Rollingstone";
$areanames{en}->{617476743} = "Rollingstone";
$areanames{en}->{617476744} = "Rollingstone";
$areanames{en}->{617476745} = "Rollingstone";
$areanames{en}->{617476748} = "Rollingstone";
$areanames{en}->{617476750} = "Townsville";
$areanames{en}->{617476751} = "Townsville";
$areanames{en}->{617476752} = "Townsville";
$areanames{en}->{617476753} = "Townsville";
$areanames{en}->{617476754} = "Townsville";
$areanames{en}->{617476755} = "Townsville";
$areanames{en}->{617476756} = "Townsville";
$areanames{en}->{61747676} = "Townsville";
$areanames{en}->{61747677} = "Townsville";
$areanames{en}->{61747678} = "Charters\ Towers";
$areanames{en}->{61747679} = "Flinders";
$areanames{en}->{61747680} = "Flinders";
$areanames{en}->{61747681} = "Flinders";
$areanames{en}->{61747682} = "Hughenden";
$areanames{en}->{61747683} = "Long\ Pocket";
$areanames{en}->{61747684} = "Millaroo";
$areanames{en}->{61747685} = "Prairie";
$areanames{en}->{61747686} = "Richmond";
$areanames{en}->{61747687} = "Richmond";
$areanames{en}->{61747688} = "Walker";
$areanames{en}->{61747689} = "Walker";
$areanames{en}->{61747690} = "Julia\ Creek";
$areanames{en}->{61747691} = "Eddington";
$areanames{en}->{61747692} = "Eddington";
$areanames{en}->{61747693} = "Cloncurry";
$areanames{en}->{61747694} = "Kalkadoon";
$areanames{en}->{61747695} = "Barkly";
$areanames{en}->{61747696} = "Kalkadoon";
$areanames{en}->{61747697} = "Normanton";
$areanames{en}->{61747698} = "Gulf";
$areanames{en}->{61747699} = "Barkly";
$areanames{en}->{61747700} = "Palm\ Island";
$areanames{en}->{61747701} = "Palm\ Island";
$areanames{en}->{61747702} = "Ravenswood";
$areanames{en}->{61747703} = "Kirk";
$areanames{en}->{61747704} = "Burdekin";
$areanames{en}->{61747705} = "Rollingstone";
$areanames{en}->{61747706} = "Woodstock";
$areanames{en}->{61747707} = "Rollingstone";
$areanames{en}->{61747708} = "Mutarnee";
$areanames{en}->{61747709} = "Mutarnee";
$areanames{en}->{6174771} = "Townsville";
$areanames{en}->{6174772} = "Townsville";
$areanames{en}->{6174773} = "Townsville";
$areanames{en}->{6174774} = "Townsville";
$areanames{en}->{6174775} = "Townsville";
$areanames{en}->{6174776} = "Ingham";
$areanames{en}->{61747770} = "Halifax";
$areanames{en}->{61747771} = "Ingham";
$areanames{en}->{61747772} = "Ingham";
$areanames{en}->{61747773} = "Bambaroo";
$areanames{en}->{61747774} = "Long\ Pocket";
$areanames{en}->{61747775} = "Mount\ Fox";
$areanames{en}->{61747776} = "Upper\ Stone";
$areanames{en}->{61747777} = "Halifax";
$areanames{en}->{61747778} = "Halifax";
$areanames{en}->{61747779} = "Halifax";
$areanames{en}->{6174778} = "Townsville";
$areanames{en}->{61747780} = "Yabulu";
$areanames{en}->{61747786} = "Yabulu";
$areanames{en}->{61747787} = "Yabulu";
$areanames{en}->{61747788} = "Woodstock";
$areanames{en}->{6174780} = "Woodstock";
$areanames{en}->{61747807} = "Collinsville";
$areanames{en}->{61747808} = "Long\ Pocket";
$areanames{en}->{61747809} = "Long\ Pocket";
$areanames{en}->{6174781} = "Townsville";
$areanames{en}->{6174782} = "Home\ Hill";
$areanames{en}->{61747824} = "Ayr";
$areanames{en}->{61747825} = "Ayr";
$areanames{en}->{61747829} = "Giru";
$areanames{en}->{6174783} = "Ayr";
$areanames{en}->{61747840} = "Dalbeg";
$areanames{en}->{61747841} = "Ayr";
$areanames{en}->{61747842} = "Ayr";
$areanames{en}->{61747843} = "Giru";
$areanames{en}->{61747844} = "Giru";
$areanames{en}->{61747845} = "Gumlu";
$areanames{en}->{61747846} = "Gumlu";
$areanames{en}->{61747847} = "Gumlu";
$areanames{en}->{61747848} = "Gumlu";
$areanames{en}->{61747849} = "Millaroo";
$areanames{en}->{61747850} = "Bowen";
$areanames{en}->{61747851} = "Bowen";
$areanames{en}->{61747852} = "Bowen";
$areanames{en}->{61747853} = "Briaba";
$areanames{en}->{61747854} = "Collinsville";
$areanames{en}->{61747855} = "Collinsville";
$areanames{en}->{61747856} = "Collinsville";
$areanames{en}->{61747857} = "Collinsville";
$areanames{en}->{61747858} = "Collinsville";
$areanames{en}->{61747859} = "Leichhardt\ Range";
$areanames{en}->{6174786} = "Bowen";
$areanames{en}->{6174787} = "Charters\ Towers";
$areanames{en}->{61747876} = "Cape\ River";
$areanames{en}->{61747880} = "Yabulu";
$areanames{en}->{61747881} = "Pentland";
$areanames{en}->{61747882} = "Charters\ Towers";
$areanames{en}->{61747883} = "Giru";
$areanames{en}->{61747884} = "Greenvale";
$areanames{en}->{61747885} = "Clarke";
$areanames{en}->{61747886} = "Yabulu";
$areanames{en}->{61747887} = "Yabulu";
$areanames{en}->{61747888} = "Yabulu";
$areanames{en}->{61747889} = "Yabulu";
$areanames{en}->{6174789} = "Townsville";
$areanames{en}->{61747900} = "Ayr";
$areanames{en}->{61747901} = "Ayr";
$areanames{en}->{61747902} = "Ayr";
$areanames{en}->{61747903} = "Ayr";
$areanames{en}->{61747904} = "Ayr";
$areanames{en}->{61747905} = "Home\ Hill";
$areanames{en}->{61747906} = "Home\ Hill";
$areanames{en}->{61747907} = "Home\ Hill";
$areanames{en}->{61747908} = "Home\ Hill";
$areanames{en}->{61747909} = "Home\ Hill";
$areanames{en}->{61747910} = "Bowen";
$areanames{en}->{61747911} = "Bowen";
$areanames{en}->{61747912} = "Bowen";
$areanames{en}->{61747913} = "Bowen";
$areanames{en}->{61747914} = "Palm\ Island";
$areanames{en}->{61747915} = "Palm\ Island";
$areanames{en}->{61747916} = "Ravenswood";
$areanames{en}->{61747917} = "Ravenswood";
$areanames{en}->{61747918} = "Ravenswood";
$areanames{en}->{61747919} = "Ravenswood";
$areanames{en}->{617479200} = "Upper\ Stone";
$areanames{en}->{617479201} = "Upper\ Stone";
$areanames{en}->{617479202} = "Upper\ Stone";
$areanames{en}->{617479203} = "Upper\ Stone";
$areanames{en}->{617479204} = "Upper\ Stone";
$areanames{en}->{617479205} = "Upper\ Stone";
$areanames{en}->{617479208} = "Upper\ Stone";
$areanames{en}->{617479210} = "Woodstock";
$areanames{en}->{617479211} = "Woodstock";
$areanames{en}->{617479212} = "Woodstock";
$areanames{en}->{617479213} = "Woodstock";
$areanames{en}->{617479214} = "Woodstock";
$areanames{en}->{617479215} = "Woodstock";
$areanames{en}->{617479218} = "Woodstock";
$areanames{en}->{617479220} = "Yabulu";
$areanames{en}->{617479221} = "Yabulu";
$areanames{en}->{617479222} = "Yabulu";
$areanames{en}->{617479223} = "Yabulu";
$areanames{en}->{617479224} = "Yabulu";
$areanames{en}->{617479225} = "Yabulu";
$areanames{en}->{617479228} = "Yabulu";
$areanames{en}->{617479230} = "Croydon";
$areanames{en}->{617479231} = "Croydon";
$areanames{en}->{617479232} = "Croydon";
$areanames{en}->{617479233} = "Croydon";
$areanames{en}->{617479234} = "Croydon";
$areanames{en}->{617479235} = "Croydon";
$areanames{en}->{617479236} = "Croydon";
$areanames{en}->{617479237} = "Croydon";
$areanames{en}->{61747924} = "Burdekin";
$areanames{en}->{61747925} = "Burdekin\/Cape\ River";
$areanames{en}->{61747926} = "Cape\ River\/Mount\ Fox";
$areanames{en}->{61747927} = "Mount\ Fox\/Mutarnee";
$areanames{en}->{61747928} = "Mutarnee\/Palm\ Island";
$areanames{en}->{61747929} = "Palm\ Island";
$areanames{en}->{61747930} = "Cape\ River";
$areanames{en}->{61747931} = "Cape\ River";
$areanames{en}->{61747932} = "Home\ Hill";
$areanames{en}->{61747933} = "Bowen";
$areanames{en}->{61747934} = "Ayr";
$areanames{en}->{61747935} = "Bowen";
$areanames{en}->{61747936} = "Bowen";
$areanames{en}->{61747937} = "Yabulu";
$areanames{en}->{61747938} = "Yabulu";
$areanames{en}->{61747939} = "Eddington";
$areanames{en}->{61747940} = "Gunpowder";
$areanames{en}->{61747941} = "Gununa";
$areanames{en}->{61747942} = "Julia\ Creek";
$areanames{en}->{61747943} = "Kalkadoon";
$areanames{en}->{61747944} = "Karumba";
$areanames{en}->{61747945} = "Normanton";
$areanames{en}->{61747946} = "The\ Monument";
$areanames{en}->{61747947} = "Flinders";
$areanames{en}->{61747948} = "Cloncurry";
$areanames{en}->{61747949} = "Hughenden";
$areanames{en}->{6174795} = "Townsville";
$areanames{en}->{6174796} = "Townsville";
$areanames{en}->{61747970} = "Ingham";
$areanames{en}->{61747971} = "Ingham";
$areanames{en}->{61747972} = "Ingham";
$areanames{en}->{61747973} = "Ingham";
$areanames{en}->{61747974} = "Ingham";
$areanames{en}->{61747975} = "Prairie";
$areanames{en}->{61747976} = "Richmond";
$areanames{en}->{61747977} = "Walker";
$areanames{en}->{61747978} = "Bambaroo";
$areanames{en}->{61747979} = "Bowen";
$areanames{en}->{6174798} = "Halifax";
$areanames{en}->{6174799} = "Townsville";
$areanames{en}->{617480000} = "Banana";
$areanames{en}->{617480003} = "Banana";
$areanames{en}->{617480006} = "Banana";
$areanames{en}->{617480007} = "Banana";
$areanames{en}->{617480008} = "Banana";
$areanames{en}->{617480009} = "Agnes\ Water";
$areanames{en}->{61748001} = "Baralaba";
$areanames{en}->{617480019} = "Alpha";
$areanames{en}->{617480020} = "Bauhinia";
$areanames{en}->{617480023} = "Bauhinia";
$areanames{en}->{617480026} = "Bauhinia";
$areanames{en}->{617480027} = "Bauhinia";
$areanames{en}->{617480028} = "Bauhinia";
$areanames{en}->{617480029} = "Bajool";
$areanames{en}->{61748003} = "Biloela";
$areanames{en}->{617480040} = "Cracow";
$areanames{en}->{617480043} = "Cracow";
$areanames{en}->{617480046} = "Cracow";
$areanames{en}->{617480047} = "Cracow";
$areanames{en}->{617480048} = "Cracow";
$areanames{en}->{617480049} = "Mackay";
$areanames{en}->{617480050} = "Goovigen";
$areanames{en}->{617480053} = "Goovigen";
$areanames{en}->{617480056} = "Goovigen";
$areanames{en}->{617480057} = "Goovigen";
$areanames{en}->{617480058} = "Goovigen";
$areanames{en}->{617480059} = "Banana";
$areanames{en}->{617480060} = "Mardale";
$areanames{en}->{617480063} = "Mardale";
$areanames{en}->{617480066} = "Mardale";
$areanames{en}->{617480067} = "Mardale";
$areanames{en}->{617480068} = "Mardale";
$areanames{en}->{617480069} = "Baralaba";
$areanames{en}->{61748007} = "Moura";
$areanames{en}->{617480080} = "Nathan\ Gorge";
$areanames{en}->{617480083} = "Nathan\ Gorge";
$areanames{en}->{617480086} = "Nathan\ Gorge";
$areanames{en}->{617480087} = "Nathan\ Gorge";
$areanames{en}->{617480088} = "Nathan\ Gorge";
$areanames{en}->{617480089} = "Bauhinia";
$areanames{en}->{617480090} = "Oombabeer";
$areanames{en}->{617480093} = "Oombabeer";
$areanames{en}->{617480096} = "Oombabeer";
$areanames{en}->{617480097} = "Oombabeer";
$areanames{en}->{617480098} = "Oombabeer";
$areanames{en}->{617480099} = "Benaraby";
$areanames{en}->{617480100} = "Pegunny";
$areanames{en}->{617480103} = "Pegunny";
$areanames{en}->{617480106} = "Pegunny";
$areanames{en}->{617480107} = "Pegunny";
$areanames{en}->{617480108} = "Pegunny";
$areanames{en}->{617480109} = "Biloela";
$areanames{en}->{617480110} = "Spier";
$areanames{en}->{617480113} = "Spier";
$areanames{en}->{617480116} = "Spier";
$areanames{en}->{617480117} = "Spier";
$areanames{en}->{617480118} = "Spier";
$areanames{en}->{617480119} = "Bingegang";
$areanames{en}->{61748012} = "Theodore";
$areanames{en}->{617480129} = "Blackwater";
$areanames{en}->{617480130} = "Zamia\ Creek";
$areanames{en}->{617480133} = "Zamia\ Creek";
$areanames{en}->{617480136} = "Zamia\ Creek";
$areanames{en}->{617480137} = "Zamia\ Creek";
$areanames{en}->{617480138} = "Zamia\ Creek";
$areanames{en}->{617480139} = "Broadsound";
$areanames{en}->{61748014} = "Alpha";
$areanames{en}->{617480149} = "Buckland";
$areanames{en}->{617480150} = "Belyando";
$areanames{en}->{617480153} = "Belyando";
$areanames{en}->{617480156} = "Belyando";
$areanames{en}->{617480157} = "Belyando";
$areanames{en}->{617480158} = "Belyando";
$areanames{en}->{617480159} = "Byfield";
$areanames{en}->{617480160} = "Bingegang";
$areanames{en}->{617480163} = "Bingegang";
$areanames{en}->{617480166} = "Bingegang";
$areanames{en}->{617480167} = "Bingegang";
$areanames{en}->{617480168} = "Bingegang";
$areanames{en}->{617480169} = "Calen";
$areanames{en}->{61748017} = "Blackwater";
$areanames{en}->{617480180} = "Buckland";
$areanames{en}->{617480183} = "Buckland";
$areanames{en}->{617480186} = "Buckland";
$areanames{en}->{617480187} = "Buckland";
$areanames{en}->{617480188} = "Buckland";
$areanames{en}->{617480189} = "Calliope";
$areanames{en}->{61748019} = "Capella";
$areanames{en}->{617480199} = "Cannon\ Valley";
$areanames{en}->{617480200} = "Carbine\ Creek";
$areanames{en}->{617480203} = "Carbine\ Creek";
$areanames{en}->{617480206} = "Carbine\ Creek";
$areanames{en}->{617480207} = "Carbine\ Creek";
$areanames{en}->{617480208} = "Carbine\ Creek";
$areanames{en}->{617480209} = "Capella";
$areanames{en}->{61748021} = "Clermont";
$areanames{en}->{617480220} = "Comet";
$areanames{en}->{617480223} = "Comet";
$areanames{en}->{617480226} = "Comet";
$areanames{en}->{617480227} = "Comet";
$areanames{en}->{617480228} = "Comet";
$areanames{en}->{617480229} = "Carbine\ Creek";
$areanames{en}->{617480230} = "Emerald";
$areanames{en}->{617480231} = "Emerald";
$areanames{en}->{617480232} = "Emerald";
$areanames{en}->{617480233} = "Emerald";
$areanames{en}->{617480234} = "Emerald";
$areanames{en}->{617480237} = "Carmila";
$areanames{en}->{617480238} = "Clermont";
$areanames{en}->{617480239} = "Colston\ Park";
$areanames{en}->{617480240} = "Gemfields";
$areanames{en}->{617480243} = "Gemfields";
$areanames{en}->{617480246} = "Gemfields";
$areanames{en}->{617480247} = "Gemfields";
$areanames{en}->{617480248} = "Gemfields";
$areanames{en}->{617480249} = "Comet";
$areanames{en}->{617480250} = "Hodgson\ Range";
$areanames{en}->{617480253} = "Hodgson\ Range";
$areanames{en}->{617480256} = "Hodgson\ Range";
$areanames{en}->{617480257} = "Hodgson\ Range";
$areanames{en}->{617480258} = "Hodgson\ Range";
$areanames{en}->{617480259} = "Connors\ Range";
$areanames{en}->{617480260} = "Miclere";
$areanames{en}->{617480263} = "Miclere";
$areanames{en}->{617480266} = "Miclere";
$areanames{en}->{617480267} = "Miclere";
$areanames{en}->{617480268} = "Miclere";
$areanames{en}->{617480269} = "Cracow";
$areanames{en}->{61748027} = "Middlemount";
$areanames{en}->{617480280} = "Mount\ Coolon";
$areanames{en}->{617480283} = "Mount\ Coolon";
$areanames{en}->{617480286} = "Mount\ Coolon";
$areanames{en}->{617480287} = "Mount\ Coolon";
$areanames{en}->{617480288} = "Mount\ Coolon";
$areanames{en}->{617480289} = "Dingo";
$areanames{en}->{617480290} = "Nogoa";
$areanames{en}->{617480293} = "Nogoa";
$areanames{en}->{617480296} = "Nogoa";
$areanames{en}->{617480297} = "Nogoa";
$areanames{en}->{617480298} = "Nogoa";
$areanames{en}->{617480299} = "Dingo\ Beach";
$areanames{en}->{617480300} = "Orion";
$areanames{en}->{617480303} = "Orion";
$areanames{en}->{617480306} = "Orion";
$areanames{en}->{617480307} = "Orion";
$areanames{en}->{617480308} = "Orion";
$areanames{en}->{617480309} = "Duaringa";
$areanames{en}->{617480310} = "Rolleston";
$areanames{en}->{617480313} = "Rolleston";
$areanames{en}->{617480316} = "Rolleston";
$areanames{en}->{617480317} = "Rolleston";
$areanames{en}->{617480318} = "Rolleston";
$areanames{en}->{617480319} = "Dysart";
$areanames{en}->{61748032} = "Springsure";
$areanames{en}->{617480329} = "Emerald";
$areanames{en}->{61748033} = "Tieri";
$areanames{en}->{617480340} = "Willows";
$areanames{en}->{617480343} = "Willows";
$areanames{en}->{617480346} = "Willows";
$areanames{en}->{617480347} = "Willows";
$areanames{en}->{617480348} = "Willows";
$areanames{en}->{617480349} = "Finch\ Hatton";
$areanames{en}->{617480350} = "Agnes\ Water";
$areanames{en}->{617480351} = "Agnes\ Water";
$areanames{en}->{617480352} = "Agnes\ Water";
$areanames{en}->{617480353} = "Agnes\ Water";
$areanames{en}->{617480354} = "Agnes\ Water";
$areanames{en}->{617480355} = "Agnes\ Water";
$areanames{en}->{617480358} = "Agnes\ Water";
$areanames{en}->{617480359} = "Fitzroy\ West";
$areanames{en}->{61748036} = "Benaraby";
$areanames{en}->{61748037} = "Calliope";
$areanames{en}->{617480380} = "Gayfield";
$areanames{en}->{617480383} = "Gayfield";
$areanames{en}->{617480386} = "Gayfield";
$areanames{en}->{617480387} = "Gayfield";
$areanames{en}->{617480388} = "Gayfield";
$areanames{en}->{617480389} = "Gargett";
$areanames{en}->{617480390} = "Gladstone";
$areanames{en}->{617480391} = "Gladstone";
$areanames{en}->{617480392} = "Gladstone";
$areanames{en}->{617480393} = "Gladstone";
$areanames{en}->{617480394} = "Gladstone";
$areanames{en}->{617480397} = "Garnant";
$areanames{en}->{617480398} = "Gayfield";
$areanames{en}->{617480399} = "Gemfields";
$areanames{en}->{61748040} = "Miriam\ Vale";
$areanames{en}->{61748041} = "Mount\ Larcom";
$areanames{en}->{617480419} = "Gladstone";
$areanames{en}->{617480420} = "Turkey\ Beach";
$areanames{en}->{617480423} = "Turkey\ Beach";
$areanames{en}->{617480426} = "Turkey\ Beach";
$areanames{en}->{617480427} = "Turkey\ Beach";
$areanames{en}->{617480428} = "Turkey\ Beach";
$areanames{en}->{617480429} = "Glenden";
$areanames{en}->{617480430} = "Ubobo";
$areanames{en}->{617480433} = "Ubobo";
$areanames{en}->{617480436} = "Ubobo";
$areanames{en}->{617480437} = "Ubobo";
$areanames{en}->{617480438} = "Ubobo";
$areanames{en}->{617480439} = "Goovigen";
$areanames{en}->{61748044} = "Calen";
$areanames{en}->{617480449} = "Hodgson\ Range";
$areanames{en}->{617480450} = "Cannon\ Valley";
$areanames{en}->{617480451} = "Cannon\ Valley";
$areanames{en}->{617480452} = "Cannon\ Valley";
$areanames{en}->{617480453} = "Cannon\ Valley";
$areanames{en}->{617480454} = "Cannon\ Valley";
$areanames{en}->{617480457} = "Isaac\ River";
$areanames{en}->{617480458} = "Cannon\ Valley";
$areanames{en}->{617480459} = "Koumala";
$areanames{en}->{617480460} = "Carmila";
$areanames{en}->{617480463} = "Carmila";
$areanames{en}->{617480466} = "Carmila";
$areanames{en}->{617480467} = "Carmila";
$areanames{en}->{617480468} = "Carmila";
$areanames{en}->{617480469} = "Lethebrook";
$areanames{en}->{617480470} = "Colston\ Park";
$areanames{en}->{617480473} = "Colston\ Park";
$areanames{en}->{617480476} = "Colston\ Park";
$areanames{en}->{617480477} = "Colston\ Park";
$areanames{en}->{617480478} = "Colston\ Park";
$areanames{en}->{617480479} = "Mackay";
$areanames{en}->{617480480} = "Connors\ Range";
$areanames{en}->{617480483} = "Connors\ Range";
$areanames{en}->{617480486} = "Connors\ Range";
$areanames{en}->{617480487} = "Connors\ Range";
$areanames{en}->{617480488} = "Connors\ Range";
$areanames{en}->{617480489} = "Mardale";
$areanames{en}->{61748049} = "Dingo\ Beach";
$areanames{en}->{617480499} = "Marlborough";
$areanames{en}->{61748050} = "Dysart";
$areanames{en}->{617480509} = "Miclere";
$areanames{en}->{617480510} = "Finch\ Hatton";
$areanames{en}->{617480513} = "Finch\ Hatton";
$areanames{en}->{617480516} = "Finch\ Hatton";
$areanames{en}->{617480517} = "Finch\ Hatton";
$areanames{en}->{617480518} = "Finch\ Hatton";
$areanames{en}->{617480519} = "Middlemount";
$areanames{en}->{617480520} = "Gargett";
$areanames{en}->{617480523} = "Gargett";
$areanames{en}->{617480526} = "Gargett";
$areanames{en}->{617480527} = "Gargett";
$areanames{en}->{617480528} = "Gargett";
$areanames{en}->{617480529} = "Miriam\ Vale";
$areanames{en}->{61748053} = "Glenden";
$areanames{en}->{617480539} = "Moranbah";
$areanames{en}->{617480540} = "Koumala";
$areanames{en}->{617480543} = "Koumala";
$areanames{en}->{617480546} = "Koumala";
$areanames{en}->{617480547} = "Koumala";
$areanames{en}->{617480548} = "Koumala";
$areanames{en}->{617480549} = "Mount\ Coolon";
$areanames{en}->{617480550} = "Lethebrook";
$areanames{en}->{617480553} = "Lethebrook";
$areanames{en}->{617480556} = "Lethebrook";
$areanames{en}->{617480557} = "Lethebrook";
$areanames{en}->{617480558} = "Lethebrook";
$areanames{en}->{617480559} = "Mount\ Gardiner";
$areanames{en}->{617480560} = "Mackay";
$areanames{en}->{617480561} = "Mackay";
$areanames{en}->{617480562} = "Mackay";
$areanames{en}->{617480563} = "Mackay";
$areanames{en}->{617480564} = "Mackay";
$areanames{en}->{617480567} = "Mount\ Larcom";
$areanames{en}->{617480568} = "Moranbah";
$areanames{en}->{617480569} = "Mount\ Morgan";
$areanames{en}->{61748057} = "Moranbah";
$areanames{en}->{617480579} = "Moura";
$areanames{en}->{61748058} = "Nebo";
$areanames{en}->{617480589} = "Nathan\ Gorge";
$areanames{en}->{61748059} = "Proserpine";
$areanames{en}->{617480598} = "Nebo";
$areanames{en}->{617480599} = "Nogoa";
$areanames{en}->{61748060} = "Sarina";
$areanames{en}->{61748061} = "St\ Lawrence";
$areanames{en}->{617480619} = "Oombabeer";
$areanames{en}->{617480620} = "Wagoora";
$areanames{en}->{617480623} = "Wagoora";
$areanames{en}->{617480626} = "Wagoora";
$areanames{en}->{617480627} = "Wagoora";
$areanames{en}->{617480628} = "Wagoora";
$areanames{en}->{617480629} = "Orion";
$areanames{en}->{61748063} = "Walkerston";
$areanames{en}->{61748064} = "Yakapari";
$areanames{en}->{617480649} = "Pegunny";
$areanames{en}->{617480650} = "Bajool";
$areanames{en}->{617480653} = "Bajool";
$areanames{en}->{617480656} = "Bajool";
$areanames{en}->{617480657} = "Bajool";
$areanames{en}->{617480658} = "Bajool";
$areanames{en}->{617480659} = "Proserpine";
$areanames{en}->{617480660} = "Broadsound";
$areanames{en}->{617480663} = "Broadsound";
$areanames{en}->{617480666} = "Broadsound";
$areanames{en}->{617480667} = "Broadsound";
$areanames{en}->{617480668} = "Broadsound";
$areanames{en}->{617480669} = "Rockhampton";
$areanames{en}->{617480670} = "Byfield";
$areanames{en}->{617480673} = "Byfield";
$areanames{en}->{617480676} = "Byfield";
$areanames{en}->{617480677} = "Byfield";
$areanames{en}->{617480678} = "Byfield";
$areanames{en}->{617480679} = "Rolleston";
$areanames{en}->{617480680} = "Dingo";
$areanames{en}->{617480683} = "Dingo";
$areanames{en}->{617480686} = "Dingo";
$areanames{en}->{617480687} = "Dingo";
$areanames{en}->{617480688} = "Dingo";
$areanames{en}->{617480689} = "Sarina";
$areanames{en}->{617480690} = "Duaringa";
$areanames{en}->{617480693} = "Duaringa";
$areanames{en}->{617480696} = "Duaringa";
$areanames{en}->{617480697} = "Duaringa";
$areanames{en}->{617480698} = "Duaringa";
$areanames{en}->{617480699} = "Spier";
$areanames{en}->{617480700} = "Fitzroy\ West";
$areanames{en}->{617480703} = "Fitzroy\ West";
$areanames{en}->{617480706} = "Fitzroy\ West";
$areanames{en}->{617480707} = "Fitzroy\ West";
$areanames{en}->{617480708} = "Fitzroy\ West";
$areanames{en}->{617480709} = "Springsure";
$areanames{en}->{617480710} = "Garnant";
$areanames{en}->{617480713} = "Garnant";
$areanames{en}->{617480716} = "Garnant";
$areanames{en}->{617480717} = "Garnant";
$areanames{en}->{617480718} = "Garnant";
$areanames{en}->{617480719} = "St\ Lawrence";
$areanames{en}->{617480720} = "Isaac\ River";
$areanames{en}->{617480723} = "Isaac\ River";
$areanames{en}->{617480726} = "Isaac\ River";
$areanames{en}->{617480727} = "Isaac\ River";
$areanames{en}->{617480728} = "Isaac\ River";
$areanames{en}->{617480729} = "The\ Caves";
$areanames{en}->{61748073} = "Marlborough";
$areanames{en}->{617480738} = "Theodore";
$areanames{en}->{617480739} = "Tieri";
$areanames{en}->{61748074} = "Mount\ Gardiner";
$areanames{en}->{617480748} = "Tungamull";
$areanames{en}->{617480749} = "Turkey\ Beach";
$areanames{en}->{61748075} = "Mount\ Morgan";
$areanames{en}->{617480759} = "Ubobo";
$areanames{en}->{617480760} = "Rockhampton";
$areanames{en}->{617480761} = "Rockhampton";
$areanames{en}->{617480762} = "Rockhampton";
$areanames{en}->{617480763} = "Rockhampton";
$areanames{en}->{617480764} = "Rockhampton";
$areanames{en}->{617480767} = "Wagoora";
$areanames{en}->{617480768} = "Walkerston";
$areanames{en}->{617480769} = "Rockhampton";
$areanames{en}->{61748077} = "The\ Caves";
$areanames{en}->{617480779} = "Westwood";
$areanames{en}->{61748078} = "Tungamull";
$areanames{en}->{617480789} = "Willows";
$areanames{en}->{617480790} = "Westwood";
$areanames{en}->{617480793} = "Westwood";
$areanames{en}->{617480796} = "Westwood";
$areanames{en}->{617480797} = "Westwood";
$areanames{en}->{617480798} = "Westwood";
$areanames{en}->{617480799} = "Woorabinda";
$areanames{en}->{61748080} = "Woorabinda";
$areanames{en}->{617480809} = "Wowan";
$areanames{en}->{617480810} = "Wowan";
$areanames{en}->{617480813} = "Wowan";
$areanames{en}->{617480816} = "Wowan";
$areanames{en}->{617480817} = "Wowan";
$areanames{en}->{617480818} = "Wowan";
$areanames{en}->{617480819} = "Yakapari";
$areanames{en}->{617480820} = "Yeppoon";
$areanames{en}->{617480821} = "Yeppoon";
$areanames{en}->{617480822} = "Yeppoon";
$areanames{en}->{617480823} = "Yeppoon";
$areanames{en}->{617480824} = "Yeppoon";
$areanames{en}->{617480825} = "Yeppoon";
$areanames{en}->{617480828} = "Yeppoon";
$areanames{en}->{617480829} = "Zamia\ Creek";
$areanames{en}->{61748083} = "Banana";
$areanames{en}->{61748084} = "Baralaba";
$areanames{en}->{61748085} = "Bauhinia";
$areanames{en}->{61748086} = "Biloela";
$areanames{en}->{61748087} = "Cracow";
$areanames{en}->{61748088} = "Goovigen";
$areanames{en}->{61748089} = "Mardale";
$areanames{en}->{61748090} = "Moura";
$areanames{en}->{61748091} = "Nathan\ Gorge";
$areanames{en}->{61748092} = "Oombabeer";
$areanames{en}->{61748093} = "Pegunny";
$areanames{en}->{61748094} = "Spier";
$areanames{en}->{61748095} = "Theodore";
$areanames{en}->{61748096} = "Zamia\ Creek";
$areanames{en}->{61748097} = "Alpha";
$areanames{en}->{61748098} = "Belyando";
$areanames{en}->{61748099} = "Bingegang";
$areanames{en}->{61748100} = "Blackwater";
$areanames{en}->{61748101} = "Buckland";
$areanames{en}->{61748102} = "Capella";
$areanames{en}->{61748103} = "Carbine\ Creek";
$areanames{en}->{61748104} = "Clermont";
$areanames{en}->{61748105} = "Comet";
$areanames{en}->{61748106} = "Gemfields";
$areanames{en}->{61748107} = "Hodgson\ Range";
$areanames{en}->{61748108} = "Miclere";
$areanames{en}->{61748109} = "Middlemount";
$areanames{en}->{61748110} = "Mount\ Coolon";
$areanames{en}->{61748111} = "Nogoa";
$areanames{en}->{61748112} = "Orion";
$areanames{en}->{61748113} = "Rolleston";
$areanames{en}->{61748114} = "Springsure";
$areanames{en}->{61748115} = "Tieri";
$areanames{en}->{61748116} = "Willows";
$areanames{en}->{61748117} = "Agnes\ Water";
$areanames{en}->{61748118} = "Benaraby";
$areanames{en}->{61748119} = "Calliope";
$areanames{en}->{61748120} = "Gayfield";
$areanames{en}->{61748121} = "Miriam\ Vale";
$areanames{en}->{61748122} = "Mount\ Larcom";
$areanames{en}->{61748123} = "Turkey\ Beach";
$areanames{en}->{61748124} = "Ubobo";
$areanames{en}->{61748125} = "Calen";
$areanames{en}->{61748126} = "Cannon\ Valley";
$areanames{en}->{61748127} = "Carmila";
$areanames{en}->{61748128} = "Colston\ Park";
$areanames{en}->{61748129} = "Connors\ Range";
$areanames{en}->{61748130} = "Dingo\ Beach";
$areanames{en}->{61748131} = "Dysart";
$areanames{en}->{61748132} = "Finch\ Hatton";
$areanames{en}->{61748133} = "Gargett";
$areanames{en}->{61748134} = "Glenden";
$areanames{en}->{61748135} = "Koumala";
$areanames{en}->{61748136} = "Lethebrook";
$areanames{en}->{61748137} = "Moranbah";
$areanames{en}->{61748138} = "Nebo";
$areanames{en}->{61748139} = "Proserpine";
$areanames{en}->{61748140} = "Sarina";
$areanames{en}->{61748141} = "St\ Lawrence";
$areanames{en}->{61748142} = "Wagoora";
$areanames{en}->{61748143} = "Walkerston";
$areanames{en}->{61748144} = "Yakapari";
$areanames{en}->{61748145} = "Bajool";
$areanames{en}->{61748146} = "Broadsound";
$areanames{en}->{61748147} = "Byfield";
$areanames{en}->{61748148} = "Dingo";
$areanames{en}->{61748149} = "Duaringa";
$areanames{en}->{61748150} = "Fitzroy\ West";
$areanames{en}->{61748151} = "Garnant";
$areanames{en}->{61748152} = "Isaac\ River";
$areanames{en}->{61748153} = "Marlborough";
$areanames{en}->{61748154} = "Mount\ Gardiner";
$areanames{en}->{61748155} = "Mount\ Morgan";
$areanames{en}->{61748156} = "The\ Caves";
$areanames{en}->{61748157} = "Tungamull";
$areanames{en}->{61748158} = "Westwood";
$areanames{en}->{61748159} = "Woorabinda";
$areanames{en}->{61748160} = "Wowan";
$areanames{en}->{61748161} = "Westwood";
$areanames{en}->{61748162} = "Westwood";
$areanames{en}->{61748163} = "Colston\ Park";
$areanames{en}->{61748164} = "Colston\ Park";
$areanames{en}->{61748165} = "Comet";
$areanames{en}->{61748166} = "Comet";
$areanames{en}->{61748167} = "Moranbah";
$areanames{en}->{61748168} = "Rockhampton";
$areanames{en}->{61748169} = "Rockhampton";
$areanames{en}->{6174817} = "Rockhampton";
$areanames{en}->{6174818} = "Mackay";
$areanames{en}->{6174819} = "Rockhampton";
$areanames{en}->{61748200} = "Carmila";
$areanames{en}->{61748201} = "Carmila";
$areanames{en}->{61748202} = "Connors\ Range";
$areanames{en}->{61748203} = "Connors\ Range";
$areanames{en}->{61748204} = "Dingo\ Beach";
$areanames{en}->{61748205} = "Dingo\ Beach";
$areanames{en}->{61748206} = "Dysart";
$areanames{en}->{61748207} = "Dysart";
$areanames{en}->{61748208} = "Finch\ Hatton";
$areanames{en}->{61748209} = "Finch\ Hatton";
$areanames{en}->{61748210} = "Gargett";
$areanames{en}->{61748211} = "Gargett";
$areanames{en}->{61748212} = "Koumala";
$areanames{en}->{61748213} = "Koumala";
$areanames{en}->{61748214} = "Lethebrook";
$areanames{en}->{61748215} = "Lethebrook";
$areanames{en}->{61748216} = "Yakapari";
$areanames{en}->{61748217} = "Yakapari";
$areanames{en}->{61748218} = "Walkerston";
$areanames{en}->{61748219} = "Walkerston";
$areanames{en}->{61748220} = "Wagoora";
$areanames{en}->{61748221} = "Wagoora";
$areanames{en}->{61748222} = "St\ Lawrence";
$areanames{en}->{61748223} = "St\ Lawrence";
$areanames{en}->{61748224} = "Sarina";
$areanames{en}->{61748225} = "Sarina";
$areanames{en}->{61748226} = "Proserpine";
$areanames{en}->{61748227} = "Proserpine";
$areanames{en}->{61748228} = "Mackay";
$areanames{en}->{61748229} = "Mackay";
$areanames{en}->{61748230} = "Moranbah";
$areanames{en}->{61748231} = "Moranbah";
$areanames{en}->{61748232} = "Nebo";
$areanames{en}->{61748233} = "Nebo";
$areanames{en}->{61748234} = "Bajool";
$areanames{en}->{61748235} = "Bajool";
$areanames{en}->{61748236} = "Dingo";
$areanames{en}->{61748237} = "Dingo";
$areanames{en}->{61748238} = "Duaringa";
$areanames{en}->{61748239} = "Duaringa";
$areanames{en}->{61748240} = "Garnant";
$areanames{en}->{61748241} = "Garnant";
$areanames{en}->{61748242} = "Marlborough";
$areanames{en}->{61748243} = "Marlborough";
$areanames{en}->{61748244} = "Tungamull";
$areanames{en}->{61748245} = "Tungamull";
$areanames{en}->{61748246} = "Rockhampton";
$areanames{en}->{61748247} = "Rockhampton";
$areanames{en}->{61748248} = "Wowan";
$areanames{en}->{61748249} = "Wowan";
$areanames{en}->{61748250} = "Yeppoon";
$areanames{en}->{61748251} = "Yeppoon";
$areanames{en}->{61748252} = "Banana";
$areanames{en}->{61748253} = "Banana";
$areanames{en}->{61748254} = "Biloela";
$areanames{en}->{61748255} = "Biloela";
$areanames{en}->{61748256} = "Goovigen";
$areanames{en}->{61748257} = "Goovigen";
$areanames{en}->{61748258} = "Spier";
$areanames{en}->{61748259} = "Spier";
$areanames{en}->{61748260} = "Blackwater";
$areanames{en}->{61748261} = "Blackwater";
$areanames{en}->{61748262} = "Capella";
$areanames{en}->{61748263} = "Capella";
$areanames{en}->{61748264} = "Clermont";
$areanames{en}->{61748265} = "Clermont";
$areanames{en}->{61748266} = "Emerald";
$areanames{en}->{61748267} = "Emerald";
$areanames{en}->{61748268} = "Middlemount";
$areanames{en}->{61748269} = "Middlemount";
$areanames{en}->{61748270} = "Springsure";
$areanames{en}->{61748271} = "Springsure";
$areanames{en}->{61748272} = "Tieri";
$areanames{en}->{61748273} = "Tieri";
$areanames{en}->{61748274} = "Agnes\ Water";
$areanames{en}->{61748275} = "Agnes\ Water";
$areanames{en}->{61748276} = "Benaraby";
$areanames{en}->{61748277} = "Benaraby";
$areanames{en}->{61748278} = "Calliope";
$areanames{en}->{61748279} = "Calliope";
$areanames{en}->{61748280} = "Gayfield";
$areanames{en}->{61748281} = "Gayfield";
$areanames{en}->{61748282} = "Gladstone";
$areanames{en}->{61748283} = "Gladstone";
$areanames{en}->{61748284} = "Miriam\ Vale";
$areanames{en}->{61748285} = "Miriam\ Vale";
$areanames{en}->{61748286} = "Mount\ Larcom";
$areanames{en}->{61748287} = "Mount\ Larcom";
$areanames{en}->{61748288} = "Turkey\ Beach";
$areanames{en}->{61748289} = "Turkey\ Beach";
$areanames{en}->{61748290} = "Moura";
$areanames{en}->{61748291} = "Moura";
$areanames{en}->{61748292} = "Mackay";
$areanames{en}->{61748293} = "Mackay";
$areanames{en}->{61748294} = "Mackay";
$areanames{en}->{61748295} = "Gladstone";
$areanames{en}->{61748296} = "Gladstone";
$areanames{en}->{61748297} = "Mackay";
$areanames{en}->{61748298} = "Gladstone";
$areanames{en}->{61748299} = "Gladstone";
$areanames{en}->{61748300} = "Ubobo";
$areanames{en}->{61748301} = "Ubobo";
$areanames{en}->{61748302} = "Glenden";
$areanames{en}->{61748303} = "Glenden";
$areanames{en}->{61748304} = "Broadsound";
$areanames{en}->{61748305} = "Broadsound";
$areanames{en}->{61748306} = "Fitzroy\ West";
$areanames{en}->{61748307} = "Fitzroy\ West";
$areanames{en}->{61748308} = "Isaac\ River";
$areanames{en}->{61748309} = "Isaac\ River";
$areanames{en}->{61748310} = "Woorabinda";
$areanames{en}->{61748311} = "Woorabinda";
$areanames{en}->{61748312} = "Mount\ Gardiner";
$areanames{en}->{61748313} = "Mount\ Gardiner";
$areanames{en}->{61748314} = "Emerald";
$areanames{en}->{61748315} = "Emerald";
$areanames{en}->{61748316} = "Bingegang";
$areanames{en}->{61748317} = "Bingegang";
$areanames{en}->{61748318} = "Buckland";
$areanames{en}->{61748319} = "Buckland";
$areanames{en}->{61748320} = "Miclere";
$areanames{en}->{61748321} = "Miclere";
$areanames{en}->{61748322} = "Orion";
$areanames{en}->{61748323} = "Orion";
$areanames{en}->{61748324} = "Carbine\ Creek";
$areanames{en}->{61748325} = "Carbine\ Creek";
$areanames{en}->{61748326} = "Hodgson\ Range";
$areanames{en}->{61748327} = "Hodgson\ Range";
$areanames{en}->{61748328} = "Nogoa";
$areanames{en}->{61748329} = "Nogoa";
$areanames{en}->{61748330} = "Willows";
$areanames{en}->{61748331} = "Willows";
$areanames{en}->{61748332} = "Nathan\ Gorge";
$areanames{en}->{61748333} = "Nathan\ Gorge";
$areanames{en}->{61748334} = "Cracow";
$areanames{en}->{61748335} = "Cracow";
$areanames{en}->{61748336} = "Baralaba";
$areanames{en}->{61748337} = "Baralaba";
$areanames{en}->{61748338} = "Mardale";
$areanames{en}->{61748339} = "Mardale";
$areanames{en}->{61748340} = "Pegunny";
$areanames{en}->{61748341} = "Pegunny";
$areanames{en}->{61748342} = "Theodore";
$areanames{en}->{61748343} = "Theodore";
$areanames{en}->{61748344} = "Bauhinia";
$areanames{en}->{61748345} = "Bauhinia";
$areanames{en}->{61748346} = "Mount\ Coolon";
$areanames{en}->{61748347} = "Mount\ Coolon";
$areanames{en}->{61748348} = "Rolleston";
$areanames{en}->{61748349} = "Rolleston";
$areanames{en}->{61748350} = "Duaringa";
$areanames{en}->{61748351} = "Duaringa";
$areanames{en}->{61748352} = "Marlborough";
$areanames{en}->{61748353} = "Woorabinda";
$areanames{en}->{61748354} = "Mount\ Morgan";
$areanames{en}->{61748355} = "Broadsound";
$areanames{en}->{61748356} = "Dingo";
$areanames{en}->{61748357} = "Fitzroy\ West";
$areanames{en}->{61748358} = "Isaac\ River";
$areanames{en}->{61748359} = "Mount\ Gardiner";
$areanames{en}->{61748360} = "Wowan";
$areanames{en}->{61748361} = "Byfield";
$areanames{en}->{61748362} = "Garnant";
$areanames{en}->{61748363} = "The\ Caves";
$areanames{en}->{61748364} = "Rockhampton";
$areanames{en}->{61748365} = "Mackay";
$areanames{en}->{61748366} = "Rockhampton";
$areanames{en}->{61748367} = "Gladstone";
$areanames{en}->{61748368} = "Gladstone";
$areanames{en}->{61748369} = "Gladstone";
$areanames{en}->{61748370} = "Rockhampton";
$areanames{en}->{61748371} = "Mackay";
$areanames{en}->{61748372} = "Yeppoon";
$areanames{en}->{61748373} = "Rockhampton";
$areanames{en}->{61748374} = "Byfield";
$areanames{en}->{61748375} = "Sarina";
$areanames{en}->{61748376} = "Baralaba";
$areanames{en}->{61748377} = "Gladstone";
$areanames{en}->{61748378} = "Mackay";
$areanames{en}->{61748379} = "Moranbah";
$areanames{en}->{61748380} = "Mount\ Morgan";
$areanames{en}->{61748381} = "Emerald";
$areanames{en}->{61748382} = "Proserpine";
$areanames{en}->{61748383} = "Gladstone";
$areanames{en}->{61748384} = "Cannon\ Valley";
$areanames{en}->{61748385} = "Rockhampton";
$areanames{en}->{61748386} = "Gladstone";
$areanames{en}->{61748387} = "Gladstone";
$areanames{en}->{61748388} = "Gladstone";
$areanames{en}->{61748389} = "Rockhampton";
$areanames{en}->{61748390} = "Gladstone";
$areanames{en}->{61748391} = "Gladstone";
$areanames{en}->{61748392} = "Calliope";
$areanames{en}->{61748393} = "Calliope";
$areanames{en}->{61748394} = "Gladstone";
$areanames{en}->{61748395} = "Gladstone";
$areanames{en}->{61748396} = "Proserpine";
$areanames{en}->{61748397} = "Rockhampton";
$areanames{en}->{61748398} = "Rockhampton";
$areanames{en}->{61748399} = "Rockhampton";
$areanames{en}->{61748400} = "Mackay";
$areanames{en}->{61748401} = "Mackay";
$areanames{en}->{61748402} = "Mackay";
$areanames{en}->{61748403} = "Moranbah";
$areanames{en}->{61748404} = "Nebo";
$areanames{en}->{61748405} = "Finch\ Hatton";
$areanames{en}->{61748406} = "Calen";
$areanames{en}->{61748407} = "Koumala";
$areanames{en}->{61748408} = "Dysart";
$areanames{en}->{61748409} = "Dysart";
$areanames{en}->{61748410} = "Moranbah";
$areanames{en}->{61748411} = "Moranbah";
$areanames{en}->{61748412} = "Moranbah";
$areanames{en}->{61748413} = "Moranbah";
$areanames{en}->{61748414} = "Cannon\ Valley";
$areanames{en}->{61748415} = "Dingo\ Beach";
$areanames{en}->{61748416} = "Mackay";
$areanames{en}->{61748417} = "Mackay";
$areanames{en}->{61748418} = "Mackay";
$areanames{en}->{61748419} = "Mackay";
$areanames{en}->{6174842} = "Mackay";
$areanames{en}->{61748430} = "Blackwater";
$areanames{en}->{61748431} = "Rockhampton";
$areanames{en}->{61748432} = "Rockhampton";
$areanames{en}->{61748433} = "Mackay";
$areanames{en}->{61748434} = "Gladstone";
$areanames{en}->{61748435} = "Emerald";
$areanames{en}->{61748436} = "Gladstone";
$areanames{en}->{61748437} = "Gladstone";
$areanames{en}->{61748438} = "Emerald";
$areanames{en}->{61748439} = "Emerald";
$areanames{en}->{6174844} = "Gladstone";
$areanames{en}->{61748450} = "Calliope";
$areanames{en}->{61748451} = "Biloela";
$areanames{en}->{61748452} = "Miriam\ Vale";
$areanames{en}->{61748453} = "Proserpine";
$areanames{en}->{61748454} = "Emerald";
$areanames{en}->{61748455} = "Sarina";
$areanames{en}->{61748456} = "Yeppoon";
$areanames{en}->{61748457} = "Gladstone";
$areanames{en}->{61748458} = "Mackay";
$areanames{en}->{61748459} = "Cracow";
$areanames{en}->{61748460} = "Mackay";
$areanames{en}->{61748461} = "Mackay";
$areanames{en}->{61748462} = "Moranbah";
$areanames{en}->{61748463} = "Moranbah";
$areanames{en}->{61748464} = "Moranbah";
$areanames{en}->{61748465} = "Moranbah";
$areanames{en}->{61748466} = "Cannon\ Valley";
$areanames{en}->{61748467} = "Cannon\ Valley";
$areanames{en}->{61748468} = "Cannon\ Valley";
$areanames{en}->{61748469} = "Cannon\ Valley";
$areanames{en}->{61748470} = "Mackay";
$areanames{en}->{61748471} = "Mackay";
$areanames{en}->{61748472} = "Rolleston";
$areanames{en}->{61748473} = "Moranbah";
$areanames{en}->{61748474} = "Middlemount";
$areanames{en}->{61748475} = "Mackay";
$areanames{en}->{61748476} = "Rockhampton";
$areanames{en}->{61748477} = "Mackay";
$areanames{en}->{61748478} = "Mackay";
$areanames{en}->{61748479} = "Springsure";
$areanames{en}->{61748480} = "Walkerston";
$areanames{en}->{61748481} = "Mackay";
$areanames{en}->{61748482} = "Mackay";
$areanames{en}->{61748483} = "Alpha";
$areanames{en}->{61748484} = "Rockhampton";
$areanames{en}->{61748485} = "Rockhampton";
$areanames{en}->{61748486} = "Rockhampton";
$areanames{en}->{61748487} = "Rockhampton";
$areanames{en}->{61748488} = "Woorabinda";
$areanames{en}->{61748489} = "Woorabinda";
$areanames{en}->{61748490} = "Gladstone";
$areanames{en}->{61748491} = "Gladstone";
$areanames{en}->{61748492} = "Gladstone";
$areanames{en}->{61748493} = "Emerald";
$areanames{en}->{61748494} = "Mackay";
$areanames{en}->{61748495} = "Mackay";
$areanames{en}->{61748496} = "Marlborough";
$areanames{en}->{61748497} = "Belyando";
$areanames{en}->{61748498} = "Bajool";
$areanames{en}->{61748499} = "Banana";
$areanames{en}->{61748500} = "Mount\ Morgan";
$areanames{en}->{61748501} = "Gladstone";
$areanames{en}->{61748502} = "Gladstone";
$areanames{en}->{61748503} = "Gladstone";
$areanames{en}->{61748504} = "Gladstone";
$areanames{en}->{61748505} = "Gladstone";
$areanames{en}->{61748506} = "Baralaba";
$areanames{en}->{61748507} = "Bauhinia";
$areanames{en}->{61748508} = "Belyando";
$areanames{en}->{61748509} = "Benaraby";
$areanames{en}->{61748510} = "Gladstone";
$areanames{en}->{61748511} = "Gladstone";
$areanames{en}->{61748512} = "Bingegang";
$areanames{en}->{61748513} = "Broadsound";
$areanames{en}->{61748514} = "Buckland";
$areanames{en}->{61748515} = "Calen";
$areanames{en}->{61748516} = "Calliope";
$areanames{en}->{61748517} = "Capella";
$areanames{en}->{61748518} = "Carbine\ Creek";
$areanames{en}->{61748519} = "Carmila";
$areanames{en}->{6174852} = "Mackay";
$areanames{en}->{61748530} = "Colston\ Park";
$areanames{en}->{61748531} = "Comet";
$areanames{en}->{61748532} = "Cracow";
$areanames{en}->{61748533} = "Dingo";
$areanames{en}->{61748534} = "Dingo\ Beach";
$areanames{en}->{61748535} = "Duaringa";
$areanames{en}->{61748536} = "Dysart";
$areanames{en}->{61748537} = "Finch\ Hatton";
$areanames{en}->{61748538} = "Fitzroy\ West";
$areanames{en}->{61748539} = "Gargett";
$areanames{en}->{61748540} = "Garnant";
$areanames{en}->{61748541} = "Gemfields";
$areanames{en}->{61748542} = "Glenden";
$areanames{en}->{61748543} = "Goovigen";
$areanames{en}->{61748544} = "Hodgson\ Range";
$areanames{en}->{61748545} = "Isaac\ River";
$areanames{en}->{61748546} = "Koumala";
$areanames{en}->{61748547} = "Lethebrook";
$areanames{en}->{61748548} = "Mardale";
$areanames{en}->{61748549} = "Marlborough";
$areanames{en}->{61748550} = "Miclere";
$areanames{en}->{61748551} = "Middlemount";
$areanames{en}->{61748552} = "Miriam\ Vale";
$areanames{en}->{61748553} = "Moranbah";
$areanames{en}->{61748554} = "Mount\ Coolon";
$areanames{en}->{61748555} = "Mount\ Gardiner";
$areanames{en}->{61748556} = "Mount\ Larcom";
$areanames{en}->{61748557} = "Mount\ Morgan";
$areanames{en}->{61748558} = "Moura";
$areanames{en}->{61748559} = "Nathan\ Gorge";
$areanames{en}->{61748560} = "Nebo";
$areanames{en}->{61748561} = "Nogoa";
$areanames{en}->{61748562} = "Oombabeer";
$areanames{en}->{61748563} = "Orion";
$areanames{en}->{61748564} = "Pegunny";
$areanames{en}->{61748565} = "Rolleston";
$areanames{en}->{61748566} = "Sarina";
$areanames{en}->{61748567} = "Spier";
$areanames{en}->{61748568} = "Springsure";
$areanames{en}->{61748569} = "St\ Lawrence";
$areanames{en}->{61748570} = "The\ Caves";
$areanames{en}->{61748571} = "Theodore";
$areanames{en}->{61748572} = "Tieri";
$areanames{en}->{61748573} = "Tungamull";
$areanames{en}->{61748574} = "Wagoora";
$areanames{en}->{61748575} = "Walkerston";
$areanames{en}->{61748576} = "Westwood";
$areanames{en}->{61748577} = "Willows";
$areanames{en}->{61748578} = "Woorabinda";
$areanames{en}->{61748579} = "Yakapari";
$areanames{en}->{61748580} = "Agnes\ Water";
$areanames{en}->{61748581} = "Cannon\ Valley";
$areanames{en}->{617485820} = "Agnes\ Water";
$areanames{en}->{617485821} = "Alpha";
$areanames{en}->{617485822} = "Bajool";
$areanames{en}->{617485823} = "Banana";
$areanames{en}->{617485824} = "Baralaba";
$areanames{en}->{617485825} = "Bauhinia";
$areanames{en}->{617485826} = "Benaraby";
$areanames{en}->{617485827} = "Biloela";
$areanames{en}->{617485828} = "Bingegang";
$areanames{en}->{617485829} = "Blackwater";
$areanames{en}->{61748583} = "Belyando";
$areanames{en}->{617485840} = "Broadsound";
$areanames{en}->{617485841} = "Buckland";
$areanames{en}->{617485842} = "Byfield";
$areanames{en}->{617485843} = "Calen";
$areanames{en}->{617485844} = "Calliope";
$areanames{en}->{617485845} = "Cannon\ Valley";
$areanames{en}->{617485846} = "Capella";
$areanames{en}->{617485847} = "Carbine\ Creek";
$areanames{en}->{617485848} = "Carmila";
$areanames{en}->{617485849} = "Clermont";
$areanames{en}->{617485850} = "Colston\ Park";
$areanames{en}->{617485851} = "Comet";
$areanames{en}->{617485852} = "Connors\ Range";
$areanames{en}->{617485853} = "Cracow";
$areanames{en}->{617485854} = "Dingo";
$areanames{en}->{617485855} = "Dingo\ Beach";
$areanames{en}->{617485856} = "Duaringa";
$areanames{en}->{617485857} = "Dysart";
$areanames{en}->{617485858} = "Emerald";
$areanames{en}->{617485859} = "Finch\ Hatton";
$areanames{en}->{617485860} = "Fitzroy\ West";
$areanames{en}->{617485861} = "Gargett";
$areanames{en}->{617485862} = "Garnant";
$areanames{en}->{617485863} = "Gayfield";
$areanames{en}->{617485864} = "Gemfields";
$areanames{en}->{617485865} = "Gladstone";
$areanames{en}->{617485866} = "Glenden";
$areanames{en}->{617485867} = "Goovigen";
$areanames{en}->{617485868} = "Hodgson\ Range";
$areanames{en}->{617485869} = "Isaac\ River";
$areanames{en}->{617485870} = "Koumala";
$areanames{en}->{617485871} = "Lethebrook";
$areanames{en}->{617485872} = "Mackay";
$areanames{en}->{617485873} = "Mardale";
$areanames{en}->{617485874} = "Marlborough";
$areanames{en}->{617485875} = "Miclere";
$areanames{en}->{617485876} = "Middlemount";
$areanames{en}->{617485877} = "Miriam\ Vale";
$areanames{en}->{617485878} = "Moranbah";
$areanames{en}->{617485879} = "Mount\ Coolon";
$areanames{en}->{617485880} = "Mount\ Gardiner";
$areanames{en}->{617485881} = "Mount\ Larcom";
$areanames{en}->{617485882} = "Mount\ Morgan";
$areanames{en}->{617485883} = "Moura";
$areanames{en}->{617485884} = "Nathan\ Gorge";
$areanames{en}->{617485885} = "Nebo";
$areanames{en}->{617485886} = "Nogoa";
$areanames{en}->{617485887} = "Oombabeer";
$areanames{en}->{617485888} = "Orion";
$areanames{en}->{617485889} = "Pegunny";
$areanames{en}->{617485890} = "Proserpine";
$areanames{en}->{617485891} = "Rockhampton";
$areanames{en}->{617485892} = "Rolleston";
$areanames{en}->{617485893} = "Sarina";
$areanames{en}->{617485894} = "Spier";
$areanames{en}->{617485895} = "Springsure";
$areanames{en}->{617485896} = "St\ Lawrence";
$areanames{en}->{617485897} = "The\ Caves";
$areanames{en}->{617485898} = "Theodore";
$areanames{en}->{617485899} = "Tieri";
$areanames{en}->{6174859} = "Yeppoon";
$areanames{en}->{617485900} = "Tungamull";
$areanames{en}->{617485901} = "Turkey\ Beach";
$areanames{en}->{617485902} = "Ubobo";
$areanames{en}->{617485903} = "Wagoora";
$areanames{en}->{617485904} = "Walkerston";
$areanames{en}->{617485905} = "Westwood";
$areanames{en}->{617485906} = "Willows";
$areanames{en}->{617485907} = "Woorabinda";
$areanames{en}->{617485908} = "Wowan";
$areanames{en}->{617485909} = "Yakapari";
$areanames{en}->{617485911} = "Zamia\ Creek";
$areanames{en}->{617485912} = "Agnes\ Water";
$areanames{en}->{617485913} = "Alpha";
$areanames{en}->{617485914} = "Bajool";
$areanames{en}->{617485915} = "Banana";
$areanames{en}->{617485916} = "Baralaba";
$areanames{en}->{617485917} = "Bauhinia";
$areanames{en}->{617485918} = "Benaraby";
$areanames{en}->{617485919} = "Biloela";
$areanames{en}->{61748592} = "Sarina";
$areanames{en}->{61748593} = "Sarina";
$areanames{en}->{61748600} = "Belyando";
$areanames{en}->{617486010} = "Bingegang";
$areanames{en}->{617486011} = "Blackwater";
$areanames{en}->{617486012} = "Broadsound";
$areanames{en}->{617486013} = "Buckland";
$areanames{en}->{617486014} = "Byfield";
$areanames{en}->{617486015} = "Calen";
$areanames{en}->{617486016} = "Calliope";
$areanames{en}->{617486017} = "Cannon\ Valley";
$areanames{en}->{617486018} = "Capella";
$areanames{en}->{617486019} = "Carbine\ Creek";
$areanames{en}->{617486020} = "Carmila";
$areanames{en}->{617486021} = "Clermont";
$areanames{en}->{617486022} = "Colston\ Park";
$areanames{en}->{617486023} = "Comet";
$areanames{en}->{617486024} = "Connors\ Range";
$areanames{en}->{617486025} = "Cracow";
$areanames{en}->{617486026} = "Dingo";
$areanames{en}->{617486027} = "Dingo\ Beach";
$areanames{en}->{617486028} = "Duaringa";
$areanames{en}->{617486029} = "Dysart";
$areanames{en}->{61748603} = "Biloela";
$areanames{en}->{61748604} = "Yakapari";
$areanames{en}->{61748605} = "Cannon\ Valley";
$areanames{en}->{61748606} = "Sarina";
$areanames{en}->{61748607} = "Walkerston";
$areanames{en}->{61748608} = "Rockhampton";
$areanames{en}->{61748609} = "Rockhampton";
$areanames{en}->{61748610} = "Moura";
$areanames{en}->{61748611} = "Rockhampton";
$areanames{en}->{61748612} = "Rockhampton";
$areanames{en}->{61748613} = "Rockhampton";
$areanames{en}->{61748614} = "Rockhampton";
$areanames{en}->{617486150} = "Emerald";
$areanames{en}->{617486151} = "Finch\ Hatton";
$areanames{en}->{617486152} = "Fitzroy\ West";
$areanames{en}->{617486153} = "Gargett";
$areanames{en}->{617486154} = "Garnant";
$areanames{en}->{617486155} = "Gayfield";
$areanames{en}->{617486156} = "Agnes\ Water";
$areanames{en}->{617486157} = "Alpha";
$areanames{en}->{617486158} = "Bajool";
$areanames{en}->{617486159} = "Banana";
$areanames{en}->{617486160} = "Baralaba";
$areanames{en}->{617486161} = "Bauhinia";
$areanames{en}->{617486162} = "Benaraby";
$areanames{en}->{617486163} = "Biloela";
$areanames{en}->{617486164} = "Bingegang";
$areanames{en}->{617486165} = "Blackwater";
$areanames{en}->{617486166} = "Broadsound";
$areanames{en}->{617486167} = "Buckland";
$areanames{en}->{617486168} = "Byfield";
$areanames{en}->{617486169} = "Calen";
$areanames{en}->{61748617} = "Belyando";
$areanames{en}->{617486180} = "Calliope";
$areanames{en}->{617486181} = "Cannon\ Valley";
$areanames{en}->{617486182} = "Capella";
$areanames{en}->{617486183} = "Carbine\ Creek";
$areanames{en}->{617486184} = "Carmila";
$areanames{en}->{617486185} = "Clermont";
$areanames{en}->{617486186} = "Colston\ Park";
$areanames{en}->{617486187} = "Comet";
$areanames{en}->{617486188} = "Connors\ Range";
$areanames{en}->{617486189} = "Cracow";
$areanames{en}->{617486190} = "Dingo";
$areanames{en}->{617486191} = "Dingo\ Beach";
$areanames{en}->{617486192} = "Duaringa";
$areanames{en}->{617486193} = "Dysart";
$areanames{en}->{617486194} = "Emerald";
$areanames{en}->{617486195} = "Finch\ Hatton";
$areanames{en}->{617486196} = "Fitzroy\ West";
$areanames{en}->{617486197} = "Gargett";
$areanames{en}->{617486198} = "Garnant";
$areanames{en}->{617486199} = "Gayfield";
$areanames{en}->{6174862} = "Mackay";
$areanames{en}->{617486200} = "Gemfields";
$areanames{en}->{617486201} = "Gladstone";
$areanames{en}->{617486202} = "Glenden";
$areanames{en}->{617486203} = "Goovigen";
$areanames{en}->{617486204} = "Hodgson\ Range";
$areanames{en}->{617486205} = "Isaac\ River";
$areanames{en}->{617486206} = "Koumala";
$areanames{en}->{617486207} = "Lethebrook";
$areanames{en}->{617486209} = "Mardale";
$areanames{en}->{61748621} = "Gladstone";
$areanames{en}->{61748630} = "Mackay";
$areanames{en}->{61748631} = "Mackay";
$areanames{en}->{61748632} = "Mackay";
$areanames{en}->{61748633} = "Mackay";
$areanames{en}->{61748634} = "Mackay";
$areanames{en}->{61748635} = "Rockhampton";
$areanames{en}->{61748636} = "Rockhampton";
$areanames{en}->{61748637} = "Rockhampton";
$areanames{en}->{61748638} = "Rockhampton";
$areanames{en}->{61748639} = "Rockhampton";
$areanames{en}->{6174864} = "Mackay";
$areanames{en}->{61748640} = "Moranbah";
$areanames{en}->{61748644} = "Emerald";
$areanames{en}->{61748645} = "Emerald";
$areanames{en}->{61748646} = "Emerald";
$areanames{en}->{6174865} = "Mackay";
$areanames{en}->{617486550} = "Marlborough";
$areanames{en}->{617486551} = "Miclere";
$areanames{en}->{617486552} = "Middlemount";
$areanames{en}->{617486553} = "Miriam\ Vale";
$areanames{en}->{617486554} = "Moranbah";
$areanames{en}->{617486555} = "Mount\ Coolon";
$areanames{en}->{617486556} = "Mount\ Gardiner";
$areanames{en}->{617486557} = "Mount\ Larcom";
$areanames{en}->{617486558} = "Mount\ Morgan";
$areanames{en}->{617486559} = "Moura";
$areanames{en}->{617486560} = "Nathan\ Gorge";
$areanames{en}->{617486561} = "Nebo";
$areanames{en}->{617486562} = "Nogoa";
$areanames{en}->{617486563} = "Oombabeer";
$areanames{en}->{617486564} = "Orion";
$areanames{en}->{617486565} = "Pegunny";
$areanames{en}->{617486566} = "Proserpine";
$areanames{en}->{617486567} = "Rockhampton";
$areanames{en}->{617486568} = "Rolleston";
$areanames{en}->{617486569} = "Sarina";
$areanames{en}->{617486570} = "Spier";
$areanames{en}->{617486571} = "Springsure";
$areanames{en}->{617486572} = "St\ Lawrence";
$areanames{en}->{617486573} = "The\ Caves";
$areanames{en}->{617486574} = "Theodore";
$areanames{en}->{617486575} = "Tieri";
$areanames{en}->{617486576} = "Tungamull";
$areanames{en}->{617486577} = "Turkey\ Beach";
$areanames{en}->{617486578} = "Ubobo";
$areanames{en}->{617486579} = "Wagoora";
$areanames{en}->{617486580} = "Walkerston";
$areanames{en}->{617486581} = "Westwood";
$areanames{en}->{617486582} = "Willows";
$areanames{en}->{617486583} = "Woorabinda";
$areanames{en}->{617486584} = "Wowan";
$areanames{en}->{617486585} = "Yakapari";
$areanames{en}->{617486586} = "Yeppoon";
$areanames{en}->{617486587} = "Zamia\ Creek";
$areanames{en}->{617486588} = "Gemfields";
$areanames{en}->{617486589} = "Gladstone";
$areanames{en}->{6174866} = "Mackay";
$areanames{en}->{61748667} = "Clermont";
$areanames{en}->{61748668} = "Agnes\ Water";
$areanames{en}->{617486690} = "Glenden";
$areanames{en}->{617486691} = "Goovigen";
$areanames{en}->{617486692} = "Hodgson\ Range";
$areanames{en}->{617486693} = "Isaac\ River";
$areanames{en}->{617486694} = "Koumala";
$areanames{en}->{617486695} = "Lethebrook";
$areanames{en}->{617486697} = "Mardale";
$areanames{en}->{617486698} = "Marlborough";
$areanames{en}->{617486699} = "Miclere";
$areanames{en}->{6174867} = "Rockhampton";
$areanames{en}->{617486700} = "Middlemount";
$areanames{en}->{617486701} = "Miriam\ Vale";
$areanames{en}->{617486702} = "Moranbah";
$areanames{en}->{617486703} = "Mount\ Coolon";
$areanames{en}->{617486704} = "Mount\ Gardiner";
$areanames{en}->{617486705} = "Mount\ Larcom";
$areanames{en}->{617486706} = "Mount\ Morgan";
$areanames{en}->{617486707} = "Moura";
$areanames{en}->{617486708} = "Nathan\ Gorge";
$areanames{en}->{617486709} = "Nebo";
$areanames{en}->{617486710} = "Nogoa";
$areanames{en}->{617486711} = "Oombabeer";
$areanames{en}->{617486712} = "Orion";
$areanames{en}->{617486713} = "Pegunny";
$areanames{en}->{617486714} = "Proserpine";
$areanames{en}->{617486716} = "Rolleston";
$areanames{en}->{617486717} = "Sarina";
$areanames{en}->{617486718} = "Spier";
$areanames{en}->{617486719} = "Springsure";
$areanames{en}->{617486720} = "St\ Lawrence";
$areanames{en}->{617486721} = "The\ Caves";
$areanames{en}->{617486722} = "Theodore";
$areanames{en}->{617486723} = "Tieri";
$areanames{en}->{617486724} = "Tungamull";
$areanames{en}->{617486725} = "Turkey\ Beach";
$areanames{en}->{617486726} = "Ubobo";
$areanames{en}->{617486727} = "Wagoora";
$areanames{en}->{617486728} = "Walkerston";
$areanames{en}->{617486729} = "Westwood";
$areanames{en}->{617486730} = "Willows";
$areanames{en}->{617486731} = "Woorabinda";
$areanames{en}->{617486732} = "Wowan";
$areanames{en}->{617486733} = "Yakapari";
$areanames{en}->{617486734} = "Yeppoon";
$areanames{en}->{617486735} = "Zamia\ Creek";
$areanames{en}->{617486736} = "Agnes\ Water";
$areanames{en}->{617486737} = "Alpha";
$areanames{en}->{617486738} = "Bajool";
$areanames{en}->{617486739} = "Banana";
$areanames{en}->{617486800} = "Baralaba";
$areanames{en}->{617486801} = "Bauhinia";
$areanames{en}->{617486802} = "Benaraby";
$areanames{en}->{617486803} = "Biloela";
$areanames{en}->{617486804} = "Bingegang";
$areanames{en}->{617486805} = "Blackwater";
$areanames{en}->{617486806} = "Broadsound";
$areanames{en}->{617486807} = "Buckland";
$areanames{en}->{617486808} = "Byfield";
$areanames{en}->{617486809} = "Calen";
$areanames{en}->{61748681} = "Belyando";
$areanames{en}->{617486820} = "Calliope";
$areanames{en}->{617486821} = "Cannon\ Valley";
$areanames{en}->{617486822} = "Capella";
$areanames{en}->{617486823} = "Carbine\ Creek";
$areanames{en}->{617486824} = "Carmila";
$areanames{en}->{617486825} = "Clermont";
$areanames{en}->{617486826} = "Colston\ Park";
$areanames{en}->{617486827} = "Comet";
$areanames{en}->{617486828} = "Connors\ Range";
$areanames{en}->{617486829} = "Cracow";
$areanames{en}->{617486830} = "Dingo";
$areanames{en}->{617486831} = "Dingo\ Beach";
$areanames{en}->{617486832} = "Duaringa";
$areanames{en}->{617486833} = "Dysart";
$areanames{en}->{617486834} = "Emerald";
$areanames{en}->{617486835} = "Finch\ Hatton";
$areanames{en}->{617486836} = "Fitzroy\ West";
$areanames{en}->{617486837} = "Gargett";
$areanames{en}->{617486838} = "Garnant";
$areanames{en}->{617486839} = "Gayfield";
$areanames{en}->{617486840} = "Gemfields";
$areanames{en}->{617486841} = "Gladstone";
$areanames{en}->{617486842} = "Glenden";
$areanames{en}->{617486843} = "Goovigen";
$areanames{en}->{617486844} = "Hodgson\ Range";
$areanames{en}->{617486845} = "Isaac\ River";
$areanames{en}->{617486846} = "Koumala";
$areanames{en}->{617486847} = "Lethebrook";
$areanames{en}->{617486848} = "Mackay";
$areanames{en}->{617486849} = "Mardale";
$areanames{en}->{617486850} = "Marlborough";
$areanames{en}->{617486851} = "Miclere";
$areanames{en}->{617486852} = "Middlemount";
$areanames{en}->{617486853} = "Miriam\ Vale";
$areanames{en}->{617486854} = "Moranbah";
$areanames{en}->{617486855} = "Mount\ Coolon";
$areanames{en}->{617486856} = "Mount\ Gardiner";
$areanames{en}->{617486857} = "Mount\ Larcom";
$areanames{en}->{617486858} = "Mount\ Morgan";
$areanames{en}->{617486859} = "Moura";
$areanames{en}->{617486860} = "Nathan\ Gorge";
$areanames{en}->{617486861} = "Nebo";
$areanames{en}->{617486862} = "Nogoa";
$areanames{en}->{617486863} = "Oombabeer";
$areanames{en}->{617486864} = "Orion";
$areanames{en}->{617486865} = "Pegunny";
$areanames{en}->{617486866} = "Proserpine";
$areanames{en}->{617486867} = "Rockhampton";
$areanames{en}->{617486868} = "Rolleston";
$areanames{en}->{617486869} = "Sarina";
$areanames{en}->{617486870} = "Spier";
$areanames{en}->{617486871} = "Springsure";
$areanames{en}->{617486872} = "St\ Lawrence";
$areanames{en}->{617486873} = "The\ Caves";
$areanames{en}->{617486874} = "Theodore";
$areanames{en}->{617486875} = "Tieri";
$areanames{en}->{617486876} = "Tungamull";
$areanames{en}->{617486877} = "Turkey\ Beach";
$areanames{en}->{617486878} = "Ubobo";
$areanames{en}->{617486879} = "Wagoora";
$areanames{en}->{617486880} = "Walkerston";
$areanames{en}->{617486881} = "Westwood";
$areanames{en}->{617486882} = "Willows";
$areanames{en}->{617486883} = "Woorabinda";
$areanames{en}->{617486884} = "Wowan";
$areanames{en}->{617486885} = "Yakapari";
$areanames{en}->{617486886} = "Yeppoon";
$areanames{en}->{617486887} = "Zamia\ Creek";
$areanames{en}->{617486888} = "Agnes\ Water";
$areanames{en}->{617486889} = "Alpha";
$areanames{en}->{617486890} = "Bajool";
$areanames{en}->{617486891} = "Banana";
$areanames{en}->{617486892} = "Baralaba";
$areanames{en}->{617486893} = "Bauhinia";
$areanames{en}->{617486894} = "Benaraby";
$areanames{en}->{617486895} = "Biloela";
$areanames{en}->{617486896} = "Bingegang";
$areanames{en}->{617486897} = "Blackwater";
$areanames{en}->{617486898} = "Broadsound";
$areanames{en}->{617486899} = "Buckland";
$areanames{en}->{61748690} = "Belyando";
$areanames{en}->{617486910} = "Byfield";
$areanames{en}->{617486911} = "Calen";
$areanames{en}->{617486912} = "Calliope";
$areanames{en}->{617486913} = "Cannon\ Valley";
$areanames{en}->{617486914} = "Capella";
$areanames{en}->{617486915} = "Carbine\ Creek";
$areanames{en}->{617486916} = "Carmila";
$areanames{en}->{617486917} = "Clermont";
$areanames{en}->{617486918} = "Colston\ Park";
$areanames{en}->{617486919} = "Comet";
$areanames{en}->{617486920} = "Connors\ Range";
$areanames{en}->{617486921} = "Cracow";
$areanames{en}->{617486922} = "Dingo";
$areanames{en}->{617486923} = "Dingo\ Beach";
$areanames{en}->{617486924} = "Duaringa";
$areanames{en}->{617486925} = "Dysart";
$areanames{en}->{617486926} = "Emerald";
$areanames{en}->{617486927} = "Finch\ Hatton";
$areanames{en}->{617486928} = "Fitzroy\ West";
$areanames{en}->{617486929} = "Gargett";
$areanames{en}->{617486930} = "Garnant";
$areanames{en}->{617486931} = "Gayfield";
$areanames{en}->{617486932} = "Gemfields";
$areanames{en}->{617486933} = "Gladstone";
$areanames{en}->{617486934} = "Glenden";
$areanames{en}->{617486935} = "Goovigen";
$areanames{en}->{617486936} = "Hodgson\ Range";
$areanames{en}->{617486937} = "Isaac\ River";
$areanames{en}->{617486938} = "Koumala";
$areanames{en}->{617486939} = "Lethebrook";
$areanames{en}->{617486940} = "Mackay";
$areanames{en}->{617486941} = "Mardale";
$areanames{en}->{617486942} = "Marlborough";
$areanames{en}->{617486943} = "Miclere";
$areanames{en}->{617486944} = "Middlemount";
$areanames{en}->{617486945} = "Miriam\ Vale";
$areanames{en}->{617486946} = "Moranbah";
$areanames{en}->{617486947} = "Mount\ Coolon";
$areanames{en}->{617486948} = "Mount\ Gardiner";
$areanames{en}->{617486949} = "Mount\ Larcom";
$areanames{en}->{617486950} = "Mount\ Morgan";
$areanames{en}->{617486951} = "Moura";
$areanames{en}->{617486952} = "Nathan\ Gorge";
$areanames{en}->{617486953} = "Nebo";
$areanames{en}->{617486954} = "Nogoa";
$areanames{en}->{617486955} = "Oombabeer";
$areanames{en}->{617486956} = "Orion";
$areanames{en}->{617486957} = "Pegunny";
$areanames{en}->{617486958} = "Proserpine";
$areanames{en}->{617486959} = "Rockhampton";
$areanames{en}->{617486960} = "Rolleston";
$areanames{en}->{617486961} = "Sarina";
$areanames{en}->{617486962} = "Spier";
$areanames{en}->{617486963} = "Springsure";
$areanames{en}->{617486964} = "St\ Lawrence";
$areanames{en}->{617486965} = "The\ Caves";
$areanames{en}->{617486966} = "Theodore";
$areanames{en}->{617486967} = "Tieri";
$areanames{en}->{617486968} = "Tungamull";
$areanames{en}->{617486969} = "Turkey\ Beach";
$areanames{en}->{617486970} = "Ubobo";
$areanames{en}->{617486971} = "Wagoora";
$areanames{en}->{617486972} = "Walkerston";
$areanames{en}->{617486973} = "Westwood";
$areanames{en}->{617486974} = "Willows";
$areanames{en}->{617486975} = "Woorabinda";
$areanames{en}->{617486976} = "Wowan";
$areanames{en}->{617486977} = "Yakapari";
$areanames{en}->{617486978} = "Yeppoon";
$areanames{en}->{617486979} = "Zamia\ Creek";
$areanames{en}->{617486980} = "Agnes\ Water";
$areanames{en}->{617486981} = "Alpha";
$areanames{en}->{617486982} = "Bajool";
$areanames{en}->{617486983} = "Banana";
$areanames{en}->{617486984} = "Baralaba";
$areanames{en}->{617486985} = "Bauhinia";
$areanames{en}->{617486986} = "Benaraby";
$areanames{en}->{617486987} = "Biloela";
$areanames{en}->{617486988} = "Bingegang";
$areanames{en}->{617486989} = "Blackwater";
$areanames{en}->{61748699} = "Belyando";
$areanames{en}->{617487000} = "Broadsound";
$areanames{en}->{617487001} = "Buckland";
$areanames{en}->{617487002} = "Byfield";
$areanames{en}->{617487003} = "Calen";
$areanames{en}->{617487004} = "Calliope";
$areanames{en}->{617487005} = "Cannon\ Valley";
$areanames{en}->{617487006} = "Capella";
$areanames{en}->{617487007} = "Carbine\ Creek";
$areanames{en}->{617487008} = "Carmila";
$areanames{en}->{617487009} = "Clermont";
$areanames{en}->{617487010} = "Colston\ Park";
$areanames{en}->{617487011} = "Comet";
$areanames{en}->{617487012} = "Connors\ Range";
$areanames{en}->{617487013} = "Cracow";
$areanames{en}->{617487014} = "Dingo";
$areanames{en}->{617487015} = "Dingo\ Beach";
$areanames{en}->{617487016} = "Duaringa";
$areanames{en}->{617487017} = "Dysart";
$areanames{en}->{617487018} = "Emerald";
$areanames{en}->{617487019} = "Finch\ Hatton";
$areanames{en}->{617487020} = "Fitzroy\ West";
$areanames{en}->{617487021} = "Gargett";
$areanames{en}->{617487022} = "Garnant";
$areanames{en}->{617487023} = "Gayfield";
$areanames{en}->{617487024} = "Gemfields";
$areanames{en}->{617487025} = "Gladstone";
$areanames{en}->{617487026} = "Glenden";
$areanames{en}->{617487027} = "Goovigen";
$areanames{en}->{617487028} = "Hodgson\ Range";
$areanames{en}->{617487029} = "Isaac\ River";
$areanames{en}->{617487030} = "Koumala";
$areanames{en}->{617487031} = "Lethebrook";
$areanames{en}->{617487032} = "Mackay";
$areanames{en}->{617487033} = "Mardale";
$areanames{en}->{617487034} = "Marlborough";
$areanames{en}->{617487035} = "Miclere";
$areanames{en}->{617487036} = "Middlemount";
$areanames{en}->{617487037} = "Miriam\ Vale";
$areanames{en}->{617487038} = "Moranbah";
$areanames{en}->{617487039} = "Mount\ Coolon";
$areanames{en}->{617487040} = "Mount\ Gardiner";
$areanames{en}->{617487041} = "Mount\ Larcom";
$areanames{en}->{617487042} = "Mount\ Morgan";
$areanames{en}->{617487043} = "Moura";
$areanames{en}->{617487044} = "Nathan\ Gorge";
$areanames{en}->{617487045} = "Nebo";
$areanames{en}->{617487046} = "Nogoa";
$areanames{en}->{617487047} = "Oombabeer";
$areanames{en}->{617487048} = "Orion";
$areanames{en}->{617487049} = "Pegunny";
$areanames{en}->{617487050} = "Proserpine";
$areanames{en}->{617487051} = "Rockhampton";
$areanames{en}->{617487052} = "Rolleston";
$areanames{en}->{617487053} = "Sarina";
$areanames{en}->{617487054} = "Spier";
$areanames{en}->{617487055} = "Springsure";
$areanames{en}->{617487056} = "St\ Lawrence";
$areanames{en}->{617487057} = "The\ Caves";
$areanames{en}->{617487058} = "Theodore";
$areanames{en}->{617487059} = "Tieri";
$areanames{en}->{617487060} = "Tungamull";
$areanames{en}->{617487061} = "Turkey\ Beach";
$areanames{en}->{617487062} = "Ubobo";
$areanames{en}->{617487063} = "Wagoora";
$areanames{en}->{617487064} = "Walkerston";
$areanames{en}->{617487065} = "Westwood";
$areanames{en}->{617487066} = "Willows";
$areanames{en}->{617487067} = "Woorabinda";
$areanames{en}->{617487068} = "Wowan";
$areanames{en}->{617487069} = "Yakapari";
$areanames{en}->{617487070} = "Yeppoon";
$areanames{en}->{617487071} = "Zamia\ Creek";
$areanames{en}->{617487072} = "Agnes\ Water";
$areanames{en}->{617487073} = "Alpha";
$areanames{en}->{617487074} = "Bajool";
$areanames{en}->{617487075} = "Banana";
$areanames{en}->{617487076} = "Baralaba";
$areanames{en}->{617487077} = "Bauhinia";
$areanames{en}->{617487078} = "Benaraby";
$areanames{en}->{617487079} = "Biloela";
$areanames{en}->{61748708} = "Glenden";
$areanames{en}->{61748709} = "Belyando";
$areanames{en}->{617487100} = "Bingegang";
$areanames{en}->{617487101} = "Blackwater";
$areanames{en}->{617487102} = "Broadsound";
$areanames{en}->{617487103} = "Buckland";
$areanames{en}->{617487104} = "Byfield";
$areanames{en}->{617487105} = "Calen";
$areanames{en}->{617487106} = "Calliope";
$areanames{en}->{617487107} = "Cannon\ Valley";
$areanames{en}->{617487108} = "Capella";
$areanames{en}->{617487109} = "Carbine\ Creek";
$areanames{en}->{617487110} = "Carmila";
$areanames{en}->{617487111} = "Clermont";
$areanames{en}->{617487112} = "Colston\ Park";
$areanames{en}->{617487113} = "Comet";
$areanames{en}->{617487114} = "Connors\ Range";
$areanames{en}->{617487115} = "Cracow";
$areanames{en}->{617487116} = "Dingo";
$areanames{en}->{617487117} = "Dingo\ Beach";
$areanames{en}->{617487118} = "Duaringa";
$areanames{en}->{617487119} = "Dysart";
$areanames{en}->{617487120} = "Emerald";
$areanames{en}->{617487121} = "Finch\ Hatton";
$areanames{en}->{617487122} = "Fitzroy\ West";
$areanames{en}->{617487123} = "Gargett";
$areanames{en}->{617487124} = "Garnant";
$areanames{en}->{617487125} = "Gayfield";
$areanames{en}->{617487126} = "Gemfields";
$areanames{en}->{617487127} = "Gladstone";
$areanames{en}->{617487128} = "Glenden";
$areanames{en}->{617487129} = "Goovigen";
$areanames{en}->{617487130} = "Hodgson\ Range";
$areanames{en}->{617487131} = "Isaac\ River";
$areanames{en}->{617487132} = "Koumala";
$areanames{en}->{617487133} = "Lethebrook";
$areanames{en}->{617487134} = "Mackay";
$areanames{en}->{617487135} = "Mardale";
$areanames{en}->{617487136} = "Marlborough";
$areanames{en}->{617487137} = "Miclere";
$areanames{en}->{617487138} = "Middlemount";
$areanames{en}->{617487139} = "Miriam\ Vale";
$areanames{en}->{617487140} = "Moranbah";
$areanames{en}->{617487141} = "Mount\ Coolon";
$areanames{en}->{617487142} = "Mount\ Gardiner";
$areanames{en}->{617487143} = "Mount\ Larcom";
$areanames{en}->{617487144} = "Mount\ Morgan";
$areanames{en}->{617487145} = "Moura";
$areanames{en}->{617487146} = "Nathan\ Gorge";
$areanames{en}->{617487147} = "Nebo";
$areanames{en}->{617487148} = "Nogoa";
$areanames{en}->{617487149} = "Oombabeer";
$areanames{en}->{617487150} = "Orion";
$areanames{en}->{617487151} = "Pegunny";
$areanames{en}->{617487152} = "Proserpine";
$areanames{en}->{617487153} = "Rockhampton";
$areanames{en}->{617487154} = "Rolleston";
$areanames{en}->{617487155} = "Sarina";
$areanames{en}->{617487156} = "Spier";
$areanames{en}->{617487157} = "Springsure";
$areanames{en}->{617487158} = "St\ Lawrence";
$areanames{en}->{617487159} = "The\ Caves";
$areanames{en}->{617487160} = "Theodore";
$areanames{en}->{617487161} = "Tieri";
$areanames{en}->{617487162} = "Tungamull";
$areanames{en}->{617487163} = "Turkey\ Beach";
$areanames{en}->{617487164} = "Ubobo";
$areanames{en}->{617487165} = "Wagoora";
$areanames{en}->{617487166} = "Walkerston";
$areanames{en}->{617487167} = "Westwood";
$areanames{en}->{617487168} = "Willows";
$areanames{en}->{617487169} = "Woorabinda";
$areanames{en}->{617487170} = "Wowan";
$areanames{en}->{617487171} = "Yakapari";
$areanames{en}->{617487172} = "Yeppoon";
$areanames{en}->{617487173} = "Zamia\ Creek";
$areanames{en}->{61748718} = "Garnant";
$areanames{en}->{61748719} = "Biloela";
$areanames{en}->{61748730} = "Clermont";
$areanames{en}->{61748749} = "Dysart";
$areanames{en}->{61748834} = "Rockhampton";
$areanames{en}->{61748835} = "Mackay";
$areanames{en}->{61748836} = "Gladstone";
$areanames{en}->{61748837} = "Gladstone";
$areanames{en}->{61748838} = "Gladstone";
$areanames{en}->{61748839} = "Gladstone";
$areanames{en}->{61748840} = "Springsure";
$areanames{en}->{61748841} = "Springsure";
$areanames{en}->{61748842} = "Mount\ Coolon";
$areanames{en}->{61748843} = "Rolleston";
$areanames{en}->{61748844} = "Comet";
$areanames{en}->{61748845} = "Tieri";
$areanames{en}->{61748846} = "Tieri";
$areanames{en}->{61748847} = "Belyando";
$areanames{en}->{61748848} = "Middlemount";
$areanames{en}->{61748849} = "Orion";
$areanames{en}->{61748850} = "Carbine\ Creek";
$areanames{en}->{61748851} = "Hodgson\ Range";
$areanames{en}->{61748852} = "Bingegang";
$areanames{en}->{61748853} = "Willows";
$areanames{en}->{61748854} = "Nogoa";
$areanames{en}->{61748855} = "Mackay";
$areanames{en}->{61748856} = "Mackay";
$areanames{en}->{61748857} = "Mackay";
$areanames{en}->{61748858} = "Moranbah";
$areanames{en}->{61748859} = "Gladstone";
$areanames{en}->{61748860} = "Gladstone";
$areanames{en}->{61748861} = "Blackwater";
$areanames{en}->{61748862} = "Rockhampton";
$areanames{en}->{61748863} = "Rockhampton";
$areanames{en}->{61748864} = "Emerald";
$areanames{en}->{61748865} = "Emerald";
$areanames{en}->{61748866} = "Mackay";
$areanames{en}->{61748867} = "Gladstone";
$areanames{en}->{61748868} = "Gladstone";
$areanames{en}->{61748869} = "Gladstone";
$areanames{en}->{6174887} = "Rockhampton";
$areanames{en}->{61748878} = "Moranbah";
$areanames{en}->{61748879} = "Moranbah";
$areanames{en}->{61748880} = "Cannon\ Valley";
$areanames{en}->{61748881} = "Cannon\ Valley";
$areanames{en}->{61748882} = "Cannon\ Valley";
$areanames{en}->{61748883} = "Walkerston";
$areanames{en}->{61748884} = "Walkerston";
$areanames{en}->{61748885} = "Walkerston";
$areanames{en}->{61748886} = "Walkerston";
$areanames{en}->{61748887} = "Walkerston";
$areanames{en}->{61748888} = "Rockhampton";
$areanames{en}->{61748889} = "Gladstone";
$areanames{en}->{6174889} = "Mackay";
$areanames{en}->{61748970} = "Emerald";
$areanames{en}->{61748971} = "Emerald";
$areanames{en}->{61748972} = "Emerald";
$areanames{en}->{61748973} = "Sarina";
$areanames{en}->{61748974} = "Sarina";
$areanames{en}->{61748975} = "Sarina";
$areanames{en}->{61748976} = "Rockhampton";
$areanames{en}->{61748977} = "Rockhampton";
$areanames{en}->{61748978} = "Rockhampton";
$areanames{en}->{61748979} = "Rockhampton";
$areanames{en}->{6174898} = "Mackay";
$areanames{en}->{61748983} = "Connors\ Range";
$areanames{en}->{61748984} = "St\ Lawrence";
$areanames{en}->{61748988} = "Theodore";
$areanames{en}->{61748989} = "Nebo";
$areanames{en}->{6174899} = "Gladstone";
$areanames{en}->{61748995} = "Mackay";
$areanames{en}->{61748996} = "Mackay";
$areanames{en}->{61748998} = "Calliope";
$areanames{en}->{61748999} = "Alpha";
$areanames{en}->{61749000} = "Rockhampton";
$areanames{en}->{61749001} = "Rockhampton";
$areanames{en}->{61749002} = "Rockhampton";
$areanames{en}->{61749003} = "Mackay";
$areanames{en}->{61749004} = "Mackay";
$areanames{en}->{61749005} = "Mackay";
$areanames{en}->{61749006} = "Agnes\ Water";
$areanames{en}->{61749007} = "Alpha";
$areanames{en}->{61749008} = "Bajool";
$areanames{en}->{61749009} = "Banana";
$areanames{en}->{61749010} = "Baralaba";
$areanames{en}->{61749011} = "Bauhinia";
$areanames{en}->{61749012} = "Belyando";
$areanames{en}->{61749013} = "Benaraby";
$areanames{en}->{61749014} = "Biloela";
$areanames{en}->{61749015} = "Bingegang";
$areanames{en}->{61749016} = "Blackwater";
$areanames{en}->{61749017} = "Broadsound";
$areanames{en}->{61749018} = "Buckland";
$areanames{en}->{61749019} = "Byfield";
$areanames{en}->{61749020} = "Agnes\ Water";
$areanames{en}->{61749021} = "Agnes\ Water";
$areanames{en}->{61749022} = "Agnes\ Water";
$areanames{en}->{61749023} = "Benaraby";
$areanames{en}->{61749024} = "Benaraby";
$areanames{en}->{61749025} = "Benaraby";
$areanames{en}->{61749026} = "Miriam\ Vale";
$areanames{en}->{61749027} = "Miriam\ Vale";
$areanames{en}->{61749028} = "Mount\ Larcom";
$areanames{en}->{61749029} = "Mount\ Larcom";
$areanames{en}->{61749030} = "Calen";
$areanames{en}->{61749031} = "Calliope";
$areanames{en}->{61749032} = "Cannon\ Valley";
$areanames{en}->{61749033} = "Capella";
$areanames{en}->{61749034} = "Carbine\ Creek";
$areanames{en}->{61749035} = "Carmila";
$areanames{en}->{61749036} = "Clermont";
$areanames{en}->{61749037} = "Colston\ Park";
$areanames{en}->{61749038} = "Comet";
$areanames{en}->{61749039} = "Connors\ Range";
$areanames{en}->{6174904} = "Gladstone";
$areanames{en}->{61749050} = "Cracow";
$areanames{en}->{61749051} = "Dingo";
$areanames{en}->{61749052} = "Dingo\ Beach";
$areanames{en}->{61749053} = "Duaringa";
$areanames{en}->{61749054} = "Dysart";
$areanames{en}->{61749055} = "Emerald";
$areanames{en}->{61749056} = "Finch\ Hatton";
$areanames{en}->{61749057} = "Fitzroy\ West";
$areanames{en}->{61749058} = "Gargett";
$areanames{en}->{61749059} = "Garnant";
$areanames{en}->{61749060} = "Gayfield";
$areanames{en}->{61749061} = "Gemfields";
$areanames{en}->{61749062} = "Gladstone";
$areanames{en}->{61749063} = "Glenden";
$areanames{en}->{61749064} = "Goovigen";
$areanames{en}->{61749065} = "Hodgson\ Range";
$areanames{en}->{61749066} = "Isaac\ River";
$areanames{en}->{61749067} = "Koumala";
$areanames{en}->{61749068} = "Lethebrook";
$areanames{en}->{61749069} = "Mardale";
$areanames{en}->{61749070} = "Marlborough";
$areanames{en}->{61749071} = "Miclere";
$areanames{en}->{61749072} = "Middlemount";
$areanames{en}->{61749073} = "Miriam\ Vale";
$areanames{en}->{61749074} = "Moranbah";
$areanames{en}->{61749075} = "Miclere";
$areanames{en}->{61749076} = "Broadsound";
$areanames{en}->{61749077} = "Mount\ Larcom";
$areanames{en}->{61749078} = "Mount\ Morgan";
$areanames{en}->{61749079} = "Moura";
$areanames{en}->{61749080} = "Nathan\ Gorge";
$areanames{en}->{61749081} = "Nebo";
$areanames{en}->{61749082} = "Oombabeer";
$areanames{en}->{61749083} = "Orion";
$areanames{en}->{61749084} = "Pegunny";
$areanames{en}->{61749085} = "Proserpine";
$areanames{en}->{61749086} = "Rockhampton";
$areanames{en}->{61749087} = "Rolleston";
$areanames{en}->{61749088} = "Sarina";
$areanames{en}->{61749089} = "Spier";
$areanames{en}->{61749090} = "Springsure";
$areanames{en}->{61749091} = "St\ Lawrence";
$areanames{en}->{61749092} = "The\ Caves";
$areanames{en}->{61749093} = "Theodore";
$areanames{en}->{61749094} = "Tieri";
$areanames{en}->{61749095} = "Tungamull";
$areanames{en}->{61749096} = "Turkey\ Beach";
$areanames{en}->{61749097} = "Ubobo";
$areanames{en}->{61749098} = "Wagoora";
$areanames{en}->{61749099} = "Walkerston";
$areanames{en}->{61749100} = "Westwood";
$areanames{en}->{61749101} = "Willows";
$areanames{en}->{61749102} = "Woorabinda";
$areanames{en}->{61749103} = "Wowan";
$areanames{en}->{61749104} = "Yakapari";
$areanames{en}->{61749105} = "Yeppoon";
$areanames{en}->{61749106} = "Zamia\ Creek";
$areanames{en}->{61749107} = "Emerald";
$areanames{en}->{61749108} = "Gladstone";
$areanames{en}->{61749109} = "Mackay";
$areanames{en}->{61749110} = "Mackay";
$areanames{en}->{61749111} = "Rockhampton";
$areanames{en}->{61749112} = "Rockhampton";
$areanames{en}->{61749113} = "Rockhampton";
$areanames{en}->{61749114} = "Mackay";
$areanames{en}->{61749115} = "Proserpine";
$areanames{en}->{61749116} = "Rockhampton";
$areanames{en}->{61749117} = "Marlborough";
$areanames{en}->{61749118} = "Mount\ Gardiner";
$areanames{en}->{61749119} = "Yeppoon";
$areanames{en}->{61749120} = "Tungamull";
$areanames{en}->{61749121} = "Tungamull";
$areanames{en}->{61749122} = "Bajool";
$areanames{en}->{61749123} = "Bajool";
$areanames{en}->{61749124} = "Mount\ Morgan";
$areanames{en}->{61749125} = "Mount\ Morgan";
$areanames{en}->{61749126} = "The\ Caves";
$areanames{en}->{61749127} = "The\ Caves";
$areanames{en}->{61749128} = "Marlborough";
$areanames{en}->{61749129} = "Garnant";
$areanames{en}->{61749130} = "Rockhampton";
$areanames{en}->{617491310} = "Emerald";
$areanames{en}->{617491315} = "Yeppoon";
$areanames{en}->{61749132} = "Woorabinda";
$areanames{en}->{61749133} = "Yeppoon";
$areanames{en}->{61749134} = "Yeppoon";
$areanames{en}->{61749135} = "Yeppoon";
$areanames{en}->{61749136} = "Yeppoon";
$areanames{en}->{61749137} = "Yeppoon";
$areanames{en}->{61749138} = "Yeppoon";
$areanames{en}->{61749139} = "Yeppoon";
$areanames{en}->{61749140} = "Rockhampton";
$areanames{en}->{61749141} = "Woorabinda";
$areanames{en}->{61749142} = "Mackay";
$areanames{en}->{61749143} = "Pegunny";
$areanames{en}->{61749144} = "Spier";
$areanames{en}->{61749145} = "Theodore";
$areanames{en}->{61749146} = "Zamia\ Creek";
$areanames{en}->{61749147} = "Banana";
$areanames{en}->{61749148} = "Baralaba";
$areanames{en}->{61749149} = "Bauhinia";
$areanames{en}->{61749150} = "Biloela";
$areanames{en}->{61749151} = "Cracow";
$areanames{en}->{61749152} = "Goovigen";
$areanames{en}->{61749153} = "Mardale";
$areanames{en}->{61749154} = "Moura";
$areanames{en}->{61749155} = "Nathan\ Gorge";
$areanames{en}->{61749156} = "Oombabeer";
$areanames{en}->{61749157} = "Willows";
$areanames{en}->{61749158} = "Nogoa";
$areanames{en}->{61749159} = "Orion";
$areanames{en}->{61749160} = "Rolleston";
$areanames{en}->{61749161} = "Springsure";
$areanames{en}->{61749162} = "Tieri";
$areanames{en}->{61749163} = "Capella";
$areanames{en}->{61749164} = "Carbine\ Creek";
$areanames{en}->{61749165} = "Clermont";
$areanames{en}->{61749166} = "Comet";
$areanames{en}->{61749167} = "Emerald";
$areanames{en}->{61749168} = "Gemfields";
$areanames{en}->{61749169} = "Hodgson\ Range";
$areanames{en}->{61749170} = "Miclere";
$areanames{en}->{61749171} = "Middlemount";
$areanames{en}->{61749172} = "Mount\ Coolon";
$areanames{en}->{61749173} = "Alpha";
$areanames{en}->{61749174} = "Belyando";
$areanames{en}->{61749175} = "Bingegang";
$areanames{en}->{61749176} = "Blackwater";
$areanames{en}->{61749177} = "Buckland";
$areanames{en}->{61749178} = "Agnes\ Water";
$areanames{en}->{61749179} = "Benaraby";
$areanames{en}->{61749180} = "Calliope";
$areanames{en}->{61749181} = "Gayfield";
$areanames{en}->{61749182} = "Gladstone";
$areanames{en}->{61749183} = "Miriam\ Vale";
$areanames{en}->{61749184} = "Mount\ Larcom";
$areanames{en}->{61749185} = "Turkey\ Beach";
$areanames{en}->{61749186} = "Ubobo";
$areanames{en}->{61749187} = "Lethebrook";
$areanames{en}->{61749188} = "Mackay";
$areanames{en}->{61749189} = "Moranbah";
$areanames{en}->{61749190} = "Nebo";
$areanames{en}->{61749191} = "Proserpine";
$areanames{en}->{61749192} = "Sarina";
$areanames{en}->{61749193} = "St\ Lawrence";
$areanames{en}->{61749194} = "Wagoora";
$areanames{en}->{61749195} = "Walkerston";
$areanames{en}->{61749196} = "Yakapari";
$areanames{en}->{61749197} = "Cannon\ Valley";
$areanames{en}->{61749198} = "Carmila";
$areanames{en}->{61749199} = "Colston\ Park";
$areanames{en}->{617492} = "Rockhampton";
$areanames{en}->{61749208} = "Marlborough";
$areanames{en}->{61749209} = "Tungamull";
$areanames{en}->{6174925} = "Yeppoon";
$areanames{en}->{61749256} = "Duaringa";
$areanames{en}->{61749257} = "Dingo";
$areanames{en}->{61749258} = "Byfield";
$areanames{en}->{61749259} = "Woorabinda";
$areanames{en}->{61749290} = "Westwood";
$areanames{en}->{61749291} = "Westwood";
$areanames{en}->{61749292} = "Connors\ Range";
$areanames{en}->{61749293} = "Dingo\ Beach";
$areanames{en}->{61749294} = "Dysart";
$areanames{en}->{61749295} = "Finch\ Hatton";
$areanames{en}->{61749296} = "Gargett";
$areanames{en}->{61749297} = "Glenden";
$areanames{en}->{61749298} = "Koumala";
$areanames{en}->{61749299} = "Calen";
$areanames{en}->{6174930} = "Rockhampton";
$areanames{en}->{61749302} = "Yeppoon";
$areanames{en}->{61749303} = "Westwood";
$areanames{en}->{6174931} = "Rockhampton";
$areanames{en}->{6174932} = "Rockhampton";
$areanames{en}->{61749330} = "Yeppoon";
$areanames{en}->{61749331} = "Rockhampton";
$areanames{en}->{61749332} = "Rockhampton";
$areanames{en}->{61749333} = "Rockhampton";
$areanames{en}->{61749334} = "Rockhampton";
$areanames{en}->{61749335} = "Rockhampton";
$areanames{en}->{61749336} = "Yeppoon";
$areanames{en}->{61749337} = "Yeppoon";
$areanames{en}->{61749338} = "Yeppoon";
$areanames{en}->{61749339} = "Tungamull";
$areanames{en}->{61749340} = "Mount\ Morgan";
$areanames{en}->{61749341} = "Rockhampton";
$areanames{en}->{61749342} = "The\ Caves";
$areanames{en}->{61749343} = "The\ Caves";
$areanames{en}->{61749344} = "Tungamull";
$areanames{en}->{61749345} = "Garnant";
$areanames{en}->{61749346} = "Bajool";
$areanames{en}->{61749347} = "Westwood";
$areanames{en}->{61749348} = "Rockhampton";
$areanames{en}->{61749349} = "Westwood";
$areanames{en}->{61749350} = "Woorabinda";
$areanames{en}->{61749351} = "Byfield";
$areanames{en}->{61749352} = "Bajool";
$areanames{en}->{61749353} = "Tungamull";
$areanames{en}->{61749354} = "Tungamull";
$areanames{en}->{61749355} = "Broadsound";
$areanames{en}->{61749356} = "Marlborough";
$areanames{en}->{61749357} = "Duaringa";
$areanames{en}->{61749358} = "Fitzroy\ West";
$areanames{en}->{61749359} = "Dingo";
$areanames{en}->{6174936} = "Rockhampton";
$areanames{en}->{61749370} = "Wowan";
$areanames{en}->{61749371} = "Wowan";
$areanames{en}->{61749372} = "Wowan";
$areanames{en}->{61749373} = "Broadsound";
$areanames{en}->{61749374} = "Rockhampton";
$areanames{en}->{61749375} = "Rockhampton";
$areanames{en}->{61749376} = "Rockhampton";
$areanames{en}->{61749377} = "Westwood";
$areanames{en}->{61749378} = "Westwood";
$areanames{en}->{61749379} = "Westwood";
$areanames{en}->{61749380} = "Mount\ Gardiner";
$areanames{en}->{61749381} = "Mount\ Morgan";
$areanames{en}->{61749382} = "Mount\ Morgan";
$areanames{en}->{61749383} = "Yeppoon";
$areanames{en}->{61749384} = "Rockhampton";
$areanames{en}->{61749385} = "Rockhampton";
$areanames{en}->{61749386} = "Rockhampton";
$areanames{en}->{61749387} = "Yeppoon";
$areanames{en}->{61749388} = "Yeppoon";
$areanames{en}->{61749389} = "Isaac\ River";
$areanames{en}->{6174939} = "Yeppoon";
$areanames{en}->{61749400} = "Mackay";
$areanames{en}->{61749401} = "Cannon\ Valley";
$areanames{en}->{61749402} = "Cannon\ Valley";
$areanames{en}->{61749403} = "Mackay";
$areanames{en}->{61749404} = "Moranbah";
$areanames{en}->{61749405} = "Glenden";
$areanames{en}->{61749406} = "Proserpine";
$areanames{en}->{61749407} = "Mackay";
$areanames{en}->{61749408} = "Lethebrook";
$areanames{en}->{61749409} = "Sarina";
$areanames{en}->{6174941} = "Moranbah";
$areanames{en}->{61749411} = "Dysart";
$areanames{en}->{61749412} = "Dysart";
$areanames{en}->{6174942} = "Mackay";
$areanames{en}->{6174943} = "Sarina";
$areanames{en}->{6174944} = "Mackay";
$areanames{en}->{6174945} = "Proserpine";
$areanames{en}->{61749457} = "Dingo\ Beach";
$areanames{en}->{61749458} = "Dingo\ Beach";
$areanames{en}->{6174946} = "Cannon\ Valley";
$areanames{en}->{61749470} = "Proserpine";
$areanames{en}->{61749471} = "Proserpine";
$areanames{en}->{61749472} = "Proserpine";
$areanames{en}->{61749473} = "Cannon\ Valley";
$areanames{en}->{61749474} = "Calen";
$areanames{en}->{61749475} = "Lethebrook";
$areanames{en}->{61749476} = "Lethebrook";
$areanames{en}->{61749477} = "Lethebrook";
$areanames{en}->{61749478} = "Lethebrook";
$areanames{en}->{61749479} = "Lethebrook";
$areanames{en}->{6174948} = "Cannon\ Valley";
$areanames{en}->{61749490} = "Dysart";
$areanames{en}->{61749491} = "Dysart";
$areanames{en}->{61749492} = "Moranbah";
$areanames{en}->{61749493} = "Moranbah";
$areanames{en}->{61749494} = "Nebo";
$areanames{en}->{61749495} = "Finch\ Hatton";
$areanames{en}->{61749496} = "Gargett";
$areanames{en}->{61749497} = "Calen";
$areanames{en}->{61749498} = "Koumala";
$areanames{en}->{61749499} = "Carmila";
$areanames{en}->{61749500} = "Dysart";
$areanames{en}->{61749501} = "Koumala";
$areanames{en}->{61749502} = "Carmila";
$areanames{en}->{61749503} = "Koumala";
$areanames{en}->{61749504} = "Colston\ Park";
$areanames{en}->{61749505} = "Nebo";
$areanames{en}->{61749506} = "Nebo";
$areanames{en}->{61749507} = "Connors\ Range";
$areanames{en}->{61749508} = "Glenden";
$areanames{en}->{61749509} = "Glenden";
$areanames{en}->{6174951} = "Mackay";
$areanames{en}->{6174952} = "Mackay";
$areanames{en}->{6174953} = "Mackay";
$areanames{en}->{61749540} = "Yakapari";
$areanames{en}->{61749541} = "Walkerston";
$areanames{en}->{61749542} = "Walkerston";
$areanames{en}->{61749543} = "Walkerston";
$areanames{en}->{61749544} = "Walkerston";
$areanames{en}->{61749545} = "Mackay";
$areanames{en}->{61749546} = "Mackay";
$areanames{en}->{61749547} = "Mackay";
$areanames{en}->{61749548} = "Mackay";
$areanames{en}->{61749549} = "Mackay";
$areanames{en}->{6174955} = "Mackay";
$areanames{en}->{6174956} = "Sarina";
$areanames{en}->{61749560} = "St\ Lawrence";
$areanames{en}->{61749568} = "Connors\ Range";
$areanames{en}->{61749569} = "St\ Lawrence";
$areanames{en}->{6174957} = "Mackay";
$areanames{en}->{61749580} = "Moranbah";
$areanames{en}->{61749581} = "Dysart";
$areanames{en}->{61749582} = "Dysart";
$areanames{en}->{61749583} = "Finch\ Hatton";
$areanames{en}->{61749584} = "Finch\ Hatton";
$areanames{en}->{61749585} = "Gargett";
$areanames{en}->{61749586} = "Gargett";
$areanames{en}->{61749587} = "Wagoora";
$areanames{en}->{61749588} = "Calen";
$areanames{en}->{61749589} = "Glenden";
$areanames{en}->{61749590} = "Yakapari";
$areanames{en}->{61749591} = "Walkerston";
$areanames{en}->{61749592} = "Walkerston";
$areanames{en}->{61749593} = "Walkerston";
$areanames{en}->{61749594} = "Walkerston";
$areanames{en}->{61749595} = "Mackay";
$areanames{en}->{61749596} = "Mackay";
$areanames{en}->{61749597} = "Walkerston";
$areanames{en}->{61749598} = "Mackay";
$areanames{en}->{61749599} = "Mackay";
$areanames{en}->{6174960} = "Mackay";
$areanames{en}->{61749610} = "Mount\ Morgan";
$areanames{en}->{61749611} = "Rockhampton";
$areanames{en}->{61749612} = "Gladstone";
$areanames{en}->{61749613} = "Mackay";
$areanames{en}->{61749614} = "Rockhampton";
$areanames{en}->{61749615} = "The\ Caves";
$areanames{en}->{61749616} = "Tungamull";
$areanames{en}->{61749617} = "Westwood";
$areanames{en}->{61749618} = "Mackay";
$areanames{en}->{61749619} = "Mackay";
$areanames{en}->{61749620} = "Gladstone";
$areanames{en}->{61749621} = "Gladstone";
$areanames{en}->{61749622} = "Gladstone";
$areanames{en}->{61749623} = "Mackay";
$areanames{en}->{61749624} = "Cannon\ Valley";
$areanames{en}->{61749625} = "Cannon\ Valley";
$areanames{en}->{61749626} = "Cannon\ Valley";
$areanames{en}->{61749627} = "Isaac\ River";
$areanames{en}->{61749628} = "Marlborough";
$areanames{en}->{61749629} = "Mount\ Gardiner";
$areanames{en}->{6174963} = "Mackay";
$areanames{en}->{61749640} = "Colston\ Park";
$areanames{en}->{61749641} = "Cannon\ Valley";
$areanames{en}->{61749642} = "Glenden";
$areanames{en}->{61749643} = "Walkerston";
$areanames{en}->{61749644} = "Wagoora";
$areanames{en}->{61749645} = "St\ Lawrence";
$areanames{en}->{61749646} = "Proserpine";
$areanames{en}->{61749647} = "Proserpine";
$areanames{en}->{61749648} = "Sarina";
$areanames{en}->{61749649} = "Sarina";
$areanames{en}->{6174965} = "Mackay";
$areanames{en}->{61749650} = "Gladstone";
$areanames{en}->{61749651} = "Gladstone";
$areanames{en}->{61749652} = "Gladstone";
$areanames{en}->{61749653} = "Cannon\ Valley";
$areanames{en}->{61749660} = "Yakapari";
$areanames{en}->{61749661} = "Yakapari";
$areanames{en}->{61749662} = "Yakapari";
$areanames{en}->{61749663} = "Yakapari";
$areanames{en}->{61749664} = "Yakapari";
$areanames{en}->{61749665} = "Walkerston";
$areanames{en}->{61749666} = "Walkerston";
$areanames{en}->{61749667} = "Walkerston";
$areanames{en}->{61749668} = "Walkerston";
$areanames{en}->{61749669} = "Walkerston";
$areanames{en}->{61749670} = "Mackay";
$areanames{en}->{61749671} = "Mackay";
$areanames{en}->{61749672} = "Mackay";
$areanames{en}->{61749673} = "Mackay";
$areanames{en}->{61749674} = "Mackay";
$areanames{en}->{61749675} = "Cannon\ Valley";
$areanames{en}->{61749676} = "Cannon\ Valley";
$areanames{en}->{61749677} = "Cannon\ Valley";
$areanames{en}->{61749678} = "Sarina";
$areanames{en}->{61749679} = "Moranbah";
$areanames{en}->{6174968} = "Mackay";
$areanames{en}->{61749687} = "Walkerston";
$areanames{en}->{61749688} = "Moranbah";
$areanames{en}->{61749689} = "Dysart";
$areanames{en}->{6174969} = "Mackay";
$areanames{en}->{61749698} = "Cannon\ Valley";
$areanames{en}->{61749699} = "Cannon\ Valley";
$areanames{en}->{6174970} = "Gladstone";
$areanames{en}->{61749702} = "Mount\ Larcom";
$areanames{en}->{61749704} = "Benaraby";
$areanames{en}->{61749705} = "Miriam\ Vale";
$areanames{en}->{6174971} = "Gladstone";
$areanames{en}->{6174972} = "Gladstone";
$areanames{en}->{6174973} = "Gladstone";
$areanames{en}->{61749740} = "Ubobo";
$areanames{en}->{61749741} = "Ubobo";
$areanames{en}->{61749742} = "Turkey\ Beach";
$areanames{en}->{61749743} = "Turkey\ Beach";
$areanames{en}->{61749744} = "Miriam\ Vale";
$areanames{en}->{61749745} = "Miriam\ Vale";
$areanames{en}->{61749746} = "Miriam\ Vale";
$areanames{en}->{61749747} = "Agnes\ Water";
$areanames{en}->{61749748} = "Gayfield";
$areanames{en}->{61749749} = "Agnes\ Water";
$areanames{en}->{6174975} = "Calliope";
$areanames{en}->{61749750} = "Benaraby";
$areanames{en}->{61749751} = "Mount\ Larcom";
$areanames{en}->{61749752} = "Gladstone";
$areanames{en}->{61749753} = "Mount\ Larcom";
$areanames{en}->{6174976} = "Gladstone";
$areanames{en}->{61749770} = "Cannon\ Valley";
$areanames{en}->{61749771} = "Yeppoon";
$areanames{en}->{61749772} = "Byfield";
$areanames{en}->{61749773} = "Byfield";
$areanames{en}->{61749774} = "Rockhampton";
$areanames{en}->{61749775} = "Mackay";
$areanames{en}->{61749776} = "Gladstone";
$areanames{en}->{61749777} = "Gladstone";
$areanames{en}->{61749778} = "Gladstone";
$areanames{en}->{61749779} = "Gladstone";
$areanames{en}->{6174980} = "Emerald";
$areanames{en}->{61749801} = "Blackwater";
$areanames{en}->{61749802} = "Clermont";
$areanames{en}->{61749805} = "Blackwater";
$areanames{en}->{61749810} = "Gemfields";
$areanames{en}->{61749811} = "Gemfields";
$areanames{en}->{61749812} = "Middlemount";
$areanames{en}->{61749813} = "Middlemount";
$areanames{en}->{61749814} = "Springsure";
$areanames{en}->{61749815} = "Springsure";
$areanames{en}->{61749816} = "Tieri";
$areanames{en}->{61749817} = "Tieri";
$areanames{en}->{61749818} = "Willows";
$areanames{en}->{61749819} = "Alpha";
$areanames{en}->{6174982} = "Emerald";
$areanames{en}->{61749825} = "Blackwater";
$areanames{en}->{61749826} = "Blackwater";
$areanames{en}->{61749827} = "Blackwater";
$areanames{en}->{61749829} = "Blackwater";
$areanames{en}->{61749830} = "Clermont";
$areanames{en}->{61749831} = "Clermont";
$areanames{en}->{61749832} = "Clermont";
$areanames{en}->{61749833} = "Clermont";
$areanames{en}->{61749834} = "Clermont";
$areanames{en}->{61749835} = "Miclere";
$areanames{en}->{61749836} = "Miclere";
$areanames{en}->{61749837} = "Emerald";
$areanames{en}->{61749838} = "Emerald";
$areanames{en}->{61749839} = "Emerald";
$areanames{en}->{61749840} = "Capella";
$areanames{en}->{61749841} = "Springsure";
$areanames{en}->{61749842} = "Buckland";
$areanames{en}->{61749843} = "Rolleston";
$areanames{en}->{61749844} = "Buckland";
$areanames{en}->{61749845} = "Comet";
$areanames{en}->{61749846} = "Orion";
$areanames{en}->{61749847} = "Tieri";
$areanames{en}->{61749848} = "Tieri";
$areanames{en}->{61749849} = "Capella";
$areanames{en}->{61749850} = "Middlemount";
$areanames{en}->{61749851} = "Alpha";
$areanames{en}->{61749852} = "Carbine\ Creek";
$areanames{en}->{61749853} = "Belyando";
$areanames{en}->{61749854} = "Gemfields";
$areanames{en}->{61749855} = "Willows";
$areanames{en}->{61749856} = "Hodgson\ Range";
$areanames{en}->{61749857} = "Middlemount";
$areanames{en}->{61749858} = "Middlemount";
$areanames{en}->{61749859} = "Middlemount";
$areanames{en}->{6174986} = "Blackwater";
$areanames{en}->{61749864} = "Capella";
$areanames{en}->{61749866} = "Mackay";
$areanames{en}->{61749867} = "Emerald";
$areanames{en}->{61749868} = "Emerald";
$areanames{en}->{6174987} = "Emerald";
$areanames{en}->{61749870} = "Alpha";
$areanames{en}->{61749871} = "Blackwater";
$areanames{en}->{61749872} = "Bingegang";
$areanames{en}->{617498730} = "Bingegang";
$areanames{en}->{61749880} = "Emerald";
$areanames{en}->{61749881} = "Emerald";
$areanames{en}->{61749882} = "Emerald";
$areanames{en}->{61749883} = "Clermont";
$areanames{en}->{61749884} = "Clermont";
$areanames{en}->{61749885} = "Clermont";
$areanames{en}->{61749886} = "Capella";
$areanames{en}->{61749887} = "Capella";
$areanames{en}->{61749888} = "Miclere";
$areanames{en}->{61749889} = "Rolleston";
$areanames{en}->{61749890} = "Nogoa";
$areanames{en}->{61749891} = "Wowan";
$areanames{en}->{61749892} = "Yeppoon";
$areanames{en}->{61749893} = "Bajool";
$areanames{en}->{61749894} = "Broadsound";
$areanames{en}->{61749895} = "Byfield";
$areanames{en}->{61749896} = "Dingo";
$areanames{en}->{61749897} = "Duaringa";
$areanames{en}->{61749898} = "Fitzroy\ West";
$areanames{en}->{61749899} = "Garnant";
$areanames{en}->{61749900} = "Biloela";
$areanames{en}->{61749901} = "Biloela";
$areanames{en}->{61749902} = "Spier";
$areanames{en}->{61749903} = "Theodore";
$areanames{en}->{61749904} = "The\ Caves";
$areanames{en}->{61749905} = "The\ Caves";
$areanames{en}->{61749906} = "Cannon\ Valley";
$areanames{en}->{61749907} = "Cannon\ Valley";
$areanames{en}->{61749908} = "Rockhampton";
$areanames{en}->{61749909} = "Moura";
$areanames{en}->{61749910} = "Emerald";
$areanames{en}->{61749911} = "Emerald";
$areanames{en}->{61749912} = "Emerald";
$areanames{en}->{61749913} = "Proserpine";
$areanames{en}->{61749914} = "Tieri";
$areanames{en}->{61749915} = "Yeppoon";
$areanames{en}->{61749916} = "Yeppoon";
$areanames{en}->{61749917} = "Mount\ Morgan";
$areanames{en}->{61749918} = "Mount\ Morgan";
$areanames{en}->{61749919} = "Gemfields";
$areanames{en}->{6174992} = "Biloela";
$areanames{en}->{6174993} = "Theodore";
$areanames{en}->{61749936} = "Nathan\ Gorge";
$areanames{en}->{61749937} = "Cracow";
$areanames{en}->{61749938} = "Biloela";
$areanames{en}->{61749939} = "Biloela";
$areanames{en}->{6174994} = "Rockhampton";
$areanames{en}->{61749950} = "Mardale";
$areanames{en}->{61749951} = "Mardale";
$areanames{en}->{61749952} = "Spier";
$areanames{en}->{61749953} = "Spier";
$areanames{en}->{61749954} = "Biloela";
$areanames{en}->{61749955} = "Biloela";
$areanames{en}->{61749956} = "Biloela";
$areanames{en}->{61749957} = "Banana";
$areanames{en}->{61749958} = "Biloela";
$areanames{en}->{61749959} = "Banana";
$areanames{en}->{61749960} = "Pegunny";
$areanames{en}->{61749961} = "Zamia\ Creek";
$areanames{en}->{61749962} = "Pegunny";
$areanames{en}->{61749963} = "Oombabeer";
$areanames{en}->{61749964} = "Bauhinia";
$areanames{en}->{61749965} = "Goovigen";
$areanames{en}->{61749966} = "Goovigen";
$areanames{en}->{61749967} = "Zamia\ Creek";
$areanames{en}->{61749968} = "Zamia\ Creek";
$areanames{en}->{61749969} = "Zamia\ Creek";
$areanames{en}->{6174997} = "Moura";
$areanames{en}->{61749978} = "Gemfields";
$areanames{en}->{61749979} = "Gemfields";
$areanames{en}->{61749980} = "Baralaba";
$areanames{en}->{61749981} = "Baralaba";
$areanames{en}->{61749982} = "Baralaba";
$areanames{en}->{61749983} = "Biloela";
$areanames{en}->{61749984} = "Biloela";
$areanames{en}->{61749985} = "Mackay";
$areanames{en}->{61749986} = "Mackay";
$areanames{en}->{61749987} = "Calen";
$areanames{en}->{61749988} = "Calen";
$areanames{en}->{61749989} = "Mackay";
$areanames{en}->{61749990} = "Rockhampton";
$areanames{en}->{61749991} = "Rockhampton";
$areanames{en}->{61749992} = "Rockhampton";
$areanames{en}->{61749993} = "Rockhampton";
$areanames{en}->{61749994} = "Rockhampton";
$areanames{en}->{61749995} = "Mackay";
$areanames{en}->{61749996} = "Mackay";
$areanames{en}->{61749997} = "Mackay";
$areanames{en}->{61749998} = "Mackay";
$areanames{en}->{61749999} = "Mackay";
$areanames{en}->{61752000} = "Nambour";
$areanames{en}->{61752001} = "Ballugan";
$areanames{en}->{61752002} = "Boonah";
$areanames{en}->{61752003} = "Caboolture";
$areanames{en}->{61752004} = "Caloundra";
$areanames{en}->{61752005} = "Coominya";
$areanames{en}->{61752006} = "Cooroy";
$areanames{en}->{61752007} = "Crossdale";
$areanames{en}->{61752008} = "Esk";
$areanames{en}->{61752009} = "Gatton";
$areanames{en}->{61752010} = "Gunalda";
$areanames{en}->{61752011} = "Gympie";
$areanames{en}->{61752012} = "Harrisville";
$areanames{en}->{61752013} = "Imbil";
$areanames{en}->{61752014} = "Jimna";
$areanames{en}->{61752015} = "Kalbar";
$areanames{en}->{61752016} = "Kenilworth";
$areanames{en}->{61752017} = "Kia\ Ora";
$areanames{en}->{61752018} = "Kilcoy";
$areanames{en}->{61752019} = "Kilkivan";
$areanames{en}->{6175202} = "Caloundra";
$areanames{en}->{61752030} = "Caloundra";
$areanames{en}->{61752031} = "Caloundra";
$areanames{en}->{61752032} = "Caloundra";
$areanames{en}->{61752033} = "Caloundra";
$areanames{en}->{61752034} = "Caloundra";
$areanames{en}->{61752035} = "Laidley";
$areanames{en}->{61752036} = "Lowood";
$areanames{en}->{61752037} = "Maleny";
$areanames{en}->{61752038} = "Maroon";
$areanames{en}->{61752039} = "Moore";
$areanames{en}->{61752040} = "Nambour";
$areanames{en}->{61752041} = "Noosaville";
$areanames{en}->{61752042} = "Pomona";
$areanames{en}->{61752043} = "Rosevale";
$areanames{en}->{61752044} = "Rosewood";
$areanames{en}->{61752045} = "Thornton";
$areanames{en}->{61752046} = "Toogoolawah";
$areanames{en}->{61752047} = "Upper\ Widgee";
$areanames{en}->{61752048} = "Wolvi";
$areanames{en}->{61752049} = "Woodbine";
$areanames{en}->{61752050} = "Woolooga";
$areanames{en}->{61752051} = "Ballugan";
$areanames{en}->{61752052} = "Boonah";
$areanames{en}->{61752053} = "Caboolture";
$areanames{en}->{61752054} = "Caloundra";
$areanames{en}->{61752055} = "Coominya";
$areanames{en}->{61752056} = "Cooroy";
$areanames{en}->{61752057} = "Crossdale";
$areanames{en}->{61752058} = "Esk";
$areanames{en}->{61752059} = "Gatton";
$areanames{en}->{61752060} = "Gunalda";
$areanames{en}->{61752061} = "Gympie";
$areanames{en}->{61752062} = "Harrisville";
$areanames{en}->{61752063} = "Imbil";
$areanames{en}->{61752064} = "Jimna";
$areanames{en}->{61752065} = "Kalbar";
$areanames{en}->{61752066} = "Kenilworth";
$areanames{en}->{61752067} = "Kia\ Ora";
$areanames{en}->{61752068} = "Kilcoy";
$areanames{en}->{61752069} = "Kilkivan";
$areanames{en}->{61752070} = "Laidley";
$areanames{en}->{61752071} = "Lowood";
$areanames{en}->{61752072} = "Maleny";
$areanames{en}->{61752073} = "Maroon";
$areanames{en}->{61752074} = "Moore";
$areanames{en}->{61752075} = "Nambour";
$areanames{en}->{61752076} = "Noosaville";
$areanames{en}->{61752077} = "Pomona";
$areanames{en}->{61752078} = "Rosevale";
$areanames{en}->{61752079} = "Rosewood";
$areanames{en}->{61752080} = "Thornton";
$areanames{en}->{61752081} = "Toogoolawah";
$areanames{en}->{61752082} = "Upper\ Widgee";
$areanames{en}->{61752083} = "Wolvi";
$areanames{en}->{61752084} = "Woodbine";
$areanames{en}->{61752085} = "Woolooga";
$areanames{en}->{61752086} = "Ballugan";
$areanames{en}->{61752087} = "Boonah";
$areanames{en}->{61752088} = "Caboolture";
$areanames{en}->{61752089} = "Caloundra";
$areanames{en}->{61752090} = "Coominya";
$areanames{en}->{61752091} = "Cooroy";
$areanames{en}->{61752092} = "Crossdale";
$areanames{en}->{61752093} = "Esk";
$areanames{en}->{61752094} = "Gatton";
$areanames{en}->{61752095} = "Gunalda";
$areanames{en}->{61752096} = "Gympie";
$areanames{en}->{61752097} = "Harrisville";
$areanames{en}->{61752098} = "Imbil";
$areanames{en}->{61752099} = "Jimna";
$areanames{en}->{61752100} = "Kalbar";
$areanames{en}->{61752101} = "Kenilworth";
$areanames{en}->{61752102} = "Kia\ Ora";
$areanames{en}->{61752103} = "Kilcoy";
$areanames{en}->{61752104} = "Kilkivan";
$areanames{en}->{61752105} = "Laidley";
$areanames{en}->{61752106} = "Lowood";
$areanames{en}->{61752107} = "Maleny";
$areanames{en}->{61752108} = "Maroon";
$areanames{en}->{61752109} = "Moore";
$areanames{en}->{61752110} = "Nambour";
$areanames{en}->{61752111} = "Noosaville";
$areanames{en}->{61752112} = "Pomona";
$areanames{en}->{61752113} = "Rosevale";
$areanames{en}->{61752114} = "Rosewood";
$areanames{en}->{61752115} = "Thornton";
$areanames{en}->{61752116} = "Toogoolawah";
$areanames{en}->{61752117} = "Upper\ Widgee";
$areanames{en}->{61752118} = "Wolvi";
$areanames{en}->{61752119} = "Woodbine";
$areanames{en}->{6175212} = "Caloundra";
$areanames{en}->{61752120} = "Woolooga";
$areanames{en}->{61752121} = "Caboolture";
$areanames{en}->{61752122} = "Caboolture";
$areanames{en}->{61752123} = "Caboolture";
$areanames{en}->{61752130} = "Caloundra";
$areanames{en}->{61752131} = "Gympie";
$areanames{en}->{61752132} = "Gympie";
$areanames{en}->{61752133} = "Ballugan";
$areanames{en}->{61752134} = "Boonah";
$areanames{en}->{61752135} = "Caboolture";
$areanames{en}->{61752136} = "Caloundra";
$areanames{en}->{61752137} = "Coominya";
$areanames{en}->{61752138} = "Cooroy";
$areanames{en}->{61752139} = "Crossdale";
$areanames{en}->{61752140} = "Esk";
$areanames{en}->{61752141} = "Gatton";
$areanames{en}->{61752142} = "Gunalda";
$areanames{en}->{61752143} = "Gympie";
$areanames{en}->{61752144} = "Harrisville";
$areanames{en}->{61752145} = "Imbil";
$areanames{en}->{61752146} = "Jimna";
$areanames{en}->{61752147} = "Kalbar";
$areanames{en}->{61752148} = "Kenilworth";
$areanames{en}->{61752149} = "Kia\ Ora";
$areanames{en}->{61752150} = "Kilcoy";
$areanames{en}->{61752151} = "Kilkivan";
$areanames{en}->{61752152} = "Laidley";
$areanames{en}->{61752153} = "Lowood";
$areanames{en}->{61752154} = "Maleny";
$areanames{en}->{61752155} = "Maroon";
$areanames{en}->{61752156} = "Moore";
$areanames{en}->{61752157} = "Nambour";
$areanames{en}->{61752158} = "Noosaville";
$areanames{en}->{61752159} = "Pomona";
$areanames{en}->{61752160} = "Rosevale";
$areanames{en}->{61752161} = "Ballugan";
$areanames{en}->{61752162} = "Boonah";
$areanames{en}->{61752163} = "Caboolture";
$areanames{en}->{61752164} = "Caloundra";
$areanames{en}->{61752165} = "Coominya";
$areanames{en}->{61752166} = "Cooroy";
$areanames{en}->{61752167} = "Crossdale";
$areanames{en}->{61752168} = "Esk";
$areanames{en}->{61752169} = "Gatton";
$areanames{en}->{61752170} = "Gunalda";
$areanames{en}->{61752171} = "Gympie";
$areanames{en}->{61752172} = "Harrisville";
$areanames{en}->{61752173} = "Imbil";
$areanames{en}->{61752174} = "Jimna";
$areanames{en}->{61752175} = "Kalbar";
$areanames{en}->{61752176} = "Kenilworth";
$areanames{en}->{61752177} = "Kia\ Ora";
$areanames{en}->{61752178} = "Kilcoy";
$areanames{en}->{61752179} = "Kilkivan";
$areanames{en}->{61752180} = "Laidley";
$areanames{en}->{61752181} = "Lowood";
$areanames{en}->{61752182} = "Maleny";
$areanames{en}->{61752183} = "Maroon";
$areanames{en}->{61752184} = "Moore";
$areanames{en}->{61752185} = "Nambour";
$areanames{en}->{61752186} = "Noosaville";
$areanames{en}->{61752187} = "Pomona";
$areanames{en}->{61752188} = "Rosevale";
$areanames{en}->{61752189} = "Rosewood";
$areanames{en}->{61752190} = "Thornton";
$areanames{en}->{61752191} = "Toogoolawah";
$areanames{en}->{61752192} = "Upper\ Widgee";
$areanames{en}->{61752193} = "Wolvi";
$areanames{en}->{61752194} = "Woodbine";
$areanames{en}->{61752195} = "Woolooga";
$areanames{en}->{61752196} = "Caboolture";
$areanames{en}->{61752197} = "Caboolture";
$areanames{en}->{61752198} = "Caboolture";
$areanames{en}->{61752199} = "Caboolture";
$areanames{en}->{61752200} = "Caboolture";
$areanames{en}->{61752201} = "Rosewood";
$areanames{en}->{61752202} = "Thornton";
$areanames{en}->{61752203} = "Toogoolawah";
$areanames{en}->{61752204} = "Upper\ Widgee";
$areanames{en}->{61752205} = "Wolvi";
$areanames{en}->{61752206} = "Woodbine";
$areanames{en}->{61752207} = "Woolooga";
$areanames{en}->{61752208} = "Ballugan";
$areanames{en}->{61752209} = "Boonah";
$areanames{en}->{61752210} = "Caboolture";
$areanames{en}->{61752211} = "Caloundra";
$areanames{en}->{61752212} = "Coominya";
$areanames{en}->{61752213} = "Cooroy";
$areanames{en}->{61752214} = "Crossdale";
$areanames{en}->{61752215} = "Esk";
$areanames{en}->{61752216} = "Gatton";
$areanames{en}->{61752217} = "Gunalda";
$areanames{en}->{61752218} = "Gympie";
$areanames{en}->{61752219} = "Harrisville";
$areanames{en}->{61752220} = "Imbil";
$areanames{en}->{61752221} = "Jimna";
$areanames{en}->{61752222} = "Kalbar";
$areanames{en}->{61752223} = "Kenilworth";
$areanames{en}->{61752224} = "Kia\ Ora";
$areanames{en}->{61752225} = "Kilcoy";
$areanames{en}->{61752226} = "Kilkivan";
$areanames{en}->{61752227} = "Laidley";
$areanames{en}->{61752228} = "Lowood";
$areanames{en}->{61752229} = "Maleny";
$areanames{en}->{61752230} = "Maroon";
$areanames{en}->{61752231} = "Moore";
$areanames{en}->{61752232} = "Nambour";
$areanames{en}->{61752233} = "Noosaville";
$areanames{en}->{61752234} = "Pomona";
$areanames{en}->{61752235} = "Rosevale";
$areanames{en}->{61752236} = "Rosewood";
$areanames{en}->{61752237} = "Thornton";
$areanames{en}->{61752238} = "Toogoolawah";
$areanames{en}->{61752239} = "Upper\ Widgee";
$areanames{en}->{61752240} = "Wolvi";
$areanames{en}->{61752241} = "Woodbine";
$areanames{en}->{61752242} = "Woolooga";
$areanames{en}->{61752243} = "Ballugan";
$areanames{en}->{61752244} = "Boonah";
$areanames{en}->{61752245} = "Caboolture";
$areanames{en}->{61752246} = "Caloundra";
$areanames{en}->{61752247} = "Coominya";
$areanames{en}->{61752248} = "Cooroy";
$areanames{en}->{61752249} = "Crossdale";
$areanames{en}->{61752250} = "Esk";
$areanames{en}->{61752251} = "Gatton";
$areanames{en}->{61752252} = "Gunalda";
$areanames{en}->{61752253} = "Gympie";
$areanames{en}->{61752254} = "Harrisville";
$areanames{en}->{61752255} = "Imbil";
$areanames{en}->{61752256} = "Jimna";
$areanames{en}->{61752257} = "Kalbar";
$areanames{en}->{61752258} = "Kenilworth";
$areanames{en}->{61752259} = "Kia\ Ora";
$areanames{en}->{61752260} = "Kilcoy";
$areanames{en}->{61752261} = "Kilkivan";
$areanames{en}->{61752262} = "Laidley";
$areanames{en}->{61752263} = "Lowood";
$areanames{en}->{61752264} = "Maleny";
$areanames{en}->{61752265} = "Maroon";
$areanames{en}->{61752266} = "Moore";
$areanames{en}->{61752267} = "Nambour";
$areanames{en}->{61752268} = "Noosaville";
$areanames{en}->{61752269} = "Pomona";
$areanames{en}->{61752270} = "Rosevale";
$areanames{en}->{61752271} = "Rosewood";
$areanames{en}->{61752272} = "Thornton";
$areanames{en}->{61752273} = "Toogoolawah";
$areanames{en}->{61752274} = "Upper\ Widgee";
$areanames{en}->{61752275} = "Wolvi";
$areanames{en}->{61752276} = "Woodbine";
$areanames{en}->{61752277} = "Woolooga";
$areanames{en}->{61752278} = "Ballugan";
$areanames{en}->{61752279} = "Boonah";
$areanames{en}->{61752280} = "Caboolture";
$areanames{en}->{61752281} = "Caloundra";
$areanames{en}->{61752282} = "Coominya";
$areanames{en}->{61752283} = "Cooroy";
$areanames{en}->{61752284} = "Crossdale";
$areanames{en}->{61752285} = "Esk";
$areanames{en}->{61752286} = "Gatton";
$areanames{en}->{61752287} = "Gunalda";
$areanames{en}->{61752288} = "Gympie";
$areanames{en}->{61752289} = "Harrisville";
$areanames{en}->{61752290} = "Imbil";
$areanames{en}->{61752291} = "Jimna";
$areanames{en}->{61752292} = "Kalbar";
$areanames{en}->{61752293} = "Kenilworth";
$areanames{en}->{61752294} = "Kia\ Ora";
$areanames{en}->{61752295} = "Kilcoy";
$areanames{en}->{61752296} = "Kilkivan";
$areanames{en}->{61752297} = "Laidley";
$areanames{en}->{61752298} = "Lowood";
$areanames{en}->{61752299} = "Maleny";
$areanames{en}->{61752300} = "Maroon";
$areanames{en}->{61752301} = "Moore";
$areanames{en}->{61752302} = "Nambour";
$areanames{en}->{61752303} = "Noosaville";
$areanames{en}->{61752304} = "Pomona";
$areanames{en}->{61752305} = "Rosevale";
$areanames{en}->{61752306} = "Rosewood";
$areanames{en}->{61752307} = "Thornton";
$areanames{en}->{61752308} = "Toogoolawah";
$areanames{en}->{61752309} = "Upper\ Widgee";
$areanames{en}->{61752310} = "Wolvi";
$areanames{en}->{61752311} = "Woodbine";
$areanames{en}->{61752312} = "Woolooga";
$areanames{en}->{61752924} = "Caboolture";
$areanames{en}->{61752925} = "Noosaville";
$areanames{en}->{61752926} = "Noosaville";
$areanames{en}->{61752927} = "Noosaville";
$areanames{en}->{61752928} = "Noosaville";
$areanames{en}->{61752929} = "Noosaville";
$areanames{en}->{61752930} = "Caboolture";
$areanames{en}->{61752931} = "Caboolture";
$areanames{en}->{61752932} = "Caboolture";
$areanames{en}->{61752933} = "Caloundra";
$areanames{en}->{61752934} = "Caloundra";
$areanames{en}->{61752935} = "Caloundra";
$areanames{en}->{61752936} = "Caloundra";
$areanames{en}->{61752937} = "Nambour";
$areanames{en}->{61752938} = "Nambour";
$areanames{en}->{61752939} = "Nambour";
$areanames{en}->{6175294} = "Nambour";
$areanames{en}->{61752947} = "Caboolture";
$areanames{en}->{61752948} = "Caboolture";
$areanames{en}->{61752949} = "Caboolture";
$areanames{en}->{61753000} = "Rosevale";
$areanames{en}->{61753001} = "Rosewood";
$areanames{en}->{61753002} = "Thornton";
$areanames{en}->{61753003} = "Woodbine";
$areanames{en}->{61753004} = "Ballugan";
$areanames{en}->{61753005} = "Gunalda";
$areanames{en}->{61753006} = "Gympie";
$areanames{en}->{61753007} = "Imbil";
$areanames{en}->{61753008} = "Kia\ Ora";
$areanames{en}->{61753009} = "Kilkivan";
$areanames{en}->{61753010} = "Pomona";
$areanames{en}->{61753011} = "Upper\ Widgee";
$areanames{en}->{61753012} = "Wolvi";
$areanames{en}->{61753013} = "Woolooga";
$areanames{en}->{61753014} = "Cooroy";
$areanames{en}->{61753015} = "Kenilworth";
$areanames{en}->{61753016} = "Nambour";
$areanames{en}->{61753017} = "Noosaville";
$areanames{en}->{61753018} = "Caboolture";
$areanames{en}->{61753019} = "Caloundra";
$areanames{en}->{61753020} = "Esk";
$areanames{en}->{61753021} = "Boonah";
$areanames{en}->{61753022} = "Gatton";
$areanames{en}->{61753023} = "Woodbine";
$areanames{en}->{61753024} = "Cooroy";
$areanames{en}->{61753025} = "Kenilworth";
$areanames{en}->{61753026} = "Nambour";
$areanames{en}->{61753027} = "Noosaville";
$areanames{en}->{61753028} = "Kilcoy";
$areanames{en}->{61753029} = "Maleny";
$areanames{en}->{61753030} = "Jimna";
$areanames{en}->{61753031} = "Kilcoy";
$areanames{en}->{61753032} = "Maleny";
$areanames{en}->{61753033} = "Woodford";
$areanames{en}->{61753034} = "Coominya";
$areanames{en}->{61753035} = "Crossdale";
$areanames{en}->{61753036} = "Esk";
$areanames{en}->{61753037} = "Lowood";
$areanames{en}->{61753038} = "Moore";
$areanames{en}->{61753039} = "Toogoolawah";
$areanames{en}->{61753040} = "Boonah";
$areanames{en}->{61753041} = "Gatton";
$areanames{en}->{61753042} = "Harrisville";
$areanames{en}->{61753043} = "Kalbar";
$areanames{en}->{61753044} = "Laidley";
$areanames{en}->{61753045} = "Maroon";
$areanames{en}->{61753046} = "Rosevale";
$areanames{en}->{61753047} = "Rosewood";
$areanames{en}->{61753048} = "Thornton";
$areanames{en}->{61753049} = "Woodbine";
$areanames{en}->{61753050} = "Ballugan";
$areanames{en}->{61753051} = "Gunalda";
$areanames{en}->{61753052} = "Imbil";
$areanames{en}->{61753053} = "Kia\ Ora";
$areanames{en}->{61753054} = "Kilkivan";
$areanames{en}->{61753055} = "Pomona";
$areanames{en}->{61753056} = "Upper\ Widgee";
$areanames{en}->{61753057} = "Wolvi";
$areanames{en}->{61753058} = "Woolooga";
$areanames{en}->{617530590} = "Cooroy";
$areanames{en}->{61753060} = "Kenilworth";
$areanames{en}->{61753061} = "Caloundra";
$areanames{en}->{61753062} = "Jimna";
$areanames{en}->{61753063} = "Kilcoy";
$areanames{en}->{61753064} = "Maleny";
$areanames{en}->{61753065} = "Woodford";
$areanames{en}->{61753066} = "Coominya";
$areanames{en}->{61753067} = "Crossdale";
$areanames{en}->{61753068} = "Esk";
$areanames{en}->{61753069} = "Lowood";
$areanames{en}->{61753070} = "Moore";
$areanames{en}->{61753071} = "Toogoolawah";
$areanames{en}->{61753072} = "Boonah";
$areanames{en}->{61753073} = "Gatton";
$areanames{en}->{61753074} = "Harrisville";
$areanames{en}->{61753075} = "Kalbar";
$areanames{en}->{61753076} = "Laidley";
$areanames{en}->{61753077} = "Maroon";
$areanames{en}->{61753078} = "Rosevale";
$areanames{en}->{61753079} = "Rosewood";
$areanames{en}->{61753080} = "Thornton";
$areanames{en}->{61753081} = "Woodbine";
$areanames{en}->{61753082} = "Ballugan";
$areanames{en}->{61753083} = "Gunalda";
$areanames{en}->{61753084} = "Imbil";
$areanames{en}->{61753085} = "Kia\ Ora";
$areanames{en}->{61753086} = "Kilkivan";
$areanames{en}->{61753087} = "Pomona";
$areanames{en}->{61753088} = "Upper\ Widgee";
$areanames{en}->{61753089} = "Wolvi";
$areanames{en}->{61753090} = "Woolooga";
$areanames{en}->{61753091} = "Cooroy";
$areanames{en}->{61753092} = "Kenilworth";
$areanames{en}->{61753093} = "Noosaville";
$areanames{en}->{61753094} = "Caboolture";
$areanames{en}->{61753095} = "Caloundra";
$areanames{en}->{61753096} = "Nambour";
$areanames{en}->{61753097} = "Caboolture";
$areanames{en}->{61753098} = "Caloundra";
$areanames{en}->{61753099} = "Jimna";
$areanames{en}->{61753100} = "Kilcoy";
$areanames{en}->{61753101} = "Maleny";
$areanames{en}->{61753102} = "Woodford";
$areanames{en}->{61753103} = "Coominya";
$areanames{en}->{61753104} = "Crossdale";
$areanames{en}->{61753105} = "Esk";
$areanames{en}->{61753106} = "Lowood";
$areanames{en}->{61753107} = "Moore";
$areanames{en}->{61753108} = "Toogoolawah";
$areanames{en}->{61753109} = "Boonah";
$areanames{en}->{61753110} = "Gatton";
$areanames{en}->{61753111} = "Harrisville";
$areanames{en}->{61753112} = "Kalbar";
$areanames{en}->{61753113} = "Laidley";
$areanames{en}->{61753114} = "Maroon";
$areanames{en}->{61753115} = "Rosevale";
$areanames{en}->{61753116} = "Rosewood";
$areanames{en}->{61753117} = "Thornton";
$areanames{en}->{61753118} = "Woodbine";
$areanames{en}->{61753119} = "Ballugan";
$areanames{en}->{61753120} = "Gunalda";
$areanames{en}->{61753121} = "Gympie";
$areanames{en}->{61753122} = "Imbil";
$areanames{en}->{61753123} = "Kia\ Ora";
$areanames{en}->{61753124} = "Kilkivan";
$areanames{en}->{61753125} = "Pomona";
$areanames{en}->{61753126} = "Upper\ Widgee";
$areanames{en}->{61753127} = "Wolvi";
$areanames{en}->{61753128} = "Woolooga";
$areanames{en}->{61753129} = "Cooroy";
$areanames{en}->{6175313} = "Nambour";
$areanames{en}->{61753130} = "Kenilworth";
$areanames{en}->{61753132} = "Noosaville";
$areanames{en}->{61753139} = "Woodford";
$areanames{en}->{61753140} = "Coominya";
$areanames{en}->{61753141} = "Caloundra";
$areanames{en}->{61753142} = "Caloundra";
$areanames{en}->{61753143} = "Caloundra";
$areanames{en}->{61753144} = "Lowood";
$areanames{en}->{61753145} = "Toogoolawah";
$areanames{en}->{61753146} = "Kalbar";
$areanames{en}->{61753147} = "Laidley";
$areanames{en}->{61753148} = "Rosewood";
$areanames{en}->{61753149} = "Thornton";
$areanames{en}->{61753150} = "Gympie";
$areanames{en}->{61753151} = "Imbil";
$areanames{en}->{61753152} = "Kilkivan";
$areanames{en}->{61753153} = "Pomona";
$areanames{en}->{61753154} = "Gympie";
$areanames{en}->{61753155} = "Nambour";
$areanames{en}->{61753156} = "Cooroy";
$areanames{en}->{61753157} = "Kenilworth";
$areanames{en}->{61753158} = "Noosaville";
$areanames{en}->{61753159} = "Lowood";
$areanames{en}->{6175316} = "Caboolture";
$areanames{en}->{61753170} = "Coominya";
$areanames{en}->{61753171} = "Esk";
$areanames{en}->{61753172} = "Crossdale";
$areanames{en}->{61753173} = "Moore";
$areanames{en}->{61753174} = "Toogoolawah";
$areanames{en}->{61753175} = "Maroon";
$areanames{en}->{61753176} = "Gatton";
$areanames{en}->{61753177} = "Kalbar";
$areanames{en}->{61753178} = "Laidley";
$areanames{en}->{61753179} = "Rosevale";
$areanames{en}->{61753180} = "Kilkivan";
$areanames{en}->{61753181} = "Pomona";
$areanames{en}->{61753182} = "Woolooga";
$areanames{en}->{61753183} = "Wolvi";
$areanames{en}->{61753184} = "Upper\ Widgee";
$areanames{en}->{61753185} = "Ballugan";
$areanames{en}->{61753186} = "Laidley";
$areanames{en}->{61753187} = "Caloundra";
$areanames{en}->{61753188} = "Maleny";
$areanames{en}->{61753189} = "Nambour";
$areanames{en}->{61753190} = "Nambour";
$areanames{en}->{61753191} = "Cooroy";
$areanames{en}->{61753192} = "Caboolture";
$areanames{en}->{61753193} = "Noosaville";
$areanames{en}->{61753194} = "Nambour";
$areanames{en}->{61753195} = "Nambour";
$areanames{en}->{61753196} = "Caloundra";
$areanames{en}->{61753197} = "Caloundra";
$areanames{en}->{61753198} = "Caboolture";
$areanames{en}->{61753199} = "Caboolture";
$areanames{en}->{61753200} = "Rosewood";
$areanames{en}->{61753201} = "Rosewood";
$areanames{en}->{61753202} = "Harrisville";
$areanames{en}->{61753203} = "Harrisville";
$areanames{en}->{61753204} = "Moore";
$areanames{en}->{61753205} = "Toogoolawah";
$areanames{en}->{61753206} = "Boonah";
$areanames{en}->{61753207} = "Gatton";
$areanames{en}->{61753208} = "Harrisville";
$areanames{en}->{61753209} = "Kalbar";
$areanames{en}->{61753210} = "Rosewood";
$areanames{en}->{61753211} = "Harrisville";
$areanames{en}->{61753212} = "Gunalda";
$areanames{en}->{61753213} = "Gympie";
$areanames{en}->{61753214} = "Imbil";
$areanames{en}->{61753215} = "Kia\ Ora";
$areanames{en}->{61753216} = "Rosewood";
$areanames{en}->{61753217} = "Harrisville";
$areanames{en}->{61753218} = "Rosewood";
$areanames{en}->{61753219} = "Boonah";
$areanames{en}->{61753220} = "Rosewood";
$areanames{en}->{61753221} = "Dayboro";
$areanames{en}->{61753222} = "Lowood";
$areanames{en}->{61753223} = "Rosewood";
$areanames{en}->{61753224} = "Caboolture";
$areanames{en}->{61753225} = "Caloundra";
$areanames{en}->{61753226} = "Laidley";
$areanames{en}->{61753227} = "Maroon";
$areanames{en}->{61753228} = "Rosewood";
$areanames{en}->{61753229} = "Rosevale";
$areanames{en}->{61753230} = "Maleny";
$areanames{en}->{61753231} = "Rosewood";
$areanames{en}->{61753232} = "Woodbine";
$areanames{en}->{61753233} = "Thornton";
$areanames{en}->{61753234} = "Caloundra";
$areanames{en}->{61753235} = "Caloundra";
$areanames{en}->{61753236} = "Caloundra";
$areanames{en}->{61753237} = "Rosewood";
$areanames{en}->{61753238} = "Thornton";
$areanames{en}->{61753239} = "Woodbine";
$areanames{en}->{6175324} = "Noosaville";
$areanames{en}->{6175325} = "Caloundra";
$areanames{en}->{6175326} = "Nambour";
$areanames{en}->{61753270} = "Caboolture";
$areanames{en}->{61753271} = "Caloundra";
$areanames{en}->{61753272} = "Caboolture";
$areanames{en}->{61753273} = "Caloundra";
$areanames{en}->{61753274} = "Maleny";
$areanames{en}->{61753275} = "Woodford";
$areanames{en}->{61753276} = "Coominya";
$areanames{en}->{61753277} = "Crossdale";
$areanames{en}->{61753278} = "Esk";
$areanames{en}->{61753279} = "Lowood";
$areanames{en}->{61753280} = "Ballugan";
$areanames{en}->{61753281} = "Caboolture";
$areanames{en}->{61753282} = "Gympie";
$areanames{en}->{61753283} = "Caloundra";
$areanames{en}->{61753284} = "Kia\ Ora";
$areanames{en}->{61753285} = "Kilkivan";
$areanames{en}->{61753286} = "Pomona";
$areanames{en}->{61753287} = "Jimna";
$areanames{en}->{61753288} = "Wolvi";
$areanames{en}->{61753289} = "Kilcoy";
$areanames{en}->{61753290} = "Cooroy";
$areanames{en}->{61753291} = "Kenilworth";
$areanames{en}->{61753292} = "Nambour";
$areanames{en}->{61753293} = "Noosaville";
$areanames{en}->{61753294} = "Caloundra";
$areanames{en}->{61753295} = "Gympie";
$areanames{en}->{61753296} = "Noosaville";
$areanames{en}->{61753297} = "Nambour";
$areanames{en}->{61753298} = "Noosaville";
$areanames{en}->{61753299} = "Noosaville";
$areanames{en}->{6175330} = "Caboolture";
$areanames{en}->{61753310} = "Maleny";
$areanames{en}->{61753311} = "Lowood";
$areanames{en}->{61753312} = "Laidley";
$areanames{en}->{61753313} = "Gympie";
$areanames{en}->{61753314} = "Cooroy";
$areanames{en}->{61753315} = "Cooroy";
$areanames{en}->{61753316} = "Coominya";
$areanames{en}->{61753317} = "Coominya";
$areanames{en}->{61753318} = "Kalbar";
$areanames{en}->{61753319} = "Kalbar";
$areanames{en}->{61753320} = "Maleny";
$areanames{en}->{61753321} = "Maleny";
$areanames{en}->{61753322} = "Cooroy";
$areanames{en}->{61753323} = "Cooroy";
$areanames{en}->{61753324} = "Kenilworth";
$areanames{en}->{61753325} = "Kenilworth";
$areanames{en}->{61753326} = "Thornton";
$areanames{en}->{61753327} = "Thornton";
$areanames{en}->{61753328} = "Rosevale";
$areanames{en}->{61753329} = "Rosevale";
$areanames{en}->{61753330} = "Maroon";
$areanames{en}->{61753331} = "Maroon";
$areanames{en}->{61753332} = "Laidley";
$areanames{en}->{61753333} = "Laidley";
$areanames{en}->{61753334} = "Gatton";
$areanames{en}->{61753335} = "Gatton";
$areanames{en}->{61753336} = "Boonah";
$areanames{en}->{61753337} = "Boonah";
$areanames{en}->{61753338} = "Lowood";
$areanames{en}->{61753339} = "Lowood";
$areanames{en}->{61753340} = "Gympie";
$areanames{en}->{61753341} = "Noosaville";
$areanames{en}->{61753342} = "Woolooga";
$areanames{en}->{61753343} = "Woolooga";
$areanames{en}->{61753344} = "Gympie";
$areanames{en}->{61753345} = "Nambour";
$areanames{en}->{61753346} = "Caloundra";
$areanames{en}->{61753347} = "Caloundra";
$areanames{en}->{61753348} = "Caloundra";
$areanames{en}->{61753349} = "Caloundra";
$areanames{en}->{61753350} = "Noosaville";
$areanames{en}->{61753351} = "Nambour";
$areanames{en}->{61753352} = "Harrisville";
$areanames{en}->{61753353} = "Harrisville";
$areanames{en}->{61753354} = "Harrisville";
$areanames{en}->{61753355} = "Rosewood";
$areanames{en}->{61753356} = "Rosewood";
$areanames{en}->{61753357} = "Rosewood";
$areanames{en}->{61753358} = "Noosaville";
$areanames{en}->{61753359} = "Noosaville";
$areanames{en}->{6175336} = "Nambour";
$areanames{en}->{6175337} = "Caloundra";
$areanames{en}->{6175338} = "Nambour";
$areanames{en}->{6175339} = "Caboolture";
$areanames{en}->{61753400} = "Ballugan";
$areanames{en}->{61753401} = "Ballugan";
$areanames{en}->{61753402} = "Upper\ Widgee";
$areanames{en}->{61753403} = "Upper\ Widgee";
$areanames{en}->{61753404} = "Crossdale";
$areanames{en}->{61753405} = "Crossdale";
$areanames{en}->{61753406} = "Esk";
$areanames{en}->{61753407} = "Esk";
$areanames{en}->{61753408} = "Moore";
$areanames{en}->{61753409} = "Moore";
$areanames{en}->{61753410} = "Kenilworth";
$areanames{en}->{61753411} = "Wolvi";
$areanames{en}->{61753412} = "Wolvi";
$areanames{en}->{61753413} = "Noosaville";
$areanames{en}->{61753414} = "Noosaville";
$areanames{en}->{61753415} = "Noosaville";
$areanames{en}->{617534169} = "Noosaville";
$areanames{en}->{61753417} = "Jimna";
$areanames{en}->{61753418} = "Caloundra";
$areanames{en}->{61753419} = "Caloundra";
$areanames{en}->{6175342} = "Caboolture";
$areanames{en}->{61753430} = "Noosaville";
$areanames{en}->{61753431} = "Noosaville";
$areanames{en}->{61753432} = "Noosaville";
$areanames{en}->{61753433} = "Caloundra";
$areanames{en}->{61753434} = "Gympie";
$areanames{en}->{61753435} = "Caboolture";
$areanames{en}->{61753436} = "Caloundra";
$areanames{en}->{61753437} = "Nambour";
$areanames{en}->{61753438} = "Nambour";
$areanames{en}->{61753439} = "Caloundra";
$areanames{en}->{61753440} = "Maleny";
$areanames{en}->{61753441} = "Crossdale";
$areanames{en}->{61753442} = "Moore";
$areanames{en}->{61753443} = "Gunalda";
$areanames{en}->{61753444} = "Wolvi";
$areanames{en}->{61753445} = "Kia\ Ora";
$areanames{en}->{61753446} = "Ballugan";
$areanames{en}->{61753447} = "Maroon";
$areanames{en}->{61753448} = "Harrisville";
$areanames{en}->{61753449} = "Kilkivan";
$areanames{en}->{61753450} = "Woodford";
$areanames{en}->{61753451} = "Upper\ Widgee";
$areanames{en}->{61753452} = "Woolooga";
$areanames{en}->{61753453} = "Rosevale";
$areanames{en}->{61753454} = "Jimna";
$areanames{en}->{61753455} = "Nambour";
$areanames{en}->{61753456} = "Caloundra";
$areanames{en}->{61753457} = "Noosaville";
$areanames{en}->{61753458} = "Nambour";
$areanames{en}->{61753459} = "Nambour";
$areanames{en}->{61753460} = "Gympie";
$areanames{en}->{61753461} = "Gatton";
$areanames{en}->{61753462} = "Moore";
$areanames{en}->{61753463} = "Imbil";
$areanames{en}->{61753464} = "Caloundra";
$areanames{en}->{61753465} = "Harrisville";
$areanames{en}->{61753466} = "Gatton";
$areanames{en}->{61753467} = "Kalbar";
$areanames{en}->{61753468} = "Esk";
$areanames{en}->{61753469} = "Caloundra";
$areanames{en}->{61753470} = "Caloundra";
$areanames{en}->{61753471} = "Upper\ Widgee";
$areanames{en}->{61753472} = "Caboolture";
$areanames{en}->{61753473} = "Woodbine";
$areanames{en}->{61753474} = "Woolooga";
$areanames{en}->{61753475} = "Maleny";
$areanames{en}->{61753476} = "Kilcoy";
$areanames{en}->{61753477} = "Kilkivan";
$areanames{en}->{61753478} = "Coominya";
$areanames{en}->{61753479} = "Caboolture";
$areanames{en}->{61753480} = "Caboolture";
$areanames{en}->{61753481} = "Crossdale";
$areanames{en}->{61753482} = "Toogoolawah";
$areanames{en}->{61753483} = "Jimna";
$areanames{en}->{61753484} = "Boonah";
$areanames{en}->{61753485} = "Ballugan";
$areanames{en}->{61753486} = "Pomona";
$areanames{en}->{61753487} = "Thornton";
$areanames{en}->{61753488} = "Wolvi";
$areanames{en}->{61753489} = "Nambour";
$areanames{en}->{61753490} = "Nambour";
$areanames{en}->{61753491} = "Rosevale";
$areanames{en}->{61753492} = "Gympie";
$areanames{en}->{61753493} = "Kia\ Ora";
$areanames{en}->{61753494} = "Maroon";
$areanames{en}->{61753495} = "Rosewood";
$areanames{en}->{61753496} = "Gunalda";
$areanames{en}->{61753497} = "Woodford";
$areanames{en}->{61753498} = "Lowood";
$areanames{en}->{61753499} = "Woodford";
$areanames{en}->{61753500} = "Woodford";
$areanames{en}->{61753501} = "Laidley";
$areanames{en}->{61753502} = "Noosaville";
$areanames{en}->{61753503} = "Kia\ Ora";
$areanames{en}->{61753504} = "Moore";
$areanames{en}->{61753505} = "Imbil";
$areanames{en}->{61753506} = "Harrisville";
$areanames{en}->{61753507} = "Upper\ Widgee";
$areanames{en}->{61753508} = "Woodbine";
$areanames{en}->{61753509} = "Caloundra";
$areanames{en}->{61753510} = "Nambour";
$areanames{en}->{61753511} = "Noosaville";
$areanames{en}->{61753512} = "Noosaville";
$areanames{en}->{61753513} = "Esk";
$areanames{en}->{61753514} = "Esk";
$areanames{en}->{61753515} = "Gatton";
$areanames{en}->{61753516} = "Gatton";
$areanames{en}->{61753517} = "Toogoolawah";
$areanames{en}->{61753518} = "Toogoolawah";
$areanames{en}->{61753519} = "Woodbine";
$areanames{en}->{61753520} = "Woodbine";
$areanames{en}->{61753521} = "Jimna";
$areanames{en}->{61753522} = "Jimna";
$areanames{en}->{61753523} = "Nambour";
$areanames{en}->{61753524} = "Gympie";
$areanames{en}->{61753525} = "Gympie";
$areanames{en}->{61753526} = "Gympie";
$areanames{en}->{61753527} = "Nambour";
$areanames{en}->{61753528} = "Nambour";
$areanames{en}->{61753529} = "Nambour";
$areanames{en}->{61753530} = "Caloundra";
$areanames{en}->{61753531} = "Kilcoy";
$areanames{en}->{61753532} = "Coominya";
$areanames{en}->{61753533} = "Crossdale";
$areanames{en}->{61753534} = "Noosaville";
$areanames{en}->{61753535} = "Nambour";
$areanames{en}->{61753536} = "Nambour";
$areanames{en}->{61753537} = "Noosaville";
$areanames{en}->{61753538} = "Gympie";
$areanames{en}->{61753539} = "Caboolture";
$areanames{en}->{61753540} = "Noosaville";
$areanames{en}->{61753541} = "Noosaville";
$areanames{en}->{61753542} = "Noosaville";
$areanames{en}->{61753543} = "Toogoolawah";
$areanames{en}->{61753544} = "Gympie";
$areanames{en}->{61753545} = "Rosewood";
$areanames{en}->{61753546} = "Nambour";
$areanames{en}->{61753547} = "Lowood";
$areanames{en}->{61753548} = "Woodford";
$areanames{en}->{61753549} = "Woodford";
$areanames{en}->{61753550} = "Nambour";
$areanames{en}->{61753551} = "Caloundra";
$areanames{en}->{61753552} = "Gatton";
$areanames{en}->{61753553} = "Kalbar";
$areanames{en}->{61753554} = "Esk";
$areanames{en}->{61753555} = "Cooroy";
$areanames{en}->{61753556} = "Noosaville";
$areanames{en}->{61753557} = "Caboolture";
$areanames{en}->{61753558} = "Woolooga";
$areanames{en}->{61753559} = "Woodford";
$areanames{en}->{61753560} = "Woodford";
$areanames{en}->{61753561} = "Maleny";
$areanames{en}->{61753562} = "Kilkivan";
$areanames{en}->{61753563} = "Jimna";
$areanames{en}->{61753564} = "Boonah";
$areanames{en}->{61753565} = "Ballugan";
$areanames{en}->{61753566} = "Pomona";
$areanames{en}->{61753567} = "Thornton";
$areanames{en}->{61753568} = "Wolvi";
$areanames{en}->{61753569} = "Woodford";
$areanames{en}->{61753570} = "Woodford";
$areanames{en}->{61753571} = "Rosevale";
$areanames{en}->{61753572} = "Kenilworth";
$areanames{en}->{61753573} = "Kia\ Ora";
$areanames{en}->{61753574} = "Maroon";
$areanames{en}->{61753575} = "Cooroy";
$areanames{en}->{61753576} = "Noosaville";
$areanames{en}->{61753577} = "Kenilworth";
$areanames{en}->{61753578} = "Nambour";
$areanames{en}->{61753579} = "Caloundra";
$areanames{en}->{61753580} = "Caloundra";
$areanames{en}->{61753581} = "Gunalda";
$areanames{en}->{61753582} = "Laidley";
$areanames{en}->{61753583} = "Nambour";
$areanames{en}->{61753584} = "Nambour";
$areanames{en}->{61753585} = "Moore";
$areanames{en}->{61753586} = "Imbil";
$areanames{en}->{61753587} = "Harrisville";
$areanames{en}->{61753588} = "Upper\ Widgee";
$areanames{en}->{61753589} = "Woodford";
$areanames{en}->{61753590} = "Caloundra";
$areanames{en}->{61753591} = "Woodbine";
$areanames{en}->{61753592} = "Coominya";
$areanames{en}->{61753593} = "Crossdale";
$areanames{en}->{61753594} = "Toogoolawah";
$areanames{en}->{61753595} = "Rosewood";
$areanames{en}->{61753596} = "Lowood";
$areanames{en}->{61753597} = "Caboolture";
$areanames{en}->{61753598} = "Kalbar";
$areanames{en}->{61753599} = "Caboolture";
$areanames{en}->{61753600} = "Caboolture";
$areanames{en}->{61753601} = "Caboolture";
$areanames{en}->{61753602} = "Woolooga";
$areanames{en}->{61753603} = "Kilkivan";
$areanames{en}->{61753604} = "Boonah";
$areanames{en}->{61753605} = "Ballugan";
$areanames{en}->{61753606} = "Pomona";
$areanames{en}->{61753607} = "Thornton";
$areanames{en}->{61753608} = "Wolvi";
$areanames{en}->{61753609} = "Caboolture";
$areanames{en}->{6175361} = "Rosewood";
$areanames{en}->{6175362} = "Rosewood";
$areanames{en}->{61753630} = "Nambour";
$areanames{en}->{61753631} = "Rosevale";
$areanames{en}->{61753632} = "Kenilworth";
$areanames{en}->{61753633} = "Kia\ Ora";
$areanames{en}->{61753634} = "Maroon";
$areanames{en}->{61753635} = "Gunalda";
$areanames{en}->{61753636} = "Toogoolawah";
$areanames{en}->{61753637} = "Toogoolawah";
$areanames{en}->{61753638} = "Toogoolawah";
$areanames{en}->{61753639} = "Nambour";
$areanames{en}->{61753640} = "Rosewood";
$areanames{en}->{61753641} = "Rosewood";
$areanames{en}->{61753701} = "Nambour";
$areanames{en}->{61753702} = "Nambour";
$areanames{en}->{61753703} = "Nambour";
$areanames{en}->{61753704} = "Nambour";
$areanames{en}->{61753705} = "Nambour";
$areanames{en}->{61753706} = "Nambour";
$areanames{en}->{61753707} = "Nambour";
$areanames{en}->{61753708} = "Nambour";
$areanames{en}->{61753709} = "Nambour";
$areanames{en}->{61753710} = "Noosaville";
$areanames{en}->{61753711} = "Pomona";
$areanames{en}->{61753712} = "Pomona";
$areanames{en}->{61753713} = "Kilkivan";
$areanames{en}->{61753714} = "Kilkivan";
$areanames{en}->{61753715} = "Kia\ Ora";
$areanames{en}->{61753716} = "Kia\ Ora";
$areanames{en}->{61753717} = "Imbil";
$areanames{en}->{61753718} = "Imbil";
$areanames{en}->{61753719} = "Gympie";
$areanames{en}->{61753720} = "Gympie";
$areanames{en}->{61753721} = "Gunalda";
$areanames{en}->{61753722} = "Gunalda";
$areanames{en}->{61753723} = "Woodford";
$areanames{en}->{61753724} = "Woodford";
$areanames{en}->{61753725} = "Kilcoy";
$areanames{en}->{61753726} = "Kilcoy";
$areanames{en}->{61753727} = "Noosaville";
$areanames{en}->{61753728} = "Noosaville";
$areanames{en}->{61753729} = "Noosaville";
$areanames{en}->{6175373} = "Nambour";
$areanames{en}->{61753738} = "Noosaville";
$areanames{en}->{61753739} = "Noosaville";
$areanames{en}->{6175374} = "Nambour";
$areanames{en}->{61753743} = "Caboolture";
$areanames{en}->{61753744} = "Caloundra";
$areanames{en}->{61753745} = "Caloundra";
$areanames{en}->{61753746} = "Caloundra";
$areanames{en}->{61753750} = "Noosaville";
$areanames{en}->{61753751} = "Gympie";
$areanames{en}->{61753752} = "Gympie";
$areanames{en}->{61753753} = "Laidley";
$areanames{en}->{61753754} = "Laidley";
$areanames{en}->{61753755} = "Caloundra";
$areanames{en}->{61753756} = "Caloundra";
$areanames{en}->{61753757} = "Caloundra";
$areanames{en}->{61753758} = "Boonah";
$areanames{en}->{61753759} = "Boonah";
$areanames{en}->{6175376} = "Nambour";
$areanames{en}->{61753770} = "Nambour";
$areanames{en}->{61753771} = "Noosaville";
$areanames{en}->{61753772} = "Noosaville";
$areanames{en}->{61753811} = "Nambour";
$areanames{en}->{6175390} = "Caloundra";
$areanames{en}->{61754000} = "Nambour";
$areanames{en}->{61754001} = "Nambour";
$areanames{en}->{61754002} = "Nambour";
$areanames{en}->{61754003} = "Ballugan";
$areanames{en}->{61754004} = "Boonah";
$areanames{en}->{61754005} = "Caboolture";
$areanames{en}->{61754006} = "Caloundra";
$areanames{en}->{61754007} = "Coominya";
$areanames{en}->{61754008} = "Cooroy";
$areanames{en}->{61754009} = "Crossdale";
$areanames{en}->{6175401} = "Kia\ Ora";
$areanames{en}->{61754010} = "Imbil";
$areanames{en}->{61754011} = "Imbil";
$areanames{en}->{61754012} = "Imbil";
$areanames{en}->{61754013} = "Imbil";
$areanames{en}->{61754020} = "Esk";
$areanames{en}->{61754021} = "Gatton";
$areanames{en}->{61754022} = "Gunalda";
$areanames{en}->{61754023} = "Gympie";
$areanames{en}->{61754024} = "Harrisville";
$areanames{en}->{61754025} = "Imbil";
$areanames{en}->{61754026} = "Jimna";
$areanames{en}->{61754027} = "Kalbar";
$areanames{en}->{61754028} = "Kenilworth";
$areanames{en}->{61754029} = "Kia\ Ora";
$areanames{en}->{61754030} = "Kilcoy";
$areanames{en}->{61754031} = "Kilkivan";
$areanames{en}->{61754032} = "Laidley";
$areanames{en}->{61754033} = "Lowood";
$areanames{en}->{61754034} = "Maleny";
$areanames{en}->{61754035} = "Maroon";
$areanames{en}->{61754036} = "Moore";
$areanames{en}->{61754037} = "Noosaville";
$areanames{en}->{61754038} = "Pomona";
$areanames{en}->{61754039} = "Rosevale";
$areanames{en}->{61754040} = "Rosewood";
$areanames{en}->{61754041} = "Thornton";
$areanames{en}->{61754042} = "Toogoolawah";
$areanames{en}->{61754043} = "Upper\ Widgee";
$areanames{en}->{61754044} = "Wolvi";
$areanames{en}->{61754045} = "Woodbine";
$areanames{en}->{61754046} = "Woodford";
$areanames{en}->{61754047} = "Woolooga";
$areanames{en}->{61754048} = "Esk";
$areanames{en}->{61754049} = "Gatton";
$areanames{en}->{61754050} = "Caboolture";
$areanames{en}->{61754051} = "Caboolture";
$areanames{en}->{61754052} = "Caloundra";
$areanames{en}->{61754053} = "Caloundra";
$areanames{en}->{61754054} = "Jimna";
$areanames{en}->{61754055} = "Kilcoy";
$areanames{en}->{61754056} = "Maleny";
$areanames{en}->{61754057} = "Woodford";
$areanames{en}->{61754058} = "Gympie";
$areanames{en}->{61754059} = "Gympie";
$areanames{en}->{6175406} = "Nambour";
$areanames{en}->{6175407} = "Caboolture";
$areanames{en}->{61754080} = "Caboolture";
$areanames{en}->{61754081} = "Caboolture";
$areanames{en}->{617540822} = "Gympie";
$areanames{en}->{617540830} = "Gympie";
$areanames{en}->{61754084} = "Nambour";
$areanames{en}->{61754085} = "Nambour";
$areanames{en}->{61754086} = "Caboolture";
$areanames{en}->{61754087} = "Caboolture";
$areanames{en}->{61754088} = "Caloundra";
$areanames{en}->{61754089} = "Esk";
$areanames{en}->{6175409} = "Nambour";
$areanames{en}->{6175410} = "Harrisville";
$areanames{en}->{61754107} = "Kalbar";
$areanames{en}->{61754108} = "Kalbar";
$areanames{en}->{6175411} = "Laidley";
$areanames{en}->{61754116} = "Rosevale";
$areanames{en}->{61754117} = "Thornton";
$areanames{en}->{61754118} = "Woodbine";
$areanames{en}->{61754120} = "Caloundra";
$areanames{en}->{61754121} = "Nambour";
$areanames{en}->{61754122} = "Noosaville";
$areanames{en}->{61754123} = "Caloundra";
$areanames{en}->{61754124} = "Woodbine";
$areanames{en}->{61754125} = "Boonah";
$areanames{en}->{61754126} = "Gatton";
$areanames{en}->{61754127} = "Noosaville";
$areanames{en}->{61754128} = "Cooroy";
$areanames{en}->{61754129} = "Kenilworth";
$areanames{en}->{6175413} = "Caloundra";
$areanames{en}->{61754140} = "Nambour";
$areanames{en}->{61754141} = "Nambour";
$areanames{en}->{61754142} = "Nambour";
$areanames{en}->{61754143} = "Nambour";
$areanames{en}->{61754144} = "Caboolture";
$areanames{en}->{61754145} = "Wolvi";
$areanames{en}->{61754146} = "Woolooga";
$areanames{en}->{61754147} = "Cooroy";
$areanames{en}->{61754148} = "Kenilworth";
$areanames{en}->{61754149} = "Nambour";
$areanames{en}->{61754150} = "Nambour";
$areanames{en}->{61754151} = "Noosaville";
$areanames{en}->{61754152} = "Caboolture";
$areanames{en}->{61754153} = "Caloundra";
$areanames{en}->{61754154} = "Jimna";
$areanames{en}->{61754155} = "Kilcoy";
$areanames{en}->{61754156} = "Maleny";
$areanames{en}->{61754157} = "Woodford";
$areanames{en}->{61754158} = "Coominya";
$areanames{en}->{61754159} = "Crossdale";
$areanames{en}->{61754160} = "Esk";
$areanames{en}->{61754161} = "Lowood";
$areanames{en}->{61754162} = "Moore";
$areanames{en}->{61754163} = "Toogoolawah";
$areanames{en}->{61754164} = "Boonah";
$areanames{en}->{61754165} = "Gatton";
$areanames{en}->{61754166} = "Harrisville";
$areanames{en}->{61754167} = "Kalbar";
$areanames{en}->{61754168} = "Laidley";
$areanames{en}->{61754169} = "Maroon";
$areanames{en}->{61754170} = "Thornton";
$areanames{en}->{61754171} = "Woodbine";
$areanames{en}->{61754172} = "Ballugan";
$areanames{en}->{61754173} = "Gunalda";
$areanames{en}->{61754174} = "Gympie";
$areanames{en}->{61754175} = "Imbil";
$areanames{en}->{61754176} = "Kia\ Ora";
$areanames{en}->{61754177} = "Kilkivan";
$areanames{en}->{61754178} = "Pomona";
$areanames{en}->{61754179} = "Upper\ Widgee";
$areanames{en}->{61754180} = "Moore";
$areanames{en}->{61754181} = "Toogoolawah";
$areanames{en}->{61754182} = "Boonah";
$areanames{en}->{61754183} = "Gatton";
$areanames{en}->{61754184} = "Harrisville";
$areanames{en}->{61754185} = "Kalbar";
$areanames{en}->{61754186} = "Laidley";
$areanames{en}->{61754187} = "Maroon";
$areanames{en}->{61754188} = "Rosevale";
$areanames{en}->{61754189} = "Rosewood";
$areanames{en}->{61754190} = "Caboolture";
$areanames{en}->{61754191} = "Caloundra";
$areanames{en}->{61754192} = "Jimna";
$areanames{en}->{61754193} = "Kilcoy";
$areanames{en}->{61754194} = "Maleny";
$areanames{en}->{61754195} = "Woodford";
$areanames{en}->{61754196} = "Coominya";
$areanames{en}->{61754197} = "Crossdale";
$areanames{en}->{61754198} = "Esk";
$areanames{en}->{61754199} = "Lowood";
$areanames{en}->{61754200} = "Caboolture";
$areanames{en}->{61754201} = "Caboolture";
$areanames{en}->{61754202} = "Caboolture";
$areanames{en}->{61754203} = "Caboolture";
$areanames{en}->{61754204} = "Woodford";
$areanames{en}->{61754205} = "Maleny";
$areanames{en}->{61754206} = "Caloundra";
$areanames{en}->{61754207} = "Caloundra";
$areanames{en}->{61754208} = "Caloundra";
$areanames{en}->{61754209} = "Caloundra";
$areanames{en}->{61754210} = "Lowood";
$areanames{en}->{61754211} = "Lowood";
$areanames{en}->{61754212} = "Lowood";
$areanames{en}->{61754213} = "Lowood";
$areanames{en}->{61754214} = "Esk";
$areanames{en}->{61754215} = "Esk";
$areanames{en}->{61754216} = "Esk";
$areanames{en}->{61754217} = "Toogoolawah";
$areanames{en}->{61754218} = "Toogoolawah";
$areanames{en}->{61754219} = "Toogoolawah";
$areanames{en}->{61754220} = "Kilcoy";
$areanames{en}->{61754221} = "Kilcoy";
$areanames{en}->{61754222} = "Kilcoy";
$areanames{en}->{61754223} = "Kilcoy";
$areanames{en}->{61754224} = "Kilcoy";
$areanames{en}->{61754225} = "Woodford";
$areanames{en}->{61754226} = "Woodford";
$areanames{en}->{61754227} = "Woodford";
$areanames{en}->{61754228} = "Woodford";
$areanames{en}->{61754229} = "Woodford";
$areanames{en}->{6175423} = "Toogoolawah";
$areanames{en}->{61754240} = "Esk";
$areanames{en}->{61754241} = "Esk";
$areanames{en}->{61754242} = "Esk";
$areanames{en}->{61754243} = "Esk";
$areanames{en}->{61754244} = "Esk";
$areanames{en}->{61754245} = "Moore";
$areanames{en}->{61754246} = "Coominya";
$areanames{en}->{61754247} = "Moore";
$areanames{en}->{61754248} = "Moore";
$areanames{en}->{61754249} = "Moore";
$areanames{en}->{61754250} = "Coominya";
$areanames{en}->{61754251} = "Coominya";
$areanames{en}->{61754252} = "Crossdale";
$areanames{en}->{61754253} = "Crossdale";
$areanames{en}->{61754254} = "Esk";
$areanames{en}->{61754255} = "Esk";
$areanames{en}->{61754256} = "Lowood";
$areanames{en}->{61754257} = "Lowood";
$areanames{en}->{61754258} = "Lowood";
$areanames{en}->{61754259} = "Lowood";
$areanames{en}->{6175426} = "Lowood";
$areanames{en}->{61754260} = "Crossdale";
$areanames{en}->{61754264} = "Coominya";
$areanames{en}->{61754265} = "Coominya";
$areanames{en}->{6175427} = "Lowood";
$areanames{en}->{6175428} = "Caboolture";
$areanames{en}->{6175429} = "Caboolture";
$areanames{en}->{61754296} = "Maleny";
$areanames{en}->{6175430} = "Nambour";
$areanames{en}->{61754305} = "Noosaville";
$areanames{en}->{61754306} = "Noosaville";
$areanames{en}->{61754307} = "Noosaville";
$areanames{en}->{6175431} = "Caboolture";
$areanames{en}->{6175432} = "Caboolture";
$areanames{en}->{6175433} = "Caboolture";
$areanames{en}->{61754340} = "Kilcoy";
$areanames{en}->{61754341} = "Kilcoy";
$areanames{en}->{61754342} = "Kilcoy";
$areanames{en}->{61754343} = "Kilcoy";
$areanames{en}->{61754344} = "Jimna";
$areanames{en}->{61754345} = "Woodford";
$areanames{en}->{61754346} = "Woodford";
$areanames{en}->{61754347} = "Woodford";
$areanames{en}->{61754348} = "Woodford";
$areanames{en}->{61754349} = "Woodford";
$areanames{en}->{6175435} = "Maleny";
$areanames{en}->{6175436} = "Caloundra";
$areanames{en}->{6175437} = "Caloundra";
$areanames{en}->{6175438} = "Caloundra";
$areanames{en}->{6175439} = "Caloundra";
$areanames{en}->{6175440} = "Noosaville";
$areanames{en}->{61754400} = "Kenilworth";
$areanames{en}->{61754401} = "Cooroy";
$areanames{en}->{6175441} = "Nambour";
$areanames{en}->{61754420} = "Nambour";
$areanames{en}->{61754421} = "Nambour";
$areanames{en}->{61754422} = "Nambour";
$areanames{en}->{61754423} = "Nambour";
$areanames{en}->{61754424} = "Noosaville";
$areanames{en}->{61754425} = "Cooroy";
$areanames{en}->{61754426} = "Cooroy";
$areanames{en}->{61754427} = "Cooroy";
$areanames{en}->{61754428} = "Cooroy";
$areanames{en}->{61754429} = "Nambour";
$areanames{en}->{6175443} = "Nambour";
$areanames{en}->{6175444} = "Nambour";
$areanames{en}->{6175445} = "Nambour";
$areanames{en}->{6175446} = "Noosaville";
$areanames{en}->{61754460} = "Kenilworth";
$areanames{en}->{61754467} = "Cooroy";
$areanames{en}->{61754468} = "Cooroy";
$areanames{en}->{61754469} = "Kenilworth";
$areanames{en}->{61754470} = "Cooroy";
$areanames{en}->{61754471} = "Noosaville";
$areanames{en}->{61754472} = "Noosaville";
$areanames{en}->{61754473} = "Noosaville";
$areanames{en}->{61754474} = "Noosaville";
$areanames{en}->{61754475} = "Noosaville";
$areanames{en}->{61754476} = "Cooroy";
$areanames{en}->{61754477} = "Cooroy";
$areanames{en}->{61754478} = "Cooroy";
$areanames{en}->{61754479} = "Cooroy";
$areanames{en}->{6175448} = "Nambour";
$areanames{en}->{61754480} = "Noosaville";
$areanames{en}->{61754481} = "Noosaville";
$areanames{en}->{61754482} = "Noosaville";
$areanames{en}->{61754483} = "Noosaville";
$areanames{en}->{6175449} = "Noosaville";
$areanames{en}->{617545} = "Nambour";
$areanames{en}->{6175454} = "Cooroy";
$areanames{en}->{61754540} = "Kenilworth";
$areanames{en}->{61754541} = "Kenilworth";
$areanames{en}->{61754542} = "Kenilworth";
$areanames{en}->{61754543} = "Kenilworth";
$areanames{en}->{6175455} = "Noosaville";
$areanames{en}->{61754600} = "Gatton";
$areanames{en}->{61754601} = "Gatton";
$areanames{en}->{61754602} = "Gatton";
$areanames{en}->{61754603} = "Laidley";
$areanames{en}->{61754604} = "Laidley";
$areanames{en}->{61754605} = "Laidley";
$areanames{en}->{61754606} = "Boonah";
$areanames{en}->{61754607} = "Boonah";
$areanames{en}->{61754608} = "Rosewood";
$areanames{en}->{61754609} = "Rosewood";
$areanames{en}->{6175461} = "Rosewood";
$areanames{en}->{6175462} = "Gatton";
$areanames{en}->{61754629} = "Woodbine";
$areanames{en}->{6175463} = "Boonah";
$areanames{en}->{61754636} = "Maroon";
$areanames{en}->{61754637} = "Kalbar";
$areanames{en}->{61754638} = "Kalbar";
$areanames{en}->{61754639} = "Kalbar";
$areanames{en}->{61754640} = "Harrisville";
$areanames{en}->{61754641} = "Rosewood";
$areanames{en}->{61754642} = "Rosewood";
$areanames{en}->{61754643} = "Rosewood";
$areanames{en}->{61754644} = "Rosewood";
$areanames{en}->{61754645} = "Rosewood";
$areanames{en}->{61754646} = "Harrisville";
$areanames{en}->{61754647} = "Harrisville";
$areanames{en}->{61754648} = "Harrisville";
$areanames{en}->{61754649} = "Rosevale";
$areanames{en}->{6175465} = "Laidley";
$areanames{en}->{61754659} = "Thornton";
$areanames{en}->{61754660} = "Gatton";
$areanames{en}->{61754661} = "Gatton";
$areanames{en}->{61754662} = "Gatton";
$areanames{en}->{61754663} = "Gatton";
$areanames{en}->{61754664} = "Laidley";
$areanames{en}->{61754665} = "Laidley";
$areanames{en}->{61754666} = "Laidley";
$areanames{en}->{61754667} = "Thornton";
$areanames{en}->{61754668} = "Laidley";
$areanames{en}->{61754669} = "Laidley";
$areanames{en}->{6175467} = "Rosewood";
$areanames{en}->{61754671} = "Harrisville";
$areanames{en}->{61754672} = "Harrisville";
$areanames{en}->{6175468} = "Gatton";
$areanames{en}->{6175469} = "Boonah";
$areanames{en}->{61754696} = "Maroon";
$areanames{en}->{61754697} = "Maroon";
$areanames{en}->{61754698} = "Kalbar";
$areanames{en}->{61754699} = "Kalbar";
$areanames{en}->{61754700} = "Noosaville";
$areanames{en}->{61754701} = "Noosaville";
$areanames{en}->{61754702} = "Noosaville";
$areanames{en}->{61754703} = "Noosaville";
$areanames{en}->{61754704} = "Cooroy";
$areanames{en}->{61754705} = "Nambour";
$areanames{en}->{61754706} = "Nambour";
$areanames{en}->{61754707} = "Nambour";
$areanames{en}->{61754708} = "Nambour";
$areanames{en}->{61754709} = "Nambour";
$areanames{en}->{6175471} = "Noosaville";
$areanames{en}->{6175472} = "Cooroy";
$areanames{en}->{61754723} = "Kenilworth";
$areanames{en}->{61754724} = "Kenilworth";
$areanames{en}->{6175473} = "Noosaville";
$areanames{en}->{6175474} = "Noosaville";
$areanames{en}->{6175475} = "Nambour";
$areanames{en}->{6175476} = "Nambour";
$areanames{en}->{6175477} = "Nambour";
$areanames{en}->{6175478} = "Nambour";
$areanames{en}->{6175479} = "Nambour";
$areanames{en}->{6175480} = "Gympie";
$areanames{en}->{61754800} = "Kia\ Ora";
$areanames{en}->{61754808} = "Pomona";
$areanames{en}->{61754809} = "Imbil";
$areanames{en}->{6175481} = "Gympie";
$areanames{en}->{6175482} = "Gympie";
$areanames{en}->{6175483} = "Gympie";
$areanames{en}->{61754840} = "Upper\ Widgee";
$areanames{en}->{61754841} = "Kilkivan";
$areanames{en}->{61754842} = "Ballugan";
$areanames{en}->{61754843} = "Imbil";
$areanames{en}->{61754844} = "Imbil";
$areanames{en}->{61754845} = "Imbil";
$areanames{en}->{61754846} = "Gunalda";
$areanames{en}->{61754847} = "Woolooga";
$areanames{en}->{61754848} = "Woolooga";
$areanames{en}->{61754849} = "Upper\ Widgee";
$areanames{en}->{6175485} = "Pomona";
$areanames{en}->{61754857} = "Gunalda";
$areanames{en}->{6175486} = "Kia\ Ora";
$areanames{en}->{61754861} = "Woolooga";
$areanames{en}->{61754866} = "Wolvi";
$areanames{en}->{61754867} = "Wolvi";
$areanames{en}->{61754870} = "Pomona";
$areanames{en}->{61754871} = "Pomona";
$areanames{en}->{61754872} = "Kilkivan";
$areanames{en}->{61754873} = "Kilkivan";
$areanames{en}->{61754874} = "Upper\ Widgee";
$areanames{en}->{61754875} = "Upper\ Widgee";
$areanames{en}->{61754876} = "Wolvi";
$areanames{en}->{61754877} = "Wolvi";
$areanames{en}->{61754878} = "Woolooga";
$areanames{en}->{61754879} = "Woolooga";
$areanames{en}->{61754880} = "Kia\ Ora";
$areanames{en}->{61754881} = "Kia\ Ora";
$areanames{en}->{61754882} = "Kia\ Ora";
$areanames{en}->{61754883} = "Kia\ Ora";
$areanames{en}->{61754884} = "Imbil";
$areanames{en}->{61754885} = "Imbil";
$areanames{en}->{61754886} = "Imbil";
$areanames{en}->{61754887} = "Ballugan";
$areanames{en}->{61754888} = "Gunalda";
$areanames{en}->{61754889} = "Gunalda";
$areanames{en}->{6175489} = "Gympie";
$areanames{en}->{6175490} = "Caboolture";
$areanames{en}->{61754902} = "Caloundra";
$areanames{en}->{61754905} = "Caloundra";
$areanames{en}->{6175494} = "Caloundra";
$areanames{en}->{61754942} = "Maleny";
$areanames{en}->{61754943} = "Maleny";
$areanames{en}->{61754944} = "Maleny";
$areanames{en}->{6175495} = "Caboolture";
$areanames{en}->{61754960} = "Caloundra";
$areanames{en}->{61754961} = "Woodford";
$areanames{en}->{61754962} = "Caboolture";
$areanames{en}->{61754963} = "Woodford";
$areanames{en}->{61754964} = "Woodford";
$areanames{en}->{61754965} = "Woodford";
$areanames{en}->{61754966} = "Caboolture";
$areanames{en}->{61754967} = "Caboolture";
$areanames{en}->{61754968} = "Caboolture";
$areanames{en}->{61754969} = "Caloundra";
$areanames{en}->{6175497} = "Caboolture";
$areanames{en}->{61754971} = "Kilcoy";
$areanames{en}->{61754972} = "Kilcoy";
$areanames{en}->{61754973} = "Jimna";
$areanames{en}->{6175498} = "Caboolture";
$areanames{en}->{61754981} = "Kilcoy";
$areanames{en}->{61754984} = "Kilcoy";
$areanames{en}->{61754990} = "Caboolture";
$areanames{en}->{61754991} = "Caboolture";
$areanames{en}->{61754992} = "Caboolture";
$areanames{en}->{61754993} = "Caboolture";
$areanames{en}->{61754994} = "Caboolture";
$areanames{en}->{61754995} = "Caloundra";
$areanames{en}->{61754996} = "Caloundra";
$areanames{en}->{61754997} = "Caloundra";
$areanames{en}->{61754998} = "Maleny";
$areanames{en}->{61754999} = "Maleny";
$areanames{en}->{617550} = "Southport";
$areanames{en}->{6175505} = "Tamborine\ Mountain";
$areanames{en}->{6175506} = "Tweed\ Heads";
$areanames{en}->{6175507} = "Tweed\ Heads";
$areanames{en}->{6175508} = "Tweed\ Heads";
$areanames{en}->{6175510} = "Southport";
$areanames{en}->{6175511} = "Southport";
$areanames{en}->{6175512} = "Southport";
$areanames{en}->{6175513} = "Tweed\ Heads";
$areanames{en}->{6175514} = "Southport";
$areanames{en}->{61755150} = "Beaudesert";
$areanames{en}->{61755151} = "Beaudesert";
$areanames{en}->{61755152} = "Beechmont";
$areanames{en}->{61755153} = "Jimboomba";
$areanames{en}->{61755154} = "Kerry";
$areanames{en}->{61755155} = "Ormeau";
$areanames{en}->{61755156} = "Rathdowney";
$areanames{en}->{61755157} = "Southport";
$areanames{en}->{61755158} = "Southport";
$areanames{en}->{61755159} = "Beaudesert";
$areanames{en}->{61755160} = "Beaudesert";
$areanames{en}->{61755161} = "Beaudesert";
$areanames{en}->{61755162} = "Beaudesert";
$areanames{en}->{61755163} = "Beechmont";
$areanames{en}->{61755164} = "Beechmont";
$areanames{en}->{61755165} = "Beechmont";
$areanames{en}->{61755166} = "Jimboomba";
$areanames{en}->{61755167} = "Jimboomba";
$areanames{en}->{61755168} = "Jimboomba";
$areanames{en}->{61755169} = "Beechmont";
$areanames{en}->{61755170} = "Kerry";
$areanames{en}->{61755171} = "Kerry";
$areanames{en}->{61755172} = "Kerry";
$areanames{en}->{61755173} = "Ormeau";
$areanames{en}->{61755174} = "Ormeau";
$areanames{en}->{61755175} = "Ormeau";
$areanames{en}->{61755176} = "Rathdowney";
$areanames{en}->{61755177} = "Rathdowney";
$areanames{en}->{61755178} = "Rathdowney";
$areanames{en}->{61755179} = "Jimboomba";
$areanames{en}->{61755180} = "Tamborine\ Mountain";
$areanames{en}->{61755181} = "Tamborine\ Mountain";
$areanames{en}->{61755182} = "Tamborine\ Mountain";
$areanames{en}->{61755183} = "Tweed\ Heads";
$areanames{en}->{61755184} = "Tweed\ Heads";
$areanames{en}->{61755185} = "Tweed\ Heads";
$areanames{en}->{61755186} = "Tamborine\ Mountain";
$areanames{en}->{61755187} = "Southport";
$areanames{en}->{61755188} = "Beaudesert";
$areanames{en}->{61755189} = "Beaudesert";
$areanames{en}->{6175519} = "Southport";
$areanames{en}->{617552} = "Tweed\ Heads";
$areanames{en}->{6175526} = "Southport";
$areanames{en}->{6175527} = "Southport";
$areanames{en}->{6175528} = "Southport";
$areanames{en}->{6175529} = "Southport";
$areanames{en}->{6175530} = "Tweed\ Heads";
$areanames{en}->{61755300} = "Southport";
$areanames{en}->{61755301} = "Southport";
$areanames{en}->{61755308} = "Southport";
$areanames{en}->{61755309} = "Southport";
$areanames{en}->{6175531} = "Southport";
$areanames{en}->{6175532} = "Southport";
$areanames{en}->{61755330} = "Tweed\ Heads";
$areanames{en}->{61755331} = "Southport";
$areanames{en}->{61755332} = "Southport";
$areanames{en}->{61755333} = "Beechmont";
$areanames{en}->{61755334} = "Beechmont";
$areanames{en}->{61755335} = "Beechmont";
$areanames{en}->{61755336} = "Beechmont";
$areanames{en}->{61755337} = "Southport";
$areanames{en}->{61755338} = "Tweed\ Heads";
$areanames{en}->{61755339} = "Tweed\ Heads";
$areanames{en}->{6175534} = "Tweed\ Heads";
$areanames{en}->{6175535} = "Tweed\ Heads";
$areanames{en}->{6175536} = "Tweed\ Heads";
$areanames{en}->{6175537} = "Southport";
$areanames{en}->{6175538} = "Southport";
$areanames{en}->{6175539} = "Southport";
$areanames{en}->{61755400} = "Beaudesert";
$areanames{en}->{61755401} = "Beaudesert";
$areanames{en}->{61755402} = "Tamborine\ Mountain";
$areanames{en}->{61755403} = "Jimboomba";
$areanames{en}->{61755404} = "Rathdowney";
$areanames{en}->{61755405} = "Beaudesert";
$areanames{en}->{61755406} = "Ormeau";
$areanames{en}->{61755407} = "Ormeau";
$areanames{en}->{61755408} = "Ormeau";
$areanames{en}->{61755409} = "Ormeau";
$areanames{en}->{6175541} = "Beaudesert";
$areanames{en}->{61755416} = "Tamborine\ Mountain";
$areanames{en}->{61755417} = "Tamborine\ Mountain";
$areanames{en}->{61755418} = "Tamborine\ Mountain";
$areanames{en}->{6175542} = "Beaudesert";
$areanames{en}->{6175543} = "Tamborine\ Mountain";
$areanames{en}->{61755431} = "Jimboomba";
$areanames{en}->{61755432} = "Jimboomba";
$areanames{en}->{61755433} = "Jimboomba";
$areanames{en}->{6175544} = "Rathdowney";
$areanames{en}->{61755440} = "Kerry";
$areanames{en}->{61755447} = "Kerry";
$areanames{en}->{61755448} = "Kerry";
$areanames{en}->{61755449} = "Kerry";
$areanames{en}->{6175545} = "Tamborine\ Mountain";
$areanames{en}->{61755458} = "Beechmont";
$areanames{en}->{61755459} = "Beechmont";
$areanames{en}->{6175546} = "Ormeau";
$areanames{en}->{61755460} = "Jimboomba";
$areanames{en}->{61755469} = "Jimboomba";
$areanames{en}->{6175547} = "Ormeau";
$areanames{en}->{61755477} = "Jimboomba";
$areanames{en}->{61755478} = "Jimboomba";
$areanames{en}->{61755479} = "Jimboomba";
$areanames{en}->{6175548} = "Beechmont";
$areanames{en}->{61755486} = "Jimboomba";
$areanames{en}->{61755487} = "Jimboomba";
$areanames{en}->{61755488} = "Jimboomba";
$areanames{en}->{61755489} = "Jimboomba";
$areanames{en}->{6175549} = "Ormeau";
$areanames{en}->{61755510} = "Southport";
$areanames{en}->{61755511} = "Southport";
$areanames{en}->{61755512} = "Beechmont";
$areanames{en}->{61755513} = "Tamborine\ Mountain";
$areanames{en}->{61755514} = "Tweed\ Heads";
$areanames{en}->{61755515} = "Jimboomba";
$areanames{en}->{61755516} = "Ormeau";
$areanames{en}->{61755517} = "Kerry";
$areanames{en}->{61755518} = "Rathdowney";
$areanames{en}->{61755519} = "Beaudesert";
$areanames{en}->{6175552} = "Southport";
$areanames{en}->{6175553} = "Southport";
$areanames{en}->{6175554} = "Southport";
$areanames{en}->{6175555} = "Southport";
$areanames{en}->{6175556} = "Southport";
$areanames{en}->{6175557} = "Southport";
$areanames{en}->{6175558} = "Southport";
$areanames{en}->{6175559} = "Tweed\ Heads";
$areanames{en}->{6175560} = "Southport";
$areanames{en}->{6175561} = "Southport";
$areanames{en}->{6175562} = "Southport";
$areanames{en}->{6175563} = "Southport";
$areanames{en}->{6175564} = "Southport";
$areanames{en}->{6175565} = "Tweed\ Heads";
$areanames{en}->{6175566} = "Tweed\ Heads";
$areanames{en}->{61755670} = "Kerry";
$areanames{en}->{61755671} = "Kerry";
$areanames{en}->{61755672} = "Kerry";
$areanames{en}->{61755673} = "Kerry";
$areanames{en}->{61755674} = "Kerry";
$areanames{en}->{61755675} = "Rathdowney";
$areanames{en}->{61755676} = "Rathdowney";
$areanames{en}->{61755677} = "Rathdowney";
$areanames{en}->{61755678} = "Rathdowney";
$areanames{en}->{61755679} = "Rathdowney";
$areanames{en}->{6175568} = "Tweed\ Heads";
$areanames{en}->{6175569} = "Tweed\ Heads";
$areanames{en}->{617557} = "Southport";
$areanames{en}->{6175576} = "Tweed\ Heads";
$areanames{en}->{617558} = "Southport";
$areanames{en}->{6175586} = "Tweed\ Heads";
$areanames{en}->{6175587} = "Tweed\ Heads";
$areanames{en}->{6175589} = "Tweed\ Heads";
$areanames{en}->{6175590} = "Tweed\ Heads";
$areanames{en}->{6175593} = "Tweed\ Heads";
$areanames{en}->{61755930} = "Southport";
$areanames{en}->{61755931} = "Southport";
$areanames{en}->{61755932} = "Southport";
$areanames{en}->{61755933} = "Southport";
$areanames{en}->{6175594} = "Southport";
$areanames{en}->{6175595} = "Southport";
$areanames{en}->{6175596} = "Southport";
$areanames{en}->{6175597} = "Southport";
$areanames{en}->{6175598} = "Tweed\ Heads";
$areanames{en}->{6175599} = "Tweed\ Heads";
$areanames{en}->{6175600} = "Southport";
$areanames{en}->{6175601} = "Tweed\ Heads";
$areanames{en}->{61756020} = "Beaudesert";
$areanames{en}->{61756021} = "Beechmont";
$areanames{en}->{61756022} = "Jimboomba";
$areanames{en}->{61756023} = "Kerry";
$areanames{en}->{61756024} = "Ormeau";
$areanames{en}->{61756025} = "Rathdowney";
$areanames{en}->{61756026} = "Southport";
$areanames{en}->{61756027} = "Tamborine\ Mountain";
$areanames{en}->{61756028} = "Tweed\ Heads";
$areanames{en}->{61756029} = "Beechmont";
$areanames{en}->{61756030} = "Kerry";
$areanames{en}->{61756031} = "Ormeau";
$areanames{en}->{61756032} = "Rathdowney";
$areanames{en}->{61756033} = "Southport";
$areanames{en}->{61756034} = "Tamborine\ Mountain";
$areanames{en}->{61756035} = "Tweed\ Heads";
$areanames{en}->{61756036} = "Jimboomba";
$areanames{en}->{61756037} = "Kerry";
$areanames{en}->{61756038} = "Ormeau";
$areanames{en}->{61756039} = "Rathdowney";
$areanames{en}->{61756040} = "Tamborine\ Mountain";
$areanames{en}->{61756041} = "Tweed\ Heads";
$areanames{en}->{61756042} = "Beechmont";
$areanames{en}->{61756043} = "Jimboomba";
$areanames{en}->{61756044} = "Kerry";
$areanames{en}->{61756045} = "Ormeau";
$areanames{en}->{61756046} = "Rathdowney";
$areanames{en}->{61756047} = "Tamborine\ Mountain";
$areanames{en}->{61756048} = "Beaudesert";
$areanames{en}->{61756049} = "Beechmont";
$areanames{en}->{61756050} = "Beaudesert";
$areanames{en}->{61756051} = "Beechmont";
$areanames{en}->{61756052} = "Jimboomba";
$areanames{en}->{61756053} = "Kerry";
$areanames{en}->{61756054} = "Ormeau";
$areanames{en}->{61756055} = "Rathdowney";
$areanames{en}->{61756056} = "Tamborine\ Mountain";
$areanames{en}->{61756057} = "Tweed\ Heads";
$areanames{en}->{61756058} = "Southport";
$areanames{en}->{61756059} = "Jimboomba";
$areanames{en}->{61756060} = "Kerry";
$areanames{en}->{61756061} = "Ormeau";
$areanames{en}->{61756062} = "Rathdowney";
$areanames{en}->{61756063} = "Southport";
$areanames{en}->{61756064} = "Tamborine\ Mountain";
$areanames{en}->{61756065} = "Tweed\ Heads";
$areanames{en}->{61756066} = "Southport";
$areanames{en}->{61756067} = "Southport";
$areanames{en}->{61756068} = "Southport";
$areanames{en}->{61756069} = "Jimboomba";
$areanames{en}->{61756070} = "Tweed\ Heads";
$areanames{en}->{61756071} = "Southport";
$areanames{en}->{61756072} = "Tamborine\ Mountain";
$areanames{en}->{61756073} = "Tweed\ Heads";
$areanames{en}->{61756074} = "Tweed\ Heads";
$areanames{en}->{61756075} = "Jimboomba";
$areanames{en}->{61756076} = "Southport";
$areanames{en}->{61756077} = "Beaudesert";
$areanames{en}->{61756078} = "Beechmont";
$areanames{en}->{61756079} = "Jimboomba";
$areanames{en}->{61756080} = "Kerry";
$areanames{en}->{61756081} = "Ormeau";
$areanames{en}->{61756082} = "Rathdowney";
$areanames{en}->{61756083} = "Tamborine\ Mountain";
$areanames{en}->{61756084} = "Tweed\ Heads";
$areanames{en}->{61756085} = "Ormeau";
$areanames{en}->{61756086} = "Ormeau";
$areanames{en}->{61756087} = "Southport";
$areanames{en}->{61756088} = "Southport";
$areanames{en}->{61756089} = "Tweed\ Heads";
$areanames{en}->{61756090} = "Beaudesert";
$areanames{en}->{61756091} = "Jimboomba";
$areanames{en}->{61756092} = "Ormeau";
$areanames{en}->{61756093} = "Tamborine\ Mountain";
$areanames{en}->{61756094} = "Southport";
$areanames{en}->{61756095} = "Beaudesert";
$areanames{en}->{61756096} = "Tweed\ Heads";
$areanames{en}->{61756097} = "Southport";
$areanames{en}->{61756098} = "Southport";
$areanames{en}->{61756099} = "Ormeau";
$areanames{en}->{61756100} = "Beaudesert";
$areanames{en}->{61756101} = "Southport";
$areanames{en}->{61756102} = "Tweed\ Heads";
$areanames{en}->{61756103} = "Beaudesert";
$areanames{en}->{61756104} = "Tweed\ Heads";
$areanames{en}->{61756105} = "Southport";
$areanames{en}->{61756106} = "Tamborine\ Mountain";
$areanames{en}->{61756107} = "Kerry";
$areanames{en}->{61756108} = "Ormeau";
$areanames{en}->{61756109} = "Beechmont";
$areanames{en}->{61756110} = "Jimboomba";
$areanames{en}->{61756111} = "Rathdowney";
$areanames{en}->{61756112} = "Beechmont";
$areanames{en}->{61756113} = "Jimboomba";
$areanames{en}->{61756114} = "Beaudesert";
$areanames{en}->{61756115} = "Tweed\ Heads";
$areanames{en}->{61756116} = "Kerry";
$areanames{en}->{61756117} = "Ormeau";
$areanames{en}->{61756118} = "Ormeau";
$areanames{en}->{61756119} = "Kerry";
$areanames{en}->{61756120} = "Ormeau";
$areanames{en}->{61756121} = "Tamborine\ Mountain";
$areanames{en}->{61756122} = "Rathdowney";
$areanames{en}->{61756123} = "Beechmont";
$areanames{en}->{61756124} = "Jimboomba";
$areanames{en}->{61756125} = "Tweed\ Heads";
$areanames{en}->{61756126} = "Rathdowney";
$areanames{en}->{61756127} = "Southport";
$areanames{en}->{61756128} = "Tamborine\ Mountain";
$areanames{en}->{61756129} = "Tweed\ Heads";
$areanames{en}->{61756130} = "Southport";
$areanames{en}->{61756131} = "Beaudesert";
$areanames{en}->{61756132} = "Southport";
$areanames{en}->{61756133} = "Southport";
$areanames{en}->{61756134} = "Beaudesert";
$areanames{en}->{61756135} = "Beechmont";
$areanames{en}->{61756136} = "Jimboomba";
$areanames{en}->{61756137} = "Kerry";
$areanames{en}->{61756138} = "Ormeau";
$areanames{en}->{61756139} = "Rathdowney";
$areanames{en}->{6175614} = "Southport";
$areanames{en}->{61756150} = "Southport";
$areanames{en}->{61756151} = "Tamborine\ Mountain";
$areanames{en}->{61756152} = "Tweed\ Heads";
$areanames{en}->{61756153} = "Beaudesert";
$areanames{en}->{61756154} = "Beechmont";
$areanames{en}->{61756155} = "Jimboomba";
$areanames{en}->{61756156} = "Kerry";
$areanames{en}->{61756157} = "Ormeau";
$areanames{en}->{61756158} = "Rathdowney";
$areanames{en}->{61756159} = "Southport";
$areanames{en}->{61756160} = "Tamborine\ Mountain";
$areanames{en}->{61756161} = "Tweed\ Heads";
$areanames{en}->{61756162} = "Beaudesert";
$areanames{en}->{61756163} = "Beechmont";
$areanames{en}->{61756164} = "Jimboomba";
$areanames{en}->{61756165} = "Kerry";
$areanames{en}->{61756166} = "Ormeau";
$areanames{en}->{61756167} = "Rathdowney";
$areanames{en}->{61756168} = "Southport";
$areanames{en}->{61756169} = "Tamborine\ Mountain";
$areanames{en}->{6175617} = "Southport";
$areanames{en}->{6175618} = "Southport";
$areanames{en}->{61756186} = "Tamborine\ Mountain";
$areanames{en}->{61756187} = "Tamborine\ Mountain";
$areanames{en}->{6175619} = "Southport";
$areanames{en}->{61756193} = "Tweed\ Heads";
$areanames{en}->{61756194} = "Beaudesert";
$areanames{en}->{61756200} = "Southport";
$areanames{en}->{61756201} = "Southport";
$areanames{en}->{61756202} = "Southport";
$areanames{en}->{61756203} = "Southport";
$areanames{en}->{61756204} = "Southport";
$areanames{en}->{61756205} = "Ormeau";
$areanames{en}->{61756206} = "Ormeau";
$areanames{en}->{61756207} = "Ormeau";
$areanames{en}->{61756208} = "Ormeau";
$areanames{en}->{61756210} = "Southport";
$areanames{en}->{61756211} = "Southport";
$areanames{en}->{61756212} = "Southport";
$areanames{en}->{61756213} = "Southport";
$areanames{en}->{61756214} = "Beaudesert";
$areanames{en}->{61756215} = "Beechmont";
$areanames{en}->{61756216} = "Jimboomba";
$areanames{en}->{61756217} = "Kerry";
$areanames{en}->{61756218} = "Ormeau";
$areanames{en}->{61756219} = "Rathdowney";
$areanames{en}->{61756220} = "Southport";
$areanames{en}->{61756221} = "Tamborine\ Mountain";
$areanames{en}->{61756222} = "Tweed\ Heads";
$areanames{en}->{61756223} = "Ormeau";
$areanames{en}->{61756224} = "Beaudesert";
$areanames{en}->{61756225} = "Beechmont";
$areanames{en}->{61756226} = "Jimboomba";
$areanames{en}->{61756227} = "Kerry";
$areanames{en}->{61756228} = "Ormeau";
$areanames{en}->{61756229} = "Rathdowney";
$areanames{en}->{61756230} = "Southport";
$areanames{en}->{61756231} = "Tamborine\ Mountain";
$areanames{en}->{61756232} = "Tweed\ Heads";
$areanames{en}->{61756233} = "Beaudesert";
$areanames{en}->{61756234} = "Beechmont";
$areanames{en}->{61756235} = "Jimboomba";
$areanames{en}->{61756236} = "Kerry";
$areanames{en}->{61756237} = "Ormeau";
$areanames{en}->{61756238} = "Rathdowney";
$areanames{en}->{61756239} = "Southport";
$areanames{en}->{61756240} = "Tamborine\ Mountain";
$areanames{en}->{61756241} = "Tweed\ Heads";
$areanames{en}->{61756242} = "Beaudesert";
$areanames{en}->{61756243} = "Beechmont";
$areanames{en}->{61756244} = "Jimboomba";
$areanames{en}->{61756245} = "Kerry";
$areanames{en}->{61756246} = "Ormeau";
$areanames{en}->{61756247} = "Rathdowney";
$areanames{en}->{61756248} = "Southport";
$areanames{en}->{61756249} = "Tamborine\ Mountain";
$areanames{en}->{61756250} = "Tweed\ Heads";
$areanames{en}->{61756251} = "Southport";
$areanames{en}->{61756252} = "Beaudesert";
$areanames{en}->{61756253} = "Beechmont";
$areanames{en}->{61756254} = "Jimboomba";
$areanames{en}->{61756255} = "Kerry";
$areanames{en}->{61756256} = "Ormeau";
$areanames{en}->{61756257} = "Rathdowney";
$areanames{en}->{61756258} = "Southport";
$areanames{en}->{61756259} = "Tamborine\ Mountain";
$areanames{en}->{6175626} = "Southport";
$areanames{en}->{6175627} = "Southport";
$areanames{en}->{6175628} = "Southport";
$areanames{en}->{6175629} = "Southport";
$areanames{en}->{617563023} = "Southport";
$areanames{en}->{617563024} = "Southport";
$areanames{en}->{617563025} = "Southport";
$areanames{en}->{617563037} = "Southport";
$areanames{en}->{61756304} = "Southport";
$areanames{en}->{617563054} = "Southport";
$areanames{en}->{617563066} = "Southport";
$areanames{en}->{61756307} = "Southport";
$areanames{en}->{617563083} = "Southport";
$areanames{en}->{61756309} = "Southport";
$areanames{en}->{6175631} = "Southport";
$areanames{en}->{61756310} = "Ormeau";
$areanames{en}->{61756311} = "Tweed\ Heads";
$areanames{en}->{6175632} = "Southport";
$areanames{en}->{6175633} = "Tweed\ Heads";
$areanames{en}->{6175634} = "Southport";
$areanames{en}->{6175635} = "Southport";
$areanames{en}->{6175636} = "Southport";
$areanames{en}->{6175637} = "Beaudesert";
$areanames{en}->{6175638} = "Southport";
$areanames{en}->{6175639} = "Southport";
$areanames{en}->{6175640} = "Beaudesert";
$areanames{en}->{617564100} = "Southport";
$areanames{en}->{617564115} = "Southport";
$areanames{en}->{61756413} = "Southport";
$areanames{en}->{61756414} = "Southport";
$areanames{en}->{6175642} = "Southport";
$areanames{en}->{6175643} = "Tweed\ Heads";
$areanames{en}->{6175644} = "Southport";
$areanames{en}->{61756450} = "Tweed\ Heads";
$areanames{en}->{61756451} = "Ormeau";
$areanames{en}->{61756452} = "Ormeau";
$areanames{en}->{61756453} = "Ormeau";
$areanames{en}->{61756454} = "Tweed\ Heads";
$areanames{en}->{61756455} = "Tweed\ Heads";
$areanames{en}->{61756456} = "Tweed\ Heads";
$areanames{en}->{61756457} = "Tweed\ Heads";
$areanames{en}->{61756458} = "Southport";
$areanames{en}->{61756459} = "Southport";
$areanames{en}->{6175646} = "Southport";
$areanames{en}->{61756460} = "Jimboomba";
$areanames{en}->{61756461} = "Jimboomba";
$areanames{en}->{61756462} = "Jimboomba";
$areanames{en}->{6175647} = "Southport";
$areanames{en}->{61756478} = "Beaudesert";
$areanames{en}->{61756479} = "Beaudesert";
$areanames{en}->{61756480} = "Tweed\ Heads";
$areanames{en}->{61756481} = "Tweed\ Heads";
$areanames{en}->{61756482} = "Tweed\ Heads";
$areanames{en}->{61756483} = "Southport";
$areanames{en}->{61756484} = "Southport";
$areanames{en}->{61756550} = "Southport";
$areanames{en}->{61756551} = "Southport";
$areanames{en}->{61756552} = "Southport";
$areanames{en}->{61756553} = "Southport";
$areanames{en}->{61756554} = "Southport";
$areanames{en}->{61756555} = "Beaudesert";
$areanames{en}->{61756556} = "Beaudesert";
$areanames{en}->{61756557} = "Beaudesert";
$areanames{en}->{61756558} = "Beaudesert";
$areanames{en}->{61756559} = "Beaudesert";
$areanames{en}->{6175656} = "Southport";
$areanames{en}->{6175657} = "Southport";
$areanames{en}->{617565800} = "Tweed\ Heads";
$areanames{en}->{617565803} = "Tweed\ Heads";
$areanames{en}->{6175659} = "Tweed\ Heads";
$areanames{en}->{61756600} = "Jimboomba";
$areanames{en}->{61756601} = "Jimboomba";
$areanames{en}->{61756602} = "Beechmont";
$areanames{en}->{61756603} = "Beechmont";
$areanames{en}->{61756604} = "Beaudesert";
$areanames{en}->{61756605} = "Beaudesert";
$areanames{en}->{61756606} = "Southport";
$areanames{en}->{61756607} = "Beaudesert";
$areanames{en}->{61756608} = "Beaudesert";
$areanames{en}->{61756609} = "Southport";
$areanames{en}->{61756619} = "Southport";
$areanames{en}->{6175662} = "Southport";
$areanames{en}->{61756629} = "Tweed\ Heads";
$areanames{en}->{6175663} = "Southport";
$areanames{en}->{61756630} = "Tweed\ Heads";
$areanames{en}->{61756631} = "Tweed\ Heads";
$areanames{en}->{61756632} = "Tweed\ Heads";
$areanames{en}->{61756633} = "Tweed\ Heads";
$areanames{en}->{6175664} = "Southport";
$areanames{en}->{6175665} = "Southport";
$areanames{en}->{61756660} = "Beaudesert";
$areanames{en}->{61756661} = "Beechmont";
$areanames{en}->{61756662} = "Jimboomba";
$areanames{en}->{61756663} = "Kerry";
$areanames{en}->{61756664} = "Ormeau";
$areanames{en}->{61756665} = "Rathdowney";
$areanames{en}->{61756666} = "Southport";
$areanames{en}->{61756667} = "Tamborine\ Mountain";
$areanames{en}->{61756668} = "Tweed\ Heads";
$areanames{en}->{61756669} = "Ormeau";
$areanames{en}->{617566705} = "Southport";
$areanames{en}->{617566710} = "Southport";
$areanames{en}->{617566715} = "Southport";
$areanames{en}->{61756672} = "Southport";
$areanames{en}->{617566733} = "Southport";
$areanames{en}->{61756680} = "Southport";
$areanames{en}->{61756681} = "Southport";
$areanames{en}->{617566829} = "Southport";
$areanames{en}->{61756684} = "Southport";
$areanames{en}->{617566854} = "Southport";
$areanames{en}->{61756686} = "Southport";
$areanames{en}->{61756687} = "Southport";
$areanames{en}->{61756688} = "Southport";
$areanames{en}->{61756689} = "Southport";
$areanames{en}->{6175669} = "Tweed\ Heads";
$areanames{en}->{6175670} = "Ormeau";
$areanames{en}->{61756717} = "Southport";
$areanames{en}->{61756718} = "Southport";
$areanames{en}->{61756719} = "Southport";
$areanames{en}->{6175672} = "Southport";
$areanames{en}->{6175675} = "Southport";
$areanames{en}->{6175676} = "Southport";
$areanames{en}->{61756770} = "Southport";
$areanames{en}->{61756771} = "Beaudesert";
$areanames{en}->{61756772} = "Tweed\ Heads";
$areanames{en}->{61756773} = "Tweed\ Heads";
$areanames{en}->{61756774} = "Rathdowney";
$areanames{en}->{61756775} = "Rathdowney";
$areanames{en}->{61756776} = "Tamborine\ Mountain";
$areanames{en}->{61756777} = "Tamborine\ Mountain";
$areanames{en}->{61756778} = "Kerry";
$areanames{en}->{61756779} = "Kerry";
$areanames{en}->{6175678} = "Southport";
$areanames{en}->{6175679} = "Southport";
$areanames{en}->{6175680} = "Southport";
$areanames{en}->{6175687} = "Southport";
$areanames{en}->{6175688} = "Beaudesert";
$areanames{en}->{61756880} = "Southport";
$areanames{en}->{61756881} = "Southport";
$areanames{en}->{61756885} = "Tweed\ Heads";
$areanames{en}->{61756886} = "Tweed\ Heads";
$areanames{en}->{61756890} = "Southport";
$areanames{en}->{61756891} = "Southport";
$areanames{en}->{61756892} = "Southport";
$areanames{en}->{61756893} = "Southport";
$areanames{en}->{61756894} = "Southport";
$areanames{en}->{61756895} = "Southport";
$areanames{en}->{61756896} = "Southport";
$areanames{en}->{61756998} = "Southport";
$areanames{en}->{61756999} = "Southport";
$areanames{en}->{617750000} = "Liston";
$areanames{en}->{617750001} = "Longreach";
$areanames{en}->{617750002} = "Lynd\ Range";
$areanames{en}->{617750003} = "Macalister";
$areanames{en}->{617750004} = "Maranoa";
$areanames{en}->{617750005} = "Meandarra";
$areanames{en}->{617750006} = "Miamba";
$areanames{en}->{617750007} = "Miles";
$areanames{en}->{617750008} = "Millmerran";
$areanames{en}->{617750009} = "Mitchell";
$areanames{en}->{617750010} = "Moonie";
$areanames{en}->{617750011} = "Morven";
$areanames{en}->{617750012} = "Mount\ Tyson";
$areanames{en}->{617750013} = "Muttaburra";
$areanames{en}->{617750014} = "Nobby";
$areanames{en}->{617750015} = "North\ Star";
$areanames{en}->{617750016} = "Oakey";
$areanames{en}->{617750017} = "Omanama";
$areanames{en}->{617750018} = "Paroo";
$areanames{en}->{617750019} = "Pikedale";
$areanames{en}->{617750020} = "Pittsworth";
$areanames{en}->{617750021} = "Quilpie";
$areanames{en}->{617750022} = "Ravensbourne";
$areanames{en}->{617750023} = "Robinson\ Gorge";
$areanames{en}->{617750024} = "Roma";
$areanames{en}->{617750025} = "Southwood";
$areanames{en}->{617750026} = "St\ George";
$areanames{en}->{617750027} = "Stanthorpe";
$areanames{en}->{617750028} = "Surat";
$areanames{en}->{617750029} = "Tabers";
$areanames{en}->{617750030} = "Talwood";
$areanames{en}->{617750031} = "Tambo";
$areanames{en}->{617750032} = "Tara";
$areanames{en}->{617750033} = "Taroom";
$areanames{en}->{617750034} = "Teelba";
$areanames{en}->{617750035} = "Texas";
$areanames{en}->{617750036} = "Thallon";
$areanames{en}->{617750037} = "Thargomindah";
$areanames{en}->{617750038} = "The\ Gums";
$areanames{en}->{617750039} = "Thomson";
$areanames{en}->{617750040} = "Tipton";
$areanames{en}->{617750041} = "Toobeah";
$areanames{en}->{617750042} = "Toowoomba";
$areanames{en}->{617750043} = "Valley\ Downs";
$areanames{en}->{617750044} = "Wallumbilla";
$areanames{en}->{617750045} = "Wandoan";
$areanames{en}->{617750046} = "Warra";
$areanames{en}->{617750047} = "Warrego";
$areanames{en}->{617750048} = "Warwick";
$areanames{en}->{617750049} = "Westgrove";
$areanames{en}->{617750050} = "Westmar";
$areanames{en}->{617750051} = "Winton";
$areanames{en}->{617750052} = "Wyaga";
$areanames{en}->{617750053} = "Yelarbon";
$areanames{en}->{617750054} = "Yetman";
$areanames{en}->{617750055} = "Yuleba";
$areanames{en}->{617750056} = "Allora";
$areanames{en}->{617750057} = "Aramac";
$areanames{en}->{617750058} = "Arcadia\ Valley";
$areanames{en}->{617750059} = "Atholwood";
$areanames{en}->{617750100} = "Auburn";
$areanames{en}->{617750101} = "Augathella";
$areanames{en}->{617750102} = "Ballandean";
$areanames{en}->{617750103} = "Balonne";
$areanames{en}->{617750104} = "Barcaldine";
$areanames{en}->{617750105} = "Barcoo";
$areanames{en}->{617750106} = "Beebo";
$areanames{en}->{617750107} = "Bell";
$areanames{en}->{617750108} = "Billa\ Billa";
$areanames{en}->{617750109} = "Bimbadeen";
$areanames{en}->{617750110} = "Blackall";
$areanames{en}->{617750111} = "Bollon";
$areanames{en}->{617750112} = "Bonshaw";
$areanames{en}->{617750113} = "Bowenville";
$areanames{en}->{617750114} = "Brigalow";
$areanames{en}->{617750115} = "Bringalily";
$areanames{en}->{617750116} = "Brookstead";
$areanames{en}->{617750117} = "Brymaroo";
$areanames{en}->{617750118} = "Bunya\ Mountains";
$areanames{en}->{617750119} = "Cambooya";
$areanames{en}->{617750120} = "Cecil\ Plains";
$areanames{en}->{617750121} = "Charleville";
$areanames{en}->{617750122} = "Chinchilla";
$areanames{en}->{617750123} = "Clifton";
$areanames{en}->{617750124} = "Cockatoo";
$areanames{en}->{617750125} = "Condamine";
$areanames{en}->{617750126} = "Coondarra";
$areanames{en}->{617750127} = "Cooyar";
$areanames{en}->{617750128} = "Cottonvale";
$areanames{en}->{617750129} = "Crows\ Nest";
$areanames{en}->{617750130} = "Culgoa";
$areanames{en}->{617750131} = "Cunnamulla";
$areanames{en}->{617750132} = "Cunningham";
$areanames{en}->{617750133} = "Dalby";
$areanames{en}->{617750134} = "Darr\ Creek";
$areanames{en}->{617750135} = "Diamantina";
$areanames{en}->{617750136} = "Diamondy";
$areanames{en}->{617750137} = "Dirranbandi";
$areanames{en}->{617750138} = "Dulacca";
$areanames{en}->{617750139} = "Dunmore";
$areanames{en}->{617750140} = "Durham\ Downs";
$areanames{en}->{617750141} = "Elbow\ Valley";
$areanames{en}->{617750142} = "Eschol";
$areanames{en}->{617750143} = "Freestone";
$areanames{en}->{617750144} = "Galilee";
$areanames{en}->{617750145} = "Glenhope";
$areanames{en}->{617750146} = "Goombi";
$areanames{en}->{617750147} = "Goombungee";
$areanames{en}->{617750148} = "Goondiwindi";
$areanames{en}->{617750149} = "Greenmount";
$areanames{en}->{617750150} = "Guluguba";
$areanames{en}->{617750151} = "Haddon";
$areanames{en}->{617750152} = "Haden";
$areanames{en}->{617750153} = "Helidon";
$areanames{en}->{617750154} = "Inglewood";
$areanames{en}->{617750155} = "Injune";
$areanames{en}->{617750156} = "Isisford";
$areanames{en}->{617750157} = "Jandowae";
$areanames{en}->{617750158} = "Jericho";
$areanames{en}->{617750159} = "Jimbour";
$areanames{en}->{617750160} = "Jondaryan";
$areanames{en}->{617750161} = "Jundah";
$areanames{en}->{617750162} = "Kilbeggan";
$areanames{en}->{617750163} = "Killarney";
$areanames{en}->{617750164} = "Kumbarilla";
$areanames{en}->{617750165} = "Kupunn";
$areanames{en}->{617750166} = "Legume";
$areanames{en}->{617750167} = "Leyburn";
$areanames{en}->{617750168} = "Liston";
$areanames{en}->{617750169} = "Longreach";
$areanames{en}->{617750170} = "Lynd\ Range";
$areanames{en}->{617750171} = "Macalister";
$areanames{en}->{617750172} = "Maranoa";
$areanames{en}->{617750173} = "Meandarra";
$areanames{en}->{617750174} = "Miamba";
$areanames{en}->{617750175} = "Miles";
$areanames{en}->{617750176} = "Millmerran";
$areanames{en}->{617750177} = "Mitchell";
$areanames{en}->{617750178} = "Moonie";
$areanames{en}->{617750179} = "Morven";
$areanames{en}->{617750180} = "Mount\ Tyson";
$areanames{en}->{617750181} = "Muttaburra";
$areanames{en}->{617750182} = "Nobby";
$areanames{en}->{617750183} = "North\ Star";
$areanames{en}->{617750184} = "Oakey";
$areanames{en}->{617750185} = "Omanama";
$areanames{en}->{617750186} = "Paroo";
$areanames{en}->{617750187} = "Pikedale";
$areanames{en}->{617750188} = "Pittsworth";
$areanames{en}->{617750189} = "Quilpie";
$areanames{en}->{617750190} = "Ravensbourne";
$areanames{en}->{617750191} = "Robinson\ Gorge";
$areanames{en}->{617750192} = "Roma";
$areanames{en}->{617750193} = "Southwood";
$areanames{en}->{617750194} = "St\ George";
$areanames{en}->{617750195} = "Stanthorpe";
$areanames{en}->{617750196} = "Surat";
$areanames{en}->{617750197} = "Tabers";
$areanames{en}->{617750198} = "Talwood";
$areanames{en}->{617750199} = "Tambo";
$areanames{en}->{617750200} = "Tara";
$areanames{en}->{617750201} = "Taroom";
$areanames{en}->{617750202} = "Teelba";
$areanames{en}->{617750203} = "Texas";
$areanames{en}->{617750204} = "Thallon";
$areanames{en}->{617750205} = "Thargomindah";
$areanames{en}->{617750206} = "The\ Gums";
$areanames{en}->{617750207} = "Thomson";
$areanames{en}->{617750208} = "Tipton";
$areanames{en}->{617750209} = "Toobeah";
$areanames{en}->{617750210} = "Toowoomba";
$areanames{en}->{617750211} = "Valley\ Downs";
$areanames{en}->{617750212} = "Wallumbilla";
$areanames{en}->{617750213} = "Wandoan";
$areanames{en}->{617750214} = "Warra";
$areanames{en}->{617750215} = "Warrego";
$areanames{en}->{617750216} = "Warwick";
$areanames{en}->{617750217} = "Westgrove";
$areanames{en}->{617750218} = "Westmar";
$areanames{en}->{617750219} = "Winton";
$areanames{en}->{617750220} = "Wyaga";
$areanames{en}->{617750221} = "Yelarbon";
$areanames{en}->{617750222} = "Yetman";
$areanames{en}->{617750223} = "Yuleba";
$areanames{en}->{617750224} = "Allora";
$areanames{en}->{617750225} = "Aramac";
$areanames{en}->{617750226} = "Arcadia\ Valley";
$areanames{en}->{617750227} = "Atholwood";
$areanames{en}->{617750228} = "Auburn";
$areanames{en}->{617750229} = "Augathella";
$areanames{en}->{61775023} = "Cambooya";
$areanames{en}->{61775024} = "Mitchell";
$areanames{en}->{617750300} = "Ballandean";
$areanames{en}->{617750301} = "Balonne";
$areanames{en}->{617750302} = "Barcaldine";
$areanames{en}->{617750303} = "Barcoo";
$areanames{en}->{617750304} = "Beebo";
$areanames{en}->{617750305} = "Bell";
$areanames{en}->{617750306} = "Billa\ Billa";
$areanames{en}->{617750307} = "Bimbadeen";
$areanames{en}->{617750308} = "Blackall";
$areanames{en}->{617750309} = "Bollon";
$areanames{en}->{617750310} = "Bonshaw";
$areanames{en}->{617750311} = "Bowenville";
$areanames{en}->{617750312} = "Brigalow";
$areanames{en}->{617750313} = "Bringalily";
$areanames{en}->{617750314} = "Brookstead";
$areanames{en}->{617750315} = "Brymaroo";
$areanames{en}->{617750316} = "Bunya\ Mountains";
$areanames{en}->{617750317} = "Cambooya";
$areanames{en}->{617750318} = "Cecil\ Plains";
$areanames{en}->{617750319} = "Charleville";
$areanames{en}->{617750320} = "Chinchilla";
$areanames{en}->{617750321} = "Clifton";
$areanames{en}->{617750322} = "Cockatoo";
$areanames{en}->{617750323} = "Condamine";
$areanames{en}->{617750324} = "Coondarra";
$areanames{en}->{617750325} = "Cooyar";
$areanames{en}->{617750326} = "Cottonvale";
$areanames{en}->{617750327} = "Crows\ Nest";
$areanames{en}->{617750328} = "Culgoa";
$areanames{en}->{617750329} = "Cunnamulla";
$areanames{en}->{617750330} = "Cunningham";
$areanames{en}->{617750331} = "Dalby";
$areanames{en}->{617750332} = "Darr\ Creek";
$areanames{en}->{617750333} = "Diamantina";
$areanames{en}->{617750334} = "Diamondy";
$areanames{en}->{617750335} = "Dirranbandi";
$areanames{en}->{617750336} = "Dulacca";
$areanames{en}->{617750337} = "Dunmore";
$areanames{en}->{617750338} = "Durham\ Downs";
$areanames{en}->{617750339} = "Elbow\ Valley";
$areanames{en}->{617750340} = "Eschol";
$areanames{en}->{617750341} = "Freestone";
$areanames{en}->{617750342} = "Galilee";
$areanames{en}->{617750343} = "Glenhope";
$areanames{en}->{617750344} = "Goombi";
$areanames{en}->{617750345} = "Goombungee";
$areanames{en}->{617750346} = "Goondiwindi";
$areanames{en}->{617750347} = "Greenmount";
$areanames{en}->{617750348} = "Guluguba";
$areanames{en}->{617750349} = "Haddon";
$areanames{en}->{617750350} = "Haden";
$areanames{en}->{617750351} = "Helidon";
$areanames{en}->{617750352} = "Inglewood";
$areanames{en}->{617750353} = "Injune";
$areanames{en}->{617750354} = "Isisford";
$areanames{en}->{617750355} = "Jandowae";
$areanames{en}->{617750356} = "Jericho";
$areanames{en}->{617750357} = "Jimbour";
$areanames{en}->{617750358} = "Jondaryan";
$areanames{en}->{617750359} = "Jundah";
$areanames{en}->{617750360} = "Kilbeggan";
$areanames{en}->{617750361} = "Killarney";
$areanames{en}->{617750362} = "Kumbarilla";
$areanames{en}->{617750363} = "Kupunn";
$areanames{en}->{617750364} = "Legume";
$areanames{en}->{617750365} = "Leyburn";
$areanames{en}->{617750366} = "Liston";
$areanames{en}->{617750367} = "Longreach";
$areanames{en}->{617750368} = "Lynd\ Range";
$areanames{en}->{617750369} = "Macalister";
$areanames{en}->{617750370} = "Maranoa";
$areanames{en}->{617750371} = "Meandarra";
$areanames{en}->{617750372} = "Miamba";
$areanames{en}->{617750373} = "Miles";
$areanames{en}->{617750374} = "Millmerran";
$areanames{en}->{617750375} = "Mitchell";
$areanames{en}->{617750376} = "Moonie";
$areanames{en}->{617750377} = "Morven";
$areanames{en}->{617750378} = "Mount\ Tyson";
$areanames{en}->{617750379} = "Muttaburra";
$areanames{en}->{617750380} = "Nobby";
$areanames{en}->{617750381} = "North\ Star";
$areanames{en}->{617750382} = "Oakey";
$areanames{en}->{617750383} = "Omanama";
$areanames{en}->{617750384} = "Paroo";
$areanames{en}->{617750385} = "Pikedale";
$areanames{en}->{617750386} = "Pittsworth";
$areanames{en}->{617750387} = "Quilpie";
$areanames{en}->{617750388} = "Ravensbourne";
$areanames{en}->{617750389} = "Robinson\ Gorge";
$areanames{en}->{617750390} = "Roma";
$areanames{en}->{617750391} = "Southwood";
$areanames{en}->{617750392} = "St\ George";
$areanames{en}->{617750393} = "Stanthorpe";
$areanames{en}->{617750394} = "Surat";
$areanames{en}->{617750395} = "Tabers";
$areanames{en}->{617750396} = "Talwood";
$areanames{en}->{617750397} = "Tambo";
$areanames{en}->{617750398} = "Tara";
$areanames{en}->{617750399} = "Taroom";
$areanames{en}->{617750400} = "Teelba";
$areanames{en}->{617750401} = "Texas";
$areanames{en}->{617750402} = "Thallon";
$areanames{en}->{617750403} = "Thargomindah";
$areanames{en}->{617750404} = "The\ Gums";
$areanames{en}->{617750405} = "Thomson";
$areanames{en}->{617750406} = "Tipton";
$areanames{en}->{617750407} = "Toobeah";
$areanames{en}->{617750408} = "Toowoomba";
$areanames{en}->{617750409} = "Valley\ Downs";
$areanames{en}->{617750410} = "Wallumbilla";
$areanames{en}->{617750411} = "Wandoan";
$areanames{en}->{617750412} = "Warra";
$areanames{en}->{617750413} = "Warrego";
$areanames{en}->{617750414} = "Warwick";
$areanames{en}->{617750415} = "Westgrove";
$areanames{en}->{617750416} = "Westmar";
$areanames{en}->{617750417} = "Winton";
$areanames{en}->{617750418} = "Wyaga";
$areanames{en}->{617750419} = "Yelarbon";
$areanames{en}->{617750420} = "Yetman";
$areanames{en}->{617750421} = "Yuleba";
$areanames{en}->{61775049} = "Bonshaw";
$areanames{en}->{61775060} = "Bunya\ Mountains";
$areanames{en}->{61775079} = "Durham\ Downs";
$areanames{en}->{61775090} = "Inglewood";
$areanames{en}->{61775109} = "Southwood";
$areanames{en}->{61775120} = "Tara";
$areanames{en}->{61775139} = "Haddon";
$areanames{en}->{61775142} = "Ravensbourne";
$areanames{en}->{61775143} = "Valley\ Downs";
$areanames{en}->{61775144} = "Toowoomba";
$areanames{en}->{61851000} = "Broome";
$areanames{en}->{61851001} = "Christmas\ Island";
$areanames{en}->{61851002} = "Cocos\ Island";
$areanames{en}->{61851003} = "Dampier";
$areanames{en}->{61851004} = "De\ Grey";
$areanames{en}->{61851005} = "Derby";
$areanames{en}->{61851006} = "Fitzroy\ Crossing";
$areanames{en}->{61851007} = "Great\ Sandy";
$areanames{en}->{61851008} = "Hall\'s\ Creek";
$areanames{en}->{61851009} = "Karratha";
$areanames{en}->{61851010} = "Kununurra";
$areanames{en}->{61851011} = "Leopold";
$areanames{en}->{61851012} = "Marble\ Bar";
$areanames{en}->{61851013} = "Millstream";
$areanames{en}->{61851014} = "Mitchell";
$areanames{en}->{61851015} = "Mount\ Bruce";
$areanames{en}->{61851016} = "Newman";
$areanames{en}->{61851017} = "Onslow";
$areanames{en}->{61851018} = "Ord";
$areanames{en}->{61851019} = "Pannawonica";
$areanames{en}->{61851020} = "Paraburdoo";
$areanames{en}->{61851021} = "Port\ Hedland";
$areanames{en}->{61851022} = "Roebuck";
$areanames{en}->{61851023} = "Sandfire";
$areanames{en}->{61851024} = "Telfer";
$areanames{en}->{61851025} = "Tom\ Price";
$areanames{en}->{61851026} = "Whaleback";
$areanames{en}->{61851027} = "Wittenoom";
$areanames{en}->{61851028} = "Wyndham";
$areanames{en}->{61851029} = "Broome";
$areanames{en}->{61851030} = "Christmas\ Island";
$areanames{en}->{61851031} = "Cocos\ Island";
$areanames{en}->{61851032} = "Dampier";
$areanames{en}->{61851033} = "De\ Grey";
$areanames{en}->{61851034} = "Derby";
$areanames{en}->{61851035} = "Fitzroy\ Crossing";
$areanames{en}->{61851036} = "Great\ Sandy";
$areanames{en}->{61851037} = "Hall\'s\ Creek";
$areanames{en}->{61851038} = "Karratha";
$areanames{en}->{61851039} = "Kununurra";
$areanames{en}->{61851040} = "Leopold";
$areanames{en}->{61851041} = "Marble\ Bar";
$areanames{en}->{61851042} = "Millstream";
$areanames{en}->{61851043} = "Mitchell";
$areanames{en}->{61851044} = "Mount\ Bruce";
$areanames{en}->{61851045} = "Newman";
$areanames{en}->{61851046} = "Onslow";
$areanames{en}->{61851047} = "Ord";
$areanames{en}->{61851048} = "Pannawonica";
$areanames{en}->{61851049} = "Paraburdoo";
$areanames{en}->{61851050} = "Port\ Hedland";
$areanames{en}->{61851051} = "Roebuck";
$areanames{en}->{61851052} = "Sandfire";
$areanames{en}->{61851053} = "Telfer";
$areanames{en}->{61851054} = "Tom\ Price";
$areanames{en}->{61851055} = "Whaleback";
$areanames{en}->{61851056} = "Wittenoom";
$areanames{en}->{61851057} = "Wyndham";
$areanames{en}->{61851058} = "Broome";
$areanames{en}->{61851059} = "Christmas\ Island";
$areanames{en}->{61851060} = "Cocos\ Island";
$areanames{en}->{61851061} = "Dampier";
$areanames{en}->{61851062} = "De\ Grey";
$areanames{en}->{61851063} = "Derby";
$areanames{en}->{61851064} = "Fitzroy\ Crossing";
$areanames{en}->{61851065} = "Great\ Sandy";
$areanames{en}->{61851066} = "Hall\'s\ Creek";
$areanames{en}->{61851067} = "Karratha";
$areanames{en}->{61851068} = "Kununurra";
$areanames{en}->{61851069} = "Leopold";
$areanames{en}->{61851070} = "Marble\ Bar";
$areanames{en}->{61851071} = "Millstream";
$areanames{en}->{61851072} = "Mitchell";
$areanames{en}->{61851073} = "Mount\ Bruce";
$areanames{en}->{61851074} = "Newman";
$areanames{en}->{61851075} = "Onslow";
$areanames{en}->{61851076} = "Ord";
$areanames{en}->{61851077} = "Pannawonica";
$areanames{en}->{61851078} = "Paraburdoo";
$areanames{en}->{61851079} = "Port\ Hedland";
$areanames{en}->{61851080} = "Roebuck";
$areanames{en}->{61851081} = "Sandfire";
$areanames{en}->{61851082} = "Telfer";
$areanames{en}->{61851083} = "Tom\ Price";
$areanames{en}->{61851084} = "Whaleback";
$areanames{en}->{61851085} = "Wittenoom";
$areanames{en}->{61851086} = "Wyndham";
$areanames{en}->{61851087} = "Broome";
$areanames{en}->{61851088} = "Christmas\ Island";
$areanames{en}->{61851089} = "Cocos\ \(Keeling\)\ Island";
$areanames{en}->{61851090} = "Dampier";
$areanames{en}->{61851091} = "De\ Grey";
$areanames{en}->{61851092} = "Derby";
$areanames{en}->{61851093} = "Fitzroy\ Crossing";
$areanames{en}->{61851094} = "Great\ Sandy";
$areanames{en}->{61851095} = "Hall\'s\ Creek";
$areanames{en}->{61851096} = "Karratha";
$areanames{en}->{61851097} = "Kununurra";
$areanames{en}->{61851098} = "Leopold";
$areanames{en}->{61851099} = "Marble\ Bar";
$areanames{en}->{61851100} = "Millstream";
$areanames{en}->{61851101} = "Mitchell";
$areanames{en}->{61851102} = "Mount\ Bruce";
$areanames{en}->{61851103} = "Newman";
$areanames{en}->{61851104} = "Onslow";
$areanames{en}->{61851105} = "Ord";
$areanames{en}->{61851106} = "Pannawonica";
$areanames{en}->{61851107} = "Paraburdoo";
$areanames{en}->{61851108} = "Port\ Hedland";
$areanames{en}->{61851109} = "Roebuck";
$areanames{en}->{61851110} = "Sandfire";
$areanames{en}->{61851111} = "Telfer";
$areanames{en}->{61851112} = "Tom\ Price";
$areanames{en}->{61851113} = "Whaleback";
$areanames{en}->{61851114} = "Wittenoom";
$areanames{en}->{61851115} = "Wyndham";
$areanames{en}->{61851116} = "Broome";
$areanames{en}->{61851117} = "Christmas\ Island";
$areanames{en}->{61851118} = "Cocos\ Island";
$areanames{en}->{61851119} = "Dampier";
$areanames{en}->{61851120} = "De\ Grey";
$areanames{en}->{61851121} = "Derby";
$areanames{en}->{61851122} = "Fitzroy\ Crossing";
$areanames{en}->{61851123} = "Great\ Sandy";
$areanames{en}->{61851124} = "Hall\'s\ Creek";
$areanames{en}->{61851125} = "Karratha";
$areanames{en}->{61851126} = "Kununurra";
$areanames{en}->{61851127} = "Leopold";
$areanames{en}->{61851128} = "Marble\ Bar";
$areanames{en}->{61851129} = "Millstream";
$areanames{en}->{61851130} = "Mitchell";
$areanames{en}->{61851131} = "Mount\ Bruce";
$areanames{en}->{61851132} = "Newman";
$areanames{en}->{61851133} = "Onslow";
$areanames{en}->{61851134} = "Ord";
$areanames{en}->{61851135} = "Pannawonica";
$areanames{en}->{61851136} = "Paraburdoo";
$areanames{en}->{61851137} = "Port\ Hedland";
$areanames{en}->{61851138} = "Roebuck";
$areanames{en}->{61851139} = "Sandfire";
$areanames{en}->{61851140} = "Telfer";
$areanames{en}->{61851141} = "Tom\ Price";
$areanames{en}->{61851142} = "Whaleback";
$areanames{en}->{61851143} = "Wittenoom";
$areanames{en}->{61851144} = "Wyndham";
$areanames{en}->{61851145} = "Broome";
$areanames{en}->{61851146} = "Christmas\ Island";
$areanames{en}->{61851148} = "Dampier";
$areanames{en}->{61851149} = "De\ Grey";
$areanames{en}->{61851150} = "Derby";
$areanames{en}->{61851151} = "Fitzroy\ Crossing";
$areanames{en}->{61851152} = "Great\ Sandy";
$areanames{en}->{61851153} = "Hall\'s\ Creek";
$areanames{en}->{61851154} = "Karratha";
$areanames{en}->{61851155} = "Kununurra";
$areanames{en}->{61851156} = "Leopold";
$areanames{en}->{61851157} = "Marble\ Bar";
$areanames{en}->{61851158} = "Millstream";
$areanames{en}->{61851159} = "Mitchell";
$areanames{en}->{61851160} = "Mount\ Bruce";
$areanames{en}->{61851161} = "Newman";
$areanames{en}->{61851162} = "Onslow";
$areanames{en}->{61851163} = "Ord";
$areanames{en}->{61851164} = "Pannawonica";
$areanames{en}->{61851165} = "Paraburdoo";
$areanames{en}->{61851166} = "Port\ Hedland";
$areanames{en}->{61851167} = "Roebuck";
$areanames{en}->{61851168} = "Sandfire";
$areanames{en}->{61851169} = "Telfer";
$areanames{en}->{61851170} = "Tom\ Price";
$areanames{en}->{61851171} = "Whaleback";
$areanames{en}->{61851172} = "Wittenoom";
$areanames{en}->{61851173} = "Wyndham";
$areanames{en}->{61851174} = "Broome";
$areanames{en}->{61851175} = "Christmas\ Island";
$areanames{en}->{61851177} = "Dampier";
$areanames{en}->{61851178} = "De\ Grey";
$areanames{en}->{61851179} = "Derby";
$areanames{en}->{61851180} = "Fitzroy\ Crossing";
$areanames{en}->{61851181} = "Great\ Sandy";
$areanames{en}->{61851182} = "Hall\'s\ Creek";
$areanames{en}->{61851183} = "Karratha";
$areanames{en}->{61851184} = "Kununurra";
$areanames{en}->{61851185} = "Leopold";
$areanames{en}->{61851186} = "Marble\ Bar";
$areanames{en}->{61851187} = "Millstream";
$areanames{en}->{61851188} = "Mitchell";
$areanames{en}->{61851189} = "Mount\ Bruce";
$areanames{en}->{61851190} = "Newman";
$areanames{en}->{61851191} = "Onslow";
$areanames{en}->{61851192} = "Ord";
$areanames{en}->{61851193} = "Pannawonica";
$areanames{en}->{61851194} = "Paraburdoo";
$areanames{en}->{61851195} = "Port\ Hedland";
$areanames{en}->{61851196} = "Roebuck";
$areanames{en}->{61851197} = "Sandfire";
$areanames{en}->{61851198} = "Telfer";
$areanames{en}->{61851199} = "Tom\ Price";
$areanames{en}->{61851200} = "Whaleback";
$areanames{en}->{61851201} = "Wittenoom";
$areanames{en}->{61851202} = "Wyndham";
$areanames{en}->{61851203} = "Broome";
$areanames{en}->{61851204} = "Christmas\ Island";
$areanames{en}->{61851205} = "Port\ Hedland";
$areanames{en}->{61851206} = "Dampier";
$areanames{en}->{61851207} = "De\ Grey";
$areanames{en}->{61851232} = "Port\ Hedland";
$areanames{en}->{61851233} = "Port\ Hedland";
$areanames{en}->{61851234} = "Broome";
$areanames{en}->{61851235} = "Christmas\ Island";
$areanames{en}->{6185124} = "Karratha";
$areanames{en}->{61851250} = "Newman";
$areanames{en}->{61851251} = "Onslow";
$areanames{en}->{61851252} = "Ord";
$areanames{en}->{61851253} = "Pannawonica";
$areanames{en}->{61851254} = "Paraburdoo";
$areanames{en}->{61851255} = "Paraburdoo";
$areanames{en}->{61851256} = "Paraburdoo";
$areanames{en}->{61851257} = "Paraburdoo";
$areanames{en}->{61851258} = "Port\ Hedland";
$areanames{en}->{61851259} = "Roebuck";
$areanames{en}->{61851260} = "Sandfire";
$areanames{en}->{61851261} = "Telfer";
$areanames{en}->{61851262} = "Tom\ Price";
$areanames{en}->{61851263} = "Whaleback";
$areanames{en}->{61851264} = "Wittenoom";
$areanames{en}->{61851265} = "Wyndham";
$areanames{en}->{61860000} = "Kalgoorlie";
$areanames{en}->{61860001} = "Burracoppin";
$areanames{en}->{61860002} = "Burracoppin";
$areanames{en}->{61860003} = "Grass\ Patch";
$areanames{en}->{61860004} = "Grass\ Patch";
$areanames{en}->{61860005} = "Holleton";
$areanames{en}->{61860006} = "Holleton";
$areanames{en}->{61860007} = "Laverton";
$areanames{en}->{61860008} = "Laverton";
$areanames{en}->{61860009} = "Leinster";
$areanames{en}->{61860010} = "Leinster";
$areanames{en}->{61860011} = "Leonora";
$areanames{en}->{61860012} = "Leonora";
$areanames{en}->{61860013} = "Mount\ Walker\ South";
$areanames{en}->{61860014} = "Mount\ Walker\ South";
$areanames{en}->{61860015} = "Kalgoorlie";
$areanames{en}->{61860016} = "Esperance";
$areanames{en}->{61860017} = "Kalgoorlie";
$areanames{en}->{61860018} = "Kambalda";
$areanames{en}->{618600190} = "Ardath";
$areanames{en}->{618600191} = "Baandee";
$areanames{en}->{618600192} = "Belka\ East";
$areanames{en}->{618600193} = "Bodallin";
$areanames{en}->{618600194} = "Bodallin\ North";
$areanames{en}->{618600195} = "Bonnie\ Rock";
$areanames{en}->{618600196} = "Bruce\ Rock";
$areanames{en}->{618600197} = "Bullaring";
$areanames{en}->{618600198} = "Bullfinch";
$areanames{en}->{618600199} = "Burracoppin";
$areanames{en}->{618600200} = "Burracoppin\ South";
$areanames{en}->{618600201} = "Cascade";
$areanames{en}->{618600202} = "Collurabbie";
$areanames{en}->{618600203} = "Condingup";
$areanames{en}->{618600204} = "Coomalbidgup";
$areanames{en}->{618600205} = "Corrigin";
$areanames{en}->{618600206} = "Corrigin\ West";
$areanames{en}->{618600207} = "Dulyalbin";
$areanames{en}->{618600208} = "Dundas";
$areanames{en}->{618600209} = "Esperance";
$areanames{en}->{61860021} = "Esperance";
$areanames{en}->{61860022} = "Kalgoorlie";
$areanames{en}->{618600230} = "Eyre";
$areanames{en}->{618600231} = "Gibson";
$areanames{en}->{618600232} = "Goldfields";
$areanames{en}->{618600233} = "Goomarin";
$areanames{en}->{618600234} = "Grass\ Patch";
$areanames{en}->{618600235} = "Great\ Victoria";
$areanames{en}->{618600236} = "Holleton";
$areanames{en}->{618600237} = "Kalgoorlie";
$areanames{en}->{618600238} = "Kambalda";
$areanames{en}->{618600239} = "Karloning";
$areanames{en}->{618600240} = "Kellerberrin";
$areanames{en}->{618600241} = "Korbelka";
$areanames{en}->{618600242} = "Laverton";
$areanames{en}->{618600243} = "Leinster";
$areanames{en}->{618600244} = "Leonora";
$areanames{en}->{618600245} = "Marvel\ Loch";
$areanames{en}->{618600246} = "Merredin";
$areanames{en}->{618600247} = "Mount\ Beaumont";
$areanames{en}->{618600248} = "Mount\ Hampton";
$areanames{en}->{618600249} = "Mount\ Merivale";
$areanames{en}->{618600250} = "Mount\ Stirling";
$areanames{en}->{618600251} = "Mount\ Walker\ South";
$areanames{en}->{618600252} = "Mukinbudin";
$areanames{en}->{618600253} = "Munglinup";
$areanames{en}->{618600254} = "Muntadgin\ East";
$areanames{en}->{618600255} = "Narembeen";
$areanames{en}->{618600256} = "Narembeen\ East";
$areanames{en}->{618600257} = "Neridup";
$areanames{en}->{618600258} = "Norseman";
$areanames{en}->{618600259} = "Nullarbor";
$areanames{en}->{618600260} = "Nungarin";
$areanames{en}->{618600261} = "Salmon\ Gums";
$areanames{en}->{618600262} = "Scaddan\ West";
$areanames{en}->{618600263} = "Shackleton";
$areanames{en}->{618600264} = "South\ Kumminin";
$areanames{en}->{618600265} = "Southern\ Cross";
$areanames{en}->{618600266} = "Speddingup\ East";
$areanames{en}->{618600267} = "Warralakin";
$areanames{en}->{618600268} = "Westonia";
$areanames{en}->{618600269} = "Wialki\ North";
$areanames{en}->{618600270} = "Wilgoyne";
$areanames{en}->{618600271} = "Yilgarn\ South";
$areanames{en}->{618600272} = "Ardath";
$areanames{en}->{618600273} = "Baandee";
$areanames{en}->{618600274} = "Belka\ East";
$areanames{en}->{618600275} = "Bodallin";
$areanames{en}->{618600276} = "Bodallin\ North";
$areanames{en}->{618600277} = "Bonnie\ Rock";
$areanames{en}->{618600278} = "Bruce\ Rock";
$areanames{en}->{618600279} = "Bullaring";
$areanames{en}->{61860028} = "Esperance";
$areanames{en}->{61860029} = "Belka\ East";
$areanames{en}->{61860030} = "Bodallin";
$areanames{en}->{61860031} = "Bodallin\ North";
$areanames{en}->{61860032} = "Bonnie\ Rock";
$areanames{en}->{61860033} = "Bruce\ Rock";
$areanames{en}->{61860034} = "Bullaring";
$areanames{en}->{61860035} = "Bullfinch";
$areanames{en}->{61860036} = "Burracoppin";
$areanames{en}->{61860037} = "Burracoppin\ South";
$areanames{en}->{61860038} = "Cascade";
$areanames{en}->{61860039} = "Coomalbidgup";
$areanames{en}->{61860040} = "Corrigin";
$areanames{en}->{61860041} = "Corrigin\ West";
$areanames{en}->{61860042} = "Eyre";
$areanames{en}->{61860043} = "Gibson";
$areanames{en}->{61860044} = "Goldfields";
$areanames{en}->{61860045} = "Goomarin";
$areanames{en}->{61860046} = "Grass\ Patch";
$areanames{en}->{61860047} = "Great\ Victoria";
$areanames{en}->{61860048} = "Holleton";
$areanames{en}->{61860049} = "Korbelka";
$areanames{en}->{61860050} = "Marvel\ Loch";
$areanames{en}->{61860051} = "Mount\ Beaumont";
$areanames{en}->{61860052} = "Mount\ Hampton";
$areanames{en}->{61860053} = "Mount\ Merivale";
$areanames{en}->{61860054} = "Mount\ Stirling";
$areanames{en}->{61860055} = "Mount\ Walker\ South";
$areanames{en}->{61860056} = "Mukinbudin";
$areanames{en}->{61860057} = "Munglinup";
$areanames{en}->{61860058} = "Muntadgin\ East";
$areanames{en}->{61860059} = "Narembeen\ East";
$areanames{en}->{61860060} = "Neridup";
$areanames{en}->{61860061} = "Norseman";
$areanames{en}->{61860062} = "Nullarbor";
$areanames{en}->{61860063} = "Nungarin";
$areanames{en}->{61860064} = "Salmon\ Gums";
$areanames{en}->{61860065} = "Scaddan\ West";
$areanames{en}->{61860066} = "South\ Kumminin";
$areanames{en}->{61860067} = "Southern\ Cross";
$areanames{en}->{61860068} = "Speddingup\ East";
$areanames{en}->{61860069} = "Warralakin";
$areanames{en}->{61860070} = "Wialki\ North";
$areanames{en}->{61860071} = "Wilgoyne";
$areanames{en}->{61860072} = "Yilgarn\ South";
$areanames{en}->{61860073} = "Esperance";
$areanames{en}->{618600740} = "Bullfinch";
$areanames{en}->{618600741} = "Burracoppin";
$areanames{en}->{618600742} = "Burracoppin\ South";
$areanames{en}->{618600743} = "Cascade";
$areanames{en}->{618600744} = "Collurabbie";
$areanames{en}->{618600745} = "Condingup";
$areanames{en}->{618600746} = "Coomalbidgup";
$areanames{en}->{618600747} = "Corrigin";
$areanames{en}->{618600748} = "Corrigin\ West";
$areanames{en}->{618600749} = "Dulyalbin";
$areanames{en}->{618600750} = "Dundas";
$areanames{en}->{618600751} = "Esperance";
$areanames{en}->{618600752} = "Eyre";
$areanames{en}->{618600753} = "Gibson";
$areanames{en}->{618600754} = "Goldfields";
$areanames{en}->{618600755} = "Goomarin";
$areanames{en}->{618600756} = "Grass\ Patch";
$areanames{en}->{618600757} = "Great\ Victoria";
$areanames{en}->{618600758} = "Holleton";
$areanames{en}->{618600759} = "Kalgoorlie";
$areanames{en}->{618600760} = "Kambalda";
$areanames{en}->{618600761} = "Karloning";
$areanames{en}->{618600762} = "Kellerberrin";
$areanames{en}->{618600763} = "Korbelka";
$areanames{en}->{618600764} = "Laverton";
$areanames{en}->{618600765} = "Leinster";
$areanames{en}->{618600766} = "Leonora";
$areanames{en}->{618600767} = "Marvel\ Loch";
$areanames{en}->{618600768} = "Merredin";
$areanames{en}->{618600769} = "Mount\ Beaumont";
$areanames{en}->{618600770} = "Mount\ Hampton";
$areanames{en}->{618600771} = "Mount\ Merivale";
$areanames{en}->{618600772} = "Mount\ Stirling";
$areanames{en}->{618600773} = "Mount\ Walker\ South";
$areanames{en}->{618600774} = "Mukinbudin";
$areanames{en}->{618600775} = "Munglinup";
$areanames{en}->{618600776} = "Muntadgin\ East";
$areanames{en}->{618600777} = "Narembeen";
$areanames{en}->{618600778} = "Narembeen\ East";
$areanames{en}->{618600779} = "Neridup";
$areanames{en}->{618600780} = "Norseman";
$areanames{en}->{618600781} = "Nullarbor";
$areanames{en}->{618600782} = "Nungarin";
$areanames{en}->{618600783} = "Salmon\ Gums";
$areanames{en}->{618600784} = "Scaddan\ West";
$areanames{en}->{618600785} = "Shackleton";
$areanames{en}->{618600786} = "South\ Kumminin";
$areanames{en}->{618600787} = "Southern\ Cross";
$areanames{en}->{618600788} = "Speddingup\ East";
$areanames{en}->{618600789} = "Warralakin";
$areanames{en}->{618600790} = "Westonia";
$areanames{en}->{618600791} = "Wialki\ North";
$areanames{en}->{618600792} = "Wilgoyne";
$areanames{en}->{618600793} = "Yilgarn\ South";
$areanames{en}->{618600794} = "Ardath";
$areanames{en}->{618600795} = "Baandee";
$areanames{en}->{618600796} = "Belka\ East";
$areanames{en}->{618600797} = "Bodallin";
$areanames{en}->{618600798} = "Bodallin\ North";
$areanames{en}->{618600799} = "Bonnie\ Rock";
$areanames{en}->{618600800} = "Bruce\ Rock";
$areanames{en}->{618600801} = "Bullaring";
$areanames{en}->{618600802} = "Bullfinch";
$areanames{en}->{618600803} = "Burracoppin";
$areanames{en}->{618600804} = "Burracoppin\ South";
$areanames{en}->{618600805} = "Cascade";
$areanames{en}->{618600806} = "Collurabbie";
$areanames{en}->{618600807} = "Condingup";
$areanames{en}->{618600808} = "Coomalbidgup";
$areanames{en}->{618600809} = "Corrigin";
$areanames{en}->{618600810} = "Corrigin\ West";
$areanames{en}->{618600811} = "Dulyalbin";
$areanames{en}->{618600812} = "Dundas";
$areanames{en}->{618600813} = "Esperance";
$areanames{en}->{618600814} = "Eyre";
$areanames{en}->{618600815} = "Gibson";
$areanames{en}->{618600816} = "Goldfields";
$areanames{en}->{618600817} = "Goomarin";
$areanames{en}->{618600818} = "Grass\ Patch";
$areanames{en}->{618600819} = "Great\ Victoria";
$areanames{en}->{618600820} = "Holleton";
$areanames{en}->{618600821} = "Kalgoorlie";
$areanames{en}->{618600822} = "Kambalda";
$areanames{en}->{618600823} = "Karloning";
$areanames{en}->{618600824} = "Kellerberrin";
$areanames{en}->{618600825} = "Korbelka";
$areanames{en}->{618600826} = "Laverton";
$areanames{en}->{618600827} = "Leinster";
$areanames{en}->{618600828} = "Leonora";
$areanames{en}->{618600829} = "Marvel\ Loch";
$areanames{en}->{618600830} = "Merredin";
$areanames{en}->{618600831} = "Mount\ Beaumont";
$areanames{en}->{618600832} = "Mount\ Hampton";
$areanames{en}->{618600833} = "Mount\ Merivale";
$areanames{en}->{618600834} = "Mount\ Stirling";
$areanames{en}->{618600835} = "Mount\ Walker\ South";
$areanames{en}->{618600836} = "Mukinbudin";
$areanames{en}->{618600837} = "Munglinup";
$areanames{en}->{618600838} = "Muntadgin\ East";
$areanames{en}->{618600839} = "Narembeen";
$areanames{en}->{618600840} = "Narembeen\ East";
$areanames{en}->{618600841} = "Neridup";
$areanames{en}->{618600842} = "Norseman";
$areanames{en}->{618600843} = "Nullarbor";
$areanames{en}->{618600844} = "Nungarin";
$areanames{en}->{618600845} = "Salmon\ Gums";
$areanames{en}->{618600846} = "Scaddan\ West";
$areanames{en}->{618600847} = "Shackleton";
$areanames{en}->{618600848} = "South\ Kumminin";
$areanames{en}->{618600849} = "Southern\ Cross";
$areanames{en}->{618600850} = "Speddingup\ East";
$areanames{en}->{618600851} = "Warralakin";
$areanames{en}->{618600852} = "Westonia";
$areanames{en}->{618600853} = "Wialki\ North";
$areanames{en}->{618600854} = "Wilgoyne";
$areanames{en}->{618600855} = "Yilgarn\ South";
$areanames{en}->{618600856} = "Ardath";
$areanames{en}->{618600857} = "Baandee";
$areanames{en}->{618600858} = "Belka\ East";
$areanames{en}->{618600859} = "Bodallin";
$areanames{en}->{61860086} = "Merredin";
$areanames{en}->{618600870} = "Bodallin\ North";
$areanames{en}->{618600871} = "Bonnie\ Rock";
$areanames{en}->{618600872} = "Bruce\ Rock";
$areanames{en}->{618600873} = "Bullaring";
$areanames{en}->{618600874} = "Bullfinch";
$areanames{en}->{618600875} = "Burracoppin";
$areanames{en}->{618600876} = "Burracoppin\ South";
$areanames{en}->{618600877} = "Cascade";
$areanames{en}->{618600878} = "Collurabbie";
$areanames{en}->{618600879} = "Condingup";
$areanames{en}->{618600880} = "Coomalbidgup";
$areanames{en}->{618600881} = "Corrigin";
$areanames{en}->{618600882} = "Corrigin\ West";
$areanames{en}->{618600883} = "Dulyalbin";
$areanames{en}->{618600884} = "Dundas";
$areanames{en}->{618600885} = "Esperance";
$areanames{en}->{618600886} = "Eyre";
$areanames{en}->{618600887} = "Gibson";
$areanames{en}->{618600888} = "Goldfields";
$areanames{en}->{618600889} = "Goomarin";
$areanames{en}->{618600890} = "Grass\ Patch";
$areanames{en}->{618600891} = "Great\ Victoria";
$areanames{en}->{618600892} = "Holleton";
$areanames{en}->{618600893} = "Kalgoorlie";
$areanames{en}->{618600894} = "Kambalda";
$areanames{en}->{618600895} = "Karloning";
$areanames{en}->{618600896} = "Kellerberrin";
$areanames{en}->{618600897} = "Korbelka";
$areanames{en}->{618600898} = "Laverton";
$areanames{en}->{618600899} = "Leinster";
$areanames{en}->{618600900} = "Leonora";
$areanames{en}->{618600901} = "Marvel\ Loch";
$areanames{en}->{618600902} = "Merredin";
$areanames{en}->{618600903} = "Mount\ Beaumont";
$areanames{en}->{618600904} = "Mount\ Hampton";
$areanames{en}->{618600905} = "Mount\ Merivale";
$areanames{en}->{618600906} = "Mount\ Stirling";
$areanames{en}->{618600907} = "Mount\ Walker\ South";
$areanames{en}->{618600908} = "Mukinbudin";
$areanames{en}->{618600909} = "Munglinup";
$areanames{en}->{618600910} = "Muntadgin\ East";
$areanames{en}->{618600911} = "Narembeen";
$areanames{en}->{618600912} = "Narembeen\ East";
$areanames{en}->{618600913} = "Neridup";
$areanames{en}->{618600914} = "Norseman";
$areanames{en}->{618600915} = "Nullarbor";
$areanames{en}->{618600916} = "Nungarin";
$areanames{en}->{618600917} = "Salmon\ Gums";
$areanames{en}->{618600918} = "Scaddan\ West";
$areanames{en}->{618600919} = "Shackleton";
$areanames{en}->{618600920} = "South\ Kumminin";
$areanames{en}->{618600921} = "Southern\ Cross";
$areanames{en}->{618600922} = "Speddingup\ East";
$areanames{en}->{618600923} = "Warralakin";
$areanames{en}->{618600924} = "Westonia";
$areanames{en}->{618600925} = "Wialki\ North";
$areanames{en}->{618600926} = "Wilgoyne";
$areanames{en}->{618600927} = "Yilgarn\ South";
$areanames{en}->{618600928} = "Ardath";
$areanames{en}->{618600929} = "Baandee";
$areanames{en}->{618600930} = "Belka\ East";
$areanames{en}->{618600931} = "Bodallin";
$areanames{en}->{618600932} = "Bodallin\ North";
$areanames{en}->{618600933} = "Bonnie\ Rock";
$areanames{en}->{618600934} = "Bruce\ Rock";
$areanames{en}->{618600935} = "Bullaring";
$areanames{en}->{618600936} = "Bullfinch";
$areanames{en}->{618600937} = "Burracoppin";
$areanames{en}->{618600938} = "Burracoppin\ South";
$areanames{en}->{618600939} = "Cascade";
$areanames{en}->{618600940} = "Collurabbie";
$areanames{en}->{618600941} = "Condingup";
$areanames{en}->{618600942} = "Coomalbidgup";
$areanames{en}->{618600943} = "Corrigin";
$areanames{en}->{618600944} = "Corrigin\ West";
$areanames{en}->{618600945} = "Dulyalbin";
$areanames{en}->{618600946} = "Dundas";
$areanames{en}->{618600947} = "Esperance";
$areanames{en}->{618600948} = "Eyre";
$areanames{en}->{618600949} = "Gibson";
$areanames{en}->{618600950} = "Goldfields";
$areanames{en}->{618600951} = "Goomarin";
$areanames{en}->{618600952} = "Grass\ Patch";
$areanames{en}->{618600953} = "Great\ Victoria";
$areanames{en}->{618600954} = "Holleton";
$areanames{en}->{618600955} = "Kalgoorlie";
$areanames{en}->{618600956} = "Kambalda";
$areanames{en}->{618600957} = "Karloning";
$areanames{en}->{618600958} = "Kellerberrin";
$areanames{en}->{618600959} = "Korbelka";
$areanames{en}->{618600960} = "Laverton";
$areanames{en}->{618600961} = "Leinster";
$areanames{en}->{618600962} = "Leonora";
$areanames{en}->{618600963} = "Marvel\ Loch";
$areanames{en}->{618600964} = "Merredin";
$areanames{en}->{618600965} = "Mount\ Beaumont";
$areanames{en}->{618600966} = "Mount\ Hampton";
$areanames{en}->{618600967} = "Mount\ Merivale";
$areanames{en}->{618600968} = "Mount\ Stirling";
$areanames{en}->{618600969} = "Mount\ Walker\ South";
$areanames{en}->{618600970} = "Mukinbudin";
$areanames{en}->{618600971} = "Munglinup";
$areanames{en}->{618600972} = "Muntadgin\ East";
$areanames{en}->{618600973} = "Narembeen";
$areanames{en}->{618600974} = "Narembeen\ East";
$areanames{en}->{618600975} = "Neridup";
$areanames{en}->{618600976} = "Norseman";
$areanames{en}->{618600977} = "Nullarbor";
$areanames{en}->{618600978} = "Nungarin";
$areanames{en}->{618600979} = "Salmon\ Gums";
$areanames{en}->{618600980} = "Scaddan\ West";
$areanames{en}->{618600981} = "Shackleton";
$areanames{en}->{618600982} = "South\ Kumminin";
$areanames{en}->{618600983} = "Southern\ Cross";
$areanames{en}->{618600984} = "Speddingup\ East";
$areanames{en}->{618600985} = "Warralakin";
$areanames{en}->{618600986} = "Westonia";
$areanames{en}->{618600987} = "Wialki\ North";
$areanames{en}->{618600988} = "Wilgoyne";
$areanames{en}->{618600989} = "Yilgarn\ South";
$areanames{en}->{618600990} = "Ardath";
$areanames{en}->{618600991} = "Baandee";
$areanames{en}->{618600992} = "Belka\ East";
$areanames{en}->{618600993} = "Bodallin";
$areanames{en}->{618600994} = "Bodallin\ North";
$areanames{en}->{618600995} = "Bonnie\ Rock";
$areanames{en}->{618600996} = "Bruce\ Rock";
$areanames{en}->{618600997} = "Bullaring";
$areanames{en}->{618600998} = "Bullfinch";
$areanames{en}->{618600999} = "Burracoppin";
$areanames{en}->{618601000} = "Burracoppin\ South";
$areanames{en}->{618601001} = "Cascade";
$areanames{en}->{618601002} = "Collurabbie";
$areanames{en}->{618601003} = "Condingup";
$areanames{en}->{618601004} = "Coomalbidgup";
$areanames{en}->{618601005} = "Corrigin";
$areanames{en}->{618601006} = "Corrigin\ West";
$areanames{en}->{618601007} = "Dulyalbin";
$areanames{en}->{618601008} = "Dundas";
$areanames{en}->{618601009} = "Esperance";
$areanames{en}->{618601010} = "Eyre";
$areanames{en}->{618601011} = "Gibson";
$areanames{en}->{618601012} = "Goldfields";
$areanames{en}->{618601013} = "Goomarin";
$areanames{en}->{618601014} = "Grass\ Patch";
$areanames{en}->{618601015} = "Great\ Victoria";
$areanames{en}->{618601016} = "Holleton";
$areanames{en}->{618601017} = "Kalgoorlie";
$areanames{en}->{618601018} = "Kambalda";
$areanames{en}->{618601019} = "Karloning";
$areanames{en}->{618601020} = "Kellerberrin";
$areanames{en}->{618601021} = "Korbelka";
$areanames{en}->{618601022} = "Laverton";
$areanames{en}->{618601023} = "Leinster";
$areanames{en}->{618601024} = "Leonora";
$areanames{en}->{618601025} = "Marvel\ Loch";
$areanames{en}->{618601026} = "Merredin";
$areanames{en}->{618601027} = "Mount\ Beaumont";
$areanames{en}->{618601028} = "Mount\ Hampton";
$areanames{en}->{618601029} = "Mount\ Merivale";
$areanames{en}->{618601030} = "Mount\ Stirling";
$areanames{en}->{618601031} = "Mount\ Walker\ South";
$areanames{en}->{618601032} = "Mukinbudin";
$areanames{en}->{618601033} = "Munglinup";
$areanames{en}->{618601034} = "Muntadgin\ East";
$areanames{en}->{618601035} = "Narembeen";
$areanames{en}->{618601036} = "Narembeen\ East";
$areanames{en}->{618601037} = "Neridup";
$areanames{en}->{618601038} = "Norseman";
$areanames{en}->{618601039} = "Nullarbor";
$areanames{en}->{618601040} = "Nungarin";
$areanames{en}->{618601041} = "Salmon\ Gums";
$areanames{en}->{618601042} = "Scaddan\ West";
$areanames{en}->{618601043} = "Shackleton";
$areanames{en}->{618601044} = "South\ Kumminin";
$areanames{en}->{618601045} = "Southern\ Cross";
$areanames{en}->{618601046} = "Speddingup\ East";
$areanames{en}->{618601047} = "Warralakin";
$areanames{en}->{618601048} = "Westonia";
$areanames{en}->{618601049} = "Wialki\ North";
$areanames{en}->{618601050} = "Wilgoyne";
$areanames{en}->{618601051} = "Yilgarn\ South";
$areanames{en}->{618601052} = "Ardath";
$areanames{en}->{618601053} = "Baandee";
$areanames{en}->{618601054} = "Belka\ East";
$areanames{en}->{618601055} = "Bodallin";
$areanames{en}->{618601056} = "Bodallin\ North";
$areanames{en}->{618601057} = "Bonnie\ Rock";
$areanames{en}->{618601058} = "Bruce\ Rock";
$areanames{en}->{618601059} = "Bullaring";
$areanames{en}->{618601060} = "Bullfinch";
$areanames{en}->{618601061} = "Burracoppin";
$areanames{en}->{618601062} = "Burracoppin\ South";
$areanames{en}->{618601063} = "Cascade";
$areanames{en}->{618601064} = "Collurabbie";
$areanames{en}->{618601065} = "Condingup";
$areanames{en}->{618601066} = "Coomalbidgup";
$areanames{en}->{618601067} = "Corrigin";
$areanames{en}->{618601068} = "Corrigin\ West";
$areanames{en}->{618601069} = "Dulyalbin";
$areanames{en}->{618601070} = "Dundas";
$areanames{en}->{618601071} = "Esperance";
$areanames{en}->{618601072} = "Eyre";
$areanames{en}->{618601073} = "Gibson";
$areanames{en}->{618601074} = "Goldfields";
$areanames{en}->{618601075} = "Goomarin";
$areanames{en}->{618601076} = "Grass\ Patch";
$areanames{en}->{618601077} = "Great\ Victoria";
$areanames{en}->{618601078} = "Holleton";
$areanames{en}->{618601079} = "Kalgoorlie";
$areanames{en}->{618601080} = "Kambalda";
$areanames{en}->{618601081} = "Karloning";
$areanames{en}->{618601082} = "Kellerberrin";
$areanames{en}->{618601083} = "Korbelka";
$areanames{en}->{618601084} = "Laverton";
$areanames{en}->{618601085} = "Leinster";
$areanames{en}->{618601086} = "Leonora";
$areanames{en}->{618601087} = "Marvel\ Loch";
$areanames{en}->{618601088} = "Merredin";
$areanames{en}->{618601089} = "Mount\ Beaumont";
$areanames{en}->{618601090} = "Mount\ Hampton";
$areanames{en}->{618601091} = "Mount\ Merivale";
$areanames{en}->{618601092} = "Mount\ Stirling";
$areanames{en}->{618601093} = "Mount\ Walker\ South";
$areanames{en}->{618601094} = "Mukinbudin";
$areanames{en}->{618601095} = "Munglinup";
$areanames{en}->{618601096} = "Muntadgin\ East";
$areanames{en}->{618601097} = "Narembeen";
$areanames{en}->{618601098} = "Narembeen\ East";
$areanames{en}->{618601099} = "Neridup";
$areanames{en}->{618601100} = "Norseman";
$areanames{en}->{618601101} = "Nullarbor";
$areanames{en}->{618601102} = "Nungarin";
$areanames{en}->{618601103} = "Salmon\ Gums";
$areanames{en}->{618601104} = "Scaddan\ West";
$areanames{en}->{618601105} = "Shackleton";
$areanames{en}->{618601106} = "South\ Kumminin";
$areanames{en}->{618601107} = "Southern\ Cross";
$areanames{en}->{618601108} = "Speddingup\ East";
$areanames{en}->{618601109} = "Warralakin";
$areanames{en}->{618601110} = "Westonia";
$areanames{en}->{618601111} = "Wialki\ North";
$areanames{en}->{618601112} = "Wilgoyne";
$areanames{en}->{618601113} = "Yilgarn\ South";
$areanames{en}->{618601114} = "Ardath";
$areanames{en}->{618601115} = "Baandee";
$areanames{en}->{618601116} = "Belka\ East";
$areanames{en}->{618601117} = "Bodallin";
$areanames{en}->{618601118} = "Bodallin\ North";
$areanames{en}->{618601119} = "Bonnie\ Rock";
$areanames{en}->{618601120} = "Bruce\ Rock";
$areanames{en}->{618601121} = "Bullaring";
$areanames{en}->{618601122} = "Bullfinch";
$areanames{en}->{618601123} = "Burracoppin";
$areanames{en}->{618601124} = "Burracoppin\ South";
$areanames{en}->{618601125} = "Cascade";
$areanames{en}->{618601126} = "Collurabbie";
$areanames{en}->{618601127} = "Condingup";
$areanames{en}->{618601128} = "Coomalbidgup";
$areanames{en}->{618601129} = "Corrigin";
$areanames{en}->{618601130} = "Corrigin\ West";
$areanames{en}->{618601131} = "Dulyalbin";
$areanames{en}->{618601132} = "Dundas";
$areanames{en}->{618601133} = "Esperance";
$areanames{en}->{618601134} = "Eyre";
$areanames{en}->{618601135} = "Gibson";
$areanames{en}->{618601136} = "Goldfields";
$areanames{en}->{618601137} = "Goomarin";
$areanames{en}->{618601138} = "Grass\ Patch";
$areanames{en}->{618601139} = "Great\ Victoria";
$areanames{en}->{618601140} = "Holleton";
$areanames{en}->{618601141} = "Kalgoorlie";
$areanames{en}->{618601142} = "Kambalda";
$areanames{en}->{618601143} = "Karloning";
$areanames{en}->{618601144} = "Kellerberrin";
$areanames{en}->{618601145} = "Korbelka";
$areanames{en}->{618601146} = "Laverton";
$areanames{en}->{618601147} = "Leinster";
$areanames{en}->{618601148} = "Leonora";
$areanames{en}->{618601149} = "Marvel\ Loch";
$areanames{en}->{618601150} = "Merredin";
$areanames{en}->{618601151} = "Mount\ Beaumont";
$areanames{en}->{618601152} = "Mount\ Hampton";
$areanames{en}->{618601153} = "Mount\ Merivale";
$areanames{en}->{618601154} = "Mount\ Stirling";
$areanames{en}->{618601155} = "Mount\ Walker\ South";
$areanames{en}->{618601156} = "Mukinbudin";
$areanames{en}->{618601157} = "Munglinup";
$areanames{en}->{618601158} = "Muntadgin\ East";
$areanames{en}->{618601159} = "Narembeen";
$areanames{en}->{618601160} = "Narembeen\ East";
$areanames{en}->{618601161} = "Neridup";
$areanames{en}->{618601162} = "Norseman";
$areanames{en}->{618601163} = "Nullarbor";
$areanames{en}->{618601164} = "Nungarin";
$areanames{en}->{618601165} = "Salmon\ Gums";
$areanames{en}->{618601166} = "Scaddan\ West";
$areanames{en}->{618601167} = "Shackleton";
$areanames{en}->{618601168} = "South\ Kumminin";
$areanames{en}->{618601169} = "Southern\ Cross";
$areanames{en}->{618601170} = "Speddingup\ East";
$areanames{en}->{618601171} = "Warralakin";
$areanames{en}->{618601172} = "Westonia";
$areanames{en}->{618601173} = "Wialki\ North";
$areanames{en}->{618601174} = "Wilgoyne";
$areanames{en}->{618601175} = "Yilgarn\ South";
$areanames{en}->{61860118} = "Southern\ Cross";
$areanames{en}->{61860119} = "Baandee";
$areanames{en}->{61860130} = "Kambalda";
$areanames{en}->{61860149} = "Narembeen";
$areanames{en}->{61860160} = "Collurabbie";
$areanames{en}->{6186100} = "Perth";
$areanames{en}->{6186101} = "Perth";
$areanames{en}->{61861020} = "Perth";
$areanames{en}->{6186103} = "Perth";
$areanames{en}->{6186104} = "Perth";
$areanames{en}->{6186105} = "Perth";
$areanames{en}->{6186106} = "Perth";
$areanames{en}->{6186107} = "Perth";
$areanames{en}->{6186108} = "Wanneroo";
$areanames{en}->{61861090} = "Perth";
$areanames{en}->{61861091} = "Perth";
$areanames{en}->{61861092} = "Perth";
$areanames{en}->{61861093} = "Perth";
$areanames{en}->{61861094} = "Perth";
$areanames{en}->{61861095} = "Perth";
$areanames{en}->{61861096} = "Perth";
$areanames{en}->{61861097} = "Perth";
$areanames{en}->{618611} = "Perth";
$areanames{en}->{61861200} = "Herne\ Hill";
$areanames{en}->{61861201} = "Herne\ Hill";
$areanames{en}->{61861202} = "Herne\ Hill";
$areanames{en}->{61861203} = "Herne\ Hill";
$areanames{en}->{61861402} = "Perth";
$areanames{en}->{6186141} = "Perth";
$areanames{en}->{6186142} = "Perth";
$areanames{en}->{6186143} = "Perth";
$areanames{en}->{6186144} = "Perth";
$areanames{en}->{6186145} = "Perth";
$areanames{en}->{6186146} = "Perth";
$areanames{en}->{61861471} = "Perth";
$areanames{en}->{61861472} = "Perth";
$areanames{en}->{61861473} = "Perth";
$areanames{en}->{61861474} = "Perth";
$areanames{en}->{61861475} = "Perth";
$areanames{en}->{61861476} = "Perth";
$areanames{en}->{61861477} = "Perth";
$areanames{en}->{61861478} = "Perth";
$areanames{en}->{61861479} = "Perth";
$areanames{en}->{6186148} = "Perth";
$areanames{en}->{61861490} = "Perth";
$areanames{en}->{61861491} = "Perth";
$areanames{en}->{61861492} = "Perth";
$areanames{en}->{61861493} = "Perth";
$areanames{en}->{61861494} = "Perth";
$areanames{en}->{61861495} = "Perth";
$areanames{en}->{61861496} = "Perth";
$areanames{en}->{6186150} = "Perth";
$areanames{en}->{6186151} = "Perth";
$areanames{en}->{6186152} = "Perth";
$areanames{en}->{61861530} = "Perth";
$areanames{en}->{61861531} = "Perth";
$areanames{en}->{61861532} = "Perth";
$areanames{en}->{61861533} = "Perth";
$areanames{en}->{61861534} = "Perth";
$areanames{en}->{61861535} = "Perth";
$areanames{en}->{61861536} = "Perth";
$areanames{en}->{6186154} = "Perth";
$areanames{en}->{6186155} = "Perth";
$areanames{en}->{618616} = "Perth";
$areanames{en}->{61861700} = "Rottnest";
$areanames{en}->{61861701} = "Rottnest";
$areanames{en}->{61861702} = "Spearwood";
$areanames{en}->{61861703} = "Spearwood";
$areanames{en}->{61861704} = "Rottnest";
$areanames{en}->{61861705} = "Spearwood";
$areanames{en}->{61861706} = "Rottnest";
$areanames{en}->{61861707} = "Spearwood";
$areanames{en}->{61861708} = "Rottnest";
$areanames{en}->{61861709} = "Spearwood";
$areanames{en}->{61861710} = "Rottnest";
$areanames{en}->{61861711} = "Spearwood";
$areanames{en}->{61861712} = "Rottnest";
$areanames{en}->{61861713} = "Spearwood";
$areanames{en}->{61861736} = "Spearwood";
$areanames{en}->{61861737} = "Spearwood";
$areanames{en}->{61861738} = "Spearwood";
$areanames{en}->{61861739} = "Spearwood";
$areanames{en}->{6186174} = "Spearwood";
$areanames{en}->{61861754} = "Spearwood";
$areanames{en}->{61861794} = "Spearwood";
$areanames{en}->{61861795} = "Spearwood";
$areanames{en}->{61861796} = "Spearwood";
$areanames{en}->{61861797} = "Spearwood";
$areanames{en}->{61861799} = "Spearwood";
$areanames{en}->{6186180} = "Perth";
$areanames{en}->{6186181} = "Perth";
$areanames{en}->{61861820} = "Perth";
$areanames{en}->{6186188} = "Perth";
$areanames{en}->{6186189} = "Perth";
$areanames{en}->{6186190} = "Herne\ Hill";
$areanames{en}->{6186191} = "Spearwood";
$areanames{en}->{61861920} = "Armadale";
$areanames{en}->{61861921} = "Herne\ Hill";
$areanames{en}->{61861922} = "Kalamunda";
$areanames{en}->{61861923} = "Spearwood";
$areanames{en}->{61861924} = "Kalamunda";
$areanames{en}->{61861925} = "Armadale";
$areanames{en}->{61861926} = "Herne\ Hill";
$areanames{en}->{61861927} = "Kalamunda";
$areanames{en}->{61861928} = "Rottnest";
$areanames{en}->{61861929} = "Spearwood";
$areanames{en}->{61861930} = "Spearwood";
$areanames{en}->{61861931} = "Spearwood";
$areanames{en}->{61861932} = "Kalamunda";
$areanames{en}->{61861933} = "Kalamunda";
$areanames{en}->{61861934} = "Kalamunda";
$areanames{en}->{61861935} = "Kalamunda";
$areanames{en}->{61861936} = "Herne\ Hill";
$areanames{en}->{61861937} = "Armadale";
$areanames{en}->{61861938} = "Kalamunda";
$areanames{en}->{61861939} = "Armadale";
$areanames{en}->{6186194} = "Herne\ Hill";
$areanames{en}->{6186195} = "Armadale";
$areanames{en}->{6186196} = "Armadale";
$areanames{en}->{61861970} = "Armadale";
$areanames{en}->{61861971} = "Rottnest";
$areanames{en}->{61861972} = "Kalamunda";
$areanames{en}->{61861973} = "Herne\ Hill";
$areanames{en}->{61861974} = "Rottnest";
$areanames{en}->{61861975} = "Spearwood";
$areanames{en}->{61861976} = "Armadale";
$areanames{en}->{61861977} = "Spearwood";
$areanames{en}->{61861978} = "Herne\ Hill";
$areanames{en}->{61861979} = "Herne\ Hill";
$areanames{en}->{6186198} = "Kalamunda";
$areanames{en}->{6186199} = "Herne\ Hill";
$areanames{en}->{618620} = "Wanneroo";
$areanames{en}->{61862024} = "Perth";
$areanames{en}->{61862025} = "Perth";
$areanames{en}->{61862053} = "Perth";
$areanames{en}->{6186208} = "Perth";
$areanames{en}->{6186210} = "Perth";
$areanames{en}->{6186211} = "Perth";
$areanames{en}->{6186212} = "Perth";
$areanames{en}->{6186213} = "Perth";
$areanames{en}->{6186214} = "Perth";
$areanames{en}->{6186215} = "Fremantle";
$areanames{en}->{6186216} = "Perth";
$areanames{en}->{6186217} = "Perth";
$areanames{en}->{6186218} = "Perth";
$areanames{en}->{61862192} = "Fremantle";
$areanames{en}->{61862193} = "Fremantle";
$areanames{en}->{61862194} = "Fremantle";
$areanames{en}->{61862195} = "Fremantle";
$areanames{en}->{61862196} = "Fremantle";
$areanames{en}->{61862197} = "Fremantle";
$areanames{en}->{61862198} = "Fremantle";
$areanames{en}->{61862199} = "Fremantle";
$areanames{en}->{6186220} = "Perth";
$areanames{en}->{6186221} = "Fremantle";
$areanames{en}->{6186222} = "Perth";
$areanames{en}->{6186223} = "Fremantle";
$areanames{en}->{6186224} = "Perth";
$areanames{en}->{6186225} = "Fremantle";
$areanames{en}->{61862252} = "Perth";
$areanames{en}->{61862259} = "Perth";
$areanames{en}->{6186226} = "Fremantle";
$areanames{en}->{6186227} = "Fremantle";
$areanames{en}->{61862280} = "Perth";
$areanames{en}->{61862281} = "Perth";
$areanames{en}->{6186229} = "Perth";
$areanames{en}->{61862303} = "Perth";
$areanames{en}->{6186231} = "Perth";
$areanames{en}->{6186232} = "Fremantle";
$areanames{en}->{6186233} = "Perth";
$areanames{en}->{61862340} = "Fremantle";
$areanames{en}->{61862341} = "Perth";
$areanames{en}->{61862342} = "Perth";
$areanames{en}->{61862343} = "Fremantle";
$areanames{en}->{61862344} = "Fremantle";
$areanames{en}->{61862345} = "Perth";
$areanames{en}->{61862346} = "Perth";
$areanames{en}->{61862347} = "Fremantle";
$areanames{en}->{61862348} = "Perth";
$areanames{en}->{61862349} = "Fremantle";
$areanames{en}->{61862350} = "Perth";
$areanames{en}->{61862351} = "Fremantle";
$areanames{en}->{61862352} = "Perth";
$areanames{en}->{618624} = "Perth";
$areanames{en}->{6186250} = "Perth";
$areanames{en}->{6186251} = "Perth";
$areanames{en}->{6186252} = "Perth";
$areanames{en}->{6186253} = "Perth";
$areanames{en}->{6186254} = "Perth";
$areanames{en}->{61862550} = "Perth";
$areanames{en}->{61862551} = "Perth";
$areanames{en}->{61862552} = "Perth";
$areanames{en}->{61862553} = "Perth";
$areanames{en}->{61862554} = "Perth";
$areanames{en}->{61862555} = "Perth";
$areanames{en}->{6186258} = "Perth";
$areanames{en}->{6186259} = "Perth";
$areanames{en}->{6186262} = "Perth";
$areanames{en}->{6186263} = "Perth";
$areanames{en}->{6186264} = "Perth";
$areanames{en}->{6186265} = "Perth";
$areanames{en}->{6186269} = "Perth";
$areanames{en}->{6186270} = "Perth";
$areanames{en}->{61862710} = "Perth";
$areanames{en}->{61862711} = "Perth";
$areanames{en}->{61862712} = "Perth";
$areanames{en}->{61862713} = "Perth";
$areanames{en}->{6186272} = "Perth";
$areanames{en}->{6186273} = "Perth";
$areanames{en}->{6186274} = "Perth";
$areanames{en}->{6186275} = "Perth";
$areanames{en}->{6186276} = "Perth";
$areanames{en}->{6186277} = "Perth";
$areanames{en}->{6186278} = "Perth";
$areanames{en}->{6186279} = "Perth";
$areanames{en}->{61862802} = "Perth";
$areanames{en}->{6186281} = "Perth";
$areanames{en}->{6186282} = "Perth";
$areanames{en}->{6186290} = "Armadale";
$areanames{en}->{6186291} = "Herne\ Hill";
$areanames{en}->{6186292} = "Kalamunda";
$areanames{en}->{6186293} = "Kalamunda";
$areanames{en}->{6186294} = "Armadale";
$areanames{en}->{6186295} = "Spearwood";
$areanames{en}->{6186296} = "Herne\ Hill";
$areanames{en}->{6186297} = "Herne\ Hill";
$areanames{en}->{6186298} = "Kalamunda";
$areanames{en}->{61862981} = "Perth";
$areanames{en}->{61862982} = "Perth\/Kalamunda";
$areanames{en}->{6186299} = "Kalamunda";
$areanames{en}->{61863000} = "Wanneroo";
$areanames{en}->{6186304} = "Wanneroo";
$areanames{en}->{61863050} = "Wanneroo";
$areanames{en}->{618631} = "Perth";
$areanames{en}->{6186312} = "Fremantle";
$areanames{en}->{6186320} = "Perth";
$areanames{en}->{6186321} = "Perth";
$areanames{en}->{6186322} = "Perth";
$areanames{en}->{6186323} = "Perth";
$areanames{en}->{6186324} = "Perth";
$areanames{en}->{6186330} = "Perth";
$areanames{en}->{6186331} = "Perth";
$areanames{en}->{6186332} = "Perth";
$areanames{en}->{61863330} = "Perth";
$areanames{en}->{61863331} = "Perth";
$areanames{en}->{61863332} = "Perth";
$areanames{en}->{61863333} = "Fremantle";
$areanames{en}->{61863334} = "Fremantle";
$areanames{en}->{61863360} = "Perth";
$areanames{en}->{61863361} = "Perth";
$areanames{en}->{61863366} = "Perth";
$areanames{en}->{61863367} = "Perth";
$areanames{en}->{61863368} = "Perth";
$areanames{en}->{61863369} = "Perth";
$areanames{en}->{6186350} = "Perth";
$areanames{en}->{61863555} = "Perth";
$areanames{en}->{61863556} = "Perth";
$areanames{en}->{618636} = "Perth";
$areanames{en}->{61863612} = "Armadale";
$areanames{en}->{61863613} = "Herne\ Hill";
$areanames{en}->{61863614} = "Kalamunda";
$areanames{en}->{61863615} = "Rottnest";
$areanames{en}->{61863616} = "Spearwood";
$areanames{en}->{61863617} = "Wanneroo";
$areanames{en}->{6186370} = "Perth";
$areanames{en}->{6186371} = "Perth";
$areanames{en}->{6186372} = "Perth";
$areanames{en}->{6186373} = "Perth";
$areanames{en}->{6186374} = "Perth";
$areanames{en}->{6186375} = "Perth";
$areanames{en}->{6186376} = "Perth";
$areanames{en}->{61863779} = "Perth";
$areanames{en}->{61863780} = "Perth";
$areanames{en}->{61863781} = "Perth";
$areanames{en}->{61863782} = "Perth";
$areanames{en}->{61863783} = "Perth";
$areanames{en}->{61863784} = "Perth";
$areanames{en}->{61863785} = "Perth";
$areanames{en}->{61863786} = "Perth";
$areanames{en}->{61863787} = "Perth";
$areanames{en}->{61863788} = "Perth";
$areanames{en}->{6186380} = "Perth";
$areanames{en}->{6186381} = "Perth";
$areanames{en}->{6186382} = "Perth";
$areanames{en}->{61863831} = "Perth";
$areanames{en}->{61863832} = "Perth";
$areanames{en}->{61863833} = "Perth";
$areanames{en}->{61863834} = "Perth";
$areanames{en}->{61863888} = "Perth";
$areanames{en}->{61863889} = "Perth";
$areanames{en}->{6186389} = "Perth";
$areanames{en}->{6186390} = "Kalamunda";
$areanames{en}->{6186391} = "Armadale";
$areanames{en}->{6186392} = "Spearwood";
$areanames{en}->{6186393} = "Herne\ Hill";
$areanames{en}->{6186394} = "Kalamunda";
$areanames{en}->{6186395} = "Rottnest";
$areanames{en}->{6186396} = "Armadale";
$areanames{en}->{6186397} = "Spearwood";
$areanames{en}->{6186398} = "Herne\ Hill";
$areanames{en}->{6186399} = "Spearwood";
$areanames{en}->{6186400} = "Wanneroo";
$areanames{en}->{61864004} = "Perth";
$areanames{en}->{61864005} = "Perth";
$areanames{en}->{61864006} = "Perth";
$areanames{en}->{6186401} = "Wanneroo";
$areanames{en}->{61864011} = "Rottnest";
$areanames{en}->{61864020} = "Wanneroo";
$areanames{en}->{61864021} = "Wanneroo";
$areanames{en}->{61864022} = "Wanneroo";
$areanames{en}->{61864023} = "Wanneroo";
$areanames{en}->{61864024} = "Wanneroo";
$areanames{en}->{61864025} = "Wanneroo";
$areanames{en}->{6186404} = "Wanneroo";
$areanames{en}->{6186406} = "Wanneroo";
$areanames{en}->{61864141} = "Fremantle";
$areanames{en}->{61864142} = "Fremantle";
$areanames{en}->{61864143} = "Fremantle";
$areanames{en}->{618641440} = "Spearwood";
$areanames{en}->{61864145} = "Fremantle";
$areanames{en}->{618641469} = "Spearwood";
$areanames{en}->{61864147} = "Fremantle";
$areanames{en}->{61864148} = "Fremantle";
$areanames{en}->{61864149} = "Fremantle";
$areanames{en}->{61864150} = "Fremantle";
$areanames{en}->{61864151} = "Fremantle";
$areanames{en}->{6186420} = "Fremantle";
$areanames{en}->{6186424} = "Perth";
$areanames{en}->{6186430} = "Perth";
$areanames{en}->{61864318} = "Perth";
$areanames{en}->{6186436} = "Perth";
$areanames{en}->{6186444} = "Perth";
$areanames{en}->{61864466} = "Perth";
$areanames{en}->{61864467} = "Perth";
$areanames{en}->{6186454} = "Perth";
$areanames{en}->{6186455} = "Perth";
$areanames{en}->{6186456} = "Perth";
$areanames{en}->{6186457} = "Perth";
$areanames{en}->{61864581} = "Perth";
$areanames{en}->{61864582} = "Perth";
$areanames{en}->{61864583} = "Perth";
$areanames{en}->{61864584} = "Perth";
$areanames{en}->{61864585} = "Perth";
$areanames{en}->{61864586} = "Perth";
$areanames{en}->{61864587} = "Perth";
$areanames{en}->{61864588} = "Perth";
$areanames{en}->{61864589} = "Perth";
$areanames{en}->{6186459} = "Perth";
$areanames{en}->{618646} = "Perth";
$areanames{en}->{6186469} = "Kalamunda";
$areanames{en}->{6186477} = "Perth";
$areanames{en}->{6186478} = "Perth";
$areanames{en}->{6186488} = "Perth";
$areanames{en}->{61864890} = "Perth";
$areanames{en}->{61864891} = "Perth";
$areanames{en}->{61864892} = "Perth";
$areanames{en}->{61864900} = "Rottnest";
$areanames{en}->{61864901} = "Herne\ Hill";
$areanames{en}->{61864902} = "Kalamunda";
$areanames{en}->{61864903} = "Armadale";
$areanames{en}->{61864904} = "Spearwood";
$areanames{en}->{61864905} = "Rottnest";
$areanames{en}->{61864906} = "Spearwood";
$areanames{en}->{61864907} = "Armadale";
$areanames{en}->{61864908} = "Kalamunda";
$areanames{en}->{61864909} = "Armadale";
$areanames{en}->{61864910} = "Kalamunda";
$areanames{en}->{61864911} = "Kalamunda";
$areanames{en}->{61864912} = "Armadale";
$areanames{en}->{61864913} = "Herne\ Hill";
$areanames{en}->{61864914} = "Armadale";
$areanames{en}->{61864915} = "Herne\ Hill";
$areanames{en}->{61864916} = "Kalamunda";
$areanames{en}->{61864917} = "Rottnest";
$areanames{en}->{61864918} = "Spearwood";
$areanames{en}->{61864919} = "Armadale";
$areanames{en}->{6186492} = "Herne\ Hill";
$areanames{en}->{61864930} = "Rottnest";
$areanames{en}->{61864931} = "Herne\ Hill";
$areanames{en}->{61864932} = "Kalamunda";
$areanames{en}->{61864933} = "Armadale";
$areanames{en}->{61864934} = "Spearwood";
$areanames{en}->{61864935} = "Rottnest";
$areanames{en}->{61864936} = "Herne\ Hill";
$areanames{en}->{61864937} = "Kalamunda";
$areanames{en}->{61864938} = "Armadale";
$areanames{en}->{61864939} = "Spearwood";
$areanames{en}->{6186494} = "Kalamunda";
$areanames{en}->{61864950} = "Armadale";
$areanames{en}->{61864951} = "Herne\ Hill";
$areanames{en}->{61864952} = "Kalamunda";
$areanames{en}->{61864953} = "Rottnest";
$areanames{en}->{61864954} = "Spearwood";
$areanames{en}->{61864955} = "Herne\ Hill";
$areanames{en}->{61864956} = "Kalamunda";
$areanames{en}->{61864957} = "Rottnest";
$areanames{en}->{61864958} = "Spearwood";
$areanames{en}->{61864959} = "Kalamunda";
$areanames{en}->{6186496} = "Armadale";
$areanames{en}->{61864970} = "Armadale";
$areanames{en}->{61864971} = "Herne\ Hill";
$areanames{en}->{61864972} = "Herne\ Hill";
$areanames{en}->{61864973} = "Herne\ Hill";
$areanames{en}->{61864974} = "Herne\ Hill";
$areanames{en}->{61864975} = "Armadale";
$areanames{en}->{61864976} = "Herne\ Hill";
$areanames{en}->{61864977} = "Kalamunda";
$areanames{en}->{61864978} = "Rottnest";
$areanames{en}->{61864979} = "Spearwood";
$areanames{en}->{61864980} = "Spearwood";
$areanames{en}->{61864981} = "Spearwood";
$areanames{en}->{61864982} = "Spearwood";
$areanames{en}->{61864983} = "Rottnest";
$areanames{en}->{61864984} = "Kalamunda";
$areanames{en}->{61864985} = "Rottnest";
$areanames{en}->{61864986} = "Armadale";
$areanames{en}->{61864987} = "Spearwood";
$areanames{en}->{61864988} = "Herne\ Hill";
$areanames{en}->{61864989} = "Spearwood";
$areanames{en}->{6186499} = "Spearwood";
$areanames{en}->{6186500} = "Perth";
$areanames{en}->{6186507} = "Perth";
$areanames{en}->{6186508} = "Perth";
$areanames{en}->{6186540} = "Perth";
$areanames{en}->{6186550} = "Perth";
$areanames{en}->{6186551} = "Perth";
$areanames{en}->{6186552} = "Perth";
$areanames{en}->{6186553} = "Perth";
$areanames{en}->{6186555} = "Perth";
$areanames{en}->{61865560} = "Perth";
$areanames{en}->{61865561} = "Perth";
$areanames{en}->{61865562} = "Perth";
$areanames{en}->{61865563} = "Perth";
$areanames{en}->{61865564} = "Perth";
$areanames{en}->{61865565} = "Perth";
$areanames{en}->{61865566} = "Perth";
$areanames{en}->{61865567} = "Perth";
$areanames{en}->{6186557} = "Perth";
$areanames{en}->{6186558} = "Perth";
$areanames{en}->{6186559} = "Perth";
$areanames{en}->{61865600} = "Kalamunda";
$areanames{en}->{61865601} = "Kalamunda";
$areanames{en}->{61865602} = "Kalamunda";
$areanames{en}->{61865603} = "Kalamunda";
$areanames{en}->{61865800} = "Armadale";
$areanames{en}->{61865801} = "Armadale";
$areanames{en}->{61865802} = "Armadale";
$areanames{en}->{61865803} = "Armadale";
$areanames{en}->{6186590} = "Spearwood";
$areanames{en}->{6186591} = "Armadale";
$areanames{en}->{6186592} = "Kalamunda";
$areanames{en}->{6186593} = "Spearwood";
$areanames{en}->{61865940} = "Armadale";
$areanames{en}->{61865941} = "Armadale";
$areanames{en}->{61865942} = "Armadale";
$areanames{en}->{61865943} = "Rottnest";
$areanames{en}->{61865944} = "Armadale";
$areanames{en}->{6186595} = "Spearwood";
$areanames{en}->{61866000} = "Yerecoin";
$areanames{en}->{61866001} = "Yerecoin";
$areanames{en}->{61866002} = "Wannamal";
$areanames{en}->{61866003} = "Wannamal";
$areanames{en}->{61866004} = "Watheroo";
$areanames{en}->{61866005} = "Watheroo";
$areanames{en}->{61866006} = "Northam";
$areanames{en}->{618660070} = "Aldersyde";
$areanames{en}->{618660071} = "Badgerin\ Rock";
$areanames{en}->{618660072} = "Badgingarra";
$areanames{en}->{618660073} = "Balkuling";
$areanames{en}->{618660074} = "Ballidu";
$areanames{en}->{618660075} = "Beacon";
$areanames{en}->{618660076} = "Beacon\ North";
$areanames{en}->{618660077} = "Bencubbin";
$areanames{en}->{618660078} = "Beverley";
$areanames{en}->{618660079} = "Beverley\ West";
$areanames{en}->{618660080} = "Bibby\ Springs";
$areanames{en}->{618660081} = "Bidaminna";
$areanames{en}->{618660082} = "Bolgart";
$areanames{en}->{618660083} = "Brookton";
$areanames{en}->{618660084} = "Burakin";
$areanames{en}->{618660085} = "Cadoux";
$areanames{en}->{618660086} = "Calingiri";
$areanames{en}->{618660087} = "Cleary\ North";
$areanames{en}->{618660088} = "Coomallo";
$areanames{en}->{618660089} = "Coomberdale";
$areanames{en}->{618660090} = "Cunderdin";
$areanames{en}->{618660091} = "Cunderdin\ North";
$areanames{en}->{618660092} = "Dale\ River";
$areanames{en}->{618660093} = "Dalwallinu";
$areanames{en}->{618660094} = "Dalwallinu\ West";
$areanames{en}->{618660095} = "Dandaragan";
$areanames{en}->{618660096} = "Dangin";
$areanames{en}->{618660097} = "Dowerin";
$areanames{en}->{618660098} = "Dukin";
$areanames{en}->{618660099} = "Ejanding";
$areanames{en}->{618660100} = "Gabbin";
$areanames{en}->{618660101} = "Gabbin\ North";
$areanames{en}->{618660102} = "Gillingarra";
$areanames{en}->{618660103} = "Goodlands";
$areanames{en}->{618660104} = "Goomalling";
$areanames{en}->{618660105} = "Jelkobine";
$areanames{en}->{618660106} = "Jennacubbine";
$areanames{en}->{618660107} = "Jurien";
$areanames{en}->{618660108} = "Kalannie";
$areanames{en}->{618660109} = "Kalannie\ East";
$areanames{en}->{618660110} = "Konnongorring";
$areanames{en}->{618660111} = "Koorda";
$areanames{en}->{618660112} = "Lancelin";
$areanames{en}->{618660113} = "Meckering";
$areanames{en}->{618660114} = "Miling";
$areanames{en}->{618660115} = "Moora";
$areanames{en}->{618660116} = "Northam";
$areanames{en}->{618660117} = "Pantapin";
$areanames{en}->{618660118} = "Paynes\ Find";
$areanames{en}->{618660119} = "Quairading";
$areanames{en}->{618660120} = "Regans\ Ford";
$areanames{en}->{618660121} = "South\ Quairading";
$areanames{en}->{618660122} = "Studleigh";
$areanames{en}->{618660123} = "Talbot\ Brook";
$areanames{en}->{618660124} = "Tammin";
$areanames{en}->{618660125} = "Trayning";
$areanames{en}->{618660126} = "Wannamal";
$areanames{en}->{618660127} = "Watheroo";
$areanames{en}->{618660128} = "Wongan\ Hills";
$areanames{en}->{618660129} = "Wubin";
$areanames{en}->{618660130} = "Wubin\ West";
$areanames{en}->{618660131} = "Wyalkatchem";
$areanames{en}->{618660132} = "Yelbeni";
$areanames{en}->{618660133} = "Yerecoin";
$areanames{en}->{618660134} = "York";
$areanames{en}->{618660135} = "Yorkrakine";
$areanames{en}->{618660136} = "Aldersyde";
$areanames{en}->{618660137} = "Badgerin\ Rock";
$areanames{en}->{618660138} = "Badgingarra";
$areanames{en}->{618660139} = "Balkuling";
$areanames{en}->{61866014} = "Badgerin\ Rock";
$areanames{en}->{61866015} = "Badgingarra";
$areanames{en}->{61866016} = "Beacon";
$areanames{en}->{61866017} = "Beacon\ North";
$areanames{en}->{61866018} = "Bencubbin";
$areanames{en}->{61866019} = "Beverley";
$areanames{en}->{61866020} = "Bibby\ Springs";
$areanames{en}->{61866021} = "Bidaminna";
$areanames{en}->{61866022} = "Bolgart";
$areanames{en}->{61866023} = "Brookton";
$areanames{en}->{61866024} = "Burakin";
$areanames{en}->{61866025} = "Cadoux";
$areanames{en}->{61866026} = "Calingiri";
$areanames{en}->{61866027} = "Cleary\ North";
$areanames{en}->{61866028} = "Coomberdale";
$areanames{en}->{61866029} = "Cunderdin";
$areanames{en}->{61866030} = "Dale\ River";
$areanames{en}->{61866031} = "Dalwallinu";
$areanames{en}->{61866032} = "Dalwallinu\ West";
$areanames{en}->{61866033} = "Dandaragan";
$areanames{en}->{61866034} = "Dangin";
$areanames{en}->{61866035} = "Dowerin";
$areanames{en}->{61866036} = "Dukin";
$areanames{en}->{61866037} = "Gabbin";
$areanames{en}->{61866038} = "Gillingarra";
$areanames{en}->{61866039} = "Goodlands";
$areanames{en}->{61866040} = "Jelkobine";
$areanames{en}->{61866041} = "Jennacubbine";
$areanames{en}->{61866042} = "Jurien";
$areanames{en}->{61866043} = "Kalannie";
$areanames{en}->{61866044} = "Konnongorring";
$areanames{en}->{61866045} = "Koorda";
$areanames{en}->{61866046} = "Meckering";
$areanames{en}->{61866047} = "Miling";
$areanames{en}->{61866048} = "Pantapin";
$areanames{en}->{61866049} = "Quairading";
$areanames{en}->{61866050} = "Regans\ Ford";
$areanames{en}->{61866051} = "South\ Quairading";
$areanames{en}->{61866052} = "Studleigh";
$areanames{en}->{61866053} = "Talbot\ Brook";
$areanames{en}->{61866054} = "Trayning";
$areanames{en}->{61866055} = "Wannamal";
$areanames{en}->{61866056} = "Watheroo";
$areanames{en}->{61866057} = "Wongan\ Hills";
$areanames{en}->{61866058} = "Wubin";
$areanames{en}->{61866059} = "Wubin\ West";
$areanames{en}->{61866060} = "Wyalkatchem";
$areanames{en}->{61866061} = "Yelbeni";
$areanames{en}->{61866062} = "Yerecoin";
$areanames{en}->{61866063} = "Yorkrakine";
$areanames{en}->{61866064} = "Aldersyde";
$areanames{en}->{61866065} = "Lancelin";
$areanames{en}->{61866066} = "Moora";
$areanames{en}->{618660670} = "Ballidu";
$areanames{en}->{618660671} = "Beacon";
$areanames{en}->{618660672} = "Beacon\ North";
$areanames{en}->{618660673} = "Bencubbin";
$areanames{en}->{618660674} = "Beverley";
$areanames{en}->{618660675} = "Beverley\ West";
$areanames{en}->{618660676} = "Bibby\ Springs";
$areanames{en}->{618660677} = "Bidaminna";
$areanames{en}->{618660678} = "Bolgart";
$areanames{en}->{618660679} = "Brookton";
$areanames{en}->{618660680} = "Burakin";
$areanames{en}->{618660681} = "Cadoux";
$areanames{en}->{618660682} = "Calingiri";
$areanames{en}->{618660683} = "Cleary\ North";
$areanames{en}->{618660684} = "Coomallo";
$areanames{en}->{618660685} = "Coomberdale";
$areanames{en}->{618660686} = "Cunderdin";
$areanames{en}->{618660687} = "Cunderdin\ North";
$areanames{en}->{618660688} = "Dale\ River";
$areanames{en}->{618660689} = "Dalwallinu";
$areanames{en}->{618660690} = "Dalwallinu\ West";
$areanames{en}->{618660691} = "Dandaragan";
$areanames{en}->{618660692} = "Dangin";
$areanames{en}->{618660693} = "Dowerin";
$areanames{en}->{618660694} = "Dukin";
$areanames{en}->{618660695} = "Ejanding";
$areanames{en}->{618660696} = "Gabbin";
$areanames{en}->{618660697} = "Gabbin\ North";
$areanames{en}->{618660698} = "Gillingarra";
$areanames{en}->{618660699} = "Goodlands";
$areanames{en}->{618660700} = "Goomalling";
$areanames{en}->{618660701} = "Jelkobine";
$areanames{en}->{618660702} = "Jennacubbine";
$areanames{en}->{618660703} = "Jurien";
$areanames{en}->{618660704} = "Kalannie";
$areanames{en}->{618660705} = "Kalannie\ East";
$areanames{en}->{618660706} = "Konnongorring";
$areanames{en}->{618660707} = "Koorda";
$areanames{en}->{618660708} = "Lancelin";
$areanames{en}->{618660709} = "Meckering";
$areanames{en}->{618660710} = "Miling";
$areanames{en}->{618660711} = "Moora";
$areanames{en}->{618660712} = "Northam";
$areanames{en}->{618660713} = "Pantapin";
$areanames{en}->{618660714} = "Paynes\ Find";
$areanames{en}->{618660715} = "Quairading";
$areanames{en}->{618660716} = "Regans\ Ford";
$areanames{en}->{618660717} = "South\ Quairading";
$areanames{en}->{618660718} = "Studleigh";
$areanames{en}->{618660719} = "Talbot\ Brook";
$areanames{en}->{618660720} = "Tammin";
$areanames{en}->{618660721} = "Trayning";
$areanames{en}->{618660722} = "Wannamal";
$areanames{en}->{618660723} = "Watheroo";
$areanames{en}->{618660724} = "Wongan\ Hills";
$areanames{en}->{618660725} = "Wubin";
$areanames{en}->{618660726} = "Wubin\ West";
$areanames{en}->{618660727} = "Wyalkatchem";
$areanames{en}->{618660728} = "Yelbeni";
$areanames{en}->{618660729} = "Yerecoin";
$areanames{en}->{618660730} = "York";
$areanames{en}->{618660731} = "Yorkrakine";
$areanames{en}->{618660732} = "Aldersyde";
$areanames{en}->{618660733} = "Badgerin\ Rock";
$areanames{en}->{618660734} = "Badgingarra";
$areanames{en}->{618660735} = "Balkuling";
$areanames{en}->{618660736} = "Ballidu";
$areanames{en}->{618660737} = "Beacon";
$areanames{en}->{618660738} = "Beacon\ North";
$areanames{en}->{618660739} = "Bencubbin";
$areanames{en}->{618660740} = "Beverley";
$areanames{en}->{618660741} = "Beverley\ West";
$areanames{en}->{618660742} = "Bibby\ Springs";
$areanames{en}->{618660743} = "Bidaminna";
$areanames{en}->{618660744} = "Bolgart";
$areanames{en}->{618660745} = "Brookton";
$areanames{en}->{618660746} = "Burakin";
$areanames{en}->{618660747} = "Cadoux";
$areanames{en}->{618660748} = "Calingiri";
$areanames{en}->{618660749} = "Cleary\ North";
$areanames{en}->{618660750} = "Coomallo";
$areanames{en}->{618660751} = "Coomberdale";
$areanames{en}->{618660752} = "Cunderdin";
$areanames{en}->{618660753} = "Cunderdin\ North";
$areanames{en}->{618660754} = "Dale\ River";
$areanames{en}->{618660755} = "Dalwallinu";
$areanames{en}->{618660756} = "Dalwallinu\ West";
$areanames{en}->{618660757} = "Dandaragan";
$areanames{en}->{618660758} = "Dangin";
$areanames{en}->{618660759} = "Dowerin";
$areanames{en}->{618660760} = "Dukin";
$areanames{en}->{618660761} = "Ejanding";
$areanames{en}->{618660762} = "Gabbin";
$areanames{en}->{618660763} = "Gabbin\ North";
$areanames{en}->{618660764} = "Gillingarra";
$areanames{en}->{618660765} = "Goodlands";
$areanames{en}->{618660766} = "Goomalling";
$areanames{en}->{618660767} = "Jelkobine";
$areanames{en}->{618660768} = "Jennacubbine";
$areanames{en}->{618660769} = "Jurien";
$areanames{en}->{618660770} = "Kalannie";
$areanames{en}->{618660771} = "Kalannie\ East";
$areanames{en}->{618660772} = "Konnongorring";
$areanames{en}->{618660773} = "Koorda";
$areanames{en}->{618660774} = "Lancelin";
$areanames{en}->{618660775} = "Meckering";
$areanames{en}->{618660776} = "Miling";
$areanames{en}->{618660777} = "Moora";
$areanames{en}->{618660778} = "Northam";
$areanames{en}->{618660779} = "Pantapin";
$areanames{en}->{618660780} = "Quairading";
$areanames{en}->{618660781} = "Regans\ Ford";
$areanames{en}->{618660782} = "South\ Quairading";
$areanames{en}->{618660783} = "Studleigh";
$areanames{en}->{618660784} = "Talbot\ Brook";
$areanames{en}->{618660785} = "Tammin";
$areanames{en}->{618660786} = "Trayning";
$areanames{en}->{618660787} = "Wannamal";
$areanames{en}->{618660788} = "Watheroo";
$areanames{en}->{618660789} = "Wongan\ Hills";
$areanames{en}->{618660790} = "Wubin";
$areanames{en}->{618660791} = "Wubin\ West";
$areanames{en}->{618660792} = "Wyalkatchem";
$areanames{en}->{618660793} = "Yelbeni";
$areanames{en}->{618660794} = "Yerecoin";
$areanames{en}->{618660795} = "York";
$areanames{en}->{618660796} = "Yorkrakine";
$areanames{en}->{618660797} = "Aldersyde";
$areanames{en}->{618660798} = "Badgerin\ Rock";
$areanames{en}->{618660799} = "Badgingarra";
$areanames{en}->{61866080} = "Northam";
$areanames{en}->{61866081} = "Jurien";
$areanames{en}->{61866082} = "Lancelin";
$areanames{en}->{618660830} = "Balkuling";
$areanames{en}->{618660831} = "Ballidu";
$areanames{en}->{618660832} = "Beacon";
$areanames{en}->{618660833} = "Beacon\ North";
$areanames{en}->{618660834} = "Bencubbin";
$areanames{en}->{618660835} = "Beverley";
$areanames{en}->{618660836} = "Beverley\ West";
$areanames{en}->{618660837} = "Bibby\ Springs";
$areanames{en}->{618660838} = "Bidaminna";
$areanames{en}->{618660839} = "Bolgart";
$areanames{en}->{618660840} = "Brookton";
$areanames{en}->{618660841} = "Burakin";
$areanames{en}->{618660842} = "Cadoux";
$areanames{en}->{618660843} = "Calingiri";
$areanames{en}->{618660844} = "Cleary\ North";
$areanames{en}->{618660845} = "Coomallo";
$areanames{en}->{618660846} = "Coomberdale";
$areanames{en}->{618660847} = "Cunderdin";
$areanames{en}->{618660848} = "Cunderdin\ North";
$areanames{en}->{618660849} = "Dale\ River";
$areanames{en}->{618660850} = "Dalwallinu";
$areanames{en}->{618660851} = "Dalwallinu\ West";
$areanames{en}->{618660852} = "Dandaragan";
$areanames{en}->{618660853} = "Dangin";
$areanames{en}->{618660854} = "Dowerin";
$areanames{en}->{618660855} = "Dukin";
$areanames{en}->{618660856} = "Ejanding";
$areanames{en}->{618660857} = "Gabbin";
$areanames{en}->{618660858} = "Gabbin\ North";
$areanames{en}->{618660859} = "Gillingarra";
$areanames{en}->{618660860} = "Goodlands";
$areanames{en}->{618660861} = "Goomalling";
$areanames{en}->{618660862} = "Jelkobine";
$areanames{en}->{618660863} = "Jennacubbine";
$areanames{en}->{618660864} = "Jurien";
$areanames{en}->{618660865} = "Kalannie";
$areanames{en}->{618660866} = "Kalannie\ East";
$areanames{en}->{618660867} = "Konnongorring";
$areanames{en}->{618660868} = "Koorda";
$areanames{en}->{618660869} = "Lancelin";
$areanames{en}->{618660870} = "Meckering";
$areanames{en}->{618660871} = "Miling";
$areanames{en}->{618660872} = "Moora";
$areanames{en}->{618660873} = "Aldersyde";
$areanames{en}->{618660874} = "Badgerin\ Rock";
$areanames{en}->{618660875} = "Badgingarra";
$areanames{en}->{618660876} = "Balkuling";
$areanames{en}->{618660877} = "Ballidu";
$areanames{en}->{618660878} = "Beacon";
$areanames{en}->{618660879} = "Beacon\ North";
$areanames{en}->{618660880} = "Bencubbin";
$areanames{en}->{618660881} = "Beverley";
$areanames{en}->{618660882} = "Beverley\ West";
$areanames{en}->{618660883} = "Bibby\ Springs";
$areanames{en}->{618660884} = "Bidaminna";
$areanames{en}->{618660885} = "Bolgart";
$areanames{en}->{618660886} = "Brookton";
$areanames{en}->{618660887} = "Burakin";
$areanames{en}->{618660888} = "Cadoux";
$areanames{en}->{618660889} = "Calingiri";
$areanames{en}->{618660890} = "Cleary\ North";
$areanames{en}->{618660891} = "Coomallo";
$areanames{en}->{618660892} = "Coomberdale";
$areanames{en}->{618660893} = "Cunderdin";
$areanames{en}->{618660894} = "Cunderdin\ North";
$areanames{en}->{618660895} = "Dale\ River";
$areanames{en}->{618660896} = "Dalwallinu";
$areanames{en}->{618660897} = "Dalwallinu\ West";
$areanames{en}->{618660898} = "Dandaragan";
$areanames{en}->{618660899} = "Dangin";
$areanames{en}->{618660900} = "Dowerin";
$areanames{en}->{618660901} = "Dukin";
$areanames{en}->{618660902} = "Ejanding";
$areanames{en}->{618660903} = "Gabbin";
$areanames{en}->{618660904} = "Gabbin\ North";
$areanames{en}->{618660905} = "Gillingarra";
$areanames{en}->{618660906} = "Goodlands";
$areanames{en}->{618660907} = "Goomalling";
$areanames{en}->{618660908} = "Jelkobine";
$areanames{en}->{618660909} = "Jennacubbine";
$areanames{en}->{618660910} = "Jurien";
$areanames{en}->{618660911} = "Kalannie";
$areanames{en}->{618660912} = "Kalannie\ East";
$areanames{en}->{618660913} = "Konnongorring";
$areanames{en}->{618660914} = "Koorda";
$areanames{en}->{618660915} = "Lancelin";
$areanames{en}->{618660916} = "Meckering";
$areanames{en}->{618660917} = "Miling";
$areanames{en}->{618660918} = "Moora";
$areanames{en}->{618660919} = "Northam";
$areanames{en}->{618660920} = "Pantapin";
$areanames{en}->{618660921} = "Quairading";
$areanames{en}->{618660922} = "Regans\ Ford";
$areanames{en}->{618660923} = "South\ Quairading";
$areanames{en}->{618660924} = "Studleigh";
$areanames{en}->{618660925} = "Talbot\ Brook";
$areanames{en}->{618660926} = "Tammin";
$areanames{en}->{618660927} = "Trayning";
$areanames{en}->{618660928} = "Wannamal";
$areanames{en}->{618660929} = "Watheroo";
$areanames{en}->{618660930} = "Wongan\ Hills";
$areanames{en}->{618660931} = "Wubin";
$areanames{en}->{618660932} = "Wubin\ West";
$areanames{en}->{618660933} = "Wyalkatchem";
$areanames{en}->{618660934} = "Yelbeni";
$areanames{en}->{618660935} = "Yerecoin";
$areanames{en}->{618660936} = "York";
$areanames{en}->{618660937} = "Yorkrakine";
$areanames{en}->{618660938} = "Northam";
$areanames{en}->{618660939} = "Pantapin";
$areanames{en}->{618660940} = "Quairading";
$areanames{en}->{618660941} = "Regans\ Ford";
$areanames{en}->{618660942} = "South\ Quairading";
$areanames{en}->{618660943} = "Studleigh";
$areanames{en}->{618660944} = "Talbot\ Brook";
$areanames{en}->{618660945} = "Tammin";
$areanames{en}->{618660946} = "Trayning";
$areanames{en}->{618660947} = "Wannamal";
$areanames{en}->{618660948} = "Watheroo";
$areanames{en}->{618660949} = "Wongan\ Hills";
$areanames{en}->{618660950} = "Wubin";
$areanames{en}->{618660951} = "Wubin\ West";
$areanames{en}->{618660952} = "Wyalkatchem";
$areanames{en}->{618660953} = "Yelbeni";
$areanames{en}->{618660954} = "Yerecoin";
$areanames{en}->{618660955} = "York";
$areanames{en}->{618660956} = "Yorkrakine";
$areanames{en}->{618660957} = "Aldersyde";
$areanames{en}->{618660958} = "Badgerin\ Rock";
$areanames{en}->{618660959} = "Badgingarra";
$areanames{en}->{618660960} = "Balkuling";
$areanames{en}->{618660961} = "Ballidu";
$areanames{en}->{618660962} = "Beacon";
$areanames{en}->{618660963} = "Beacon\ North";
$areanames{en}->{618660964} = "Bencubbin";
$areanames{en}->{618660965} = "Beverley";
$areanames{en}->{618660966} = "Beverley\ West";
$areanames{en}->{618660967} = "Bibby\ Springs";
$areanames{en}->{618660968} = "Bidaminna";
$areanames{en}->{618660969} = "Bolgart";
$areanames{en}->{618660970} = "Brookton";
$areanames{en}->{618660971} = "Burakin";
$areanames{en}->{618660972} = "Cadoux";
$areanames{en}->{618660973} = "Calingiri";
$areanames{en}->{618660974} = "Cleary\ North";
$areanames{en}->{618660975} = "Coomallo";
$areanames{en}->{618660976} = "Coomberdale";
$areanames{en}->{618660977} = "Cunderdin";
$areanames{en}->{618660978} = "Cunderdin\ North";
$areanames{en}->{618660979} = "Dale\ River";
$areanames{en}->{618660980} = "Dalwallinu";
$areanames{en}->{618660981} = "Dalwallinu\ West";
$areanames{en}->{618660982} = "Dandaragan";
$areanames{en}->{618660983} = "Dangin";
$areanames{en}->{618660984} = "Dowerin";
$areanames{en}->{618660985} = "Dukin";
$areanames{en}->{618660986} = "Ejanding";
$areanames{en}->{618660987} = "Gabbin";
$areanames{en}->{618660988} = "Gabbin\ North";
$areanames{en}->{618660989} = "Gillingarra";
$areanames{en}->{618660990} = "Goodlands";
$areanames{en}->{618660991} = "Goomalling";
$areanames{en}->{618660992} = "Jelkobine";
$areanames{en}->{618660993} = "Jennacubbine";
$areanames{en}->{618660994} = "Jurien";
$areanames{en}->{618660995} = "Kalannie";
$areanames{en}->{618660996} = "Kalannie\ East";
$areanames{en}->{618660997} = "Konnongorring";
$areanames{en}->{618660998} = "Koorda";
$areanames{en}->{618660999} = "Lancelin";
$areanames{en}->{618661000} = "Meckering";
$areanames{en}->{618661001} = "Miling";
$areanames{en}->{618661002} = "Moora";
$areanames{en}->{618661003} = "Northam";
$areanames{en}->{618661004} = "Pantapin";
$areanames{en}->{618661005} = "Quairading";
$areanames{en}->{618661006} = "Regans\ Ford";
$areanames{en}->{618661007} = "South\ Quairading";
$areanames{en}->{618661008} = "Studleigh";
$areanames{en}->{618661009} = "Talbot\ Brook";
$areanames{en}->{618661010} = "Tammin";
$areanames{en}->{618661011} = "Trayning";
$areanames{en}->{618661012} = "Wannamal";
$areanames{en}->{618661013} = "Watheroo";
$areanames{en}->{618661014} = "Wongan\ Hills";
$areanames{en}->{618661015} = "Wubin";
$areanames{en}->{618661016} = "Wubin\ West";
$areanames{en}->{618661017} = "Wyalkatchem";
$areanames{en}->{618661018} = "Yelbeni";
$areanames{en}->{618661019} = "Yerecoin";
$areanames{en}->{618661020} = "York";
$areanames{en}->{618661021} = "Yorkrakine";
$areanames{en}->{618661022} = "Aldersyde";
$areanames{en}->{618661023} = "Badgerin\ Rock";
$areanames{en}->{618661024} = "Badgingarra";
$areanames{en}->{618661025} = "Balkuling";
$areanames{en}->{618661026} = "Ballidu";
$areanames{en}->{618661027} = "Beacon";
$areanames{en}->{618661028} = "Beacon\ North";
$areanames{en}->{618661029} = "Bencubbin";
$areanames{en}->{618661030} = "Beverley";
$areanames{en}->{618661031} = "Beverley\ West";
$areanames{en}->{618661032} = "Bibby\ Springs";
$areanames{en}->{618661033} = "Bidaminna";
$areanames{en}->{618661034} = "Bolgart";
$areanames{en}->{618661035} = "Brookton";
$areanames{en}->{618661036} = "Burakin";
$areanames{en}->{618661037} = "Cadoux";
$areanames{en}->{618661038} = "Calingiri";
$areanames{en}->{618661039} = "Cleary\ North";
$areanames{en}->{618661040} = "Coomallo";
$areanames{en}->{618661041} = "Coomberdale";
$areanames{en}->{618661042} = "Cunderdin";
$areanames{en}->{618661043} = "Cunderdin\ North";
$areanames{en}->{618661044} = "Dale\ River";
$areanames{en}->{618661045} = "Dalwallinu";
$areanames{en}->{618661046} = "Dalwallinu\ West";
$areanames{en}->{618661047} = "Dandaragan";
$areanames{en}->{618661048} = "Dangin";
$areanames{en}->{618661049} = "Dowerin";
$areanames{en}->{618661050} = "Dukin";
$areanames{en}->{618661051} = "Ejanding";
$areanames{en}->{618661052} = "Gabbin";
$areanames{en}->{618661053} = "Gabbin\ North";
$areanames{en}->{618661054} = "Gillingarra";
$areanames{en}->{618661055} = "Goodlands";
$areanames{en}->{618661056} = "Goomalling";
$areanames{en}->{618661057} = "Jelkobine";
$areanames{en}->{618661058} = "Jennacubbine";
$areanames{en}->{618661059} = "Jurien";
$areanames{en}->{618661060} = "Kalannie";
$areanames{en}->{618661061} = "Kalannie\ East";
$areanames{en}->{618661062} = "Konnongorring";
$areanames{en}->{618661063} = "Koorda";
$areanames{en}->{618661064} = "Lancelin";
$areanames{en}->{618661065} = "Meckering";
$areanames{en}->{618661066} = "Miling";
$areanames{en}->{618661067} = "Moora";
$areanames{en}->{618661068} = "Northam";
$areanames{en}->{618661069} = "Pantapin";
$areanames{en}->{618661070} = "Quairading";
$areanames{en}->{618661071} = "Regans\ Ford";
$areanames{en}->{618661072} = "South\ Quairading";
$areanames{en}->{618661073} = "Studleigh";
$areanames{en}->{618661074} = "Talbot\ Brook";
$areanames{en}->{618661075} = "Tammin";
$areanames{en}->{618661076} = "Trayning";
$areanames{en}->{618661077} = "Wannamal";
$areanames{en}->{618661078} = "Watheroo";
$areanames{en}->{618661079} = "Wongan\ Hills";
$areanames{en}->{618661080} = "Wubin";
$areanames{en}->{618661081} = "Wubin\ West";
$areanames{en}->{618661082} = "Wyalkatchem";
$areanames{en}->{618661083} = "Yelbeni";
$areanames{en}->{618661084} = "Yerecoin";
$areanames{en}->{618661085} = "York";
$areanames{en}->{618661086} = "Yorkrakine";
$areanames{en}->{618661087} = "Aldersyde";
$areanames{en}->{618661088} = "Badgerin\ Rock";
$areanames{en}->{618661089} = "Badgingarra";
$areanames{en}->{61866109} = "Cunderdin";
$areanames{en}->{61866110} = "Wongan\ Hills";
$areanames{en}->{618661110} = "Balkuling";
$areanames{en}->{618661111} = "Ballidu";
$areanames{en}->{618661112} = "Beacon";
$areanames{en}->{618661113} = "Beacon\ North";
$areanames{en}->{618661114} = "Bencubbin";
$areanames{en}->{618661115} = "Beverley";
$areanames{en}->{618661116} = "Beverley\ West";
$areanames{en}->{618661117} = "Bibby\ Springs";
$areanames{en}->{618661118} = "Bidaminna";
$areanames{en}->{618661119} = "Bolgart";
$areanames{en}->{618661120} = "Brookton";
$areanames{en}->{618661121} = "Burakin";
$areanames{en}->{618661122} = "Cadoux";
$areanames{en}->{618661123} = "Calingiri";
$areanames{en}->{618661124} = "Cleary\ North";
$areanames{en}->{618661125} = "Coomallo";
$areanames{en}->{618661126} = "Coomberdale";
$areanames{en}->{618661127} = "Cunderdin";
$areanames{en}->{618661128} = "Cunderdin\ North";
$areanames{en}->{618661129} = "Dale\ River";
$areanames{en}->{618661130} = "Dalwallinu";
$areanames{en}->{618661131} = "Dalwallinu\ West";
$areanames{en}->{618661132} = "Dandaragan";
$areanames{en}->{618661133} = "Dangin";
$areanames{en}->{618661134} = "Dowerin";
$areanames{en}->{618661135} = "Dukin";
$areanames{en}->{618661136} = "Ejanding";
$areanames{en}->{618661137} = "Gabbin";
$areanames{en}->{618661138} = "Gabbin\ North";
$areanames{en}->{618661139} = "Gillingarra";
$areanames{en}->{618661140} = "Goodlands";
$areanames{en}->{618661141} = "Goomalling";
$areanames{en}->{618661142} = "Jelkobine";
$areanames{en}->{618661143} = "Jennacubbine";
$areanames{en}->{618661144} = "Jurien";
$areanames{en}->{618661145} = "Kalannie";
$areanames{en}->{618661146} = "Kalannie\ East";
$areanames{en}->{618661147} = "Konnongorring";
$areanames{en}->{618661148} = "Koorda";
$areanames{en}->{618661149} = "Lancelin";
$areanames{en}->{618661150} = "Meckering";
$areanames{en}->{618661151} = "Miling";
$areanames{en}->{618661152} = "Moora";
$areanames{en}->{618661153} = "Northam";
$areanames{en}->{618661154} = "Pantapin";
$areanames{en}->{618661155} = "Paynes\ Find";
$areanames{en}->{618661156} = "Quairading";
$areanames{en}->{618661157} = "Regans\ Ford";
$areanames{en}->{618661158} = "South\ Quairading";
$areanames{en}->{618661159} = "Studleigh";
$areanames{en}->{618661160} = "Talbot\ Brook";
$areanames{en}->{618661161} = "Tammin";
$areanames{en}->{618661162} = "Trayning";
$areanames{en}->{618661163} = "Wannamal";
$areanames{en}->{618661164} = "Watheroo";
$areanames{en}->{618661165} = "Wongan\ Hills";
$areanames{en}->{618661166} = "Wubin";
$areanames{en}->{618661167} = "Wubin\ West";
$areanames{en}->{618661168} = "Wyalkatchem";
$areanames{en}->{618661169} = "Yelbeni";
$areanames{en}->{618661170} = "Yerecoin";
$areanames{en}->{618661171} = "York";
$areanames{en}->{618661172} = "Yorkrakine";
$areanames{en}->{61866118} = "Bibby\ Springs";
$areanames{en}->{61866119} = "Balkuling";
$areanames{en}->{61866130} = "Coomallo";
$areanames{en}->{61866149} = "York";
$areanames{en}->{61866611} = "Dalwallinu";
$areanames{en}->{61866612} = "Northam";
$areanames{en}->{61866613} = "Beverley";
$areanames{en}->{61866614} = "Beverley";
$areanames{en}->{61866615} = "Beverley";
$areanames{en}->{61866616} = "Beverley\ West";
$areanames{en}->{61866617} = "Beverley\ West";
$areanames{en}->{61866618} = "Beverley\ West";
$areanames{en}->{61867000} = "Augusta";
$areanames{en}->{61867001} = "Balingup";
$areanames{en}->{61867002} = "Beedelup";
$areanames{en}->{61867003} = "Boyup\ Brook";
$areanames{en}->{61867004} = "Bridgetown";
$areanames{en}->{61867005} = "Brunswick\ Junction";
$areanames{en}->{61867006} = "Bunbury";
$areanames{en}->{61867007} = "Busselton";
$areanames{en}->{61867008} = "Capel";
$areanames{en}->{61867009} = "Collie";
$areanames{en}->{61867010} = "Cundinup";
$areanames{en}->{61867011} = "Dardanup";
$areanames{en}->{61867012} = "Darkan";
$areanames{en}->{61867013} = "Dinninup";
$areanames{en}->{61867014} = "Dinninup\ North";
$areanames{en}->{61867015} = "Donnybrook";
$areanames{en}->{61867016} = "Harvey";
$areanames{en}->{61867017} = "Jangardup";
$areanames{en}->{61867018} = "Lake\ Clifton";
$areanames{en}->{61867019} = "Manjimup";
$areanames{en}->{61867020} = "Margaret\ River";
$areanames{en}->{61867021} = "Marybrook";
$areanames{en}->{61867022} = "Myalup";
$areanames{en}->{61867023} = "Nannup";
$areanames{en}->{61867024} = "Nyamup";
$areanames{en}->{61867025} = "Pemberton";
$areanames{en}->{61867026} = "Tonebridge";
$areanames{en}->{61867027} = "Upper\ Preston";
$areanames{en}->{61867028} = "Waroona";
$areanames{en}->{61867029} = "Wilga";
$areanames{en}->{61867030} = "Augusta";
$areanames{en}->{61867031} = "Balingup";
$areanames{en}->{61867032} = "Beedelup";
$areanames{en}->{61867033} = "Boyup\ Brook";
$areanames{en}->{61867034} = "Bridgetown";
$areanames{en}->{61867035} = "Brunswick\ Junction";
$areanames{en}->{61867036} = "Bunbury";
$areanames{en}->{61867037} = "Busselton";
$areanames{en}->{61867038} = "Capel";
$areanames{en}->{61867039} = "Collie";
$areanames{en}->{61867040} = "Cundinup";
$areanames{en}->{61867041} = "Dardanup";
$areanames{en}->{61867042} = "Darkan";
$areanames{en}->{61867043} = "Dinninup";
$areanames{en}->{61867044} = "Dinninup\ North";
$areanames{en}->{61867045} = "Donnybrook";
$areanames{en}->{61867046} = "Harvey";
$areanames{en}->{61867047} = "Jangardup";
$areanames{en}->{61867048} = "Lake\ Clifton";
$areanames{en}->{61867049} = "Manjimup";
$areanames{en}->{61867050} = "Margaret\ River";
$areanames{en}->{61867051} = "Marybrook";
$areanames{en}->{61867052} = "Myalup";
$areanames{en}->{61867053} = "Nannup";
$areanames{en}->{61867054} = "Nyamup";
$areanames{en}->{61867055} = "Pemberton";
$areanames{en}->{61867056} = "Tonebridge";
$areanames{en}->{61867057} = "Upper\ Preston";
$areanames{en}->{61867058} = "Waroona";
$areanames{en}->{61867059} = "Wilga";
$areanames{en}->{61867060} = "Augusta";
$areanames{en}->{61867061} = "Balingup";
$areanames{en}->{61867062} = "Beedelup";
$areanames{en}->{61867063} = "Boyup\ Brook";
$areanames{en}->{61867064} = "Bridgetown";
$areanames{en}->{61867065} = "Brunswick\ Junction";
$areanames{en}->{61867066} = "Bunbury";
$areanames{en}->{61867067} = "Busselton";
$areanames{en}->{61867068} = "Capel";
$areanames{en}->{61867069} = "Collie";
$areanames{en}->{61867070} = "Cundinup";
$areanames{en}->{61867071} = "Dardanup";
$areanames{en}->{61867072} = "Darkan";
$areanames{en}->{61867073} = "Dinninup";
$areanames{en}->{61867074} = "Dinninup\ North";
$areanames{en}->{61867075} = "Donnybrook";
$areanames{en}->{61867076} = "Harvey";
$areanames{en}->{61867077} = "Jangardup";
$areanames{en}->{61867078} = "Lake\ Clifton";
$areanames{en}->{61867079} = "Manjimup";
$areanames{en}->{61867080} = "Margaret\ River";
$areanames{en}->{61867081} = "Marybrook";
$areanames{en}->{61867082} = "Myalup";
$areanames{en}->{61867083} = "Nannup";
$areanames{en}->{61867084} = "Nyamup";
$areanames{en}->{61867085} = "Pemberton";
$areanames{en}->{61867086} = "Tonebridge";
$areanames{en}->{61867087} = "Upper\ Preston";
$areanames{en}->{61867088} = "Waroona";
$areanames{en}->{61867089} = "Wilga";
$areanames{en}->{61867090} = "Augusta";
$areanames{en}->{61867091} = "Balingup";
$areanames{en}->{61867092} = "Beedelup";
$areanames{en}->{61867093} = "Boyup\ Brook";
$areanames{en}->{61867094} = "Bridgetown";
$areanames{en}->{61867095} = "Brunswick\ Junction";
$areanames{en}->{61867096} = "Bunbury";
$areanames{en}->{61867097} = "Busselton";
$areanames{en}->{61867098} = "Capel";
$areanames{en}->{61867099} = "Collie";
$areanames{en}->{61867100} = "Cundinup";
$areanames{en}->{61867101} = "Dardanup";
$areanames{en}->{61867102} = "Darkan";
$areanames{en}->{61867103} = "Dinninup";
$areanames{en}->{61867104} = "Dinninup\ North";
$areanames{en}->{61867105} = "Donnybrook";
$areanames{en}->{61867106} = "Harvey";
$areanames{en}->{61867107} = "Jangardup";
$areanames{en}->{61867108} = "Lake\ Clifton";
$areanames{en}->{61867109} = "Manjimup";
$areanames{en}->{61867110} = "Margaret\ River";
$areanames{en}->{61867111} = "Marybrook";
$areanames{en}->{61867112} = "Myalup";
$areanames{en}->{61867113} = "Nannup";
$areanames{en}->{61867114} = "Nyamup";
$areanames{en}->{61867115} = "Pemberton";
$areanames{en}->{61867116} = "Tonebridge";
$areanames{en}->{61867117} = "Upper\ Preston";
$areanames{en}->{61867118} = "Waroona";
$areanames{en}->{61867119} = "Wilga";
$areanames{en}->{61867120} = "Augusta";
$areanames{en}->{61867121} = "Balingup";
$areanames{en}->{61867122} = "Beedelup";
$areanames{en}->{61867123} = "Boyup\ Brook";
$areanames{en}->{61867124} = "Bridgetown";
$areanames{en}->{61867125} = "Brunswick\ Junction";
$areanames{en}->{61867126} = "Bunbury";
$areanames{en}->{61867127} = "Busselton";
$areanames{en}->{61867128} = "Capel";
$areanames{en}->{61867129} = "Collie";
$areanames{en}->{61867130} = "Cundinup";
$areanames{en}->{61867131} = "Dardanup";
$areanames{en}->{61867132} = "Darkan";
$areanames{en}->{61867133} = "Dinninup";
$areanames{en}->{61867134} = "Dinninup\ North";
$areanames{en}->{61867135} = "Donnybrook";
$areanames{en}->{61867136} = "Harvey";
$areanames{en}->{61867137} = "Jangardup";
$areanames{en}->{61867138} = "Lake\ Clifton";
$areanames{en}->{61867139} = "Manjimup";
$areanames{en}->{61867140} = "Margaret\ River";
$areanames{en}->{61867141} = "Marybrook";
$areanames{en}->{61867142} = "Myalup";
$areanames{en}->{61867143} = "Nannup";
$areanames{en}->{61867144} = "Nyamup";
$areanames{en}->{61867145} = "Pemberton";
$areanames{en}->{61867146} = "Tonebridge";
$areanames{en}->{61867147} = "Upper\ Preston";
$areanames{en}->{61867148} = "Waroona";
$areanames{en}->{61867149} = "Wilga";
$areanames{en}->{61867150} = "Busselton";
$areanames{en}->{61867151} = "Marybrook";
$areanames{en}->{61867152} = "Marybrook";
$areanames{en}->{61867153} = "Marybrook";
$areanames{en}->{61867154} = "Augusta";
$areanames{en}->{61867155} = "Balingup";
$areanames{en}->{61867156} = "Beedelup";
$areanames{en}->{61867157} = "Boyup\ Brook";
$areanames{en}->{61867158} = "Bridgetown";
$areanames{en}->{61867159} = "Brunswick\ Junction";
$areanames{en}->{61867160} = "Bunbury";
$areanames{en}->{61867161} = "Busselton";
$areanames{en}->{61867162} = "Capel";
$areanames{en}->{61867163} = "Collie";
$areanames{en}->{61867164} = "Cundinup";
$areanames{en}->{61867165} = "Dardanup";
$areanames{en}->{61867166} = "Darkan";
$areanames{en}->{61867167} = "Dinninup";
$areanames{en}->{61867168} = "Dinninup\ North";
$areanames{en}->{61867169} = "Donnybrook";
$areanames{en}->{61867170} = "Harvey";
$areanames{en}->{61867171} = "Jangardup";
$areanames{en}->{61867172} = "Lake\ Clifton";
$areanames{en}->{61867173} = "Manjimup";
$areanames{en}->{61867174} = "Margaret\ River";
$areanames{en}->{61867175} = "Marybrook";
$areanames{en}->{61867176} = "Myalup";
$areanames{en}->{61867177} = "Nannup";
$areanames{en}->{61867178} = "Nyamup";
$areanames{en}->{61867179} = "Pemberton";
$areanames{en}->{61867180} = "Tonebridge";
$areanames{en}->{61867181} = "Upper\ Preston";
$areanames{en}->{61867182} = "Waroona";
$areanames{en}->{61867183} = "Wilga";
$areanames{en}->{61867184} = "Augusta";
$areanames{en}->{61867185} = "Balingup";
$areanames{en}->{61867186} = "Beedelup";
$areanames{en}->{61867187} = "Boyup\ Brook";
$areanames{en}->{61867188} = "Bridgetown";
$areanames{en}->{61867189} = "Brunswick\ Junction";
$areanames{en}->{61867190} = "Bunbury";
$areanames{en}->{61867191} = "Busselton";
$areanames{en}->{61867192} = "Capel";
$areanames{en}->{61867193} = "Collie";
$areanames{en}->{61867194} = "Cundinup";
$areanames{en}->{61867195} = "Dardanup";
$areanames{en}->{61867196} = "Darkan";
$areanames{en}->{61867197} = "Dinninup";
$areanames{en}->{61867198} = "Dinninup\ North";
$areanames{en}->{61867199} = "Donnybrook";
$areanames{en}->{61867200} = "Harvey";
$areanames{en}->{61867201} = "Jangardup";
$areanames{en}->{61867202} = "Lake\ Clifton";
$areanames{en}->{61867203} = "Manjimup";
$areanames{en}->{61867204} = "Margaret\ River";
$areanames{en}->{61867205} = "Marybrook";
$areanames{en}->{61867206} = "Myalup";
$areanames{en}->{61867207} = "Nannup";
$areanames{en}->{61867208} = "Nyamup";
$areanames{en}->{61867209} = "Pemberton";
$areanames{en}->{61867210} = "Tonebridge";
$areanames{en}->{61867211} = "Upper\ Preston";
$areanames{en}->{61867212} = "Waroona";
$areanames{en}->{61867213} = "Wilga";
$areanames{en}->{61867214} = "Augusta";
$areanames{en}->{61867215} = "Balingup";
$areanames{en}->{61867216} = "Beedelup";
$areanames{en}->{61867217} = "Boyup\ Brook";
$areanames{en}->{61867218} = "Bridgetown";
$areanames{en}->{61867219} = "Brunswick\ Junction";
$areanames{en}->{61867220} = "Bunbury";
$areanames{en}->{61867221} = "Busselton";
$areanames{en}->{61867222} = "Capel";
$areanames{en}->{61867223} = "Collie";
$areanames{en}->{61867224} = "Cundinup";
$areanames{en}->{61867225} = "Dardanup";
$areanames{en}->{61867226} = "Darkan";
$areanames{en}->{61867227} = "Dinninup";
$areanames{en}->{61867228} = "Dinninup\ North";
$areanames{en}->{61867229} = "Donnybrook";
$areanames{en}->{61867230} = "Harvey";
$areanames{en}->{61867231} = "Jangardup";
$areanames{en}->{61867232} = "Lake\ Clifton";
$areanames{en}->{61867233} = "Manjimup";
$areanames{en}->{61867234} = "Margaret\ River";
$areanames{en}->{61867235} = "Marybrook";
$areanames{en}->{61867236} = "Myalup";
$areanames{en}->{61867237} = "Nannup";
$areanames{en}->{61867238} = "Nyamup";
$areanames{en}->{61867239} = "Pemberton";
$areanames{en}->{61867240} = "Tonebridge";
$areanames{en}->{61867241} = "Upper\ Preston";
$areanames{en}->{61867242} = "Waroona";
$areanames{en}->{61867243} = "Wilga";
$areanames{en}->{61867244} = "Busselton";
$areanames{en}->{61867245} = "Marybrook";
$areanames{en}->{618680000} = "Kukerin";
$areanames{en}->{618680003} = "Kukerin";
$areanames{en}->{618680006} = "Kukerin";
$areanames{en}->{618680007} = "Kukerin";
$areanames{en}->{618680008} = "Kukerin";
$areanames{en}->{618680009} = "Albany";
$areanames{en}->{61868001} = "Lake\ Grace";
$areanames{en}->{618680019} = "Amelup";
$areanames{en}->{618680020} = "Lake\ King";
$areanames{en}->{618680023} = "Lake\ King";
$areanames{en}->{618680026} = "Lake\ King";
$areanames{en}->{618680027} = "Lake\ King";
$areanames{en}->{618680028} = "Lake\ King";
$areanames{en}->{618680029} = "Arthur\ River";
$areanames{en}->{618680030} = "Lake\ Magenta";
$areanames{en}->{618680033} = "Lake\ Magenta";
$areanames{en}->{618680036} = "Lake\ Magenta";
$areanames{en}->{618680037} = "Lake\ Magenta";
$areanames{en}->{618680038} = "Lake\ Magenta";
$areanames{en}->{618680039} = "Badgebup";
$areanames{en}->{618680040} = "Moodiarrup";
$areanames{en}->{618680043} = "Moodiarrup";
$areanames{en}->{618680046} = "Moodiarrup";
$areanames{en}->{618680047} = "Moodiarrup";
$areanames{en}->{618680048} = "Moodiarrup";
$areanames{en}->{618680049} = "Katanning";
$areanames{en}->{618680050} = "Moulyinning";
$areanames{en}->{618680053} = "Moulyinning";
$areanames{en}->{618680056} = "Moulyinning";
$areanames{en}->{618680057} = "Moulyinning";
$areanames{en}->{618680058} = "Moulyinning";
$areanames{en}->{618680059} = "Badgebup\ North";
$areanames{en}->{61868006} = "Newdegate";
$areanames{en}->{618680069} = "Beaufort\ River";
$areanames{en}->{618680070} = "Newdegate\ East";
$areanames{en}->{618680073} = "Newdegate\ East";
$areanames{en}->{618680076} = "Newdegate\ East";
$areanames{en}->{618680077} = "Newdegate\ East";
$areanames{en}->{618680078} = "Newdegate\ East";
$areanames{en}->{618680079} = "Bedford\ Harbour";
$areanames{en}->{618680080} = "Newdegate\ North";
$areanames{en}->{618680083} = "Newdegate\ North";
$areanames{en}->{618680086} = "Newdegate\ North";
$areanames{en}->{618680087} = "Newdegate\ North";
$areanames{en}->{618680088} = "Newdegate\ North";
$areanames{en}->{618680089} = "Boddington";
$areanames{en}->{618680090} = "Pingaring";
$areanames{en}->{618680093} = "Pingaring";
$areanames{en}->{618680096} = "Pingaring";
$areanames{en}->{618680097} = "Pingaring";
$areanames{en}->{618680098} = "Pingaring";
$areanames{en}->{618680099} = "Bokerup";
$areanames{en}->{618680100} = "Tarin\ Rock";
$areanames{en}->{618680103} = "Tarin\ Rock";
$areanames{en}->{618680106} = "Tarin\ Rock";
$areanames{en}->{618680107} = "Tarin\ Rock";
$areanames{en}->{618680108} = "Tarin\ Rock";
$areanames{en}->{618680109} = "Borden";
$areanames{en}->{618680110} = "Varley";
$areanames{en}->{618680113} = "Varley";
$areanames{en}->{618680116} = "Varley";
$areanames{en}->{618680117} = "Varley";
$areanames{en}->{618680118} = "Varley";
$areanames{en}->{618680119} = "Boscabel";
$areanames{en}->{61868012} = "Wagin";
$areanames{en}->{618680129} = "Bow\ Bridge";
$areanames{en}->{61868013} = "Cranbrook";
$areanames{en}->{618680139} = "Bradfords";
$areanames{en}->{61868014} = "Jingalup";
$areanames{en}->{61868015} = "Jingalup";
$areanames{en}->{61868016} = "Katanning";
$areanames{en}->{61868017} = "Albany";
$areanames{en}->{61868018} = "Bokerup";
$areanames{en}->{61868019} = "Bow\ Bridge";
$areanames{en}->{61868020} = "Denbarker";
$areanames{en}->{61868021} = "Denmark";
$areanames{en}->{61868022} = "Gnowellen";
$areanames{en}->{61868023} = "Kojaneerup";
$areanames{en}->{61868024} = "Kronkup";
$areanames{en}->{61868025} = "Manypeaks";
$areanames{en}->{61868026} = "Manypeaks\ North";
$areanames{en}->{61868027} = "Mettler";
$areanames{en}->{61868028} = "Mount\ Barker";
$areanames{en}->{61868029} = "Perillup";
$areanames{en}->{61868030} = "Porongurup";
$areanames{en}->{61868031} = "Rocky\ Gully";
$areanames{en}->{61868032} = "Tenterden";
$areanames{en}->{61868033} = "Unicup";
$areanames{en}->{61868034} = "Walpole";
$areanames{en}->{61868035} = "Woogenilup";
$areanames{en}->{61868036} = "Amelup";
$areanames{en}->{61868037} = "Badgebup";
$areanames{en}->{61868038} = "Badgebup\ North";
$areanames{en}->{61868039} = "Bedford\ Harbour";
$areanames{en}->{61868040} = "Borden";
$areanames{en}->{61868041} = "Boscabel";
$areanames{en}->{61868042} = "Bremer\ Bay";
$areanames{en}->{61868043} = "Broomehill";
$areanames{en}->{61868044} = "Cairlocup";
$areanames{en}->{61868045} = "Chittinup";
$areanames{en}->{61868046} = "Congee";
$areanames{en}->{61868047} = "Corackerup";
$areanames{en}->{61868048} = "Cranbrook";
$areanames{en}->{61868049} = "Fitzgerald";
$areanames{en}->{61868050} = "Gairdner";
$areanames{en}->{61868051} = "Gnowangerup";
$areanames{en}->{61868052} = "Hartville";
$areanames{en}->{61868053} = "Hopetoun";
$areanames{en}->{61868054} = "Jacup";
$areanames{en}->{61868055} = "Jerdacuttup";
$areanames{en}->{61868056} = "Jerramungup";
$areanames{en}->{61868057} = "Jingalup";
$areanames{en}->{61868058} = "Katanning";
$areanames{en}->{61868059} = "Kojonup";
$areanames{en}->{61868060} = "Kuringup";
$areanames{en}->{61868061} = "Lake\ Toolbrunup";
$areanames{en}->{61868062} = "Lumeah";
$areanames{en}->{61868063} = "Magitup";
$areanames{en}->{61868064} = "Mount\ Madden";
$areanames{en}->{61868065} = "Muradup";
$areanames{en}->{61868066} = "Nalyerlup";
$areanames{en}->{61868067} = "Nyabing";
$areanames{en}->{61868068} = "Ongerup\ North";
$areanames{en}->{61868069} = "Pingrup";
$areanames{en}->{61868070} = "Pingrup\ East";
$areanames{en}->{61868071} = "Ravensthorpe";
$areanames{en}->{61868072} = "Ravensthorpe\ West";
$areanames{en}->{61868073} = "Tambellup";
$areanames{en}->{61868074} = "West\ River";
$areanames{en}->{61868075} = "Woodanilling";
$areanames{en}->{61868076} = "Dudinin";
$areanames{en}->{61868077} = "Harrismith";
$areanames{en}->{61868078} = "Hyden";
$areanames{en}->{61868079} = "Hyden\ East";
$areanames{en}->{61868080} = "Karlgarin";
$areanames{en}->{61868081} = "Kondinin";
$areanames{en}->{61868082} = "Kulin";
$areanames{en}->{61868083} = "Kulin\ West";
$areanames{en}->{61868084} = "Lake\ Oconnor";
$areanames{en}->{61868085} = "Walyurin";
$areanames{en}->{61868086} = "Wickepin\ East";
$areanames{en}->{61868087} = "Yealering";
$areanames{en}->{61868088} = "Boddington";
$areanames{en}->{61868089} = "Bradfords";
$areanames{en}->{61868090} = "Cuballing";
$areanames{en}->{61868091} = "Narrakine";
$areanames{en}->{61868092} = "Narrogin";
$areanames{en}->{61868093} = "Nomans\ Lake";
$areanames{en}->{61868094} = "Pingelly";
$areanames{en}->{61868095} = "Pingelly\ East";
$areanames{en}->{61868096} = "Pumphreys";
$areanames{en}->{61868097} = "Quindanning";
$areanames{en}->{61868098} = "Tarwonga";
$areanames{en}->{61868099} = "Wickepin";
$areanames{en}->{61868100} = "Williams";
$areanames{en}->{61868101} = "Arthur\ River";
$areanames{en}->{61868102} = "Beaufort\ River";
$areanames{en}->{61868103} = "Dongolocking";
$areanames{en}->{61868104} = "Dumbleyung";
$areanames{en}->{61868105} = "Holland\ Rocks";
$areanames{en}->{61868106} = "Jaloran";
$areanames{en}->{61868107} = "Kukerin";
$areanames{en}->{61868108} = "Lake\ Grace";
$areanames{en}->{61868109} = "Lake\ King";
$areanames{en}->{61868110} = "Lake\ Magenta";
$areanames{en}->{61868111} = "Moodiarrup";
$areanames{en}->{61868112} = "Moulyinning";
$areanames{en}->{61868113} = "Newdegate";
$areanames{en}->{61868114} = "Newdegate\ East";
$areanames{en}->{61868115} = "Newdegate\ North";
$areanames{en}->{61868116} = "Pingaring";
$areanames{en}->{61868117} = "Tarin\ Rock";
$areanames{en}->{61868118} = "Varley";
$areanames{en}->{61868119} = "Wagin";
$areanames{en}->{61868120} = "Albany";
$areanames{en}->{61868121} = "Mount\ Barker";
$areanames{en}->{61868122} = "Manypeaks";
$areanames{en}->{61868123} = "Manypeaks";
$areanames{en}->{61868124} = "Tenterden";
$areanames{en}->{61868125} = "Tenterden";
$areanames{en}->{61868126} = "Bokerup";
$areanames{en}->{61868127} = "Bokerup";
$areanames{en}->{61868128} = "Bow\ Bridge";
$areanames{en}->{61868129} = "Bow\ Bridge";
$areanames{en}->{61868130} = "Denbarker";
$areanames{en}->{61868131} = "Denbarker";
$areanames{en}->{61868132} = "Gnowellen";
$areanames{en}->{61868133} = "Gnowellen";
$areanames{en}->{61868134} = "Kojaneerup";
$areanames{en}->{61868135} = "Kojaneerup";
$areanames{en}->{61868136} = "Kronkup";
$areanames{en}->{61868137} = "Kronkup";
$areanames{en}->{61868138} = "Manypeaks\ North";
$areanames{en}->{61868139} = "Manypeaks\ North";
$areanames{en}->{61868140} = "Mettler";
$areanames{en}->{61868141} = "Mettler";
$areanames{en}->{61868142} = "Perillup";
$areanames{en}->{61868143} = "Perillup";
$areanames{en}->{61868144} = "Rocky\ Gully";
$areanames{en}->{61868145} = "Rocky\ Gully";
$areanames{en}->{61868146} = "Unicup";
$areanames{en}->{61868147} = "Unicup";
$areanames{en}->{61868148} = "Walpole";
$areanames{en}->{61868149} = "Walpole";
$areanames{en}->{61868150} = "Woogenilup";
$areanames{en}->{61868151} = "Woogenilup";
$areanames{en}->{61868152} = "Jaloran";
$areanames{en}->{61868153} = "Jaloran";
$areanames{en}->{61868154} = "Lake\ Grace";
$areanames{en}->{61868155} = "Lake\ Grace";
$areanames{en}->{61868156} = "Moodiarrup";
$areanames{en}->{61868157} = "Moodiarrup";
$areanames{en}->{61868158} = "Moulyinning";
$areanames{en}->{61868159} = "Moulyinning";
$areanames{en}->{61868160} = "Lumeah";
$areanames{en}->{61868161} = "Lumeah";
$areanames{en}->{61868162} = "Hopetoun";
$areanames{en}->{61868163} = "Hopetoun";
$areanames{en}->{61868164} = "Jacup";
$areanames{en}->{61868165} = "Jacup";
$areanames{en}->{61868166} = "Jerdacuttup";
$areanames{en}->{61868167} = "Jerdacuttup";
$areanames{en}->{61868168} = "Jerramungup";
$areanames{en}->{61868169} = "Jerramungup";
$areanames{en}->{61868170} = "Lake\ Magenta";
$areanames{en}->{61868171} = "Lake\ Magenta";
$areanames{en}->{61868172} = "Lake\ Oconnor";
$areanames{en}->{61868173} = "Lake\ Oconnor";
$areanames{en}->{61868174} = "Newdegate";
$areanames{en}->{61868175} = "Newdegate";
$areanames{en}->{61868176} = "Newdegate\ East";
$areanames{en}->{61868177} = "Newdegate\ East";
$areanames{en}->{61868178} = "Newdegate\ North";
$areanames{en}->{61868179} = "Newdegate\ North";
$areanames{en}->{61868180} = "Pingaring";
$areanames{en}->{61868181} = "Pingaring";
$areanames{en}->{61868182} = "Tarin\ Rock";
$areanames{en}->{61868183} = "Tarin\ Rock";
$areanames{en}->{61868184} = "Varley";
$areanames{en}->{61868185} = "Varley";
$areanames{en}->{61868186} = "Albany";
$areanames{en}->{61868187} = "Pingelly";
$areanames{en}->{61868188} = "Katanning";
$areanames{en}->{61868189} = "Hopetoun";
$areanames{en}->{61868190} = "Mettler";
$areanames{en}->{61868191} = "Tenterden";
$areanames{en}->{61868192} = "Denmark";
$areanames{en}->{61868193} = "Denmark";
$areanames{en}->{61868194} = "Denmark";
$areanames{en}->{61868195} = "Albany";
$areanames{en}->{61868196} = "Albany";
$areanames{en}->{61868197} = "Albany";
$areanames{en}->{61868198} = "Katanning";
$areanames{en}->{61868199} = "Denmark";
$areanames{en}->{618682000} = "Bremer\ Bay";
$areanames{en}->{618682001} = "Broomehill";
$areanames{en}->{618682002} = "Cairlocup";
$areanames{en}->{618682003} = "Chittinup";
$areanames{en}->{618682004} = "Congee";
$areanames{en}->{618682005} = "Corackerup";
$areanames{en}->{618682006} = "Cranbrook";
$areanames{en}->{618682007} = "Cuballing";
$areanames{en}->{618682008} = "Denbarker";
$areanames{en}->{618682009} = "Denmark";
$areanames{en}->{61868201} = "Katanning";
$areanames{en}->{61868202} = "Albany";
$areanames{en}->{61868203} = "Albany";
$areanames{en}->{61868204} = "Porongurup";
$areanames{en}->{618682050} = "Dongolocking";
$areanames{en}->{618682051} = "Dudinin";
$areanames{en}->{618682052} = "Dumbleyung";
$areanames{en}->{618682053} = "Fitzgerald";
$areanames{en}->{618682054} = "Gairdner";
$areanames{en}->{618682055} = "Gnowangerup";
$areanames{en}->{618682056} = "Gnowellen";
$areanames{en}->{618682057} = "Harrismith";
$areanames{en}->{618682058} = "Hartville";
$areanames{en}->{618682059} = "Holland\ Rocks";
$areanames{en}->{61868206} = "Pingelly";
$areanames{en}->{61868207} = "Hyden";
$areanames{en}->{61868208} = "Hopetoun";
$areanames{en}->{61868209} = "Ravensthorpe";
$areanames{en}->{61868210} = "Albany";
$areanames{en}->{61868211} = "Albany";
$areanames{en}->{61868212} = "Albany";
$areanames{en}->{61868213} = "Albany";
$areanames{en}->{618682140} = "Hopetoun";
$areanames{en}->{618682141} = "Hyden";
$areanames{en}->{618682142} = "Hyden\ East";
$areanames{en}->{618682143} = "Jacup";
$areanames{en}->{618682144} = "Jaloran";
$areanames{en}->{618682145} = "Jerdacuttup";
$areanames{en}->{618682146} = "Jerramungup";
$areanames{en}->{618682147} = "Jingalup";
$areanames{en}->{618682148} = "Karlgarin";
$areanames{en}->{618682149} = "Katanning";
$areanames{en}->{618682150} = "Kojaneerup";
$areanames{en}->{618682151} = "Kojonup";
$areanames{en}->{618682152} = "Kondinin";
$areanames{en}->{618682153} = "Kronkup";
$areanames{en}->{618682154} = "Kukerin";
$areanames{en}->{618682155} = "Kulin";
$areanames{en}->{618682156} = "Kulin\ West";
$areanames{en}->{618682157} = "Kuringup";
$areanames{en}->{618682158} = "Lake\ Grace";
$areanames{en}->{618682159} = "Lake\ King";
$areanames{en}->{618682160} = "Lake\ Magenta";
$areanames{en}->{618682161} = "Lake\ Oconnor";
$areanames{en}->{618682162} = "Lake\ Toolbrunup";
$areanames{en}->{618682163} = "Lumeah";
$areanames{en}->{618682164} = "Magitup";
$areanames{en}->{618682165} = "Manypeaks";
$areanames{en}->{618682166} = "Manypeaks\ North";
$areanames{en}->{618682167} = "Mettler";
$areanames{en}->{618682168} = "Moodiarrup";
$areanames{en}->{618682169} = "Moulyinning";
$areanames{en}->{618682170} = "Mount\ Barker";
$areanames{en}->{618682171} = "Mount\ Madden";
$areanames{en}->{618682172} = "Muradup";
$areanames{en}->{618682173} = "Nalyerlup";
$areanames{en}->{618682174} = "Narrakine";
$areanames{en}->{618682175} = "Narrogin";
$areanames{en}->{618682176} = "Newdegate";
$areanames{en}->{618682177} = "Newdegate\ East";
$areanames{en}->{618682178} = "Newdegate\ North";
$areanames{en}->{618682179} = "Nomans\ Lake";
$areanames{en}->{618682180} = "Nyabing";
$areanames{en}->{618682181} = "Ongerup\ North";
$areanames{en}->{618682182} = "Perillup";
$areanames{en}->{618682183} = "Pingaring";
$areanames{en}->{618682184} = "Pingelly";
$areanames{en}->{618682185} = "Pingelly\ East";
$areanames{en}->{618682186} = "Pingrup";
$areanames{en}->{618682187} = "Pingrup\ East";
$areanames{en}->{618682188} = "Porongurup";
$areanames{en}->{618682189} = "Pumphreys";
$areanames{en}->{618682190} = "Quindanning";
$areanames{en}->{618682191} = "Ravensthorpe";
$areanames{en}->{618682192} = "Ravensthorpe\ West";
$areanames{en}->{618682193} = "Rocky\ Gully";
$areanames{en}->{618682194} = "Tambellup";
$areanames{en}->{618682195} = "Tarin\ Rock";
$areanames{en}->{618682196} = "Tarwonga";
$areanames{en}->{618682197} = "Tenterden";
$areanames{en}->{618682198} = "Unicup";
$areanames{en}->{618682199} = "Varley";
$areanames{en}->{618682200} = "Wagin";
$areanames{en}->{618682201} = "Walpole";
$areanames{en}->{618682202} = "Walyurin";
$areanames{en}->{618682203} = "West\ River";
$areanames{en}->{618682204} = "Wickepin";
$areanames{en}->{618682205} = "Wickepin\ East";
$areanames{en}->{618682206} = "Williams";
$areanames{en}->{618682207} = "Woodanilling";
$areanames{en}->{618682208} = "Woogenilup";
$areanames{en}->{618682209} = "Yealering";
$areanames{en}->{61868221} = "Kojonup";
$areanames{en}->{61868222} = "Arthur\ River";
$areanames{en}->{61868223} = "Badgebup";
$areanames{en}->{61868224} = "Badgebup\ North";
$areanames{en}->{61868225} = "Beaufort\ River";
$areanames{en}->{61868226} = "Bedford\ Harbour";
$areanames{en}->{61868227} = "Borden";
$areanames{en}->{61868228} = "Boscabel";
$areanames{en}->{61868229} = "Bradfords";
$areanames{en}->{61868230} = "Broomehill";
$areanames{en}->{61868231} = "Hopetoun";
$areanames{en}->{61868232} = "Cairlocup";
$areanames{en}->{61868233} = "Chittinup";
$areanames{en}->{61868234} = "Congee";
$areanames{en}->{61868235} = "Corackerup";
$areanames{en}->{61868236} = "Cranbrook";
$areanames{en}->{61868237} = "Cuballing";
$areanames{en}->{61868238} = "Dongolocking";
$areanames{en}->{61868239} = "Dudinin";
$areanames{en}->{61868240} = "Dumbleyung";
$areanames{en}->{61868241} = "Gairdner";
$areanames{en}->{61868242} = "Gnowangerup";
$areanames{en}->{61868243} = "Hartville";
$areanames{en}->{61868244} = "Holland\ Rocks";
$areanames{en}->{61868245} = "Hyden\ East";
$areanames{en}->{61868246} = "Jacup";
$areanames{en}->{61868247} = "Jaloran";
$areanames{en}->{61868248} = "Jerdacuttup";
$areanames{en}->{61868249} = "Jerramungup";
$areanames{en}->{61868250} = "Jingalup";
$areanames{en}->{61868251} = "Karlgarin";
$areanames{en}->{61868252} = "Kojaneerup";
$areanames{en}->{61868253} = "Kojonup";
$areanames{en}->{61868254} = "Kondinin";
$areanames{en}->{61868255} = "Kronkup";
$areanames{en}->{61868256} = "Kulin";
$areanames{en}->{61868257} = "Kuringup";
$areanames{en}->{61868258} = "Lake\ Grace";
$areanames{en}->{61868259} = "Lake\ King";
$areanames{en}->{61868260} = "Lake\ Magenta";
$areanames{en}->{61868261} = "Lake\ Oconnor";
$areanames{en}->{61868262} = "Lumeah";
$areanames{en}->{61868263} = "Magitup";
$areanames{en}->{61868264} = "Manypeaks";
$areanames{en}->{61868265} = "Manypeaks\ North";
$areanames{en}->{61868266} = "Mettler";
$areanames{en}->{61868267} = "Moulyinning";
$areanames{en}->{61868268} = "Mount\ Madden";
$areanames{en}->{61868269} = "Muradup";
$areanames{en}->{61868270} = "Nalyerlup";
$areanames{en}->{61868271} = "Narrakine";
$areanames{en}->{61868272} = "Newdegate\ East";
$areanames{en}->{61868273} = "Newdegate\ North";
$areanames{en}->{61868274} = "Nomans\ Lake";
$areanames{en}->{61868275} = "Nyabing";
$areanames{en}->{61868276} = "Perillup";
$areanames{en}->{61868277} = "Pingaring";
$areanames{en}->{61868278} = "Pingelly\ East";
$areanames{en}->{61868279} = "Pingrup\ East";
$areanames{en}->{61868280} = "Porongurup";
$areanames{en}->{61868281} = "Pumphreys";
$areanames{en}->{61868282} = "Quindanning";
$areanames{en}->{61868283} = "Ravensthorpe";
$areanames{en}->{61868284} = "Ravensthorpe\ West";
$areanames{en}->{61868285} = "Rocky\ Gully";
$areanames{en}->{61868286} = "Tambellup";
$areanames{en}->{61868287} = "Tarin\ Rock";
$areanames{en}->{61868288} = "Unicup";
$areanames{en}->{61868289} = "Varley";
$areanames{en}->{61868290} = "Wagin";
$areanames{en}->{61868291} = "Walpole";
$areanames{en}->{61868292} = "Walyurin";
$areanames{en}->{61868293} = "West\ River";
$areanames{en}->{61868294} = "Wickepin";
$areanames{en}->{61868295} = "Wickepin\ East";
$areanames{en}->{61868296} = "Williams";
$areanames{en}->{61868297} = "Woodanilling";
$areanames{en}->{61868298} = "Woogenilup";
$areanames{en}->{61868299} = "Yealering";
$areanames{en}->{61868300} = "Pingrup";
$areanames{en}->{61868301} = "Albany";
$areanames{en}->{618683020} = "Albany";
$areanames{en}->{618683021} = "Amelup";
$areanames{en}->{618683022} = "Arthur\ River";
$areanames{en}->{618683023} = "Badgebup";
$areanames{en}->{618683024} = "Badgebup\ North";
$areanames{en}->{618683025} = "Beaufort\ River";
$areanames{en}->{618683026} = "Bedford\ Harbour";
$areanames{en}->{618683027} = "Boddington";
$areanames{en}->{618683028} = "Bokerup";
$areanames{en}->{618683029} = "Borden";
$areanames{en}->{618683030} = "Boscabel";
$areanames{en}->{618683031} = "Bow\ Bridge";
$areanames{en}->{618683032} = "Bradfords";
$areanames{en}->{618683033} = "Bremer\ Bay";
$areanames{en}->{618683034} = "Broomehill";
$areanames{en}->{618683035} = "Cairlocup";
$areanames{en}->{618683036} = "Chittinup";
$areanames{en}->{618683037} = "Congee";
$areanames{en}->{618683038} = "Corackerup";
$areanames{en}->{618683039} = "Cranbrook";
$areanames{en}->{618683040} = "Cuballing";
$areanames{en}->{618683041} = "Denbarker";
$areanames{en}->{618683042} = "Denmark";
$areanames{en}->{618683043} = "Dongolocking";
$areanames{en}->{618683044} = "Dudinin";
$areanames{en}->{618683045} = "Dumbleyung";
$areanames{en}->{618683046} = "Fitzgerald";
$areanames{en}->{618683047} = "Gairdner";
$areanames{en}->{618683048} = "Gnowangerup";
$areanames{en}->{618683049} = "Gnowellen";
$areanames{en}->{618683050} = "Harrismith";
$areanames{en}->{618683051} = "Hartville";
$areanames{en}->{618683052} = "Holland\ Rocks";
$areanames{en}->{618683053} = "Hopetoun";
$areanames{en}->{618683054} = "Hyden";
$areanames{en}->{618683055} = "Hyden\ East";
$areanames{en}->{618683056} = "Jacup";
$areanames{en}->{618683057} = "Jaloran";
$areanames{en}->{618683058} = "Jerdacuttup";
$areanames{en}->{618683059} = "Jerramungup";
$areanames{en}->{618683060} = "Jingalup";
$areanames{en}->{618683061} = "Karlgarin";
$areanames{en}->{618683062} = "Katanning";
$areanames{en}->{618683063} = "Kojaneerup";
$areanames{en}->{618683064} = "Kojonup";
$areanames{en}->{618683065} = "Kondinin";
$areanames{en}->{618683066} = "Kronkup";
$areanames{en}->{618683067} = "Kukerin";
$areanames{en}->{618683068} = "Kulin";
$areanames{en}->{618683069} = "Kulin\ West";
$areanames{en}->{618683070} = "Kuringup";
$areanames{en}->{618683071} = "Lake\ Grace";
$areanames{en}->{618683072} = "Lake\ King";
$areanames{en}->{618683073} = "Lake\ Magenta";
$areanames{en}->{618683074} = "Lake\ Oconnor";
$areanames{en}->{618683075} = "Lake\ Toolbrunup";
$areanames{en}->{618683076} = "Lumeah";
$areanames{en}->{618683077} = "Magitup";
$areanames{en}->{618683078} = "Manypeaks";
$areanames{en}->{618683079} = "Manypeaks\ North";
$areanames{en}->{618683080} = "Mettler";
$areanames{en}->{618683081} = "Moodiarrup";
$areanames{en}->{618683082} = "Moulyinning";
$areanames{en}->{618683083} = "Mount\ Barker";
$areanames{en}->{618683084} = "Mount\ Madden";
$areanames{en}->{618683085} = "Muradup";
$areanames{en}->{618683086} = "Nalyerlup";
$areanames{en}->{618683087} = "Narrakine";
$areanames{en}->{618683088} = "Narrogin";
$areanames{en}->{618683089} = "Newdegate";
$areanames{en}->{618683090} = "Newdegate\ East";
$areanames{en}->{618683091} = "Newdegate\ North";
$areanames{en}->{618683092} = "Nomans\ Lake";
$areanames{en}->{618683093} = "Nyabing";
$areanames{en}->{618683094} = "Ongerup\ North";
$areanames{en}->{618683095} = "Perillup";
$areanames{en}->{618683096} = "Pingaring";
$areanames{en}->{618683097} = "Pingelly";
$areanames{en}->{618683098} = "Pingelly\ East";
$areanames{en}->{618683099} = "Pingrup";
$areanames{en}->{618683100} = "Pingrup\ East";
$areanames{en}->{618683101} = "Porongurup";
$areanames{en}->{618683102} = "Pumphreys";
$areanames{en}->{618683103} = "Quindanning";
$areanames{en}->{618683104} = "Ravensthorpe";
$areanames{en}->{618683105} = "Ravensthorpe\ West";
$areanames{en}->{618683106} = "Rocky\ Gully";
$areanames{en}->{618683107} = "Tambellup";
$areanames{en}->{618683108} = "Tarin\ Rock";
$areanames{en}->{618683109} = "Tarwonga";
$areanames{en}->{618683110} = "Tenterden";
$areanames{en}->{618683111} = "Unicup";
$areanames{en}->{618683112} = "Varley";
$areanames{en}->{618683113} = "Wagin";
$areanames{en}->{618683114} = "Walpole";
$areanames{en}->{618683115} = "Walyurin";
$areanames{en}->{618683116} = "West\ River";
$areanames{en}->{618683117} = "Wickepin";
$areanames{en}->{618683118} = "Wickepin\ East";
$areanames{en}->{618683119} = "Williams";
$areanames{en}->{618683120} = "Woodanilling";
$areanames{en}->{618683121} = "Woogenilup";
$areanames{en}->{618683122} = "Yealering";
$areanames{en}->{618683123} = "Albany";
$areanames{en}->{618683124} = "Amelup";
$areanames{en}->{618683125} = "Arthur\ River";
$areanames{en}->{618683126} = "Badgebup";
$areanames{en}->{618683127} = "Badgebup\ North";
$areanames{en}->{618683128} = "Beaufort\ River";
$areanames{en}->{618683129} = "Bedford\ Harbour";
$areanames{en}->{618683130} = "Boddington";
$areanames{en}->{618683131} = "Bokerup";
$areanames{en}->{618683132} = "Borden";
$areanames{en}->{618683133} = "Boscabel";
$areanames{en}->{618683134} = "Bow\ Bridge";
$areanames{en}->{618683135} = "Bradfords";
$areanames{en}->{618683136} = "Bremer\ Bay";
$areanames{en}->{618683137} = "Broomehill";
$areanames{en}->{618683138} = "Cairlocup";
$areanames{en}->{618683139} = "Chittinup";
$areanames{en}->{618683140} = "Congee";
$areanames{en}->{618683141} = "Corackerup";
$areanames{en}->{618683142} = "Cranbrook";
$areanames{en}->{618683143} = "Cuballing";
$areanames{en}->{618683144} = "Denbarker";
$areanames{en}->{618683145} = "Denmark";
$areanames{en}->{618683146} = "Dongolocking";
$areanames{en}->{618683147} = "Dudinin";
$areanames{en}->{618683148} = "Dumbleyung";
$areanames{en}->{618683149} = "Fitzgerald";
$areanames{en}->{618683150} = "Gairdner";
$areanames{en}->{618683151} = "Gnowangerup";
$areanames{en}->{618683152} = "Gnowellen";
$areanames{en}->{618683153} = "Harrismith";
$areanames{en}->{618683154} = "Hartville";
$areanames{en}->{618683155} = "Holland\ Rocks";
$areanames{en}->{618683156} = "Hopetoun";
$areanames{en}->{618683157} = "Hyden";
$areanames{en}->{618683158} = "Hyden\ East";
$areanames{en}->{618683159} = "Jacup";
$areanames{en}->{618683160} = "Jaloran";
$areanames{en}->{618683161} = "Jerdacuttup";
$areanames{en}->{618683162} = "Jerramungup";
$areanames{en}->{618683163} = "Jingalup";
$areanames{en}->{618683164} = "Karlgarin";
$areanames{en}->{618683165} = "Katanning";
$areanames{en}->{618683166} = "Kojaneerup";
$areanames{en}->{618683167} = "Kojonup";
$areanames{en}->{618683168} = "Kondinin";
$areanames{en}->{618683169} = "Kronkup";
$areanames{en}->{618683170} = "Kukerin";
$areanames{en}->{618683171} = "Kulin";
$areanames{en}->{618683172} = "Kulin\ West";
$areanames{en}->{618683173} = "Kuringup";
$areanames{en}->{618683174} = "Lake\ Grace";
$areanames{en}->{618683175} = "Lake\ King";
$areanames{en}->{618683176} = "Lake\ Magenta";
$areanames{en}->{618683177} = "Lake\ Oconnor";
$areanames{en}->{618683178} = "Lake\ Toolbrunup";
$areanames{en}->{618683179} = "Lumeah";
$areanames{en}->{618683180} = "Magitup";
$areanames{en}->{618683181} = "Manypeaks";
$areanames{en}->{618683182} = "Manypeaks\ North";
$areanames{en}->{618683183} = "Mettler";
$areanames{en}->{618683184} = "Moodiarrup";
$areanames{en}->{618683185} = "Moulyinning";
$areanames{en}->{618683186} = "Mount\ Barker";
$areanames{en}->{618683187} = "Mount\ Madden";
$areanames{en}->{618683188} = "Muradup";
$areanames{en}->{618683189} = "Nalyerlup";
$areanames{en}->{618683190} = "Narrakine";
$areanames{en}->{618683191} = "Narrogin";
$areanames{en}->{618683192} = "Newdegate";
$areanames{en}->{618683193} = "Newdegate\ East";
$areanames{en}->{618683194} = "Newdegate\ North";
$areanames{en}->{618683195} = "Nomans\ Lake";
$areanames{en}->{618683196} = "Nyabing";
$areanames{en}->{618683197} = "Ongerup\ North";
$areanames{en}->{618683198} = "Perillup";
$areanames{en}->{618683199} = "Pingaring";
$areanames{en}->{618683200} = "Pingelly";
$areanames{en}->{618683201} = "Pingelly\ East";
$areanames{en}->{618683202} = "Pingrup";
$areanames{en}->{618683203} = "Pingrup\ East";
$areanames{en}->{618683204} = "Porongurup";
$areanames{en}->{618683205} = "Pumphreys";
$areanames{en}->{618683206} = "Quindanning";
$areanames{en}->{618683207} = "Ravensthorpe";
$areanames{en}->{618683208} = "Ravensthorpe\ West";
$areanames{en}->{618683209} = "Rocky\ Gully";
$areanames{en}->{618683210} = "Tambellup";
$areanames{en}->{618683211} = "Tarin\ Rock";
$areanames{en}->{618683212} = "Tarwonga";
$areanames{en}->{618683213} = "Tenterden";
$areanames{en}->{618683214} = "Unicup";
$areanames{en}->{618683215} = "Varley";
$areanames{en}->{618683216} = "Wagin";
$areanames{en}->{618683217} = "Walpole";
$areanames{en}->{618683218} = "Walyurin";
$areanames{en}->{618683219} = "West\ River";
$areanames{en}->{618683220} = "Wickepin";
$areanames{en}->{618683221} = "Wickepin\ East";
$areanames{en}->{618683222} = "Williams";
$areanames{en}->{618683223} = "Woodanilling";
$areanames{en}->{618683224} = "Woogenilup";
$areanames{en}->{618683225} = "Yealering";
$areanames{en}->{618683226} = "Albany";
$areanames{en}->{618683227} = "Amelup";
$areanames{en}->{618683228} = "Arthur\ River";
$areanames{en}->{618683229} = "Badgebup";
$areanames{en}->{61868323} = "Narrogin";
$areanames{en}->{618683240} = "Badgebup\ North";
$areanames{en}->{618683241} = "Beaufort\ River";
$areanames{en}->{618683242} = "Bedford\ Harbour";
$areanames{en}->{618683243} = "Boddington";
$areanames{en}->{618683244} = "Bokerup";
$areanames{en}->{618683245} = "Borden";
$areanames{en}->{618683246} = "Boscabel";
$areanames{en}->{618683247} = "Bow\ Bridge";
$areanames{en}->{618683248} = "Bradfords";
$areanames{en}->{618683249} = "Bremer\ Bay";
$areanames{en}->{618683250} = "Broomehill";
$areanames{en}->{618683251} = "Cairlocup";
$areanames{en}->{618683252} = "Chittinup";
$areanames{en}->{618683253} = "Congee";
$areanames{en}->{618683254} = "Corackerup";
$areanames{en}->{618683255} = "Cranbrook";
$areanames{en}->{618683256} = "Cuballing";
$areanames{en}->{618683257} = "Denbarker";
$areanames{en}->{618683258} = "Denmark";
$areanames{en}->{618683259} = "Dongolocking";
$areanames{en}->{618683260} = "Dudinin";
$areanames{en}->{618683261} = "Dumbleyung";
$areanames{en}->{618683262} = "Fitzgerald";
$areanames{en}->{618683263} = "Gairdner";
$areanames{en}->{618683264} = "Gnowangerup";
$areanames{en}->{618683265} = "Gnowellen";
$areanames{en}->{618683266} = "Harrismith";
$areanames{en}->{618683267} = "Hartville";
$areanames{en}->{618683268} = "Holland\ Rocks";
$areanames{en}->{618683269} = "Hopetoun";
$areanames{en}->{618683270} = "Hyden";
$areanames{en}->{618683271} = "Hyden\ East";
$areanames{en}->{618683272} = "Jacup";
$areanames{en}->{618683273} = "Jaloran";
$areanames{en}->{618683274} = "Jerdacuttup";
$areanames{en}->{618683275} = "Jerramungup";
$areanames{en}->{618683276} = "Jingalup";
$areanames{en}->{618683277} = "Karlgarin";
$areanames{en}->{618683278} = "Katanning";
$areanames{en}->{618683279} = "Kojaneerup";
$areanames{en}->{618683280} = "Kojonup";
$areanames{en}->{618683281} = "Kondinin";
$areanames{en}->{618683282} = "Kronkup";
$areanames{en}->{618683283} = "Kukerin";
$areanames{en}->{618683284} = "Kulin";
$areanames{en}->{618683285} = "Kulin\ West";
$areanames{en}->{618683286} = "Kuringup";
$areanames{en}->{618683287} = "Lake\ Grace";
$areanames{en}->{618683288} = "Lake\ King";
$areanames{en}->{618683289} = "Lake\ Magenta";
$areanames{en}->{618683290} = "Lake\ Oconnor";
$areanames{en}->{618683291} = "Lake\ Toolbrunup";
$areanames{en}->{618683292} = "Lumeah";
$areanames{en}->{618683293} = "Magitup";
$areanames{en}->{618683294} = "Manypeaks";
$areanames{en}->{618683295} = "Manypeaks\ North";
$areanames{en}->{618683296} = "Mettler";
$areanames{en}->{618683297} = "Moodiarrup";
$areanames{en}->{618683298} = "Moulyinning";
$areanames{en}->{618683299} = "Mount\ Barker";
$areanames{en}->{618683300} = "Mount\ Madden";
$areanames{en}->{618683301} = "Muradup";
$areanames{en}->{618683302} = "Nalyerlup";
$areanames{en}->{618683303} = "Narrakine";
$areanames{en}->{618683304} = "Narrogin";
$areanames{en}->{618683305} = "Newdegate";
$areanames{en}->{618683306} = "Newdegate\ East";
$areanames{en}->{618683307} = "Newdegate\ North";
$areanames{en}->{618683308} = "Nomans\ Lake";
$areanames{en}->{618683309} = "Nyabing";
$areanames{en}->{618683310} = "Ongerup\ North";
$areanames{en}->{618683311} = "Perillup";
$areanames{en}->{618683312} = "Pingaring";
$areanames{en}->{618683313} = "Pingelly";
$areanames{en}->{618683314} = "Pingelly\ East";
$areanames{en}->{618683315} = "Pingrup";
$areanames{en}->{618683316} = "Pingrup\ East";
$areanames{en}->{618683317} = "Porongurup";
$areanames{en}->{618683318} = "Pumphreys";
$areanames{en}->{618683319} = "Quindanning";
$areanames{en}->{618683320} = "Ravensthorpe";
$areanames{en}->{618683321} = "Ravensthorpe\ West";
$areanames{en}->{618683322} = "Rocky\ Gully";
$areanames{en}->{618683323} = "Tambellup";
$areanames{en}->{618683324} = "Tarin\ Rock";
$areanames{en}->{618683325} = "Tarwonga";
$areanames{en}->{618683326} = "Tenterden";
$areanames{en}->{618683327} = "Unicup";
$areanames{en}->{618683328} = "Varley";
$areanames{en}->{618683329} = "Albany";
$areanames{en}->{618683330} = "Amelup";
$areanames{en}->{618683331} = "Arthur\ River";
$areanames{en}->{618683332} = "Badgebup";
$areanames{en}->{618683333} = "Badgebup\ North";
$areanames{en}->{618683334} = "Beaufort\ River";
$areanames{en}->{618683335} = "Bedford\ Harbour";
$areanames{en}->{618683336} = "Boddington";
$areanames{en}->{618683337} = "Bokerup";
$areanames{en}->{618683338} = "Borden";
$areanames{en}->{618683339} = "Boscabel";
$areanames{en}->{618683340} = "Bow\ Bridge";
$areanames{en}->{618683341} = "Bradfords";
$areanames{en}->{618683342} = "Bremer\ Bay";
$areanames{en}->{618683343} = "Broomehill";
$areanames{en}->{618683344} = "Cairlocup";
$areanames{en}->{618683345} = "Chittinup";
$areanames{en}->{618683346} = "Congee";
$areanames{en}->{618683347} = "Corackerup";
$areanames{en}->{618683348} = "Cranbrook";
$areanames{en}->{618683349} = "Cuballing";
$areanames{en}->{618683350} = "Denbarker";
$areanames{en}->{618683351} = "Denmark";
$areanames{en}->{618683352} = "Dongolocking";
$areanames{en}->{618683353} = "Dudinin";
$areanames{en}->{618683354} = "Dumbleyung";
$areanames{en}->{618683355} = "Fitzgerald";
$areanames{en}->{618683356} = "Gairdner";
$areanames{en}->{618683357} = "Gnowangerup";
$areanames{en}->{618683358} = "Gnowellen";
$areanames{en}->{618683359} = "Harrismith";
$areanames{en}->{618683360} = "Hartville";
$areanames{en}->{618683361} = "Holland\ Rocks";
$areanames{en}->{618683362} = "Hopetoun";
$areanames{en}->{618683363} = "Hyden";
$areanames{en}->{618683364} = "Hyden\ East";
$areanames{en}->{618683365} = "Jacup";
$areanames{en}->{618683366} = "Jaloran";
$areanames{en}->{618683367} = "Jerdacuttup";
$areanames{en}->{618683368} = "Jerramungup";
$areanames{en}->{618683369} = "Jingalup";
$areanames{en}->{618683370} = "Karlgarin";
$areanames{en}->{618683371} = "Katanning";
$areanames{en}->{618683372} = "Kojaneerup";
$areanames{en}->{618683373} = "Kojonup";
$areanames{en}->{618683374} = "Kondinin";
$areanames{en}->{618683375} = "Kronkup";
$areanames{en}->{618683376} = "Kukerin";
$areanames{en}->{618683377} = "Kulin";
$areanames{en}->{618683378} = "Kulin\ West";
$areanames{en}->{618683379} = "Kuringup";
$areanames{en}->{618683380} = "Lake\ Grace";
$areanames{en}->{618683381} = "Lake\ King";
$areanames{en}->{618683382} = "Lake\ Magenta";
$areanames{en}->{618683383} = "Lake\ Oconnor";
$areanames{en}->{618683384} = "Lake\ Toolbrunup";
$areanames{en}->{618683385} = "Lumeah";
$areanames{en}->{618683386} = "Magitup";
$areanames{en}->{618683387} = "Manypeaks";
$areanames{en}->{618683388} = "Manypeaks\ North";
$areanames{en}->{618683389} = "Mettler";
$areanames{en}->{618683390} = "Moodiarrup";
$areanames{en}->{618683391} = "Moulyinning";
$areanames{en}->{618683392} = "Mount\ Barker";
$areanames{en}->{618683393} = "Mount\ Madden";
$areanames{en}->{618683394} = "Muradup";
$areanames{en}->{618683395} = "Nalyerlup";
$areanames{en}->{618683396} = "Narrakine";
$areanames{en}->{618683397} = "Narrogin";
$areanames{en}->{618683398} = "Newdegate";
$areanames{en}->{618683399} = "Newdegate\ East";
$areanames{en}->{618683400} = "Newdegate\ North";
$areanames{en}->{618683401} = "Nomans\ Lake";
$areanames{en}->{618683402} = "Nyabing";
$areanames{en}->{618683403} = "Ongerup\ North";
$areanames{en}->{618683404} = "Perillup";
$areanames{en}->{618683405} = "Pingaring";
$areanames{en}->{618683406} = "Pingelly";
$areanames{en}->{618683407} = "Pingelly\ East";
$areanames{en}->{618683408} = "Pingrup";
$areanames{en}->{618683409} = "Pingrup\ East";
$areanames{en}->{618683410} = "Porongurup";
$areanames{en}->{618683411} = "Pumphreys";
$areanames{en}->{618683412} = "Quindanning";
$areanames{en}->{618683413} = "Ravensthorpe";
$areanames{en}->{618683414} = "Ravensthorpe\ West";
$areanames{en}->{618683415} = "Rocky\ Gully";
$areanames{en}->{618683416} = "Tambellup";
$areanames{en}->{618683417} = "Tarin\ Rock";
$areanames{en}->{618683418} = "Tarwonga";
$areanames{en}->{618683419} = "Tenterden";
$areanames{en}->{618683420} = "Unicup";
$areanames{en}->{618683421} = "Varley";
$areanames{en}->{618683422} = "Wagin";
$areanames{en}->{618683423} = "Walpole";
$areanames{en}->{618683424} = "Walyurin";
$areanames{en}->{618683425} = "West\ River";
$areanames{en}->{618683426} = "Wickepin";
$areanames{en}->{618683427} = "Wickepin\ East";
$areanames{en}->{618683428} = "Williams";
$areanames{en}->{618683429} = "Woodanilling";
$areanames{en}->{618683430} = "Woogenilup";
$areanames{en}->{618683431} = "Yealering";
$areanames{en}->{618683432} = "Wagin";
$areanames{en}->{618683433} = "Walpole";
$areanames{en}->{618683434} = "Walyurin";
$areanames{en}->{618683435} = "West\ River";
$areanames{en}->{618683436} = "Wickepin";
$areanames{en}->{618683437} = "Wickepin\ East";
$areanames{en}->{618683438} = "Williams";
$areanames{en}->{618683439} = "Woodanilling";
$areanames{en}->{61868344} = "Albany";
$areanames{en}->{61868345} = "Albany";
$areanames{en}->{61868346} = "Albany";
$areanames{en}->{618683470} = "Woogenilup";
$areanames{en}->{618683471} = "Yealering";
$areanames{en}->{618683472} = "Albany";
$areanames{en}->{618683473} = "Amelup";
$areanames{en}->{618683474} = "Arthur\ River";
$areanames{en}->{618683475} = "Badgebup";
$areanames{en}->{618683476} = "Badgebup\ North";
$areanames{en}->{618683477} = "Beaufort\ River";
$areanames{en}->{618683478} = "Bedford\ Harbour";
$areanames{en}->{618683479} = "Boddington";
$areanames{en}->{618683480} = "Bokerup";
$areanames{en}->{618683481} = "Borden";
$areanames{en}->{618683482} = "Boscabel";
$areanames{en}->{618683483} = "Bow\ Bridge";
$areanames{en}->{618683484} = "Bradfords";
$areanames{en}->{618683485} = "Bremer\ Bay";
$areanames{en}->{618683486} = "Broomehill";
$areanames{en}->{618683487} = "Cairlocup";
$areanames{en}->{618683488} = "Chittinup";
$areanames{en}->{618683489} = "Congee";
$areanames{en}->{618683490} = "Corackerup";
$areanames{en}->{618683491} = "Cranbrook";
$areanames{en}->{618683492} = "Cuballing";
$areanames{en}->{618683493} = "Denbarker";
$areanames{en}->{618683494} = "Denmark";
$areanames{en}->{618683495} = "Dongolocking";
$areanames{en}->{618683496} = "Dudinin";
$areanames{en}->{618683497} = "Dumbleyung";
$areanames{en}->{618683498} = "Fitzgerald";
$areanames{en}->{618683499} = "Gairdner";
$areanames{en}->{618683500} = "Gnowangerup";
$areanames{en}->{618683501} = "Gnowellen";
$areanames{en}->{618683502} = "Harrismith";
$areanames{en}->{618683503} = "Hartville";
$areanames{en}->{618683504} = "Holland\ Rocks";
$areanames{en}->{618683505} = "Hopetoun";
$areanames{en}->{618683506} = "Hyden";
$areanames{en}->{618683507} = "Hyden\ East";
$areanames{en}->{618683508} = "Jacup";
$areanames{en}->{618683509} = "Jaloran";
$areanames{en}->{618683510} = "Jerdacuttup";
$areanames{en}->{618683511} = "Jerramungup";
$areanames{en}->{618683512} = "Jingalup";
$areanames{en}->{618683513} = "Karlgarin";
$areanames{en}->{618683514} = "Katanning";
$areanames{en}->{618683515} = "Kojaneerup";
$areanames{en}->{618683516} = "Kojonup";
$areanames{en}->{618683517} = "Kondinin";
$areanames{en}->{618683518} = "Kronkup";
$areanames{en}->{618683519} = "Kukerin";
$areanames{en}->{618683520} = "Kulin";
$areanames{en}->{618683521} = "Kulin\ West";
$areanames{en}->{618683522} = "Kuringup";
$areanames{en}->{618683523} = "Lake\ Grace";
$areanames{en}->{618683524} = "Lake\ King";
$areanames{en}->{618683525} = "Lake\ Magenta";
$areanames{en}->{618683526} = "Lake\ Oconnor";
$areanames{en}->{618683527} = "Lake\ Toolbrunup";
$areanames{en}->{618683528} = "Lumeah";
$areanames{en}->{618683529} = "Magitup";
$areanames{en}->{618683530} = "Manypeaks";
$areanames{en}->{618683531} = "Manypeaks\ North";
$areanames{en}->{618683532} = "Mettler";
$areanames{en}->{618683533} = "Moodiarrup";
$areanames{en}->{618683534} = "Moulyinning";
$areanames{en}->{618683535} = "Mount\ Barker";
$areanames{en}->{618683536} = "Mount\ Madden";
$areanames{en}->{618683537} = "Muradup";
$areanames{en}->{618683538} = "Nalyerlup";
$areanames{en}->{618683539} = "Narrakine";
$areanames{en}->{618683540} = "Narrogin";
$areanames{en}->{618683541} = "Newdegate";
$areanames{en}->{618683542} = "Newdegate\ East";
$areanames{en}->{618683543} = "Newdegate\ North";
$areanames{en}->{618683544} = "Nomans\ Lake";
$areanames{en}->{618683545} = "Nyabing";
$areanames{en}->{618683546} = "Ongerup\ North";
$areanames{en}->{618683547} = "Perillup";
$areanames{en}->{618683548} = "Pingaring";
$areanames{en}->{618683549} = "Pingelly";
$areanames{en}->{618683550} = "Pingelly\ East";
$areanames{en}->{618683551} = "Pingrup";
$areanames{en}->{618683552} = "Pingrup\ East";
$areanames{en}->{618683553} = "Porongurup";
$areanames{en}->{618683554} = "Pumphreys";
$areanames{en}->{618683555} = "Quindanning";
$areanames{en}->{618683556} = "Ravensthorpe";
$areanames{en}->{618683557} = "Ravensthorpe\ West";
$areanames{en}->{618683558} = "Rocky\ Gully";
$areanames{en}->{618683559} = "Tambellup";
$areanames{en}->{618683560} = "Tarin\ Rock";
$areanames{en}->{618683561} = "Tarwonga";
$areanames{en}->{618683562} = "Tenterden";
$areanames{en}->{618683563} = "Unicup";
$areanames{en}->{618683564} = "Varley";
$areanames{en}->{618683565} = "Wagin";
$areanames{en}->{618683566} = "Walpole";
$areanames{en}->{618683567} = "Walyurin";
$areanames{en}->{618683568} = "West\ River";
$areanames{en}->{618683569} = "Wickepin";
$areanames{en}->{618683570} = "Wickepin\ East";
$areanames{en}->{618683571} = "Williams";
$areanames{en}->{618683572} = "Woodanilling";
$areanames{en}->{618683573} = "Woogenilup";
$areanames{en}->{618683574} = "Yealering";
$areanames{en}->{618683575} = "Albany";
$areanames{en}->{618683576} = "Amelup";
$areanames{en}->{618683577} = "Arthur\ River";
$areanames{en}->{618683578} = "Badgebup";
$areanames{en}->{618683579} = "Badgebup\ North";
$areanames{en}->{618683580} = "Beaufort\ River";
$areanames{en}->{618683581} = "Bedford\ Harbour";
$areanames{en}->{618683582} = "Boddington";
$areanames{en}->{618683583} = "Bokerup";
$areanames{en}->{618683584} = "Borden";
$areanames{en}->{618683585} = "Boscabel";
$areanames{en}->{618683586} = "Bow\ Bridge";
$areanames{en}->{618683587} = "Bradfords";
$areanames{en}->{618683588} = "Bremer\ Bay";
$areanames{en}->{618683589} = "Broomehill";
$areanames{en}->{618683590} = "Cairlocup";
$areanames{en}->{618683591} = "Chittinup";
$areanames{en}->{618683592} = "Congee";
$areanames{en}->{618683593} = "Corackerup";
$areanames{en}->{618683594} = "Cranbrook";
$areanames{en}->{618683595} = "Cuballing";
$areanames{en}->{618683596} = "Denbarker";
$areanames{en}->{618683597} = "Denmark";
$areanames{en}->{618683598} = "Dongolocking";
$areanames{en}->{618683599} = "Dudinin";
$areanames{en}->{618683600} = "Dumbleyung";
$areanames{en}->{618683601} = "Fitzgerald";
$areanames{en}->{618683602} = "Gairdner";
$areanames{en}->{618683603} = "Gnowangerup";
$areanames{en}->{618683604} = "Gnowellen";
$areanames{en}->{618683605} = "Harrismith";
$areanames{en}->{618683606} = "Hartville";
$areanames{en}->{618683607} = "Holland\ Rocks";
$areanames{en}->{618683608} = "Hopetoun";
$areanames{en}->{618683609} = "Hyden";
$areanames{en}->{618683610} = "Hyden\ East";
$areanames{en}->{618683611} = "Jacup";
$areanames{en}->{618683612} = "Jaloran";
$areanames{en}->{618683613} = "Jerdacuttup";
$areanames{en}->{618683614} = "Jerramungup";
$areanames{en}->{618683615} = "Jingalup";
$areanames{en}->{618683616} = "Karlgarin";
$areanames{en}->{618683617} = "Katanning";
$areanames{en}->{618683618} = "Kojaneerup";
$areanames{en}->{618683619} = "Kojonup";
$areanames{en}->{618683620} = "Kondinin";
$areanames{en}->{618683621} = "Kronkup";
$areanames{en}->{618683622} = "Kukerin";
$areanames{en}->{618683623} = "Kulin";
$areanames{en}->{618683624} = "Kulin\ West";
$areanames{en}->{618683625} = "Kuringup";
$areanames{en}->{618683626} = "Lake\ Grace";
$areanames{en}->{618683627} = "Lake\ King";
$areanames{en}->{618683628} = "Lake\ Magenta";
$areanames{en}->{618683629} = "Lake\ Oconnor";
$areanames{en}->{618683630} = "Lake\ Toolbrunup";
$areanames{en}->{618683631} = "Lumeah";
$areanames{en}->{618683632} = "Magitup";
$areanames{en}->{618683633} = "Manypeaks";
$areanames{en}->{618683634} = "Manypeaks\ North";
$areanames{en}->{618683635} = "Mettler";
$areanames{en}->{618683636} = "Moodiarrup";
$areanames{en}->{618683637} = "Moulyinning";
$areanames{en}->{618683638} = "Mount\ Barker";
$areanames{en}->{618683639} = "Mount\ Madden";
$areanames{en}->{618683640} = "Muradup";
$areanames{en}->{618683641} = "Nalyerlup";
$areanames{en}->{618683642} = "Narrakine";
$areanames{en}->{618683643} = "Narrogin";
$areanames{en}->{618683644} = "Newdegate";
$areanames{en}->{618683645} = "Newdegate\ East";
$areanames{en}->{618683646} = "Newdegate\ North";
$areanames{en}->{618683647} = "Nomans\ Lake";
$areanames{en}->{618683648} = "Nyabing";
$areanames{en}->{618683649} = "Ongerup\ North";
$areanames{en}->{618683650} = "Perillup";
$areanames{en}->{618683651} = "Pingaring";
$areanames{en}->{618683652} = "Pingelly";
$areanames{en}->{618683653} = "Pingelly\ East";
$areanames{en}->{618683654} = "Pingrup";
$areanames{en}->{618683655} = "Pingrup\ East";
$areanames{en}->{618683656} = "Porongurup";
$areanames{en}->{618683657} = "Pumphreys";
$areanames{en}->{618683658} = "Quindanning";
$areanames{en}->{618683659} = "Ravensthorpe";
$areanames{en}->{618683660} = "Ravensthorpe\ West";
$areanames{en}->{618683661} = "Rocky\ Gully";
$areanames{en}->{618683662} = "Tambellup";
$areanames{en}->{618683663} = "Tarin\ Rock";
$areanames{en}->{618683664} = "Tarwonga";
$areanames{en}->{618683665} = "Tenterden";
$areanames{en}->{618683666} = "Unicup";
$areanames{en}->{618683667} = "Varley";
$areanames{en}->{618683668} = "Wagin";
$areanames{en}->{618683669} = "Walpole";
$areanames{en}->{618683670} = "Walyurin";
$areanames{en}->{618683671} = "West\ River";
$areanames{en}->{618683672} = "Wickepin";
$areanames{en}->{618683673} = "Wickepin\ East";
$areanames{en}->{618683674} = "Williams";
$areanames{en}->{618683675} = "Woodanilling";
$areanames{en}->{618683676} = "Woogenilup";
$areanames{en}->{618683677} = "Yealering";
$areanames{en}->{618683678} = "Albany";
$areanames{en}->{618683679} = "Amelup";
$areanames{en}->{61868368} = "Ravensthorpe";
$areanames{en}->{618683690} = "Arthur\ River";
$areanames{en}->{618683691} = "Badgebup";
$areanames{en}->{618683692} = "Badgebup\ North";
$areanames{en}->{618683693} = "Beaufort\ River";
$areanames{en}->{618683694} = "Bedford\ Harbour";
$areanames{en}->{618683695} = "Boddington";
$areanames{en}->{618683696} = "Bokerup";
$areanames{en}->{618683697} = "Borden";
$areanames{en}->{618683698} = "Boscabel";
$areanames{en}->{618683699} = "Bow\ Bridge";
$areanames{en}->{618683700} = "Bradfords";
$areanames{en}->{618683701} = "Bremer\ Bay";
$areanames{en}->{618683702} = "Broomehill";
$areanames{en}->{618683703} = "Cairlocup";
$areanames{en}->{618683704} = "Chittinup";
$areanames{en}->{618683705} = "Congee";
$areanames{en}->{618683706} = "Corackerup";
$areanames{en}->{618683707} = "Cranbrook";
$areanames{en}->{618683708} = "Cuballing";
$areanames{en}->{618683709} = "Denbarker";
$areanames{en}->{618683710} = "Denmark";
$areanames{en}->{618683711} = "Dongolocking";
$areanames{en}->{618683712} = "Dudinin";
$areanames{en}->{618683713} = "Dumbleyung";
$areanames{en}->{618683714} = "Fitzgerald";
$areanames{en}->{618683715} = "Gairdner";
$areanames{en}->{618683716} = "Gnowangerup";
$areanames{en}->{618683717} = "Gnowellen";
$areanames{en}->{618683718} = "Harrismith";
$areanames{en}->{618683719} = "Hartville";
$areanames{en}->{618683720} = "Holland\ Rocks";
$areanames{en}->{618683721} = "Hopetoun";
$areanames{en}->{618683722} = "Hyden";
$areanames{en}->{618683723} = "Hyden\ East";
$areanames{en}->{618683724} = "Jacup";
$areanames{en}->{618683725} = "Jaloran";
$areanames{en}->{618683726} = "Jerdacuttup";
$areanames{en}->{618683727} = "Jerramungup";
$areanames{en}->{618683728} = "Jingalup";
$areanames{en}->{618683729} = "Karlgarin";
$areanames{en}->{618683730} = "Katanning";
$areanames{en}->{618683731} = "Kojaneerup";
$areanames{en}->{618683732} = "Kojonup";
$areanames{en}->{618683733} = "Kondinin";
$areanames{en}->{618683734} = "Kronkup";
$areanames{en}->{618683735} = "Kukerin";
$areanames{en}->{618683736} = "Kulin";
$areanames{en}->{618683737} = "Kulin\ West";
$areanames{en}->{618683738} = "Kuringup";
$areanames{en}->{618683739} = "Lake\ Grace";
$areanames{en}->{618683740} = "Lake\ King";
$areanames{en}->{618683741} = "Lake\ Magenta";
$areanames{en}->{618683742} = "Lake\ Oconnor";
$areanames{en}->{618683743} = "Lake\ Toolbrunup";
$areanames{en}->{618683744} = "Lumeah";
$areanames{en}->{618683745} = "Magitup";
$areanames{en}->{618683746} = "Manypeaks";
$areanames{en}->{618683747} = "Manypeaks\ North";
$areanames{en}->{618683748} = "Mettler";
$areanames{en}->{618683749} = "Moodiarrup";
$areanames{en}->{618683750} = "Moulyinning";
$areanames{en}->{618683751} = "Mount\ Barker";
$areanames{en}->{618683752} = "Mount\ Madden";
$areanames{en}->{618683753} = "Muradup";
$areanames{en}->{618683754} = "Nalyerlup";
$areanames{en}->{618683755} = "Narrakine";
$areanames{en}->{618683756} = "Narrogin";
$areanames{en}->{618683757} = "Newdegate";
$areanames{en}->{618683758} = "Newdegate\ East";
$areanames{en}->{618683759} = "Newdegate\ North";
$areanames{en}->{618683760} = "Nomans\ Lake";
$areanames{en}->{618683761} = "Nyabing";
$areanames{en}->{618683762} = "Ongerup\ North";
$areanames{en}->{618683763} = "Perillup";
$areanames{en}->{618683764} = "Pingaring";
$areanames{en}->{618683765} = "Pingelly";
$areanames{en}->{618683766} = "Pingelly\ East";
$areanames{en}->{618683767} = "Pingrup";
$areanames{en}->{618683768} = "Pingrup\ East";
$areanames{en}->{618683769} = "Porongurup";
$areanames{en}->{618683770} = "Pumphreys";
$areanames{en}->{618683771} = "Quindanning";
$areanames{en}->{618683772} = "Ravensthorpe";
$areanames{en}->{618683773} = "Ravensthorpe\ West";
$areanames{en}->{618683774} = "Rocky\ Gully";
$areanames{en}->{618683775} = "Tambellup";
$areanames{en}->{618683776} = "Tarin\ Rock";
$areanames{en}->{618683777} = "Tarwonga";
$areanames{en}->{618683778} = "Tenterden";
$areanames{en}->{618683779} = "Unicup";
$areanames{en}->{618683780} = "Varley";
$areanames{en}->{618683781} = "Wagin";
$areanames{en}->{618683782} = "Walpole";
$areanames{en}->{618683783} = "Walyurin";
$areanames{en}->{618683784} = "West\ River";
$areanames{en}->{618683785} = "Wickepin";
$areanames{en}->{618683786} = "Wickepin\ East";
$areanames{en}->{618683787} = "Williams";
$areanames{en}->{618683788} = "Woodanilling";
$areanames{en}->{618683789} = "Woogenilup";
$areanames{en}->{618683790} = "Yealering";
$areanames{en}->{61868389} = "Bremer\ Bay";
$areanames{en}->{61868400} = "Fitzgerald";
$areanames{en}->{61868419} = "Lake\ Toolbrunup";
$areanames{en}->{61868430} = "Narrogin";
$areanames{en}->{61868446} = "Pingelly";
$areanames{en}->{61868447} = "Wagin";
$areanames{en}->{61868888} = "Albany";
$areanames{en}->{61868889} = "Lake\ Toolbrunup";
$areanames{en}->{618700} = "Adelaide";
$areanames{en}->{618707} = "Adelaide";
$areanames{en}->{6187080} = "Adelaide";
$areanames{en}->{6187081} = "Adelaide";
$areanames{en}->{6187082} = "Adelaide";
$areanames{en}->{6187083} = "Adelaide";
$areanames{en}->{6187087} = "Adelaide";
$areanames{en}->{6187088} = "Adelaide";
$areanames{en}->{6187089} = "Adelaide";
$areanames{en}->{6187099} = "Adelaide";
$areanames{en}->{61871000} = "Adelaide";
$areanames{en}->{61871001} = "Adelaide";
$areanames{en}->{61871002} = "Adelaide";
$areanames{en}->{61871003} = "Adelaide";
$areanames{en}->{61871004} = "Adelaide";
$areanames{en}->{61871005} = "Adelaide";
$areanames{en}->{61871006} = "Adelaide";
$areanames{en}->{61871007} = "Adelaide";
$areanames{en}->{61871008} = "Adelaide";
$areanames{en}->{6187109} = "Adelaide";
$areanames{en}->{61871101} = "Adelaide";
$areanames{en}->{61871110} = "Adelaide";
$areanames{en}->{61871111} = "Adelaide";
$areanames{en}->{61871112} = "Adelaide";
$areanames{en}->{61871113} = "Adelaide";
$areanames{en}->{6187117} = "Adelaide";
$areanames{en}->{618712} = "Adelaide";
$areanames{en}->{61871201} = "Woodside";
$areanames{en}->{61871203} = "Mount\ Barker";
$areanames{en}->{61871300} = "Adelaide";
$areanames{en}->{61871301} = "Adelaide";
$areanames{en}->{61871302} = "Adelaide";
$areanames{en}->{61871303} = "Adelaide";
$areanames{en}->{6187131} = "Adelaide";
$areanames{en}->{6187132} = "Adelaide";
$areanames{en}->{6187133} = "Adelaide";
$areanames{en}->{61871400} = "Adelaide";
$areanames{en}->{61871401} = "Adelaide";
$areanames{en}->{61871501} = "Adelaide";
$areanames{en}->{61871603} = "Adelaide";
$areanames{en}->{61871705} = "Adelaide";
$areanames{en}->{6187180} = "Salisbury";
$areanames{en}->{6187181} = "Woodside";
$areanames{en}->{6187182} = "Mount\ Barker";
$areanames{en}->{6187183} = "Mclaren\ Vale";
$areanames{en}->{61871840} = "Mclaren\ Vale";
$areanames{en}->{61871841} = "Mclaren\ Vale";
$areanames{en}->{61871842} = "Salisbury";
$areanames{en}->{61871843} = "Woodside";
$areanames{en}->{61871844} = "Mount\ Barker";
$areanames{en}->{61871845} = "Mclaren\ Vale";
$areanames{en}->{61871846} = "Mclaren\ Vale";
$areanames{en}->{61871847} = "Mount\ Barker";
$areanames{en}->{61871848} = "Salisbury";
$areanames{en}->{61871849} = "Woodside";
$areanames{en}->{6187185} = "Woodside";
$areanames{en}->{61871850} = "Mclaren\ Vale";
$areanames{en}->{61871851} = "Salisbury";
$areanames{en}->{61871853} = "Salisbury";
$areanames{en}->{6187186} = "Mclaren\ Vale";
$areanames{en}->{6187187} = "Mount\ Barker";
$areanames{en}->{6187188} = "Salisbury";
$areanames{en}->{6187189} = "Woodside";
$areanames{en}->{6187190} = "Mount\ Barker";
$areanames{en}->{61872000} = "Adelaide";
$areanames{en}->{6187201} = "Adelaide";
$areanames{en}->{61872021} = "Adelaide";
$areanames{en}->{6187210} = "Adelaide";
$areanames{en}->{61872110} = "Adelaide";
$areanames{en}->{618722} = "Adelaide";
$areanames{en}->{6187227} = "Woodside";
$areanames{en}->{61872280} = "Salisbury";
$areanames{en}->{61872281} = "Mclaren\ Vale";
$areanames{en}->{61872283} = "Mount\ Barker";
$areanames{en}->{61872284} = "Woodside";
$areanames{en}->{6187230} = "Adelaide";
$areanames{en}->{6187231} = "Adelaide";
$areanames{en}->{61872320} = "Adelaide";
$areanames{en}->{61872330} = "Adelaide";
$areanames{en}->{61872331} = "Adelaide";
$areanames{en}->{61872332} = "Adelaide";
$areanames{en}->{61872333} = "Adelaide";
$areanames{en}->{61872334} = "Adelaide";
$areanames{en}->{61872600} = "Mclaren\ Vale";
$areanames{en}->{61872601} = "Mclaren\ Vale";
$areanames{en}->{61872602} = "Mclaren\ Vale";
$areanames{en}->{61872603} = "Mclaren\ Vale";
$areanames{en}->{61872604} = "Mclaren\ Vale";
$areanames{en}->{61872605} = "Mclaren\ Vale";
$areanames{en}->{61872606} = "Mclaren\ Vale";
$areanames{en}->{61872607} = "Mclaren\ Vale";
$areanames{en}->{61872608} = "Mclaren\ Vale";
$areanames{en}->{6187280} = "Mount\ Barker";
$areanames{en}->{6187281} = "Woodside";
$areanames{en}->{61872820} = "Mclaren\ Vale";
$areanames{en}->{61872821} = "Mount\ Barker";
$areanames{en}->{61872822} = "Mclaren\ Vale";
$areanames{en}->{61872823} = "Salisbury";
$areanames{en}->{61872824} = "Mount\ Barker";
$areanames{en}->{61872825} = "Woodside";
$areanames{en}->{61872826} = "Mount\ Barker";
$areanames{en}->{61872827} = "Woodside";
$areanames{en}->{61872828} = "Mclaren\ Vale";
$areanames{en}->{61872829} = "Salisbury";
$areanames{en}->{6187283} = "Mclaren\ Vale";
$areanames{en}->{6187284} = "Salisbury";
$areanames{en}->{6187285} = "Salisbury";
$areanames{en}->{61872859} = "Mclaren\ Vale";
$areanames{en}->{61872860} = "Mclaren\ Vale";
$areanames{en}->{61872861} = "Mount\ Barker";
$areanames{en}->{61872862} = "Salisbury";
$areanames{en}->{61872863} = "Mclaren\ Vale";
$areanames{en}->{61872864} = "Salisbury";
$areanames{en}->{61872865} = "Woodside";
$areanames{en}->{61872866} = "Woodside";
$areanames{en}->{61872867} = "Salisbury";
$areanames{en}->{61872868} = "Woodside";
$areanames{en}->{61872869} = "Salisbury";
$areanames{en}->{6187287} = "Mount\ Barker";
$areanames{en}->{6187288} = "Mclaren\ Vale";
$areanames{en}->{6187289} = "Salisbury";
$areanames{en}->{618732} = "Adelaide";
$areanames{en}->{6187327} = "Woodside";
$areanames{en}->{61873333} = "Adelaide";
$areanames{en}->{61873334} = "Adelaide";
$areanames{en}->{6187370} = "Salisbury";
$areanames{en}->{6187371} = "Salisbury";
$areanames{en}->{6187372} = "Salisbury";
$areanames{en}->{61873730} = "Salisbury";
$areanames{en}->{61873800} = "Salisbury";
$areanames{en}->{61873801} = "Mount\ Barker";
$areanames{en}->{61873802} = "Mount\ Barker";
$areanames{en}->{61873803} = "Mount\ Barker";
$areanames{en}->{61873807} = "Mount\ Barker";
$areanames{en}->{61873808} = "Salisbury";
$areanames{en}->{61873809} = "Salisbury";
$areanames{en}->{6187381} = "Salisbury";
$areanames{en}->{61873820} = "Salisbury";
$areanames{en}->{61873821} = "Salisbury";
$areanames{en}->{61873822} = "Salisbury";
$areanames{en}->{61873823} = "Salisbury";
$areanames{en}->{61873824} = "Salisbury";
$areanames{en}->{61873825} = "Salisbury";
$areanames{en}->{61873826} = "Salisbury";
$areanames{en}->{61873827} = "Salisbury";
$areanames{en}->{6187383} = "Salisbury";
$areanames{en}->{6187389} = "Salisbury";
$areanames{en}->{6187420} = "Adelaide";
$areanames{en}->{6187421} = "Adelaide";
$areanames{en}->{6187422} = "Adelaide";
$areanames{en}->{6187423} = "Adelaide";
$areanames{en}->{6187424} = "Adelaide";
$areanames{en}->{6187425} = "Adelaide";
$areanames{en}->{61874260} = "Adelaide";
$areanames{en}->{6187427} = "Adelaide";
$areanames{en}->{61874444} = "Adelaide";
$areanames{en}->{61874445} = "Adelaide";
$areanames{en}->{61874777} = "Adelaide";
$areanames{en}->{61874778} = "Adelaide";
$areanames{en}->{6187480} = "Salisbury";
$areanames{en}->{61874800} = "Mclaren\ Vale";
$areanames{en}->{6187481} = "Woodside";
$areanames{en}->{61874816} = "Mclaren\ Vale";
$areanames{en}->{61874817} = "Mclaren\ Vale";
$areanames{en}->{61874818} = "Mclaren\ Vale";
$areanames{en}->{61874854} = "Salisbury";
$areanames{en}->{61875000} = "Renmark";
$areanames{en}->{61875001} = "Taldra";
$areanames{en}->{61875002} = "Taplan";
$areanames{en}->{61875003} = "Wanbi";
$areanames{en}->{61875004} = "Wunkar";
$areanames{en}->{61875005} = "Karatta";
$areanames{en}->{61875006} = "Kingscote";
$areanames{en}->{61875007} = "Parndana";
$areanames{en}->{61875008} = "Penneshaw";
$areanames{en}->{61875009} = "Mallala";
$areanames{en}->{61875010} = "Two\ Wells";
$areanames{en}->{61875011} = "Windsor";
$areanames{en}->{61875012} = "Callington";
$areanames{en}->{61875013} = "Hartley";
$areanames{en}->{61875014} = "Langhorne\ Creek";
$areanames{en}->{61875015} = "Milang";
$areanames{en}->{61875016} = "Murray\ Bridge";
$areanames{en}->{61875017} = "Mypolonga";
$areanames{en}->{61875018} = "Strathalbyn";
$areanames{en}->{61875019} = "Bow\ Hill";
$areanames{en}->{61875020} = "Bower";
$areanames{en}->{61875021} = "Eudunda";
$areanames{en}->{61875022} = "Kapunda";
$areanames{en}->{61875023} = "Mannum";
$areanames{en}->{61875024} = "Mount\ Pleasant";
$areanames{en}->{61875025} = "Robertstown";
$areanames{en}->{61875026} = "Sanderston";
$areanames{en}->{61875027} = "Sandleton";
$areanames{en}->{61875028} = "Sedan";
$areanames{en}->{61875029} = "Swan\ Reach";
$areanames{en}->{61875030} = "Tanunda";
$areanames{en}->{61875031} = "Truro";
$areanames{en}->{61875032} = "Walker\ Flat";
$areanames{en}->{61875033} = "Coonalpyn";
$areanames{en}->{61875034} = "Copeville";
$areanames{en}->{61875035} = "Culburra";
$areanames{en}->{61875036} = "Geranium";
$areanames{en}->{61875037} = "Gurrai";
$areanames{en}->{61875038} = "Halidon";
$areanames{en}->{61875039} = "Karoonda";
$areanames{en}->{61875040} = "Lameroo";
$areanames{en}->{61875041} = "Malinong";
$areanames{en}->{61875042} = "Marama";
$areanames{en}->{61875043} = "Meningie";
$areanames{en}->{61875044} = "Meningie\ East";
$areanames{en}->{61875045} = "Narrung";
$areanames{en}->{61875046} = "Peake";
$areanames{en}->{61875047} = "Peebinga";
$areanames{en}->{61875048} = "Perponda";
$areanames{en}->{61875049} = "Pinnaroo";
$areanames{en}->{61875050} = "Policemans\ Point";
$areanames{en}->{61875051} = "Tailem\ Bend";
$areanames{en}->{61875052} = "Wynarka";
$areanames{en}->{61875053} = "Yumali";
$areanames{en}->{61875054} = "Goolwa";
$areanames{en}->{61875055} = "Victor\ Harbor";
$areanames{en}->{61875056} = "Willunga";
$areanames{en}->{61875057} = "Yankalilla";
$areanames{en}->{61875058} = "Blanchetown";
$areanames{en}->{61875059} = "Lowbank";
$areanames{en}->{61875060} = "Mantung";
$areanames{en}->{61875061} = "Morgan";
$areanames{en}->{61875062} = "New\ Well";
$areanames{en}->{61875063} = "Taylorville";
$areanames{en}->{61875064} = "Waikerie";
$areanames{en}->{61875065} = "Auburn";
$areanames{en}->{61875066} = "Freeling";
$areanames{en}->{61875067} = "Gawler";
$areanames{en}->{61875068} = "Hamley\ Bridge";
$areanames{en}->{61875069} = "Riverton";
$areanames{en}->{61875070} = "Two\ Wells";
$areanames{en}->{61875071} = "Murray\ Bridge";
$areanames{en}->{61875072} = "Gawler";
$areanames{en}->{61875073} = "Barmera";
$areanames{en}->{61875074} = "Berri";
$areanames{en}->{61875075} = "Loxton";
$areanames{en}->{61875076} = "Paruna";
$areanames{en}->{61875077} = "Renmark";
$areanames{en}->{61875078} = "Taplan";
$areanames{en}->{61875079} = "Taldra";
$areanames{en}->{61875080} = "Wanbi";
$areanames{en}->{61875081} = "Wunkar";
$areanames{en}->{61875082} = "Auburn";
$areanames{en}->{61875083} = "Auburn";
$areanames{en}->{61875084} = "Gawler";
$areanames{en}->{61875085} = "Strathalbyn";
$areanames{en}->{61875086} = "Tanunda";
$areanames{en}->{61875087} = "Strathalbyn";
$areanames{en}->{61875088} = "Victor\ Harbor";
$areanames{en}->{61875089} = "Goolwa";
$areanames{en}->{61875090} = "Tanunda";
$areanames{en}->{61875091} = "Goolwa";
$areanames{en}->{61875092} = "Victor\ Harbor";
$areanames{en}->{61875093} = "Willunga";
$areanames{en}->{61875094} = "Murray\ Bridge";
$areanames{en}->{61875095} = "Freeling";
$areanames{en}->{61875096} = "Freeling";
$areanames{en}->{61875097} = "Gawler";
$areanames{en}->{61875098} = "Gawler";
$areanames{en}->{61875099} = "Barmera";
$areanames{en}->{61875100} = "Barmera";
$areanames{en}->{61875101} = "Gawler";
$areanames{en}->{61875102} = "Willunga";
$areanames{en}->{61875103} = "Renmark";
$areanames{en}->{61875104} = "Renmark";
$areanames{en}->{61875105} = "Mallala";
$areanames{en}->{61875106} = "Mallala";
$areanames{en}->{61875107} = "Two\ Wells";
$areanames{en}->{61875108} = "Two\ Wells";
$areanames{en}->{61875109} = "Langhorne\ Creek";
$areanames{en}->{61875110} = "Langhorne\ Creek";
$areanames{en}->{61875111} = "Milang";
$areanames{en}->{61875112} = "Milang";
$areanames{en}->{61875113} = "Murray\ Bridge";
$areanames{en}->{61875114} = "Murray\ Bridge";
$areanames{en}->{61875115} = "Mypolonga";
$areanames{en}->{61875116} = "Mypolonga";
$areanames{en}->{61875117} = "Strathalbyn";
$areanames{en}->{61875118} = "Strathalbyn";
$areanames{en}->{61875119} = "Kapunda";
$areanames{en}->{61875120} = "Kapunda";
$areanames{en}->{61875121} = "Kapunda";
$areanames{en}->{61875122} = "Kapunda";
$areanames{en}->{61875123} = "Mannum";
$areanames{en}->{61875124} = "Mannum";
$areanames{en}->{61875125} = "Mount\ Pleasant";
$areanames{en}->{61875126} = "Mount\ Pleasant";
$areanames{en}->{61875127} = "Robertstown";
$areanames{en}->{61875128} = "Robertstown";
$areanames{en}->{61875129} = "Sanderston";
$areanames{en}->{61875130} = "Sanderston";
$areanames{en}->{61875131} = "Sandleton";
$areanames{en}->{61875132} = "Sandleton";
$areanames{en}->{61875133} = "Sedan";
$areanames{en}->{61875134} = "Sedan";
$areanames{en}->{61875135} = "Swan\ Reach";
$areanames{en}->{61875136} = "Swan\ Reach";
$areanames{en}->{61875137} = "Tanunda";
$areanames{en}->{61875138} = "Tanunda";
$areanames{en}->{61875139} = "Truro";
$areanames{en}->{61875140} = "Truro";
$areanames{en}->{61875141} = "Coonalpyn";
$areanames{en}->{61875142} = "Coonalpyn";
$areanames{en}->{61875143} = "Culburra";
$areanames{en}->{61875144} = "Culburra";
$areanames{en}->{61875145} = "Malinong";
$areanames{en}->{61875146} = "Malinong";
$areanames{en}->{61875147} = "Marama";
$areanames{en}->{61875148} = "Marama";
$areanames{en}->{61875149} = "Meningie";
$areanames{en}->{61875150} = "Meningie";
$areanames{en}->{61875151} = "Meningie\ East";
$areanames{en}->{61875152} = "Meningie\ East";
$areanames{en}->{61875153} = "Pinnaroo";
$areanames{en}->{61875154} = "Pinnaroo";
$areanames{en}->{61875155} = "Tailem\ Bend";
$areanames{en}->{61875156} = "Tailem\ Bend";
$areanames{en}->{61875157} = "Wynarka";
$areanames{en}->{61875158} = "Wynarka";
$areanames{en}->{61875159} = "Yumali";
$areanames{en}->{61875160} = "Yumali";
$areanames{en}->{61875161} = "Goolwa";
$areanames{en}->{61875162} = "Goolwa";
$areanames{en}->{61875163} = "Victor\ Harbor";
$areanames{en}->{61875164} = "Victor\ Harbor";
$areanames{en}->{61875165} = "Willunga";
$areanames{en}->{61875166} = "Willunga";
$areanames{en}->{61875167} = "Yankalilla";
$areanames{en}->{61875168} = "Yankalilla";
$areanames{en}->{61875169} = "Blanchetown";
$areanames{en}->{61875170} = "Blanchetown";
$areanames{en}->{61875171} = "Lowbank";
$areanames{en}->{61875172} = "Lowbank";
$areanames{en}->{61875173} = "Morgan";
$areanames{en}->{61875174} = "Morgan";
$areanames{en}->{61875175} = "Taylorville";
$areanames{en}->{61875176} = "Taylorville";
$areanames{en}->{61875177} = "Waikerie";
$areanames{en}->{61875178} = "Waikerie";
$areanames{en}->{61875179} = "Victor\ Harbor";
$areanames{en}->{61875180} = "Hartley";
$areanames{en}->{61875181} = "Mount\ Pleasant";
$areanames{en}->{61875182} = "Goolwa";
$areanames{en}->{61875183} = "Halidon";
$areanames{en}->{61875184} = "Halidon";
$areanames{en}->{61875185} = "Karoonda";
$areanames{en}->{61875186} = "Karoonda";
$areanames{en}->{61875187} = "Lameroo";
$areanames{en}->{61875188} = "Lameroo";
$areanames{en}->{61875189} = "Kingscote";
$areanames{en}->{61875190} = "Narrung";
$areanames{en}->{61875191} = "Narrung";
$areanames{en}->{61875192} = "Peake";
$areanames{en}->{61875193} = "Peake";
$areanames{en}->{61875194} = "Peebinga";
$areanames{en}->{61875195} = "Peebinga";
$areanames{en}->{61875196} = "Policemans\ Point";
$areanames{en}->{61875197} = "Policemans\ Point";
$areanames{en}->{61875198} = "Hamley\ Bridge";
$areanames{en}->{61875199} = "Hamley\ Bridge";
$areanames{en}->{61875200} = "Karatta";
$areanames{en}->{61875201} = "Karatta";
$areanames{en}->{61875202} = "Kingscote";
$areanames{en}->{61875203} = "Kingscote";
$areanames{en}->{61875204} = "Parndana";
$areanames{en}->{61875205} = "Parndana";
$areanames{en}->{61875206} = "Penneshaw";
$areanames{en}->{61875207} = "Penneshaw";
$areanames{en}->{61875208} = "Callington";
$areanames{en}->{61875209} = "Callington";
$areanames{en}->{61875210} = "Bow\ Hill";
$areanames{en}->{61875211} = "Bow\ Hill";
$areanames{en}->{61875212} = "Bower";
$areanames{en}->{61875213} = "Bower";
$areanames{en}->{61875214} = "Walker\ Flat";
$areanames{en}->{61875215} = "Walker\ Flat";
$areanames{en}->{61875216} = "Gawler";
$areanames{en}->{61875217} = "Tailem\ Bend";
$areanames{en}->{61875218} = "Coonalpyn";
$areanames{en}->{61875219} = "Willunga";
$areanames{en}->{61875220} = "Berri";
$areanames{en}->{61875221} = "Meningie";
$areanames{en}->{61875222} = "Murray\ Bridge";
$areanames{en}->{61875223} = "Gawler";
$areanames{en}->{61875224} = "Victor\ Harbor";
$areanames{en}->{61875225} = "Tanunda";
$areanames{en}->{61875226} = "Berri";
$areanames{en}->{61875227} = "Mount\ Pleasant";
$areanames{en}->{61875228} = "Strathalbyn";
$areanames{en}->{61875229} = "Gawler";
$areanames{en}->{61875230} = "Gawler";
$areanames{en}->{61875231} = "Victor\ Harbor";
$areanames{en}->{61875232} = "Willunga";
$areanames{en}->{61875233} = "Gawler";
$areanames{en}->{61875234} = "Murray\ Bridge";
$areanames{en}->{61875235} = "Barmera";
$areanames{en}->{61875236} = "Renmark";
$areanames{en}->{61875237} = "Swan\ Reach";
$areanames{en}->{61875238} = "Tanunda";
$areanames{en}->{61875239} = "Victor\ Harbor";
$areanames{en}->{61875240} = "Gawler";
$areanames{en}->{61875241} = "Strathalbyn";
$areanames{en}->{61875242} = "Victor\ Harbor";
$areanames{en}->{61875243} = "Goolwa";
$areanames{en}->{61875244} = "Loxton";
$areanames{en}->{618752450} = "Barmera";
$areanames{en}->{618752451} = "Berri";
$areanames{en}->{618752452} = "Blanchetown";
$areanames{en}->{618752453} = "Bow\ Hill";
$areanames{en}->{618752454} = "Bower";
$areanames{en}->{618752455} = "Callington";
$areanames{en}->{618752456} = "Coonalpyn";
$areanames{en}->{618752457} = "Copeville";
$areanames{en}->{618752458} = "Culburra";
$areanames{en}->{618752459} = "Eudunda";
$areanames{en}->{618752460} = "Geranium";
$areanames{en}->{618752461} = "Goolwa";
$areanames{en}->{618752462} = "Gurrai";
$areanames{en}->{618752463} = "Halidon";
$areanames{en}->{618752464} = "Hartley";
$areanames{en}->{618752465} = "Kapunda";
$areanames{en}->{618752466} = "Karatta";
$areanames{en}->{618752467} = "Karoonda";
$areanames{en}->{618752468} = "Kingscote";
$areanames{en}->{618752469} = "Lameroo";
$areanames{en}->{618752470} = "Langhorne\ Creek";
$areanames{en}->{618752471} = "Lowbank";
$areanames{en}->{618752472} = "Loxton";
$areanames{en}->{618752473} = "Malinong";
$areanames{en}->{618752474} = "Mallala";
$areanames{en}->{618752475} = "Mannum";
$areanames{en}->{618752476} = "Mantung";
$areanames{en}->{618752477} = "Marama";
$areanames{en}->{618752478} = "Meningie";
$areanames{en}->{618752479} = "Meningie\ East";
$areanames{en}->{618752480} = "Milang";
$areanames{en}->{618752481} = "Morgan";
$areanames{en}->{618752482} = "Mount\ Pleasant";
$areanames{en}->{618752483} = "Murray\ Bridge";
$areanames{en}->{618752484} = "Mypolonga";
$areanames{en}->{618752485} = "Narrung";
$areanames{en}->{618752486} = "New\ Well";
$areanames{en}->{618752487} = "Parndana";
$areanames{en}->{618752488} = "Paruna";
$areanames{en}->{618752489} = "Peake";
$areanames{en}->{618752490} = "Peebinga";
$areanames{en}->{618752491} = "Penneshaw";
$areanames{en}->{618752492} = "Perponda";
$areanames{en}->{618752493} = "Pinnaroo";
$areanames{en}->{618752494} = "Policemans\ Point";
$areanames{en}->{618752495} = "Renmark";
$areanames{en}->{618752496} = "Robertstown";
$areanames{en}->{618752497} = "Sanderston";
$areanames{en}->{618752498} = "Sandleton";
$areanames{en}->{618752499} = "Sedan";
$areanames{en}->{618752500} = "Strathalbyn";
$areanames{en}->{618752501} = "Swan\ Reach";
$areanames{en}->{618752502} = "Tailem\ Bend";
$areanames{en}->{618752503} = "Taldra";
$areanames{en}->{618752504} = "Tanunda";
$areanames{en}->{618752505} = "Taplan";
$areanames{en}->{618752506} = "Taylorville";
$areanames{en}->{618752507} = "Truro";
$areanames{en}->{618752508} = "Two\ Wells";
$areanames{en}->{618752509} = "Victor\ Harbor";
$areanames{en}->{618752510} = "Waikerie";
$areanames{en}->{618752511} = "Walker\ Flat";
$areanames{en}->{618752512} = "Wanbi";
$areanames{en}->{618752513} = "Willunga";
$areanames{en}->{618752514} = "Windsor";
$areanames{en}->{618752515} = "Wunkar";
$areanames{en}->{618752516} = "Wynarka";
$areanames{en}->{618752517} = "Yankalilla";
$areanames{en}->{618752518} = "Yumali";
$areanames{en}->{618752519} = "Barmera";
$areanames{en}->{61875252} = "Blanchetown";
$areanames{en}->{61875253} = "Bow\ Hill";
$areanames{en}->{61875254} = "Bower";
$areanames{en}->{61875255} = "Copeville";
$areanames{en}->{61875256} = "Culburra";
$areanames{en}->{61875257} = "Geranium";
$areanames{en}->{61875258} = "Goolwa";
$areanames{en}->{61875259} = "Gurrai";
$areanames{en}->{61875260} = "Halidon";
$areanames{en}->{61875261} = "Kapunda";
$areanames{en}->{61875262} = "Karoonda";
$areanames{en}->{61875263} = "Lameroo";
$areanames{en}->{61875264} = "Lowbank";
$areanames{en}->{61875265} = "Malinong";
$areanames{en}->{61875266} = "Mallala";
$areanames{en}->{61875267} = "Goolwa";
$areanames{en}->{61875268} = "Marama";
$areanames{en}->{61875269} = "Meningie\ East";
$areanames{en}->{61875270} = "Mypolonga";
$areanames{en}->{61875271} = "New\ Well";
$areanames{en}->{61875272} = "Parndana";
$areanames{en}->{61875273} = "Paruna";
$areanames{en}->{61875274} = "Peebinga";
$areanames{en}->{61875275} = "Penneshaw";
$areanames{en}->{61875276} = "Robertstown";
$areanames{en}->{61875277} = "Sanderston";
$areanames{en}->{61875278} = "Sandleton";
$areanames{en}->{61875279} = "Sedan";
$areanames{en}->{61875280} = "Taldra";
$areanames{en}->{61875281} = "Taplan";
$areanames{en}->{61875282} = "Taylorville";
$areanames{en}->{61875283} = "Truro";
$areanames{en}->{61875284} = "Walker\ Flat";
$areanames{en}->{61875285} = "Wanbi";
$areanames{en}->{61875286} = "Wunkar";
$areanames{en}->{61875287} = "Wynarka";
$areanames{en}->{61875288} = "Yumali";
$areanames{en}->{61875289} = "Riverton";
$areanames{en}->{61875290} = "Barmera";
$areanames{en}->{61875291} = "Kingscote";
$areanames{en}->{618752920} = "Berri";
$areanames{en}->{618752921} = "Blanchetown";
$areanames{en}->{618752922} = "Bow\ Hill";
$areanames{en}->{618752923} = "Bower";
$areanames{en}->{618752924} = "Callington";
$areanames{en}->{618752925} = "Coonalpyn";
$areanames{en}->{618752926} = "Copeville";
$areanames{en}->{618752927} = "Culburra";
$areanames{en}->{618752928} = "Eudunda";
$areanames{en}->{618752929} = "Geranium";
$areanames{en}->{618752930} = "Goolwa";
$areanames{en}->{618752931} = "Gurrai";
$areanames{en}->{618752932} = "Halidon";
$areanames{en}->{618752933} = "Hartley";
$areanames{en}->{618752934} = "Kapunda";
$areanames{en}->{618752935} = "Karatta";
$areanames{en}->{618752936} = "Karoonda";
$areanames{en}->{618752937} = "Kingscote";
$areanames{en}->{618752938} = "Lameroo";
$areanames{en}->{618752939} = "Langhorne\ Creek";
$areanames{en}->{618752940} = "Lowbank";
$areanames{en}->{618752941} = "Loxton";
$areanames{en}->{618752942} = "Malinong";
$areanames{en}->{618752943} = "Mallala";
$areanames{en}->{618752944} = "Mannum";
$areanames{en}->{618752945} = "Mantung";
$areanames{en}->{618752946} = "Marama";
$areanames{en}->{618752947} = "Meningie";
$areanames{en}->{618752948} = "Meningie\ East";
$areanames{en}->{618752949} = "Milang";
$areanames{en}->{618752950} = "Morgan";
$areanames{en}->{618752951} = "Mount\ Pleasant";
$areanames{en}->{618752952} = "Murray\ Bridge";
$areanames{en}->{618752953} = "Mypolonga";
$areanames{en}->{618752954} = "Narrung";
$areanames{en}->{618752955} = "New\ Well";
$areanames{en}->{618752956} = "Parndana";
$areanames{en}->{618752957} = "Paruna";
$areanames{en}->{618752958} = "Peake";
$areanames{en}->{618752959} = "Peebinga";
$areanames{en}->{618752960} = "Penneshaw";
$areanames{en}->{618752961} = "Perponda";
$areanames{en}->{618752962} = "Pinnaroo";
$areanames{en}->{618752963} = "Policemans\ Point";
$areanames{en}->{618752964} = "Renmark";
$areanames{en}->{618752965} = "Robertstown";
$areanames{en}->{618752966} = "Sanderston";
$areanames{en}->{618752967} = "Sandleton";
$areanames{en}->{618752968} = "Sedan";
$areanames{en}->{618752969} = "Strathalbyn";
$areanames{en}->{618752970} = "Swan\ Reach";
$areanames{en}->{618752971} = "Tailem\ Bend";
$areanames{en}->{618752972} = "Taldra";
$areanames{en}->{618752973} = "Tanunda";
$areanames{en}->{618752974} = "Taplan";
$areanames{en}->{618752975} = "Taylorville";
$areanames{en}->{618752976} = "Truro";
$areanames{en}->{618752977} = "Two\ Wells";
$areanames{en}->{618752978} = "Victor\ Harbor";
$areanames{en}->{618752979} = "Waikerie";
$areanames{en}->{618752980} = "Walker\ Flat";
$areanames{en}->{618752981} = "Wanbi";
$areanames{en}->{618752982} = "Willunga";
$areanames{en}->{618752983} = "Windsor";
$areanames{en}->{618752984} = "Wunkar";
$areanames{en}->{618752985} = "Wynarka";
$areanames{en}->{618752986} = "Yankalilla";
$areanames{en}->{618752987} = "Yumali";
$areanames{en}->{618752988} = "Barmera";
$areanames{en}->{618752989} = "Berri";
$areanames{en}->{61875299} = "Yankalilla";
$areanames{en}->{618753000} = "Blanchetown";
$areanames{en}->{618753001} = "Bow\ Hill";
$areanames{en}->{618753002} = "Bower";
$areanames{en}->{618753003} = "Callington";
$areanames{en}->{618753004} = "Coonalpyn";
$areanames{en}->{618753005} = "Copeville";
$areanames{en}->{618753006} = "Culburra";
$areanames{en}->{618753007} = "Eudunda";
$areanames{en}->{618753008} = "Geranium";
$areanames{en}->{618753009} = "Goolwa";
$areanames{en}->{618753010} = "Gurrai";
$areanames{en}->{618753011} = "Halidon";
$areanames{en}->{618753012} = "Hartley";
$areanames{en}->{618753013} = "Kapunda";
$areanames{en}->{618753014} = "Karatta";
$areanames{en}->{618753015} = "Karoonda";
$areanames{en}->{618753016} = "Kingscote";
$areanames{en}->{618753017} = "Lameroo";
$areanames{en}->{618753018} = "Langhorne\ Creek";
$areanames{en}->{618753019} = "Lowbank";
$areanames{en}->{618753020} = "Loxton";
$areanames{en}->{618753021} = "Malinong";
$areanames{en}->{618753022} = "Mallala";
$areanames{en}->{618753023} = "Mannum";
$areanames{en}->{618753024} = "Mantung";
$areanames{en}->{618753025} = "Marama";
$areanames{en}->{618753026} = "Meningie";
$areanames{en}->{618753027} = "Meningie\ East";
$areanames{en}->{618753028} = "Milang";
$areanames{en}->{618753029} = "Morgan";
$areanames{en}->{618753030} = "Mount\ Pleasant";
$areanames{en}->{618753031} = "Murray\ Bridge";
$areanames{en}->{618753032} = "Mypolonga";
$areanames{en}->{618753033} = "Narrung";
$areanames{en}->{618753034} = "New\ Well";
$areanames{en}->{618753035} = "Parndana";
$areanames{en}->{618753036} = "Paruna";
$areanames{en}->{618753037} = "Peake";
$areanames{en}->{618753038} = "Peebinga";
$areanames{en}->{618753039} = "Penneshaw";
$areanames{en}->{618753040} = "Perponda";
$areanames{en}->{618753041} = "Pinnaroo";
$areanames{en}->{618753042} = "Policemans\ Point";
$areanames{en}->{618753043} = "Renmark";
$areanames{en}->{618753044} = "Robertstown";
$areanames{en}->{618753045} = "Sanderston";
$areanames{en}->{618753046} = "Sandleton";
$areanames{en}->{618753047} = "Sedan";
$areanames{en}->{618753048} = "Strathalbyn";
$areanames{en}->{618753049} = "Swan\ Reach";
$areanames{en}->{618753050} = "Tailem\ Bend";
$areanames{en}->{618753051} = "Taldra";
$areanames{en}->{618753052} = "Tanunda";
$areanames{en}->{618753053} = "Taplan";
$areanames{en}->{618753054} = "Taylorville";
$areanames{en}->{618753055} = "Truro";
$areanames{en}->{618753056} = "Two\ Wells";
$areanames{en}->{618753057} = "Victor\ Harbor";
$areanames{en}->{618753058} = "Waikerie";
$areanames{en}->{618753059} = "Walker\ Flat";
$areanames{en}->{61875306} = "Gawler";
$areanames{en}->{61875307} = "Gawler";
$areanames{en}->{61875308} = "Berri";
$areanames{en}->{618753090} = "Wanbi";
$areanames{en}->{618753091} = "Willunga";
$areanames{en}->{618753092} = "Windsor";
$areanames{en}->{618753093} = "Wunkar";
$areanames{en}->{618753094} = "Wynarka";
$areanames{en}->{618753095} = "Yankalilla";
$areanames{en}->{618753096} = "Yumali";
$areanames{en}->{618753097} = "Barmera";
$areanames{en}->{618753098} = "Berri";
$areanames{en}->{618753099} = "Blanchetown";
$areanames{en}->{618753100} = "Bow\ Hill";
$areanames{en}->{618753101} = "Bower";
$areanames{en}->{618753102} = "Callington";
$areanames{en}->{618753103} = "Coonalpyn";
$areanames{en}->{618753104} = "Copeville";
$areanames{en}->{618753105} = "Culburra";
$areanames{en}->{618753106} = "Eudunda";
$areanames{en}->{618753107} = "Geranium";
$areanames{en}->{618753108} = "Goolwa";
$areanames{en}->{618753109} = "Gurrai";
$areanames{en}->{61875311} = "Victor\ Harbor";
$areanames{en}->{61875312} = "Tanunda";
$areanames{en}->{618753130} = "Halidon";
$areanames{en}->{618753131} = "Hartley";
$areanames{en}->{618753132} = "Kapunda";
$areanames{en}->{618753133} = "Karatta";
$areanames{en}->{618753134} = "Karoonda";
$areanames{en}->{618753135} = "Kingscote";
$areanames{en}->{618753136} = "Lameroo";
$areanames{en}->{618753137} = "Langhorne\ Creek";
$areanames{en}->{618753138} = "Lowbank";
$areanames{en}->{618753139} = "Loxton";
$areanames{en}->{618753140} = "Malinong";
$areanames{en}->{618753141} = "Mallala";
$areanames{en}->{618753142} = "Mannum";
$areanames{en}->{618753143} = "Mantung";
$areanames{en}->{618753144} = "Marama";
$areanames{en}->{618753145} = "Meningie";
$areanames{en}->{618753146} = "Barmera";
$areanames{en}->{618753147} = "Berri";
$areanames{en}->{618753148} = "Blanchetown";
$areanames{en}->{618753149} = "Bow\ Hill";
$areanames{en}->{618753150} = "Bower";
$areanames{en}->{618753151} = "Callington";
$areanames{en}->{618753152} = "Coonalpyn";
$areanames{en}->{618753153} = "Copeville";
$areanames{en}->{618753154} = "Culburra";
$areanames{en}->{618753155} = "Eudunda";
$areanames{en}->{618753156} = "Geranium";
$areanames{en}->{618753157} = "Goolwa";
$areanames{en}->{618753158} = "Gurrai";
$areanames{en}->{618753159} = "Halidon";
$areanames{en}->{618753160} = "Hartley";
$areanames{en}->{618753161} = "Kapunda";
$areanames{en}->{618753162} = "Karatta";
$areanames{en}->{618753163} = "Karoonda";
$areanames{en}->{618753164} = "Kingscote";
$areanames{en}->{618753165} = "Lameroo";
$areanames{en}->{618753166} = "Langhorne\ Creek";
$areanames{en}->{618753167} = "Lowbank";
$areanames{en}->{618753168} = "Loxton";
$areanames{en}->{618753169} = "Malinong";
$areanames{en}->{618753170} = "Mallala";
$areanames{en}->{618753171} = "Mannum";
$areanames{en}->{618753172} = "Mantung";
$areanames{en}->{618753173} = "Marama";
$areanames{en}->{618753174} = "Meningie";
$areanames{en}->{618753175} = "Meningie\ East";
$areanames{en}->{618753176} = "Milang";
$areanames{en}->{618753177} = "Morgan";
$areanames{en}->{618753178} = "Mount\ Pleasant";
$areanames{en}->{618753179} = "Murray\ Bridge";
$areanames{en}->{618753180} = "Mypolonga";
$areanames{en}->{618753181} = "Narrung";
$areanames{en}->{618753182} = "New\ Well";
$areanames{en}->{618753183} = "Parndana";
$areanames{en}->{618753184} = "Paruna";
$areanames{en}->{618753185} = "Peake";
$areanames{en}->{618753186} = "Peebinga";
$areanames{en}->{618753187} = "Penneshaw";
$areanames{en}->{618753188} = "Perponda";
$areanames{en}->{618753189} = "Pinnaroo";
$areanames{en}->{618753190} = "Policemans\ Point";
$areanames{en}->{618753191} = "Renmark";
$areanames{en}->{618753192} = "Robertstown";
$areanames{en}->{618753193} = "Sanderston";
$areanames{en}->{618753194} = "Sandleton";
$areanames{en}->{618753195} = "Sedan";
$areanames{en}->{618753196} = "Strathalbyn";
$areanames{en}->{618753197} = "Swan\ Reach";
$areanames{en}->{618753198} = "Tailem\ Bend";
$areanames{en}->{618753199} = "Taldra";
$areanames{en}->{618753200} = "Tanunda";
$areanames{en}->{618753201} = "Taplan";
$areanames{en}->{618753202} = "Taylorville";
$areanames{en}->{618753203} = "Truro";
$areanames{en}->{618753204} = "Two\ Wells";
$areanames{en}->{618753205} = "Victor\ Harbor";
$areanames{en}->{618753206} = "Waikerie";
$areanames{en}->{618753207} = "Walker\ Flat";
$areanames{en}->{618753208} = "Wanbi";
$areanames{en}->{618753209} = "Willunga";
$areanames{en}->{618753210} = "Windsor";
$areanames{en}->{618753211} = "Wunkar";
$areanames{en}->{618753212} = "Wynarka";
$areanames{en}->{618753213} = "Yankalilla";
$areanames{en}->{618753214} = "Yumali";
$areanames{en}->{618753215} = "Meningie\ East";
$areanames{en}->{618753216} = "Milang";
$areanames{en}->{618753217} = "Morgan";
$areanames{en}->{618753218} = "Mount\ Pleasant";
$areanames{en}->{618753219} = "Murray\ Bridge";
$areanames{en}->{61875322} = "Lameroo";
$areanames{en}->{61875323} = "Lameroo";
$areanames{en}->{61875324} = "Lameroo";
$areanames{en}->{61875325} = "Victor\ Harbor";
$areanames{en}->{61875326} = "Victor\ Harbor";
$areanames{en}->{61875327} = "Victor\ Harbor";
$areanames{en}->{618753280} = "Mypolonga";
$areanames{en}->{618753281} = "Narrung";
$areanames{en}->{618753282} = "New\ Well";
$areanames{en}->{618753283} = "Parndana";
$areanames{en}->{618753284} = "Paruna";
$areanames{en}->{618753285} = "Peake";
$areanames{en}->{618753286} = "Peebinga";
$areanames{en}->{618753287} = "Penneshaw";
$areanames{en}->{618753288} = "Perponda";
$areanames{en}->{618753289} = "Pinnaroo";
$areanames{en}->{618753290} = "Policemans\ Point";
$areanames{en}->{618753291} = "Renmark";
$areanames{en}->{618753292} = "Robertstown";
$areanames{en}->{618753293} = "Sanderston";
$areanames{en}->{618753294} = "Sandleton";
$areanames{en}->{618753295} = "Sedan";
$areanames{en}->{618753296} = "Strathalbyn";
$areanames{en}->{618753297} = "Swan\ Reach";
$areanames{en}->{618753298} = "Tailem\ Bend";
$areanames{en}->{618753299} = "Taldra";
$areanames{en}->{618753300} = "Tanunda";
$areanames{en}->{618753301} = "Taplan";
$areanames{en}->{618753302} = "Taylorville";
$areanames{en}->{618753303} = "Truro";
$areanames{en}->{618753304} = "Two\ Wells";
$areanames{en}->{618753305} = "Victor\ Harbor";
$areanames{en}->{618753306} = "Waikerie";
$areanames{en}->{618753307} = "Walker\ Flat";
$areanames{en}->{618753308} = "Wanbi";
$areanames{en}->{618753309} = "Willunga";
$areanames{en}->{618753310} = "Windsor";
$areanames{en}->{618753311} = "Wunkar";
$areanames{en}->{618753312} = "Wynarka";
$areanames{en}->{618753313} = "Yankalilla";
$areanames{en}->{618753314} = "Yumali";
$areanames{en}->{618753315} = "Barmera";
$areanames{en}->{618753316} = "Berri";
$areanames{en}->{618753317} = "Blanchetown";
$areanames{en}->{618753318} = "Bow\ Hill";
$areanames{en}->{618753319} = "Bower";
$areanames{en}->{618753320} = "Callington";
$areanames{en}->{618753321} = "Coonalpyn";
$areanames{en}->{618753322} = "Copeville";
$areanames{en}->{618753323} = "Culburra";
$areanames{en}->{618753324} = "Eudunda";
$areanames{en}->{618753325} = "Geranium";
$areanames{en}->{618753326} = "Goolwa";
$areanames{en}->{618753327} = "Gurrai";
$areanames{en}->{618753328} = "Halidon";
$areanames{en}->{618753329} = "Hartley";
$areanames{en}->{618753330} = "Kapunda";
$areanames{en}->{618753331} = "Karatta";
$areanames{en}->{618753332} = "Karoonda";
$areanames{en}->{618753333} = "Kingscote";
$areanames{en}->{618753334} = "Lameroo";
$areanames{en}->{618753335} = "Langhorne\ Creek";
$areanames{en}->{618753336} = "Lowbank";
$areanames{en}->{618753337} = "Loxton";
$areanames{en}->{618753338} = "Malinong";
$areanames{en}->{618753339} = "Mallala";
$areanames{en}->{618753340} = "Mannum";
$areanames{en}->{618753341} = "Mantung";
$areanames{en}->{618753342} = "Marama";
$areanames{en}->{618753343} = "Meningie";
$areanames{en}->{618753344} = "Meningie\ East";
$areanames{en}->{618753345} = "Milang";
$areanames{en}->{618753346} = "Morgan";
$areanames{en}->{618753347} = "Mount\ Pleasant";
$areanames{en}->{618753348} = "Murray\ Bridge";
$areanames{en}->{618753349} = "Mypolonga";
$areanames{en}->{618753350} = "Narrung";
$areanames{en}->{618753351} = "New\ Well";
$areanames{en}->{618753352} = "Parndana";
$areanames{en}->{618753353} = "Paruna";
$areanames{en}->{618753354} = "Peake";
$areanames{en}->{618753355} = "Peebinga";
$areanames{en}->{618753356} = "Penneshaw";
$areanames{en}->{618753357} = "Perponda";
$areanames{en}->{618753358} = "Pinnaroo";
$areanames{en}->{618753359} = "Policemans\ Point";
$areanames{en}->{618753360} = "Renmark";
$areanames{en}->{618753361} = "Robertstown";
$areanames{en}->{618753362} = "Sanderston";
$areanames{en}->{618753363} = "Sandleton";
$areanames{en}->{618753364} = "Sedan";
$areanames{en}->{618753365} = "Strathalbyn";
$areanames{en}->{618753366} = "Swan\ Reach";
$areanames{en}->{618753367} = "Tailem\ Bend";
$areanames{en}->{618753368} = "Taldra";
$areanames{en}->{618753369} = "Tanunda";
$areanames{en}->{618753370} = "Taplan";
$areanames{en}->{618753371} = "Taylorville";
$areanames{en}->{618753372} = "Truro";
$areanames{en}->{618753373} = "Two\ Wells";
$areanames{en}->{618753374} = "Victor\ Harbor";
$areanames{en}->{618753375} = "Waikerie";
$areanames{en}->{618753376} = "Walker\ Flat";
$areanames{en}->{618753377} = "Wanbi";
$areanames{en}->{618753378} = "Willunga";
$areanames{en}->{618753379} = "Windsor";
$areanames{en}->{618753380} = "Wunkar";
$areanames{en}->{618753381} = "Wynarka";
$areanames{en}->{618753382} = "Yankalilla";
$areanames{en}->{618753383} = "Yumali";
$areanames{en}->{618753384} = "Barmera";
$areanames{en}->{618753385} = "Berri";
$areanames{en}->{618753386} = "Blanchetown";
$areanames{en}->{618753387} = "Bow\ Hill";
$areanames{en}->{618753388} = "Bower";
$areanames{en}->{618753389} = "Callington";
$areanames{en}->{618753390} = "Coonalpyn";
$areanames{en}->{618753391} = "Copeville";
$areanames{en}->{618753392} = "Culburra";
$areanames{en}->{618753393} = "Eudunda";
$areanames{en}->{618753394} = "Geranium";
$areanames{en}->{618753395} = "Goolwa";
$areanames{en}->{618753396} = "Gurrai";
$areanames{en}->{618753397} = "Halidon";
$areanames{en}->{618753398} = "Hartley";
$areanames{en}->{618753399} = "Kapunda";
$areanames{en}->{618753400} = "Karatta";
$areanames{en}->{618753401} = "Karoonda";
$areanames{en}->{618753402} = "Kingscote";
$areanames{en}->{618753403} = "Lameroo";
$areanames{en}->{618753404} = "Langhorne\ Creek";
$areanames{en}->{618753405} = "Lowbank";
$areanames{en}->{618753406} = "Loxton";
$areanames{en}->{618753407} = "Malinong";
$areanames{en}->{618753408} = "Mallala";
$areanames{en}->{618753409} = "Mannum";
$areanames{en}->{618753410} = "Mantung";
$areanames{en}->{618753411} = "Marama";
$areanames{en}->{618753412} = "Meningie";
$areanames{en}->{618753413} = "Meningie\ East";
$areanames{en}->{618753414} = "Milang";
$areanames{en}->{618753415} = "Morgan";
$areanames{en}->{618753416} = "Mount\ Pleasant";
$areanames{en}->{618753417} = "Murray\ Bridge";
$areanames{en}->{618753418} = "Mypolonga";
$areanames{en}->{618753419} = "Narrung";
$areanames{en}->{618753420} = "New\ Well";
$areanames{en}->{618753421} = "Parndana";
$areanames{en}->{618753422} = "Paruna";
$areanames{en}->{618753423} = "Peake";
$areanames{en}->{618753424} = "Peebinga";
$areanames{en}->{618753425} = "Penneshaw";
$areanames{en}->{618753426} = "Perponda";
$areanames{en}->{618753427} = "Pinnaroo";
$areanames{en}->{618753428} = "Policemans\ Point";
$areanames{en}->{618753429} = "Renmark";
$areanames{en}->{618753430} = "Robertstown";
$areanames{en}->{618753431} = "Sanderston";
$areanames{en}->{618753432} = "Sandleton";
$areanames{en}->{618753433} = "Sedan";
$areanames{en}->{618753434} = "Strathalbyn";
$areanames{en}->{618753435} = "Swan\ Reach";
$areanames{en}->{618753436} = "Tailem\ Bend";
$areanames{en}->{618753437} = "Taldra";
$areanames{en}->{618753438} = "Tanunda";
$areanames{en}->{618753439} = "Taplan";
$areanames{en}->{618753440} = "Taylorville";
$areanames{en}->{618753441} = "Truro";
$areanames{en}->{618753442} = "Two\ Wells";
$areanames{en}->{618753443} = "Victor\ Harbor";
$areanames{en}->{618753444} = "Waikerie";
$areanames{en}->{618753445} = "Walker\ Flat";
$areanames{en}->{618753446} = "Wanbi";
$areanames{en}->{618753447} = "Willunga";
$areanames{en}->{618753448} = "Windsor";
$areanames{en}->{618753449} = "Wunkar";
$areanames{en}->{618753450} = "Wynarka";
$areanames{en}->{618753451} = "Yankalilla";
$areanames{en}->{618753452} = "Yumali";
$areanames{en}->{618753453} = "Barmera";
$areanames{en}->{618753454} = "Berri";
$areanames{en}->{618753455} = "Blanchetown";
$areanames{en}->{618753456} = "Bow\ Hill";
$areanames{en}->{618753457} = "Bower";
$areanames{en}->{618753458} = "Callington";
$areanames{en}->{618753459} = "Coonalpyn";
$areanames{en}->{61875346} = "Tailem\ Bend";
$areanames{en}->{618753470} = "Copeville";
$areanames{en}->{618753471} = "Culburra";
$areanames{en}->{618753472} = "Eudunda";
$areanames{en}->{618753473} = "Geranium";
$areanames{en}->{618753474} = "Goolwa";
$areanames{en}->{618753475} = "Gurrai";
$areanames{en}->{618753476} = "Halidon";
$areanames{en}->{618753477} = "Hartley";
$areanames{en}->{618753478} = "Kapunda";
$areanames{en}->{618753479} = "Karatta";
$areanames{en}->{618753480} = "Karoonda";
$areanames{en}->{618753481} = "Kingscote";
$areanames{en}->{618753482} = "Lameroo";
$areanames{en}->{618753483} = "Langhorne\ Creek";
$areanames{en}->{618753484} = "Lowbank";
$areanames{en}->{618753485} = "Loxton";
$areanames{en}->{618753486} = "Malinong";
$areanames{en}->{618753487} = "Mallala";
$areanames{en}->{618753488} = "Mannum";
$areanames{en}->{618753489} = "Mantung";
$areanames{en}->{618753490} = "Marama";
$areanames{en}->{618753491} = "Meningie";
$areanames{en}->{618753492} = "Meningie\ East";
$areanames{en}->{618753493} = "Milang";
$areanames{en}->{618753494} = "Morgan";
$areanames{en}->{618753495} = "Mount\ Pleasant";
$areanames{en}->{618753496} = "Murray\ Bridge";
$areanames{en}->{618753497} = "Mypolonga";
$areanames{en}->{618753498} = "Narrung";
$areanames{en}->{618753499} = "New\ Well";
$areanames{en}->{618753500} = "Parndana";
$areanames{en}->{618753501} = "Paruna";
$areanames{en}->{618753502} = "Peake";
$areanames{en}->{618753503} = "Peebinga";
$areanames{en}->{618753504} = "Penneshaw";
$areanames{en}->{618753505} = "Perponda";
$areanames{en}->{618753506} = "Pinnaroo";
$areanames{en}->{618753507} = "Policemans\ Point";
$areanames{en}->{618753508} = "Renmark";
$areanames{en}->{618753509} = "Robertstown";
$areanames{en}->{618753510} = "Sanderston";
$areanames{en}->{618753511} = "Sandleton";
$areanames{en}->{618753512} = "Sedan";
$areanames{en}->{618753513} = "Strathalbyn";
$areanames{en}->{618753514} = "Swan\ Reach";
$areanames{en}->{618753515} = "Tailem\ Bend";
$areanames{en}->{618753516} = "Taldra";
$areanames{en}->{618753517} = "Tanunda";
$areanames{en}->{618753518} = "Taplan";
$areanames{en}->{618753519} = "Taylorville";
$areanames{en}->{618753520} = "Truro";
$areanames{en}->{618753521} = "Two\ Wells";
$areanames{en}->{618753522} = "Victor\ Harbor";
$areanames{en}->{618753523} = "Waikerie";
$areanames{en}->{618753524} = "Walker\ Flat";
$areanames{en}->{618753525} = "Wanbi";
$areanames{en}->{618753526} = "Willunga";
$areanames{en}->{618753527} = "Windsor";
$areanames{en}->{618753528} = "Wunkar";
$areanames{en}->{618753529} = "Wynarka";
$areanames{en}->{618753530} = "Yankalilla";
$areanames{en}->{618753531} = "Yumali";
$areanames{en}->{61875354} = "Kapunda";
$areanames{en}->{61875360} = "Callington";
$areanames{en}->{61875379} = "Langhorne\ Creek";
$areanames{en}->{61875390} = "Meningie";
$areanames{en}->{61875409} = "Policemans\ Point";
$areanames{en}->{61875420} = "Tailem\ Bend";
$areanames{en}->{61875433} = "Mannum";
$areanames{en}->{61875550} = "Murray\ Bridge";
$areanames{en}->{61875551} = "Windsor";
$areanames{en}->{61875552} = "Willunga";
$areanames{en}->{61875553} = "Berri";
$areanames{en}->{61875554} = "Berri";
$areanames{en}->{61875555} = "Berri";
$areanames{en}->{61875556} = "Gawler";
$areanames{en}->{61875557} = "Wunkar";
$areanames{en}->{61875558} = "Wunkar";
$areanames{en}->{61875559} = "Paruna";
$areanames{en}->{61875560} = "Paruna";
$areanames{en}->{61875561} = "Taldra";
$areanames{en}->{61875562} = "Taldra";
$areanames{en}->{61875563} = "Taplan";
$areanames{en}->{61875564} = "Taplan";
$areanames{en}->{61875565} = "Wanbi";
$areanames{en}->{61875566} = "Wanbi";
$areanames{en}->{61875567} = "Copeville";
$areanames{en}->{61875568} = "Copeville";
$areanames{en}->{61875569} = "Geranium";
$areanames{en}->{61875570} = "Geranium";
$areanames{en}->{61875571} = "Gurrai";
$areanames{en}->{61875572} = "Gurrai";
$areanames{en}->{61875573} = "Mount\ Pleasant";
$areanames{en}->{61875574} = "Langhorne\ Creek";
$areanames{en}->{61875575} = "Freeling";
$areanames{en}->{61875576} = "Callington";
$areanames{en}->{61875577} = "Gawler";
$areanames{en}->{61875578} = "Murray\ Bridge";
$areanames{en}->{61875579} = "Gawler";
$areanames{en}->{6187558} = "Gawler";
$areanames{en}->{6187559} = "Murray\ Bridge";
$areanames{en}->{61875998} = "Willunga";
$areanames{en}->{61875999} = "Strathalbyn";
$areanames{en}->{61876000} = "Ceduna";
$areanames{en}->{61876001} = "Coorabie";
$areanames{en}->{61876002} = "Courela";
$areanames{en}->{61876003} = "Great\ Bight";
$areanames{en}->{61876004} = "Mudamuckla";
$areanames{en}->{61876005} = "Nunjikompita";
$areanames{en}->{61876006} = "Penong";
$areanames{en}->{61876007} = "Poochera";
$areanames{en}->{61876008} = "Port\ Kenny";
$areanames{en}->{61876009} = "Streaky\ Bay";
$areanames{en}->{61876010} = "Wirrulla";
$areanames{en}->{61876011} = "Everard";
$areanames{en}->{61876012} = "Indian\ Pacific";
$areanames{en}->{61876013} = "Marla";
$areanames{en}->{61876014} = "Mintabie";
$areanames{en}->{61876015} = "Booleroo\ Centre";
$areanames{en}->{61876016} = "Caltowie";
$areanames{en}->{61876017} = "Georgetown";
$areanames{en}->{61876018} = "Gladstone";
$areanames{en}->{61876019} = "Jamestown";
$areanames{en}->{61876020} = "Laura";
$areanames{en}->{61876021} = "Melrose";
$areanames{en}->{61876022} = "Willowie";
$areanames{en}->{61876023} = "Wilmington";
$areanames{en}->{61876024} = "Carrieton";
$areanames{en}->{61876025} = "Herbert";
$areanames{en}->{61876026} = "Morchard";
$areanames{en}->{61876027} = "Orroroo";
$areanames{en}->{61876028} = "Peterborough";
$areanames{en}->{61876029} = "Terowie";
$areanames{en}->{61876030} = "Yunta";
$areanames{en}->{61876031} = "Hawker";
$areanames{en}->{61876032} = "Iron\ Baron";
$areanames{en}->{61876033} = "Iron\ Knob";
$areanames{en}->{61876034} = "Kelly";
$areanames{en}->{61876035} = "Kimba";
$areanames{en}->{61876036} = "Port\ Augusta";
$areanames{en}->{61876037} = "Quorn";
$areanames{en}->{61876038} = "The\ Ranges";
$areanames{en}->{61876039} = "Whyalla";
$areanames{en}->{61876040} = "Wilpena";
$areanames{en}->{61876041} = "Arno\ Bay";
$areanames{en}->{61876042} = "Bayley\ Plains";
$areanames{en}->{61876043} = "Cleve";
$areanames{en}->{61876044} = "Coffin\ Bay";
$areanames{en}->{61876045} = "Coulta";
$areanames{en}->{61876046} = "Cowell";
$areanames{en}->{61876047} = "Cummins";
$areanames{en}->{61876048} = "Darke\ Peak";
$areanames{en}->{61876049} = "Elliston";
$areanames{en}->{61876050} = "Kapinnie";
$areanames{en}->{61876051} = "Koongawa";
$areanames{en}->{61876052} = "Koppio";
$areanames{en}->{61876053} = "Kyancutta";
$areanames{en}->{61876054} = "Lock";
$areanames{en}->{61876055} = "Miltalie";
$areanames{en}->{61876056} = "Minnipa";
$areanames{en}->{61876057} = "Mount\ Hope";
$areanames{en}->{61876058} = "Port\ Lincoln";
$areanames{en}->{61876059} = "Port\ Neill";
$areanames{en}->{61876060} = "Rudall";
$areanames{en}->{61876061} = "Sheringa";
$areanames{en}->{61876062} = "Sleaford\ Mere";
$areanames{en}->{61876063} = "Spilsby";
$areanames{en}->{61876064} = "Tooligie\ Hill";
$areanames{en}->{61876065} = "Tumby\ Bay";
$areanames{en}->{61876066} = "Ungarra";
$areanames{en}->{61876067} = "Wanilla";
$areanames{en}->{61876068} = "Wharminda";
$areanames{en}->{61876069} = "Wudinna";
$areanames{en}->{61876070} = "Yabmana";
$areanames{en}->{61876071} = "Yeelanna";
$areanames{en}->{61876072} = "Crystal\ Brook";
$areanames{en}->{61876073} = "Mambray\ Creek";
$areanames{en}->{61876074} = "Nelshaby";
$areanames{en}->{61876075} = "Port\ Broughton";
$areanames{en}->{61876076} = "Port\ Pirie";
$areanames{en}->{61876077} = "Redhill";
$areanames{en}->{61876078} = "Wandearah\ East";
$areanames{en}->{61876079} = "Andamooka";
$areanames{en}->{61876080} = "Coober\ Pedy";
$areanames{en}->{61876081} = "Frome";
$areanames{en}->{61876082} = "Gairdner";
$areanames{en}->{61876083} = "Glendambo";
$areanames{en}->{61876084} = "Leigh\ Creek\ South";
$areanames{en}->{61876085} = "Roxby\ Downs";
$areanames{en}->{61876086} = "Tarcoola";
$areanames{en}->{61876087} = "Woomera";
$areanames{en}->{61876088} = "Port\ Lincoln";
$areanames{en}->{61876089} = "Whyalla";
$areanames{en}->{61876090} = "Whyalla";
$areanames{en}->{61876091} = "Port\ Lincoln";
$areanames{en}->{61876092} = "Caltowie";
$areanames{en}->{61876093} = "Caltowie";
$areanames{en}->{61876094} = "Georgetown";
$areanames{en}->{61876095} = "Georgetown";
$areanames{en}->{61876096} = "Herbert";
$areanames{en}->{61876097} = "Herbert";
$areanames{en}->{61876098} = "Laura";
$areanames{en}->{61876099} = "Laura";
$areanames{en}->{61876100} = "Peterborough";
$areanames{en}->{61876101} = "Peterborough";
$areanames{en}->{61876102} = "Ceduna";
$areanames{en}->{61876103} = "Ceduna";
$areanames{en}->{61876104} = "Terowie";
$areanames{en}->{61876105} = "Terowie";
$areanames{en}->{61876106} = "Hawker";
$areanames{en}->{61876107} = "Hawker";
$areanames{en}->{61876108} = "Port\ Augusta";
$areanames{en}->{61876109} = "Port\ Augusta";
$areanames{en}->{61876110} = "Quorn";
$areanames{en}->{61876111} = "Quorn";
$areanames{en}->{61876112} = "Whyalla";
$areanames{en}->{61876113} = "Whyalla";
$areanames{en}->{61876114} = "Port\ Lincoln";
$areanames{en}->{61876115} = "Port\ Lincoln";
$areanames{en}->{61876116} = "Spilsby";
$areanames{en}->{61876117} = "Spilsby";
$areanames{en}->{61876118} = "Crystal\ Brook";
$areanames{en}->{61876119} = "Crystal\ Brook";
$areanames{en}->{61876120} = "Carrieton";
$areanames{en}->{61876121} = "Carrieton";
$areanames{en}->{61876122} = "Nelshaby";
$areanames{en}->{61876123} = "Nelshaby";
$areanames{en}->{61876124} = "Port\ Broughton";
$areanames{en}->{61876125} = "Port\ Broughton";
$areanames{en}->{61876126} = "Port\ Pirie";
$areanames{en}->{61876127} = "Port\ Pirie";
$areanames{en}->{61876128} = "Redhill";
$areanames{en}->{61876129} = "Redhill";
$areanames{en}->{61876130} = "Wandearah\ East";
$areanames{en}->{61876131} = "Wandearah\ East";
$areanames{en}->{61876132} = "Coober\ Pedy";
$areanames{en}->{61876133} = "Coober\ Pedy";
$areanames{en}->{61876134} = "Roxby\ Downs";
$areanames{en}->{61876135} = "Roxby\ Downs";
$areanames{en}->{61876136} = "Woomera";
$areanames{en}->{61876137} = "Woomera";
$areanames{en}->{61876138} = "Mambray\ Creek";
$areanames{en}->{61876139} = "Mambray\ Creek";
$areanames{en}->{61876140} = "Morchard";
$areanames{en}->{61876141} = "Morchard";
$areanames{en}->{61876142} = "The\ Ranges";
$areanames{en}->{61876143} = "The\ Ranges";
$areanames{en}->{61876144} = "Iron\ Baron";
$areanames{en}->{61876145} = "Iron\ Baron";
$areanames{en}->{61876146} = "Iron\ Knob";
$areanames{en}->{61876147} = "Iron\ Knob";
$areanames{en}->{61876148} = "Wilpena";
$areanames{en}->{61876149} = "Wilpena";
$areanames{en}->{61876150} = "Yeelanna";
$areanames{en}->{61876151} = "Yeelanna";
$areanames{en}->{61876152} = "Cleve";
$areanames{en}->{61876153} = "Cleve";
$areanames{en}->{61876154} = "Coffin\ Bay";
$areanames{en}->{61876155} = "Coffin\ Bay";
$areanames{en}->{61876156} = "Coulta";
$areanames{en}->{61876157} = "Coulta";
$areanames{en}->{61876158} = "Cowell";
$areanames{en}->{61876159} = "Cowell";
$areanames{en}->{61876160} = "Cummins";
$areanames{en}->{61876161} = "Cummins";
$areanames{en}->{61876162} = "Koppio";
$areanames{en}->{61876163} = "Koppio";
$areanames{en}->{61876164} = "Sleaford\ Mere";
$areanames{en}->{61876165} = "Sleaford\ Mere";
$areanames{en}->{61876166} = "Tumby\ Bay";
$areanames{en}->{61876167} = "Tumby\ Bay";
$areanames{en}->{61876168} = "Ungarra";
$areanames{en}->{61876169} = "Ungarra";
$areanames{en}->{61876170} = "Wanilla";
$areanames{en}->{61876171} = "Wanilla";
$areanames{en}->{61876172} = "Courela";
$areanames{en}->{61876173} = "Courela";
$areanames{en}->{61876174} = "Mudamuckla";
$areanames{en}->{61876175} = "Mudamuckla";
$areanames{en}->{61876176} = "Nunjikompita";
$areanames{en}->{61876177} = "Nunjikompita";
$areanames{en}->{61876178} = "Penong";
$areanames{en}->{61876179} = "Penong";
$areanames{en}->{61876180} = "Everard";
$areanames{en}->{61876181} = "Everard";
$areanames{en}->{61876182} = "Indian\ Pacific";
$areanames{en}->{61876183} = "Indian\ Pacific";
$areanames{en}->{61876184} = "Booleroo\ Centre";
$areanames{en}->{61876185} = "Booleroo\ Centre";
$areanames{en}->{61876186} = "Melrose";
$areanames{en}->{61876187} = "Melrose";
$areanames{en}->{61876188} = "Wilmington";
$areanames{en}->{61876189} = "Wilmington";
$areanames{en}->{61876190} = "Glendambo";
$areanames{en}->{61876191} = "Glendambo";
$areanames{en}->{61876192} = "Frome";
$areanames{en}->{61876193} = "Frome";
$areanames{en}->{61876194} = "Coorabie";
$areanames{en}->{61876195} = "Coorabie";
$areanames{en}->{61876196} = "Great\ Bight";
$areanames{en}->{61876197} = "Great\ Bight";
$areanames{en}->{61876198} = "Kapinnie";
$areanames{en}->{61876199} = "Kapinnie";
$areanames{en}->{61876200} = "Kelly";
$areanames{en}->{61876201} = "Kelly";
$areanames{en}->{61876202} = "Kimba";
$areanames{en}->{61876203} = "Kimba";
$areanames{en}->{61876204} = "Koongawa";
$areanames{en}->{61876205} = "Koongawa";
$areanames{en}->{61876206} = "Kyancutta";
$areanames{en}->{61876207} = "Kyancutta";
$areanames{en}->{61876208} = "Leigh\ Creek\ South";
$areanames{en}->{61876209} = "Leigh\ Creek\ South";
$areanames{en}->{61876210} = "Lock";
$areanames{en}->{61876211} = "Lock";
$areanames{en}->{61876212} = "Marla";
$areanames{en}->{61876213} = "Marla";
$areanames{en}->{61876214} = "Miltalie";
$areanames{en}->{61876215} = "Miltalie";
$areanames{en}->{61876216} = "Minnipa";
$areanames{en}->{61876217} = "Minnipa";
$areanames{en}->{61876218} = "Mintabie";
$areanames{en}->{61876219} = "Mintabie";
$areanames{en}->{61876220} = "Mount\ Hope";
$areanames{en}->{61876221} = "Mount\ Hope";
$areanames{en}->{61876222} = "Poochera";
$areanames{en}->{61876223} = "Poochera";
$areanames{en}->{61876224} = "Port\ Kenny";
$areanames{en}->{61876225} = "Port\ Kenny";
$areanames{en}->{61876226} = "Port\ Neill";
$areanames{en}->{61876227} = "Port\ Neill";
$areanames{en}->{61876228} = "Streaky\ Bay";
$areanames{en}->{61876229} = "Streaky\ Bay";
$areanames{en}->{61876230} = "Tarcoola";
$areanames{en}->{61876231} = "Tarcoola";
$areanames{en}->{61876232} = "Wirrulla";
$areanames{en}->{61876233} = "Wirrulla";
$areanames{en}->{61876234} = "Yabmana";
$areanames{en}->{61876235} = "Yabmana";
$areanames{en}->{61876236} = "Yunta";
$areanames{en}->{61876237} = "Yunta";
$areanames{en}->{61876238} = "Port\ Augusta";
$areanames{en}->{61876239} = "Port\ Pirie";
$areanames{en}->{61876240} = "Port\ Lincoln";
$areanames{en}->{61876241} = "Port\ Lincoln";
$areanames{en}->{61876242} = "Port\ Lincoln";
$areanames{en}->{61876243} = "Port\ Pirie";
$areanames{en}->{61876244} = "Whyalla";
$areanames{en}->{61876245} = "Port\ Augusta";
$areanames{en}->{61876246} = "Port\ Lincoln";
$areanames{en}->{61876247} = "Port\ Augusta";
$areanames{en}->{61876248} = "Port\ Pirie";
$areanames{en}->{61876249} = "Whyalla";
$areanames{en}->{61876250} = "Redhill";
$areanames{en}->{61876251} = "Coober\ Pedy";
$areanames{en}->{61876252} = "Port\ Augusta";
$areanames{en}->{61876253} = "Port\ Lincoln";
$areanames{en}->{61876254} = "Port\ Pirie";
$areanames{en}->{61876255} = "Port\ Pirie";
$areanames{en}->{618762560} = "Andamooka";
$areanames{en}->{618762561} = "Arno\ Bay";
$areanames{en}->{618762562} = "Bayley\ Plains";
$areanames{en}->{618762563} = "Booleroo\ Centre";
$areanames{en}->{618762564} = "Caltowie";
$areanames{en}->{618762565} = "Carrieton";
$areanames{en}->{618762566} = "Ceduna";
$areanames{en}->{618762567} = "Cleve";
$areanames{en}->{618762568} = "Coffin\ Bay";
$areanames{en}->{618762569} = "Coober\ Pedy";
$areanames{en}->{618762570} = "Coorabie";
$areanames{en}->{618762571} = "Coulta";
$areanames{en}->{618762572} = "Courela";
$areanames{en}->{618762573} = "Cowell";
$areanames{en}->{618762574} = "Crystal\ Brook";
$areanames{en}->{618762575} = "Cummins";
$areanames{en}->{618762576} = "Darke\ Peak";
$areanames{en}->{618762577} = "Elliston";
$areanames{en}->{618762578} = "Everard";
$areanames{en}->{618762579} = "Frome";
$areanames{en}->{618762580} = "Gairdner";
$areanames{en}->{618762581} = "Georgetown";
$areanames{en}->{618762582} = "Gladstone";
$areanames{en}->{618762583} = "Glendambo";
$areanames{en}->{618762584} = "Great\ Bight";
$areanames{en}->{618762585} = "Hawker";
$areanames{en}->{618762586} = "Herbert";
$areanames{en}->{618762587} = "Indian\ Pacific";
$areanames{en}->{618762588} = "Iron\ Baron";
$areanames{en}->{618762589} = "Iron\ Knob";
$areanames{en}->{618762590} = "Jamestown";
$areanames{en}->{618762591} = "Kapinnie";
$areanames{en}->{618762592} = "Kelly";
$areanames{en}->{618762593} = "Kimba";
$areanames{en}->{618762594} = "Koongawa";
$areanames{en}->{618762595} = "Koppio";
$areanames{en}->{618762596} = "Kyancutta";
$areanames{en}->{618762597} = "Laura";
$areanames{en}->{618762598} = "Leigh\ Creek\ South";
$areanames{en}->{618762599} = "Lock";
$areanames{en}->{618762600} = "Mambray\ Creek";
$areanames{en}->{618762601} = "Marla";
$areanames{en}->{618762602} = "Melrose";
$areanames{en}->{618762603} = "Miltalie";
$areanames{en}->{618762604} = "Minnipa";
$areanames{en}->{618762605} = "Mintabie";
$areanames{en}->{618762606} = "Morchard";
$areanames{en}->{618762607} = "Mount\ Hope";
$areanames{en}->{618762608} = "Mudamuckla";
$areanames{en}->{618762609} = "Nelshaby";
$areanames{en}->{618762610} = "Nunjikompita";
$areanames{en}->{618762611} = "Orroroo";
$areanames{en}->{618762612} = "Penong";
$areanames{en}->{618762613} = "Peterborough";
$areanames{en}->{618762614} = "Poochera";
$areanames{en}->{618762615} = "Port\ Augusta";
$areanames{en}->{618762616} = "Port\ Broughton";
$areanames{en}->{618762617} = "Port\ Kenny";
$areanames{en}->{618762618} = "Port\ Lincoln";
$areanames{en}->{618762619} = "Port\ Neill";
$areanames{en}->{618762620} = "Port\ Pirie";
$areanames{en}->{618762621} = "Quorn";
$areanames{en}->{618762622} = "Redhill";
$areanames{en}->{618762623} = "Roxby\ Downs";
$areanames{en}->{618762624} = "Rudall";
$areanames{en}->{618762625} = "Sheringa";
$areanames{en}->{618762626} = "Sleaford\ Mere";
$areanames{en}->{618762627} = "Spilsby";
$areanames{en}->{618762628} = "Streaky\ Bay";
$areanames{en}->{618762629} = "Tarcoola";
$areanames{en}->{618762630} = "Terowie";
$areanames{en}->{618762631} = "The\ Ranges";
$areanames{en}->{618762632} = "Tooligie\ Hill";
$areanames{en}->{618762633} = "Tumby\ Bay";
$areanames{en}->{618762634} = "Ungarra";
$areanames{en}->{618762635} = "Wandearah\ East";
$areanames{en}->{618762636} = "Wanilla";
$areanames{en}->{618762637} = "Wharminda";
$areanames{en}->{618762638} = "Whyalla";
$areanames{en}->{618762639} = "Willowie";
$areanames{en}->{618762640} = "Wilmington";
$areanames{en}->{618762641} = "Wilpena";
$areanames{en}->{618762642} = "Wirrulla";
$areanames{en}->{618762643} = "Woomera";
$areanames{en}->{618762644} = "Wudinna";
$areanames{en}->{618762645} = "Yabmana";
$areanames{en}->{618762646} = "Yeelanna";
$areanames{en}->{618762647} = "Yunta";
$areanames{en}->{618762648} = "Andamooka";
$areanames{en}->{618762649} = "Arno\ Bay";
$areanames{en}->{61876265} = "Bayley\ Plains";
$areanames{en}->{61876266} = "Booleroo\ Centre";
$areanames{en}->{61876267} = "Caltowie";
$areanames{en}->{61876268} = "Port\ Lincoln";
$areanames{en}->{61876269} = "Carrieton";
$areanames{en}->{61876270} = "Cleve";
$areanames{en}->{61876271} = "Coorabie";
$areanames{en}->{61876272} = "Coulta";
$areanames{en}->{61876273} = "Courela";
$areanames{en}->{61876274} = "Cowell";
$areanames{en}->{61876275} = "Crystal\ Brook";
$areanames{en}->{61876276} = "Darke\ Peak";
$areanames{en}->{61876277} = "Frome";
$areanames{en}->{61876278} = "Gladstone";
$areanames{en}->{61876279} = "Glendambo";
$areanames{en}->{61876280} = "Hawker";
$areanames{en}->{61876281} = "Herbert";
$areanames{en}->{61876282} = "Quorn";
$areanames{en}->{61876283} = "Port\ Augusta";
$areanames{en}->{61876284} = "Ceduna";
$areanames{en}->{61876285} = "Ceduna";
$areanames{en}->{61876286} = "Ceduna";
$areanames{en}->{61876287} = "Coorabie";
$areanames{en}->{61876288} = "Penong";
$areanames{en}->{61876289} = "Poochera";
$areanames{en}->{61876290} = "Indian\ Pacific";
$areanames{en}->{61876291} = "Iron\ Baron";
$areanames{en}->{61876292} = "Iron\ Knob";
$areanames{en}->{61876293} = "Kapinnie";
$areanames{en}->{61876294} = "Kelly";
$areanames{en}->{61876295} = "Kimba";
$areanames{en}->{61876296} = "Koongawa";
$areanames{en}->{61876297} = "Koppio";
$areanames{en}->{61876298} = "Kyancutta";
$areanames{en}->{61876299} = "Lock";
$areanames{en}->{61876300} = "Mambray\ Creek";
$areanames{en}->{61876301} = "Marla";
$areanames{en}->{61876302} = "Melrose";
$areanames{en}->{61876303} = "Miltalie";
$areanames{en}->{61876304} = "Minnipa";
$areanames{en}->{61876305} = "Mintabie";
$areanames{en}->{61876306} = "Morchard";
$areanames{en}->{61876307} = "Mount\ Hope";
$areanames{en}->{61876308} = "Mudamuckla";
$areanames{en}->{61876309} = "Nelshaby";
$areanames{en}->{61876310} = "Nunjikompita";
$areanames{en}->{61876311} = "Orroroo";
$areanames{en}->{61876312} = "Penong";
$areanames{en}->{61876313} = "Peterborough";
$areanames{en}->{61876314} = "Port\ Broughton";
$areanames{en}->{61876315} = "Quorn";
$areanames{en}->{61876316} = "Sheringa";
$areanames{en}->{61876317} = "Sleaford\ Mere";
$areanames{en}->{61876318} = "Tarcoola";
$areanames{en}->{61876319} = "Terowie";
$areanames{en}->{61876320} = "Tooligie\ Hill";
$areanames{en}->{61876321} = "Tumby\ Bay";
$areanames{en}->{61876322} = "Ungarra";
$areanames{en}->{61876323} = "Wandearah\ East";
$areanames{en}->{61876324} = "Wanilla";
$areanames{en}->{61876325} = "Wharminda";
$areanames{en}->{61876326} = "Willowie";
$areanames{en}->{61876327} = "Wilpena";
$areanames{en}->{61876328} = "Wudinna";
$areanames{en}->{61876329} = "Yabmana";
$areanames{en}->{61876330} = "Yeelanna";
$areanames{en}->{61876331} = "Yunta";
$areanames{en}->{61876332} = "Coober\ Pedy";
$areanames{en}->{61876333} = "Whyalla";
$areanames{en}->{618763340} = "Bayley\ Plains";
$areanames{en}->{618763341} = "Booleroo\ Centre";
$areanames{en}->{618763342} = "Caltowie";
$areanames{en}->{618763343} = "Carrieton";
$areanames{en}->{618763344} = "Ceduna";
$areanames{en}->{618763345} = "Cleve";
$areanames{en}->{618763346} = "Coffin\ Bay";
$areanames{en}->{618763347} = "Coober\ Pedy";
$areanames{en}->{618763348} = "Coorabie";
$areanames{en}->{618763349} = "Coulta";
$areanames{en}->{618763350} = "Courela";
$areanames{en}->{618763351} = "Cowell";
$areanames{en}->{618763352} = "Crystal\ Brook";
$areanames{en}->{618763353} = "Cummins";
$areanames{en}->{618763354} = "Darke\ Peak";
$areanames{en}->{618763355} = "Elliston";
$areanames{en}->{618763356} = "Everard";
$areanames{en}->{618763357} = "Frome";
$areanames{en}->{618763358} = "Gairdner";
$areanames{en}->{618763359} = "Georgetown";
$areanames{en}->{618763360} = "Gladstone";
$areanames{en}->{618763361} = "Glendambo";
$areanames{en}->{618763362} = "Great\ Bight";
$areanames{en}->{618763363} = "Hawker";
$areanames{en}->{618763364} = "Herbert";
$areanames{en}->{618763365} = "Indian\ Pacific";
$areanames{en}->{618763366} = "Iron\ Baron";
$areanames{en}->{618763367} = "Iron\ Knob";
$areanames{en}->{618763368} = "Jamestown";
$areanames{en}->{618763369} = "Kapinnie";
$areanames{en}->{618763370} = "Kelly";
$areanames{en}->{618763371} = "Kimba";
$areanames{en}->{618763372} = "Koongawa";
$areanames{en}->{618763373} = "Koppio";
$areanames{en}->{618763374} = "Kyancutta";
$areanames{en}->{618763375} = "Laura";
$areanames{en}->{618763376} = "Leigh\ Creek\ South";
$areanames{en}->{618763377} = "Lock";
$areanames{en}->{618763378} = "Mambray\ Creek";
$areanames{en}->{618763379} = "Marla";
$areanames{en}->{618763380} = "Melrose";
$areanames{en}->{618763381} = "Miltalie";
$areanames{en}->{618763382} = "Minnipa";
$areanames{en}->{618763383} = "Mintabie";
$areanames{en}->{618763384} = "Morchard";
$areanames{en}->{618763385} = "Mount\ Hope";
$areanames{en}->{618763386} = "Mudamuckla";
$areanames{en}->{618763387} = "Nelshaby";
$areanames{en}->{618763388} = "Nunjikompita";
$areanames{en}->{618763389} = "Orroroo";
$areanames{en}->{618763390} = "Penong";
$areanames{en}->{618763391} = "Peterborough";
$areanames{en}->{618763392} = "Poochera";
$areanames{en}->{618763393} = "Port\ Augusta";
$areanames{en}->{618763394} = "Port\ Broughton";
$areanames{en}->{618763395} = "Port\ Kenny";
$areanames{en}->{618763396} = "Port\ Lincoln";
$areanames{en}->{618763397} = "Port\ Neill";
$areanames{en}->{618763398} = "Port\ Pirie";
$areanames{en}->{618763399} = "Quorn";
$areanames{en}->{618763400} = "Redhill";
$areanames{en}->{618763401} = "Roxby\ Downs";
$areanames{en}->{618763402} = "Rudall";
$areanames{en}->{618763403} = "Sheringa";
$areanames{en}->{618763404} = "Sleaford\ Mere";
$areanames{en}->{618763405} = "Spilsby";
$areanames{en}->{618763406} = "Streaky\ Bay";
$areanames{en}->{618763407} = "Tarcoola";
$areanames{en}->{618763408} = "Terowie";
$areanames{en}->{618763409} = "The\ Ranges";
$areanames{en}->{618763410} = "Tooligie\ Hill";
$areanames{en}->{618763411} = "Tumby\ Bay";
$areanames{en}->{618763412} = "Ungarra";
$areanames{en}->{618763413} = "Wandearah\ East";
$areanames{en}->{618763414} = "Wanilla";
$areanames{en}->{618763415} = "Wharminda";
$areanames{en}->{618763416} = "Whyalla";
$areanames{en}->{618763417} = "Willowie";
$areanames{en}->{618763418} = "Wilmington";
$areanames{en}->{618763419} = "Wilpena";
$areanames{en}->{618763420} = "Wirrulla";
$areanames{en}->{618763421} = "Woomera";
$areanames{en}->{618763422} = "Wudinna";
$areanames{en}->{618763423} = "Yabmana";
$areanames{en}->{618763424} = "Yeelanna";
$areanames{en}->{618763425} = "Yunta";
$areanames{en}->{618763426} = "Andamooka";
$areanames{en}->{618763427} = "Arno\ Bay";
$areanames{en}->{618763428} = "Bayley\ Plains";
$areanames{en}->{618763429} = "Booleroo\ Centre";
$areanames{en}->{61876343} = "Ceduna";
$areanames{en}->{618763440} = "Caltowie";
$areanames{en}->{618763441} = "Carrieton";
$areanames{en}->{618763442} = "Ceduna";
$areanames{en}->{618763443} = "Cleve";
$areanames{en}->{618763444} = "Coffin\ Bay";
$areanames{en}->{618763445} = "Coober\ Pedy";
$areanames{en}->{618763446} = "Coorabie";
$areanames{en}->{618763447} = "Coulta";
$areanames{en}->{618763448} = "Courela";
$areanames{en}->{618763449} = "Cowell";
$areanames{en}->{618763450} = "Crystal\ Brook";
$areanames{en}->{618763451} = "Cummins";
$areanames{en}->{618763452} = "Darke\ Peak";
$areanames{en}->{618763453} = "Elliston";
$areanames{en}->{618763454} = "Everard";
$areanames{en}->{618763455} = "Frome";
$areanames{en}->{618763456} = "Gairdner";
$areanames{en}->{618763457} = "Georgetown";
$areanames{en}->{618763458} = "Gladstone";
$areanames{en}->{618763459} = "Glendambo";
$areanames{en}->{618763460} = "Great\ Bight";
$areanames{en}->{618763461} = "Hawker";
$areanames{en}->{618763462} = "Herbert";
$areanames{en}->{618763463} = "Indian\ Pacific";
$areanames{en}->{618763464} = "Iron\ Baron";
$areanames{en}->{618763465} = "Iron\ Knob";
$areanames{en}->{618763466} = "Jamestown";
$areanames{en}->{618763467} = "Kapinnie";
$areanames{en}->{618763468} = "Kelly";
$areanames{en}->{618763469} = "Kimba";
$areanames{en}->{618763470} = "Koongawa";
$areanames{en}->{618763471} = "Koppio";
$areanames{en}->{618763472} = "Kyancutta";
$areanames{en}->{618763473} = "Laura";
$areanames{en}->{618763474} = "Leigh\ Creek\ South";
$areanames{en}->{618763475} = "Lock";
$areanames{en}->{618763476} = "Mambray\ Creek";
$areanames{en}->{618763477} = "Marla";
$areanames{en}->{618763478} = "Melrose";
$areanames{en}->{618763479} = "Miltalie";
$areanames{en}->{618763480} = "Minnipa";
$areanames{en}->{618763481} = "Mintabie";
$areanames{en}->{618763482} = "Morchard";
$areanames{en}->{618763483} = "Mount\ Hope";
$areanames{en}->{618763484} = "Mudamuckla";
$areanames{en}->{618763485} = "Nelshaby";
$areanames{en}->{618763486} = "Nunjikompita";
$areanames{en}->{618763487} = "Orroroo";
$areanames{en}->{618763488} = "Penong";
$areanames{en}->{618763489} = "Peterborough";
$areanames{en}->{618763490} = "Poochera";
$areanames{en}->{618763491} = "Port\ Augusta";
$areanames{en}->{618763492} = "Port\ Broughton";
$areanames{en}->{618763493} = "Port\ Kenny";
$areanames{en}->{618763494} = "Port\ Lincoln";
$areanames{en}->{618763495} = "Port\ Neill";
$areanames{en}->{618763496} = "Port\ Pirie";
$areanames{en}->{618763497} = "Quorn";
$areanames{en}->{618763498} = "Redhill";
$areanames{en}->{618763499} = "Roxby\ Downs";
$areanames{en}->{618763500} = "Rudall";
$areanames{en}->{618763501} = "Sheringa";
$areanames{en}->{618763502} = "Sleaford\ Mere";
$areanames{en}->{618763503} = "Spilsby";
$areanames{en}->{618763504} = "Streaky\ Bay";
$areanames{en}->{618763505} = "Tarcoola";
$areanames{en}->{618763506} = "Terowie";
$areanames{en}->{618763507} = "The\ Ranges";
$areanames{en}->{618763508} = "Tooligie\ Hill";
$areanames{en}->{618763509} = "Tumby\ Bay";
$areanames{en}->{618763510} = "Ungarra";
$areanames{en}->{618763511} = "Wandearah\ East";
$areanames{en}->{618763512} = "Wanilla";
$areanames{en}->{618763513} = "Wharminda";
$areanames{en}->{618763514} = "Whyalla";
$areanames{en}->{618763515} = "Willowie";
$areanames{en}->{618763516} = "Wilmington";
$areanames{en}->{618763517} = "Wilpena";
$areanames{en}->{618763518} = "Wirrulla";
$areanames{en}->{618763519} = "Woomera";
$areanames{en}->{618763520} = "Wudinna";
$areanames{en}->{618763521} = "Yabmana";
$areanames{en}->{618763522} = "Yeelanna";
$areanames{en}->{618763523} = "Yunta";
$areanames{en}->{618763524} = "Andamooka";
$areanames{en}->{618763525} = "Arno\ Bay";
$areanames{en}->{618763526} = "Bayley\ Plains";
$areanames{en}->{618763527} = "Booleroo\ Centre";
$areanames{en}->{618763528} = "Caltowie";
$areanames{en}->{618763529} = "Carrieton";
$areanames{en}->{61876353} = "Kimba";
$areanames{en}->{61876354} = "Port\ Broughton";
$areanames{en}->{61876355} = "Roxby\ Downs";
$areanames{en}->{61876356} = "Whyalla";
$areanames{en}->{61876357} = "Whyalla";
$areanames{en}->{61876358} = "Whyalla";
$areanames{en}->{618763590} = "Ceduna";
$areanames{en}->{618763591} = "Cleve";
$areanames{en}->{618763592} = "Coffin\ Bay";
$areanames{en}->{618763593} = "Coober\ Pedy";
$areanames{en}->{618763594} = "Coorabie";
$areanames{en}->{618763595} = "Coulta";
$areanames{en}->{618763596} = "Courela";
$areanames{en}->{618763597} = "Cowell";
$areanames{en}->{618763598} = "Crystal\ Brook";
$areanames{en}->{618763599} = "Cummins";
$areanames{en}->{618763600} = "Darke\ Peak";
$areanames{en}->{618763601} = "Elliston";
$areanames{en}->{618763602} = "Everard";
$areanames{en}->{618763603} = "Frome";
$areanames{en}->{618763604} = "Gairdner";
$areanames{en}->{618763605} = "Georgetown";
$areanames{en}->{618763606} = "Gladstone";
$areanames{en}->{618763607} = "Glendambo";
$areanames{en}->{618763608} = "Great\ Bight";
$areanames{en}->{618763609} = "Hawker";
$areanames{en}->{618763610} = "Herbert";
$areanames{en}->{618763611} = "Indian\ Pacific";
$areanames{en}->{618763612} = "Andamooka";
$areanames{en}->{618763613} = "Arno\ Bay";
$areanames{en}->{618763614} = "Bayley\ Plains";
$areanames{en}->{618763615} = "Booleroo\ Centre";
$areanames{en}->{618763616} = "Caltowie";
$areanames{en}->{618763617} = "Carrieton";
$areanames{en}->{618763618} = "Ceduna";
$areanames{en}->{618763619} = "Cleve";
$areanames{en}->{618763620} = "Coffin\ Bay";
$areanames{en}->{618763621} = "Coober\ Pedy";
$areanames{en}->{618763622} = "Coorabie";
$areanames{en}->{618763623} = "Coulta";
$areanames{en}->{618763624} = "Courela";
$areanames{en}->{618763625} = "Cowell";
$areanames{en}->{618763626} = "Crystal\ Brook";
$areanames{en}->{618763627} = "Cummins";
$areanames{en}->{618763628} = "Darke\ Peak";
$areanames{en}->{618763629} = "Elliston";
$areanames{en}->{618763630} = "Everard";
$areanames{en}->{618763631} = "Frome";
$areanames{en}->{618763632} = "Gairdner";
$areanames{en}->{618763633} = "Georgetown";
$areanames{en}->{618763634} = "Gladstone";
$areanames{en}->{618763635} = "Glendambo";
$areanames{en}->{618763636} = "Great\ Bight";
$areanames{en}->{618763637} = "Hawker";
$areanames{en}->{618763638} = "Herbert";
$areanames{en}->{618763639} = "Indian\ Pacific";
$areanames{en}->{618763640} = "Iron\ Baron";
$areanames{en}->{618763641} = "Iron\ Knob";
$areanames{en}->{618763642} = "Jamestown";
$areanames{en}->{618763643} = "Kapinnie";
$areanames{en}->{618763644} = "Kelly";
$areanames{en}->{618763645} = "Kimba";
$areanames{en}->{618763646} = "Koongawa";
$areanames{en}->{618763647} = "Koppio";
$areanames{en}->{618763648} = "Kyancutta";
$areanames{en}->{618763649} = "Laura";
$areanames{en}->{618763650} = "Leigh\ Creek\ South";
$areanames{en}->{618763651} = "Lock";
$areanames{en}->{618763652} = "Mambray\ Creek";
$areanames{en}->{618763653} = "Marla";
$areanames{en}->{618763654} = "Melrose";
$areanames{en}->{618763655} = "Miltalie";
$areanames{en}->{618763656} = "Minnipa";
$areanames{en}->{618763657} = "Mintabie";
$areanames{en}->{618763658} = "Morchard";
$areanames{en}->{618763659} = "Mount\ Hope";
$areanames{en}->{618763660} = "Mudamuckla";
$areanames{en}->{618763661} = "Nelshaby";
$areanames{en}->{618763662} = "Nunjikompita";
$areanames{en}->{618763663} = "Orroroo";
$areanames{en}->{618763664} = "Penong";
$areanames{en}->{618763665} = "Peterborough";
$areanames{en}->{618763666} = "Poochera";
$areanames{en}->{618763667} = "Port\ Augusta";
$areanames{en}->{618763668} = "Port\ Broughton";
$areanames{en}->{618763669} = "Port\ Kenny";
$areanames{en}->{618763670} = "Port\ Lincoln";
$areanames{en}->{618763671} = "Port\ Neill";
$areanames{en}->{618763672} = "Port\ Pirie";
$areanames{en}->{618763673} = "Quorn";
$areanames{en}->{618763674} = "Redhill";
$areanames{en}->{618763675} = "Roxby\ Downs";
$areanames{en}->{618763676} = "Rudall";
$areanames{en}->{618763677} = "Sheringa";
$areanames{en}->{618763678} = "Sleaford\ Mere";
$areanames{en}->{618763679} = "Spilsby";
$areanames{en}->{618763680} = "Streaky\ Bay";
$areanames{en}->{618763681} = "Tarcoola";
$areanames{en}->{618763682} = "Terowie";
$areanames{en}->{618763683} = "The\ Ranges";
$areanames{en}->{618763684} = "Tooligie\ Hill";
$areanames{en}->{618763685} = "Tumby\ Bay";
$areanames{en}->{618763686} = "Ungarra";
$areanames{en}->{618763687} = "Wandearah\ East";
$areanames{en}->{618763688} = "Wanilla";
$areanames{en}->{618763689} = "Wharminda";
$areanames{en}->{618763690} = "Whyalla";
$areanames{en}->{618763691} = "Willowie";
$areanames{en}->{618763692} = "Wilmington";
$areanames{en}->{618763693} = "Wilpena";
$areanames{en}->{618763694} = "Wirrulla";
$areanames{en}->{618763695} = "Woomera";
$areanames{en}->{618763696} = "Wudinna";
$areanames{en}->{618763697} = "Yabmana";
$areanames{en}->{618763698} = "Yeelanna";
$areanames{en}->{618763699} = "Yunta";
$areanames{en}->{618763700} = "Iron\ Baron";
$areanames{en}->{618763701} = "Iron\ Knob";
$areanames{en}->{618763702} = "Jamestown";
$areanames{en}->{618763703} = "Kapinnie";
$areanames{en}->{618763704} = "Kelly";
$areanames{en}->{618763705} = "Kimba";
$areanames{en}->{618763706} = "Koongawa";
$areanames{en}->{618763707} = "Koppio";
$areanames{en}->{618763708} = "Kyancutta";
$areanames{en}->{618763709} = "Laura";
$areanames{en}->{618763710} = "Leigh\ Creek\ South";
$areanames{en}->{618763711} = "Lock";
$areanames{en}->{618763712} = "Mambray\ Creek";
$areanames{en}->{618763713} = "Marla";
$areanames{en}->{618763714} = "Melrose";
$areanames{en}->{618763715} = "Miltalie";
$areanames{en}->{618763716} = "Minnipa";
$areanames{en}->{618763717} = "Mintabie";
$areanames{en}->{618763718} = "Morchard";
$areanames{en}->{618763719} = "Mount\ Hope";
$areanames{en}->{618763720} = "Mudamuckla";
$areanames{en}->{618763721} = "Nelshaby";
$areanames{en}->{618763722} = "Nunjikompita";
$areanames{en}->{618763723} = "Orroroo";
$areanames{en}->{618763724} = "Penong";
$areanames{en}->{618763725} = "Peterborough";
$areanames{en}->{618763726} = "Poochera";
$areanames{en}->{618763727} = "Port\ Augusta";
$areanames{en}->{618763728} = "Port\ Broughton";
$areanames{en}->{618763729} = "Port\ Kenny";
$areanames{en}->{618763730} = "Port\ Lincoln";
$areanames{en}->{618763731} = "Port\ Neill";
$areanames{en}->{618763732} = "Port\ Pirie";
$areanames{en}->{618763733} = "Quorn";
$areanames{en}->{618763734} = "Redhill";
$areanames{en}->{618763735} = "Roxby\ Downs";
$areanames{en}->{618763736} = "Rudall";
$areanames{en}->{618763737} = "Sheringa";
$areanames{en}->{618763738} = "Sleaford\ Mere";
$areanames{en}->{618763739} = "Spilsby";
$areanames{en}->{618763740} = "Streaky\ Bay";
$areanames{en}->{618763741} = "Tarcoola";
$areanames{en}->{618763742} = "Terowie";
$areanames{en}->{618763743} = "The\ Ranges";
$areanames{en}->{618763744} = "Tooligie\ Hill";
$areanames{en}->{618763745} = "Tumby\ Bay";
$areanames{en}->{618763746} = "Ungarra";
$areanames{en}->{618763747} = "Wandearah\ East";
$areanames{en}->{618763748} = "Wanilla";
$areanames{en}->{618763749} = "Wharminda";
$areanames{en}->{618763750} = "Whyalla";
$areanames{en}->{618763751} = "Willowie";
$areanames{en}->{618763752} = "Wilmington";
$areanames{en}->{618763753} = "Wilpena";
$areanames{en}->{618763754} = "Wirrulla";
$areanames{en}->{618763755} = "Woomera";
$areanames{en}->{618763756} = "Wudinna";
$areanames{en}->{618763757} = "Yabmana";
$areanames{en}->{618763758} = "Yeelanna";
$areanames{en}->{618763759} = "Yunta";
$areanames{en}->{618763760} = "Andamooka";
$areanames{en}->{618763761} = "Arno\ Bay";
$areanames{en}->{618763762} = "Bayley\ Plains";
$areanames{en}->{618763763} = "Booleroo\ Centre";
$areanames{en}->{618763764} = "Caltowie";
$areanames{en}->{618763765} = "Carrieton";
$areanames{en}->{618763766} = "Ceduna";
$areanames{en}->{618763767} = "Cleve";
$areanames{en}->{618763768} = "Coffin\ Bay";
$areanames{en}->{618763769} = "Coober\ Pedy";
$areanames{en}->{618763770} = "Coorabie";
$areanames{en}->{618763771} = "Coulta";
$areanames{en}->{618763772} = "Courela";
$areanames{en}->{618763773} = "Cowell";
$areanames{en}->{618763774} = "Crystal\ Brook";
$areanames{en}->{618763775} = "Cummins";
$areanames{en}->{618763776} = "Darke\ Peak";
$areanames{en}->{618763777} = "Elliston";
$areanames{en}->{618763778} = "Everard";
$areanames{en}->{618763779} = "Frome";
$areanames{en}->{618763780} = "Gairdner";
$areanames{en}->{618763781} = "Georgetown";
$areanames{en}->{618763782} = "Gladstone";
$areanames{en}->{618763783} = "Glendambo";
$areanames{en}->{618763784} = "Great\ Bight";
$areanames{en}->{618763785} = "Hawker";
$areanames{en}->{618763786} = "Herbert";
$areanames{en}->{618763787} = "Indian\ Pacific";
$areanames{en}->{618763788} = "Iron\ Baron";
$areanames{en}->{618763789} = "Iron\ Knob";
$areanames{en}->{618763790} = "Jamestown";
$areanames{en}->{618763791} = "Kapinnie";
$areanames{en}->{618763792} = "Kelly";
$areanames{en}->{618763793} = "Kimba";
$areanames{en}->{618763794} = "Koongawa";
$areanames{en}->{618763795} = "Koppio";
$areanames{en}->{618763796} = "Kyancutta";
$areanames{en}->{618763797} = "Laura";
$areanames{en}->{618763798} = "Leigh\ Creek\ South";
$areanames{en}->{618763799} = "Lock";
$areanames{en}->{618763800} = "Mambray\ Creek";
$areanames{en}->{618763801} = "Marla";
$areanames{en}->{618763802} = "Melrose";
$areanames{en}->{618763803} = "Miltalie";
$areanames{en}->{618763804} = "Minnipa";
$areanames{en}->{618763805} = "Mintabie";
$areanames{en}->{618763806} = "Morchard";
$areanames{en}->{618763807} = "Mount\ Hope";
$areanames{en}->{618763808} = "Mudamuckla";
$areanames{en}->{618763809} = "Nelshaby";
$areanames{en}->{618763810} = "Nunjikompita";
$areanames{en}->{618763811} = "Orroroo";
$areanames{en}->{618763812} = "Penong";
$areanames{en}->{618763813} = "Peterborough";
$areanames{en}->{618763814} = "Poochera";
$areanames{en}->{618763815} = "Port\ Augusta";
$areanames{en}->{618763816} = "Port\ Broughton";
$areanames{en}->{618763817} = "Port\ Kenny";
$areanames{en}->{618763818} = "Port\ Lincoln";
$areanames{en}->{618763819} = "Port\ Neill";
$areanames{en}->{618763820} = "Port\ Pirie";
$areanames{en}->{618763821} = "Quorn";
$areanames{en}->{618763822} = "Redhill";
$areanames{en}->{618763823} = "Roxby\ Downs";
$areanames{en}->{618763824} = "Rudall";
$areanames{en}->{618763825} = "Sheringa";
$areanames{en}->{618763826} = "Sleaford\ Mere";
$areanames{en}->{618763827} = "Spilsby";
$areanames{en}->{618763828} = "Streaky\ Bay";
$areanames{en}->{618763829} = "Tarcoola";
$areanames{en}->{618763830} = "Terowie";
$areanames{en}->{618763831} = "The\ Ranges";
$areanames{en}->{618763832} = "Tooligie\ Hill";
$areanames{en}->{618763833} = "Tumby\ Bay";
$areanames{en}->{618763834} = "Ungarra";
$areanames{en}->{618763835} = "Wandearah\ East";
$areanames{en}->{618763836} = "Wanilla";
$areanames{en}->{618763837} = "Wharminda";
$areanames{en}->{618763838} = "Whyalla";
$areanames{en}->{618763839} = "Willowie";
$areanames{en}->{618763840} = "Wilmington";
$areanames{en}->{618763841} = "Wilpena";
$areanames{en}->{618763842} = "Wirrulla";
$areanames{en}->{618763843} = "Woomera";
$areanames{en}->{618763844} = "Wudinna";
$areanames{en}->{618763845} = "Yabmana";
$areanames{en}->{618763846} = "Yeelanna";
$areanames{en}->{618763847} = "Yunta";
$areanames{en}->{618763848} = "Andamooka";
$areanames{en}->{618763849} = "Arno\ Bay";
$areanames{en}->{618763850} = "Bayley\ Plains";
$areanames{en}->{618763851} = "Booleroo\ Centre";
$areanames{en}->{618763852} = "Caltowie";
$areanames{en}->{618763853} = "Carrieton";
$areanames{en}->{618763854} = "Ceduna";
$areanames{en}->{618763855} = "Cleve";
$areanames{en}->{618763856} = "Coffin\ Bay";
$areanames{en}->{618763857} = "Coober\ Pedy";
$areanames{en}->{618763858} = "Coorabie";
$areanames{en}->{618763859} = "Coulta";
$areanames{en}->{618763860} = "Courela";
$areanames{en}->{618763861} = "Cowell";
$areanames{en}->{618763862} = "Crystal\ Brook";
$areanames{en}->{618763863} = "Cummins";
$areanames{en}->{618763864} = "Darke\ Peak";
$areanames{en}->{618763865} = "Elliston";
$areanames{en}->{618763866} = "Everard";
$areanames{en}->{618763867} = "Frome";
$areanames{en}->{618763868} = "Gairdner";
$areanames{en}->{618763869} = "Georgetown";
$areanames{en}->{618763870} = "Gladstone";
$areanames{en}->{618763871} = "Glendambo";
$areanames{en}->{618763872} = "Great\ Bight";
$areanames{en}->{618763873} = "Hawker";
$areanames{en}->{618763874} = "Herbert";
$areanames{en}->{618763875} = "Indian\ Pacific";
$areanames{en}->{618763876} = "Iron\ Baron";
$areanames{en}->{618763877} = "Iron\ Knob";
$areanames{en}->{618763878} = "Jamestown";
$areanames{en}->{618763879} = "Kapinnie";
$areanames{en}->{618763880} = "Kelly";
$areanames{en}->{618763881} = "Kimba";
$areanames{en}->{618763882} = "Koongawa";
$areanames{en}->{618763883} = "Koppio";
$areanames{en}->{618763884} = "Kyancutta";
$areanames{en}->{618763885} = "Laura";
$areanames{en}->{618763886} = "Leigh\ Creek\ South";
$areanames{en}->{618763887} = "Lock";
$areanames{en}->{618763888} = "Mambray\ Creek";
$areanames{en}->{618763889} = "Marla";
$areanames{en}->{618763890} = "Melrose";
$areanames{en}->{618763891} = "Miltalie";
$areanames{en}->{618763892} = "Minnipa";
$areanames{en}->{618763893} = "Mintabie";
$areanames{en}->{618763894} = "Morchard";
$areanames{en}->{618763895} = "Mount\ Hope";
$areanames{en}->{618763896} = "Mudamuckla";
$areanames{en}->{618763897} = "Nelshaby";
$areanames{en}->{618763898} = "Nunjikompita";
$areanames{en}->{618763899} = "Orroroo";
$areanames{en}->{618763900} = "Penong";
$areanames{en}->{618763901} = "Peterborough";
$areanames{en}->{618763902} = "Poochera";
$areanames{en}->{618763903} = "Port\ Augusta";
$areanames{en}->{618763904} = "Port\ Broughton";
$areanames{en}->{618763905} = "Port\ Kenny";
$areanames{en}->{618763906} = "Port\ Lincoln";
$areanames{en}->{618763907} = "Port\ Neill";
$areanames{en}->{618763908} = "Port\ Pirie";
$areanames{en}->{618763909} = "Quorn";
$areanames{en}->{618763910} = "Redhill";
$areanames{en}->{618763911} = "Roxby\ Downs";
$areanames{en}->{618763912} = "Rudall";
$areanames{en}->{618763913} = "Sheringa";
$areanames{en}->{618763914} = "Sleaford\ Mere";
$areanames{en}->{618763915} = "Spilsby";
$areanames{en}->{618763916} = "Streaky\ Bay";
$areanames{en}->{618763917} = "Tarcoola";
$areanames{en}->{618763918} = "Terowie";
$areanames{en}->{618763919} = "The\ Ranges";
$areanames{en}->{618763920} = "Tooligie\ Hill";
$areanames{en}->{618763921} = "Tumby\ Bay";
$areanames{en}->{618763922} = "Ungarra";
$areanames{en}->{618763923} = "Wandearah\ East";
$areanames{en}->{618763924} = "Wanilla";
$areanames{en}->{618763925} = "Wharminda";
$areanames{en}->{618763926} = "Whyalla";
$areanames{en}->{618763927} = "Willowie";
$areanames{en}->{618763928} = "Wilmington";
$areanames{en}->{618763929} = "Wilpena";
$areanames{en}->{618763930} = "Wirrulla";
$areanames{en}->{618763931} = "Woomera";
$areanames{en}->{618763932} = "Wudinna";
$areanames{en}->{618763933} = "Yabmana";
$areanames{en}->{618763934} = "Yeelanna";
$areanames{en}->{618763935} = "Yunta";
$areanames{en}->{618763936} = "Andamooka";
$areanames{en}->{618763937} = "Arno\ Bay";
$areanames{en}->{618763938} = "Bayley\ Plains";
$areanames{en}->{618763939} = "Booleroo\ Centre";
$areanames{en}->{618763940} = "Caltowie";
$areanames{en}->{618763941} = "Carrieton";
$areanames{en}->{618763942} = "Ceduna";
$areanames{en}->{618763943} = "Cleve";
$areanames{en}->{618763944} = "Coffin\ Bay";
$areanames{en}->{618763945} = "Coober\ Pedy";
$areanames{en}->{618763946} = "Coorabie";
$areanames{en}->{618763947} = "Coulta";
$areanames{en}->{618763948} = "Courela";
$areanames{en}->{618763949} = "Cowell";
$areanames{en}->{618763950} = "Crystal\ Brook";
$areanames{en}->{618763951} = "Cummins";
$areanames{en}->{618763952} = "Darke\ Peak";
$areanames{en}->{618763953} = "Elliston";
$areanames{en}->{618763954} = "Everard";
$areanames{en}->{618763955} = "Frome";
$areanames{en}->{618763956} = "Gairdner";
$areanames{en}->{618763957} = "Georgetown";
$areanames{en}->{618763958} = "Gladstone";
$areanames{en}->{618763959} = "Glendambo";
$areanames{en}->{618763960} = "Great\ Bight";
$areanames{en}->{618763961} = "Hawker";
$areanames{en}->{618763962} = "Herbert";
$areanames{en}->{618763963} = "Indian\ Pacific";
$areanames{en}->{618763964} = "Iron\ Baron";
$areanames{en}->{618763965} = "Iron\ Knob";
$areanames{en}->{618763966} = "Jamestown";
$areanames{en}->{618763967} = "Kapinnie";
$areanames{en}->{618763968} = "Kelly";
$areanames{en}->{618763969} = "Kimba";
$areanames{en}->{618763970} = "Koongawa";
$areanames{en}->{618763971} = "Koppio";
$areanames{en}->{618763972} = "Kyancutta";
$areanames{en}->{618763973} = "Laura";
$areanames{en}->{618763974} = "Leigh\ Creek\ South";
$areanames{en}->{618763975} = "Lock";
$areanames{en}->{618763976} = "Mambray\ Creek";
$areanames{en}->{618763977} = "Marla";
$areanames{en}->{618763978} = "Melrose";
$areanames{en}->{618763979} = "Miltalie";
$areanames{en}->{618763980} = "Minnipa";
$areanames{en}->{618763981} = "Mintabie";
$areanames{en}->{618763982} = "Morchard";
$areanames{en}->{618763983} = "Mount\ Hope";
$areanames{en}->{618763984} = "Mudamuckla";
$areanames{en}->{618763985} = "Nelshaby";
$areanames{en}->{618763986} = "Nunjikompita";
$areanames{en}->{618763987} = "Orroroo";
$areanames{en}->{618763988} = "Penong";
$areanames{en}->{618763989} = "Peterborough";
$areanames{en}->{618763990} = "Poochera";
$areanames{en}->{618763991} = "Port\ Augusta";
$areanames{en}->{618763992} = "Port\ Broughton";
$areanames{en}->{618763993} = "Port\ Kenny";
$areanames{en}->{618763994} = "Port\ Lincoln";
$areanames{en}->{618763995} = "Port\ Neill";
$areanames{en}->{618763996} = "Port\ Pirie";
$areanames{en}->{618763997} = "Quorn";
$areanames{en}->{618763998} = "Redhill";
$areanames{en}->{618763999} = "Roxby\ Downs";
$areanames{en}->{618764000} = "Rudall";
$areanames{en}->{618764001} = "Sheringa";
$areanames{en}->{618764002} = "Sleaford\ Mere";
$areanames{en}->{618764003} = "Spilsby";
$areanames{en}->{618764004} = "Streaky\ Bay";
$areanames{en}->{618764005} = "Tarcoola";
$areanames{en}->{618764006} = "Terowie";
$areanames{en}->{618764007} = "The\ Ranges";
$areanames{en}->{618764008} = "Tooligie\ Hill";
$areanames{en}->{618764009} = "Tumby\ Bay";
$areanames{en}->{618764010} = "Ungarra";
$areanames{en}->{618764011} = "Wandearah\ East";
$areanames{en}->{618764012} = "Wanilla";
$areanames{en}->{618764013} = "Wharminda";
$areanames{en}->{618764014} = "Whyalla";
$areanames{en}->{618764015} = "Willowie";
$areanames{en}->{618764016} = "Wilmington";
$areanames{en}->{618764017} = "Wilpena";
$areanames{en}->{618764018} = "Wirrulla";
$areanames{en}->{618764019} = "Woomera";
$areanames{en}->{618764020} = "Wudinna";
$areanames{en}->{618764021} = "Yabmana";
$areanames{en}->{618764022} = "Yeelanna";
$areanames{en}->{618764023} = "Yunta";
$areanames{en}->{61876403} = "Jamestown";
$areanames{en}->{61876410} = "Coffin\ Bay";
$areanames{en}->{61876411} = "Coffin\ Bay";
$areanames{en}->{61876412} = "Coffin\ Bay";
$areanames{en}->{61876413} = "Whyalla";
$areanames{en}->{61876414} = "Cummins";
$areanames{en}->{61876415} = "Cummins";
$areanames{en}->{61876416} = "Cummins";
$areanames{en}->{61876417} = "Elliston";
$areanames{en}->{61876418} = "Elliston";
$areanames{en}->{61876419} = "Elliston";
$areanames{en}->{61876429} = "Leigh\ Creek\ South";
$areanames{en}->{61876440} = "Port\ Neill";
$areanames{en}->{61876459} = "Wirrulla";
$areanames{en}->{61876470} = "Gairdner";
$areanames{en}->{61876477} = "Nelshaby";
$areanames{en}->{61877000} = "Bangham";
$areanames{en}->{61877001} = "Wrattonbully";
$areanames{en}->{61877002} = "Bordertown";
$areanames{en}->{61877003} = "Cannawigara";
$areanames{en}->{61877004} = "Colebatch";
$areanames{en}->{61877005} = "Keith";
$areanames{en}->{61877006} = "Laffer";
$areanames{en}->{61877007} = "Makin";
$areanames{en}->{61877008} = "Marcollat";
$areanames{en}->{61877009} = "Monkoora";
$areanames{en}->{61877010} = "Tintinara";
$areanames{en}->{61877011} = "Western\ Flat";
$areanames{en}->{61877012} = "Willalooka";
$areanames{en}->{61877013} = "Wirrega";
$areanames{en}->{61877014} = "Coonawarra";
$areanames{en}->{61877015} = "Greenways";
$areanames{en}->{61877016} = "Kalangadoo";
$areanames{en}->{61877017} = "Kongorong";
$areanames{en}->{61877018} = "Millicent";
$areanames{en}->{61877019} = "Mount\ Gambier";
$areanames{en}->{61877020} = "Penola";
$areanames{en}->{61877021} = "Port\ Macdonnell";
$areanames{en}->{61877022} = "Rendelsham";
$areanames{en}->{61877023} = "Short";
$areanames{en}->{61877024} = "Tantanoola";
$areanames{en}->{61877025} = "Tarpeena";
$areanames{en}->{61877026} = "Thornlea";
$areanames{en}->{61877027} = "Avenue\ Range";
$areanames{en}->{61877028} = "Conmurra";
$areanames{en}->{61877029} = "Frances";
$areanames{en}->{61877030} = "Keilira";
$areanames{en}->{61877031} = "Kingston\ Se";
$areanames{en}->{61877032} = "Lochaber";
$areanames{en}->{61877033} = "Lucindale";
$areanames{en}->{61877034} = "Lucindale\ South";
$areanames{en}->{61877035} = "Naracoorte";
$areanames{en}->{61877036} = "Padthaway";
$areanames{en}->{61877037} = "Reedy\ Creek";
$areanames{en}->{61877038} = "Robe";
$areanames{en}->{61877039} = "Taratap";
$areanames{en}->{61877040} = "Tilley\ Swamp";
$areanames{en}->{61877041} = "Cannawigara";
$areanames{en}->{61877042} = "Mount\ Gambier";
$areanames{en}->{61877043} = "Mount\ Gambier";
$areanames{en}->{61877044} = "Mount\ Gambier";
$areanames{en}->{61877045} = "Mount\ Gambier";
$areanames{en}->{61877046} = "Avenue\ Range";
$areanames{en}->{61877047} = "Bangham";
$areanames{en}->{61877048} = "Bordertown";
$areanames{en}->{61877049} = "Cannawigara";
$areanames{en}->{61877050} = "Colebatch";
$areanames{en}->{61877051} = "Conmurra";
$areanames{en}->{61877052} = "Coonawarra";
$areanames{en}->{61877053} = "Frances";
$areanames{en}->{61877054} = "Greenways";
$areanames{en}->{61877055} = "Kalangadoo";
$areanames{en}->{61877056} = "Keilira";
$areanames{en}->{61877057} = "Keith";
$areanames{en}->{61877058} = "Kingston\ Se";
$areanames{en}->{61877059} = "Kongorong";
$areanames{en}->{61877060} = "Laffer";
$areanames{en}->{61877061} = "Lochaber";
$areanames{en}->{61877062} = "Lucindale";
$areanames{en}->{61877063} = "Lucindale\ South";
$areanames{en}->{61877064} = "Makin";
$areanames{en}->{61877065} = "Marcollat";
$areanames{en}->{61877066} = "Millicent";
$areanames{en}->{61877067} = "Monkoora";
$areanames{en}->{61877068} = "Mount\ Gambier";
$areanames{en}->{61877069} = "Naracoorte";
$areanames{en}->{61877070} = "Padthaway";
$areanames{en}->{61877071} = "Penola";
$areanames{en}->{61877072} = "Port\ Macdonnell";
$areanames{en}->{61877073} = "Reedy\ Creek";
$areanames{en}->{61877074} = "Rendelsham";
$areanames{en}->{61877075} = "Robe";
$areanames{en}->{61877076} = "Short";
$areanames{en}->{61877077} = "Tantanoola";
$areanames{en}->{61877078} = "Taratap";
$areanames{en}->{61877079} = "Tarpeena";
$areanames{en}->{61877080} = "Thornlea";
$areanames{en}->{61877081} = "Tilley\ Swamp";
$areanames{en}->{61877082} = "Tintinara";
$areanames{en}->{61877083} = "Western\ Flat";
$areanames{en}->{61877084} = "Willalooka";
$areanames{en}->{61877085} = "Wirrega";
$areanames{en}->{61877086} = "Wrattonbully";
$areanames{en}->{61877087} = "Avenue\ Range";
$areanames{en}->{61877088} = "Bangham";
$areanames{en}->{61877089} = "Bordertown";
$areanames{en}->{61877090} = "Cannawigara";
$areanames{en}->{61877091} = "Colebatch";
$areanames{en}->{61877092} = "Conmurra";
$areanames{en}->{61877093} = "Coonawarra";
$areanames{en}->{61877094} = "Frances";
$areanames{en}->{61877095} = "Greenways";
$areanames{en}->{61877096} = "Kalangadoo";
$areanames{en}->{61877097} = "Keilira";
$areanames{en}->{61877098} = "Keith";
$areanames{en}->{61877099} = "Kingston\ Se";
$areanames{en}->{61877100} = "Kongorong";
$areanames{en}->{61877101} = "Laffer";
$areanames{en}->{61877102} = "Lochaber";
$areanames{en}->{61877103} = "Lucindale";
$areanames{en}->{61877104} = "Lucindale\ South";
$areanames{en}->{61877105} = "Makin";
$areanames{en}->{61877106} = "Marcollat";
$areanames{en}->{61877107} = "Millicent";
$areanames{en}->{61877108} = "Monkoora";
$areanames{en}->{61877109} = "Mount\ Gambier";
$areanames{en}->{61877110} = "Naracoorte";
$areanames{en}->{61877111} = "Padthaway";
$areanames{en}->{61877112} = "Penola";
$areanames{en}->{61877113} = "Port\ Macdonnell";
$areanames{en}->{61877114} = "Reedy\ Creek";
$areanames{en}->{61877115} = "Rendelsham";
$areanames{en}->{61877116} = "Robe";
$areanames{en}->{61877117} = "Short";
$areanames{en}->{61877118} = "Tantanoola";
$areanames{en}->{61877119} = "Taratap";
$areanames{en}->{61877120} = "Tarpeena";
$areanames{en}->{61877121} = "Thornlea";
$areanames{en}->{61877122} = "Tilley\ Swamp";
$areanames{en}->{61877123} = "Tintinara";
$areanames{en}->{61877124} = "Western\ Flat";
$areanames{en}->{61877125} = "Willalooka";
$areanames{en}->{61877126} = "Wirrega";
$areanames{en}->{61877127} = "Wrattonbully";
$areanames{en}->{61877128} = "Avenue\ Range";
$areanames{en}->{61877129} = "Bangham";
$areanames{en}->{61877130} = "Bordertown";
$areanames{en}->{61877131} = "Cannawigara";
$areanames{en}->{61877132} = "Colebatch";
$areanames{en}->{61877133} = "Conmurra";
$areanames{en}->{61877134} = "Coonawarra";
$areanames{en}->{61877135} = "Frances";
$areanames{en}->{61877136} = "Greenways";
$areanames{en}->{61877137} = "Kalangadoo";
$areanames{en}->{61877138} = "Keilira";
$areanames{en}->{61877139} = "Keith";
$areanames{en}->{61877140} = "Kingston\ Se";
$areanames{en}->{61877141} = "Kongorong";
$areanames{en}->{61877142} = "Laffer";
$areanames{en}->{61877143} = "Lochaber";
$areanames{en}->{61877144} = "Lucindale";
$areanames{en}->{61877145} = "Lucindale\ South";
$areanames{en}->{61877146} = "Makin";
$areanames{en}->{61877147} = "Marcollat";
$areanames{en}->{61877148} = "Millicent";
$areanames{en}->{61877149} = "Monkoora";
$areanames{en}->{61877150} = "Mount\ Gambier";
$areanames{en}->{61877151} = "Naracoorte";
$areanames{en}->{61877152} = "Padthaway";
$areanames{en}->{61877153} = "Penola";
$areanames{en}->{61877154} = "Port\ Macdonnell";
$areanames{en}->{61877155} = "Reedy\ Creek";
$areanames{en}->{61877156} = "Rendelsham";
$areanames{en}->{61877157} = "Robe";
$areanames{en}->{61877158} = "Short";
$areanames{en}->{61877159} = "Tantanoola";
$areanames{en}->{61877160} = "Taratap";
$areanames{en}->{61877161} = "Tarpeena";
$areanames{en}->{61877162} = "Thornlea";
$areanames{en}->{61877163} = "Tilley\ Swamp";
$areanames{en}->{61877164} = "Tintinara";
$areanames{en}->{61877165} = "Western\ Flat";
$areanames{en}->{61877166} = "Willalooka";
$areanames{en}->{61877167} = "Wirrega";
$areanames{en}->{61877168} = "Wrattonbully";
$areanames{en}->{61877169} = "Mount\ Gambier";
$areanames{en}->{61877170} = "Mount\ Gambier";
$areanames{en}->{61877171} = "Avenue\ Range";
$areanames{en}->{61877172} = "Bangham";
$areanames{en}->{61877173} = "Bordertown";
$areanames{en}->{61877174} = "Cannawigara";
$areanames{en}->{61877175} = "Colebatch";
$areanames{en}->{61877176} = "Conmurra";
$areanames{en}->{61877177} = "Coonawarra";
$areanames{en}->{61877178} = "Frances";
$areanames{en}->{61877179} = "Greenways";
$areanames{en}->{61877180} = "Kalangadoo";
$areanames{en}->{61877181} = "Keilira";
$areanames{en}->{61877182} = "Keith";
$areanames{en}->{61877183} = "Kingston\ Se";
$areanames{en}->{61877184} = "Kongorong";
$areanames{en}->{61877185} = "Laffer";
$areanames{en}->{61877186} = "Lochaber";
$areanames{en}->{61877187} = "Lucindale";
$areanames{en}->{61877188} = "Lucindale\ South";
$areanames{en}->{61877189} = "Makin";
$areanames{en}->{61877190} = "Marcollat";
$areanames{en}->{61877191} = "Millicent";
$areanames{en}->{61877192} = "Monkoora";
$areanames{en}->{61877193} = "Mount\ Gambier";
$areanames{en}->{61877194} = "Naracoorte";
$areanames{en}->{61877195} = "Padthaway";
$areanames{en}->{61877196} = "Penola";
$areanames{en}->{61877197} = "Port\ Macdonnell";
$areanames{en}->{61877198} = "Reedy\ Creek";
$areanames{en}->{61877199} = "Rendelsham";
$areanames{en}->{61877200} = "Robe";
$areanames{en}->{61877201} = "Short";
$areanames{en}->{61877202} = "Tantanoola";
$areanames{en}->{61877203} = "Taratap";
$areanames{en}->{61877204} = "Tarpeena";
$areanames{en}->{61877205} = "Thornlea";
$areanames{en}->{61877206} = "Tilley\ Swamp";
$areanames{en}->{61877207} = "Tintinara";
$areanames{en}->{61877208} = "Western\ Flat";
$areanames{en}->{61877209} = "Willalooka";
$areanames{en}->{61877210} = "Avenue\ Range";
$areanames{en}->{61877211} = "Bangham";
$areanames{en}->{61877212} = "Bordertown";
$areanames{en}->{61877213} = "Cannawigara";
$areanames{en}->{61877214} = "Colebatch";
$areanames{en}->{61877215} = "Conmurra";
$areanames{en}->{61877216} = "Coonawarra";
$areanames{en}->{61877217} = "Frances";
$areanames{en}->{61877218} = "Greenways";
$areanames{en}->{61877219} = "Kalangadoo";
$areanames{en}->{61877220} = "Keilira";
$areanames{en}->{61877221} = "Keith";
$areanames{en}->{61877222} = "Kingston\ Se";
$areanames{en}->{61877223} = "Kongorong";
$areanames{en}->{61877224} = "Laffer";
$areanames{en}->{61877225} = "Lochaber";
$areanames{en}->{61877226} = "Lucindale";
$areanames{en}->{61877227} = "Lucindale\ South";
$areanames{en}->{61877228} = "Makin";
$areanames{en}->{61877229} = "Marcollat";
$areanames{en}->{61877230} = "Millicent";
$areanames{en}->{61877231} = "Monkoora";
$areanames{en}->{61877232} = "Mount\ Gambier";
$areanames{en}->{61877233} = "Mount\ Gambier";
$areanames{en}->{61877234} = "Mount\ Gambier";
$areanames{en}->{61877235} = "Naracoorte";
$areanames{en}->{61877236} = "Padthaway";
$areanames{en}->{61877237} = "Penola";
$areanames{en}->{61877238} = "Port\ Macdonnell";
$areanames{en}->{61877239} = "Reedy\ Creek";
$areanames{en}->{61877240} = "Rendelsham";
$areanames{en}->{61877241} = "Robe";
$areanames{en}->{61877242} = "Short";
$areanames{en}->{61877243} = "Tantanoola";
$areanames{en}->{61877244} = "Taratap";
$areanames{en}->{61877245} = "Tarpeena";
$areanames{en}->{61877246} = "Thornlea";
$areanames{en}->{61877247} = "Tilley\ Swamp";
$areanames{en}->{61877248} = "Tintinara";
$areanames{en}->{61877249} = "Western\ Flat";
$areanames{en}->{6187725} = "Mount\ Gambier";
$areanames{en}->{61877250} = "Willalooka";
$areanames{en}->{61877251} = "Wirrega";
$areanames{en}->{61877252} = "Wrattonbully";
$areanames{en}->{61877260} = "Wirrega";
$areanames{en}->{61877261} = "Wrattonbully";
$areanames{en}->{61877262} = "Avenue\ Range";
$areanames{en}->{61877263} = "Bangham";
$areanames{en}->{61877264} = "Bordertown";
$areanames{en}->{61877265} = "Cannawigara";
$areanames{en}->{61877266} = "Colebatch";
$areanames{en}->{61877267} = "Conmurra";
$areanames{en}->{61877268} = "Coonawarra";
$areanames{en}->{61877269} = "Frances";
$areanames{en}->{61877270} = "Greenways";
$areanames{en}->{61877271} = "Kalangadoo";
$areanames{en}->{61877272} = "Keilira";
$areanames{en}->{61877273} = "Keith";
$areanames{en}->{61877274} = "Kingston\ Se";
$areanames{en}->{61877275} = "Kongorong";
$areanames{en}->{61877276} = "Laffer";
$areanames{en}->{61877277} = "Lochaber";
$areanames{en}->{61877278} = "Lucindale";
$areanames{en}->{61877279} = "Lucindale\ South";
$areanames{en}->{61877280} = "Makin";
$areanames{en}->{61877281} = "Marcollat";
$areanames{en}->{61877282} = "Millicent";
$areanames{en}->{61877283} = "Monkoora";
$areanames{en}->{61877284} = "Mount\ Gambier";
$areanames{en}->{61877285} = "Naracoorte";
$areanames{en}->{61877286} = "Padthaway";
$areanames{en}->{61877287} = "Penola";
$areanames{en}->{61877288} = "Port\ Macdonnell";
$areanames{en}->{61877289} = "Reedy\ Creek";
$areanames{en}->{61877290} = "Rendelsham";
$areanames{en}->{61877291} = "Robe";
$areanames{en}->{61877292} = "Short";
$areanames{en}->{61877293} = "Tantanoola";
$areanames{en}->{61877294} = "Taratap";
$areanames{en}->{61877295} = "Tarpeena";
$areanames{en}->{61877296} = "Thornlea";
$areanames{en}->{61877297} = "Tilley\ Swamp";
$areanames{en}->{61877298} = "Tintinara";
$areanames{en}->{61877299} = "Western\ Flat";
$areanames{en}->{61877300} = "Willalooka";
$areanames{en}->{61877301} = "Wirrega";
$areanames{en}->{61877302} = "Wrattonbully";
$areanames{en}->{61877303} = "Avenue\ Range";
$areanames{en}->{61877304} = "Bangham";
$areanames{en}->{61877305} = "Bordertown";
$areanames{en}->{61877306} = "Cannawigara";
$areanames{en}->{61877307} = "Colebatch";
$areanames{en}->{61877308} = "Conmurra";
$areanames{en}->{61877309} = "Coonawarra";
$areanames{en}->{61877310} = "Frances";
$areanames{en}->{61877311} = "Greenways";
$areanames{en}->{61877312} = "Kalangadoo";
$areanames{en}->{61877313} = "Keilira";
$areanames{en}->{61877314} = "Keith";
$areanames{en}->{61877315} = "Kingston\ Se";
$areanames{en}->{61877316} = "Kongorong";
$areanames{en}->{61877317} = "Laffer";
$areanames{en}->{61877318} = "Lochaber";
$areanames{en}->{61877319} = "Lucindale";
$areanames{en}->{61877320} = "Lucindale\ South";
$areanames{en}->{61877321} = "Makin";
$areanames{en}->{61877322} = "Marcollat";
$areanames{en}->{61877323} = "Millicent";
$areanames{en}->{61877324} = "Monkoora";
$areanames{en}->{61877325} = "Mount\ Gambier";
$areanames{en}->{61877326} = "Naracoorte";
$areanames{en}->{61877327} = "Padthaway";
$areanames{en}->{61877328} = "Penola";
$areanames{en}->{61877329} = "Port\ Macdonnell";
$areanames{en}->{61877330} = "Reedy\ Creek";
$areanames{en}->{61877331} = "Rendelsham";
$areanames{en}->{61877332} = "Robe";
$areanames{en}->{61877333} = "Short";
$areanames{en}->{61877334} = "Tantanoola";
$areanames{en}->{61877335} = "Taratap";
$areanames{en}->{61877336} = "Tarpeena";
$areanames{en}->{61877337} = "Thornlea";
$areanames{en}->{61877338} = "Tilley\ Swamp";
$areanames{en}->{61877339} = "Tintinara";
$areanames{en}->{61877340} = "Western\ Flat";
$areanames{en}->{61877341} = "Willalooka";
$areanames{en}->{61877342} = "Wirrega";
$areanames{en}->{61877343} = "Wrattonbully";
$areanames{en}->{61877344} = "Avenue\ Range";
$areanames{en}->{61877345} = "Bangham";
$areanames{en}->{61877346} = "Bordertown";
$areanames{en}->{61877347} = "Cannawigara";
$areanames{en}->{61877348} = "Colebatch";
$areanames{en}->{61877349} = "Conmurra";
$areanames{en}->{61877350} = "Coonawarra";
$areanames{en}->{61877351} = "Frances";
$areanames{en}->{61877352} = "Greenways";
$areanames{en}->{61877353} = "Kalangadoo";
$areanames{en}->{61877354} = "Keilira";
$areanames{en}->{61877355} = "Keith";
$areanames{en}->{61877356} = "Kingston\ Se";
$areanames{en}->{61877357} = "Kongorong";
$areanames{en}->{61877358} = "Laffer";
$areanames{en}->{61877359} = "Lochaber";
$areanames{en}->{61877360} = "Lucindale";
$areanames{en}->{61877361} = "Lucindale\ South";
$areanames{en}->{61877362} = "Makin";
$areanames{en}->{61877363} = "Marcollat";
$areanames{en}->{61877364} = "Millicent";
$areanames{en}->{61877365} = "Monkoora";
$areanames{en}->{61877366} = "Mount\ Gambier";
$areanames{en}->{61877367} = "Naracoorte";
$areanames{en}->{61877368} = "Padthaway";
$areanames{en}->{61877369} = "Penola";
$areanames{en}->{61877370} = "Port\ Macdonnell";
$areanames{en}->{61877371} = "Reedy\ Creek";
$areanames{en}->{61877372} = "Rendelsham";
$areanames{en}->{61877373} = "Robe";
$areanames{en}->{61877374} = "Short";
$areanames{en}->{61877375} = "Tantanoola";
$areanames{en}->{61877376} = "Taratap";
$areanames{en}->{61877377} = "Tarpeena";
$areanames{en}->{61877378} = "Thornlea";
$areanames{en}->{61877379} = "Tilley\ Swamp";
$areanames{en}->{61877380} = "Tintinara";
$areanames{en}->{61877381} = "Western\ Flat";
$areanames{en}->{61877382} = "Willalooka";
$areanames{en}->{61877383} = "Wirrega";
$areanames{en}->{61877384} = "Wrattonbully";
$areanames{en}->{61878000} = "Alford";
$areanames{en}->{61878001} = "Ardrossan";
$areanames{en}->{61878002} = "Arthurton";
$areanames{en}->{618780030} = "Auburn";
$areanames{en}->{618780031} = "Freeling";
$areanames{en}->{618780032} = "Gawler";
$areanames{en}->{618780033} = "Hamley\ Bridge";
$areanames{en}->{618780034} = "Riverton";
$areanames{en}->{618780035} = "Auburn";
$areanames{en}->{618780036} = "Freeling";
$areanames{en}->{618780037} = "Gawler";
$areanames{en}->{618780038} = "Hamley\ Bridge";
$areanames{en}->{618780039} = "Riverton";
$areanames{en}->{61878004} = "Balaklava";
$areanames{en}->{61878005} = "Blyth";
$areanames{en}->{61878006} = "Booborowie";
$areanames{en}->{61878007} = "Braemer";
$areanames{en}->{61878008} = "Brinkworth";
$areanames{en}->{61878009} = "Burra";
$areanames{en}->{61878010} = "Bute";
$areanames{en}->{61878011} = "Clare";
$areanames{en}->{61878012} = "Curramulka";
$areanames{en}->{61878013} = "Halbury";
$areanames{en}->{61878014} = "Hallett";
$areanames{en}->{61878015} = "Kadina";
$areanames{en}->{61878016} = "Lochiel";
$areanames{en}->{61878017} = "Maitland";
$areanames{en}->{61878018} = "Marion\ Bay";
$areanames{en}->{61878019} = "Minlaton";
$areanames{en}->{61878020} = "Moonta";
$areanames{en}->{61878021} = "Nantawarra";
$areanames{en}->{61878022} = "Paskeville";
$areanames{en}->{61878023} = "Pine\ Point";
$areanames{en}->{61878024} = "Port\ Victoria";
$areanames{en}->{61878025} = "Port\ Wakefield";
$areanames{en}->{61878026} = "Snowtown";
$areanames{en}->{61878027} = "South\ Hummocks";
$areanames{en}->{61878028} = "Spalding";
$areanames{en}->{61878029} = "Thistle";
$areanames{en}->{61878030} = "Warooka";
$areanames{en}->{61878031} = "Wedge";
$areanames{en}->{61878032} = "Yorketown";
$areanames{en}->{61878033} = "Alford";
$areanames{en}->{61878034} = "Ardrossan";
$areanames{en}->{61878035} = "Arthurton";
$areanames{en}->{61878036} = "Balaklava";
$areanames{en}->{61878037} = "Blyth";
$areanames{en}->{61878038} = "Booborowie";
$areanames{en}->{61878039} = "Braemer";
$areanames{en}->{61878040} = "Brinkworth";
$areanames{en}->{61878041} = "Burra";
$areanames{en}->{61878042} = "Bute";
$areanames{en}->{61878043} = "Clare";
$areanames{en}->{61878044} = "Curramulka";
$areanames{en}->{61878045} = "Halbury";
$areanames{en}->{61878046} = "Hallett";
$areanames{en}->{61878047} = "Kadina";
$areanames{en}->{61878048} = "Lochiel";
$areanames{en}->{61878049} = "Maitland";
$areanames{en}->{61878050} = "Marion\ Bay";
$areanames{en}->{61878051} = "Minlaton";
$areanames{en}->{61878052} = "Moonta";
$areanames{en}->{61878053} = "Nantawarra";
$areanames{en}->{61878054} = "Paskeville";
$areanames{en}->{61878055} = "Pine\ Point";
$areanames{en}->{61878056} = "Port\ Victoria";
$areanames{en}->{61878057} = "Port\ Wakefield";
$areanames{en}->{61878058} = "Snowtown";
$areanames{en}->{61878059} = "South\ Hummocks";
$areanames{en}->{61878060} = "Spalding";
$areanames{en}->{61878061} = "Thistle";
$areanames{en}->{61878062} = "Warooka";
$areanames{en}->{61878063} = "Wedge";
$areanames{en}->{61878064} = "Yorketown";
$areanames{en}->{61878065} = "Alford";
$areanames{en}->{61878066} = "Ardrossan";
$areanames{en}->{61878067} = "Arthurton";
$areanames{en}->{618780680} = "Auburn";
$areanames{en}->{618780681} = "Freeling";
$areanames{en}->{618780682} = "Gawler";
$areanames{en}->{618780683} = "Hamley\ Bridge";
$areanames{en}->{618780684} = "Riverton";
$areanames{en}->{618780685} = "Auburn";
$areanames{en}->{618780686} = "Freeling";
$areanames{en}->{618780687} = "Gawler";
$areanames{en}->{618780688} = "Hamley\ Bridge";
$areanames{en}->{618780689} = "Riverton";
$areanames{en}->{61878069} = "Balaklava";
$areanames{en}->{61878070} = "Blyth";
$areanames{en}->{61878071} = "Booborowie";
$areanames{en}->{61878072} = "Braemer";
$areanames{en}->{61878073} = "Brinkworth";
$areanames{en}->{61878074} = "Burra";
$areanames{en}->{61878075} = "Bute";
$areanames{en}->{61878076} = "Clare";
$areanames{en}->{61878077} = "Curramulka";
$areanames{en}->{61878078} = "Halbury";
$areanames{en}->{61878079} = "Hallett";
$areanames{en}->{61878080} = "Kadina";
$areanames{en}->{61878081} = "Lochiel";
$areanames{en}->{61878082} = "Maitland";
$areanames{en}->{61878083} = "Marion\ Bay";
$areanames{en}->{61878084} = "Minlaton";
$areanames{en}->{61878085} = "Moonta";
$areanames{en}->{61878086} = "Nantawarra";
$areanames{en}->{61878087} = "Paskeville";
$areanames{en}->{61878088} = "Pine\ Point";
$areanames{en}->{61878089} = "Port\ Victoria";
$areanames{en}->{61878090} = "Port\ Wakefield";
$areanames{en}->{61878091} = "Snowtown";
$areanames{en}->{61878092} = "South\ Hummocks";
$areanames{en}->{61878093} = "Spalding";
$areanames{en}->{61878094} = "Thistle";
$areanames{en}->{61878095} = "Warooka";
$areanames{en}->{61878096} = "Wedge";
$areanames{en}->{61878097} = "Yorketown";
$areanames{en}->{61878098} = "Alford";
$areanames{en}->{61878099} = "Ardrossan";
$areanames{en}->{61878100} = "Arthurton";
$areanames{en}->{61878101} = "Balaklava";
$areanames{en}->{61878102} = "Blyth";
$areanames{en}->{61878103} = "Booborowie";
$areanames{en}->{61878104} = "Braemer";
$areanames{en}->{61878105} = "Brinkworth";
$areanames{en}->{61878106} = "Burra";
$areanames{en}->{61878107} = "Bute";
$areanames{en}->{61878108} = "Clare";
$areanames{en}->{61878109} = "Curramulka";
$areanames{en}->{61878110} = "Halbury";
$areanames{en}->{61878111} = "Hallett";
$areanames{en}->{61878112} = "Kadina";
$areanames{en}->{61878113} = "Lochiel";
$areanames{en}->{61878114} = "Maitland";
$areanames{en}->{61878115} = "Marion\ Bay";
$areanames{en}->{61878116} = "Minlaton";
$areanames{en}->{61878117} = "Moonta";
$areanames{en}->{61878118} = "Nantawarra";
$areanames{en}->{61878119} = "Paskeville";
$areanames{en}->{61878120} = "Pine\ Point";
$areanames{en}->{61878121} = "Port\ Victoria";
$areanames{en}->{61878122} = "Port\ Wakefield";
$areanames{en}->{61878123} = "Snowtown";
$areanames{en}->{61878124} = "South\ Hummocks";
$areanames{en}->{61878125} = "Spalding";
$areanames{en}->{61878126} = "Thistle";
$areanames{en}->{61878127} = "Warooka";
$areanames{en}->{61878128} = "Wedge";
$areanames{en}->{61878129} = "Yorketown";
$areanames{en}->{61878130} = "Alford";
$areanames{en}->{61878131} = "Ardrossan";
$areanames{en}->{61878132} = "Arthurton";
$areanames{en}->{618781330} = "Auburn";
$areanames{en}->{618781331} = "Freeling";
$areanames{en}->{618781332} = "Gawler";
$areanames{en}->{618781333} = "Hamley\ Bridge";
$areanames{en}->{618781334} = "Riverton";
$areanames{en}->{618781335} = "Auburn";
$areanames{en}->{618781336} = "Freeling";
$areanames{en}->{618781337} = "Gawler";
$areanames{en}->{618781338} = "Hamley\ Bridge";
$areanames{en}->{618781339} = "Riverton";
$areanames{en}->{61878134} = "Balaklava";
$areanames{en}->{61878135} = "Blyth";
$areanames{en}->{61878136} = "Booborowie";
$areanames{en}->{61878137} = "Braemer";
$areanames{en}->{61878138} = "Brinkworth";
$areanames{en}->{61878139} = "Burra";
$areanames{en}->{61878140} = "Bute";
$areanames{en}->{61878141} = "Clare";
$areanames{en}->{61878142} = "Curramulka";
$areanames{en}->{61878143} = "Halbury";
$areanames{en}->{61878144} = "Hallett";
$areanames{en}->{61878145} = "Kadina";
$areanames{en}->{61878146} = "Lochiel";
$areanames{en}->{61878147} = "Maitland";
$areanames{en}->{61878148} = "Marion\ Bay";
$areanames{en}->{61878149} = "Minlaton";
$areanames{en}->{61878150} = "Moonta";
$areanames{en}->{61878151} = "Nantawarra";
$areanames{en}->{61878152} = "Paskeville";
$areanames{en}->{61878153} = "Pine\ Point";
$areanames{en}->{61878154} = "Port\ Victoria";
$areanames{en}->{61878155} = "Port\ Wakefield";
$areanames{en}->{61878156} = "Snowtown";
$areanames{en}->{61878157} = "South\ Hummocks";
$areanames{en}->{61878158} = "Spalding";
$areanames{en}->{61878159} = "Thistle";
$areanames{en}->{61878160} = "Warooka";
$areanames{en}->{61878161} = "Wedge";
$areanames{en}->{61878162} = "Yorketown";
$areanames{en}->{61878163} = "Clare";
$areanames{en}->{61878164} = "Clare";
$areanames{en}->{61878165} = "Clare";
$areanames{en}->{61878166} = "Alford";
$areanames{en}->{61878167} = "Ardrossan";
$areanames{en}->{61878168} = "Arthurton";
$areanames{en}->{61878169} = "Balaklava";
$areanames{en}->{61878170} = "Blyth";
$areanames{en}->{61878171} = "Booborowie";
$areanames{en}->{61878172} = "Braemer";
$areanames{en}->{61878173} = "Brinkworth";
$areanames{en}->{61878174} = "Burra";
$areanames{en}->{61878175} = "Bute";
$areanames{en}->{61878176} = "Clare";
$areanames{en}->{61878177} = "Curramulka";
$areanames{en}->{61878178} = "Halbury";
$areanames{en}->{61878179} = "Hallett";
$areanames{en}->{61878180} = "Kadina";
$areanames{en}->{61878181} = "Lochiel";
$areanames{en}->{61878182} = "Maitland";
$areanames{en}->{61878183} = "Marion\ Bay";
$areanames{en}->{61878184} = "Minlaton";
$areanames{en}->{61878185} = "Moonta";
$areanames{en}->{61878186} = "Nantawarra";
$areanames{en}->{61878187} = "Paskeville";
$areanames{en}->{61878188} = "Pine\ Point";
$areanames{en}->{61878189} = "Port\ Victoria";
$areanames{en}->{61878190} = "Port\ Wakefield";
$areanames{en}->{61878191} = "Snowtown";
$areanames{en}->{61878192} = "South\ Hummocks";
$areanames{en}->{61878193} = "Spalding";
$areanames{en}->{61878194} = "Thistle";
$areanames{en}->{61878195} = "Warooka";
$areanames{en}->{61878196} = "Wedge";
$areanames{en}->{61878197} = "Yorketown";
$areanames{en}->{61878198} = "Alford";
$areanames{en}->{61878199} = "Ardrossan";
$areanames{en}->{61878200} = "Arthurton";
$areanames{en}->{618782010} = "Auburn";
$areanames{en}->{618782011} = "Freeling";
$areanames{en}->{618782012} = "Gawler";
$areanames{en}->{618782013} = "Hamley\ Bridge";
$areanames{en}->{618782014} = "Riverton";
$areanames{en}->{618782015} = "Auburn";
$areanames{en}->{618782016} = "Freeling";
$areanames{en}->{618782017} = "Gawler";
$areanames{en}->{618782018} = "Hamley\ Bridge";
$areanames{en}->{618782019} = "Riverton";
$areanames{en}->{61878202} = "Balaklava";
$areanames{en}->{61878203} = "Blyth";
$areanames{en}->{61878204} = "Booborowie";
$areanames{en}->{61878205} = "Braemer";
$areanames{en}->{61878206} = "Brinkworth";
$areanames{en}->{61878207} = "Burra";
$areanames{en}->{61878208} = "Bute";
$areanames{en}->{61878209} = "Clare";
$areanames{en}->{61878210} = "Curramulka";
$areanames{en}->{61878211} = "Halbury";
$areanames{en}->{61878212} = "Hallett";
$areanames{en}->{61878213} = "Kadina";
$areanames{en}->{61878214} = "Lochiel";
$areanames{en}->{61878215} = "Maitland";
$areanames{en}->{61878216} = "Marion\ Bay";
$areanames{en}->{61878217} = "Minlaton";
$areanames{en}->{61878218} = "Moonta";
$areanames{en}->{61878219} = "Nantawarra";
$areanames{en}->{61878220} = "Paskeville";
$areanames{en}->{61878221} = "Pine\ Point";
$areanames{en}->{61878222} = "Port\ Victoria";
$areanames{en}->{61878223} = "Port\ Wakefield";
$areanames{en}->{61878224} = "Snowtown";
$areanames{en}->{61878225} = "South\ Hummocks";
$areanames{en}->{61878226} = "Spalding";
$areanames{en}->{61878227} = "Thistle";
$areanames{en}->{61878228} = "Warooka";
$areanames{en}->{61878229} = "Wedge";
$areanames{en}->{61878230} = "Yorketown";
$areanames{en}->{61878231} = "Alford";
$areanames{en}->{61878232} = "Ardrossan";
$areanames{en}->{61878233} = "Arthurton";
$areanames{en}->{61878234} = "Balaklava";
$areanames{en}->{61878235} = "Blyth";
$areanames{en}->{61878236} = "Booborowie";
$areanames{en}->{61878237} = "Braemer";
$areanames{en}->{61878238} = "Brinkworth";
$areanames{en}->{61878239} = "Burra";
$areanames{en}->{61878240} = "Bute";
$areanames{en}->{61878241} = "Clare";
$areanames{en}->{61878242} = "Curramulka";
$areanames{en}->{61878243} = "Halbury";
$areanames{en}->{61878244} = "Hallett";
$areanames{en}->{61878245} = "Kadina";
$areanames{en}->{61878246} = "Lochiel";
$areanames{en}->{61878247} = "Maitland";
$areanames{en}->{61878248} = "Marion\ Bay";
$areanames{en}->{61878249} = "Minlaton";
$areanames{en}->{61878250} = "Moonta";
$areanames{en}->{61878251} = "Nantawarra";
$areanames{en}->{61878252} = "Paskeville";
$areanames{en}->{61878253} = "Pine\ Point";
$areanames{en}->{61878254} = "Port\ Victoria";
$areanames{en}->{61878255} = "Port\ Wakefield";
$areanames{en}->{61878256} = "Snowtown";
$areanames{en}->{61878257} = "South\ Hummocks";
$areanames{en}->{61878258} = "Spalding";
$areanames{en}->{61878259} = "Thistle";
$areanames{en}->{61878260} = "Warooka";
$areanames{en}->{61878261} = "Wedge";
$areanames{en}->{61878262} = "Yorketown";
$areanames{en}->{61879000} = "Alice\ Springs";
$areanames{en}->{61879001} = "Darwin";
$areanames{en}->{61879002} = "Davenport";
$areanames{en}->{61879003} = "Davenport";
$areanames{en}->{61879004} = "Petermann";
$areanames{en}->{61879005} = "Petermann";
$areanames{en}->{61879006} = "Plenty";
$areanames{en}->{61879007} = "Plenty";
$areanames{en}->{61879008} = "Rodinga";
$areanames{en}->{61879009} = "Rodinga";
$areanames{en}->{61879010} = "Tablelands";
$areanames{en}->{61879011} = "Tablelands";
$areanames{en}->{61879012} = "Alyangula";
$areanames{en}->{61879013} = "Alyangula";
$areanames{en}->{61879014} = "Borroloola";
$areanames{en}->{61879015} = "Borroloola";
$areanames{en}->{61879016} = "Carpentaria";
$areanames{en}->{61879017} = "Carpentaria";
$areanames{en}->{61879018} = "Daly";
$areanames{en}->{61879019} = "Daly";
$areanames{en}->{61879020} = "Alice\ Springs";
$areanames{en}->{61879021} = "Alice\ Springs";
$areanames{en}->{61879022} = "Petermann";
$areanames{en}->{61879023} = "Roper\ River";
$areanames{en}->{61879024} = "Noonamah";
$areanames{en}->{61879025} = "Batchelor";
$areanames{en}->{61879026} = "Ranken\ River";
$areanames{en}->{61879027} = "Jabiru";
$areanames{en}->{61879028} = "Rodinga";
$areanames{en}->{61879029} = "Darwin";
$areanames{en}->{61879030} = "Darwin";
$areanames{en}->{61879031} = "Daly";
$areanames{en}->{61879032} = "Katherine";
$areanames{en}->{61879033} = "Borroloola";
$areanames{en}->{61879034} = "Davenport";
$areanames{en}->{61879035} = "Simpson";
$areanames{en}->{61879036} = "Tennant\ Creek";
$areanames{en}->{61879037} = "Noonamah";
$areanames{en}->{61879038} = "Alyangula";
$areanames{en}->{61879039} = "Darwin";
$areanames{en}->{61879040} = "Darwin";
$areanames{en}->{61879041} = "Carpentaria";
$areanames{en}->{61879042} = "Tablelands";
$areanames{en}->{61879043} = "Yulara";
$areanames{en}->{61879044} = "Alice\ Springs";
$areanames{en}->{61879045} = "Victoria\ River";
$areanames{en}->{61879046} = "Arnhem";
$areanames{en}->{61879047} = "Elliott";
$areanames{en}->{61879048} = "Pine\ Creek";
$areanames{en}->{61879049} = "Alice\ Springs";
$areanames{en}->{61879050} = "Davenport";
$areanames{en}->{61879051} = "Tiwi";
$areanames{en}->{61879052} = "Plenty";
$areanames{en}->{61879053} = "Nhulunbuy";
$areanames{en}->{61879054} = "Darwin";
$areanames{en}->{61879055} = "Alice\ Springs";
$areanames{en}->{61879056} = "Darwin";
$areanames{en}->{61879057} = "Darwin";
$areanames{en}->{61879058} = "Alice\ Springs";
$areanames{en}->{61879059} = "Elliott";
$areanames{en}->{61879060} = "Petermann";
$areanames{en}->{61879061} = "Darwin";
$areanames{en}->{61879062} = "Darwin";
$areanames{en}->{61879063} = "Nhulunbuy";
$areanames{en}->{61879064} = "Elliott";
$areanames{en}->{61879065} = "Roper\ River";
$areanames{en}->{61879066} = "Noonamah";
$areanames{en}->{61879067} = "Alice\ Springs";
$areanames{en}->{61879068} = "Pine\ Creek";
$areanames{en}->{61879069} = "Plenty";
$areanames{en}->{61879070} = "Ranken\ River";
$areanames{en}->{61879071} = "Tiwi";
$areanames{en}->{61879072} = "Elliott";
$areanames{en}->{61879073} = "Alyangula";
$areanames{en}->{61879074} = "Rodinga";
$areanames{en}->{61879075} = "Carpentaria";
$areanames{en}->{61879076} = "Plenty";
$areanames{en}->{61879077} = "Davenport";
$areanames{en}->{61879078} = "Tablelands";
$areanames{en}->{61879079} = "Rodinga";
$areanames{en}->{61879080} = "Simpson";
$areanames{en}->{61879081} = "Victoria\ River";
$areanames{en}->{61879082} = "Daly";
$areanames{en}->{61879083} = "Arnhem";
$areanames{en}->{61879084} = "Katherine";
$areanames{en}->{61879085} = "Yulara";
$areanames{en}->{61879086} = "Tennant\ Creek";
$areanames{en}->{61879087} = "Simpson";
$areanames{en}->{61879088} = "Borroloola";
$areanames{en}->{61879089} = "Tablelands";
$areanames{en}->{61879090} = "Tanami";
$areanames{en}->{61879091} = "Batchelor";
$areanames{en}->{61879092} = "Petermann";
$areanames{en}->{61879093} = "Ranken\ River";
$areanames{en}->{61879094} = "Jabiru";
$areanames{en}->{61879095} = "Nhulunbuy";
$areanames{en}->{61879096} = "Roper\ River";
$areanames{en}->{61879097} = "Noonamah";
$areanames{en}->{61879098} = "Pine\ Creek";
$areanames{en}->{61879099} = "Tennant\ Creek";
$areanames{en}->{61879100} = "Yulara";
$areanames{en}->{61879101} = "Tiwi";
$areanames{en}->{61879102} = "Rodinga";
$areanames{en}->{61879103} = "Alyangula";
$areanames{en}->{61879104} = "Carpentaria";
$areanames{en}->{61879105} = "Plenty";
$areanames{en}->{61879106} = "Davenport";
$areanames{en}->{61879107} = "Tablelands";
$areanames{en}->{61879108} = "Victoria\ River";
$areanames{en}->{61879109} = "Alyangula";
$areanames{en}->{61879110} = "Arnhem";
$areanames{en}->{61879111} = "Daly";
$areanames{en}->{61879112} = "Katherine";
$areanames{en}->{61879113} = "Arnhem";
$areanames{en}->{61879114} = "Simpson";
$areanames{en}->{61879115} = "Tennant\ Creek";
$areanames{en}->{61879116} = "Yulara";
$areanames{en}->{61879117} = "Borroloola";
$areanames{en}->{61879118} = "Batchelor";
$areanames{en}->{61879119} = "Batchelor";
$areanames{en}->{61879120} = "Borroloola";
$areanames{en}->{61879121} = "Petermann";
$areanames{en}->{61879122} = "Ranken\ River";
$areanames{en}->{61879123} = "Jabiru";
$areanames{en}->{61879124} = "Nhulunbuy";
$areanames{en}->{61879125} = "Darwin";
$areanames{en}->{61879126} = "Carpentaria";
$areanames{en}->{61879127} = "Daly";
$areanames{en}->{61879128} = "Darwin";
$areanames{en}->{61879129} = "Jabiru";
$areanames{en}->{61879130} = "Katherine";
$areanames{en}->{61879131} = "Nhulunbuy";
$areanames{en}->{61879132} = "Noonamah";
$areanames{en}->{61879133} = "Pine\ Creek";
$areanames{en}->{61879134} = "Roper\ River";
$areanames{en}->{61879135} = "Tiwi";
$areanames{en}->{61879136} = "Victoria\ River";
$areanames{en}->{61879137} = "Darwin";
$areanames{en}->{61879138} = "Darwin";
$areanames{en}->{61879139} = "Darwin";
$areanames{en}->{61879140} = "Alice\ Springs";
$areanames{en}->{61879141} = "Alyangula";
$areanames{en}->{61879142} = "Arnhem";
$areanames{en}->{61879143} = "Batchelor";
$areanames{en}->{61879144} = "Borroloola";
$areanames{en}->{61879145} = "Carpentaria";
$areanames{en}->{61879146} = "Daly";
$areanames{en}->{61879147} = "Darwin";
$areanames{en}->{61879148} = "Alice\ Springs";
$areanames{en}->{61879149} = "Davenport";
$areanames{en}->{6187915} = "Darwin";
$areanames{en}->{61879160} = "Elliott";
$areanames{en}->{61879161} = "Jabiru";
$areanames{en}->{61879162} = "Katherine";
$areanames{en}->{61879163} = "Nhulunbuy";
$areanames{en}->{61879164} = "Noonamah";
$areanames{en}->{61879165} = "Petermann";
$areanames{en}->{61879166} = "Pine\ Creek";
$areanames{en}->{61879167} = "Plenty";
$areanames{en}->{61879168} = "Ranken\ River";
$areanames{en}->{61879169} = "Rodinga";
$areanames{en}->{61879170} = "Roper\ River";
$areanames{en}->{61879171} = "Simpson";
$areanames{en}->{61879172} = "Tablelands";
$areanames{en}->{61879173} = "Tanami";
$areanames{en}->{61879174} = "Tennant\ Creek";
$areanames{en}->{61879175} = "Tiwi";
$areanames{en}->{61879176} = "Victoria\ River";
$areanames{en}->{61879177} = "Yulara";
$areanames{en}->{61879178} = "Darwin";
$areanames{en}->{61879179} = "Darwin";
$areanames{en}->{6187918} = "Darwin";
$areanames{en}->{6187919} = "Darwin";
$areanames{en}->{61879200} = "Alice\ Springs";
$areanames{en}->{61879201} = "Alyangula";
$areanames{en}->{61879202} = "Arnhem";
$areanames{en}->{61879203} = "Batchelor";
$areanames{en}->{61879204} = "Borroloola";
$areanames{en}->{61879205} = "Carpentaria";
$areanames{en}->{61879206} = "Daly";
$areanames{en}->{61879207} = "Darwin";
$areanames{en}->{61879208} = "Davenport";
$areanames{en}->{61879209} = "Elliott";
$areanames{en}->{61879210} = "Jabiru";
$areanames{en}->{61879211} = "Katherine";
$areanames{en}->{61879212} = "Nhulunbuy";
$areanames{en}->{61879213} = "Noonamah";
$areanames{en}->{61879214} = "Petermann";
$areanames{en}->{61879215} = "Pine\ Creek";
$areanames{en}->{61879216} = "Plenty";
$areanames{en}->{61879217} = "Ranken\ River";
$areanames{en}->{61879218} = "Rodinga";
$areanames{en}->{61879219} = "Roper\ River";
$areanames{en}->{6187922} = "Darwin";
$areanames{en}->{61879230} = "Darwin";
$areanames{en}->{61879231} = "Darwin";
$areanames{en}->{61879232} = "Darwin";
$areanames{en}->{61879233} = "Simpson";
$areanames{en}->{61879234} = "Tablelands";
$areanames{en}->{61879235} = "Tanami";
$areanames{en}->{61879236} = "Tennant\ Creek";
$areanames{en}->{61879237} = "Tiwi";
$areanames{en}->{61879238} = "Victoria\ River";
$areanames{en}->{61879239} = "Yulara";
$areanames{en}->{61879240} = "Alice\ Springs";
$areanames{en}->{61879241} = "Alyangula";
$areanames{en}->{61879242} = "Arnhem";
$areanames{en}->{61879243} = "Batchelor";
$areanames{en}->{61879244} = "Borroloola";
$areanames{en}->{61879245} = "Carpentaria";
$areanames{en}->{61879246} = "Daly";
$areanames{en}->{61879247} = "Darwin";
$areanames{en}->{61879248} = "Davenport";
$areanames{en}->{61879249} = "Elliott";
$areanames{en}->{61879250} = "Jabiru";
$areanames{en}->{61879251} = "Katherine";
$areanames{en}->{61879252} = "Nhulunbuy";
$areanames{en}->{61879253} = "Noonamah";
$areanames{en}->{61879254} = "Petermann";
$areanames{en}->{61879255} = "Pine\ Creek";
$areanames{en}->{61879256} = "Plenty";
$areanames{en}->{61879257} = "Ranken\ River";
$areanames{en}->{61879258} = "Rodinga";
$areanames{en}->{61879259} = "Roper\ River";
$areanames{en}->{61879260} = "Simpson";
$areanames{en}->{61879261} = "Tablelands";
$areanames{en}->{61879262} = "Tanami";
$areanames{en}->{61879263} = "Tennant\ Creek";
$areanames{en}->{61879264} = "Tiwi";
$areanames{en}->{61879265} = "Victoria\ River";
$areanames{en}->{61879266} = "Yulara";
$areanames{en}->{61879267} = "Darwin";
$areanames{en}->{61879268} = "Darwin";
$areanames{en}->{61879269} = "Darwin";
$areanames{en}->{6187927} = "Darwin";
$areanames{en}->{6187928} = "Darwin";
$areanames{en}->{61879287} = "Alice\ Springs";
$areanames{en}->{61879288} = "Alice\ Springs";
$areanames{en}->{61879289} = "Alice\ Springs";
$areanames{en}->{6187929} = "Darwin";
$areanames{en}->{61879300} = "Alice\ Springs";
$areanames{en}->{61879301} = "Alyangula";
$areanames{en}->{61879302} = "Arnhem";
$areanames{en}->{61879303} = "Batchelor";
$areanames{en}->{61879304} = "Borroloola";
$areanames{en}->{61879305} = "Carpentaria";
$areanames{en}->{61879306} = "Daly";
$areanames{en}->{61879307} = "Darwin";
$areanames{en}->{61879308} = "Davenport";
$areanames{en}->{61879309} = "Elliott";
$areanames{en}->{61879310} = "Jabiru";
$areanames{en}->{61879311} = "Katherine";
$areanames{en}->{61879312} = "Nhulunbuy";
$areanames{en}->{61879313} = "Noonamah";
$areanames{en}->{61879314} = "Alice\ Springs";
$areanames{en}->{61879315} = "Alyangula";
$areanames{en}->{61879316} = "Arnhem";
$areanames{en}->{61879317} = "Batchelor";
$areanames{en}->{61879318} = "Borroloola";
$areanames{en}->{61879319} = "Carpentaria";
$areanames{en}->{61879320} = "Daly";
$areanames{en}->{61879321} = "Darwin";
$areanames{en}->{61879322} = "Davenport";
$areanames{en}->{61879323} = "Elliott";
$areanames{en}->{61879324} = "Jabiru";
$areanames{en}->{61879325} = "Katherine";
$areanames{en}->{61879326} = "Nhulunbuy";
$areanames{en}->{61879327} = "Noonamah";
$areanames{en}->{61879328} = "Petermann";
$areanames{en}->{61879329} = "Pine\ Creek";
$areanames{en}->{61879330} = "Plenty";
$areanames{en}->{61879331} = "Ranken\ River";
$areanames{en}->{61879332} = "Rodinga";
$areanames{en}->{61879333} = "Roper\ River";
$areanames{en}->{61879334} = "Simpson";
$areanames{en}->{61879335} = "Tablelands";
$areanames{en}->{61879336} = "Tanami";
$areanames{en}->{61879337} = "Tennant\ Creek";
$areanames{en}->{61879338} = "Tiwi";
$areanames{en}->{61879339} = "Victoria\ River";
$areanames{en}->{61879340} = "Yulara";
$areanames{en}->{61879341} = "Petermann";
$areanames{en}->{61879342} = "Pine\ Creek";
$areanames{en}->{61879343} = "Plenty";
$areanames{en}->{61879344} = "Ranken\ River";
$areanames{en}->{61879345} = "Rodinga";
$areanames{en}->{61879346} = "Roper\ River";
$areanames{en}->{61879347} = "Simpson";
$areanames{en}->{61879348} = "Tablelands";
$areanames{en}->{61879349} = "Tanami";
$areanames{en}->{61879350} = "Tennant\ Creek";
$areanames{en}->{61879351} = "Tiwi";
$areanames{en}->{61879352} = "Victoria\ River";
$areanames{en}->{61879353} = "Yulara";
$areanames{en}->{61879354} = "Alice\ Springs";
$areanames{en}->{61879355} = "Alyangula";
$areanames{en}->{61879356} = "Arnhem";
$areanames{en}->{61879357} = "Batchelor";
$areanames{en}->{61879358} = "Borroloola";
$areanames{en}->{61879359} = "Carpentaria";
$areanames{en}->{61879360} = "Daly";
$areanames{en}->{61879361} = "Darwin";
$areanames{en}->{61879362} = "Davenport";
$areanames{en}->{61879363} = "Elliott";
$areanames{en}->{61879364} = "Jabiru";
$areanames{en}->{61879365} = "Katherine";
$areanames{en}->{61879366} = "Nhulunbuy";
$areanames{en}->{61879367} = "Noonamah";
$areanames{en}->{61879368} = "Petermann";
$areanames{en}->{61879369} = "Pine\ Creek";
$areanames{en}->{61879370} = "Plenty";
$areanames{en}->{61879371} = "Ranken\ River";
$areanames{en}->{61879372} = "Rodinga";
$areanames{en}->{61879373} = "Roper\ River";
$areanames{en}->{61879374} = "Simpson";
$areanames{en}->{61879375} = "Tablelands";
$areanames{en}->{61879376} = "Tanami";
$areanames{en}->{61879377} = "Tennant\ Creek";
$areanames{en}->{61879378} = "Tiwi";
$areanames{en}->{61879379} = "Victoria\ River";
$areanames{en}->{61879380} = "Yulara";
$areanames{en}->{61879381} = "Nhulunbuy";
$areanames{en}->{61879382} = "Nhulunbuy";
$areanames{en}->{61879383} = "Alice\ Springs";
$areanames{en}->{61879384} = "Alyangula";
$areanames{en}->{61879385} = "Arnhem";
$areanames{en}->{61879386} = "Batchelor";
$areanames{en}->{61879387} = "Borroloola";
$areanames{en}->{61879388} = "Carpentaria";
$areanames{en}->{61879389} = "Daly";
$areanames{en}->{61879390} = "Darwin";
$areanames{en}->{61879391} = "Davenport";
$areanames{en}->{61879392} = "Elliott";
$areanames{en}->{61879393} = "Jabiru";
$areanames{en}->{61879394} = "Katherine";
$areanames{en}->{61879395} = "Nhulunbuy";
$areanames{en}->{61879396} = "Noonamah";
$areanames{en}->{61879397} = "Petermann";
$areanames{en}->{61879398} = "Pine\ Creek";
$areanames{en}->{61879399} = "Plenty";
$areanames{en}->{61879400} = "Ranken\ River";
$areanames{en}->{61879401} = "Rodinga";
$areanames{en}->{61879402} = "Roper\ River";
$areanames{en}->{61879403} = "Simpson";
$areanames{en}->{61879404} = "Tablelands";
$areanames{en}->{61879405} = "Tanami";
$areanames{en}->{61879406} = "Tennant\ Creek";
$areanames{en}->{61879407} = "Tiwi";
$areanames{en}->{61879408} = "Victoria\ River";
$areanames{en}->{61879409} = "Yulara";
$areanames{en}->{61879410} = "Alice\ Springs";
$areanames{en}->{61879411} = "Alyangula";
$areanames{en}->{61879412} = "Arnhem";
$areanames{en}->{61879413} = "Batchelor";
$areanames{en}->{61879414} = "Borroloola";
$areanames{en}->{61879415} = "Carpentaria";
$areanames{en}->{61879416} = "Daly";
$areanames{en}->{61879417} = "Darwin";
$areanames{en}->{61879418} = "Davenport";
$areanames{en}->{61879419} = "Elliott";
$areanames{en}->{61879420} = "Jabiru";
$areanames{en}->{61879421} = "Katherine";
$areanames{en}->{61879422} = "Nhulunbuy";
$areanames{en}->{61879423} = "Noonamah";
$areanames{en}->{61879424} = "Petermann";
$areanames{en}->{61879425} = "Pine\ Creek";
$areanames{en}->{61879426} = "Plenty";
$areanames{en}->{61879427} = "Ranken\ River";
$areanames{en}->{61879428} = "Rodinga";
$areanames{en}->{61879429} = "Roper\ River";
$areanames{en}->{61879430} = "Simpson";
$areanames{en}->{61879431} = "Tablelands";
$areanames{en}->{61879432} = "Tanami";
$areanames{en}->{61879433} = "Tennant\ Creek";
$areanames{en}->{61879434} = "Tiwi";
$areanames{en}->{61879435} = "Victoria\ River";
$areanames{en}->{61879436} = "Yulara";
$areanames{en}->{61879691} = "Tennant\ Creek";
$areanames{en}->{61879692} = "Alice\ Springs";
$areanames{en}->{61879693} = "Alice\ Springs";
$areanames{en}->{61879694} = "Alice\ Springs";
$areanames{en}->{61879695} = "Darwin";
$areanames{en}->{61879696} = "Darwin";
$areanames{en}->{61879697} = "Darwin";
$areanames{en}->{61879698} = "Darwin";
$areanames{en}->{61879699} = "Darwin";
$areanames{en}->{61879700} = "Darwin";
$areanames{en}->{61879781} = "Tennant\ Creek";
$areanames{en}->{61879782} = "Katherine";
$areanames{en}->{61879783} = "Darwin";
$areanames{en}->{61879784} = "Darwin";
$areanames{en}->{61879785} = "Darwin";
$areanames{en}->{61879786} = "Darwin";
$areanames{en}->{61879787} = "Darwin";
$areanames{en}->{61879788} = "Darwin";
$areanames{en}->{61879789} = "Borroloola";
$areanames{en}->{6187979} = "Darwin";
$areanames{en}->{61879795} = "Arnhem";
$areanames{en}->{6187980} = "Darwin";
$areanames{en}->{6187988} = "Darwin";
$areanames{en}->{6187989} = "Darwin";
$areanames{en}->{61879994} = "Batchelor";
$areanames{en}->{61879995} = "Batchelor";
$areanames{en}->{61879996} = "Alice\ Springs";
$areanames{en}->{61879997} = "Darwin";
$areanames{en}->{61879998} = "Darwin";
$areanames{en}->{61879999} = "Darwin";
$areanames{en}->{61880000} = "Broken\ Hill";
$areanames{en}->{61880001} = "Broken\ Hill";
$areanames{en}->{61880002} = "Broken\ Hill";
$areanames{en}->{61880003} = "Broken\ Hill";
$areanames{en}->{61880004} = "Broken\ Hill";
$areanames{en}->{61880005} = "Dolo";
$areanames{en}->{61880006} = "Menindee";
$areanames{en}->{61880007} = "Pimpara";
$areanames{en}->{61880008} = "Tepco";
$areanames{en}->{61880009} = "The\ Darling";
$areanames{en}->{61880010} = "Broken\ Hill";
$areanames{en}->{61880011} = "Broken\ Hill";
$areanames{en}->{61880012} = "Broken\ Hill";
$areanames{en}->{61880013} = "Dolo";
$areanames{en}->{61880014} = "Dolo";
$areanames{en}->{61880015} = "Dolo";
$areanames{en}->{61880016} = "Menindee";
$areanames{en}->{61880017} = "Menindee";
$areanames{en}->{61880018} = "Menindee";
$areanames{en}->{61880019} = "Tibooburra";
$areanames{en}->{61880020} = "Pimpara";
$areanames{en}->{61880021} = "Pimpara";
$areanames{en}->{61880022} = "Pimpara";
$areanames{en}->{61880023} = "Tepco";
$areanames{en}->{61880024} = "Tepco";
$areanames{en}->{61880025} = "Tepco";
$areanames{en}->{61880026} = "The\ Darling";
$areanames{en}->{61880027} = "The\ Darling";
$areanames{en}->{61880028} = "The\ Darling";
$areanames{en}->{61880029} = "White\ Cliffs";
$areanames{en}->{61880030} = "Tibooburra";
$areanames{en}->{61880031} = "Tibooburra";
$areanames{en}->{61880032} = "Tibooburra";
$areanames{en}->{61880033} = "White\ Cliffs";
$areanames{en}->{61880034} = "White\ Cliffs";
$areanames{en}->{61880035} = "White\ Cliffs";
$areanames{en}->{61880036} = "Wilcannia";
$areanames{en}->{61880037} = "Wilcannia";
$areanames{en}->{61880038} = "Wilcannia";
$areanames{en}->{61880039} = "Wilcannia";
$areanames{en}->{61880040} = "Broken\ Hill";
$areanames{en}->{61880041} = "Dolo";
$areanames{en}->{61880042} = "Menindee";
$areanames{en}->{61880043} = "Pimpara";
$areanames{en}->{61880044} = "Tepco";
$areanames{en}->{61880045} = "The\ Darling";
$areanames{en}->{61880046} = "Tibooburra";
$areanames{en}->{61880047} = "White\ Cliffs";
$areanames{en}->{61880048} = "Wilcannia";
$areanames{en}->{61880049} = "Broken\ Hill";
$areanames{en}->{61880050} = "Dolo";
$areanames{en}->{61880051} = "Menindee";
$areanames{en}->{61880052} = "Pimpara";
$areanames{en}->{61880053} = "Tepco";
$areanames{en}->{61880054} = "The\ Darling";
$areanames{en}->{61880055} = "Tibooburra";
$areanames{en}->{61880056} = "White\ Cliffs";
$areanames{en}->{61880057} = "Wilcannia";
$areanames{en}->{61880058} = "Broken\ Hill";
$areanames{en}->{61880059} = "Dolo";
$areanames{en}->{61880060} = "Menindee";
$areanames{en}->{61880061} = "Pimpara";
$areanames{en}->{61880062} = "Tepco";
$areanames{en}->{61880063} = "The\ Darling";
$areanames{en}->{61880064} = "Tibooburra";
$areanames{en}->{61880065} = "White\ Cliffs";
$areanames{en}->{61880066} = "Wilcannia";
$areanames{en}->{61880067} = "Broken\ Hill";
$areanames{en}->{61880068} = "Dolo";
$areanames{en}->{61880069} = "Menindee";
$areanames{en}->{61880070} = "Pimpara";
$areanames{en}->{61880071} = "Tepco";
$areanames{en}->{61880072} = "The\ Darling";
$areanames{en}->{61880073} = "Tibooburra";
$areanames{en}->{61880074} = "White\ Cliffs";
$areanames{en}->{61880075} = "Wilcannia";
$areanames{en}->{61880076} = "Broken\ Hill";
$areanames{en}->{61880077} = "Dolo";
$areanames{en}->{61880078} = "Menindee";
$areanames{en}->{61880079} = "Pimpara";
$areanames{en}->{61880080} = "Tepco";
$areanames{en}->{61880081} = "The\ Darling";
$areanames{en}->{61880082} = "Tibooburra";
$areanames{en}->{61880083} = "White\ Cliffs";
$areanames{en}->{61880084} = "Wilcannia";
$areanames{en}->{61880085} = "Broken\ Hill";
$areanames{en}->{61880086} = "Dolo";
$areanames{en}->{61880087} = "Menindee";
$areanames{en}->{61880088} = "Pimpara";
$areanames{en}->{61880089} = "Tepco";
$areanames{en}->{61880090} = "The\ Darling";
$areanames{en}->{61880091} = "Tibooburra";
$areanames{en}->{61880092} = "White\ Cliffs";
$areanames{en}->{61880093} = "Wilcannia";
$areanames{en}->{61880094} = "Broken\ Hill";
$areanames{en}->{61880095} = "Broken\ Hill";
$areanames{en}->{61880096} = "Broken\ Hill";
$areanames{en}->{61880097} = "Dolo";
$areanames{en}->{61880098} = "The\ Darling";
$areanames{en}->{61880099} = "Broken\ Hill";
$areanames{en}->{61880100} = "Dolo";
$areanames{en}->{61880101} = "Wilcannia";
$areanames{en}->{61880102} = "Pimpara";
$areanames{en}->{61880103} = "White\ Cliffs";
$areanames{en}->{61880104} = "Tibooburra";
$areanames{en}->{61880105} = "Tepco";
$areanames{en}->{61880106} = "Menindee";
$areanames{en}->{61880107} = "Broken\ Hill";
$areanames{en}->{61880108} = "Dolo";
$areanames{en}->{61880109} = "Menindee";
$areanames{en}->{61880110} = "Pimpara";
$areanames{en}->{61880111} = "The\ Darling";
$areanames{en}->{61880112} = "Wilcannia";
$areanames{en}->{61880113} = "Pimpara";
$areanames{en}->{61880114} = "White\ Cliffs";
$areanames{en}->{61880115} = "Tibooburra";
$areanames{en}->{61880116} = "Tepco";
$areanames{en}->{61880117} = "Menindee";
$areanames{en}->{61880118} = "Broken\ Hill";
$areanames{en}->{61880119} = "Tepco";
$areanames{en}->{61880120} = "The\ Darling";
$areanames{en}->{61880121} = "Tepco";
$areanames{en}->{61880122} = "Menindee";
$areanames{en}->{61880123} = "The\ Darling";
$areanames{en}->{61880124} = "Tibooburra";
$areanames{en}->{61880125} = "Pimpara";
$areanames{en}->{61880126} = "Wilcannia";
$areanames{en}->{61880127} = "White\ Cliffs";
$areanames{en}->{61880128} = "Dolo";
$areanames{en}->{61880129} = "Tibooburra";
$areanames{en}->{61880130} = "White\ Cliffs";
$areanames{en}->{61880131} = "Broken\ Hill";
$areanames{en}->{61880132} = "Wilcannia";
$areanames{en}->{61880133} = "Broken\ Hill";
$areanames{en}->{61880134} = "Dolo";
$areanames{en}->{61880135} = "Menindee";
$areanames{en}->{61880136} = "Pimpara";
$areanames{en}->{61880137} = "Tepco";
$areanames{en}->{61880138} = "The\ Darling";
$areanames{en}->{61880139} = "Tibooburra";
$areanames{en}->{61880140} = "White\ Cliffs";
$areanames{en}->{61880141} = "Wilcannia";
$areanames{en}->{61880142} = "Broken\ Hill";
$areanames{en}->{61880143} = "Dolo";
$areanames{en}->{61880144} = "Menindee";
$areanames{en}->{61880145} = "Pimpara";
$areanames{en}->{61880146} = "Tepco";
$areanames{en}->{61880147} = "The\ Darling";
$areanames{en}->{61880148} = "Tibooburra";
$areanames{en}->{61880149} = "White\ Cliffs";
$areanames{en}->{61880150} = "Wilcannia";
$areanames{en}->{61880151} = "Broken\ Hill";
$areanames{en}->{61880152} = "Dolo";
$areanames{en}->{61880153} = "Menindee";
$areanames{en}->{61880154} = "Pimpara";
$areanames{en}->{61880155} = "Tepco";
$areanames{en}->{61880156} = "The\ Darling";
$areanames{en}->{61880157} = "Tibooburra";
$areanames{en}->{61880158} = "White\ Cliffs";
$areanames{en}->{61880159} = "Wilcannia";
$areanames{en}->{61880160} = "Broken\ Hill";
$areanames{en}->{61880161} = "Dolo";
$areanames{en}->{61880162} = "Menindee";
$areanames{en}->{61880163} = "Pimpara";
$areanames{en}->{61880164} = "Tepco";
$areanames{en}->{61880165} = "The\ Darling";
$areanames{en}->{61880166} = "Tibooburra";
$areanames{en}->{61880167} = "White\ Cliffs";
$areanames{en}->{61880168} = "Wilcannia";
$areanames{en}->{61880169} = "Broken\ Hill";
$areanames{en}->{61880170} = "Dolo";
$areanames{en}->{61880171} = "Menindee";
$areanames{en}->{61880172} = "Pimpara";
$areanames{en}->{61880173} = "Tepco";
$areanames{en}->{61880174} = "The\ Darling";
$areanames{en}->{61880175} = "Tibooburra";
$areanames{en}->{61880176} = "White\ Cliffs";
$areanames{en}->{61880177} = "Wilcannia";
$areanames{en}->{61880178} = "Broken\ Hill";
$areanames{en}->{61880179} = "Dolo";
$areanames{en}->{61880180} = "Menindee";
$areanames{en}->{61880181} = "Pimpara";
$areanames{en}->{61880182} = "Tepco";
$areanames{en}->{61880183} = "The\ Darling";
$areanames{en}->{61880184} = "Tibooburra";
$areanames{en}->{61880185} = "White\ Cliffs";
$areanames{en}->{61880186} = "Wilcannia";
$areanames{en}->{61880187} = "Broken\ Hill";
$areanames{en}->{61880188} = "Dolo";
$areanames{en}->{61880189} = "Menindee";
$areanames{en}->{61880190} = "Pimpara";
$areanames{en}->{61880191} = "Tepco";
$areanames{en}->{61880192} = "The\ Darling";
$areanames{en}->{61880193} = "Tibooburra";
$areanames{en}->{61880194} = "White\ Cliffs";
$areanames{en}->{61880195} = "Wilcannia";
$areanames{en}->{61880196} = "Broken\ Hill";
$areanames{en}->{61880197} = "Dolo";
$areanames{en}->{61880198} = "Menindee";
$areanames{en}->{61880199} = "Pimpara";
$areanames{en}->{61880200} = "Tepco";
$areanames{en}->{61880201} = "The\ Darling";
$areanames{en}->{61880202} = "Tibooburra";
$areanames{en}->{61880203} = "White\ Cliffs";
$areanames{en}->{61880204} = "Wilcannia";
$areanames{en}->{61880800} = "Broken\ Hill";
$areanames{en}->{61880801} = "Broken\ Hill";
$areanames{en}->{61880802} = "Broken\ Hill";
$areanames{en}->{61880803} = "Broken\ Hill";
$areanames{en}->{61880804} = "Menindee";
$areanames{en}->{61880805} = "Wilcannia";
$areanames{en}->{61880806} = "The\ Darling";
$areanames{en}->{61880807} = "Tepco";
$areanames{en}->{61880808} = "Dolo";
$areanames{en}->{61880809} = "Pimpara";
$areanames{en}->{61880810} = "Broken\ Hill";
$areanames{en}->{61880811} = "Broken\ Hill";
$areanames{en}->{61880812} = "Dolo";
$areanames{en}->{61880813} = "Dolo";
$areanames{en}->{61880814} = "Pimpara";
$areanames{en}->{61880815} = "Pimpara";
$areanames{en}->{61880816} = "Tepco";
$areanames{en}->{61880817} = "Tepco";
$areanames{en}->{61880818} = "Menindee";
$areanames{en}->{61880819} = "Menindee";
$areanames{en}->{6188082} = "Broken\ Hill";
$areanames{en}->{61880830} = "Dolo";
$areanames{en}->{61880831} = "The\ Darling";
$areanames{en}->{61880832} = "Menindee";
$areanames{en}->{61880833} = "Menindee";
$areanames{en}->{61880834} = "Tibooburra";
$areanames{en}->{61880835} = "Tibooburra";
$areanames{en}->{61880836} = "White\ Cliffs";
$areanames{en}->{61880837} = "White\ Cliffs";
$areanames{en}->{61880838} = "Wilcannia";
$areanames{en}->{61880839} = "Wilcannia";
$areanames{en}->{6188084} = "Broken\ Hill";
$areanames{en}->{6188087} = "Broken\ Hill";
$areanames{en}->{6188088} = "Broken\ Hill";
$areanames{en}->{61880890} = "Broken\ Hill";
$areanames{en}->{61880891} = "Broken\ Hill";
$areanames{en}->{61880892} = "Broken\ Hill";
$areanames{en}->{61880893} = "Broken\ Hill";
$areanames{en}->{61880894} = "Broken\ Hill";
$areanames{en}->{61880900} = "Wilcannia";
$areanames{en}->{61880901} = "Wilcannia";
$areanames{en}->{61880902} = "White\ Cliffs";
$areanames{en}->{61880903} = "White\ Cliffs";
$areanames{en}->{61880904} = "Tibooburra";
$areanames{en}->{61880905} = "Tibooburra";
$areanames{en}->{61880906} = "The\ Darling";
$areanames{en}->{61880907} = "The\ Darling";
$areanames{en}->{61880908} = "Broken\ Hill";
$areanames{en}->{61880910} = "Tepco";
$areanames{en}->{61880911} = "Tepco";
$areanames{en}->{61880912} = "Pimpara";
$areanames{en}->{61880913} = "Wilcannia";
$areanames{en}->{61880914} = "Menindee";
$areanames{en}->{61880915} = "Wilcannia";
$areanames{en}->{61880916} = "Wilcannia";
$areanames{en}->{61880917} = "The\ Darling";
$areanames{en}->{61880918} = "Pimpara";
$areanames{en}->{61880919} = "Dolo";
$areanames{en}->{61880920} = "Broken\ Hill";
$areanames{en}->{61880921} = "Dolo";
$areanames{en}->{61880922} = "Menindee";
$areanames{en}->{61880923} = "Pimpara";
$areanames{en}->{61880924} = "Tepco";
$areanames{en}->{61880925} = "The\ Darling";
$areanames{en}->{61880926} = "Tibooburra";
$areanames{en}->{61880927} = "White\ Cliffs";
$areanames{en}->{61880928} = "Wilcannia";
$areanames{en}->{6188100} = "Adelaide";
$areanames{en}->{6188101} = "Adelaide";
$areanames{en}->{6188104} = "Adelaide";
$areanames{en}->{6188110} = "Adelaide";
$areanames{en}->{6188111} = "Adelaide";
$areanames{en}->{6188112} = "Adelaide";
$areanames{en}->{6188113} = "Adelaide";
$areanames{en}->{6188114} = "Adelaide";
$areanames{en}->{6188115} = "Adelaide";
$areanames{en}->{6188116} = "Adelaide";
$areanames{en}->{6188117} = "Adelaide";
$areanames{en}->{6188118} = "Adelaide";
$areanames{en}->{61881190} = "Adelaide";
$areanames{en}->{6188120} = "Adelaide";
$areanames{en}->{6188121} = "Adelaide";
$areanames{en}->{6188124} = "Adelaide";
$areanames{en}->{6188129} = "Adelaide";
$areanames{en}->{6188130} = "Adelaide";
$areanames{en}->{6188131} = "Adelaide";
$areanames{en}->{6188132} = "Adelaide";
$areanames{en}->{6188133} = "Adelaide";
$areanames{en}->{6188134} = "Adelaide";
$areanames{en}->{6188135} = "Adelaide";
$areanames{en}->{6188139} = "Adelaide";
$areanames{en}->{6188150} = "Adelaide";
$areanames{en}->{6188152} = "Adelaide";
$areanames{en}->{6188154} = "Adelaide";
$areanames{en}->{61881550} = "Adelaide";
$areanames{en}->{61881551} = "Adelaide";
$areanames{en}->{61881552} = "Adelaide";
$areanames{en}->{61881553} = "Adelaide";
$areanames{en}->{61881554} = "Adelaide";
$areanames{en}->{61881555} = "Adelaide";
$areanames{en}->{61881556} = "Adelaide";
$areanames{en}->{6188159} = "Adelaide";
$areanames{en}->{6188161} = "Adelaide";
$areanames{en}->{6188162} = "Adelaide";
$areanames{en}->{6188164} = "Adelaide";
$areanames{en}->{6188165} = "Adelaide";
$areanames{en}->{61881660} = "Adelaide";
$areanames{en}->{61881661} = "Adelaide";
$areanames{en}->{61881662} = "Adelaide";
$areanames{en}->{61881663} = "Adelaide";
$areanames{en}->{61881666} = "Adelaide";
$areanames{en}->{61881667} = "Adelaide";
$areanames{en}->{6188168} = "Adelaide";
$areanames{en}->{6188169} = "Adelaide";
$areanames{en}->{6188172} = "Adelaide";
$areanames{en}->{6188177} = "Adelaide";
$areanames{en}->{6188178} = "Adelaide";
$areanames{en}->{6188179} = "Adelaide";
$areanames{en}->{6188180} = "Salisbury";
$areanames{en}->{6188181} = "Woodside";
$areanames{en}->{6188182} = "Salisbury";
$areanames{en}->{6188183} = "Mount\ Barker";
$areanames{en}->{6188184} = "Mclaren\ Vale";
$areanames{en}->{61881850} = "Mclaren\ Vale";
$areanames{en}->{61881851} = "Salisbury";
$areanames{en}->{61881852} = "Woodside";
$areanames{en}->{61881853} = "Mount\ Barker";
$areanames{en}->{61881854} = "Mount\ Barker";
$areanames{en}->{61881855} = "Salisbury";
$areanames{en}->{61881856} = "Woodside";
$areanames{en}->{61881857} = "Mclaren\ Vale";
$areanames{en}->{61881858} = "Mclaren\ Vale";
$areanames{en}->{61881859} = "Mclaren\ Vale";
$areanames{en}->{6188186} = "Mclaren\ Vale";
$areanames{en}->{6188187} = "Mclaren\ Vale";
$areanames{en}->{6188188} = "Mount\ Barker";
$areanames{en}->{6188189} = "Woodside";
$areanames{en}->{61881900} = "Adelaide";
$areanames{en}->{61881901} = "Adelaide";
$areanames{en}->{61881902} = "Adelaide";
$areanames{en}->{6188193} = "Adelaide";
$areanames{en}->{6188198} = "Adelaide";
$areanames{en}->{618820} = "Adelaide";
$areanames{en}->{61882073} = "Mclaren\ Vale";
$areanames{en}->{61882079} = "Salisbury";
$areanames{en}->{6188209} = "Salisbury";
$areanames{en}->{61882097} = "Woodside";
$areanames{en}->{61882098} = "Woodside";
$areanames{en}->{61882099} = "Woodside";
$areanames{en}->{618821} = "Adelaide";
$areanames{en}->{6188220} = "Adelaide";
$areanames{en}->{618823} = "Adelaide";
$areanames{en}->{6188240} = "Adelaide";
$areanames{en}->{6188241} = "Adelaide";
$areanames{en}->{6188242} = "Adelaide";
$areanames{en}->{6188243} = "Adelaide";
$areanames{en}->{6188244} = "Adelaide";
$areanames{en}->{6188245} = "Adelaide";
$areanames{en}->{6188246} = "Adelaide";
$areanames{en}->{6188248} = "Adelaide";
$areanames{en}->{6188249} = "Adelaide";
$areanames{en}->{618825} = "Salisbury";
$areanames{en}->{6188253} = "Adelaide";
$areanames{en}->{6188257} = "Adelaide";
$areanames{en}->{618826} = "Adelaide";
$areanames{en}->{61882790} = "Adelaide";
$areanames{en}->{61882791} = "Adelaide";
$areanames{en}->{61882799} = "Adelaide";
$areanames{en}->{6188286} = "Salisbury";
$areanames{en}->{618830} = "Adelaide";
$areanames{en}->{61883017} = "Mclaren\ Vale";
$areanames{en}->{61883070} = "Mclaren\ Vale";
$areanames{en}->{61883071} = "Mclaren\ Vale";
$areanames{en}->{61883072} = "Mclaren\ Vale";
$areanames{en}->{61883073} = "Mclaren\ Vale";
$areanames{en}->{61883074} = "Salisbury";
$areanames{en}->{61883075} = "Salisbury";
$areanames{en}->{61883076} = "Salisbury";
$areanames{en}->{61883077} = "Salisbury";
$areanames{en}->{61883079} = "Salisbury";
$areanames{en}->{6188310} = "Adelaide";
$areanames{en}->{6188311} = "Adelaide";
$areanames{en}->{6188312} = "Adelaide";
$areanames{en}->{6188313} = "Adelaide";
$areanames{en}->{6188314} = "Adelaide";
$areanames{en}->{6188315} = "Adelaide";
$areanames{en}->{6188316} = "Adelaide";
$areanames{en}->{6188317} = "Adelaide";
$areanames{en}->{61883182} = "Adelaide";
$areanames{en}->{61883188} = "Adelaide";
$areanames{en}->{6188321} = "Mclaren\ Vale";
$areanames{en}->{6188322} = "Mclaren\ Vale";
$areanames{en}->{6188323} = "Mclaren\ Vale";
$areanames{en}->{6188324} = "Mclaren\ Vale";
$areanames{en}->{6188325} = "Mclaren\ Vale";
$areanames{en}->{6188326} = "Mclaren\ Vale";
$areanames{en}->{6188327} = "Mclaren\ Vale";
$areanames{en}->{6188328} = "Mclaren\ Vale";
$areanames{en}->{6188329} = "Mclaren\ Vale";
$areanames{en}->{618833} = "Adelaide";
$areanames{en}->{6188335} = "Salisbury";
$areanames{en}->{618834} = "Adelaide";
$areanames{en}->{61883780} = "Adelaide";
$areanames{en}->{6188379} = "Adelaide";
$areanames{en}->{6188380} = "Salisbury";
$areanames{en}->{6188381} = "Mclaren\ Vale";
$areanames{en}->{6188382} = "Mclaren\ Vale";
$areanames{en}->{6188383} = "Mclaren\ Vale";
$areanames{en}->{6188384} = "Mclaren\ Vale";
$areanames{en}->{61883858} = "Adelaide";
$areanames{en}->{61883859} = "Woodside";
$areanames{en}->{6188386} = "Mclaren\ Vale";
$areanames{en}->{6188387} = "Mclaren\ Vale";
$areanames{en}->{6188388} = "Mount\ Barker";
$areanames{en}->{6188389} = "Woodside";
$areanames{en}->{6188390} = "Adelaide";
$areanames{en}->{6188391} = "Mount\ Barker";
$areanames{en}->{6188392} = "Mclaren\ Vale";
$areanames{en}->{6188393} = "Mount\ Barker";
$areanames{en}->{61883932} = "Salisbury";
$areanames{en}->{61883933} = "Salisbury";
$areanames{en}->{61883934} = "Salisbury";
$areanames{en}->{61883935} = "Salisbury";
$areanames{en}->{6188394} = "Adelaide";
$areanames{en}->{6188395} = "Adelaide";
$areanames{en}->{6188396} = "Adelaide";
$areanames{en}->{6188397} = "Adelaide";
$areanames{en}->{6188398} = "Mount\ Barker";
$areanames{en}->{6188399} = "Mount\ Barker";
$areanames{en}->{618840} = "Adelaide";
$areanames{en}->{61884066} = "Mclaren\ Vale";
$areanames{en}->{61884067} = "Mount\ Barker";
$areanames{en}->{61884068} = "Salisbury";
$areanames{en}->{618841} = "Adelaide";
$areanames{en}->{6188423} = "Adelaide";
$areanames{en}->{6188424} = "Adelaide";
$areanames{en}->{6188428} = "Adelaide";
$areanames{en}->{6188429} = "Adelaide";
$areanames{en}->{6188431} = "Adelaide";
$areanames{en}->{6188432} = "Adelaide";
$areanames{en}->{6188433} = "Adelaide";
$areanames{en}->{6188440} = "Adelaide";
$areanames{en}->{6188441} = "Mclaren\ Vale";
$areanames{en}->{6188442} = "Mclaren\ Vale";
$areanames{en}->{6188443} = "Adelaide";
$areanames{en}->{6188444} = "Adelaide";
$areanames{en}->{6188445} = "Adelaide";
$areanames{en}->{6188447} = "Adelaide";
$areanames{en}->{6188448} = "Adelaide";
$areanames{en}->{6188449} = "Adelaide";
$areanames{en}->{6188450} = "Adelaide";
$areanames{en}->{6188451} = "Adelaide";
$areanames{en}->{6188456} = "Adelaide";
$areanames{en}->{61884570} = "Adelaide";
$areanames{en}->{61884571} = "Adelaide";
$areanames{en}->{6188460} = "Adelaide";
$areanames{en}->{6188461} = "Adelaide";
$areanames{en}->{6188462} = "Adelaide";
$areanames{en}->{6188463} = "Adelaide";
$areanames{en}->{6188464} = "Adelaide";
$areanames{en}->{6188465} = "Adelaide";
$areanames{en}->{6188468} = "Adelaide";
$areanames{en}->{6188470} = "Adelaide";
$areanames{en}->{6188480} = "Salisbury";
$areanames{en}->{6188481} = "Mount\ Barker";
$areanames{en}->{6188482} = "Salisbury";
$areanames{en}->{6188483} = "Woodside";
$areanames{en}->{6188484} = "Woodside";
$areanames{en}->{6188485} = "Mount\ Barker";
$areanames{en}->{61884860} = "Salisbury";
$areanames{en}->{61884861} = "Salisbury";
$areanames{en}->{61884862} = "Salisbury";
$areanames{en}->{61884863} = "Woodside";
$areanames{en}->{61884864} = "Mount\ Barker";
$areanames{en}->{61884865} = "Mclaren\ Vale";
$areanames{en}->{61884866} = "Salisbury";
$areanames{en}->{61884867} = "Woodside";
$areanames{en}->{61884868} = "Mclaren\ Vale";
$areanames{en}->{61884869} = "Mount\ Barker";
$areanames{en}->{6188487} = "Salisbury";
$areanames{en}->{6188488} = "Mclaren\ Vale";
$areanames{en}->{6188489} = "Mclaren\ Vale";
$areanames{en}->{6188490} = "Adelaide";
$areanames{en}->{6188500} = "Murray\ Bridge";
$areanames{en}->{61885010} = "Barmera";
$areanames{en}->{61885011} = "Barmera";
$areanames{en}->{61885012} = "Barmera";
$areanames{en}->{61885013} = "Berri";
$areanames{en}->{61885014} = "Berri";
$areanames{en}->{61885015} = "Berri";
$areanames{en}->{61885016} = "Blanchetown";
$areanames{en}->{61885017} = "Blanchetown";
$areanames{en}->{61885018} = "Blanchetown";
$areanames{en}->{618850190} = "Yumali";
$areanames{en}->{618850191} = "Yumali";
$areanames{en}->{618850192} = "Yumali";
$areanames{en}->{618850193} = "Yumali";
$areanames{en}->{618850194} = "Yumali";
$areanames{en}->{618850195} = "Yumali";
$areanames{en}->{618850196} = "Yumali";
$areanames{en}->{618850197} = "Yumali";
$areanames{en}->{618850198} = "Yumali";
$areanames{en}->{61885020} = "Bow\ Hill";
$areanames{en}->{61885021} = "Bow\ Hill";
$areanames{en}->{61885022} = "Bow\ Hill";
$areanames{en}->{61885023} = "Bower";
$areanames{en}->{61885024} = "Bower";
$areanames{en}->{61885025} = "Bower";
$areanames{en}->{61885026} = "Callington";
$areanames{en}->{61885027} = "Callington";
$areanames{en}->{61885028} = "Callington";
$areanames{en}->{618850290} = "Berri";
$areanames{en}->{618850291} = "Berri";
$areanames{en}->{618850292} = "Berri";
$areanames{en}->{618850293} = "Berri";
$areanames{en}->{618850294} = "Berri";
$areanames{en}->{618850295} = "Berri";
$areanames{en}->{618850296} = "Berri";
$areanames{en}->{618850298} = "Berri";
$areanames{en}->{61885030} = "Coonalpyn";
$areanames{en}->{61885031} = "Coonalpyn";
$areanames{en}->{61885032} = "Coonalpyn";
$areanames{en}->{61885033} = "Copeville";
$areanames{en}->{61885034} = "Copeville";
$areanames{en}->{61885035} = "Copeville";
$areanames{en}->{61885036} = "Culburra";
$areanames{en}->{61885037} = "Culburra";
$areanames{en}->{61885038} = "Culburra";
$areanames{en}->{618850390} = "Loxton";
$areanames{en}->{618850391} = "Loxton";
$areanames{en}->{618850392} = "Loxton";
$areanames{en}->{618850393} = "Loxton";
$areanames{en}->{618850394} = "Loxton";
$areanames{en}->{618850395} = "Loxton";
$areanames{en}->{618850396} = "Loxton";
$areanames{en}->{618850398} = "Loxton";
$areanames{en}->{61885040} = "Eudunda";
$areanames{en}->{61885041} = "Eudunda";
$areanames{en}->{61885042} = "Eudunda";
$areanames{en}->{61885043} = "Freeling";
$areanames{en}->{61885044} = "Freeling";
$areanames{en}->{61885045} = "Freeling";
$areanames{en}->{61885046} = "Gawler";
$areanames{en}->{61885047} = "Gawler";
$areanames{en}->{61885048} = "Gawler";
$areanames{en}->{61885049} = "Gawler";
$areanames{en}->{61885050} = "Gawler";
$areanames{en}->{61885051} = "Gawler";
$areanames{en}->{61885052} = "Gawler";
$areanames{en}->{61885053} = "Geranium";
$areanames{en}->{61885054} = "Geranium";
$areanames{en}->{61885055} = "Geranium";
$areanames{en}->{61885056} = "Goolwa";
$areanames{en}->{61885057} = "Goolwa";
$areanames{en}->{61885058} = "Goolwa";
$areanames{en}->{61885059} = "Gawler";
$areanames{en}->{61885060} = "Gurrai";
$areanames{en}->{61885061} = "Gurrai";
$areanames{en}->{61885062} = "Gurrai";
$areanames{en}->{61885063} = "Halidon";
$areanames{en}->{61885064} = "Halidon";
$areanames{en}->{61885065} = "Halidon";
$areanames{en}->{61885066} = "Hamley\ Bridge";
$areanames{en}->{61885067} = "Hamley\ Bridge";
$areanames{en}->{61885068} = "Hamley\ Bridge";
$areanames{en}->{618850690} = "Paruna";
$areanames{en}->{618850691} = "Paruna";
$areanames{en}->{618850692} = "Paruna";
$areanames{en}->{618850693} = "Paruna";
$areanames{en}->{618850694} = "Paruna";
$areanames{en}->{618850695} = "Paruna";
$areanames{en}->{618850696} = "Paruna";
$areanames{en}->{618850698} = "Paruna";
$areanames{en}->{61885070} = "Hartley";
$areanames{en}->{61885071} = "Hartley";
$areanames{en}->{61885072} = "Hartley";
$areanames{en}->{61885073} = "Kapunda";
$areanames{en}->{61885074} = "Kapunda";
$areanames{en}->{61885075} = "Kapunda";
$areanames{en}->{61885076} = "Karatta";
$areanames{en}->{61885077} = "Karatta";
$areanames{en}->{61885078} = "Karatta";
$areanames{en}->{618850790} = "Renmark";
$areanames{en}->{618850791} = "Renmark";
$areanames{en}->{618850792} = "Renmark";
$areanames{en}->{618850793} = "Renmark";
$areanames{en}->{618850794} = "Renmark";
$areanames{en}->{618850795} = "Renmark";
$areanames{en}->{618850796} = "Renmark";
$areanames{en}->{618850798} = "Renmark";
$areanames{en}->{61885080} = "Karoonda";
$areanames{en}->{61885081} = "Karoonda";
$areanames{en}->{61885082} = "Karoonda";
$areanames{en}->{61885083} = "Kingscote";
$areanames{en}->{61885084} = "Kingscote";
$areanames{en}->{61885085} = "Kingscote";
$areanames{en}->{61885086} = "Lameroo";
$areanames{en}->{61885087} = "Lameroo";
$areanames{en}->{61885088} = "Lameroo";
$areanames{en}->{618850890} = "Taldra";
$areanames{en}->{618850891} = "Taldra";
$areanames{en}->{618850892} = "Taldra";
$areanames{en}->{618850893} = "Taldra";
$areanames{en}->{618850894} = "Taldra";
$areanames{en}->{618850895} = "Taldra";
$areanames{en}->{618850896} = "Taldra";
$areanames{en}->{618850898} = "Taldra";
$areanames{en}->{61885090} = "Langhorne\ Creek";
$areanames{en}->{61885091} = "Langhorne\ Creek";
$areanames{en}->{61885092} = "Langhorne\ Creek";
$areanames{en}->{61885093} = "Lowbank";
$areanames{en}->{61885094} = "Lowbank";
$areanames{en}->{61885095} = "Lowbank";
$areanames{en}->{61885096} = "Loxton";
$areanames{en}->{61885097} = "Loxton";
$areanames{en}->{61885098} = "Loxton";
$areanames{en}->{618850990} = "Taplan";
$areanames{en}->{618850991} = "Taplan";
$areanames{en}->{618850992} = "Taplan";
$areanames{en}->{618850993} = "Taplan";
$areanames{en}->{618850994} = "Taplan";
$areanames{en}->{618850995} = "Taplan";
$areanames{en}->{618850996} = "Taplan";
$areanames{en}->{618850998} = "Taplan";
$areanames{en}->{61885100} = "Malinong";
$areanames{en}->{61885101} = "Malinong";
$areanames{en}->{61885102} = "Malinong";
$areanames{en}->{61885103} = "Mallala";
$areanames{en}->{61885104} = "Mallala";
$areanames{en}->{61885105} = "Mallala";
$areanames{en}->{61885106} = "Mannum";
$areanames{en}->{61885107} = "Mannum";
$areanames{en}->{61885108} = "Mannum";
$areanames{en}->{618851090} = "Wanbi";
$areanames{en}->{618851091} = "Wanbi";
$areanames{en}->{618851092} = "Wanbi";
$areanames{en}->{618851093} = "Wanbi";
$areanames{en}->{618851094} = "Wanbi";
$areanames{en}->{618851095} = "Wanbi";
$areanames{en}->{618851096} = "Wanbi";
$areanames{en}->{618851098} = "Wanbi";
$areanames{en}->{61885110} = "Mantung";
$areanames{en}->{61885111} = "Mantung";
$areanames{en}->{61885112} = "Mantung";
$areanames{en}->{61885113} = "Marama";
$areanames{en}->{61885114} = "Marama";
$areanames{en}->{61885115} = "Marama";
$areanames{en}->{61885116} = "Meningie";
$areanames{en}->{61885117} = "Meningie";
$areanames{en}->{61885118} = "Meningie";
$areanames{en}->{618851190} = "Wunkar";
$areanames{en}->{618851191} = "Wunkar";
$areanames{en}->{618851192} = "Wunkar";
$areanames{en}->{618851193} = "Wunkar";
$areanames{en}->{618851194} = "Wunkar";
$areanames{en}->{618851195} = "Wunkar";
$areanames{en}->{618851196} = "Wunkar";
$areanames{en}->{618851198} = "Wunkar";
$areanames{en}->{61885120} = "Meningie\ East";
$areanames{en}->{61885121} = "Meningie\ East";
$areanames{en}->{61885122} = "Meningie\ East";
$areanames{en}->{61885123} = "Milang";
$areanames{en}->{61885124} = "Milang";
$areanames{en}->{61885125} = "Milang";
$areanames{en}->{61885126} = "Morgan";
$areanames{en}->{61885127} = "Morgan";
$areanames{en}->{61885128} = "Morgan";
$areanames{en}->{618851290} = "Karatta";
$areanames{en}->{618851291} = "Karatta";
$areanames{en}->{618851292} = "Karatta";
$areanames{en}->{618851293} = "Karatta";
$areanames{en}->{618851294} = "Karatta";
$areanames{en}->{618851295} = "Karatta";
$areanames{en}->{618851296} = "Karatta";
$areanames{en}->{618851298} = "Karatta";
$areanames{en}->{618851299} = "Karatta";
$areanames{en}->{61885130} = "Mount\ Pleasant";
$areanames{en}->{61885131} = "Mount\ Pleasant";
$areanames{en}->{61885132} = "Mount\ Pleasant";
$areanames{en}->{61885133} = "Murray\ Bridge";
$areanames{en}->{61885134} = "Murray\ Bridge";
$areanames{en}->{61885135} = "Murray\ Bridge";
$areanames{en}->{61885136} = "Mypolonga";
$areanames{en}->{61885137} = "Mypolonga";
$areanames{en}->{61885138} = "Mypolonga";
$areanames{en}->{61885139} = "Murray\ Bridge";
$areanames{en}->{61885140} = "Narrung";
$areanames{en}->{61885141} = "Narrung";
$areanames{en}->{61885142} = "Narrung";
$areanames{en}->{61885143} = "New\ Well";
$areanames{en}->{61885144} = "New\ Well";
$areanames{en}->{61885145} = "New\ Well";
$areanames{en}->{61885146} = "Parndana";
$areanames{en}->{61885147} = "Parndana";
$areanames{en}->{61885148} = "Parndana";
$areanames{en}->{618851490} = "Kingscote";
$areanames{en}->{618851491} = "Kingscote";
$areanames{en}->{618851492} = "Kingscote";
$areanames{en}->{618851493} = "Kingscote";
$areanames{en}->{618851494} = "Kingscote";
$areanames{en}->{618851495} = "Kingscote";
$areanames{en}->{618851496} = "Kingscote";
$areanames{en}->{618851498} = "Kingscote";
$areanames{en}->{618851499} = "Kingscote";
$areanames{en}->{61885150} = "Paruna";
$areanames{en}->{61885151} = "Paruna";
$areanames{en}->{61885152} = "Paruna";
$areanames{en}->{61885153} = "Peake";
$areanames{en}->{61885154} = "Peake";
$areanames{en}->{61885155} = "Peake";
$areanames{en}->{61885156} = "Peebinga";
$areanames{en}->{61885157} = "Peebinga";
$areanames{en}->{61885158} = "Peebinga";
$areanames{en}->{618851590} = "Parndana";
$areanames{en}->{618851591} = "Parndana";
$areanames{en}->{618851592} = "Parndana";
$areanames{en}->{618851593} = "Parndana";
$areanames{en}->{618851594} = "Parndana";
$areanames{en}->{618851595} = "Parndana";
$areanames{en}->{618851596} = "Parndana";
$areanames{en}->{618851598} = "Parndana";
$areanames{en}->{618851599} = "Parndana";
$areanames{en}->{61885160} = "Penneshaw";
$areanames{en}->{61885161} = "Penneshaw";
$areanames{en}->{61885162} = "Penneshaw";
$areanames{en}->{61885163} = "Perponda";
$areanames{en}->{61885164} = "Perponda";
$areanames{en}->{61885165} = "Perponda";
$areanames{en}->{61885166} = "Pinnaroo";
$areanames{en}->{61885167} = "Pinnaroo";
$areanames{en}->{61885168} = "Pinnaroo";
$areanames{en}->{618851690} = "Penneshaw";
$areanames{en}->{618851691} = "Penneshaw";
$areanames{en}->{618851692} = "Penneshaw";
$areanames{en}->{618851693} = "Penneshaw";
$areanames{en}->{618851694} = "Penneshaw";
$areanames{en}->{618851695} = "Penneshaw";
$areanames{en}->{618851696} = "Penneshaw";
$areanames{en}->{618851698} = "Penneshaw";
$areanames{en}->{618851699} = "Penneshaw";
$areanames{en}->{61885170} = "Policemans\ Point";
$areanames{en}->{61885171} = "Policemans\ Point";
$areanames{en}->{61885172} = "Policemans\ Point";
$areanames{en}->{61885173} = "Renmark";
$areanames{en}->{61885174} = "Renmark";
$areanames{en}->{61885175} = "Renmark";
$areanames{en}->{61885176} = "Robertstown";
$areanames{en}->{61885177} = "Robertstown";
$areanames{en}->{61885178} = "Robertstown";
$areanames{en}->{618851790} = "Mallala";
$areanames{en}->{618851791} = "Mallala";
$areanames{en}->{618851792} = "Mallala";
$areanames{en}->{618851793} = "Mallala";
$areanames{en}->{618851794} = "Mallala";
$areanames{en}->{618851795} = "Mallala";
$areanames{en}->{618851796} = "Mallala";
$areanames{en}->{618851797} = "Mallala";
$areanames{en}->{618851798} = "Mallala";
$areanames{en}->{61885180} = "Sanderston";
$areanames{en}->{61885181} = "Sanderston";
$areanames{en}->{61885182} = "Sanderston";
$areanames{en}->{61885183} = "Sandleton";
$areanames{en}->{61885184} = "Sandleton";
$areanames{en}->{61885185} = "Sandleton";
$areanames{en}->{61885186} = "Sedan";
$areanames{en}->{61885187} = "Sedan";
$areanames{en}->{61885188} = "Sedan";
$areanames{en}->{618851890} = "Two\ Wells";
$areanames{en}->{618851891} = "Two\ Wells";
$areanames{en}->{618851892} = "Two\ Wells";
$areanames{en}->{618851893} = "Two\ Wells";
$areanames{en}->{618851894} = "Two\ Wells";
$areanames{en}->{618851895} = "Two\ Wells";
$areanames{en}->{618851896} = "Two\ Wells";
$areanames{en}->{618851898} = "Two\ Wells";
$areanames{en}->{618851899} = "Two\ Wells";
$areanames{en}->{61885190} = "Strathalbyn";
$areanames{en}->{61885191} = "Strathalbyn";
$areanames{en}->{61885192} = "Strathalbyn";
$areanames{en}->{61885193} = "Swan\ Reach";
$areanames{en}->{61885194} = "Swan\ Reach";
$areanames{en}->{61885195} = "Swan\ Reach";
$areanames{en}->{61885196} = "Tailem\ Bend";
$areanames{en}->{61885197} = "Tailem\ Bend";
$areanames{en}->{61885198} = "Tailem\ Bend";
$areanames{en}->{618851990} = "Windsor";
$areanames{en}->{618851991} = "Windsor";
$areanames{en}->{618851992} = "Windsor";
$areanames{en}->{618851993} = "Windsor";
$areanames{en}->{618851994} = "Windsor";
$areanames{en}->{618851995} = "Windsor";
$areanames{en}->{618851996} = "Windsor";
$areanames{en}->{618851997} = "Windsor";
$areanames{en}->{618851998} = "Windsor";
$areanames{en}->{61885200} = "Two\ Wells";
$areanames{en}->{61885201} = "Two\ Wells";
$areanames{en}->{61885202} = "Two\ Wells";
$areanames{en}->{61885203} = "Two\ Wells";
$areanames{en}->{61885204} = "Two\ Wells";
$areanames{en}->{61885205} = "Two\ Wells";
$areanames{en}->{618852060} = "Gawler";
$areanames{en}->{618852061} = "Gawler";
$areanames{en}->{618852062} = "Gawler";
$areanames{en}->{618852063} = "Gawler";
$areanames{en}->{618852064} = "Gawler";
$areanames{en}->{618852065} = "Gawler";
$areanames{en}->{618852068} = "Gawler";
$areanames{en}->{618852069} = "Gawler";
$areanames{en}->{618852070} = "Hamley\ Bridge";
$areanames{en}->{618852071} = "Hamley\ Bridge";
$areanames{en}->{618852072} = "Hamley\ Bridge";
$areanames{en}->{618852073} = "Hamley\ Bridge";
$areanames{en}->{618852074} = "Hamley\ Bridge";
$areanames{en}->{618852075} = "Hamley\ Bridge";
$areanames{en}->{618852076} = "Hamley\ Bridge";
$areanames{en}->{618852077} = "Hamley\ Bridge";
$areanames{en}->{618852078} = "Hamley\ Bridge";
$areanames{en}->{618852080} = "Riverton";
$areanames{en}->{618852081} = "Riverton";
$areanames{en}->{618852082} = "Riverton";
$areanames{en}->{618852083} = "Riverton";
$areanames{en}->{618852084} = "Riverton";
$areanames{en}->{618852085} = "Riverton";
$areanames{en}->{618852086} = "Riverton";
$areanames{en}->{618852087} = "Riverton";
$areanames{en}->{618852088} = "Riverton";
$areanames{en}->{618852090} = "Barmera";
$areanames{en}->{618852091} = "Barmera";
$areanames{en}->{618852092} = "Barmera";
$areanames{en}->{618852093} = "Barmera";
$areanames{en}->{618852094} = "Barmera";
$areanames{en}->{618852095} = "Barmera";
$areanames{en}->{618852096} = "Barmera";
$areanames{en}->{618852098} = "Barmera";
$areanames{en}->{6188521} = "Gawler";
$areanames{en}->{61885216} = "Freeling";
$areanames{en}->{61885217} = "Freeling";
$areanames{en}->{61885218} = "Hamley\ Bridge";
$areanames{en}->{61885219} = "Hamley\ Bridge";
$areanames{en}->{6188522} = "Gawler";
$areanames{en}->{6188523} = "Gawler";
$areanames{en}->{6188524} = "Gawler";
$areanames{en}->{6188525} = "Freeling";
$areanames{en}->{61885256} = "Gawler";
$areanames{en}->{61885257} = "Gawler";
$areanames{en}->{61885258} = "Gawler";
$areanames{en}->{61885259} = "Gawler";
$areanames{en}->{6188526} = "Gawler";
$areanames{en}->{61885260} = "Mypolonga";
$areanames{en}->{61885261} = "Murray\ Bridge";
$areanames{en}->{61885262} = "Mannum";
$areanames{en}->{61885263} = "Karoonda";
$areanames{en}->{6188527} = "Mallala";
$areanames{en}->{61885280} = "Hamley\ Bridge";
$areanames{en}->{61885281} = "Hamley\ Bridge";
$areanames{en}->{61885282} = "Hamley\ Bridge";
$areanames{en}->{61885283} = "Hamley\ Bridge";
$areanames{en}->{61885284} = "Hamley\ Bridge";
$areanames{en}->{61885285} = "Hamley\ Bridge";
$areanames{en}->{61885286} = "Hamley\ Bridge";
$areanames{en}->{618852870} = "Goolwa";
$areanames{en}->{618852871} = "Goolwa";
$areanames{en}->{618852872} = "Goolwa";
$areanames{en}->{618852873} = "Goolwa";
$areanames{en}->{618852876} = "Goolwa";
$areanames{en}->{618852878} = "Goolwa";
$areanames{en}->{618852879} = "Goolwa";
$areanames{en}->{618852880} = "Victor\ Harbor";
$areanames{en}->{618852881} = "Victor\ Harbor";
$areanames{en}->{618852882} = "Victor\ Harbor";
$areanames{en}->{618852883} = "Victor\ Harbor";
$areanames{en}->{618852884} = "Victor\ Harbor";
$areanames{en}->{618852885} = "Victor\ Harbor";
$areanames{en}->{618852887} = "Victor\ Harbor";
$areanames{en}->{618852888} = "Victor\ Harbor";
$areanames{en}->{618852889} = "Victor\ Harbor";
$areanames{en}->{618852890} = "Willunga";
$areanames{en}->{618852891} = "Willunga";
$areanames{en}->{618852892} = "Willunga";
$areanames{en}->{618852893} = "Willunga";
$areanames{en}->{618852896} = "Willunga";
$areanames{en}->{618852898} = "Willunga";
$areanames{en}->{618852899} = "Willunga";
$areanames{en}->{61885290} = "Windsor";
$areanames{en}->{61885291} = "Windsor";
$areanames{en}->{61885292} = "Windsor";
$areanames{en}->{61885293} = "Windsor";
$areanames{en}->{61885294} = "Riverton";
$areanames{en}->{61885295} = "Riverton";
$areanames{en}->{61885296} = "Barmera";
$areanames{en}->{61885297} = "Berri";
$areanames{en}->{61885298} = "Loxton";
$areanames{en}->{61885299} = "Paruna";
$areanames{en}->{61885300} = "Taldra";
$areanames{en}->{61885301} = "Taldra";
$areanames{en}->{61885302} = "Taldra";
$areanames{en}->{61885303} = "Tanunda";
$areanames{en}->{61885304} = "Tanunda";
$areanames{en}->{61885305} = "Tanunda";
$areanames{en}->{61885306} = "Taplan";
$areanames{en}->{61885307} = "Taplan";
$areanames{en}->{61885308} = "Taplan";
$areanames{en}->{618853090} = "Callington";
$areanames{en}->{618853091} = "Callington";
$areanames{en}->{618853092} = "Callington";
$areanames{en}->{618853093} = "Callington";
$areanames{en}->{618853094} = "Callington";
$areanames{en}->{618853095} = "Callington";
$areanames{en}->{618853096} = "Callington";
$areanames{en}->{618853098} = "Callington";
$areanames{en}->{618853099} = "Callington";
$areanames{en}->{6188531} = "Murray\ Bridge";
$areanames{en}->{6188532} = "Murray\ Bridge";
$areanames{en}->{61885330} = "Taylorville";
$areanames{en}->{61885331} = "Taylorville";
$areanames{en}->{61885332} = "Taylorville";
$areanames{en}->{61885333} = "Truro";
$areanames{en}->{61885334} = "Truro";
$areanames{en}->{61885335} = "Truro";
$areanames{en}->{61885336} = "Two\ Wells";
$areanames{en}->{61885337} = "Two\ Wells";
$areanames{en}->{61885338} = "Two\ Wells";
$areanames{en}->{61885339} = "Murray\ Bridge";
$areanames{en}->{6188534} = "Murray\ Bridge";
$areanames{en}->{61885346} = "Tanunda";
$areanames{en}->{61885347} = "Mantung";
$areanames{en}->{61885348} = "Mantung";
$areanames{en}->{61885349} = "New\ Well";
$areanames{en}->{61885350} = "New\ Well";
$areanames{en}->{61885351} = "Windsor";
$areanames{en}->{61885352} = "Penneshaw";
$areanames{en}->{61885353} = "Mypolonga";
$areanames{en}->{61885354} = "Mypolonga";
$areanames{en}->{61885355} = "Murray\ Bridge";
$areanames{en}->{61885356} = "Murray\ Bridge";
$areanames{en}->{61885357} = "Murray\ Bridge";
$areanames{en}->{61885358} = "Murray\ Bridge";
$areanames{en}->{61885359} = "Murray\ Bridge";
$areanames{en}->{6188536} = "Strathalbyn";
$areanames{en}->{61885370} = "Milang";
$areanames{en}->{61885371} = "Milang";
$areanames{en}->{61885372} = "Milang";
$areanames{en}->{61885373} = "Langhorne\ Creek";
$areanames{en}->{61885374} = "Langhorne\ Creek";
$areanames{en}->{61885375} = "Hartley";
$areanames{en}->{61885376} = "Hartley";
$areanames{en}->{61885377} = "Eudunda";
$areanames{en}->{61885378} = "Eudunda";
$areanames{en}->{61885379} = "Loxton";
$areanames{en}->{61885380} = "Loxton";
$areanames{en}->{61885381} = "Mypolonga";
$areanames{en}->{61885382} = "Mypolonga";
$areanames{en}->{61885383} = "Callington";
$areanames{en}->{61885384} = "Callington";
$areanames{en}->{61885385} = "Callington";
$areanames{en}->{61885386} = "Callington";
$areanames{en}->{61885387} = "Callington";
$areanames{en}->{61885388} = "Berri";
$areanames{en}->{61885389} = "Berri";
$areanames{en}->{61885390} = "Mypolonga";
$areanames{en}->{61885391} = "Murray\ Bridge";
$areanames{en}->{61885392} = "Murray\ Bridge";
$areanames{en}->{61885393} = "Murray\ Bridge";
$areanames{en}->{61885394} = "Murray\ Bridge";
$areanames{en}->{61885395} = "Callington";
$areanames{en}->{61885396} = "Hartley";
$areanames{en}->{61885397} = "Langhorne\ Creek";
$areanames{en}->{61885398} = "Milang";
$areanames{en}->{61885399} = "Strathalbyn";
$areanames{en}->{6188540} = "Morgan";
$areanames{en}->{61885405} = "Blanchetown";
$areanames{en}->{61885406} = "Blanchetown";
$areanames{en}->{61885407} = "New\ Well";
$areanames{en}->{61885408} = "Blanchetown";
$areanames{en}->{6188541} = "Waikerie";
$areanames{en}->{61885420} = "Waikerie";
$areanames{en}->{61885421} = "Waikerie";
$areanames{en}->{61885422} = "Waikerie";
$areanames{en}->{61885423} = "Morgan";
$areanames{en}->{61885424} = "Morgan";
$areanames{en}->{61885425} = "Blanchetown";
$areanames{en}->{61885426} = "Taylorville";
$areanames{en}->{61885427} = "New\ Well";
$areanames{en}->{61885428} = "Murray\ Bridge";
$areanames{en}->{61885429} = "Two\ Wells";
$areanames{en}->{61885430} = "Taylorville";
$areanames{en}->{61885431} = "Taylorville";
$areanames{en}->{61885432} = "Taylorville";
$areanames{en}->{61885433} = "Milang";
$areanames{en}->{61885434} = "Strathalbyn";
$areanames{en}->{61885435} = "Murray\ Bridge";
$areanames{en}->{61885436} = "Murray\ Bridge";
$areanames{en}->{61885438} = "Berri";
$areanames{en}->{61885439} = "Waikerie";
$areanames{en}->{61885440} = "Victor\ Harbor";
$areanames{en}->{61885441} = "Victor\ Harbor";
$areanames{en}->{61885442} = "Victor\ Harbor";
$areanames{en}->{61885443} = "Waikerie";
$areanames{en}->{61885444} = "Waikerie";
$areanames{en}->{61885445} = "Waikerie";
$areanames{en}->{61885446} = "Walker\ Flat";
$areanames{en}->{61885447} = "Walker\ Flat";
$areanames{en}->{61885448} = "Walker\ Flat";
$areanames{en}->{618854490} = "Hartley";
$areanames{en}->{618854491} = "Hartley";
$areanames{en}->{618854492} = "Hartley";
$areanames{en}->{618854493} = "Hartley";
$areanames{en}->{618854496} = "Hartley";
$areanames{en}->{618854497} = "Hartley";
$areanames{en}->{618854498} = "Hartley";
$areanames{en}->{618854499} = "Hartley";
$areanames{en}->{618854500} = "Yankalilla";
$areanames{en}->{618854501} = "Yankalilla";
$areanames{en}->{618854502} = "Yankalilla";
$areanames{en}->{618854503} = "Yankalilla";
$areanames{en}->{618854504} = "Yankalilla";
$areanames{en}->{618854507} = "Yankalilla";
$areanames{en}->{618854508} = "Yankalilla";
$areanames{en}->{618854510} = "Blanchetown";
$areanames{en}->{618854511} = "Blanchetown";
$areanames{en}->{618854512} = "Blanchetown";
$areanames{en}->{618854513} = "Blanchetown";
$areanames{en}->{618854514} = "Blanchetown";
$areanames{en}->{618854515} = "Blanchetown";
$areanames{en}->{618854516} = "Blanchetown";
$areanames{en}->{618854517} = "Blanchetown";
$areanames{en}->{618854518} = "Blanchetown";
$areanames{en}->{618854520} = "Lowbank";
$areanames{en}->{618854521} = "Lowbank";
$areanames{en}->{618854522} = "Lowbank";
$areanames{en}->{618854523} = "Lowbank";
$areanames{en}->{618854524} = "Lowbank";
$areanames{en}->{618854525} = "Lowbank";
$areanames{en}->{618854526} = "Lowbank";
$areanames{en}->{618854527} = "Lowbank";
$areanames{en}->{618854528} = "Lowbank";
$areanames{en}->{618854530} = "Mantung";
$areanames{en}->{618854531} = "Mantung";
$areanames{en}->{618854532} = "Mantung";
$areanames{en}->{618854533} = "Mantung";
$areanames{en}->{618854534} = "Mantung";
$areanames{en}->{618854535} = "Mantung";
$areanames{en}->{618854536} = "Mantung";
$areanames{en}->{618854537} = "Mantung";
$areanames{en}->{618854538} = "Mantung";
$areanames{en}->{618854540} = "Morgan";
$areanames{en}->{618854541} = "Morgan";
$areanames{en}->{618854542} = "Morgan";
$areanames{en}->{618854543} = "Morgan";
$areanames{en}->{618854544} = "Morgan";
$areanames{en}->{618854545} = "Morgan";
$areanames{en}->{618854546} = "Morgan";
$areanames{en}->{618854547} = "Morgan";
$areanames{en}->{618854548} = "Morgan";
$areanames{en}->{618854550} = "New\ Well";
$areanames{en}->{618854551} = "New\ Well";
$areanames{en}->{618854552} = "New\ Well";
$areanames{en}->{618854553} = "New\ Well";
$areanames{en}->{618854554} = "New\ Well";
$areanames{en}->{618854555} = "New\ Well";
$areanames{en}->{618854556} = "New\ Well";
$areanames{en}->{618854557} = "New\ Well";
$areanames{en}->{618854558} = "New\ Well";
$areanames{en}->{618854560} = "Taylorville";
$areanames{en}->{618854561} = "Taylorville";
$areanames{en}->{618854562} = "Taylorville";
$areanames{en}->{618854563} = "Taylorville";
$areanames{en}->{618854564} = "Taylorville";
$areanames{en}->{618854565} = "Taylorville";
$areanames{en}->{618854566} = "Taylorville";
$areanames{en}->{618854567} = "Taylorville";
$areanames{en}->{618854568} = "Taylorville";
$areanames{en}->{618854570} = "Waikerie";
$areanames{en}->{618854571} = "Waikerie";
$areanames{en}->{618854572} = "Waikerie";
$areanames{en}->{618854573} = "Waikerie";
$areanames{en}->{618854574} = "Waikerie";
$areanames{en}->{618854575} = "Waikerie";
$areanames{en}->{618854576} = "Waikerie";
$areanames{en}->{618854577} = "Waikerie";
$areanames{en}->{618854578} = "Waikerie";
$areanames{en}->{618854580} = "Auburn";
$areanames{en}->{618854581} = "Auburn";
$areanames{en}->{618854582} = "Auburn";
$areanames{en}->{618854583} = "Auburn";
$areanames{en}->{618854584} = "Auburn";
$areanames{en}->{618854585} = "Auburn";
$areanames{en}->{618854586} = "Auburn";
$areanames{en}->{618854587} = "Auburn";
$areanames{en}->{618854588} = "Auburn";
$areanames{en}->{618854590} = "Freeling";
$areanames{en}->{618854591} = "Freeling";
$areanames{en}->{618854592} = "Freeling";
$areanames{en}->{618854593} = "Freeling";
$areanames{en}->{618854594} = "Freeling";
$areanames{en}->{618854595} = "Freeling";
$areanames{en}->{618854596} = "Freeling";
$areanames{en}->{618854598} = "Freeling";
$areanames{en}->{618854599} = "Freeling";
$areanames{en}->{61885460} = "Wanbi";
$areanames{en}->{61885461} = "Wanbi";
$areanames{en}->{61885462} = "Wanbi";
$areanames{en}->{61885463} = "Willunga";
$areanames{en}->{61885464} = "Willunga";
$areanames{en}->{61885465} = "Willunga";
$areanames{en}->{61885466} = "Windsor";
$areanames{en}->{61885467} = "Windsor";
$areanames{en}->{61885468} = "Windsor";
$areanames{en}->{618854690} = "Langhorne\ Creek";
$areanames{en}->{618854691} = "Langhorne\ Creek";
$areanames{en}->{618854692} = "Langhorne\ Creek";
$areanames{en}->{618854693} = "Langhorne\ Creek";
$areanames{en}->{618854694} = "Langhorne\ Creek";
$areanames{en}->{618854697} = "Langhorne\ Creek";
$areanames{en}->{618854698} = "Langhorne\ Creek";
$areanames{en}->{618854699} = "Langhorne\ Creek";
$areanames{en}->{61885470} = "Wunkar";
$areanames{en}->{61885471} = "Wunkar";
$areanames{en}->{61885472} = "Wunkar";
$areanames{en}->{61885473} = "Wynarka";
$areanames{en}->{61885474} = "Wynarka";
$areanames{en}->{61885475} = "Wynarka";
$areanames{en}->{61885476} = "Yankalilla";
$areanames{en}->{61885477} = "Yankalilla";
$areanames{en}->{61885478} = "Yankalilla";
$areanames{en}->{618854790} = "Milang";
$areanames{en}->{618854791} = "Milang";
$areanames{en}->{618854792} = "Milang";
$areanames{en}->{618854793} = "Milang";
$areanames{en}->{618854794} = "Milang";
$areanames{en}->{618854797} = "Milang";
$areanames{en}->{618854798} = "Milang";
$areanames{en}->{618854799} = "Milang";
$areanames{en}->{61885480} = "Yumali";
$areanames{en}->{61885481} = "Yumali";
$areanames{en}->{61885482} = "Yumali";
$areanames{en}->{61885483} = "Victor\ Harbor";
$areanames{en}->{61885484} = "Gawler";
$areanames{en}->{61885485} = "Murray\ Bridge";
$areanames{en}->{61885486} = "Tanunda";
$areanames{en}->{61885487} = "Strathalbyn";
$areanames{en}->{61885488} = "Victor\ Harbor";
$areanames{en}->{618854890} = "Murray\ Bridge";
$areanames{en}->{618854891} = "Murray\ Bridge";
$areanames{en}->{618854892} = "Murray\ Bridge";
$areanames{en}->{618854893} = "Murray\ Bridge";
$areanames{en}->{618854894} = "Murray\ Bridge";
$areanames{en}->{618854898} = "Murray\ Bridge";
$areanames{en}->{618854899} = "Murray\ Bridge";
$areanames{en}->{618854900} = "Mypolonga";
$areanames{en}->{618854901} = "Mypolonga";
$areanames{en}->{618854902} = "Mypolonga";
$areanames{en}->{618854903} = "Mypolonga";
$areanames{en}->{618854904} = "Mypolonga";
$areanames{en}->{618854905} = "Mypolonga";
$areanames{en}->{618854906} = "Mypolonga";
$areanames{en}->{618854907} = "Mypolonga";
$areanames{en}->{618854908} = "Mypolonga";
$areanames{en}->{618854910} = "Strathalbyn";
$areanames{en}->{618854911} = "Strathalbyn";
$areanames{en}->{618854912} = "Strathalbyn";
$areanames{en}->{618854913} = "Strathalbyn";
$areanames{en}->{618854916} = "Strathalbyn";
$areanames{en}->{618854917} = "Strathalbyn";
$areanames{en}->{618854918} = "Strathalbyn";
$areanames{en}->{618854919} = "Strathalbyn";
$areanames{en}->{618854920} = "Bow\ Hill";
$areanames{en}->{618854921} = "Bow\ Hill";
$areanames{en}->{618854922} = "Bow\ Hill";
$areanames{en}->{618854923} = "Bow\ Hill";
$areanames{en}->{618854924} = "Bow\ Hill";
$areanames{en}->{618854925} = "Bow\ Hill";
$areanames{en}->{618854926} = "Bow\ Hill";
$areanames{en}->{618854927} = "Bow\ Hill";
$areanames{en}->{618854928} = "Bow\ Hill";
$areanames{en}->{618854930} = "Bower";
$areanames{en}->{618854931} = "Bower";
$areanames{en}->{618854932} = "Bower";
$areanames{en}->{618854933} = "Bower";
$areanames{en}->{618854934} = "Bower";
$areanames{en}->{618854935} = "Bower";
$areanames{en}->{618854936} = "Bower";
$areanames{en}->{618854937} = "Bower";
$areanames{en}->{618854938} = "Bower";
$areanames{en}->{618854940} = "Eudunda";
$areanames{en}->{618854941} = "Eudunda";
$areanames{en}->{618854942} = "Eudunda";
$areanames{en}->{618854943} = "Eudunda";
$areanames{en}->{618854944} = "Eudunda";
$areanames{en}->{618854945} = "Eudunda";
$areanames{en}->{618854946} = "Eudunda";
$areanames{en}->{618854947} = "Eudunda";
$areanames{en}->{618854948} = "Eudunda";
$areanames{en}->{618854950} = "Kapunda";
$areanames{en}->{618854951} = "Kapunda";
$areanames{en}->{618854952} = "Kapunda";
$areanames{en}->{618854953} = "Kapunda";
$areanames{en}->{618854954} = "Kapunda";
$areanames{en}->{618854955} = "Kapunda";
$areanames{en}->{618854956} = "Kapunda";
$areanames{en}->{618854957} = "Kapunda";
$areanames{en}->{618854958} = "Kapunda";
$areanames{en}->{618854960} = "Mannum";
$areanames{en}->{618854961} = "Mannum";
$areanames{en}->{618854962} = "Mannum";
$areanames{en}->{618854963} = "Mannum";
$areanames{en}->{618854964} = "Mannum";
$areanames{en}->{618854965} = "Mannum";
$areanames{en}->{618854966} = "Mannum";
$areanames{en}->{618854967} = "Mannum";
$areanames{en}->{618854968} = "Mannum";
$areanames{en}->{618854970} = "Mount\ Pleasant";
$areanames{en}->{618854971} = "Mount\ Pleasant";
$areanames{en}->{618854972} = "Mount\ Pleasant";
$areanames{en}->{618854973} = "Mount\ Pleasant";
$areanames{en}->{618854974} = "Mount\ Pleasant";
$areanames{en}->{618854975} = "Mount\ Pleasant";
$areanames{en}->{618854976} = "Mount\ Pleasant";
$areanames{en}->{618854978} = "Mount\ Pleasant";
$areanames{en}->{618854979} = "Mount\ Pleasant";
$areanames{en}->{618854980} = "Robertstown";
$areanames{en}->{618854981} = "Robertstown";
$areanames{en}->{618854982} = "Robertstown";
$areanames{en}->{618854983} = "Robertstown";
$areanames{en}->{618854984} = "Robertstown";
$areanames{en}->{618854985} = "Robertstown";
$areanames{en}->{618854986} = "Robertstown";
$areanames{en}->{618854987} = "Robertstown";
$areanames{en}->{618854988} = "Robertstown";
$areanames{en}->{618854990} = "Sanderston";
$areanames{en}->{618854991} = "Sanderston";
$areanames{en}->{618854992} = "Sanderston";
$areanames{en}->{618854993} = "Sanderston";
$areanames{en}->{618854994} = "Sanderston";
$areanames{en}->{618854995} = "Sanderston";
$areanames{en}->{618854996} = "Sanderston";
$areanames{en}->{618854997} = "Sanderston";
$areanames{en}->{618854998} = "Sanderston";
$areanames{en}->{6188550} = "Willunga";
$areanames{en}->{61885505} = "Yankalilla";
$areanames{en}->{61885506} = "Strathalbyn";
$areanames{en}->{61885508} = "Goolwa";
$areanames{en}->{61885509} = "Goolwa";
$areanames{en}->{61885510} = "Victor\ Harbor";
$areanames{en}->{61885511} = "Victor\ Harbor";
$areanames{en}->{61885512} = "Victor\ Harbor";
$areanames{en}->{61885513} = "Victor\ Harbor";
$areanames{en}->{61885514} = "Kingscote";
$areanames{en}->{61885515} = "Victor\ Harbor";
$areanames{en}->{61885516} = "Kingscote";
$areanames{en}->{61885517} = "Penneshaw";
$areanames{en}->{61885518} = "Parndana";
$areanames{en}->{61885519} = "Karatta";
$areanames{en}->{6188552} = "Victor\ Harbor";
$areanames{en}->{6188553} = "Kingscote";
$areanames{en}->{61885531} = "Penneshaw";
$areanames{en}->{61885536} = "Penneshaw";
$areanames{en}->{61885537} = "Penneshaw";
$areanames{en}->{61885538} = "Penneshaw";
$areanames{en}->{6188554} = "Victor\ Harbor";
$areanames{en}->{6188555} = "Goolwa";
$areanames{en}->{61885558} = "Victor\ Harbor";
$areanames{en}->{61885559} = "Victor\ Harbor";
$areanames{en}->{6188556} = "Willunga";
$areanames{en}->{6188557} = "Willunga";
$areanames{en}->{6188558} = "Yankalilla";
$areanames{en}->{61885590} = "Kingscote";
$areanames{en}->{61885591} = "Penneshaw";
$areanames{en}->{61885592} = "Kingscote";
$areanames{en}->{61885593} = "Parndana";
$areanames{en}->{61885594} = "Karatta";
$areanames{en}->{61885595} = "Parndana";
$areanames{en}->{61885596} = "Parndana";
$areanames{en}->{61885597} = "Karatta";
$areanames{en}->{61885598} = "Karatta";
$areanames{en}->{61885599} = "Parndana";
$areanames{en}->{61885600} = "Bower";
$areanames{en}->{61885601} = "Sandleton";
$areanames{en}->{61885602} = "Bow\ Hill";
$areanames{en}->{61885603} = "Mount\ Pleasant";
$areanames{en}->{61885604} = "Kapunda";
$areanames{en}->{61885605} = "Kapunda";
$areanames{en}->{61885606} = "Truro";
$areanames{en}->{61885607} = "Eudunda";
$areanames{en}->{61885608} = "Robertstown";
$areanames{en}->{61885609} = "Tanunda";
$areanames{en}->{61885610} = "Tanunda";
$areanames{en}->{61885611} = "Tanunda";
$areanames{en}->{61885612} = "Tanunda";
$areanames{en}->{61885613} = "Tanunda";
$areanames{en}->{61885614} = "Tanunda";
$areanames{en}->{61885615} = "Sanderston";
$areanames{en}->{61885616} = "Mannum";
$areanames{en}->{61885617} = "Walker\ Flat";
$areanames{en}->{61885618} = "Sedan";
$areanames{en}->{61885619} = "Swan\ Reach";
$areanames{en}->{6188562} = "Tanunda";
$areanames{en}->{61885625} = "Sedan";
$areanames{en}->{61885626} = "Sandleton";
$areanames{en}->{61885627} = "Bower";
$areanames{en}->{6188563} = "Tanunda";
$areanames{en}->{6188564} = "Tanunda";
$areanames{en}->{61885640} = "Truro";
$areanames{en}->{61885645} = "Sedan";
$areanames{en}->{61885646} = "Sedan";
$areanames{en}->{61885649} = "Truro";
$areanames{en}->{61885650} = "Sedan";
$areanames{en}->{61885651} = "Sedan";
$areanames{en}->{61885652} = "Sedan";
$areanames{en}->{61885653} = "Tanunda";
$areanames{en}->{61885654} = "Tanunda";
$areanames{en}->{61885655} = "Truro";
$areanames{en}->{61885656} = "Truro";
$areanames{en}->{61885657} = "Tanunda";
$areanames{en}->{61885658} = "Tanunda";
$areanames{en}->{61885659} = "Tanunda";
$areanames{en}->{61885660} = "Kapunda";
$areanames{en}->{61885661} = "Kapunda";
$areanames{en}->{61885662} = "Kapunda";
$areanames{en}->{61885663} = "Kapunda";
$areanames{en}->{61885664} = "Kapunda";
$areanames{en}->{61885665} = "Coonalpyn";
$areanames{en}->{61885666} = "Kingscote";
$areanames{en}->{61885667} = "Kingscote";
$areanames{en}->{61885668} = "Kingscote";
$areanames{en}->{61885669} = "Mallala";
$areanames{en}->{618856700} = "Sandleton";
$areanames{en}->{618856701} = "Sandleton";
$areanames{en}->{618856702} = "Sandleton";
$areanames{en}->{618856703} = "Sandleton";
$areanames{en}->{618856704} = "Sandleton";
$areanames{en}->{618856705} = "Sandleton";
$areanames{en}->{618856706} = "Sandleton";
$areanames{en}->{618856707} = "Sandleton";
$areanames{en}->{618856708} = "Sandleton";
$areanames{en}->{618856710} = "Sedan";
$areanames{en}->{618856711} = "Sedan";
$areanames{en}->{618856712} = "Sedan";
$areanames{en}->{618856713} = "Sedan";
$areanames{en}->{618856714} = "Sedan";
$areanames{en}->{618856715} = "Sedan";
$areanames{en}->{618856716} = "Sedan";
$areanames{en}->{618856717} = "Sedan";
$areanames{en}->{618856718} = "Sedan";
$areanames{en}->{618856720} = "Swan\ Reach";
$areanames{en}->{618856721} = "Swan\ Reach";
$areanames{en}->{618856722} = "Swan\ Reach";
$areanames{en}->{618856723} = "Swan\ Reach";
$areanames{en}->{618856724} = "Swan\ Reach";
$areanames{en}->{618856725} = "Swan\ Reach";
$areanames{en}->{618856726} = "Swan\ Reach";
$areanames{en}->{618856727} = "Swan\ Reach";
$areanames{en}->{618856728} = "Swan\ Reach";
$areanames{en}->{61885673} = "Tanunda";
$areanames{en}->{618856740} = "Truro";
$areanames{en}->{618856741} = "Truro";
$areanames{en}->{618856742} = "Truro";
$areanames{en}->{618856743} = "Truro";
$areanames{en}->{618856744} = "Truro";
$areanames{en}->{618856745} = "Truro";
$areanames{en}->{618856746} = "Truro";
$areanames{en}->{618856747} = "Truro";
$areanames{en}->{618856748} = "Truro";
$areanames{en}->{618856750} = "Walker\ Flat";
$areanames{en}->{618856751} = "Walker\ Flat";
$areanames{en}->{618856752} = "Walker\ Flat";
$areanames{en}->{618856753} = "Walker\ Flat";
$areanames{en}->{618856754} = "Walker\ Flat";
$areanames{en}->{618856755} = "Walker\ Flat";
$areanames{en}->{618856756} = "Walker\ Flat";
$areanames{en}->{618856757} = "Walker\ Flat";
$areanames{en}->{618856758} = "Walker\ Flat";
$areanames{en}->{618856760} = "Coonalpyn";
$areanames{en}->{618856761} = "Coonalpyn";
$areanames{en}->{618856762} = "Coonalpyn";
$areanames{en}->{618856763} = "Coonalpyn";
$areanames{en}->{618856764} = "Coonalpyn";
$areanames{en}->{618856765} = "Coonalpyn";
$areanames{en}->{618856766} = "Coonalpyn";
$areanames{en}->{618856768} = "Coonalpyn";
$areanames{en}->{618856769} = "Coonalpyn";
$areanames{en}->{618856770} = "Copeville";
$areanames{en}->{618856771} = "Copeville";
$areanames{en}->{618856772} = "Copeville";
$areanames{en}->{618856773} = "Copeville";
$areanames{en}->{618856774} = "Copeville";
$areanames{en}->{618856775} = "Copeville";
$areanames{en}->{618856776} = "Copeville";
$areanames{en}->{618856777} = "Copeville";
$areanames{en}->{618856778} = "Copeville";
$areanames{en}->{618856780} = "Culburra";
$areanames{en}->{618856781} = "Culburra";
$areanames{en}->{618856782} = "Culburra";
$areanames{en}->{618856783} = "Culburra";
$areanames{en}->{618856784} = "Culburra";
$areanames{en}->{618856785} = "Culburra";
$areanames{en}->{618856786} = "Culburra";
$areanames{en}->{618856787} = "Culburra";
$areanames{en}->{618856788} = "Culburra";
$areanames{en}->{618856790} = "Geranium";
$areanames{en}->{618856791} = "Geranium";
$areanames{en}->{618856792} = "Geranium";
$areanames{en}->{618856793} = "Geranium";
$areanames{en}->{618856794} = "Geranium";
$areanames{en}->{618856795} = "Geranium";
$areanames{en}->{618856796} = "Geranium";
$areanames{en}->{618856797} = "Geranium";
$areanames{en}->{618856798} = "Geranium";
$areanames{en}->{6188568} = "Mount\ Pleasant";
$areanames{en}->{61885686} = "Tanunda";
$areanames{en}->{61885687} = "Tanunda";
$areanames{en}->{61885688} = "Tanunda";
$areanames{en}->{61885689} = "Tanunda";
$areanames{en}->{6188569} = "Mannum";
$areanames{en}->{61885693} = "Sanderston";
$areanames{en}->{61885700} = "Swan\ Reach";
$areanames{en}->{61885701} = "Swan\ Reach";
$areanames{en}->{61885702} = "Swan\ Reach";
$areanames{en}->{61885703} = "Swan\ Reach";
$areanames{en}->{61885704} = "Bow\ Hill";
$areanames{en}->{61885705} = "Bow\ Hill";
$areanames{en}->{61885706} = "Bow\ Hill";
$areanames{en}->{61885707} = "Walker\ Flat";
$areanames{en}->{61885708} = "Walker\ Flat";
$areanames{en}->{61885709} = "Walker\ Flat";
$areanames{en}->{61885710} = "Coonalpyn";
$areanames{en}->{61885711} = "Coonalpyn";
$areanames{en}->{61885712} = "Hartley";
$areanames{en}->{61885713} = "Hartley";
$areanames{en}->{61885714} = "Berri";
$areanames{en}->{61885715} = "Berri";
$areanames{en}->{61885716} = "Berri";
$areanames{en}->{61885717} = "Callington";
$areanames{en}->{61885718} = "Callington";
$areanames{en}->{61885719} = "Callington";
$areanames{en}->{6188572} = "Tailem\ Bend";
$areanames{en}->{61885730} = "Coonalpyn";
$areanames{en}->{61885731} = "Coonalpyn";
$areanames{en}->{61885732} = "Coonalpyn";
$areanames{en}->{61885733} = "Yumali";
$areanames{en}->{61885734} = "Yumali";
$areanames{en}->{61885735} = "Yumali";
$areanames{en}->{61885736} = "Yumali";
$areanames{en}->{61885737} = "Malinong";
$areanames{en}->{61885738} = "Malinong";
$areanames{en}->{61885739} = "Goolwa";
$areanames{en}->{61885740} = "Narrung";
$areanames{en}->{61885741} = "Narrung";
$areanames{en}->{61885742} = "Narrung";
$areanames{en}->{61885743} = "Peake";
$areanames{en}->{61885744} = "Peake";
$areanames{en}->{61885745} = "Victor\ Harbor";
$areanames{en}->{61885746} = "Victor\ Harbor";
$areanames{en}->{61885747} = "Victor\ Harbor";
$areanames{en}->{61885748} = "Victor\ Harbor";
$areanames{en}->{61885749} = "Victor\ Harbor";
$areanames{en}->{61885750} = "Meningie";
$areanames{en}->{61885751} = "Meningie";
$areanames{en}->{61885752} = "Meningie";
$areanames{en}->{61885753} = "Policemans\ Point";
$areanames{en}->{61885754} = "Meningie";
$areanames{en}->{61885755} = "Meningie\ East";
$areanames{en}->{61885756} = "Meningie\ East";
$areanames{en}->{61885757} = "Policemans\ Point";
$areanames{en}->{61885758} = "Culburra";
$areanames{en}->{61885759} = "Culburra";
$areanames{en}->{61885760} = "Geranium";
$areanames{en}->{61885761} = "Geranium";
$areanames{en}->{61885762} = "Geranium";
$areanames{en}->{61885763} = "Lameroo";
$areanames{en}->{61885764} = "Lameroo";
$areanames{en}->{61885765} = "Lameroo";
$areanames{en}->{61885766} = "Lameroo";
$areanames{en}->{61885767} = "Lameroo";
$areanames{en}->{61885768} = "Loxton";
$areanames{en}->{61885770} = "Peebinga";
$areanames{en}->{61885771} = "Geranium";
$areanames{en}->{61885772} = "Geranium";
$areanames{en}->{61885773} = "Geranium";
$areanames{en}->{61885774} = "Gurrai";
$areanames{en}->{61885775} = "Peebinga";
$areanames{en}->{61885776} = "Peebinga";
$areanames{en}->{61885777} = "Pinnaroo";
$areanames{en}->{61885778} = "Pinnaroo";
$areanames{en}->{61885779} = "Pinnaroo";
$areanames{en}->{61885780} = "Karoonda";
$areanames{en}->{61885781} = "Karoonda";
$areanames{en}->{61885782} = "Karoonda";
$areanames{en}->{61885783} = "Karoonda";
$areanames{en}->{61885784} = "Karoonda";
$areanames{en}->{61885785} = "Perponda";
$areanames{en}->{61885786} = "Copeville";
$areanames{en}->{61885787} = "Halidon";
$areanames{en}->{61885788} = "Marama";
$areanames{en}->{61885789} = "Wynarka";
$areanames{en}->{61885790} = "Meningie\ East";
$areanames{en}->{61885791} = "Karoonda";
$areanames{en}->{61885792} = "Lameroo";
$areanames{en}->{61885793} = "Pinnaroo";
$areanames{en}->{61885794} = "Coonalpyn";
$areanames{en}->{61885795} = "Meningie";
$areanames{en}->{61885796} = "Tailem\ Bend";
$areanames{en}->{61885797} = "Tanunda";
$areanames{en}->{61885798} = "Tanunda";
$areanames{en}->{61885799} = "Tanunda";
$areanames{en}->{61885800} = "Berri";
$areanames{en}->{61885801} = "Berri";
$areanames{en}->{61885802} = "Berri";
$areanames{en}->{61885803} = "Renmark";
$areanames{en}->{61885804} = "Renmark";
$areanames{en}->{61885805} = "Berri";
$areanames{en}->{61885806} = "Loxton";
$areanames{en}->{61885807} = "Barmera";
$areanames{en}->{61885808} = "Berri";
$areanames{en}->{61885809} = "Renmark";
$areanames{en}->{61885810} = "Bower";
$areanames{en}->{61885811} = "Eudunda";
$areanames{en}->{61885812} = "Eudunda";
$areanames{en}->{61885813} = "Eudunda";
$areanames{en}->{61885814} = "Meningie";
$areanames{en}->{61885815} = "Willunga";
$areanames{en}->{61885816} = "Barmera";
$areanames{en}->{61885817} = "Robertstown";
$areanames{en}->{61885818} = "Robertstown";
$areanames{en}->{61885819} = "Robertstown";
$areanames{en}->{6188582} = "Berri";
$areanames{en}->{6188583} = "Berri";
$areanames{en}->{61885830} = "Barmera";
$areanames{en}->{61885834} = "Barmera";
$areanames{en}->{61885839} = "Barmera";
$areanames{en}->{6188584} = "Loxton";
$areanames{en}->{618858500} = "Gurrai";
$areanames{en}->{618858501} = "Gurrai";
$areanames{en}->{618858502} = "Gurrai";
$areanames{en}->{618858503} = "Gurrai";
$areanames{en}->{618858504} = "Gurrai";
$areanames{en}->{618858505} = "Gurrai";
$areanames{en}->{618858506} = "Gurrai";
$areanames{en}->{618858507} = "Gurrai";
$areanames{en}->{618858508} = "Gurrai";
$areanames{en}->{618858510} = "Halidon";
$areanames{en}->{618858511} = "Halidon";
$areanames{en}->{618858512} = "Halidon";
$areanames{en}->{618858513} = "Halidon";
$areanames{en}->{618858514} = "Halidon";
$areanames{en}->{618858515} = "Halidon";
$areanames{en}->{618858516} = "Halidon";
$areanames{en}->{618858517} = "Halidon";
$areanames{en}->{618858518} = "Halidon";
$areanames{en}->{618858520} = "Karoonda";
$areanames{en}->{618858521} = "Karoonda";
$areanames{en}->{618858522} = "Karoonda";
$areanames{en}->{618858523} = "Karoonda";
$areanames{en}->{618858524} = "Karoonda";
$areanames{en}->{618858525} = "Karoonda";
$areanames{en}->{618858526} = "Karoonda";
$areanames{en}->{618858527} = "Karoonda";
$areanames{en}->{618858528} = "Karoonda";
$areanames{en}->{618858530} = "Lameroo";
$areanames{en}->{618858531} = "Lameroo";
$areanames{en}->{618858532} = "Lameroo";
$areanames{en}->{618858533} = "Lameroo";
$areanames{en}->{618858534} = "Lameroo";
$areanames{en}->{618858535} = "Lameroo";
$areanames{en}->{618858536} = "Lameroo";
$areanames{en}->{618858537} = "Lameroo";
$areanames{en}->{618858538} = "Lameroo";
$areanames{en}->{618858540} = "Malinong";
$areanames{en}->{618858541} = "Malinong";
$areanames{en}->{618858542} = "Malinong";
$areanames{en}->{618858543} = "Malinong";
$areanames{en}->{618858544} = "Malinong";
$areanames{en}->{618858545} = "Malinong";
$areanames{en}->{618858546} = "Malinong";
$areanames{en}->{618858547} = "Malinong";
$areanames{en}->{618858548} = "Malinong";
$areanames{en}->{618858550} = "Marama";
$areanames{en}->{618858551} = "Marama";
$areanames{en}->{618858552} = "Marama";
$areanames{en}->{618858553} = "Marama";
$areanames{en}->{618858554} = "Marama";
$areanames{en}->{618858555} = "Marama";
$areanames{en}->{618858556} = "Marama";
$areanames{en}->{618858557} = "Marama";
$areanames{en}->{618858558} = "Marama";
$areanames{en}->{618858560} = "Meningie";
$areanames{en}->{618858561} = "Meningie";
$areanames{en}->{618858562} = "Meningie";
$areanames{en}->{618858563} = "Meningie";
$areanames{en}->{618858564} = "Meningie";
$areanames{en}->{618858565} = "Meningie";
$areanames{en}->{618858566} = "Meningie";
$areanames{en}->{618858568} = "Meningie";
$areanames{en}->{618858569} = "Meningie";
$areanames{en}->{618858570} = "Meningie\ East";
$areanames{en}->{618858571} = "Meningie\ East";
$areanames{en}->{618858572} = "Meningie\ East";
$areanames{en}->{618858573} = "Meningie\ East";
$areanames{en}->{618858574} = "Meningie\ East";
$areanames{en}->{618858575} = "Meningie\ East";
$areanames{en}->{618858576} = "Meningie\ East";
$areanames{en}->{618858577} = "Meningie\ East";
$areanames{en}->{618858578} = "Meningie\ East";
$areanames{en}->{618858580} = "Narrung";
$areanames{en}->{618858581} = "Narrung";
$areanames{en}->{618858582} = "Narrung";
$areanames{en}->{618858583} = "Narrung";
$areanames{en}->{618858584} = "Narrung";
$areanames{en}->{618858585} = "Narrung";
$areanames{en}->{618858586} = "Narrung";
$areanames{en}->{618858587} = "Narrung";
$areanames{en}->{618858588} = "Narrung";
$areanames{en}->{618858590} = "Peake";
$areanames{en}->{618858591} = "Peake";
$areanames{en}->{618858592} = "Peake";
$areanames{en}->{618858593} = "Peake";
$areanames{en}->{618858594} = "Peake";
$areanames{en}->{618858595} = "Peake";
$areanames{en}->{618858596} = "Peake";
$areanames{en}->{618858597} = "Peake";
$areanames{en}->{618858598} = "Peake";
$areanames{en}->{6188586} = "Renmark";
$areanames{en}->{61885870} = "Taplan";
$areanames{en}->{61885871} = "Taplan";
$areanames{en}->{61885872} = "Taplan";
$areanames{en}->{61885873} = "Paruna";
$areanames{en}->{61885874} = "Wanbi";
$areanames{en}->{61885875} = "Wanbi";
$areanames{en}->{61885876} = "Wunkar";
$areanames{en}->{61885877} = "Wunkar";
$areanames{en}->{61885878} = "Paruna";
$areanames{en}->{61885879} = "Wanbi";
$areanames{en}->{6188588} = "Barmera";
$areanames{en}->{61885890} = "Mannum";
$areanames{en}->{61885891} = "Renmark";
$areanames{en}->{61885892} = "Kingscote";
$areanames{en}->{61885893} = "Lowbank";
$areanames{en}->{61885894} = "Lowbank";
$areanames{en}->{61885895} = "Yankalilla";
$areanames{en}->{61885897} = "Mantung";
$areanames{en}->{61885898} = "Mantung";
$areanames{en}->{61885899} = "Willunga";
$areanames{en}->{61885900} = "Freeling";
$areanames{en}->{61885901} = "Gawler";
$areanames{en}->{61885902} = "Auburn";
$areanames{en}->{61885903} = "Hamley\ Bridge";
$areanames{en}->{61885904} = "Riverton";
$areanames{en}->{61885905} = "Kingscote";
$areanames{en}->{61885906} = "Parndana";
$areanames{en}->{61885907} = "Penneshaw";
$areanames{en}->{61885908} = "Karatta";
$areanames{en}->{61885909} = "Mallala";
$areanames{en}->{61885910} = "Two\ Wells";
$areanames{en}->{61885911} = "Windsor";
$areanames{en}->{61885912} = "Callington";
$areanames{en}->{61885913} = "Hartley";
$areanames{en}->{61885914} = "Langhorne\ Creek";
$areanames{en}->{61885915} = "Milang";
$areanames{en}->{61885916} = "Murray\ Bridge";
$areanames{en}->{61885917} = "Mypolonga";
$areanames{en}->{61885918} = "Strathalbyn";
$areanames{en}->{61885919} = "Sanderston";
$areanames{en}->{61885920} = "Sandleton";
$areanames{en}->{61885921} = "Sedan";
$areanames{en}->{61885922} = "Swan\ Reach";
$areanames{en}->{61885923} = "Tanunda";
$areanames{en}->{61885924} = "Truro";
$areanames{en}->{61885925} = "Walker\ Flat";
$areanames{en}->{61885926} = "Bow\ Hill";
$areanames{en}->{61885927} = "Bower";
$areanames{en}->{61885928} = "Eudunda";
$areanames{en}->{61885929} = "Kapunda";
$areanames{en}->{61885930} = "Mannum";
$areanames{en}->{61885931} = "Mount\ Pleasant";
$areanames{en}->{61885932} = "Robertstown";
$areanames{en}->{61885933} = "Peake";
$areanames{en}->{61885934} = "Peebinga";
$areanames{en}->{61885935} = "Perponda";
$areanames{en}->{61885936} = "Pinnaroo";
$areanames{en}->{61885937} = "Policemans\ Point";
$areanames{en}->{61885938} = "Tailem\ Bend";
$areanames{en}->{61885939} = "Wynarka";
$areanames{en}->{61885940} = "Yumali";
$areanames{en}->{61885941} = "Geranium";
$areanames{en}->{61885942} = "Gurrai";
$areanames{en}->{61885943} = "Halidon";
$areanames{en}->{61885944} = "Karoonda";
$areanames{en}->{61885945} = "Lameroo";
$areanames{en}->{61885946} = "Malinong";
$areanames{en}->{61885947} = "Marama";
$areanames{en}->{61885948} = "Meningie";
$areanames{en}->{61885949} = "Meningie\ East";
$areanames{en}->{6188595} = "Renmark";
$areanames{en}->{61885952} = "Berri";
$areanames{en}->{61885956} = "Taldra";
$areanames{en}->{61885959} = "Loxton";
$areanames{en}->{61885960} = "Narrung";
$areanames{en}->{61885961} = "Coonalpyn";
$areanames{en}->{61885962} = "Copeville";
$areanames{en}->{61885963} = "Culburra";
$areanames{en}->{61885964} = "Willunga";
$areanames{en}->{61885965} = "Yankalilla";
$areanames{en}->{61885966} = "Goolwa";
$areanames{en}->{61885967} = "Victor\ Harbor";
$areanames{en}->{61885968} = "Blanchetown";
$areanames{en}->{61885969} = "Lowbank";
$areanames{en}->{61885970} = "Mantung";
$areanames{en}->{61885971} = "Morgan";
$areanames{en}->{61885972} = "New\ Well";
$areanames{en}->{61885973} = "Taylorville";
$areanames{en}->{61885974} = "Waikerie";
$areanames{en}->{61885975} = "Barmera";
$areanames{en}->{61885976} = "Berri";
$areanames{en}->{61885977} = "Loxton";
$areanames{en}->{61885978} = "Paruna";
$areanames{en}->{61885979} = "Renmark";
$areanames{en}->{6188598} = "Yankalilla";
$areanames{en}->{61885987} = "Tailem\ Bend";
$areanames{en}->{61885990} = "Taldra";
$areanames{en}->{61885991} = "Taplan";
$areanames{en}->{61885992} = "Wanbi";
$areanames{en}->{61885993} = "Wunkar";
$areanames{en}->{618859940} = "Peebinga";
$areanames{en}->{618859941} = "Peebinga";
$areanames{en}->{618859942} = "Peebinga";
$areanames{en}->{618859943} = "Peebinga";
$areanames{en}->{618859944} = "Peebinga";
$areanames{en}->{618859945} = "Peebinga";
$areanames{en}->{618859946} = "Peebinga";
$areanames{en}->{618859947} = "Peebinga";
$areanames{en}->{618859948} = "Peebinga";
$areanames{en}->{618859950} = "Perponda";
$areanames{en}->{618859953} = "Perponda";
$areanames{en}->{618859954} = "Perponda";
$areanames{en}->{618859955} = "Perponda";
$areanames{en}->{618859956} = "Perponda";
$areanames{en}->{618859958} = "Perponda";
$areanames{en}->{618859960} = "Pinnaroo";
$areanames{en}->{618859961} = "Pinnaroo";
$areanames{en}->{618859962} = "Pinnaroo";
$areanames{en}->{618859963} = "Pinnaroo";
$areanames{en}->{618859964} = "Pinnaroo";
$areanames{en}->{618859965} = "Pinnaroo";
$areanames{en}->{618859966} = "Pinnaroo";
$areanames{en}->{618859967} = "Pinnaroo";
$areanames{en}->{618859968} = "Pinnaroo";
$areanames{en}->{618859970} = "Policemans\ Point";
$areanames{en}->{618859971} = "Policemans\ Point";
$areanames{en}->{618859972} = "Policemans\ Point";
$areanames{en}->{618859973} = "Policemans\ Point";
$areanames{en}->{618859974} = "Policemans\ Point";
$areanames{en}->{618859975} = "Policemans\ Point";
$areanames{en}->{618859976} = "Policemans\ Point";
$areanames{en}->{618859977} = "Policemans\ Point";
$areanames{en}->{618859978} = "Policemans\ Point";
$areanames{en}->{618859980} = "Tailem\ Bend";
$areanames{en}->{618859981} = "Tailem\ Bend";
$areanames{en}->{618859982} = "Tailem\ Bend";
$areanames{en}->{618859983} = "Tailem\ Bend";
$areanames{en}->{618859984} = "Tailem\ Bend";
$areanames{en}->{618859985} = "Tailem\ Bend";
$areanames{en}->{618859986} = "Tailem\ Bend";
$areanames{en}->{618859988} = "Tailem\ Bend";
$areanames{en}->{618859989} = "Tailem\ Bend";
$areanames{en}->{618859990} = "Wynarka";
$areanames{en}->{618859991} = "Wynarka";
$areanames{en}->{618859992} = "Wynarka";
$areanames{en}->{618859993} = "Wynarka";
$areanames{en}->{618859994} = "Wynarka";
$areanames{en}->{618859995} = "Wynarka";
$areanames{en}->{618859996} = "Wynarka";
$areanames{en}->{618859997} = "Wynarka";
$areanames{en}->{618859998} = "Wynarka";
$areanames{en}->{61886000} = "Andamooka";
$areanames{en}->{61886001} = "Andamooka";
$areanames{en}->{61886002} = "Andamooka";
$areanames{en}->{61886003} = "Arno\ Bay";
$areanames{en}->{61886004} = "Arno\ Bay";
$areanames{en}->{61886005} = "Arno\ Bay";
$areanames{en}->{61886006} = "Bayley\ Plains";
$areanames{en}->{61886007} = "Bayley\ Plains";
$areanames{en}->{61886008} = "Bayley\ Plains";
$areanames{en}->{618860090} = "Ceduna";
$areanames{en}->{618860091} = "Ceduna";
$areanames{en}->{618860092} = "Ceduna";
$areanames{en}->{618860093} = "Ceduna";
$areanames{en}->{618860094} = "Ceduna";
$areanames{en}->{618860095} = "Ceduna";
$areanames{en}->{618860096} = "Ceduna";
$areanames{en}->{618860098} = "Ceduna";
$areanames{en}->{618860099} = "Ceduna";
$areanames{en}->{61886010} = "Booleroo\ Centre";
$areanames{en}->{61886011} = "Booleroo\ Centre";
$areanames{en}->{61886012} = "Booleroo\ Centre";
$areanames{en}->{61886013} = "Caltowie";
$areanames{en}->{61886014} = "Caltowie";
$areanames{en}->{61886015} = "Caltowie";
$areanames{en}->{61886016} = "Carrieton";
$areanames{en}->{61886017} = "Carrieton";
$areanames{en}->{61886018} = "Carrieton";
$areanames{en}->{61886019} = "Laura";
$areanames{en}->{61886020} = "Ceduna";
$areanames{en}->{61886021} = "Ceduna";
$areanames{en}->{61886022} = "Ceduna";
$areanames{en}->{61886023} = "Cleve";
$areanames{en}->{61886024} = "Cleve";
$areanames{en}->{61886025} = "Cleve";
$areanames{en}->{61886026} = "Coffin\ Bay";
$areanames{en}->{61886027} = "Coffin\ Bay";
$areanames{en}->{61886028} = "Coffin\ Bay";
$areanames{en}->{61886029} = "Coober\ Pedy";
$areanames{en}->{61886030} = "Coober\ Pedy";
$areanames{en}->{61886031} = "Coober\ Pedy";
$areanames{en}->{61886032} = "Coober\ Pedy";
$areanames{en}->{61886033} = "Coorabie";
$areanames{en}->{61886034} = "Coorabie";
$areanames{en}->{61886035} = "Coorabie";
$areanames{en}->{61886036} = "Coulta";
$areanames{en}->{61886037} = "Coulta";
$areanames{en}->{61886038} = "Coulta";
$areanames{en}->{61886039} = "Melrose";
$areanames{en}->{61886040} = "Courela";
$areanames{en}->{61886041} = "Courela";
$areanames{en}->{61886042} = "Courela";
$areanames{en}->{61886043} = "Cowell";
$areanames{en}->{61886044} = "Cowell";
$areanames{en}->{61886045} = "Cowell";
$areanames{en}->{61886046} = "Crystal\ Brook";
$areanames{en}->{61886047} = "Crystal\ Brook";
$areanames{en}->{61886048} = "Crystal\ Brook";
$areanames{en}->{61886049} = "Willowie";
$areanames{en}->{61886050} = "Cummins";
$areanames{en}->{61886051} = "Cummins";
$areanames{en}->{61886052} = "Cummins";
$areanames{en}->{61886053} = "Darke\ Peak";
$areanames{en}->{61886054} = "Darke\ Peak";
$areanames{en}->{61886055} = "Darke\ Peak";
$areanames{en}->{61886056} = "Elliston";
$areanames{en}->{61886057} = "Elliston";
$areanames{en}->{61886058} = "Elliston";
$areanames{en}->{61886059} = "Wilmington";
$areanames{en}->{61886060} = "Everard";
$areanames{en}->{61886061} = "Everard";
$areanames{en}->{61886062} = "Everard";
$areanames{en}->{61886063} = "Frome";
$areanames{en}->{61886064} = "Frome";
$areanames{en}->{61886065} = "Frome";
$areanames{en}->{61886066} = "Gairdner";
$areanames{en}->{61886067} = "Gairdner";
$areanames{en}->{61886068} = "Gairdner";
$areanames{en}->{61886069} = "Booleroo\ Centre";
$areanames{en}->{61886070} = "Georgetown";
$areanames{en}->{61886071} = "Georgetown";
$areanames{en}->{61886072} = "Georgetown";
$areanames{en}->{61886073} = "Gladstone";
$areanames{en}->{61886074} = "Gladstone";
$areanames{en}->{61886075} = "Gladstone";
$areanames{en}->{61886076} = "Glendambo";
$areanames{en}->{61886077} = "Glendambo";
$areanames{en}->{61886078} = "Glendambo";
$areanames{en}->{61886079} = "Caltowie";
$areanames{en}->{61886080} = "Great\ Bight";
$areanames{en}->{61886081} = "Great\ Bight";
$areanames{en}->{61886082} = "Great\ Bight";
$areanames{en}->{61886083} = "Hawker";
$areanames{en}->{61886084} = "Hawker";
$areanames{en}->{61886085} = "Hawker";
$areanames{en}->{61886086} = "Herbert";
$areanames{en}->{61886087} = "Herbert";
$areanames{en}->{61886088} = "Herbert";
$areanames{en}->{61886089} = "Georgetown";
$areanames{en}->{61886090} = "Indian\ Pacific";
$areanames{en}->{61886091} = "Indian\ Pacific";
$areanames{en}->{61886092} = "Indian\ Pacific";
$areanames{en}->{61886093} = "Iron\ Baron";
$areanames{en}->{61886094} = "Iron\ Baron";
$areanames{en}->{61886095} = "Iron\ Baron";
$areanames{en}->{61886096} = "Iron\ Knob";
$areanames{en}->{61886097} = "Iron\ Knob";
$areanames{en}->{61886098} = "Iron\ Knob";
$areanames{en}->{61886099} = "Gladstone";
$areanames{en}->{61886100} = "Jamestown";
$areanames{en}->{61886101} = "Jamestown";
$areanames{en}->{61886102} = "Jamestown";
$areanames{en}->{61886103} = "Kapinnie";
$areanames{en}->{61886104} = "Kapinnie";
$areanames{en}->{61886105} = "Kapinnie";
$areanames{en}->{61886106} = "Kelly";
$areanames{en}->{61886107} = "Kelly";
$areanames{en}->{61886108} = "Kelly";
$areanames{en}->{61886109} = "Jamestown";
$areanames{en}->{61886110} = "Kimba";
$areanames{en}->{61886111} = "Kimba";
$areanames{en}->{61886112} = "Kimba";
$areanames{en}->{61886113} = "Koongawa";
$areanames{en}->{61886114} = "Koongawa";
$areanames{en}->{61886115} = "Koongawa";
$areanames{en}->{61886116} = "Koppio";
$areanames{en}->{61886117} = "Koppio";
$areanames{en}->{61886118} = "Koppio";
$areanames{en}->{61886119} = "Wilpena";
$areanames{en}->{61886120} = "Kyancutta";
$areanames{en}->{61886121} = "Kyancutta";
$areanames{en}->{61886122} = "Kyancutta";
$areanames{en}->{61886123} = "Laura";
$areanames{en}->{61886124} = "Laura";
$areanames{en}->{61886125} = "Laura";
$areanames{en}->{61886126} = "Leigh\ Creek\ South";
$areanames{en}->{61886127} = "Leigh\ Creek\ South";
$areanames{en}->{61886128} = "Leigh\ Creek\ South";
$areanames{en}->{61886129} = "Hawker";
$areanames{en}->{61886130} = "Lock";
$areanames{en}->{61886131} = "Lock";
$areanames{en}->{61886132} = "Lock";
$areanames{en}->{61886133} = "Mambray\ Creek";
$areanames{en}->{61886134} = "Mambray\ Creek";
$areanames{en}->{61886135} = "Mambray\ Creek";
$areanames{en}->{61886136} = "Marla";
$areanames{en}->{61886137} = "Marla";
$areanames{en}->{61886138} = "Marla";
$areanames{en}->{61886139} = "Iron\ Baron";
$areanames{en}->{61886140} = "Melrose";
$areanames{en}->{61886141} = "Melrose";
$areanames{en}->{61886142} = "Melrose";
$areanames{en}->{61886143} = "Miltalie";
$areanames{en}->{61886144} = "Miltalie";
$areanames{en}->{61886145} = "Miltalie";
$areanames{en}->{61886146} = "Minnipa";
$areanames{en}->{61886147} = "Minnipa";
$areanames{en}->{61886148} = "Minnipa";
$areanames{en}->{61886149} = "Iron\ Knob";
$areanames{en}->{61886150} = "Mintabie";
$areanames{en}->{61886151} = "Mintabie";
$areanames{en}->{61886152} = "Mintabie";
$areanames{en}->{61886153} = "Morchard";
$areanames{en}->{61886154} = "Morchard";
$areanames{en}->{61886155} = "Morchard";
$areanames{en}->{61886156} = "Mount\ Hope";
$areanames{en}->{61886157} = "Mount\ Hope";
$areanames{en}->{61886158} = "Mount\ Hope";
$areanames{en}->{61886159} = "Kelly";
$areanames{en}->{61886160} = "Mudamuckla";
$areanames{en}->{61886161} = "Mudamuckla";
$areanames{en}->{61886162} = "Mudamuckla";
$areanames{en}->{61886163} = "Nelshaby";
$areanames{en}->{61886164} = "Nelshaby";
$areanames{en}->{61886165} = "Nelshaby";
$areanames{en}->{61886166} = "Nunjikompita";
$areanames{en}->{61886167} = "Nunjikompita";
$areanames{en}->{61886168} = "Nunjikompita";
$areanames{en}->{61886169} = "Kimba";
$areanames{en}->{61886170} = "Orroroo";
$areanames{en}->{61886171} = "Orroroo";
$areanames{en}->{61886172} = "Orroroo";
$areanames{en}->{61886173} = "Penong";
$areanames{en}->{61886174} = "Penong";
$areanames{en}->{61886175} = "Penong";
$areanames{en}->{61886176} = "Peterborough";
$areanames{en}->{61886177} = "Peterborough";
$areanames{en}->{61886178} = "Peterborough";
$areanames{en}->{61886179} = "Port\ Augusta";
$areanames{en}->{61886180} = "Poochera";
$areanames{en}->{61886181} = "Poochera";
$areanames{en}->{61886182} = "Poochera";
$areanames{en}->{61886183} = "Port\ Augusta";
$areanames{en}->{61886184} = "Port\ Augusta";
$areanames{en}->{61886185} = "Port\ Augusta";
$areanames{en}->{61886186} = "Port\ Broughton";
$areanames{en}->{61886187} = "Port\ Broughton";
$areanames{en}->{61886188} = "Port\ Broughton";
$areanames{en}->{61886189} = "Port\ Augusta";
$areanames{en}->{61886190} = "Port\ Kenny";
$areanames{en}->{61886191} = "Port\ Kenny";
$areanames{en}->{61886192} = "Port\ Kenny";
$areanames{en}->{61886193} = "Port\ Lincoln";
$areanames{en}->{61886194} = "Port\ Lincoln";
$areanames{en}->{61886195} = "Port\ Lincoln";
$areanames{en}->{61886196} = "Port\ Neill";
$areanames{en}->{61886197} = "Port\ Neill";
$areanames{en}->{61886198} = "Port\ Neill";
$areanames{en}->{61886199} = "Quorn";
$areanames{en}->{618862000} = "Quorn";
$areanames{en}->{618862001} = "Quorn";
$areanames{en}->{618862002} = "Quorn";
$areanames{en}->{618862003} = "Quorn";
$areanames{en}->{618862004} = "Quorn";
$areanames{en}->{618862005} = "Quorn";
$areanames{en}->{618862006} = "Quorn";
$areanames{en}->{618862007} = "Quorn";
$areanames{en}->{618862010} = "The\ Ranges";
$areanames{en}->{618862011} = "The\ Ranges";
$areanames{en}->{618862012} = "The\ Ranges";
$areanames{en}->{618862013} = "The\ Ranges";
$areanames{en}->{618862014} = "The\ Ranges";
$areanames{en}->{618862015} = "The\ Ranges";
$areanames{en}->{618862016} = "The\ Ranges";
$areanames{en}->{618862017} = "The\ Ranges";
$areanames{en}->{61886202} = "Rudall";
$areanames{en}->{61886203} = "Rudall";
$areanames{en}->{61886204} = "Rudall";
$areanames{en}->{61886205} = "Rudall";
$areanames{en}->{61886206} = "Rudall";
$areanames{en}->{61886207} = "Darke\ Peak";
$areanames{en}->{618862080} = "Whyalla";
$areanames{en}->{618862081} = "Whyalla";
$areanames{en}->{618862082} = "Whyalla";
$areanames{en}->{618862083} = "Whyalla";
$areanames{en}->{618862084} = "Whyalla";
$areanames{en}->{618862085} = "Whyalla";
$areanames{en}->{618862086} = "Whyalla";
$areanames{en}->{618862089} = "Whyalla";
$areanames{en}->{618862090} = "Wilpena";
$areanames{en}->{618862091} = "Wilpena";
$areanames{en}->{618862092} = "Wilpena";
$areanames{en}->{618862093} = "Wilpena";
$areanames{en}->{618862094} = "Wilpena";
$areanames{en}->{618862095} = "Wilpena";
$areanames{en}->{618862096} = "Wilpena";
$areanames{en}->{618862097} = "Wilpena";
$areanames{en}->{61886210} = "Wharminda";
$areanames{en}->{61886211} = "Port\ Lincoln";
$areanames{en}->{61886212} = "Port\ Lincoln";
$areanames{en}->{61886213} = "Port\ Lincoln";
$areanames{en}->{61886214} = "Port\ Lincoln";
$areanames{en}->{61886215} = "Arno\ Bay";
$areanames{en}->{618862160} = "Arno\ Bay";
$areanames{en}->{618862161} = "Arno\ Bay";
$areanames{en}->{618862162} = "Arno\ Bay";
$areanames{en}->{618862163} = "Arno\ Bay";
$areanames{en}->{618862164} = "Arno\ Bay";
$areanames{en}->{618862165} = "Arno\ Bay";
$areanames{en}->{618862166} = "Arno\ Bay";
$areanames{en}->{618862167} = "Arno\ Bay";
$areanames{en}->{618862168} = "Arno\ Bay";
$areanames{en}->{61886217} = "Cleve";
$areanames{en}->{61886218} = "Cummins";
$areanames{en}->{61886219} = "Coffin\ Bay";
$areanames{en}->{618862200} = "Bayley\ Plains";
$areanames{en}->{618862201} = "Bayley\ Plains";
$areanames{en}->{618862202} = "Bayley\ Plains";
$areanames{en}->{618862203} = "Bayley\ Plains";
$areanames{en}->{618862204} = "Bayley\ Plains";
$areanames{en}->{618862205} = "Bayley\ Plains";
$areanames{en}->{618862206} = "Bayley\ Plains";
$areanames{en}->{618862207} = "Bayley\ Plains";
$areanames{en}->{618862208} = "Bayley\ Plains";
$areanames{en}->{61886221} = "Darke\ Peak";
$areanames{en}->{61886222} = "Miltalie";
$areanames{en}->{61886223} = "Kyancutta";
$areanames{en}->{61886224} = "Minnipa";
$areanames{en}->{61886225} = "Wudinna";
$areanames{en}->{61886226} = "Tumby\ Bay";
$areanames{en}->{618862270} = "Cleve";
$areanames{en}->{618862271} = "Cleve";
$areanames{en}->{618862272} = "Cleve";
$areanames{en}->{618862273} = "Cleve";
$areanames{en}->{618862274} = "Cleve";
$areanames{en}->{618862275} = "Cleve";
$areanames{en}->{618862276} = "Cleve";
$areanames{en}->{618862277} = "Cleve";
$areanames{en}->{618862278} = "Cleve";
$areanames{en}->{61886228} = "Sheringa";
$areanames{en}->{61886229} = "Elliston";
$areanames{en}->{61886230} = "Port\ Lincoln";
$areanames{en}->{61886231} = "Tooligie\ Hill";
$areanames{en}->{61886232} = "Ungarra";
$areanames{en}->{61886233} = "Yeelanna";
$areanames{en}->{61886234} = "Kapinnie";
$areanames{en}->{61886235} = "Mount\ Hope";
$areanames{en}->{61886236} = "Coulta";
$areanames{en}->{61886237} = "Koppio";
$areanames{en}->{61886238} = "Wanilla";
$areanames{en}->{61886239} = "Sleaford\ Mere";
$areanames{en}->{61886240} = "Mudamuckla";
$areanames{en}->{61886241} = "Ceduna";
$areanames{en}->{61886242} = "Ceduna";
$areanames{en}->{61886243} = "Great\ Bight";
$areanames{en}->{61886244} = "Ceduna";
$areanames{en}->{61886245} = "Courela";
$areanames{en}->{61886246} = "Streaky\ Bay";
$areanames{en}->{61886247} = "Wirrulla";
$areanames{en}->{61886248} = "Poochera";
$areanames{en}->{61886249} = "Port\ Kenny";
$areanames{en}->{61886250} = "Ceduna";
$areanames{en}->{61886251} = "Penong\/Great\ Bight";
$areanames{en}->{618862519} = "Great\ Bight";
$areanames{en}->{61886252} = "Ceduna";
$areanames{en}->{61886253} = "Ceduna";
$areanames{en}->{61886254} = "Nunjikompita";
$areanames{en}->{61886255} = "Port\ Kenny";
$areanames{en}->{61886256} = "Coorabie\/Great\ Bight";
$areanames{en}->{61886257} = "Mudamuckla";
$areanames{en}->{61886258} = "Mudamuckla";
$areanames{en}->{61886259} = "Ceduna";
$areanames{en}->{61886260} = "Wirrulla";
$areanames{en}->{61886261} = "Streaky\ Bay";
$areanames{en}->{61886262} = "Ceduna";
$areanames{en}->{61886263} = "Poochera";
$areanames{en}->{61886264} = "Streaky\ Bay";
$areanames{en}->{61886265} = "Streaky\ Bay";
$areanames{en}->{61886266} = "Courela";
$areanames{en}->{61886267} = "Streaky\ Bay";
$areanames{en}->{61886268} = "Wirrulla";
$areanames{en}->{61886269} = "Ceduna";
$areanames{en}->{6188627} = "Kimba";
$areanames{en}->{61886275} = "Kelly";
$areanames{en}->{61886276} = "Kelly";
$areanames{en}->{61886277} = "Kelly";
$areanames{en}->{61886279} = "Kelly";
$areanames{en}->{61886280} = "Arno\ Bay";
$areanames{en}->{61886281} = "Arno\ Bay";
$areanames{en}->{61886282} = "Cleve";
$areanames{en}->{61886283} = "Cleve";
$areanames{en}->{61886284} = "Cleve";
$areanames{en}->{61886285} = "Yabmana";
$areanames{en}->{61886286} = "Cleve";
$areanames{en}->{61886287} = "Ceduna";
$areanames{en}->{61886288} = "Wharminda";
$areanames{en}->{61886289} = "Wharminda";
$areanames{en}->{618862900} = "Coffin\ Bay";
$areanames{en}->{618862901} = "Coffin\ Bay";
$areanames{en}->{618862902} = "Coffin\ Bay";
$areanames{en}->{618862903} = "Coffin\ Bay";
$areanames{en}->{618862904} = "Coffin\ Bay";
$areanames{en}->{618862905} = "Coffin\ Bay";
$areanames{en}->{618862906} = "Coffin\ Bay";
$areanames{en}->{618862907} = "Coffin\ Bay";
$areanames{en}->{618862908} = "Coffin\ Bay";
$areanames{en}->{618862910} = "Coulta";
$areanames{en}->{618862911} = "Coulta";
$areanames{en}->{618862912} = "Coulta";
$areanames{en}->{618862913} = "Coulta";
$areanames{en}->{618862914} = "Coulta";
$areanames{en}->{618862915} = "Coulta";
$areanames{en}->{618862916} = "Coulta";
$areanames{en}->{618862917} = "Coulta";
$areanames{en}->{618862918} = "Coulta";
$areanames{en}->{61886292} = "Cowell";
$areanames{en}->{61886293} = "Cowell";
$areanames{en}->{61886294} = "Cowell";
$areanames{en}->{61886295} = "Cowell";
$areanames{en}->{61886296} = "Cowell";
$areanames{en}->{61886297} = "Miltalie";
$areanames{en}->{618862980} = "Cowell";
$areanames{en}->{618862981} = "Cowell";
$areanames{en}->{618862982} = "Cowell";
$areanames{en}->{618862983} = "Cowell";
$areanames{en}->{618862984} = "Cowell";
$areanames{en}->{618862985} = "Cowell";
$areanames{en}->{618862986} = "Cowell";
$areanames{en}->{618862987} = "Cowell";
$areanames{en}->{618862988} = "Cowell";
$areanames{en}->{618862990} = "Cummins";
$areanames{en}->{618862991} = "Cummins";
$areanames{en}->{618862992} = "Cummins";
$areanames{en}->{618862993} = "Cummins";
$areanames{en}->{618862994} = "Cummins";
$areanames{en}->{618862995} = "Cummins";
$areanames{en}->{618862996} = "Cummins";
$areanames{en}->{618862998} = "Cummins";
$areanames{en}->{618862999} = "Cummins";
$areanames{en}->{61886300} = "Port\ Pirie";
$areanames{en}->{61886301} = "Port\ Pirie";
$areanames{en}->{61886302} = "Port\ Pirie";
$areanames{en}->{61886303} = "Quorn";
$areanames{en}->{61886304} = "Quorn";
$areanames{en}->{61886305} = "Quorn";
$areanames{en}->{61886306} = "Redhill";
$areanames{en}->{61886307} = "Redhill";
$areanames{en}->{61886308} = "Redhill";
$areanames{en}->{61886309} = "The\ Ranges";
$areanames{en}->{61886310} = "Roxby\ Downs";
$areanames{en}->{61886311} = "Roxby\ Downs";
$areanames{en}->{61886312} = "Roxby\ Downs";
$areanames{en}->{61886313} = "Rudall";
$areanames{en}->{61886314} = "Rudall";
$areanames{en}->{61886315} = "Rudall";
$areanames{en}->{61886316} = "Sheringa";
$areanames{en}->{61886317} = "Sheringa";
$areanames{en}->{61886318} = "Sheringa";
$areanames{en}->{61886319} = "Whyalla";
$areanames{en}->{6188632} = "Port\ Pirie";
$areanames{en}->{61886330} = "Port\ Pirie";
$areanames{en}->{61886331} = "Port\ Pirie";
$areanames{en}->{61886332} = "Port\ Pirie";
$areanames{en}->{61886333} = "Port\ Pirie";
$areanames{en}->{61886334} = "Port\ Pirie";
$areanames{en}->{61886335} = "Port\ Pirie";
$areanames{en}->{618863360} = "Darke\ Peak";
$areanames{en}->{618863361} = "Darke\ Peak";
$areanames{en}->{618863362} = "Darke\ Peak";
$areanames{en}->{618863363} = "Darke\ Peak";
$areanames{en}->{618863364} = "Darke\ Peak";
$areanames{en}->{618863365} = "Darke\ Peak";
$areanames{en}->{618863366} = "Darke\ Peak";
$areanames{en}->{618863367} = "Darke\ Peak";
$areanames{en}->{618863368} = "Darke\ Peak";
$areanames{en}->{618863370} = "Elliston";
$areanames{en}->{618863371} = "Elliston";
$areanames{en}->{618863372} = "Elliston";
$areanames{en}->{618863373} = "Elliston";
$areanames{en}->{618863374} = "Elliston";
$areanames{en}->{618863375} = "Elliston";
$areanames{en}->{618863376} = "Elliston";
$areanames{en}->{618863377} = "Elliston";
$areanames{en}->{618863378} = "Elliston";
$areanames{en}->{61886338} = "Port\ Pirie";
$areanames{en}->{61886339} = "Port\ Pirie";
$areanames{en}->{61886340} = "Nelshaby";
$areanames{en}->{61886341} = "Nelshaby";
$areanames{en}->{61886342} = "Port\ Pirie";
$areanames{en}->{61886343} = "Port\ Pirie";
$areanames{en}->{61886344} = "Nelshaby";
$areanames{en}->{61886345} = "Nelshaby";
$areanames{en}->{61886346} = "Nelshaby";
$areanames{en}->{61886347} = "Mambray\ Creek";
$areanames{en}->{61886348} = "Mambray\ Creek";
$areanames{en}->{61886349} = "Port\ Pirie";
$areanames{en}->{61886350} = "Port\ Broughton";
$areanames{en}->{61886351} = "Port\ Broughton";
$areanames{en}->{61886352} = "Port\ Broughton";
$areanames{en}->{61886353} = "Port\ Broughton";
$areanames{en}->{61886354} = "Port\ Broughton";
$areanames{en}->{61886355} = "Port\ Broughton";
$areanames{en}->{618863560} = "Minnipa";
$areanames{en}->{618863561} = "Minnipa";
$areanames{en}->{618863562} = "Minnipa";
$areanames{en}->{618863563} = "Minnipa";
$areanames{en}->{618863564} = "Minnipa";
$areanames{en}->{618863565} = "Minnipa";
$areanames{en}->{618863566} = "Minnipa";
$areanames{en}->{618863567} = "Minnipa";
$areanames{en}->{618863568} = "Minnipa";
$areanames{en}->{618863570} = "Mount\ Hope";
$areanames{en}->{618863571} = "Mount\ Hope";
$areanames{en}->{618863572} = "Mount\ Hope";
$areanames{en}->{618863573} = "Mount\ Hope";
$areanames{en}->{618863574} = "Mount\ Hope";
$areanames{en}->{618863575} = "Mount\ Hope";
$areanames{en}->{618863576} = "Mount\ Hope";
$areanames{en}->{618863577} = "Mount\ Hope";
$areanames{en}->{618863578} = "Mount\ Hope";
$areanames{en}->{61886358} = "Port\ Lincoln";
$areanames{en}->{618863590} = "Port\ Neill";
$areanames{en}->{618863591} = "Port\ Neill";
$areanames{en}->{618863592} = "Port\ Neill";
$areanames{en}->{618863593} = "Port\ Neill";
$areanames{en}->{618863594} = "Port\ Neill";
$areanames{en}->{618863595} = "Port\ Neill";
$areanames{en}->{618863596} = "Port\ Neill";
$areanames{en}->{618863597} = "Port\ Neill";
$areanames{en}->{618863598} = "Port\ Neill";
$areanames{en}->{6188636} = "Crystal\ Brook";
$areanames{en}->{61886365} = "Wandearah\ East";
$areanames{en}->{61886366} = "Wandearah\ East";
$areanames{en}->{61886367} = "Redhill";
$areanames{en}->{61886368} = "Redhill";
$areanames{en}->{618863700} = "Rudall";
$areanames{en}->{618863701} = "Rudall";
$areanames{en}->{618863702} = "Rudall";
$areanames{en}->{618863703} = "Rudall";
$areanames{en}->{618863704} = "Rudall";
$areanames{en}->{618863705} = "Rudall";
$areanames{en}->{618863706} = "Rudall";
$areanames{en}->{618863707} = "Rudall";
$areanames{en}->{618863708} = "Rudall";
$areanames{en}->{61886371} = "Gladstone";
$areanames{en}->{61886372} = "Georgetown";
$areanames{en}->{61886373} = "Laura";
$areanames{en}->{61886374} = "Melrose";
$areanames{en}->{618863750} = "Nelshaby";
$areanames{en}->{618863751} = "Nelshaby";
$areanames{en}->{618863752} = "Nelshaby";
$areanames{en}->{618863753} = "Nelshaby";
$areanames{en}->{618863754} = "Nelshaby";
$areanames{en}->{618863755} = "Nelshaby";
$areanames{en}->{618863756} = "Nelshaby";
$areanames{en}->{618863757} = "Nelshaby";
$areanames{en}->{61886376} = "Willowie";
$areanames{en}->{61886377} = "Wilmington";
$areanames{en}->{61886378} = "Caltowie";
$areanames{en}->{61886379} = "Jamestown";
$areanames{en}->{61886380} = "Redhill";
$areanames{en}->{61886381} = "Port\ Pirie";
$areanames{en}->{61886382} = "Port\ Pirie";
$areanames{en}->{61886383} = "Port\ Pirie";
$areanames{en}->{61886384} = "Port\ Pirie";
$areanames{en}->{61886385} = "Crystal\ Brook";
$areanames{en}->{61886386} = "Port\ Pirie";
$areanames{en}->{61886387} = "Nelshaby";
$areanames{en}->{61886388} = "Port\ Broughton";
$areanames{en}->{61886389} = "Mambray\ Creek";
$areanames{en}->{61886390} = "Orroroo";
$areanames{en}->{61886391} = "Terowie";
$areanames{en}->{61886392} = "Orroroo";
$areanames{en}->{61886393} = "Morchard";
$areanames{en}->{61886394} = "Carrieton";
$areanames{en}->{618863950} = "Sheringa";
$areanames{en}->{618863951} = "Sheringa";
$areanames{en}->{618863952} = "Sheringa";
$areanames{en}->{618863953} = "Sheringa";
$areanames{en}->{618863954} = "Sheringa";
$areanames{en}->{618863955} = "Sheringa";
$areanames{en}->{618863956} = "Sheringa";
$areanames{en}->{618863957} = "Sheringa";
$areanames{en}->{618863958} = "Sheringa";
$areanames{en}->{618863960} = "Sleaford\ Mere";
$areanames{en}->{618863961} = "Sleaford\ Mere";
$areanames{en}->{618863962} = "Sleaford\ Mere";
$areanames{en}->{618863963} = "Sleaford\ Mere";
$areanames{en}->{618863964} = "Sleaford\ Mere";
$areanames{en}->{618863965} = "Sleaford\ Mere";
$areanames{en}->{618863966} = "Sleaford\ Mere";
$areanames{en}->{618863967} = "Sleaford\ Mere";
$areanames{en}->{618863968} = "Sleaford\ Mere";
$areanames{en}->{61886397} = "Port\ Lincoln";
$areanames{en}->{618863980} = "Tooligie\ Hill";
$areanames{en}->{618863981} = "Tooligie\ Hill";
$areanames{en}->{618863982} = "Tooligie\ Hill";
$areanames{en}->{618863983} = "Tooligie\ Hill";
$areanames{en}->{618863984} = "Tooligie\ Hill";
$areanames{en}->{618863985} = "Tooligie\ Hill";
$areanames{en}->{618863986} = "Tooligie\ Hill";
$areanames{en}->{618863987} = "Tooligie\ Hill";
$areanames{en}->{618863988} = "Tooligie\ Hill";
$areanames{en}->{618863990} = "Tumby\ Bay";
$areanames{en}->{618863991} = "Tumby\ Bay";
$areanames{en}->{618863992} = "Tumby\ Bay";
$areanames{en}->{618863993} = "Tumby\ Bay";
$areanames{en}->{618863994} = "Tumby\ Bay";
$areanames{en}->{618863995} = "Tumby\ Bay";
$areanames{en}->{618863996} = "Tumby\ Bay";
$areanames{en}->{618863997} = "Tumby\ Bay";
$areanames{en}->{618863998} = "Tumby\ Bay";
$areanames{en}->{61886400} = "Whyalla";
$areanames{en}->{61886401} = "Whyalla";
$areanames{en}->{61886402} = "Whyalla";
$areanames{en}->{61886403} = "Whyalla";
$areanames{en}->{61886404} = "Whyalla";
$areanames{en}->{618864050} = "Kapinnie";
$areanames{en}->{618864051} = "Kapinnie";
$areanames{en}->{618864052} = "Kapinnie";
$areanames{en}->{618864053} = "Kapinnie";
$areanames{en}->{618864054} = "Kapinnie";
$areanames{en}->{618864055} = "Kapinnie";
$areanames{en}->{618864056} = "Kapinnie";
$areanames{en}->{618864057} = "Kapinnie";
$areanames{en}->{618864058} = "Kapinnie";
$areanames{en}->{618864060} = "Koongawa";
$areanames{en}->{618864061} = "Koongawa";
$areanames{en}->{618864062} = "Koongawa";
$areanames{en}->{618864063} = "Koongawa";
$areanames{en}->{618864064} = "Koongawa";
$areanames{en}->{618864065} = "Koongawa";
$areanames{en}->{618864066} = "Koongawa";
$areanames{en}->{618864067} = "Koongawa";
$areanames{en}->{618864068} = "Koongawa";
$areanames{en}->{618864070} = "Koppio";
$areanames{en}->{618864071} = "Koppio";
$areanames{en}->{618864072} = "Koppio";
$areanames{en}->{618864073} = "Koppio";
$areanames{en}->{618864074} = "Koppio";
$areanames{en}->{618864075} = "Koppio";
$areanames{en}->{618864076} = "Koppio";
$areanames{en}->{618864077} = "Koppio";
$areanames{en}->{618864078} = "Koppio";
$areanames{en}->{618864080} = "Kyancutta";
$areanames{en}->{618864081} = "Kyancutta";
$areanames{en}->{618864082} = "Kyancutta";
$areanames{en}->{618864083} = "Kyancutta";
$areanames{en}->{618864084} = "Kyancutta";
$areanames{en}->{618864085} = "Kyancutta";
$areanames{en}->{618864086} = "Kyancutta";
$areanames{en}->{618864087} = "Kyancutta";
$areanames{en}->{618864088} = "Kyancutta";
$areanames{en}->{618864090} = "Lock";
$areanames{en}->{618864091} = "Lock";
$areanames{en}->{618864092} = "Lock";
$areanames{en}->{618864093} = "Lock";
$areanames{en}->{618864094} = "Lock";
$areanames{en}->{618864095} = "Lock";
$areanames{en}->{618864096} = "Lock";
$areanames{en}->{618864097} = "Lock";
$areanames{en}->{618864098} = "Lock";
$areanames{en}->{6188641} = "Port\ Augusta";
$areanames{en}->{6188642} = "Port\ Augusta";
$areanames{en}->{61886430} = "Port\ Augusta";
$areanames{en}->{618864310} = "Yeelanna";
$areanames{en}->{618864311} = "Yeelanna";
$areanames{en}->{618864312} = "Yeelanna";
$areanames{en}->{618864313} = "Yeelanna";
$areanames{en}->{618864314} = "Yeelanna";
$areanames{en}->{618864315} = "Yeelanna";
$areanames{en}->{618864316} = "Yeelanna";
$areanames{en}->{618864317} = "Yeelanna";
$areanames{en}->{618864318} = "Yeelanna";
$areanames{en}->{618864320} = "Crystal\ Brook";
$areanames{en}->{618864321} = "Crystal\ Brook";
$areanames{en}->{618864322} = "Crystal\ Brook";
$areanames{en}->{618864323} = "Crystal\ Brook";
$areanames{en}->{618864324} = "Crystal\ Brook";
$areanames{en}->{618864325} = "Crystal\ Brook";
$areanames{en}->{618864326} = "Crystal\ Brook";
$areanames{en}->{618864327} = "Crystal\ Brook";
$areanames{en}->{618864330} = "Mambray\ Creek";
$areanames{en}->{618864331} = "Mambray\ Creek";
$areanames{en}->{618864332} = "Mambray\ Creek";
$areanames{en}->{618864333} = "Mambray\ Creek";
$areanames{en}->{618864334} = "Mambray\ Creek";
$areanames{en}->{618864335} = "Mambray\ Creek";
$areanames{en}->{618864336} = "Mambray\ Creek";
$areanames{en}->{618864337} = "Mambray\ Creek";
$areanames{en}->{618864340} = "Port\ Broughton";
$areanames{en}->{618864341} = "Port\ Broughton";
$areanames{en}->{618864342} = "Port\ Broughton";
$areanames{en}->{618864343} = "Port\ Broughton";
$areanames{en}->{618864344} = "Port\ Broughton";
$areanames{en}->{618864345} = "Port\ Broughton";
$areanames{en}->{618864346} = "Port\ Broughton";
$areanames{en}->{618864347} = "Port\ Broughton";
$areanames{en}->{61886435} = "Port\ Augusta";
$areanames{en}->{61886436} = "Port\ Augusta";
$areanames{en}->{61886437} = "Port\ Augusta";
$areanames{en}->{61886438} = "The\ Ranges";
$areanames{en}->{61886439} = "Port\ Augusta";
$areanames{en}->{6188644} = "Whyalla";
$areanames{en}->{6188645} = "Whyalla";
$areanames{en}->{618864600} = "Port\ Pirie";
$areanames{en}->{618864601} = "Port\ Pirie";
$areanames{en}->{618864602} = "Port\ Pirie";
$areanames{en}->{618864603} = "Port\ Pirie";
$areanames{en}->{618864604} = "Port\ Pirie";
$areanames{en}->{618864605} = "Port\ Pirie";
$areanames{en}->{618864606} = "Port\ Pirie";
$areanames{en}->{618864607} = "Port\ Pirie";
$areanames{en}->{618864608} = "Port\ Pirie";
$areanames{en}->{618864610} = "Redhill";
$areanames{en}->{618864611} = "Redhill";
$areanames{en}->{618864612} = "Redhill";
$areanames{en}->{618864613} = "Redhill";
$areanames{en}->{618864614} = "Redhill";
$areanames{en}->{61886462} = "Iron\ Knob";
$areanames{en}->{618864630} = "Wandearah\ East";
$areanames{en}->{618864631} = "Wandearah\ East";
$areanames{en}->{618864632} = "Wandearah\ East";
$areanames{en}->{618864633} = "Wandearah\ East";
$areanames{en}->{618864634} = "Wandearah\ East";
$areanames{en}->{618864635} = "Wandearah\ East";
$areanames{en}->{618864636} = "Wandearah\ East";
$areanames{en}->{618864637} = "Wandearah\ East";
$areanames{en}->{618864640} = "Andamooka";
$areanames{en}->{618864641} = "Andamooka";
$areanames{en}->{618864642} = "Andamooka";
$areanames{en}->{618864643} = "Andamooka";
$areanames{en}->{618864644} = "Andamooka";
$areanames{en}->{618864645} = "Andamooka";
$areanames{en}->{618864646} = "Andamooka";
$areanames{en}->{618864647} = "Andamooka";
$areanames{en}->{618864648} = "Andamooka";
$areanames{en}->{618864650} = "Coober\ Pedy";
$areanames{en}->{618864651} = "Coober\ Pedy";
$areanames{en}->{618864652} = "Coober\ Pedy";
$areanames{en}->{618864653} = "Coober\ Pedy";
$areanames{en}->{618864654} = "Coober\ Pedy";
$areanames{en}->{618864655} = "Coober\ Pedy";
$areanames{en}->{618864656} = "Coober\ Pedy";
$areanames{en}->{61886466} = "The\ Ranges";
$areanames{en}->{61886467} = "The\ Ranges";
$areanames{en}->{61886468} = "Iron\ Baron";
$areanames{en}->{61886469} = "The\ Ranges";
$areanames{en}->{61886470} = "The\ Ranges";
$areanames{en}->{61886471} = "Port\ Augusta";
$areanames{en}->{61886472} = "Port\ Augusta";
$areanames{en}->{61886473} = "Port\ Augusta";
$areanames{en}->{61886474} = "Iron\ Knob";
$areanames{en}->{61886475} = "Whyalla";
$areanames{en}->{61886476} = "Whyalla";
$areanames{en}->{61886477} = "Whyalla";
$areanames{en}->{61886478} = "Whyalla";
$areanames{en}->{61886479} = "Iron\ Baron";
$areanames{en}->{61886480} = "Wilpena";
$areanames{en}->{61886481} = "The\ Ranges";
$areanames{en}->{61886482} = "Hawker";
$areanames{en}->{61886483} = "The\ Ranges";
$areanames{en}->{61886484} = "Hawker\/The\ Ranges";
$areanames{en}->{61886485} = "Port\ Augusta";
$areanames{en}->{61886486} = "Quorn";
$areanames{en}->{61886487} = "Quorn";
$areanames{en}->{61886488} = "Whyalla";
$areanames{en}->{61886489} = "Port\ Augusta";
$areanames{en}->{6188649} = "Whyalla";
$areanames{en}->{618865000} = "Frome";
$areanames{en}->{618865001} = "Frome";
$areanames{en}->{618865002} = "Frome";
$areanames{en}->{618865003} = "Frome";
$areanames{en}->{618865004} = "Frome";
$areanames{en}->{618865005} = "Frome";
$areanames{en}->{618865006} = "Frome";
$areanames{en}->{618865007} = "Frome";
$areanames{en}->{618865008} = "Frome";
$areanames{en}->{618865010} = "Gairdner";
$areanames{en}->{618865011} = "Gairdner";
$areanames{en}->{618865012} = "Gairdner";
$areanames{en}->{618865013} = "Gairdner";
$areanames{en}->{618865014} = "Gairdner";
$areanames{en}->{618865015} = "Gairdner";
$areanames{en}->{618865016} = "Gairdner";
$areanames{en}->{618865017} = "Gairdner";
$areanames{en}->{618865018} = "Gairdner";
$areanames{en}->{618865020} = "Glendambo";
$areanames{en}->{618865021} = "Glendambo";
$areanames{en}->{618865022} = "Glendambo";
$areanames{en}->{618865023} = "Glendambo";
$areanames{en}->{618865024} = "Glendambo";
$areanames{en}->{618865025} = "Glendambo";
$areanames{en}->{618865026} = "Glendambo";
$areanames{en}->{618865027} = "Glendambo";
$areanames{en}->{618865028} = "Glendambo";
$areanames{en}->{61886503} = "Herbert";
$areanames{en}->{61886504} = "Yunta";
$areanames{en}->{61886505} = "Herbert";
$areanames{en}->{61886506} = "Herbert";
$areanames{en}->{618865070} = "Roxby\ Downs";
$areanames{en}->{618865071} = "Roxby\ Downs";
$areanames{en}->{618865072} = "Roxby\ Downs";
$areanames{en}->{618865073} = "Roxby\ Downs";
$areanames{en}->{618865074} = "Roxby\ Downs";
$areanames{en}->{618865075} = "Roxby\ Downs";
$areanames{en}->{618865076} = "Roxby\ Downs";
$areanames{en}->{618865077} = "Roxby\ Downs";
$areanames{en}->{618865078} = "Roxby\ Downs";
$areanames{en}->{618865080} = "Tarcoola";
$areanames{en}->{618865081} = "Tarcoola";
$areanames{en}->{618865082} = "Tarcoola";
$areanames{en}->{618865083} = "Tarcoola";
$areanames{en}->{618865084} = "Tarcoola";
$areanames{en}->{618865085} = "Tarcoola";
$areanames{en}->{618865086} = "Tarcoola";
$areanames{en}->{618865087} = "Tarcoola";
$areanames{en}->{618865088} = "Tarcoola";
$areanames{en}->{618865090} = "Woomera";
$areanames{en}->{618865091} = "Woomera";
$areanames{en}->{618865092} = "Woomera";
$areanames{en}->{618865093} = "Woomera";
$areanames{en}->{618865094} = "Woomera";
$areanames{en}->{618865095} = "Woomera";
$areanames{en}->{618865096} = "Woomera";
$areanames{en}->{618865097} = "Woomera";
$areanames{en}->{618865098} = "Woomera";
$areanames{en}->{6188651} = "Peterborough";
$areanames{en}->{61886520} = "Sleaford\ Mere";
$areanames{en}->{61886521} = "Sleaford\ Mere";
$areanames{en}->{61886522} = "Sleaford\ Mere";
$areanames{en}->{61886523} = "Spilsby";
$areanames{en}->{61886524} = "Spilsby";
$areanames{en}->{61886525} = "Spilsby";
$areanames{en}->{61886526} = "Streaky\ Bay";
$areanames{en}->{61886527} = "Streaky\ Bay";
$areanames{en}->{61886528} = "Streaky\ Bay";
$areanames{en}->{61886529} = "Crystal\ Brook";
$areanames{en}->{61886530} = "Tarcoola";
$areanames{en}->{61886531} = "Tarcoola";
$areanames{en}->{61886532} = "Tarcoola";
$areanames{en}->{61886533} = "Terowie";
$areanames{en}->{61886534} = "Terowie";
$areanames{en}->{61886535} = "Terowie";
$areanames{en}->{61886536} = "The\ Ranges";
$areanames{en}->{61886537} = "The\ Ranges";
$areanames{en}->{61886538} = "The\ Ranges";
$areanames{en}->{61886539} = "Mambray\ Creek";
$areanames{en}->{61886540} = "Tooligie\ Hill";
$areanames{en}->{61886541} = "Tooligie\ Hill";
$areanames{en}->{61886542} = "Tooligie\ Hill";
$areanames{en}->{61886543} = "Tumby\ Bay";
$areanames{en}->{61886544} = "Tumby\ Bay";
$areanames{en}->{61886545} = "Tumby\ Bay";
$areanames{en}->{61886546} = "Ungarra";
$areanames{en}->{61886547} = "Ungarra";
$areanames{en}->{61886548} = "Ungarra";
$areanames{en}->{61886549} = "Nelshaby";
$areanames{en}->{61886550} = "Wandearah\ East";
$areanames{en}->{61886551} = "Wandearah\ East";
$areanames{en}->{61886552} = "Wandearah\ East";
$areanames{en}->{61886553} = "Wanilla";
$areanames{en}->{61886554} = "Wanilla";
$areanames{en}->{61886555} = "Wanilla";
$areanames{en}->{61886556} = "Wharminda";
$areanames{en}->{61886557} = "Wharminda";
$areanames{en}->{61886558} = "Wharminda";
$areanames{en}->{61886559} = "Port\ Broughton";
$areanames{en}->{61886560} = "Whyalla";
$areanames{en}->{61886561} = "Whyalla";
$areanames{en}->{61886562} = "Whyalla";
$areanames{en}->{61886563} = "Willowie";
$areanames{en}->{61886564} = "Willowie";
$areanames{en}->{61886565} = "Willowie";
$areanames{en}->{61886566} = "Wilmington";
$areanames{en}->{61886567} = "Wilmington";
$areanames{en}->{61886568} = "Wilmington";
$areanames{en}->{61886569} = "Port\ Pirie";
$areanames{en}->{61886570} = "Wilpena";
$areanames{en}->{61886571} = "Wilpena";
$areanames{en}->{61886572} = "Wilpena";
$areanames{en}->{61886573} = "Wirrulla";
$areanames{en}->{61886574} = "Wirrulla";
$areanames{en}->{61886575} = "Wirrulla";
$areanames{en}->{61886576} = "Woomera";
$areanames{en}->{61886577} = "Woomera";
$areanames{en}->{61886578} = "Woomera";
$areanames{en}->{61886579} = "Redhill";
$areanames{en}->{61886580} = "Orroroo";
$areanames{en}->{61886581} = "Orroroo";
$areanames{en}->{618865820} = "Coorabie";
$areanames{en}->{618865821} = "Coorabie";
$areanames{en}->{618865822} = "Coorabie";
$areanames{en}->{618865823} = "Coorabie";
$areanames{en}->{618865824} = "Coorabie";
$areanames{en}->{618865825} = "Coorabie";
$areanames{en}->{618865826} = "Coorabie";
$areanames{en}->{618865827} = "Coorabie";
$areanames{en}->{618865828} = "Coorabie";
$areanames{en}->{618865830} = "Courela";
$areanames{en}->{618865831} = "Courela";
$areanames{en}->{618865832} = "Courela";
$areanames{en}->{618865833} = "Courela";
$areanames{en}->{618865834} = "Courela";
$areanames{en}->{618865835} = "Courela";
$areanames{en}->{618865836} = "Courela";
$areanames{en}->{618865837} = "Courela";
$areanames{en}->{618865838} = "Courela";
$areanames{en}->{618865840} = "Great\ Bight";
$areanames{en}->{618865841} = "Great\ Bight";
$areanames{en}->{618865842} = "Great\ Bight";
$areanames{en}->{618865843} = "Great\ Bight";
$areanames{en}->{618865844} = "Great\ Bight";
$areanames{en}->{618865845} = "Great\ Bight";
$areanames{en}->{618865846} = "Great\ Bight";
$areanames{en}->{618865847} = "Great\ Bight";
$areanames{en}->{618865848} = "Great\ Bight";
$areanames{en}->{61886585} = "Orroroo";
$areanames{en}->{61886586} = "Orroroo";
$areanames{en}->{61886587} = "Orroroo";
$areanames{en}->{61886588} = "Carrieton";
$areanames{en}->{61886589} = "Carrieton";
$areanames{en}->{61886590} = "Morchard";
$areanames{en}->{61886591} = "Terowie";
$areanames{en}->{618865920} = "Mudamuckla";
$areanames{en}->{618865921} = "Mudamuckla";
$areanames{en}->{618865922} = "Mudamuckla";
$areanames{en}->{618865923} = "Mudamuckla";
$areanames{en}->{618865924} = "Mudamuckla";
$areanames{en}->{618865925} = "Mudamuckla";
$areanames{en}->{618865926} = "Mudamuckla";
$areanames{en}->{618865927} = "Mudamuckla";
$areanames{en}->{618865928} = "Mudamuckla";
$areanames{en}->{618865930} = "Nunjikompita";
$areanames{en}->{618865931} = "Nunjikompita";
$areanames{en}->{618865932} = "Nunjikompita";
$areanames{en}->{618865933} = "Nunjikompita";
$areanames{en}->{618865934} = "Nunjikompita";
$areanames{en}->{618865935} = "Nunjikompita";
$areanames{en}->{618865936} = "Nunjikompita";
$areanames{en}->{618865937} = "Nunjikompita";
$areanames{en}->{618865938} = "Nunjikompita";
$areanames{en}->{618865940} = "Penong";
$areanames{en}->{618865941} = "Penong";
$areanames{en}->{618865942} = "Penong";
$areanames{en}->{618865943} = "Penong";
$areanames{en}->{618865944} = "Penong";
$areanames{en}->{618865945} = "Penong";
$areanames{en}->{618865946} = "Penong";
$areanames{en}->{618865947} = "Penong";
$areanames{en}->{618865948} = "Penong";
$areanames{en}->{61886595} = "Morchard";
$areanames{en}->{618865960} = "Poochera";
$areanames{en}->{618865961} = "Poochera";
$areanames{en}->{618865962} = "Poochera";
$areanames{en}->{618865963} = "Poochera";
$areanames{en}->{618865964} = "Poochera";
$areanames{en}->{618865965} = "Poochera";
$areanames{en}->{618865966} = "Poochera";
$areanames{en}->{618865967} = "Poochera";
$areanames{en}->{618865968} = "Poochera";
$areanames{en}->{618865970} = "Miltalie";
$areanames{en}->{618865971} = "Miltalie";
$areanames{en}->{618865972} = "Miltalie";
$areanames{en}->{618865973} = "Miltalie";
$areanames{en}->{618865974} = "Miltalie";
$areanames{en}->{618865975} = "Miltalie";
$areanames{en}->{618865976} = "Miltalie";
$areanames{en}->{618865977} = "Miltalie";
$areanames{en}->{618865978} = "Miltalie";
$areanames{en}->{618865980} = "Ungarra";
$areanames{en}->{618865981} = "Ungarra";
$areanames{en}->{618865982} = "Ungarra";
$areanames{en}->{618865983} = "Ungarra";
$areanames{en}->{618865984} = "Ungarra";
$areanames{en}->{618865985} = "Ungarra";
$areanames{en}->{618865986} = "Ungarra";
$areanames{en}->{618865987} = "Ungarra";
$areanames{en}->{618865988} = "Ungarra";
$areanames{en}->{61886599} = "Morchard";
$areanames{en}->{61886600} = "Wudinna";
$areanames{en}->{61886601} = "Wudinna";
$areanames{en}->{61886602} = "Wudinna";
$areanames{en}->{61886603} = "Yabmana";
$areanames{en}->{61886604} = "Yabmana";
$areanames{en}->{61886605} = "Yabmana";
$areanames{en}->{61886606} = "Yeelanna";
$areanames{en}->{61886607} = "Yeelanna";
$areanames{en}->{61886608} = "Yeelanna";
$areanames{en}->{61886609} = "Wandearah\ East";
$areanames{en}->{61886610} = "Yunta";
$areanames{en}->{61886611} = "Yunta";
$areanames{en}->{61886612} = "Yunta";
$areanames{en}->{61886613} = "Port\ Lincoln";
$areanames{en}->{61886614} = "Whyalla";
$areanames{en}->{61886615} = "Coober\ Pedy";
$areanames{en}->{618866160} = "Port\ Kenny";
$areanames{en}->{618866161} = "Port\ Kenny";
$areanames{en}->{618866162} = "Port\ Kenny";
$areanames{en}->{618866163} = "Port\ Kenny";
$areanames{en}->{618866164} = "Port\ Kenny";
$areanames{en}->{618866165} = "Port\ Kenny";
$areanames{en}->{618866166} = "Port\ Kenny";
$areanames{en}->{618866167} = "Port\ Kenny";
$areanames{en}->{618866168} = "Port\ Kenny";
$areanames{en}->{618866170} = "Streaky\ Bay";
$areanames{en}->{618866171} = "Streaky\ Bay";
$areanames{en}->{618866172} = "Streaky\ Bay";
$areanames{en}->{618866173} = "Streaky\ Bay";
$areanames{en}->{618866174} = "Streaky\ Bay";
$areanames{en}->{618866175} = "Streaky\ Bay";
$areanames{en}->{618866176} = "Streaky\ Bay";
$areanames{en}->{618866177} = "Streaky\ Bay";
$areanames{en}->{618866178} = "Streaky\ Bay";
$areanames{en}->{618866180} = "Wirrulla";
$areanames{en}->{618866181} = "Wirrulla";
$areanames{en}->{618866182} = "Wirrulla";
$areanames{en}->{618866183} = "Wirrulla";
$areanames{en}->{618866184} = "Wirrulla";
$areanames{en}->{618866185} = "Wirrulla";
$areanames{en}->{618866186} = "Wirrulla";
$areanames{en}->{618866187} = "Wirrulla";
$areanames{en}->{618866188} = "Wirrulla";
$areanames{en}->{618866190} = "Everard";
$areanames{en}->{618866191} = "Everard";
$areanames{en}->{618866192} = "Everard";
$areanames{en}->{618866193} = "Everard";
$areanames{en}->{618866194} = "Everard";
$areanames{en}->{618866195} = "Everard";
$areanames{en}->{618866196} = "Everard";
$areanames{en}->{618866197} = "Everard";
$areanames{en}->{618866198} = "Everard";
$areanames{en}->{61886621} = "Port\ Lincoln";
$areanames{en}->{61886622} = "Gladstone";
$areanames{en}->{61886623} = "Gladstone";
$areanames{en}->{61886624} = "Georgetown";
$areanames{en}->{61886625} = "Georgetown";
$areanames{en}->{61886626} = "Georgetown";
$areanames{en}->{61886627} = "Georgetown";
$areanames{en}->{61886628} = "Georgetown";
$areanames{en}->{61886629} = "Gladstone";
$areanames{en}->{61886630} = "Laura";
$areanames{en}->{61886631} = "Laura";
$areanames{en}->{61886632} = "Laura";
$areanames{en}->{61886633} = "Laura";
$areanames{en}->{61886634} = "Laura";
$areanames{en}->{61886635} = "Laura";
$areanames{en}->{618866360} = "Wanilla";
$areanames{en}->{618866361} = "Wanilla";
$areanames{en}->{618866362} = "Wanilla";
$areanames{en}->{618866363} = "Wanilla";
$areanames{en}->{618866364} = "Wanilla";
$areanames{en}->{618866365} = "Wanilla";
$areanames{en}->{618866366} = "Wanilla";
$areanames{en}->{618866367} = "Wanilla";
$areanames{en}->{618866368} = "Wanilla";
$areanames{en}->{618866370} = "Wharminda";
$areanames{en}->{618866371} = "Wharminda";
$areanames{en}->{618866372} = "Wharminda";
$areanames{en}->{618866373} = "Wharminda";
$areanames{en}->{618866374} = "Wharminda";
$areanames{en}->{618866375} = "Wharminda";
$areanames{en}->{618866376} = "Wharminda";
$areanames{en}->{618866377} = "Wharminda";
$areanames{en}->{618866378} = "Wharminda";
$areanames{en}->{618866380} = "Wudinna";
$areanames{en}->{618866381} = "Wudinna";
$areanames{en}->{618866382} = "Wudinna";
$areanames{en}->{618866383} = "Wudinna";
$areanames{en}->{618866384} = "Wudinna";
$areanames{en}->{618866385} = "Wudinna";
$areanames{en}->{618866386} = "Wudinna";
$areanames{en}->{618866387} = "Wudinna";
$areanames{en}->{618866388} = "Wudinna";
$areanames{en}->{618866390} = "Yabmana";
$areanames{en}->{618866391} = "Yabmana";
$areanames{en}->{618866392} = "Yabmana";
$areanames{en}->{618866393} = "Yabmana";
$areanames{en}->{618866394} = "Yabmana";
$areanames{en}->{618866395} = "Yabmana";
$areanames{en}->{618866396} = "Yabmana";
$areanames{en}->{618866397} = "Yabmana";
$areanames{en}->{618866398} = "Yabmana";
$areanames{en}->{6188664} = "Jamestown";
$areanames{en}->{61886646} = "Port\ Lincoln";
$areanames{en}->{61886647} = "Gladstone";
$areanames{en}->{61886648} = "Gladstone";
$areanames{en}->{61886649} = "Whyalla";
$areanames{en}->{61886650} = "Georgetown";
$areanames{en}->{61886651} = "Jamestown";
$areanames{en}->{61886652} = "Jamestown";
$areanames{en}->{61886653} = "Jamestown";
$areanames{en}->{61886654} = "Georgetown";
$areanames{en}->{61886655} = "Caltowie";
$areanames{en}->{61886656} = "Caltowie";
$areanames{en}->{61886657} = "Caltowie";
$areanames{en}->{61886658} = "Caltowie";
$areanames{en}->{61886659} = "Caltowie";
$areanames{en}->{6188666} = "Melrose";
$areanames{en}->{61886666} = "Willowie";
$areanames{en}->{61886667} = "Willowie";
$areanames{en}->{61886670} = "Gairdner";
$areanames{en}->{61886671} = "Gairdner";
$areanames{en}->{61886672} = "Booleroo\ Centre";
$areanames{en}->{61886673} = "Booleroo\ Centre";
$areanames{en}->{61886674} = "Booleroo\ Centre";
$areanames{en}->{61886675} = "Wilmington";
$areanames{en}->{61886676} = "Wilmington";
$areanames{en}->{61886677} = "Jamestown";
$areanames{en}->{61886678} = "Jamestown";
$areanames{en}->{61886679} = "Andamooka";
$areanames{en}->{61886680} = "Andamooka";
$areanames{en}->{61886681} = "Gladstone";
$areanames{en}->{61886682} = "Ceduna";
$areanames{en}->{61886683} = "Laura";
$areanames{en}->{61886684} = "Laura";
$areanames{en}->{61886685} = "Laura";
$areanames{en}->{61886686} = "Port\ Augusta";
$areanames{en}->{61886687} = "Port\ Augusta";
$areanames{en}->{61886688} = "Port\ Augusta";
$areanames{en}->{61886689} = "Whyalla";
$areanames{en}->{618866900} = "Indian\ Pacific";
$areanames{en}->{618866901} = "Indian\ Pacific";
$areanames{en}->{618866902} = "Indian\ Pacific";
$areanames{en}->{618866903} = "Indian\ Pacific";
$areanames{en}->{618866904} = "Indian\ Pacific";
$areanames{en}->{618866905} = "Indian\ Pacific";
$areanames{en}->{618866906} = "Indian\ Pacific";
$areanames{en}->{618866907} = "Indian\ Pacific";
$areanames{en}->{618866908} = "Indian\ Pacific";
$areanames{en}->{618866910} = "Marla";
$areanames{en}->{618866911} = "Marla";
$areanames{en}->{618866912} = "Marla";
$areanames{en}->{618866913} = "Marla";
$areanames{en}->{618866914} = "Marla";
$areanames{en}->{618866915} = "Marla";
$areanames{en}->{618866916} = "Marla";
$areanames{en}->{618866917} = "Marla";
$areanames{en}->{618866918} = "Marla";
$areanames{en}->{618866920} = "Mintabie";
$areanames{en}->{618866921} = "Mintabie";
$areanames{en}->{618866922} = "Mintabie";
$areanames{en}->{618866923} = "Mintabie";
$areanames{en}->{618866924} = "Mintabie";
$areanames{en}->{618866925} = "Mintabie";
$areanames{en}->{618866926} = "Mintabie";
$areanames{en}->{618866927} = "Mintabie";
$areanames{en}->{618866928} = "Mintabie";
$areanames{en}->{618866930} = "Booleroo\ Centre";
$areanames{en}->{618866931} = "Booleroo\ Centre";
$areanames{en}->{618866932} = "Booleroo\ Centre";
$areanames{en}->{618866933} = "Booleroo\ Centre";
$areanames{en}->{618866934} = "Booleroo\ Centre";
$areanames{en}->{618866935} = "Booleroo\ Centre";
$areanames{en}->{618866936} = "Booleroo\ Centre";
$areanames{en}->{618866937} = "Booleroo\ Centre";
$areanames{en}->{618866940} = "Caltowie";
$areanames{en}->{618866941} = "Caltowie";
$areanames{en}->{618866942} = "Caltowie";
$areanames{en}->{618866943} = "Caltowie";
$areanames{en}->{618866944} = "Caltowie";
$areanames{en}->{618866945} = "Caltowie";
$areanames{en}->{618866946} = "Caltowie";
$areanames{en}->{618866947} = "Caltowie";
$areanames{en}->{618866950} = "Georgetown";
$areanames{en}->{618866951} = "Georgetown";
$areanames{en}->{618866952} = "Georgetown";
$areanames{en}->{618866953} = "Georgetown";
$areanames{en}->{618866954} = "Georgetown";
$areanames{en}->{618866955} = "Georgetown";
$areanames{en}->{618866956} = "Georgetown";
$areanames{en}->{618866957} = "Georgetown";
$areanames{en}->{618866960} = "Gladstone";
$areanames{en}->{618866961} = "Gladstone";
$areanames{en}->{618866962} = "Gladstone";
$areanames{en}->{618866963} = "Gladstone";
$areanames{en}->{618866964} = "Gladstone";
$areanames{en}->{618866965} = "Gladstone";
$areanames{en}->{618866966} = "Gladstone";
$areanames{en}->{618866967} = "Gladstone";
$areanames{en}->{618866968} = "Gladstone";
$areanames{en}->{618866970} = "Jamestown";
$areanames{en}->{618866971} = "Jamestown";
$areanames{en}->{618866972} = "Jamestown";
$areanames{en}->{618866973} = "Jamestown";
$areanames{en}->{618866974} = "Jamestown";
$areanames{en}->{618866975} = "Jamestown";
$areanames{en}->{618866976} = "Jamestown";
$areanames{en}->{618866977} = "Jamestown";
$areanames{en}->{618866980} = "Laura";
$areanames{en}->{618866981} = "Laura";
$areanames{en}->{618866982} = "Laura";
$areanames{en}->{618866983} = "Laura";
$areanames{en}->{618866984} = "Laura";
$areanames{en}->{618866985} = "Laura";
$areanames{en}->{618866986} = "Laura";
$areanames{en}->{618866987} = "Laura";
$areanames{en}->{618866990} = "Melrose";
$areanames{en}->{618866991} = "Melrose";
$areanames{en}->{618866992} = "Melrose";
$areanames{en}->{618866993} = "Melrose";
$areanames{en}->{618866994} = "Melrose";
$areanames{en}->{618866995} = "Melrose";
$areanames{en}->{618866996} = "Melrose";
$areanames{en}->{618866997} = "Melrose";
$areanames{en}->{61886700} = "Everard";
$areanames{en}->{61886701} = "Everard";
$areanames{en}->{61886702} = "Indian\ Pacific";
$areanames{en}->{61886703} = "Indian\ Pacific";
$areanames{en}->{61886704} = "Indian\ Pacific";
$areanames{en}->{61886705} = "Mintabie";
$areanames{en}->{61886706} = "Everard";
$areanames{en}->{61886707} = "Marla\/Everard";
$areanames{en}->{61886708} = "Marla";
$areanames{en}->{61886709} = "Marla";
$areanames{en}->{6188671} = "Roxby\ Downs";
$areanames{en}->{61886720} = "Andamooka";
$areanames{en}->{61886721} = "Glendambo\/Gairdner";
$areanames{en}->{618867219} = "Gairdner";
$areanames{en}->{61886722} = "Tarcoola";
$areanames{en}->{61886723} = "Coober\ Pedy";
$areanames{en}->{61886724} = "Coober\ Pedy";
$areanames{en}->{61886725} = "Coober\ Pedy";
$areanames{en}->{61886726} = "Gairdner";
$areanames{en}->{61886727} = "Andamooka";
$areanames{en}->{61886728} = "Gairdner";
$areanames{en}->{61886729} = "Andamooka";
$areanames{en}->{61886730} = "Gairdner";
$areanames{en}->{61886731} = "Gairdner";
$areanames{en}->{61886732} = "Gairdner";
$areanames{en}->{61886733} = "Coober\ Pedy";
$areanames{en}->{61886734} = "Coober\ Pedy";
$areanames{en}->{61886735} = "Woomera";
$areanames{en}->{61886736} = "Woomera";
$areanames{en}->{61886737} = "Woomera";
$areanames{en}->{61886738} = "Woomera";
$areanames{en}->{61886739} = "Woomera";
$areanames{en}->{61886740} = "Wilpena";
$areanames{en}->{61886741} = "Wilpena";
$areanames{en}->{61886742} = "Wilpena";
$areanames{en}->{61886743} = "Woomera";
$areanames{en}->{61886744} = "Woomera";
$areanames{en}->{61886748} = "Gairdner";
$areanames{en}->{61886749} = "Frome";
$areanames{en}->{6188675} = "Frome";
$areanames{en}->{61886752} = "Leigh\ Creek\ South";
$areanames{en}->{61886753} = "Leigh\ Creek\ South";
$areanames{en}->{61886754} = "Leigh\ Creek\ South";
$areanames{en}->{61886760} = "Cummins";
$areanames{en}->{61886761} = "Cummins";
$areanames{en}->{61886762} = "Cummins";
$areanames{en}->{61886763} = "Cummins";
$areanames{en}->{61886764} = "Cummins";
$areanames{en}->{61886765} = "Yeelanna";
$areanames{en}->{61886766} = "Yeelanna";
$areanames{en}->{61886767} = "Ungarra";
$areanames{en}->{61886768} = "Yeelanna";
$areanames{en}->{61886769} = "Yeelanna";
$areanames{en}->{618867700} = "Willowie";
$areanames{en}->{618867701} = "Willowie";
$areanames{en}->{618867702} = "Willowie";
$areanames{en}->{618867703} = "Willowie";
$areanames{en}->{618867704} = "Willowie";
$areanames{en}->{618867705} = "Willowie";
$areanames{en}->{618867706} = "Willowie";
$areanames{en}->{618867707} = "Willowie";
$areanames{en}->{618867710} = "Wilmington";
$areanames{en}->{618867711} = "Wilmington";
$areanames{en}->{618867712} = "Wilmington";
$areanames{en}->{618867713} = "Wilmington";
$areanames{en}->{618867714} = "Wilmington";
$areanames{en}->{618867715} = "Wilmington";
$areanames{en}->{618867716} = "Wilmington";
$areanames{en}->{618867717} = "Wilmington";
$areanames{en}->{618867720} = "Carrieton";
$areanames{en}->{618867721} = "Carrieton";
$areanames{en}->{618867722} = "Carrieton";
$areanames{en}->{618867723} = "Carrieton";
$areanames{en}->{618867724} = "Carrieton";
$areanames{en}->{618867725} = "Carrieton";
$areanames{en}->{618867726} = "Carrieton";
$areanames{en}->{618867727} = "Carrieton";
$areanames{en}->{618867728} = "Carrieton";
$areanames{en}->{618867730} = "Herbert";
$areanames{en}->{618867731} = "Herbert";
$areanames{en}->{618867732} = "Herbert";
$areanames{en}->{618867733} = "Herbert";
$areanames{en}->{618867734} = "Herbert";
$areanames{en}->{618867735} = "Herbert";
$areanames{en}->{618867736} = "Herbert";
$areanames{en}->{618867737} = "Herbert";
$areanames{en}->{618867738} = "Herbert";
$areanames{en}->{618867740} = "Morchard";
$areanames{en}->{618867741} = "Morchard";
$areanames{en}->{618867742} = "Morchard";
$areanames{en}->{618867743} = "Morchard";
$areanames{en}->{618867744} = "Morchard";
$areanames{en}->{618867745} = "Morchard";
$areanames{en}->{618867746} = "Morchard";
$areanames{en}->{618867747} = "Morchard";
$areanames{en}->{618867748} = "Morchard";
$areanames{en}->{618867750} = "Orroroo";
$areanames{en}->{618867751} = "Orroroo";
$areanames{en}->{618867752} = "Orroroo";
$areanames{en}->{618867753} = "Orroroo";
$areanames{en}->{618867754} = "Orroroo";
$areanames{en}->{618867755} = "Orroroo";
$areanames{en}->{618867756} = "Orroroo";
$areanames{en}->{618867757} = "Orroroo";
$areanames{en}->{618867758} = "Orroroo";
$areanames{en}->{618867760} = "Peterborough";
$areanames{en}->{618867761} = "Peterborough";
$areanames{en}->{618867762} = "Peterborough";
$areanames{en}->{618867763} = "Peterborough";
$areanames{en}->{618867764} = "Peterborough";
$areanames{en}->{618867765} = "Peterborough";
$areanames{en}->{618867766} = "Peterborough";
$areanames{en}->{618867767} = "Peterborough";
$areanames{en}->{618867768} = "Peterborough";
$areanames{en}->{618867770} = "Terowie";
$areanames{en}->{618867771} = "Terowie";
$areanames{en}->{618867772} = "Terowie";
$areanames{en}->{618867773} = "Terowie";
$areanames{en}->{618867774} = "Terowie";
$areanames{en}->{618867775} = "Terowie";
$areanames{en}->{618867776} = "Terowie";
$areanames{en}->{618867777} = "Terowie";
$areanames{en}->{618867778} = "Terowie";
$areanames{en}->{618867780} = "Yunta";
$areanames{en}->{618867781} = "Yunta";
$areanames{en}->{618867782} = "Yunta";
$areanames{en}->{618867783} = "Yunta";
$areanames{en}->{618867784} = "Yunta";
$areanames{en}->{618867785} = "Yunta";
$areanames{en}->{618867786} = "Yunta";
$areanames{en}->{618867787} = "Yunta";
$areanames{en}->{618867788} = "Yunta";
$areanames{en}->{618867790} = "Hawker";
$areanames{en}->{618867791} = "Hawker";
$areanames{en}->{618867792} = "Hawker";
$areanames{en}->{618867793} = "Hawker";
$areanames{en}->{618867794} = "Hawker";
$areanames{en}->{618867795} = "Hawker";
$areanames{en}->{618867796} = "Hawker";
$areanames{en}->{618867797} = "Hawker";
$areanames{en}->{61886780} = "Woomera";
$areanames{en}->{61886781} = "Woomera";
$areanames{en}->{61886782} = "Woomera";
$areanames{en}->{61886783} = "Roxby\ Downs";
$areanames{en}->{61886784} = "Frome";
$areanames{en}->{61886785} = "Roxby\ Downs";
$areanames{en}->{61886786} = "Leigh\ Creek\ South";
$areanames{en}->{61886787} = "Leigh\ Creek\ South";
$areanames{en}->{61886788} = "Coober\ Pedy";
$areanames{en}->{61886789} = "Coober\ Pedy";
$areanames{en}->{61886790} = "Orroroo";
$areanames{en}->{61886791} = "Orroroo";
$areanames{en}->{61886792} = "Andamooka";
$areanames{en}->{6188680} = "Wudinna";
$areanames{en}->{61886805} = "Minnipa";
$areanames{en}->{61886806} = "Minnipa";
$areanames{en}->{61886807} = "Minnipa";
$areanames{en}->{61886808} = "Minnipa";
$areanames{en}->{61886810} = "Koongawa";
$areanames{en}->{61886811} = "Kyancutta";
$areanames{en}->{61886812} = "Kyancutta";
$areanames{en}->{61886813} = "Miltalie";
$areanames{en}->{61886814} = "Coober\ Pedy";
$areanames{en}->{61886817} = "Koongawa";
$areanames{en}->{61886818} = "Kyancutta";
$areanames{en}->{61886819} = "Kyancutta";
$areanames{en}->{6188682} = "Port\ Lincoln";
$areanames{en}->{6188683} = "Port\ Lincoln";
$areanames{en}->{61886839} = "Rudall";
$areanames{en}->{61886840} = "Port\ Lincoln";
$areanames{en}->{61886841} = "Port\ Lincoln";
$areanames{en}->{61886842} = "Port\ Lincoln";
$areanames{en}->{61886843} = "Port\ Lincoln";
$areanames{en}->{61886844} = "Koppio";
$areanames{en}->{61886845} = "Koppio";
$areanames{en}->{61886846} = "Koppio";
$areanames{en}->{61886847} = "Spilsby";
$areanames{en}->{61886848} = "Koppio";
$areanames{en}->{61886849} = "Koppio";
$areanames{en}->{61886850} = "Quorn";
$areanames{en}->{61886852} = "Wanilla";
$areanames{en}->{61886853} = "Coffin\ Bay";
$areanames{en}->{61886854} = "Coffin\ Bay";
$areanames{en}->{61886855} = "Coffin\ Bay";
$areanames{en}->{61886856} = "Sleaford\ Mere";
$areanames{en}->{61886858} = "Roxby\ Downs";
$areanames{en}->{6188686} = "Port\ Augusta";
$areanames{en}->{61886870} = "Elliston";
$areanames{en}->{61886871} = "Coulta";
$areanames{en}->{61886872} = "Coulta";
$areanames{en}->{61886873} = "Tooligie\ Hill";
$areanames{en}->{61886874} = "Tooligie\ Hill";
$areanames{en}->{61886875} = "Elliston";
$areanames{en}->{61886876} = "Kapinnie";
$areanames{en}->{61886877} = "Mount\ Hope";
$areanames{en}->{61886878} = "Sheringa";
$areanames{en}->{61886879} = "Elliston";
$areanames{en}->{61886880} = "Port\ Neill";
$areanames{en}->{61886881} = "Tumby\ Bay";
$areanames{en}->{61886882} = "Tumby\ Bay";
$areanames{en}->{61886883} = "Port\ Lincoln";
$areanames{en}->{61886884} = "Tumby\ Bay";
$areanames{en}->{61886885} = "Tumby\ Bay";
$areanames{en}->{61886886} = "Tumby\ Bay";
$areanames{en}->{61886887} = "Port\ Neill";
$areanames{en}->{61886888} = "Ungarra";
$areanames{en}->{61886889} = "Port\ Neill";
$areanames{en}->{61886890} = "Lock";
$areanames{en}->{61886891} = "Lock";
$areanames{en}->{61886892} = "Lock";
$areanames{en}->{61886893} = "Lock";
$areanames{en}->{61886894} = "Bayley\ Plains";
$areanames{en}->{61886895} = "Bayley\ Plains";
$areanames{en}->{618869000} = "Iron\ Baron";
$areanames{en}->{618869001} = "Iron\ Baron";
$areanames{en}->{618869002} = "Iron\ Baron";
$areanames{en}->{618869003} = "Iron\ Baron";
$areanames{en}->{618869004} = "Iron\ Baron";
$areanames{en}->{618869005} = "Iron\ Baron";
$areanames{en}->{618869006} = "Iron\ Baron";
$areanames{en}->{618869007} = "Iron\ Baron";
$areanames{en}->{618869010} = "Iron\ Knob";
$areanames{en}->{618869011} = "Iron\ Knob";
$areanames{en}->{618869012} = "Iron\ Knob";
$areanames{en}->{618869013} = "Iron\ Knob";
$areanames{en}->{618869014} = "Iron\ Knob";
$areanames{en}->{618869015} = "Iron\ Knob";
$areanames{en}->{618869016} = "Iron\ Knob";
$areanames{en}->{618869017} = "Iron\ Knob";
$areanames{en}->{618869020} = "Kelly";
$areanames{en}->{618869021} = "Kelly";
$areanames{en}->{618869022} = "Kelly";
$areanames{en}->{618869023} = "Kelly";
$areanames{en}->{618869024} = "Kelly";
$areanames{en}->{618869025} = "Kelly";
$areanames{en}->{618869026} = "Kelly";
$areanames{en}->{618869027} = "Kelly";
$areanames{en}->{618869030} = "Kimba";
$areanames{en}->{618869031} = "Kimba";
$areanames{en}->{618869032} = "Kimba";
$areanames{en}->{618869033} = "Kimba";
$areanames{en}->{618869034} = "Kimba";
$areanames{en}->{618869035} = "Kimba";
$areanames{en}->{618869036} = "Kimba";
$areanames{en}->{618869037} = "Kimba";
$areanames{en}->{618869040} = "Leigh\ Creek\ South";
$areanames{en}->{618869041} = "Leigh\ Creek\ South";
$areanames{en}->{618869042} = "Leigh\ Creek\ South";
$areanames{en}->{618869043} = "Leigh\ Creek\ South";
$areanames{en}->{618869044} = "Leigh\ Creek\ South";
$areanames{en}->{618869045} = "Leigh\ Creek\ South";
$areanames{en}->{618869046} = "Leigh\ Creek\ South";
$areanames{en}->{618869047} = "Leigh\ Creek\ South";
$areanames{en}->{618869048} = "Leigh\ Creek\ South";
$areanames{en}->{618869050} = "Spilsby";
$areanames{en}->{618869051} = "Spilsby";
$areanames{en}->{618869052} = "Spilsby";
$areanames{en}->{618869053} = "Spilsby";
$areanames{en}->{618869054} = "Spilsby";
$areanames{en}->{618869055} = "Spilsby";
$areanames{en}->{618869056} = "Spilsby";
$areanames{en}->{618869057} = "Spilsby";
$areanames{en}->{618869058} = "Spilsby";
$areanames{en}->{61886910} = "Coober\ Pedy";
$areanames{en}->{61886911} = "Frome";
$areanames{en}->{61886912} = "Gairdner";
$areanames{en}->{61886913} = "Glendambo";
$areanames{en}->{61886914} = "Leigh\ Creek\ South";
$areanames{en}->{61886915} = "Roxby\ Downs";
$areanames{en}->{61886916} = "Tarcoola";
$areanames{en}->{61886917} = "Woomera";
$areanames{en}->{61886918} = "Port\ Augusta";
$areanames{en}->{618869190} = "Port\ Augusta";
$areanames{en}->{618869191} = "Port\ Augusta";
$areanames{en}->{618869192} = "Port\ Augusta";
$areanames{en}->{618869193} = "Port\ Augusta";
$areanames{en}->{618869194} = "Port\ Augusta";
$areanames{en}->{618869198} = "Port\ Augusta";
$areanames{en}->{618869199} = "Port\ Augusta";
$areanames{en}->{61886920} = "Yabmana";
$areanames{en}->{61886921} = "Yeelanna";
$areanames{en}->{61886922} = "Crystal\ Brook";
$areanames{en}->{61886923} = "Mambray\ Creek";
$areanames{en}->{61886924} = "Nelshaby";
$areanames{en}->{61886925} = "Port\ Broughton";
$areanames{en}->{61886926} = "Port\ Pirie";
$areanames{en}->{61886927} = "Redhill";
$areanames{en}->{61886928} = "Wandearah\ East";
$areanames{en}->{61886929} = "Andamooka";
$areanames{en}->{61886930} = "Rudall";
$areanames{en}->{61886931} = "Sheringa";
$areanames{en}->{61886932} = "Sleaford\ Mere";
$areanames{en}->{61886933} = "Spilsby";
$areanames{en}->{61886934} = "Tooligie\ Hill";
$areanames{en}->{61886935} = "Tumby\ Bay";
$areanames{en}->{61886936} = "Ungarra";
$areanames{en}->{61886937} = "Wanilla";
$areanames{en}->{61886938} = "Wharminda";
$areanames{en}->{61886939} = "Wudinna";
$areanames{en}->{61886940} = "Kapinnie";
$areanames{en}->{61886941} = "Koongawa";
$areanames{en}->{61886942} = "Koppio";
$areanames{en}->{61886943} = "Kyancutta";
$areanames{en}->{61886944} = "Lock";
$areanames{en}->{61886945} = "Miltalie";
$areanames{en}->{61886946} = "Minnipa";
$areanames{en}->{61886947} = "Mount\ Hope";
$areanames{en}->{61886948} = "Port\ Lincoln";
$areanames{en}->{61886949} = "Port\ Neill";
$areanames{en}->{61886950} = "Wilpena";
$areanames{en}->{61886951} = "Arno\ Bay";
$areanames{en}->{61886952} = "Bayley\ Plains";
$areanames{en}->{61886953} = "Cleve";
$areanames{en}->{61886954} = "Coffin\ Bay";
$areanames{en}->{61886955} = "Coulta";
$areanames{en}->{61886956} = "Cowell";
$areanames{en}->{61886957} = "Cummins";
$areanames{en}->{61886958} = "Darke\ Peak";
$areanames{en}->{61886959} = "Elliston";
$areanames{en}->{61886960} = "Yunta";
$areanames{en}->{61886961} = "Hawker";
$areanames{en}->{61886962} = "Iron\ Baron";
$areanames{en}->{61886963} = "Iron\ Knob";
$areanames{en}->{61886964} = "Kelly";
$areanames{en}->{61886965} = "Kimba";
$areanames{en}->{61886966} = "Port\ Augusta";
$areanames{en}->{61886967} = "Quorn";
$areanames{en}->{61886968} = "The\ Ranges";
$areanames{en}->{61886969} = "Whyalla";
$areanames{en}->{61886970} = "Laura";
$areanames{en}->{61886971} = "Melrose";
$areanames{en}->{61886972} = "Willowie";
$areanames{en}->{61886973} = "Wilmington";
$areanames{en}->{61886974} = "Carrieton";
$areanames{en}->{61886975} = "Herbert";
$areanames{en}->{61886976} = "Morchard";
$areanames{en}->{61886977} = "Orroroo";
$areanames{en}->{61886978} = "Peterborough";
$areanames{en}->{61886979} = "Terowie";
$areanames{en}->{61886980} = "Wirrulla";
$areanames{en}->{61886981} = "Everard";
$areanames{en}->{61886982} = "Indian\ Pacific";
$areanames{en}->{61886983} = "Marla";
$areanames{en}->{61886984} = "Mintabie";
$areanames{en}->{61886985} = "Booleroo\ Centre";
$areanames{en}->{61886986} = "Caltowie";
$areanames{en}->{61886987} = "Georgetown";
$areanames{en}->{61886988} = "Gladstone";
$areanames{en}->{61886989} = "Jamestown";
$areanames{en}->{61886990} = "Ceduna";
$areanames{en}->{61886991} = "Coorabie";
$areanames{en}->{61886992} = "Courela";
$areanames{en}->{61886993} = "Great\ Bight";
$areanames{en}->{61886994} = "Mudamuckla";
$areanames{en}->{61886995} = "Nunjikompita";
$areanames{en}->{61886996} = "Penong";
$areanames{en}->{61886997} = "Poochera";
$areanames{en}->{61886998} = "Port\ Kenny";
$areanames{en}->{61886999} = "Streaky\ Bay";
$areanames{en}->{61887000} = "Avenue\ Range";
$areanames{en}->{61887001} = "Avenue\ Range";
$areanames{en}->{61887002} = "Avenue\ Range";
$areanames{en}->{61887003} = "Bangham";
$areanames{en}->{61887004} = "Bangham";
$areanames{en}->{61887005} = "Bangham";
$areanames{en}->{61887006} = "Bordertown";
$areanames{en}->{61887007} = "Bordertown";
$areanames{en}->{61887008} = "Bordertown";
$areanames{en}->{61887009} = "Wrattonbully";
$areanames{en}->{61887010} = "Cannawigara";
$areanames{en}->{61887011} = "Cannawigara";
$areanames{en}->{61887012} = "Cannawigara";
$areanames{en}->{61887013} = "Colebatch";
$areanames{en}->{61887014} = "Colebatch";
$areanames{en}->{61887015} = "Colebatch";
$areanames{en}->{61887016} = "Conmurra";
$areanames{en}->{61887017} = "Conmurra";
$areanames{en}->{61887018} = "Conmurra";
$areanames{en}->{61887019} = "Bangham";
$areanames{en}->{61887020} = "Coonawarra";
$areanames{en}->{61887021} = "Coonawarra";
$areanames{en}->{61887022} = "Coonawarra";
$areanames{en}->{61887023} = "Frances";
$areanames{en}->{61887024} = "Frances";
$areanames{en}->{61887025} = "Frances";
$areanames{en}->{61887026} = "Greenways";
$areanames{en}->{61887027} = "Greenways";
$areanames{en}->{61887028} = "Greenways";
$areanames{en}->{61887029} = "Bordertown";
$areanames{en}->{61887030} = "Kalangadoo";
$areanames{en}->{61887031} = "Kalangadoo";
$areanames{en}->{61887032} = "Kalangadoo";
$areanames{en}->{61887033} = "Keilira";
$areanames{en}->{61887034} = "Keilira";
$areanames{en}->{61887035} = "Keilira";
$areanames{en}->{61887036} = "Keith";
$areanames{en}->{61887037} = "Keith";
$areanames{en}->{61887038} = "Keith";
$areanames{en}->{61887039} = "Cannawigara";
$areanames{en}->{61887040} = "Kingston\ Se";
$areanames{en}->{61887041} = "Kingston\ Se";
$areanames{en}->{61887042} = "Kingston\ Se";
$areanames{en}->{61887043} = "Kongorong";
$areanames{en}->{61887044} = "Kongorong";
$areanames{en}->{61887045} = "Kongorong";
$areanames{en}->{61887046} = "Laffer";
$areanames{en}->{61887047} = "Laffer";
$areanames{en}->{61887048} = "Laffer";
$areanames{en}->{61887049} = "Colebatch";
$areanames{en}->{61887050} = "Lochaber";
$areanames{en}->{61887051} = "Lochaber";
$areanames{en}->{61887052} = "Lochaber";
$areanames{en}->{61887053} = "Lucindale";
$areanames{en}->{61887054} = "Lucindale";
$areanames{en}->{61887055} = "Lucindale";
$areanames{en}->{61887056} = "Lucindale\ South";
$areanames{en}->{61887057} = "Lucindale\ South";
$areanames{en}->{61887058} = "Lucindale\ South";
$areanames{en}->{61887059} = "Keith";
$areanames{en}->{61887060} = "Makin";
$areanames{en}->{61887061} = "Makin";
$areanames{en}->{61887062} = "Makin";
$areanames{en}->{61887063} = "Marcollat";
$areanames{en}->{61887064} = "Marcollat";
$areanames{en}->{61887065} = "Marcollat";
$areanames{en}->{61887066} = "Millicent";
$areanames{en}->{61887067} = "Millicent";
$areanames{en}->{61887068} = "Millicent";
$areanames{en}->{61887069} = "Laffer";
$areanames{en}->{6188707} = "Mount\ Gambier";
$areanames{en}->{61887073} = "Monkoora";
$areanames{en}->{61887074} = "Monkoora";
$areanames{en}->{61887075} = "Monkoora";
$areanames{en}->{61887080} = "Naracoorte";
$areanames{en}->{61887081} = "Naracoorte";
$areanames{en}->{61887082} = "Naracoorte";
$areanames{en}->{61887083} = "Padthaway";
$areanames{en}->{61887084} = "Padthaway";
$areanames{en}->{61887085} = "Padthaway";
$areanames{en}->{61887086} = "Penola";
$areanames{en}->{61887087} = "Penola";
$areanames{en}->{61887088} = "Penola";
$areanames{en}->{61887089} = "Makin";
$areanames{en}->{61887090} = "Port\ Macdonnell";
$areanames{en}->{61887091} = "Port\ Macdonnell";
$areanames{en}->{61887092} = "Port\ Macdonnell";
$areanames{en}->{61887093} = "Reedy\ Creek";
$areanames{en}->{61887094} = "Reedy\ Creek";
$areanames{en}->{61887095} = "Reedy\ Creek";
$areanames{en}->{61887096} = "Rendelsham";
$areanames{en}->{61887097} = "Rendelsham";
$areanames{en}->{61887098} = "Rendelsham";
$areanames{en}->{61887099} = "Marcollat";
$areanames{en}->{61887100} = "Robe";
$areanames{en}->{61887101} = "Robe";
$areanames{en}->{61887102} = "Robe";
$areanames{en}->{61887103} = "Short";
$areanames{en}->{61887104} = "Short";
$areanames{en}->{61887105} = "Short";
$areanames{en}->{61887106} = "Tantanoola";
$areanames{en}->{61887107} = "Tantanoola";
$areanames{en}->{61887108} = "Tantanoola";
$areanames{en}->{61887109} = "Monkoora";
$areanames{en}->{61887110} = "Taratap";
$areanames{en}->{61887111} = "Taratap";
$areanames{en}->{61887112} = "Taratap";
$areanames{en}->{61887113} = "Tarpeena";
$areanames{en}->{61887114} = "Tarpeena";
$areanames{en}->{61887115} = "Tarpeena";
$areanames{en}->{61887116} = "Thornlea";
$areanames{en}->{61887117} = "Thornlea";
$areanames{en}->{61887118} = "Thornlea";
$areanames{en}->{61887119} = "Tintinara";
$areanames{en}->{61887120} = "Tilley\ Swamp";
$areanames{en}->{61887121} = "Tilley\ Swamp";
$areanames{en}->{61887122} = "Tilley\ Swamp";
$areanames{en}->{61887123} = "Tintinara";
$areanames{en}->{61887124} = "Tintinara";
$areanames{en}->{61887125} = "Tintinara";
$areanames{en}->{61887126} = "Western\ Flat";
$areanames{en}->{61887127} = "Western\ Flat";
$areanames{en}->{61887128} = "Western\ Flat";
$areanames{en}->{61887129} = "Western\ Flat";
$areanames{en}->{61887130} = "Willalooka";
$areanames{en}->{61887131} = "Willalooka";
$areanames{en}->{61887132} = "Willalooka";
$areanames{en}->{61887133} = "Wirrega";
$areanames{en}->{61887134} = "Wirrega";
$areanames{en}->{61887135} = "Wirrega";
$areanames{en}->{61887136} = "Wrattonbully";
$areanames{en}->{61887137} = "Wrattonbully";
$areanames{en}->{61887138} = "Wrattonbully";
$areanames{en}->{61887139} = "Mount\ Gambier";
$areanames{en}->{61887140} = "Willalooka";
$areanames{en}->{61887141} = "Wirrega";
$areanames{en}->{61887142} = "Coonawarra";
$areanames{en}->{61887143} = "Greenways";
$areanames{en}->{61887144} = "Kalangadoo";
$areanames{en}->{61887145} = "Kongorong";
$areanames{en}->{61887146} = "Millicent";
$areanames{en}->{61887147} = "Mount\ Gambier";
$areanames{en}->{61887148} = "Penola";
$areanames{en}->{61887149} = "Port\ Macdonnell";
$areanames{en}->{61887150} = "Rendelsham";
$areanames{en}->{61887151} = "Short";
$areanames{en}->{61887152} = "Tantanoola";
$areanames{en}->{61887153} = "Tarpeena";
$areanames{en}->{61887154} = "Thornlea";
$areanames{en}->{61887155} = "Wrattonbully";
$areanames{en}->{61887156} = "Avenue\ Range";
$areanames{en}->{61887157} = "Conmurra";
$areanames{en}->{61887158} = "Frances";
$areanames{en}->{61887159} = "Keilira";
$areanames{en}->{61887160} = "Kingston\ Se";
$areanames{en}->{61887161} = "Lochaber";
$areanames{en}->{61887162} = "Lucindale";
$areanames{en}->{61887163} = "Lucindale\ South";
$areanames{en}->{61887164} = "Naracoorte";
$areanames{en}->{61887165} = "Padthaway";
$areanames{en}->{61887166} = "Reedy\ Creek";
$areanames{en}->{61887167} = "Robe";
$areanames{en}->{61887168} = "Taratap";
$areanames{en}->{61887169} = "Tilley\ Swamp";
$areanames{en}->{61887170} = "Bangham";
$areanames{en}->{61887171} = "Bordertown";
$areanames{en}->{61887172} = "Cannawigara";
$areanames{en}->{61887173} = "Colebatch";
$areanames{en}->{61887174} = "Keith";
$areanames{en}->{61887175} = "Laffer";
$areanames{en}->{61887176} = "Makin";
$areanames{en}->{61887177} = "Marcollat";
$areanames{en}->{61887178} = "Monkoora";
$areanames{en}->{61887179} = "Tintinara";
$areanames{en}->{61887180} = "Western\ Flat";
$areanames{en}->{61887181} = "Willalooka";
$areanames{en}->{61887182} = "Wirrega";
$areanames{en}->{61887183} = "Coonawarra";
$areanames{en}->{61887184} = "Greenways";
$areanames{en}->{61887185} = "Kalangadoo";
$areanames{en}->{61887186} = "Kongorong";
$areanames{en}->{61887187} = "Millicent";
$areanames{en}->{61887188} = "Mount\ Gambier";
$areanames{en}->{61887189} = "Penola";
$areanames{en}->{61887190} = "Port\ Macdonnell";
$areanames{en}->{61887191} = "Rendelsham";
$areanames{en}->{61887192} = "Short";
$areanames{en}->{61887193} = "Tantanoola";
$areanames{en}->{61887194} = "Tarpeena";
$areanames{en}->{61887195} = "Thornlea";
$areanames{en}->{61887196} = "Avenue\ Range";
$areanames{en}->{61887197} = "Conmurra";
$areanames{en}->{61887198} = "Frances";
$areanames{en}->{61887199} = "Keilira";
$areanames{en}->{61887200} = "Kingston\ Se";
$areanames{en}->{61887201} = "Lochaber";
$areanames{en}->{61887202} = "Lucindale";
$areanames{en}->{61887203} = "Lucindale\ South";
$areanames{en}->{61887204} = "Naracoorte";
$areanames{en}->{61887205} = "Padthaway";
$areanames{en}->{61887206} = "Reedy\ Creek";
$areanames{en}->{61887207} = "Robe";
$areanames{en}->{61887208} = "Taratap";
$areanames{en}->{61887209} = "Tilley\ Swamp";
$areanames{en}->{61887210} = "Mount\ Gambier";
$areanames{en}->{61887211} = "Mount\ Gambier";
$areanames{en}->{61887212} = "Mount\ Gambier";
$areanames{en}->{61887213} = "Mount\ Gambier";
$areanames{en}->{61887214} = "Tantanoola";
$areanames{en}->{61887215} = "Tarpeena";
$areanames{en}->{61887216} = "Tarpeena";
$areanames{en}->{61887217} = "Kongorong";
$areanames{en}->{61887218} = "Mount\ Gambier";
$areanames{en}->{61887219} = "Port\ Macdonnell";
$areanames{en}->{61887220} = "Mount\ Gambier";
$areanames{en}->{61887221} = "Wrattonbully";
$areanames{en}->{61887222} = "Bangham";
$areanames{en}->{61887223} = "Bordertown";
$areanames{en}->{61887224} = "Cannawigara";
$areanames{en}->{61887225} = "Colebatch";
$areanames{en}->{61887226} = "Keith";
$areanames{en}->{61887227} = "Laffer";
$areanames{en}->{61887228} = "Makin";
$areanames{en}->{61887229} = "Marcollat";
$areanames{en}->{6188723} = "Mount\ Gambier";
$areanames{en}->{6188724} = "Mount\ Gambier";
$areanames{en}->{6188725} = "Mount\ Gambier";
$areanames{en}->{6188726} = "Mount\ Gambier";
$areanames{en}->{61887270} = "Monkoora";
$areanames{en}->{61887271} = "Tintinara";
$areanames{en}->{61887272} = "Western\ Flat";
$areanames{en}->{61887273} = "Willalooka";
$areanames{en}->{61887274} = "Wirrega";
$areanames{en}->{61887275} = "Coonawarra";
$areanames{en}->{61887276} = "Greenways";
$areanames{en}->{61887277} = "Kalangadoo";
$areanames{en}->{61887278} = "Kongorong";
$areanames{en}->{61887279} = "Millicent";
$areanames{en}->{61887280} = "Mount\ Gambier";
$areanames{en}->{61887281} = "Penola";
$areanames{en}->{61887282} = "Port\ Macdonnell";
$areanames{en}->{61887283} = "Rendelsham";
$areanames{en}->{61887284} = "Short";
$areanames{en}->{61887285} = "Tantanoola";
$areanames{en}->{61887286} = "Tarpeena";
$areanames{en}->{61887287} = "Thornlea";
$areanames{en}->{61887288} = "Avenue\ Range";
$areanames{en}->{61887289} = "Conmurra";
$areanames{en}->{61887290} = "Frances";
$areanames{en}->{61887291} = "Keilira";
$areanames{en}->{61887292} = "Wrattonbully";
$areanames{en}->{61887293} = "Kingston\ Se";
$areanames{en}->{61887294} = "Lochaber";
$areanames{en}->{61887295} = "Lucindale";
$areanames{en}->{61887296} = "Lucindale\ South";
$areanames{en}->{61887297} = "Naracoorte";
$areanames{en}->{61887298} = "Padthaway";
$areanames{en}->{61887299} = "Reedy\ Creek";
$areanames{en}->{61887300} = "Millicent";
$areanames{en}->{61887301} = "Millicent";
$areanames{en}->{61887302} = "Millicent";
$areanames{en}->{61887303} = "Millicent";
$areanames{en}->{61887304} = "Tantanoola";
$areanames{en}->{61887305} = "Thornlea";
$areanames{en}->{61887306} = "Millicent";
$areanames{en}->{61887307} = "Greenways";
$areanames{en}->{61887308} = "Rendelsham";
$areanames{en}->{61887309} = "Rendelsham";
$areanames{en}->{61887310} = "Penola";
$areanames{en}->{61887311} = "Penola";
$areanames{en}->{61887312} = "Penola";
$areanames{en}->{61887313} = "Penola";
$areanames{en}->{61887314} = "Coonawarra";
$areanames{en}->{61887315} = "Coonawarra";
$areanames{en}->{61887316} = "Coonawarra";
$areanames{en}->{61887317} = "Short";
$areanames{en}->{61887318} = "Short";
$areanames{en}->{61887319} = "Short";
$areanames{en}->{61887320} = "Robe";
$areanames{en}->{61887321} = "Taratap";
$areanames{en}->{61887322} = "Tilley\ Swamp";
$areanames{en}->{61887323} = "Tintinara";
$areanames{en}->{61887324} = "Mount\ Gambier";
$areanames{en}->{61887325} = "Bangham";
$areanames{en}->{61887326} = "Bordertown";
$areanames{en}->{61887327} = "Cannawigara";
$areanames{en}->{61887328} = "Colebatch";
$areanames{en}->{61887329} = "Keith";
$areanames{en}->{6188733} = "Millicent";
$areanames{en}->{61887340} = "Tantanoola";
$areanames{en}->{61887341} = "Greenways";
$areanames{en}->{61887342} = "Greenways";
$areanames{en}->{61887343} = "Greenways";
$areanames{en}->{61887344} = "Tantanoola";
$areanames{en}->{61887345} = "Tantanoola";
$areanames{en}->{61887346} = "Rendelsham";
$areanames{en}->{61887347} = "Rendelsham";
$areanames{en}->{61887348} = "Millicent";
$areanames{en}->{61887349} = "Millicent";
$areanames{en}->{61887350} = "Thornlea";
$areanames{en}->{61887351} = "Mount\ Gambier";
$areanames{en}->{61887352} = "Thornlea";
$areanames{en}->{61887353} = "Rendelsham";
$areanames{en}->{61887354} = "Rendelsham";
$areanames{en}->{61887355} = "Millicent";
$areanames{en}->{61887356} = "Rendelsham";
$areanames{en}->{61887357} = "Rendelsham";
$areanames{en}->{61887358} = "Rendelsham";
$areanames{en}->{61887359} = "Thornlea";
$areanames{en}->{6188736} = "Coonawarra";
$areanames{en}->{61887366} = "Short";
$areanames{en}->{61887367} = "Short";
$areanames{en}->{61887368} = "Short";
$areanames{en}->{61887369} = "Short";
$areanames{en}->{6188737} = "Penola";
$areanames{en}->{6188738} = "Port\ Macdonnell";
$areanames{en}->{61887380} = "Kongorong";
$areanames{en}->{61887381} = "Kongorong";
$areanames{en}->{61887389} = "Kongorong";
$areanames{en}->{61887390} = "Tarpeena";
$areanames{en}->{61887391} = "Tarpeena";
$areanames{en}->{61887392} = "Kalangadoo";
$areanames{en}->{61887393} = "Kalangadoo";
$areanames{en}->{61887394} = "Kalangadoo";
$areanames{en}->{61887395} = "Kalangadoo";
$areanames{en}->{61887396} = "Tarpeena";
$areanames{en}->{61887397} = "Tarpeena";
$areanames{en}->{61887398} = "Tarpeena";
$areanames{en}->{61887399} = "Kalangadoo";
$areanames{en}->{61887400} = "Bangham";
$areanames{en}->{61887401} = "Bordertown";
$areanames{en}->{61887402} = "Cannawigara";
$areanames{en}->{61887403} = "Colebatch";
$areanames{en}->{61887404} = "Keith";
$areanames{en}->{61887405} = "Laffer";
$areanames{en}->{61887406} = "Makin";
$areanames{en}->{61887407} = "Marcollat";
$areanames{en}->{61887408} = "Monkoora";
$areanames{en}->{61887409} = "Tintinara";
$areanames{en}->{61887410} = "Western\ Flat";
$areanames{en}->{61887411} = "Willalooka";
$areanames{en}->{61887412} = "Wirrega";
$areanames{en}->{61887413} = "Coonawarra";
$areanames{en}->{61887414} = "Greenways";
$areanames{en}->{61887415} = "Kalangadoo";
$areanames{en}->{61887416} = "Kongorong";
$areanames{en}->{61887417} = "Millicent";
$areanames{en}->{61887418} = "Mount\ Gambier";
$areanames{en}->{61887419} = "Penola";
$areanames{en}->{61887420} = "Port\ Macdonnell";
$areanames{en}->{61887421} = "Rendelsham";
$areanames{en}->{61887422} = "Short";
$areanames{en}->{61887423} = "Tantanoola";
$areanames{en}->{61887424} = "Tarpeena";
$areanames{en}->{61887425} = "Thornlea";
$areanames{en}->{61887426} = "Avenue\ Range";
$areanames{en}->{61887427} = "Conmurra";
$areanames{en}->{61887428} = "Frances";
$areanames{en}->{61887429} = "Keilira";
$areanames{en}->{61887430} = "Kingston\ Se";
$areanames{en}->{61887431} = "Lochaber";
$areanames{en}->{61887432} = "Lucindale";
$areanames{en}->{61887433} = "Lucindale\ South";
$areanames{en}->{61887434} = "Naracoorte";
$areanames{en}->{61887435} = "Padthaway";
$areanames{en}->{61887436} = "Reedy\ Creek";
$areanames{en}->{61887437} = "Robe";
$areanames{en}->{61887438} = "Taratap";
$areanames{en}->{61887439} = "Tilley\ Swamp";
$areanames{en}->{61887440} = "Wrattonbully";
$areanames{en}->{61887441} = "Laffer";
$areanames{en}->{61887442} = "Makin";
$areanames{en}->{61887443} = "Marcollat";
$areanames{en}->{61887444} = "Monkoora";
$areanames{en}->{61887445} = "Tintinara";
$areanames{en}->{61887446} = "Western\ Flat";
$areanames{en}->{61887447} = "Willalooka";
$areanames{en}->{61887448} = "Wirrega";
$areanames{en}->{61887449} = "Coonawarra";
$areanames{en}->{61887450} = "Greenways";
$areanames{en}->{61887451} = "Kalangadoo";
$areanames{en}->{61887452} = "Kongorong";
$areanames{en}->{61887453} = "Millicent";
$areanames{en}->{61887454} = "Penola";
$areanames{en}->{61887455} = "Port\ Macdonnell";
$areanames{en}->{61887456} = "Rendelsham";
$areanames{en}->{61887457} = "Short";
$areanames{en}->{61887458} = "Tantanoola";
$areanames{en}->{61887459} = "Tarpeena";
$areanames{en}->{61887460} = "Thornlea";
$areanames{en}->{61887461} = "Avenue\ Range";
$areanames{en}->{61887462} = "Conmurra";
$areanames{en}->{61887463} = "Frances";
$areanames{en}->{61887464} = "Keilira";
$areanames{en}->{61887465} = "Kingston\ Se";
$areanames{en}->{61887466} = "Lochaber";
$areanames{en}->{61887467} = "Lucindale";
$areanames{en}->{61887468} = "Lucindale\ South";
$areanames{en}->{61887469} = "Naracoorte";
$areanames{en}->{61887470} = "Padthaway";
$areanames{en}->{61887471} = "Reedy\ Creek";
$areanames{en}->{61887472} = "Robe";
$areanames{en}->{61887473} = "Taratap";
$areanames{en}->{61887474} = "Tilley\ Swamp";
$areanames{en}->{61887475} = "Wrattonbully";
$areanames{en}->{61887476} = "Bangham";
$areanames{en}->{61887477} = "Bordertown";
$areanames{en}->{61887478} = "Cannawigara";
$areanames{en}->{61887479} = "Colebatch";
$areanames{en}->{61887480} = "Keith";
$areanames{en}->{61887481} = "Laffer";
$areanames{en}->{61887482} = "Makin";
$areanames{en}->{61887483} = "Marcollat";
$areanames{en}->{61887484} = "Monkoora";
$areanames{en}->{61887485} = "Tintinara";
$areanames{en}->{61887486} = "Western\ Flat";
$areanames{en}->{61887487} = "Willalooka";
$areanames{en}->{61887488} = "Wirrega";
$areanames{en}->{61887489} = "Coonawarra";
$areanames{en}->{61887490} = "Greenways";
$areanames{en}->{61887491} = "Kalangadoo";
$areanames{en}->{61887492} = "Kongorong";
$areanames{en}->{61887493} = "Millicent";
$areanames{en}->{61887494} = "Mount\ Gambier";
$areanames{en}->{61887495} = "Penola";
$areanames{en}->{61887496} = "Port\ Macdonnell";
$areanames{en}->{61887497} = "Rendelsham";
$areanames{en}->{61887498} = "Short";
$areanames{en}->{61887499} = "Tantanoola";
$areanames{en}->{61887500} = "Bordertown";
$areanames{en}->{61887501} = "Bordertown";
$areanames{en}->{61887502} = "Bordertown";
$areanames{en}->{61887503} = "Bordertown";
$areanames{en}->{61887504} = "Bordertown";
$areanames{en}->{61887505} = "Wirrega";
$areanames{en}->{61887506} = "Wirrega";
$areanames{en}->{61887507} = "Cannawigara";
$areanames{en}->{61887508} = "Western\ Flat";
$areanames{en}->{61887509} = "Bangham";
$areanames{en}->{61887510} = "Keith";
$areanames{en}->{61887511} = "Keith";
$areanames{en}->{61887512} = "Keith";
$areanames{en}->{61887513} = "Willalooka";
$areanames{en}->{61887514} = "Marcollat";
$areanames{en}->{61887515} = "Laffer";
$areanames{en}->{61887516} = "Monkoora";
$areanames{en}->{61887517} = "Colebatch";
$areanames{en}->{61887518} = "Tintinara";
$areanames{en}->{61887519} = "Makin";
$areanames{en}->{6188752} = "Bordertown";
$areanames{en}->{6188753} = "Bordertown";
$areanames{en}->{6188754} = "Wirrega";
$areanames{en}->{6188755} = "Keith";
$areanames{en}->{61887560} = "Colebatch";
$areanames{en}->{61887561} = "Colebatch";
$areanames{en}->{61887562} = "Monkoora";
$areanames{en}->{61887563} = "Monkoora";
$areanames{en}->{61887564} = "Wirrega";
$areanames{en}->{61887565} = "Tintinara";
$areanames{en}->{61887566} = "Keith";
$areanames{en}->{61887567} = "Keith";
$areanames{en}->{61887568} = "Keith";
$areanames{en}->{61887569} = "Keith";
$areanames{en}->{61887570} = "Makin";
$areanames{en}->{61887571} = "Tintinara";
$areanames{en}->{61887572} = "Tintinara";
$areanames{en}->{61887573} = "Marcollat";
$areanames{en}->{61887574} = "Laffer";
$areanames{en}->{61887575} = "Laffer";
$areanames{en}->{61887576} = "Tintinara";
$areanames{en}->{61887577} = "Marcollat";
$areanames{en}->{61887578} = "Willalooka";
$areanames{en}->{61887579} = "Willalooka";
$areanames{en}->{61887580} = "Western\ Flat";
$areanames{en}->{61887581} = "Western\ Flat";
$areanames{en}->{61887582} = "Western\ Flat";
$areanames{en}->{61887583} = "Bangham";
$areanames{en}->{61887584} = "Bangham";
$areanames{en}->{61887585} = "Cannawigara";
$areanames{en}->{61887586} = "Cannawigara";
$areanames{en}->{61887587} = "Cannawigara";
$areanames{en}->{61887588} = "Cannawigara";
$areanames{en}->{61887589} = "Cannawigara";
$areanames{en}->{61887590} = "Tarpeena";
$areanames{en}->{61887591} = "Thornlea";
$areanames{en}->{61887592} = "Avenue\ Range";
$areanames{en}->{61887593} = "Conmurra";
$areanames{en}->{61887594} = "Frances";
$areanames{en}->{61887595} = "Keilira";
$areanames{en}->{61887596} = "Kingston\ Se";
$areanames{en}->{61887597} = "Lochaber";
$areanames{en}->{61887598} = "Lucindale";
$areanames{en}->{61887599} = "Lucindale\ South";
$areanames{en}->{61887600} = "Frances";
$areanames{en}->{61887601} = "Naracoorte";
$areanames{en}->{61887602} = "Naracoorte";
$areanames{en}->{61887603} = "Padthaway";
$areanames{en}->{61887604} = "Lochaber";
$areanames{en}->{61887605} = "Avenue\ Range";
$areanames{en}->{61887606} = "Conmurra";
$areanames{en}->{61887607} = "Lucindale";
$areanames{en}->{61887608} = "Lucindale\ South";
$areanames{en}->{61887609} = "Wrattonbully";
$areanames{en}->{61887610} = "Reedy\ Creek";
$areanames{en}->{61887611} = "Kingston\ Se";
$areanames{en}->{61887612} = "Kingston\ Se";
$areanames{en}->{61887613} = "Kingston\ Se";
$areanames{en}->{61887614} = "Robe";
$areanames{en}->{61887615} = "Taratap";
$areanames{en}->{61887616} = "Tilley\ Swamp";
$areanames{en}->{61887617} = "Keilira";
$areanames{en}->{61887618} = "Reedy\ Creek";
$areanames{en}->{61887619} = "Robe";
$areanames{en}->{6188762} = "Naracoorte";
$areanames{en}->{61887630} = "Naracoorte";
$areanames{en}->{61887631} = "Padthaway";
$areanames{en}->{61887632} = "Reedy\ Creek";
$areanames{en}->{61887633} = "Robe";
$areanames{en}->{61887634} = "Taratap";
$areanames{en}->{61887635} = "Tilley\ Swamp";
$areanames{en}->{61887636} = "Wrattonbully";
$areanames{en}->{61887637} = "Mount\ Gambier";
$areanames{en}->{61887638} = "Millicent";
$areanames{en}->{61887639} = "Wrattonbully";
$areanames{en}->{61887640} = "Wrattonbully";
$areanames{en}->{61887641} = "Wrattonbully";
$areanames{en}->{61887642} = "Naracoorte";
$areanames{en}->{61887643} = "Naracoorte";
$areanames{en}->{61887644} = "Naracoorte";
$areanames{en}->{61887645} = "Wrattonbully";
$areanames{en}->{61887646} = "Wrattonbully";
$areanames{en}->{61887647} = "Wrattonbully";
$areanames{en}->{61887648} = "Lucindale";
$areanames{en}->{61887649} = "Lucindale";
$areanames{en}->{61887650} = "Frances";
$areanames{en}->{61887651} = "Frances";
$areanames{en}->{61887652} = "Lochaber";
$areanames{en}->{61887653} = "Lochaber";
$areanames{en}->{61887654} = "Lochaber";
$areanames{en}->{61887655} = "Padthaway";
$areanames{en}->{61887656} = "Padthaway";
$areanames{en}->{61887657} = "Naracoorte";
$areanames{en}->{61887658} = "Lochaber";
$areanames{en}->{61887659} = "Frances";
$areanames{en}->{61887660} = "Avenue\ Range";
$areanames{en}->{61887661} = "Avenue\ Range";
$areanames{en}->{61887662} = "Lucindale";
$areanames{en}->{61887663} = "Lucindale";
$areanames{en}->{61887664} = "Lucindale";
$areanames{en}->{61887665} = "Padthaway";
$areanames{en}->{61887666} = "Padthaway";
$areanames{en}->{61887667} = "Conmurra";
$areanames{en}->{61887668} = "Conmurra";
$areanames{en}->{61887669} = "Conmurra";
$areanames{en}->{6188767} = "Kingston\ Se";
$areanames{en}->{61887675} = "Keilira";
$areanames{en}->{61887677} = "Taratap";
$areanames{en}->{61887678} = "Tilley\ Swamp";
$areanames{en}->{61887679} = "Keilira";
$areanames{en}->{6188768} = "Robe";
$areanames{en}->{61887687} = "Reedy\ Creek";
$areanames{en}->{61887688} = "Reedy\ Creek";
$areanames{en}->{61887689} = "Reedy\ Creek";
$areanames{en}->{6188769} = "Lucindale\ South";
$areanames{en}->{61887698} = "Lochaber";
$areanames{en}->{61887699} = "Frances";
$areanames{en}->{61887700} = "Bangham";
$areanames{en}->{61887701} = "Bordertown";
$areanames{en}->{61887702} = "Cannawigara";
$areanames{en}->{61887703} = "Colebatch";
$areanames{en}->{61887704} = "Keith";
$areanames{en}->{61887705} = "Laffer";
$areanames{en}->{61887706} = "Makin";
$areanames{en}->{61887707} = "Western\ Flat";
$areanames{en}->{61887708} = "Marcollat";
$areanames{en}->{61887709} = "Monkoora";
$areanames{en}->{61887710} = "Willalooka";
$areanames{en}->{61887711} = "Wirrega";
$areanames{en}->{61887712} = "Coonawarra";
$areanames{en}->{61887713} = "Greenways";
$areanames{en}->{61887714} = "Port\ Macdonnell";
$areanames{en}->{61887715} = "Kalangadoo";
$areanames{en}->{61887716} = "Kongorong";
$areanames{en}->{61887717} = "Millicent";
$areanames{en}->{61887718} = "Penola";
$areanames{en}->{61887719} = "Rendelsham";
$areanames{en}->{61887720} = "Short";
$areanames{en}->{61887721} = "Tantanoola";
$areanames{en}->{61887722} = "Tarpeena";
$areanames{en}->{61887723} = "Thornlea";
$areanames{en}->{61887724} = "Avenue\ Range";
$areanames{en}->{61887725} = "Conmurra";
$areanames{en}->{61887726} = "Frances";
$areanames{en}->{61887727} = "Keilira";
$areanames{en}->{61887728} = "Kingston\ Se";
$areanames{en}->{61887729} = "Lochaber";
$areanames{en}->{61887730} = "Lucindale";
$areanames{en}->{61887731} = "Lucindale\ South";
$areanames{en}->{61887732} = "Naracoorte";
$areanames{en}->{61887733} = "Padthaway";
$areanames{en}->{61887734} = "Reedy\ Creek";
$areanames{en}->{61887735} = "Robe";
$areanames{en}->{61887736} = "Taratap";
$areanames{en}->{61887737} = "Tilley\ Swamp";
$areanames{en}->{61887738} = "Mount\ Gambier";
$areanames{en}->{61887739} = "Mount\ Gambier";
$areanames{en}->{61887740} = "Mount\ Gambier";
$areanames{en}->{61887741} = "Wirrega";
$areanames{en}->{61887742} = "Wirrega";
$areanames{en}->{61887743} = "Greenways";
$areanames{en}->{61887744} = "Greenways";
$areanames{en}->{61887745} = "Kongorong";
$areanames{en}->{61887746} = "Kongorong";
$areanames{en}->{61887747} = "Rendelsham";
$areanames{en}->{61887748} = "Rendelsham";
$areanames{en}->{61887749} = "Short";
$areanames{en}->{61887750} = "Short";
$areanames{en}->{61887751} = "Tarpeena";
$areanames{en}->{61887752} = "Tarpeena";
$areanames{en}->{61887753} = "Thornlea";
$areanames{en}->{61887754} = "Thornlea";
$areanames{en}->{61887755} = "Wrattonbully";
$areanames{en}->{61887756} = "Wrattonbully";
$areanames{en}->{61887757} = "Avenue\ Range";
$areanames{en}->{61887758} = "Avenue\ Range";
$areanames{en}->{61887759} = "Conmurra";
$areanames{en}->{61887760} = "Conmurra";
$areanames{en}->{61887761} = "Frances";
$areanames{en}->{61887762} = "Frances";
$areanames{en}->{61887763} = "Lochaber";
$areanames{en}->{61887764} = "Lochaber";
$areanames{en}->{61887765} = "Lucindale";
$areanames{en}->{61887766} = "Lucindale";
$areanames{en}->{61887767} = "Lucindale\ South";
$areanames{en}->{61887768} = "Lucindale\ South";
$areanames{en}->{61887769} = "Taratap";
$areanames{en}->{61887770} = "Taratap";
$areanames{en}->{61887771} = "Tilley\ Swamp";
$areanames{en}->{61887772} = "Tilley\ Swamp";
$areanames{en}->{61887773} = "Bangham";
$areanames{en}->{61887774} = "Bangham";
$areanames{en}->{61887775} = "Bordertown";
$areanames{en}->{61887776} = "Bordertown";
$areanames{en}->{61887777} = "Mount\ Gambier";
$areanames{en}->{61887778} = "Tintinara";
$areanames{en}->{61887779} = "Colebatch";
$areanames{en}->{61887780} = "Marcollat";
$areanames{en}->{61887781} = "Mount\ Gambier";
$areanames{en}->{61887782} = "Mount\ Gambier";
$areanames{en}->{61887783} = "Coonawarra";
$areanames{en}->{61887784} = "Kongorong";
$areanames{en}->{61887785} = "Mount\ Gambier";
$areanames{en}->{61887786} = "Penola";
$areanames{en}->{61887787} = "Kingston\ Se";
$areanames{en}->{61887788} = "Greenways";
$areanames{en}->{61887789} = "Conmurra";
$areanames{en}->{61887790} = "Monkoora";
$areanames{en}->{61887791} = "Bangham";
$areanames{en}->{61887792} = "Avenue\ Range";
$areanames{en}->{61887793} = "Frances";
$areanames{en}->{61887794} = "Tarpeena";
$areanames{en}->{61887795} = "Bordertown";
$areanames{en}->{61887796} = "Kalangadoo";
$areanames{en}->{61887797} = "Millicent";
$areanames{en}->{61887798} = "Padthaway";
$areanames{en}->{61887799} = "Keilira";
$areanames{en}->{61887800} = "Port\ Macdonnell";
$areanames{en}->{61887801} = "Cannawigara";
$areanames{en}->{61887802} = "Keilira";
$areanames{en}->{61887803} = "Taratap";
$areanames{en}->{61887804} = "Lochaber";
$areanames{en}->{61887805} = "Reedy\ Creek";
$areanames{en}->{61887806} = "Wirrega";
$areanames{en}->{61887807} = "Makin";
$areanames{en}->{61887808} = "Tantanoola";
$areanames{en}->{61887809} = "Keith";
$areanames{en}->{61887810} = "Padthaway";
$areanames{en}->{61887811} = "Rendelsham";
$areanames{en}->{61887812} = "Willalooka";
$areanames{en}->{61887813} = "Robe";
$areanames{en}->{61887814} = "Monkoora";
$areanames{en}->{61887815} = "Keith";
$areanames{en}->{61887816} = "Naracoorte";
$areanames{en}->{61887817} = "Marcollat";
$areanames{en}->{61887818} = "Wrattonbully";
$areanames{en}->{61887819} = "Laffer";
$areanames{en}->{61887820} = "Naracoorte";
$areanames{en}->{61887821} = "Western\ Flat";
$areanames{en}->{61887822} = "Tintinara";
$areanames{en}->{61887823} = "Lucindale";
$areanames{en}->{61887824} = "Lucindale\ South";
$areanames{en}->{61887825} = "Port\ Macdonnell";
$areanames{en}->{61887826} = "Tilley\ Swamp";
$areanames{en}->{61887827} = "Laffer";
$areanames{en}->{61887828} = "Short";
$areanames{en}->{61887829} = "Lochaber";
$areanames{en}->{61887830} = "Short";
$areanames{en}->{61887831} = "Thornlea";
$areanames{en}->{61887832} = "Conmurra";
$areanames{en}->{61887833} = "Colebatch";
$areanames{en}->{61887834} = "Coonawarra";
$areanames{en}->{61887835} = "Kongorong";
$areanames{en}->{61887836} = "Mount\ Gambier";
$areanames{en}->{61887837} = "Penola";
$areanames{en}->{61887838} = "Kingston\ Se";
$areanames{en}->{61887839} = "Reedy\ Creek";
$areanames{en}->{61887840} = "Rendelsham";
$areanames{en}->{61887841} = "Greenways";
$areanames{en}->{61887842} = "Bangham";
$areanames{en}->{61887843} = "Avenue\ Range";
$areanames{en}->{61887844} = "Frances";
$areanames{en}->{61887845} = "Tarpeena";
$areanames{en}->{61887846} = "Bordertown";
$areanames{en}->{61887847} = "Kalangadoo";
$areanames{en}->{61887848} = "Millicent";
$areanames{en}->{61887849} = "Lucindale";
$areanames{en}->{61887850} = "Robe";
$areanames{en}->{61887851} = "Padthaway";
$areanames{en}->{61887852} = "Cannawigara";
$areanames{en}->{61887853} = "Keilira";
$areanames{en}->{61887854} = "Taratap";
$areanames{en}->{61887855} = "Lochaber";
$areanames{en}->{61887856} = "Reedy\ Creek";
$areanames{en}->{61887857} = "Wirrega";
$areanames{en}->{61887858} = "Makin";
$areanames{en}->{61887859} = "Lucindale\ South";
$areanames{en}->{61887860} = "Wirrega";
$areanames{en}->{61887861} = "Tantanoola";
$areanames{en}->{61887862} = "Rendelsham";
$areanames{en}->{61887863} = "Willalooka";
$areanames{en}->{61887864} = "Robe";
$areanames{en}->{61887865} = "Monkoora";
$areanames{en}->{61887866} = "Keith";
$areanames{en}->{61887867} = "Naracoorte";
$areanames{en}->{61887868} = "Marcollat";
$areanames{en}->{61887869} = "Makin";
$areanames{en}->{61887870} = "Willalooka";
$areanames{en}->{61887871} = "Wrattonbully";
$areanames{en}->{61887872} = "Western\ Flat";
$areanames{en}->{61887873} = "Tintinara";
$areanames{en}->{61887874} = "Lucindale";
$areanames{en}->{61887875} = "Lucindale\ South";
$areanames{en}->{61887876} = "Port\ Macdonnell";
$areanames{en}->{61887877} = "Tilley\ Swamp";
$areanames{en}->{61887878} = "Laffer";
$areanames{en}->{61887879} = "Tintinara";
$areanames{en}->{61887880} = "Western\ Flat";
$areanames{en}->{61887881} = "Short";
$areanames{en}->{61887882} = "Thornlea";
$areanames{en}->{61887883} = "Conmurra";
$areanames{en}->{61887884} = "Colebatch";
$areanames{en}->{61887885} = "Coonawarra";
$areanames{en}->{61887886} = "Kongorong";
$areanames{en}->{61887887} = "Penola";
$areanames{en}->{61887888} = "Kingston\ Se";
$areanames{en}->{61887889} = "Thornlea";
$areanames{en}->{61887890} = "Tilley\ Swamp";
$areanames{en}->{61887891} = "Greenways";
$areanames{en}->{61887892} = "Bangham";
$areanames{en}->{61887893} = "Avenue\ Range";
$areanames{en}->{61887894} = "Frances";
$areanames{en}->{61887895} = "Tarpeena";
$areanames{en}->{61887896} = "Bordertown";
$areanames{en}->{61887897} = "Kalangadoo";
$areanames{en}->{61887898} = "Millicent";
$areanames{en}->{61887899} = "Taratap";
$areanames{en}->{6188790} = "Bordertown";
$areanames{en}->{61887910} = "Bangham";
$areanames{en}->{61887911} = "Bordertown";
$areanames{en}->{61887912} = "Cannawigara";
$areanames{en}->{61887913} = "Colebatch";
$areanames{en}->{61887914} = "Keith";
$areanames{en}->{61887915} = "Laffer";
$areanames{en}->{61887916} = "Makin";
$areanames{en}->{61887917} = "Marcollat";
$areanames{en}->{61887918} = "Monkoora";
$areanames{en}->{61887919} = "Tintinara";
$areanames{en}->{61887920} = "Western\ Flat";
$areanames{en}->{61887921} = "Willalooka";
$areanames{en}->{61887922} = "Wirrega";
$areanames{en}->{61887923} = "Coonawarra";
$areanames{en}->{61887924} = "Greenways";
$areanames{en}->{61887925} = "Kalangadoo";
$areanames{en}->{61887926} = "Kongorong";
$areanames{en}->{61887927} = "Millicent";
$areanames{en}->{61887928} = "Mount\ Gambier";
$areanames{en}->{61887929} = "Penola";
$areanames{en}->{61887930} = "Port\ Macdonnell";
$areanames{en}->{61887931} = "Rendelsham";
$areanames{en}->{61887932} = "Short";
$areanames{en}->{61887933} = "Tantanoola";
$areanames{en}->{61887934} = "Tarpeena";
$areanames{en}->{61887935} = "Thornlea";
$areanames{en}->{61887936} = "Avenue\ Range";
$areanames{en}->{61887937} = "Conmurra";
$areanames{en}->{61887938} = "Frances";
$areanames{en}->{61887939} = "Keilira";
$areanames{en}->{61887940} = "Kingston\ Se";
$areanames{en}->{61887941} = "Lochaber";
$areanames{en}->{61887942} = "Lucindale";
$areanames{en}->{61887943} = "Lucindale\ South";
$areanames{en}->{61887944} = "Naracoorte";
$areanames{en}->{61887945} = "Padthaway";
$areanames{en}->{61887946} = "Reedy\ Creek";
$areanames{en}->{61887947} = "Robe";
$areanames{en}->{61887948} = "Taratap";
$areanames{en}->{61887949} = "Tilley\ Swamp";
$areanames{en}->{61887950} = "Bordertown";
$areanames{en}->{61887951} = "Bordertown";
$areanames{en}->{61887952} = "Cannawigara";
$areanames{en}->{61887953} = "Cannawigara";
$areanames{en}->{61887954} = "Keith";
$areanames{en}->{61887955} = "Keith";
$areanames{en}->{61887956} = "Laffer";
$areanames{en}->{61887957} = "Laffer";
$areanames{en}->{61887958} = "Willalooka";
$areanames{en}->{61887959} = "Willalooka";
$areanames{en}->{61887960} = "Keilira";
$areanames{en}->{61887961} = "Keilira";
$areanames{en}->{61887962} = "Kingston\ Se";
$areanames{en}->{61887963} = "Kingston\ Se";
$areanames{en}->{61887964} = "Naracoorte";
$areanames{en}->{61887965} = "Naracoorte";
$areanames{en}->{61887966} = "Millicent";
$areanames{en}->{61887967} = "Millicent";
$areanames{en}->{61887968} = "Reedy\ Creek";
$areanames{en}->{61887969} = "Reedy\ Creek";
$areanames{en}->{61887970} = "Colebatch";
$areanames{en}->{61887971} = "Colebatch";
$areanames{en}->{61887972} = "Coonawarra";
$areanames{en}->{61887973} = "Coonawarra";
$areanames{en}->{61887974} = "Kalangadoo";
$areanames{en}->{61887975} = "Kalangadoo";
$areanames{en}->{61887976} = "Makin";
$areanames{en}->{61887977} = "Makin";
$areanames{en}->{61887978} = "Mount\ Gambier";
$areanames{en}->{61887979} = "Mount\ Gambier";
$areanames{en}->{61887980} = "Penola";
$areanames{en}->{61887981} = "Penola";
$areanames{en}->{61887982} = "Port\ Macdonnell";
$areanames{en}->{61887983} = "Port\ Macdonnell";
$areanames{en}->{61887984} = "Tantanoola";
$areanames{en}->{61887985} = "Tantanoola";
$areanames{en}->{61887986} = "Marcollat";
$areanames{en}->{61887987} = "Marcollat";
$areanames{en}->{61887988} = "Padthaway";
$areanames{en}->{61887989} = "Padthaway";
$areanames{en}->{61887990} = "Monkoora";
$areanames{en}->{61887991} = "Monkoora";
$areanames{en}->{61887992} = "Robe";
$areanames{en}->{61887993} = "Robe";
$areanames{en}->{61887994} = "Mount\ Gambier";
$areanames{en}->{61887995} = "Tintinara";
$areanames{en}->{61887996} = "Tintinara";
$areanames{en}->{61887997} = "Western\ Flat";
$areanames{en}->{61887998} = "Western\ Flat";
$areanames{en}->{61887999} = "Tantanoola";
$areanames{en}->{61888000} = "Alford";
$areanames{en}->{61888001} = "Alford";
$areanames{en}->{61888002} = "Alford";
$areanames{en}->{61888003} = "Ardrossan";
$areanames{en}->{61888004} = "Ardrossan";
$areanames{en}->{61888005} = "Ardrossan";
$areanames{en}->{61888006} = "Arthurton";
$areanames{en}->{61888007} = "Arthurton";
$areanames{en}->{61888008} = "Arthurton";
$areanames{en}->{61888009} = "Warooka";
$areanames{en}->{61888010} = "Auburn";
$areanames{en}->{61888011} = "Auburn";
$areanames{en}->{61888012} = "Auburn";
$areanames{en}->{61888013} = "Balaklava";
$areanames{en}->{61888014} = "Balaklava";
$areanames{en}->{61888015} = "Balaklava";
$areanames{en}->{61888016} = "Blyth";
$areanames{en}->{61888017} = "Blyth";
$areanames{en}->{61888018} = "Blyth";
$areanames{en}->{61888019} = "Yorketown";
$areanames{en}->{61888020} = "Booborowie";
$areanames{en}->{61888021} = "Booborowie";
$areanames{en}->{61888022} = "Booborowie";
$areanames{en}->{61888023} = "Braemer";
$areanames{en}->{61888024} = "Braemer";
$areanames{en}->{61888025} = "Braemer";
$areanames{en}->{61888026} = "Brinkworth";
$areanames{en}->{61888027} = "Brinkworth";
$areanames{en}->{61888028} = "Brinkworth";
$areanames{en}->{61888029} = "Balaklava";
$areanames{en}->{61888030} = "Burra";
$areanames{en}->{61888031} = "Burra";
$areanames{en}->{61888032} = "Burra";
$areanames{en}->{61888033} = "Bute";
$areanames{en}->{61888034} = "Bute";
$areanames{en}->{61888035} = "Bute";
$areanames{en}->{61888036} = "Clare";
$areanames{en}->{61888037} = "Clare";
$areanames{en}->{61888038} = "Clare";
$areanames{en}->{61888039} = "Halbury";
$areanames{en}->{61888040} = "Curramulka";
$areanames{en}->{61888041} = "Curramulka";
$areanames{en}->{61888042} = "Curramulka";
$areanames{en}->{61888043} = "Halbury";
$areanames{en}->{61888044} = "Halbury";
$areanames{en}->{61888045} = "Halbury";
$areanames{en}->{61888046} = "Hallett";
$areanames{en}->{61888047} = "Hallett";
$areanames{en}->{61888048} = "Hallett";
$areanames{en}->{61888049} = "Lochiel";
$areanames{en}->{61888050} = "Kadina";
$areanames{en}->{61888051} = "Kadina";
$areanames{en}->{61888052} = "Kadina";
$areanames{en}->{61888053} = "Lochiel";
$areanames{en}->{61888054} = "Lochiel";
$areanames{en}->{61888055} = "Lochiel";
$areanames{en}->{61888056} = "Maitland";
$areanames{en}->{61888057} = "Maitland";
$areanames{en}->{61888058} = "Maitland";
$areanames{en}->{61888059} = "Nantawarra";
$areanames{en}->{61888060} = "Marion\ Bay";
$areanames{en}->{61888061} = "Marion\ Bay";
$areanames{en}->{61888062} = "Marion\ Bay";
$areanames{en}->{61888063} = "Minlaton";
$areanames{en}->{61888064} = "Minlaton";
$areanames{en}->{61888065} = "Minlaton";
$areanames{en}->{61888066} = "Moonta";
$areanames{en}->{61888067} = "Moonta";
$areanames{en}->{61888068} = "Moonta";
$areanames{en}->{61888069} = "Port\ Wakefield";
$areanames{en}->{61888070} = "Nantawarra";
$areanames{en}->{61888071} = "Nantawarra";
$areanames{en}->{61888072} = "Nantawarra";
$areanames{en}->{61888073} = "Paskeville";
$areanames{en}->{61888074} = "Paskeville";
$areanames{en}->{61888075} = "Paskeville";
$areanames{en}->{61888076} = "Pine\ Point";
$areanames{en}->{61888077} = "Pine\ Point";
$areanames{en}->{61888078} = "Pine\ Point";
$areanames{en}->{61888079} = "Snowtown";
$areanames{en}->{61888080} = "Port\ Victoria";
$areanames{en}->{61888081} = "Port\ Victoria";
$areanames{en}->{61888082} = "Port\ Victoria";
$areanames{en}->{61888083} = "Port\ Wakefield";
$areanames{en}->{61888084} = "Port\ Wakefield";
$areanames{en}->{61888085} = "Port\ Wakefield";
$areanames{en}->{61888086} = "Riverton";
$areanames{en}->{61888087} = "Riverton";
$areanames{en}->{61888088} = "Riverton";
$areanames{en}->{61888089} = "South\ Hummocks";
$areanames{en}->{61888090} = "Snowtown";
$areanames{en}->{61888091} = "Snowtown";
$areanames{en}->{61888092} = "Snowtown";
$areanames{en}->{61888093} = "South\ Hummocks";
$areanames{en}->{61888094} = "South\ Hummocks";
$areanames{en}->{61888095} = "South\ Hummocks";
$areanames{en}->{61888096} = "Spalding";
$areanames{en}->{61888097} = "Spalding";
$areanames{en}->{61888098} = "Spalding";
$areanames{en}->{61888099} = "Booborowie";
$areanames{en}->{61888100} = "Thistle";
$areanames{en}->{61888101} = "Thistle";
$areanames{en}->{61888102} = "Thistle";
$areanames{en}->{61888103} = "Warooka";
$areanames{en}->{61888104} = "Warooka";
$areanames{en}->{61888105} = "Warooka";
$areanames{en}->{61888106} = "Wedge";
$areanames{en}->{61888107} = "Wedge";
$areanames{en}->{61888108} = "Wedge";
$areanames{en}->{61888109} = "Braemer";
$areanames{en}->{61888110} = "Yorketown";
$areanames{en}->{61888111} = "Yorketown";
$areanames{en}->{61888112} = "Yorketown";
$areanames{en}->{61888113} = "Balaklava";
$areanames{en}->{61888114} = "Clare";
$areanames{en}->{61888115} = "Braemer";
$areanames{en}->{61888116} = "Kadina";
$areanames{en}->{61888117} = "Burra";
$areanames{en}->{61888118} = "Hallett";
$areanames{en}->{61888119} = "Blyth";
$areanames{en}->{61888120} = "Brinkworth";
$areanames{en}->{61888121} = "Clare";
$areanames{en}->{61888122} = "Spalding";
$areanames{en}->{61888123} = "Alford";
$areanames{en}->{61888124} = "Bute";
$areanames{en}->{61888125} = "Kadina";
$areanames{en}->{61888126} = "Moonta";
$areanames{en}->{61888127} = "Paskeville";
$areanames{en}->{61888128} = "Ardrossan";
$areanames{en}->{61888129} = "Arthurton";
$areanames{en}->{61888130} = "Maitland";
$areanames{en}->{61888131} = "Pine\ Point";
$areanames{en}->{61888132} = "Port\ Victoria";
$areanames{en}->{61888133} = "Thistle";
$areanames{en}->{61888134} = "Wedge";
$areanames{en}->{61888135} = "Warooka";
$areanames{en}->{61888136} = "Yorketown";
$areanames{en}->{61888137} = "Curramulka";
$areanames{en}->{61888138} = "Marion\ Bay";
$areanames{en}->{61888139} = "Minlaton";
$areanames{en}->{61888140} = "Balaklava";
$areanames{en}->{61888141} = "Halbury";
$areanames{en}->{61888142} = "Lochiel";
$areanames{en}->{61888143} = "Nantawarra";
$areanames{en}->{61888144} = "Port\ Wakefield";
$areanames{en}->{61888145} = "Snowtown";
$areanames{en}->{61888146} = "South\ Hummocks";
$areanames{en}->{61888147} = "Booborowie";
$areanames{en}->{61888148} = "Braemer";
$areanames{en}->{61888149} = "Burra";
$areanames{en}->{61888150} = "Hallett";
$areanames{en}->{61888151} = "Blyth";
$areanames{en}->{61888152} = "Brinkworth";
$areanames{en}->{61888153} = "Clare";
$areanames{en}->{61888154} = "Spalding";
$areanames{en}->{61888155} = "Alford";
$areanames{en}->{61888156} = "Bute";
$areanames{en}->{61888157} = "Kadina";
$areanames{en}->{61888158} = "Moonta";
$areanames{en}->{61888159} = "Paskeville";
$areanames{en}->{61888160} = "Ardrossan";
$areanames{en}->{61888161} = "Arthurton";
$areanames{en}->{61888162} = "Maitland";
$areanames{en}->{61888163} = "Pine\ Point";
$areanames{en}->{61888164} = "Port\ Victoria";
$areanames{en}->{61888165} = "Thistle";
$areanames{en}->{61888166} = "Wedge";
$areanames{en}->{61888167} = "Curramulka";
$areanames{en}->{61888168} = "Marion\ Bay";
$areanames{en}->{61888169} = "Minlaton";
$areanames{en}->{61888170} = "Warooka";
$areanames{en}->{61888171} = "Yorketown";
$areanames{en}->{61888172} = "Balaklava";
$areanames{en}->{61888173} = "Halbury";
$areanames{en}->{61888174} = "Lochiel";
$areanames{en}->{61888175} = "Nantawarra";
$areanames{en}->{61888176} = "Port\ Wakefield";
$areanames{en}->{61888177} = "Snowtown";
$areanames{en}->{61888178} = "South\ Hummocks";
$areanames{en}->{61888179} = "Booborowie";
$areanames{en}->{61888180} = "Braemer";
$areanames{en}->{61888181} = "Burra";
$areanames{en}->{61888182} = "Hallett";
$areanames{en}->{61888183} = "Blyth";
$areanames{en}->{61888184} = "Brinkworth";
$areanames{en}->{61888185} = "Clare";
$areanames{en}->{61888186} = "Spalding";
$areanames{en}->{61888187} = "Alford";
$areanames{en}->{61888188} = "Bute";
$areanames{en}->{61888189} = "Kadina";
$areanames{en}->{61888190} = "Moonta";
$areanames{en}->{61888191} = "Paskeville";
$areanames{en}->{61888192} = "Ardrossan";
$areanames{en}->{61888193} = "Arthurton";
$areanames{en}->{61888194} = "Maitland";
$areanames{en}->{61888195} = "Pine\ Point";
$areanames{en}->{61888196} = "Port\ Victoria";
$areanames{en}->{61888197} = "Thistle";
$areanames{en}->{61888198} = "Wedge";
$areanames{en}->{61888199} = "Curramulka";
$areanames{en}->{61888200} = "Braemer";
$areanames{en}->{61888201} = "Clare";
$areanames{en}->{61888202} = "Snowtown";
$areanames{en}->{61888203} = "Snowtown";
$areanames{en}->{61888204} = "Snowtown";
$areanames{en}->{61888205} = "Clare";
$areanames{en}->{61888206} = "Clare";
$areanames{en}->{61888207} = "Braemer";
$areanames{en}->{61888208} = "Braemer";
$areanames{en}->{61888209} = "Clare";
$areanames{en}->{6188821} = "Kadina";
$areanames{en}->{61888220} = "Marion\ Bay";
$areanames{en}->{61888221} = "Minlaton";
$areanames{en}->{61888222} = "Warooka";
$areanames{en}->{61888223} = "Yorketown";
$areanames{en}->{61888224} = "Clare";
$areanames{en}->{61888225} = "Kadina";
$areanames{en}->{61888226} = "Maitland";
$areanames{en}->{61888227} = "Minlaton";
$areanames{en}->{61888228} = "Warooka";
$areanames{en}->{61888229} = "Yorketown";
$areanames{en}->{6188823} = "Kadina";
$areanames{en}->{6188824} = "Alford";
$areanames{en}->{6188825} = "Moonta";
$areanames{en}->{6188826} = "Bute";
$areanames{en}->{6188827} = "Paskeville";
$areanames{en}->{6188828} = "Kadina";
$areanames{en}->{61888286} = "Moonta";
$areanames{en}->{61888287} = "Alford";
$areanames{en}->{61888288} = "Bute";
$areanames{en}->{61888289} = "Paskeville";
$areanames{en}->{61888290} = "Balaklava";
$areanames{en}->{61888291} = "Halbury";
$areanames{en}->{61888292} = "Lochiel";
$areanames{en}->{61888293} = "Balaklava";
$areanames{en}->{61888294} = "Halbury";
$areanames{en}->{61888295} = "Lochiel";
$areanames{en}->{61888296} = "Nantawarra";
$areanames{en}->{61888297} = "Port\ Wakefield";
$areanames{en}->{61888298} = "Snowtown";
$areanames{en}->{61888299} = "South\ Hummocks";
$areanames{en}->{61888300} = "Booborowie";
$areanames{en}->{61888301} = "Braemer";
$areanames{en}->{61888302} = "Burra";
$areanames{en}->{61888303} = "Hallett";
$areanames{en}->{61888304} = "Blyth";
$areanames{en}->{61888305} = "Brinkworth";
$areanames{en}->{61888306} = "Clare";
$areanames{en}->{61888307} = "Spalding";
$areanames{en}->{61888308} = "Alford";
$areanames{en}->{61888309} = "Bute";
$areanames{en}->{61888310} = "Maitland";
$areanames{en}->{61888311} = "Maitland";
$areanames{en}->{61888312} = "Maitland";
$areanames{en}->{61888313} = "Port\ Victoria";
$areanames{en}->{61888314} = "Pine\ Point";
$areanames{en}->{61888315} = "Pine\ Point";
$areanames{en}->{61888316} = "Ardrossan";
$areanames{en}->{61888317} = "Arthurton";
$areanames{en}->{61888318} = "Ardrossan";
$areanames{en}->{61888319} = "Ardrossan";
$areanames{en}->{6188832} = "Maitland";
$areanames{en}->{61888330} = "Kadina";
$areanames{en}->{61888331} = "Moonta";
$areanames{en}->{61888332} = "Paskeville";
$areanames{en}->{61888333} = "Ardrossan";
$areanames{en}->{61888334} = "Arthurton";
$areanames{en}->{61888335} = "Maitland";
$areanames{en}->{61888336} = "Pine\ Point";
$areanames{en}->{61888337} = "Port\ Victoria";
$areanames{en}->{61888338} = "Thistle";
$areanames{en}->{61888339} = "Wedge";
$areanames{en}->{6188834} = "Port\ Victoria";
$areanames{en}->{6188835} = "Arthurton";
$areanames{en}->{6188836} = "Maitland";
$areanames{en}->{6188837} = "Ardrossan";
$areanames{en}->{6188838} = "Pine\ Point";
$areanames{en}->{6188839} = "Pine\ Point";
$areanames{en}->{6188840} = "Riverton";
$areanames{en}->{61888400} = "Auburn";
$areanames{en}->{61888401} = "Auburn";
$areanames{en}->{61888402} = "Auburn";
$areanames{en}->{6188841} = "Clare";
$areanames{en}->{61888415} = "Spalding";
$areanames{en}->{61888417} = "Blyth";
$areanames{en}->{61888419} = "Brinkworth";
$areanames{en}->{6188842} = "Clare";
$areanames{en}->{6188843} = "Clare";
$areanames{en}->{6188844} = "Blyth";
$areanames{en}->{6188845} = "Spalding";
$areanames{en}->{6188846} = "Brinkworth";
$areanames{en}->{6188847} = "Riverton";
$areanames{en}->{6188848} = "Riverton";
$areanames{en}->{6188849} = "Auburn";
$areanames{en}->{61888500} = "Yorketown";
$areanames{en}->{61888501} = "Yorketown";
$areanames{en}->{61888502} = "Yorketown";
$areanames{en}->{61888503} = "Warooka";
$areanames{en}->{61888504} = "Yorketown";
$areanames{en}->{61888505} = "Marion\ Bay";
$areanames{en}->{61888506} = "Yorketown";
$areanames{en}->{61888507} = "Minlaton";
$areanames{en}->{61888508} = "Curramulka";
$areanames{en}->{61888509} = "Curramulka";
$areanames{en}->{61888510} = "Curramulka";
$areanames{en}->{61888511} = "Marion\ Bay";
$areanames{en}->{61888512} = "Minlaton";
$areanames{en}->{61888513} = "Warooka";
$areanames{en}->{61888514} = "Yorketown";
$areanames{en}->{61888515} = "Nantawarra";
$areanames{en}->{61888516} = "Port\ Wakefield";
$areanames{en}->{61888517} = "Snowtown";
$areanames{en}->{61888518} = "South\ Hummocks";
$areanames{en}->{61888519} = "Booborowie";
$areanames{en}->{6188852} = "Yorketown";
$areanames{en}->{6188853} = "Minlaton";
$areanames{en}->{61888536} = "Curramulka";
$areanames{en}->{61888537} = "Curramulka";
$areanames{en}->{61888538} = "Curramulka";
$areanames{en}->{61888539} = "Curramulka";
$areanames{en}->{61888540} = "Curramulka";
$areanames{en}->{61888541} = "Curramulka";
$areanames{en}->{61888542} = "Curramulka";
$areanames{en}->{61888543} = "Marion\ Bay";
$areanames{en}->{61888544} = "Marion\ Bay";
$areanames{en}->{61888545} = "Warooka";
$areanames{en}->{61888546} = "Warooka";
$areanames{en}->{61888547} = "Curramulka";
$areanames{en}->{61888548} = "Curramulka";
$areanames{en}->{61888549} = "Warooka";
$areanames{en}->{6188855} = "Warooka";
$areanames{en}->{61888556} = "Thistle";
$areanames{en}->{61888557} = "Wedge";
$areanames{en}->{61888558} = "Wedge";
$areanames{en}->{61888559} = "Thistle";
$areanames{en}->{61888560} = "Braemer";
$areanames{en}->{61888561} = "Burra";
$areanames{en}->{61888562} = "Hallett";
$areanames{en}->{61888563} = "Blyth";
$areanames{en}->{61888564} = "Brinkworth";
$areanames{en}->{61888565} = "Clare";
$areanames{en}->{61888566} = "Spalding";
$areanames{en}->{61888567} = "Alford";
$areanames{en}->{61888568} = "Bute";
$areanames{en}->{61888569} = "Kadina";
$areanames{en}->{61888570} = "Moonta";
$areanames{en}->{61888571} = "Paskeville";
$areanames{en}->{61888572} = "Ardrossan";
$areanames{en}->{61888573} = "Arthurton";
$areanames{en}->{61888574} = "Maitland";
$areanames{en}->{61888575} = "Pine\ Point";
$areanames{en}->{61888576} = "Port\ Victoria";
$areanames{en}->{61888577} = "Thistle";
$areanames{en}->{61888578} = "Wedge";
$areanames{en}->{61888579} = "Curramulka";
$areanames{en}->{61888580} = "Marion\ Bay";
$areanames{en}->{61888581} = "Minlaton";
$areanames{en}->{61888582} = "Warooka";
$areanames{en}->{61888583} = "Yorketown";
$areanames{en}->{61888584} = "Balaklava";
$areanames{en}->{61888585} = "Halbury";
$areanames{en}->{61888586} = "Lochiel";
$areanames{en}->{61888587} = "Nantawarra";
$areanames{en}->{61888588} = "Port\ Wakefield";
$areanames{en}->{61888589} = "Snowtown";
$areanames{en}->{61888590} = "South\ Hummocks";
$areanames{en}->{61888591} = "Booborowie";
$areanames{en}->{61888592} = "Braemer";
$areanames{en}->{61888593} = "Burra";
$areanames{en}->{61888594} = "Hallett";
$areanames{en}->{61888595} = "Blyth";
$areanames{en}->{61888596} = "Brinkworth";
$areanames{en}->{61888597} = "Clare";
$areanames{en}->{61888598} = "Spalding";
$areanames{en}->{61888599} = "Alford";
$areanames{en}->{61888600} = "Balaklava";
$areanames{en}->{61888601} = "Balaklava";
$areanames{en}->{61888602} = "Balaklava";
$areanames{en}->{61888603} = "Balaklava";
$areanames{en}->{61888604} = "Snowtown";
$areanames{en}->{61888605} = "Lochiel";
$areanames{en}->{61888606} = "Halbury";
$areanames{en}->{61888607} = "Nantawarra";
$areanames{en}->{61888608} = "South\ Hummocks";
$areanames{en}->{61888609} = "Port\ Wakefield";
$areanames{en}->{61888610} = "Bute";
$areanames{en}->{61888611} = "Kadina";
$areanames{en}->{61888612} = "Moonta";
$areanames{en}->{61888613} = "Paskeville";
$areanames{en}->{61888614} = "Ardrossan";
$areanames{en}->{61888615} = "Arthurton";
$areanames{en}->{61888616} = "Maitland";
$areanames{en}->{61888617} = "Pine\ Point";
$areanames{en}->{61888618} = "Port\ Victoria";
$areanames{en}->{61888619} = "Thistle";
$areanames{en}->{6188862} = "Balaklava";
$areanames{en}->{6188863} = "Halbury";
$areanames{en}->{6188864} = "Nantawarra";
$areanames{en}->{6188865} = "Snowtown";
$areanames{en}->{6188866} = "Lochiel";
$areanames{en}->{6188867} = "Port\ Wakefield";
$areanames{en}->{6188868} = "South\ Hummocks";
$areanames{en}->{61888690} = "Wedge";
$areanames{en}->{61888691} = "Curramulka";
$areanames{en}->{61888692} = "Marion\ Bay";
$areanames{en}->{61888693} = "Minlaton";
$areanames{en}->{61888694} = "Warooka";
$areanames{en}->{61888695} = "Yorketown";
$areanames{en}->{61888696} = "Balaklava";
$areanames{en}->{61888697} = "Halbury";
$areanames{en}->{61888698} = "Lochiel";
$areanames{en}->{61888699} = "Nantawarra";
$areanames{en}->{61888700} = "Port\ Wakefield";
$areanames{en}->{61888701} = "Snowtown";
$areanames{en}->{61888702} = "South\ Hummocks";
$areanames{en}->{61888703} = "Booborowie";
$areanames{en}->{61888704} = "Braemer";
$areanames{en}->{61888705} = "Burra";
$areanames{en}->{61888706} = "Hallett";
$areanames{en}->{61888707} = "Blyth";
$areanames{en}->{61888708} = "Brinkworth";
$areanames{en}->{61888709} = "Spalding";
$areanames{en}->{61888710} = "Alford";
$areanames{en}->{61888711} = "Bute";
$areanames{en}->{61888712} = "Moonta";
$areanames{en}->{61888713} = "Paskeville";
$areanames{en}->{61888714} = "Ardrossan";
$areanames{en}->{61888715} = "Arthurton";
$areanames{en}->{61888716} = "Pine\ Point";
$areanames{en}->{61888717} = "Port\ Victoria";
$areanames{en}->{61888718} = "Curramulka";
$areanames{en}->{61888719} = "Marion\ Bay";
$areanames{en}->{61888720} = "Thistle";
$areanames{en}->{61888721} = "Wedge";
$areanames{en}->{61888722} = "Maitland";
$areanames{en}->{61888723} = "Balaklava";
$areanames{en}->{61888724} = "Clare";
$areanames{en}->{61888725} = "Kadina";
$areanames{en}->{61888726} = "Snowtown";
$areanames{en}->{61888727} = "Snowtown";
$areanames{en}->{61888728} = "South\ Hummocks";
$areanames{en}->{61888729} = "South\ Hummocks";
$areanames{en}->{61888730} = "Clare";
$areanames{en}->{61888731} = "Clare";
$areanames{en}->{61888732} = "Alford";
$areanames{en}->{61888733} = "Alford";
$areanames{en}->{61888734} = "Bute";
$areanames{en}->{61888735} = "Bute";
$areanames{en}->{61888736} = "Kadina";
$areanames{en}->{61888737} = "Kadina";
$areanames{en}->{61888738} = "Moonta";
$areanames{en}->{61888739} = "Moonta";
$areanames{en}->{61888740} = "Paskeville";
$areanames{en}->{61888741} = "Paskeville";
$areanames{en}->{61888742} = "Arthurton";
$areanames{en}->{61888743} = "Arthurton";
$areanames{en}->{61888744} = "Ardrossan";
$areanames{en}->{61888745} = "Ardrossan";
$areanames{en}->{61888746} = "Maitland";
$areanames{en}->{61888747} = "Maitland";
$areanames{en}->{61888748} = "Pine\ Point";
$areanames{en}->{61888749} = "Pine\ Point";
$areanames{en}->{61888750} = "Port\ Victoria";
$areanames{en}->{61888751} = "Port\ Victoria";
$areanames{en}->{61888752} = "Port\ Wakefield";
$areanames{en}->{61888753} = "Port\ Wakefield";
$areanames{en}->{61888754} = "Braemer";
$areanames{en}->{61888755} = "Braemer";
$areanames{en}->{61888756} = "Spalding";
$areanames{en}->{61888757} = "Spalding";
$areanames{en}->{61888758} = "Wedge";
$areanames{en}->{61888759} = "Wedge";
$areanames{en}->{61888760} = "Balaklava";
$areanames{en}->{61888761} = "Maitland";
$areanames{en}->{61888762} = "Minlaton";
$areanames{en}->{61888763} = "Curramulka";
$areanames{en}->{61888764} = "Kadina";
$areanames{en}->{61888765} = "Maitland";
$areanames{en}->{61888766} = "Booborowie";
$areanames{en}->{61888767} = "Maitland";
$areanames{en}->{61888768} = "Wedge";
$areanames{en}->{61888769} = "Halbury";
$areanames{en}->{61888770} = "Lochiel";
$areanames{en}->{61888771} = "Spalding";
$areanames{en}->{61888772} = "Paskeville";
$areanames{en}->{61888773} = "Snowtown";
$areanames{en}->{61888774} = "Kadina";
$areanames{en}->{61888775} = "Warooka";
$areanames{en}->{61888776} = "Clare";
$areanames{en}->{61888777} = "Minlaton";
$areanames{en}->{61888778} = "Balaklava";
$areanames{en}->{61888779} = "Nantawarra";
$areanames{en}->{61888780} = "Port\ Wakefield";
$areanames{en}->{61888781} = "Pine\ Point";
$areanames{en}->{61888782} = "Ardrossan";
$areanames{en}->{61888783} = "Lochiel";
$areanames{en}->{61888784} = "Blyth";
$areanames{en}->{61888785} = "Thistle";
$areanames{en}->{61888786} = "Brinkworth";
$areanames{en}->{61888787} = "Hallett";
$areanames{en}->{61888788} = "Braemer";
$areanames{en}->{61888789} = "Snowtown";
$areanames{en}->{61888790} = "South\ Hummocks";
$areanames{en}->{61888791} = "Burra";
$areanames{en}->{61888792} = "Yorketown";
$areanames{en}->{61888793} = "Halbury";
$areanames{en}->{61888794} = "Port\ Victoria";
$areanames{en}->{61888795} = "Bute";
$areanames{en}->{61888796} = "Nantawarra";
$areanames{en}->{61888797} = "South\ Hummocks";
$areanames{en}->{61888798} = "Alford";
$areanames{en}->{61888799} = "Booborowie";
$areanames{en}->{61888800} = "Braemer";
$areanames{en}->{61888801} = "Moonta";
$areanames{en}->{61888802} = "Marion\ Bay";
$areanames{en}->{61888803} = "Port\ Wakefield";
$areanames{en}->{61888804} = "Arthurton";
$areanames{en}->{61888805} = "Kadina";
$areanames{en}->{61888806} = "Curramulka";
$areanames{en}->{61888807} = "Booborowie";
$areanames{en}->{61888808} = "Maitland";
$areanames{en}->{61888809} = "Burra";
$areanames{en}->{61888810} = "Hallett";
$areanames{en}->{61888811} = "Wedge";
$areanames{en}->{61888812} = "Spalding";
$areanames{en}->{61888813} = "Paskeville";
$areanames{en}->{61888814} = "Snowtown";
$areanames{en}->{61888815} = "Kadina";
$areanames{en}->{61888816} = "Warooka";
$areanames{en}->{61888817} = "Clare";
$areanames{en}->{61888818} = "Minlaton";
$areanames{en}->{61888819} = "Blyth";
$areanames{en}->{61888820} = "Brinkworth";
$areanames{en}->{61888821} = "Balaklava";
$areanames{en}->{61888822} = "Pine\ Point";
$areanames{en}->{61888823} = "Ardrossan";
$areanames{en}->{61888824} = "Lochiel";
$areanames{en}->{61888825} = "Blyth";
$areanames{en}->{61888826} = "Thistle";
$areanames{en}->{61888827} = "Brinkworth";
$areanames{en}->{61888828} = "Hallett";
$areanames{en}->{61888829} = "Clare";
$areanames{en}->{61888830} = "Spalding";
$areanames{en}->{61888831} = "Braemer";
$areanames{en}->{61888832} = "Burra";
$areanames{en}->{61888833} = "Yorketown";
$areanames{en}->{61888834} = "Halbury";
$areanames{en}->{61888835} = "Port\ Victoria";
$areanames{en}->{61888836} = "Bute";
$areanames{en}->{61888837} = "Nantawarra";
$areanames{en}->{61888838} = "South\ Hummocks";
$areanames{en}->{61888839} = "Alford";
$areanames{en}->{61888840} = "Bute";
$areanames{en}->{61888841} = "Alford";
$areanames{en}->{61888842} = "Moonta";
$areanames{en}->{61888843} = "Marion\ Bay";
$areanames{en}->{61888844} = "Port\ Wakefield";
$areanames{en}->{61888845} = "Arthurton";
$areanames{en}->{61888846} = "Curramulka";
$areanames{en}->{61888847} = "Booborowie";
$areanames{en}->{61888848} = "Maitland";
$areanames{en}->{61888849} = "Kadina";
$areanames{en}->{61888850} = "Moonta";
$areanames{en}->{61888851} = "Wedge";
$areanames{en}->{61888852} = "Spalding";
$areanames{en}->{61888853} = "Paskeville";
$areanames{en}->{61888854} = "Snowtown";
$areanames{en}->{61888855} = "Kadina";
$areanames{en}->{61888856} = "Warooka";
$areanames{en}->{61888857} = "Clare";
$areanames{en}->{61888858} = "Minlaton";
$areanames{en}->{61888859} = "Paskeville";
$areanames{en}->{61888860} = "Ardrossan";
$areanames{en}->{61888861} = "Balaklava";
$areanames{en}->{61888862} = "Pine\ Point";
$areanames{en}->{61888863} = "Ardrossan";
$areanames{en}->{61888864} = "Lochiel";
$areanames{en}->{61888865} = "Blyth";
$areanames{en}->{61888866} = "Thistle";
$areanames{en}->{61888867} = "Brinkworth";
$areanames{en}->{61888868} = "Hallett";
$areanames{en}->{61888869} = "Arthurton";
$areanames{en}->{61888870} = "Maitland";
$areanames{en}->{61888871} = "Braemer";
$areanames{en}->{61888872} = "Burra";
$areanames{en}->{61888873} = "Yorketown";
$areanames{en}->{61888874} = "Halbury";
$areanames{en}->{61888875} = "Port\ Victoria";
$areanames{en}->{61888876} = "Bute";
$areanames{en}->{61888877} = "Nantawarra";
$areanames{en}->{61888878} = "South\ Hummocks";
$areanames{en}->{61888879} = "Pine\ Point";
$areanames{en}->{61888880} = "Port\ Victoria";
$areanames{en}->{61888881} = "Alford";
$areanames{en}->{61888882} = "Moonta";
$areanames{en}->{61888883} = "Marion\ Bay";
$areanames{en}->{61888884} = "Port\ Wakefield";
$areanames{en}->{61888885} = "Arthurton";
$areanames{en}->{61888886} = "Thistle";
$areanames{en}->{61888887} = "Moonta";
$areanames{en}->{61888888} = "Curramulka";
$areanames{en}->{61888889} = "Marion\ Bay";
$areanames{en}->{61888890} = "Minlaton";
$areanames{en}->{61888891} = "Warooka";
$areanames{en}->{61888892} = "Yorketown";
$areanames{en}->{61888893} = "Balaklava";
$areanames{en}->{61888894} = "Balaklava";
$areanames{en}->{61888895} = "Balaklava";
$areanames{en}->{61888896} = "Clare";
$areanames{en}->{61888897} = "Clare";
$areanames{en}->{61888898} = "Clare";
$areanames{en}->{61888899} = "Spalding";
$areanames{en}->{61888900} = "Burra";
$areanames{en}->{61888901} = "Burra";
$areanames{en}->{61888902} = "Burra";
$areanames{en}->{61888903} = "Booborowie";
$areanames{en}->{61888904} = "Booborowie";
$areanames{en}->{61888905} = "Booborowie";
$areanames{en}->{61888906} = "Booborowie";
$areanames{en}->{61888907} = "Hallett";
$areanames{en}->{61888908} = "Braemer";
$areanames{en}->{61888909} = "Hallett";
$areanames{en}->{61888910} = "Balaklava";
$areanames{en}->{61888911} = "Balaklava";
$areanames{en}->{61888912} = "Halbury";
$areanames{en}->{61888913} = "Halbury";
$areanames{en}->{61888914} = "Lochiel";
$areanames{en}->{61888915} = "Lochiel";
$areanames{en}->{61888916} = "Nantawarra";
$areanames{en}->{61888917} = "Nantawarra";
$areanames{en}->{61888918} = "Thistle";
$areanames{en}->{61888919} = "Thistle";
$areanames{en}->{6188892} = "Burra";
$areanames{en}->{61888926} = "Hallett";
$areanames{en}->{61888927} = "Braemer";
$areanames{en}->{61888928} = "Braemer";
$areanames{en}->{61888929} = "Hallett";
$areanames{en}->{6188893} = "Booborowie";
$areanames{en}->{6188894} = "Hallett";
$areanames{en}->{61888950} = "Balaklava";
$areanames{en}->{61888951} = "Halbury";
$areanames{en}->{61888952} = "Lochiel";
$areanames{en}->{61888953} = "Nantawarra";
$areanames{en}->{61888954} = "Port\ Wakefield";
$areanames{en}->{61888955} = "Snowtown";
$areanames{en}->{61888956} = "South\ Hummocks";
$areanames{en}->{61888957} = "Booborowie";
$areanames{en}->{61888958} = "Braemer";
$areanames{en}->{61888959} = "Burra";
$areanames{en}->{61888960} = "Hallett";
$areanames{en}->{61888961} = "Blyth";
$areanames{en}->{61888962} = "Brinkworth";
$areanames{en}->{61888963} = "Clare";
$areanames{en}->{61888964} = "Spalding";
$areanames{en}->{61888965} = "Alford";
$areanames{en}->{61888966} = "Bute";
$areanames{en}->{61888967} = "Kadina";
$areanames{en}->{61888968} = "Moonta";
$areanames{en}->{61888969} = "Paskeville";
$areanames{en}->{61888970} = "Ardrossan";
$areanames{en}->{61888971} = "Arthurton";
$areanames{en}->{61888972} = "Maitland";
$areanames{en}->{61888973} = "Pine\ Point";
$areanames{en}->{61888974} = "Port\ Victoria";
$areanames{en}->{61888975} = "Thistle";
$areanames{en}->{61888976} = "Wedge";
$areanames{en}->{61888977} = "Curramulka";
$areanames{en}->{61888978} = "Marion\ Bay";
$areanames{en}->{61888979} = "Minlaton";
$areanames{en}->{61888980} = "Booborowie";
$areanames{en}->{61888981} = "Booborowie";
$areanames{en}->{61888982} = "Burra";
$areanames{en}->{61888983} = "Burra";
$areanames{en}->{61888984} = "Curramulka";
$areanames{en}->{61888985} = "Curramulka";
$areanames{en}->{61888986} = "Hallett";
$areanames{en}->{61888987} = "Hallett";
$areanames{en}->{61888988} = "Marion\ Bay";
$areanames{en}->{61888989} = "Marion\ Bay";
$areanames{en}->{61888990} = "Blyth";
$areanames{en}->{61888991} = "Blyth";
$areanames{en}->{61888992} = "Minlaton";
$areanames{en}->{61888993} = "Minlaton";
$areanames{en}->{61888994} = "Brinkworth";
$areanames{en}->{61888995} = "Brinkworth";
$areanames{en}->{61888996} = "Warooka";
$areanames{en}->{61888997} = "Warooka";
$areanames{en}->{61888998} = "Yorketown";
$areanames{en}->{61888999} = "Yorketown";
$areanames{en}->{6188900} = "Darwin";
$areanames{en}->{6188901} = "Darwin";
$areanames{en}->{61889020} = "Alice\ Springs";
$areanames{en}->{61889021} = "Alice\ Springs";
$areanames{en}->{61889022} = "Alice\ Springs";
$areanames{en}->{61889023} = "Alyangula";
$areanames{en}->{61889024} = "Alyangula";
$areanames{en}->{61889025} = "Alyangula";
$areanames{en}->{61889026} = "Arnhem";
$areanames{en}->{61889027} = "Arnhem";
$areanames{en}->{61889028} = "Arnhem";
$areanames{en}->{61889029} = "Alice\ Springs";
$areanames{en}->{61889030} = "Arrowsmith";
$areanames{en}->{61889031} = "Arrowsmith";
$areanames{en}->{61889032} = "Arrowsmith";
$areanames{en}->{61889033} = "Batchelor";
$areanames{en}->{61889034} = "Batchelor";
$areanames{en}->{61889035} = "Batchelor";
$areanames{en}->{61889036} = "Borroloola";
$areanames{en}->{61889037} = "Borroloola";
$areanames{en}->{61889038} = "Borroloola";
$areanames{en}->{61889039} = "Davenport";
$areanames{en}->{61889040} = "Carpentaria";
$areanames{en}->{61889041} = "Carpentaria";
$areanames{en}->{61889042} = "Carpentaria";
$areanames{en}->{61889043} = "Daly";
$areanames{en}->{61889044} = "Daly";
$areanames{en}->{61889045} = "Daly";
$areanames{en}->{61889046} = "Davenport";
$areanames{en}->{61889047} = "Davenport";
$areanames{en}->{61889048} = "Davenport";
$areanames{en}->{61889049} = "Elliott";
$areanames{en}->{61889050} = "Elliott";
$areanames{en}->{61889051} = "Elliott";
$areanames{en}->{61889052} = "Elliott";
$areanames{en}->{61889053} = "Jabiru";
$areanames{en}->{61889054} = "Jabiru";
$areanames{en}->{61889055} = "Jabiru";
$areanames{en}->{61889056} = "Katherine";
$areanames{en}->{61889057} = "Katherine";
$areanames{en}->{61889058} = "Katherine";
$areanames{en}->{61889059} = "Petermann";
$areanames{en}->{61889060} = "Nhulunbuy";
$areanames{en}->{61889061} = "Nhulunbuy";
$areanames{en}->{61889062} = "Nhulunbuy";
$areanames{en}->{61889063} = "Noonamah";
$areanames{en}->{61889064} = "Noonamah";
$areanames{en}->{61889065} = "Noonamah";
$areanames{en}->{61889066} = "Petermann";
$areanames{en}->{61889067} = "Petermann";
$areanames{en}->{61889068} = "Petermann";
$areanames{en}->{61889069} = "Plenty";
$areanames{en}->{61889070} = "Pine\ Creek";
$areanames{en}->{61889071} = "Pine\ Creek";
$areanames{en}->{61889072} = "Pine\ Creek";
$areanames{en}->{61889073} = "Plenty";
$areanames{en}->{61889074} = "Plenty";
$areanames{en}->{61889075} = "Plenty";
$areanames{en}->{61889076} = "Ranken\ River";
$areanames{en}->{61889077} = "Ranken\ River";
$areanames{en}->{61889078} = "Ranken\ River";
$areanames{en}->{61889079} = "Ranken\ River";
$areanames{en}->{61889080} = "Rodinga";
$areanames{en}->{61889081} = "Rodinga";
$areanames{en}->{61889082} = "Rodinga";
$areanames{en}->{61889083} = "Roper\ River";
$areanames{en}->{61889084} = "Roper\ River";
$areanames{en}->{61889085} = "Roper\ River";
$areanames{en}->{61889086} = "Simpson";
$areanames{en}->{61889087} = "Simpson";
$areanames{en}->{61889088} = "Simpson";
$areanames{en}->{61889089} = "Rodinga";
$areanames{en}->{61889090} = "Tablelands";
$areanames{en}->{61889091} = "Tablelands";
$areanames{en}->{61889092} = "Tablelands";
$areanames{en}->{61889093} = "Tanami";
$areanames{en}->{61889094} = "Tanami";
$areanames{en}->{61889095} = "Tanami";
$areanames{en}->{61889096} = "Tennant\ Creek";
$areanames{en}->{61889097} = "Tennant\ Creek";
$areanames{en}->{61889098} = "Tennant\ Creek";
$areanames{en}->{61889099} = "Simpson";
$areanames{en}->{61889100} = "Tiwi";
$areanames{en}->{61889101} = "Tiwi";
$areanames{en}->{61889102} = "Tiwi";
$areanames{en}->{61889103} = "Victoria\ River";
$areanames{en}->{61889104} = "Victoria\ River";
$areanames{en}->{61889105} = "Victoria\ River";
$areanames{en}->{61889106} = "Yulara";
$areanames{en}->{61889107} = "Yulara";
$areanames{en}->{61889108} = "Yulara";
$areanames{en}->{61889109} = "Tablelands";
$areanames{en}->{61889110} = "Darwin";
$areanames{en}->{61889111} = "Darwin";
$areanames{en}->{61889112} = "Tanami";
$areanames{en}->{61889113} = "Tennant\ Creek";
$areanames{en}->{61889114} = "Yulara";
$areanames{en}->{61889115} = "Alyangula";
$areanames{en}->{61889116} = "Arnhem";
$areanames{en}->{61889117} = "Batchelor";
$areanames{en}->{61889118} = "Borroloola";
$areanames{en}->{61889119} = "Carpentaria";
$areanames{en}->{61889120} = "Alice\ Springs";
$areanames{en}->{61889121} = "Daly";
$areanames{en}->{61889122} = "Darwin";
$areanames{en}->{61889123} = "Jabiru";
$areanames{en}->{61889124} = "Katherine";
$areanames{en}->{61889125} = "Nhulunbuy";
$areanames{en}->{61889126} = "Noonamah";
$areanames{en}->{61889127} = "Pine\ Creek";
$areanames{en}->{61889128} = "Roper\ River";
$areanames{en}->{61889129} = "Tiwi";
$areanames{en}->{61889130} = "Alice\ Springs";
$areanames{en}->{61889131} = "Davenport";
$areanames{en}->{61889132} = "Elliott";
$areanames{en}->{61889133} = "Petermann";
$areanames{en}->{61889134} = "Plenty";
$areanames{en}->{61889135} = "Ranken\ River";
$areanames{en}->{61889136} = "Rodinga";
$areanames{en}->{61889137} = "Simpson";
$areanames{en}->{61889138} = "Tablelands";
$areanames{en}->{61889139} = "Tanami";
$areanames{en}->{6188914} = "Darwin";
$areanames{en}->{61889150} = "Tennant\ Creek";
$areanames{en}->{61889151} = "Yulara";
$areanames{en}->{61889152} = "Alyangula";
$areanames{en}->{61889153} = "Arnhem";
$areanames{en}->{61889154} = "Batchelor";
$areanames{en}->{61889155} = "Borroloola";
$areanames{en}->{61889156} = "Carpentaria";
$areanames{en}->{61889157} = "Daly";
$areanames{en}->{61889158} = "Davenport";
$areanames{en}->{61889159} = "Jabiru";
$areanames{en}->{61889160} = "Katherine";
$areanames{en}->{61889161} = "Nhulunbuy";
$areanames{en}->{61889162} = "Noonamah";
$areanames{en}->{61889163} = "Pine\ Creek";
$areanames{en}->{61889164} = "Roper\ River";
$areanames{en}->{61889165} = "Tiwi";
$areanames{en}->{61889166} = "Victoria\ River";
$areanames{en}->{61889167} = "Darwin";
$areanames{en}->{61889168} = "Darwin";
$areanames{en}->{61889169} = "Darwin";
$areanames{en}->{61889170} = "Darwin";
$areanames{en}->{61889171} = "Darwin";
$areanames{en}->{61889172} = "Ranken\ River";
$areanames{en}->{61889173} = "Rodinga";
$areanames{en}->{61889174} = "Simpson";
$areanames{en}->{61889175} = "Tablelands";
$areanames{en}->{61889176} = "Tanami";
$areanames{en}->{61889177} = "Tennant\ Creek";
$areanames{en}->{61889178} = "Yulara";
$areanames{en}->{61889179} = "Alyangula";
$areanames{en}->{61889180} = "Arnhem";
$areanames{en}->{61889181} = "Batchelor";
$areanames{en}->{61889182} = "Borroloola";
$areanames{en}->{61889183} = "Carpentaria";
$areanames{en}->{61889184} = "Daly";
$areanames{en}->{61889185} = "Jabiru";
$areanames{en}->{61889186} = "Katherine";
$areanames{en}->{61889187} = "Nhulunbuy";
$areanames{en}->{61889188} = "Noonamah";
$areanames{en}->{61889189} = "Pine\ Creek";
$areanames{en}->{6188919} = "Darwin";
$areanames{en}->{618892} = "Darwin";
$areanames{en}->{61889210} = "Victoria\ River";
$areanames{en}->{61889213} = "Alice\ Springs";
$areanames{en}->{61889214} = "Alice\ Springs";
$areanames{en}->{61889215} = "Roper\ River";
$areanames{en}->{61889216} = "Tiwi";
$areanames{en}->{61889217} = "Victoria\ River";
$areanames{en}->{61889219} = "Elliott";
$areanames{en}->{61889260} = "Petermann";
$areanames{en}->{61889261} = "Plenty";
$areanames{en}->{61889262} = "Ranken\ River";
$areanames{en}->{61889263} = "Rodinga";
$areanames{en}->{61889264} = "Simpson";
$areanames{en}->{61889265} = "Tablelands";
$areanames{en}->{61889266} = "Tanami";
$areanames{en}->{61889267} = "Tennant\ Creek";
$areanames{en}->{61889268} = "Yulara";
$areanames{en}->{61889269} = "Alyangula";
$areanames{en}->{6188929} = "Alice\ Springs";
$areanames{en}->{6188930} = "Darwin";
$areanames{en}->{6188931} = "Darwin";
$areanames{en}->{6188932} = "Darwin";
$areanames{en}->{61889330} = "Davenport";
$areanames{en}->{61889331} = "Elliott";
$areanames{en}->{61889332} = "Petermann";
$areanames{en}->{61889333} = "Plenty";
$areanames{en}->{61889334} = "Ranken\ River";
$areanames{en}->{61889335} = "Rodinga";
$areanames{en}->{61889336} = "Simpson";
$areanames{en}->{61889337} = "Tablelands";
$areanames{en}->{61889338} = "Tanami";
$areanames{en}->{61889339} = "Tennant\ Creek";
$areanames{en}->{61889340} = "Yulara";
$areanames{en}->{61889341} = "Alyangula";
$areanames{en}->{61889342} = "Arnhem";
$areanames{en}->{61889343} = "Batchelor";
$areanames{en}->{61889344} = "Borroloola";
$areanames{en}->{61889345} = "Carpentaria";
$areanames{en}->{61889346} = "Daly";
$areanames{en}->{61889347} = "Jabiru";
$areanames{en}->{61889348} = "Katherine";
$areanames{en}->{61889349} = "Nhulunbuy";
$areanames{en}->{6188935} = "Darwin";
$areanames{en}->{6188936} = "Darwin";
$areanames{en}->{61889370} = "Noonamah";
$areanames{en}->{61889371} = "Pine\ Creek";
$areanames{en}->{61889372} = "Roper\ River";
$areanames{en}->{61889373} = "Tiwi";
$areanames{en}->{61889374} = "Victoria\ River";
$areanames{en}->{61889375} = "Arnhem";
$areanames{en}->{61889376} = "Batchelor";
$areanames{en}->{61889377} = "Borroloola";
$areanames{en}->{61889378} = "Carpentaria";
$areanames{en}->{61889379} = "Daly";
$areanames{en}->{61889380} = "Jabiru";
$areanames{en}->{61889381} = "Jabiru";
$areanames{en}->{61889382} = "Nhulunbuy";
$areanames{en}->{61889383} = "Jabiru";
$areanames{en}->{61889384} = "Pine\ Creek";
$areanames{en}->{61889385} = "Roper\ River";
$areanames{en}->{61889386} = "Tiwi";
$areanames{en}->{61889387} = "Victoria\ River";
$areanames{en}->{61889388} = "Alice\ Springs";
$areanames{en}->{61889389} = "Davenport";
$areanames{en}->{61889390} = "Darwin";
$areanames{en}->{61889391} = "Nhulunbuy";
$areanames{en}->{61889392} = "Nhulunbuy";
$areanames{en}->{61889393} = "Nhulunbuy";
$areanames{en}->{61889394} = "Tiwi";
$areanames{en}->{61889395} = "Noonamah";
$areanames{en}->{61889396} = "Batchelor";
$areanames{en}->{61889397} = "Batchelor";
$areanames{en}->{61889398} = "Daly";
$areanames{en}->{61889399} = "Daly";
$areanames{en}->{618894} = "Darwin";
$areanames{en}->{61889400} = "Elliott";
$areanames{en}->{61889401} = "Petermann";
$areanames{en}->{61889402} = "Plenty";
$areanames{en}->{61889403} = "Ranken\ River";
$areanames{en}->{61889404} = "Rodinga";
$areanames{en}->{61889405} = "Simpson";
$areanames{en}->{61889406} = "Tablelands";
$areanames{en}->{61889407} = "Tanami";
$areanames{en}->{61889408} = "Tennant\ Creek";
$areanames{en}->{61889409} = "Yulara";
$areanames{en}->{61889490} = "Alyangula";
$areanames{en}->{61889491} = "Arnhem";
$areanames{en}->{61889492} = "Batchelor";
$areanames{en}->{61889493} = "Borroloola";
$areanames{en}->{61889494} = "Carpentaria";
$areanames{en}->{61889495} = "Daly";
$areanames{en}->{61889497} = "Jabiru";
$areanames{en}->{61889498} = "Katherine";
$areanames{en}->{61889499} = "Nhulunbuy";
$areanames{en}->{618895} = "Alice\ Springs";
$areanames{en}->{6188954} = "Petermann";
$areanames{en}->{61889557} = "Petermann";
$areanames{en}->{61889558} = "Petermann";
$areanames{en}->{61889559} = "Petermann";
$areanames{en}->{61889560} = "Rodinga";
$areanames{en}->{61889561} = "Yulara";
$areanames{en}->{61889562} = "Yulara\/Petermann";
$areanames{en}->{61889563} = "Yulara";
$areanames{en}->{61889564} = "Tanami";
$areanames{en}->{61889565} = "Tanami";
$areanames{en}->{61889566} = "Simpson";
$areanames{en}->{61889567} = "Petermann";
$areanames{en}->{61889568} = "Tanami";
$areanames{en}->{61889569} = "Plenty";
$areanames{en}->{61889570} = "Plenty";
$areanames{en}->{61889571} = "Plenty";
$areanames{en}->{61889572} = "Yulara";
$areanames{en}->{61889573} = "Rodinga";
$areanames{en}->{61889574} = "Simpson";
$areanames{en}->{61889575} = "Simpson";
$areanames{en}->{61889576} = "Yulara";
$areanames{en}->{61889577} = "Yulara";
$areanames{en}->{61889578} = "Tanami";
$areanames{en}->{61889579} = "Tanami";
$areanames{en}->{61889600} = "Noonamah";
$areanames{en}->{61889601} = "Pine\ Creek";
$areanames{en}->{61889602} = "Roper\ River";
$areanames{en}->{61889603} = "Tiwi";
$areanames{en}->{61889604} = "Victoria\ River";
$areanames{en}->{61889605} = "Alice\ Springs";
$areanames{en}->{61889606} = "Davenport";
$areanames{en}->{61889607} = "Elliott";
$areanames{en}->{61889608} = "Petermann";
$areanames{en}->{61889609} = "Plenty";
$areanames{en}->{61889610} = "Elliott";
$areanames{en}->{61889611} = "Petermann";
$areanames{en}->{61889612} = "Plenty";
$areanames{en}->{61889613} = "Ranken\ River";
$areanames{en}->{61889614} = "Rodinga";
$areanames{en}->{61889615} = "Simpson";
$areanames{en}->{61889616} = "Tablelands";
$areanames{en}->{61889617} = "Tanami";
$areanames{en}->{61889618} = "Tennant\ Creek";
$areanames{en}->{61889619} = "Alyangula";
$areanames{en}->{6188962} = "Tennant\ Creek";
$areanames{en}->{61889629} = "Elliott";
$areanames{en}->{61889630} = "Tennant\ Creek";
$areanames{en}->{61889631} = "Alice\ Springs";
$areanames{en}->{61889632} = "Tennant\ Creek";
$areanames{en}->{61889633} = "Tennant\ Creek";
$areanames{en}->{61889634} = "Ranken\ River";
$areanames{en}->{61889635} = "Darwin";
$areanames{en}->{61889636} = "Katherine";
$areanames{en}->{61889637} = "Katherine";
$areanames{en}->{61889638} = "Tablelands";
$areanames{en}->{61889639} = "Davenport";
$areanames{en}->{61889640} = "Davenport";
$areanames{en}->{61889641} = "Davenport";
$areanames{en}->{61889642} = "Davenport";
$areanames{en}->{61889643} = "Tablelands";
$areanames{en}->{61889644} = "Tablelands";
$areanames{en}->{61889645} = "Ranken\ River";
$areanames{en}->{61889646} = "Tanami";
$areanames{en}->{61889647} = "Tanami";
$areanames{en}->{61889648} = "Tanami";
$areanames{en}->{61889649} = "Tanami";
$areanames{en}->{61889650} = "Alice\ Springs";
$areanames{en}->{61889651} = "Katherine";
$areanames{en}->{61889652} = "Nhulunbuy";
$areanames{en}->{61889653} = "Tennant\ Creek";
$areanames{en}->{61889654} = "Darwin";
$areanames{en}->{61889655} = "Arnhem";
$areanames{en}->{61889656} = "Batchelor";
$areanames{en}->{61889657} = "Borroloola";
$areanames{en}->{61889658} = "Carpentaria";
$areanames{en}->{61889659} = "Daly";
$areanames{en}->{61889660} = "Rodinga";
$areanames{en}->{61889661} = "Jabiru";
$areanames{en}->{61889662} = "Katherine";
$areanames{en}->{61889663} = "Nhulunbuy";
$areanames{en}->{61889664} = "Noonamah";
$areanames{en}->{61889665} = "Pine\ Creek";
$areanames{en}->{61889666} = "Roper\ River";
$areanames{en}->{61889667} = "Tiwi";
$areanames{en}->{61889668} = "Victoria\ River";
$areanames{en}->{61889669} = "Plenty";
$areanames{en}->{61889670} = "Alice\ Springs";
$areanames{en}->{61889671} = "Darwin";
$areanames{en}->{61889672} = "Alice\ Springs";
$areanames{en}->{61889673} = "Alice\ Springs";
$areanames{en}->{61889674} = "Arnhem";
$areanames{en}->{61889675} = "Arnhem";
$areanames{en}->{61889676} = "Victoria\ River";
$areanames{en}->{61889677} = "Victoria\ River";
$areanames{en}->{61889678} = "Jabiru";
$areanames{en}->{61889679} = "Jabiru";
$areanames{en}->{61889680} = "Noonamah";
$areanames{en}->{61889681} = "Noonamah";
$areanames{en}->{61889682} = "Tanami";
$areanames{en}->{61889683} = "Alice\ Springs";
$areanames{en}->{61889684} = "Alice\ Springs";
$areanames{en}->{61889685} = "Alice\ Springs";
$areanames{en}->{61889686} = "Tanami";
$areanames{en}->{61889687} = "Tanami";
$areanames{en}->{61889688} = "Nhulunbuy";
$areanames{en}->{61889689} = "Darwin";
$areanames{en}->{6188969} = "Elliott";
$areanames{en}->{6188970} = "Arnhem";
$areanames{en}->{61889706} = "Tiwi";
$areanames{en}->{61889707} = "Tiwi";
$areanames{en}->{61889708} = "Tiwi";
$areanames{en}->{61889709} = "Tiwi";
$areanames{en}->{6188971} = "Katherine";
$areanames{en}->{6188972} = "Katherine";
$areanames{en}->{6188973} = "Katherine";
$areanames{en}->{6188974} = "Katherine";
$areanames{en}->{61889745} = "Victoria\ River";
$areanames{en}->{61889747} = "Pine\ Creek";
$areanames{en}->{61889749} = "Carpentaria";
$areanames{en}->{61889750} = "Victoria\ River";
$areanames{en}->{61889751} = "Victoria\ River";
$areanames{en}->{61889752} = "Victoria\ River";
$areanames{en}->{61889753} = "Daly";
$areanames{en}->{61889754} = "Roper\ River";
$areanames{en}->{61889755} = "Carpentaria";
$areanames{en}->{61889756} = "Borroloola";
$areanames{en}->{61889757} = "Borroloola";
$areanames{en}->{61889758} = "Borroloola";
$areanames{en}->{61889759} = "Carpentaria";
$areanames{en}->{6188976} = "Batchelor";
$areanames{en}->{61889761} = "Pine\ Creek";
$areanames{en}->{61889768} = "Pine\ Creek";
$areanames{en}->{61889769} = "Pine\ Creek";
$areanames{en}->{61889770} = "Victoria\ River";
$areanames{en}->{61889771} = "Victoria\ River";
$areanames{en}->{61889772} = "Roper\ River";
$areanames{en}->{61889773} = "Roper\ River";
$areanames{en}->{61889774} = "Roper\ River";
$areanames{en}->{61889775} = "Roper\ River";
$areanames{en}->{61889776} = "Roper\ River";
$areanames{en}->{61889777} = "Daly";
$areanames{en}->{61889778} = "Daly";
$areanames{en}->{61889779} = "Daly";
$areanames{en}->{61889780} = "Daly";
$areanames{en}->{61889781} = "Daly";
$areanames{en}->{61889782} = "Daly";
$areanames{en}->{61889783} = "Tiwi";
$areanames{en}->{61889784} = "Noonamah";
$areanames{en}->{61889785} = "Darwin";
$areanames{en}->{61889786} = "Roper\ River";
$areanames{en}->{61889787} = "Arnhem";
$areanames{en}->{61889788} = "Arnhem";
$areanames{en}->{61889789} = "Arnhem";
$areanames{en}->{6188979} = "Arnhem";
$areanames{en}->{61889792} = "Jabiru";
$areanames{en}->{61889793} = "Jabiru";
$areanames{en}->{61889794} = "Jabiru";
$areanames{en}->{61889799} = "Jabiru";
$areanames{en}->{618898} = "Darwin";
$areanames{en}->{61889847} = "Noonamah";
$areanames{en}->{61889848} = "Noonamah";
$areanames{en}->{61889849} = "Noonamah";
$areanames{en}->{6188986} = "Noonamah";
$areanames{en}->{61889860} = "Katherine";
$areanames{en}->{61889868} = "Nhulunbuy";
$areanames{en}->{61889869} = "Davenport";
$areanames{en}->{6188987} = "Nhulunbuy";
$areanames{en}->{61889874} = "Alyangula";
$areanames{en}->{61889876} = "Alyangula";
$areanames{en}->{61889877} = "Alyangula";
$areanames{en}->{61889879} = "Arnhem";
$areanames{en}->{6188988} = "Noonamah";
$areanames{en}->{61889900} = "Alice\ Springs";
$areanames{en}->{61889901} = "Davenport";
$areanames{en}->{61889902} = "Elliott";
$areanames{en}->{61889903} = "Petermann";
$areanames{en}->{61889904} = "Plenty";
$areanames{en}->{61889905} = "Ranken\ River";
$areanames{en}->{61889906} = "Rodinga";
$areanames{en}->{61889907} = "Simpson";
$areanames{en}->{61889908} = "Tablelands";
$areanames{en}->{61889909} = "Tanami";
$areanames{en}->{61889910} = "Tennant\ Creek";
$areanames{en}->{61889911} = "Yulara";
$areanames{en}->{61889912} = "Alyangula";
$areanames{en}->{61889913} = "Arnhem";
$areanames{en}->{61889914} = "Batchelor";
$areanames{en}->{61889915} = "Borroloola";
$areanames{en}->{61889916} = "Carpentaria";
$areanames{en}->{61889917} = "Daly";
$areanames{en}->{61889918} = "Darwin";
$areanames{en}->{61889919} = "Jabiru";
$areanames{en}->{61889920} = "Katherine";
$areanames{en}->{61889921} = "Nhulunbuy";
$areanames{en}->{61889922} = "Noonamah";
$areanames{en}->{61889923} = "Pine\ Creek";
$areanames{en}->{61889924} = "Roper\ River";
$areanames{en}->{61889925} = "Tiwi";
$areanames{en}->{61889926} = "Victoria\ River";
$areanames{en}->{61889927} = "Darwin";
$areanames{en}->{61889928} = "Darwin";
$areanames{en}->{61889929} = "Darwin";
$areanames{en}->{6188993} = "Tanami";
$areanames{en}->{61889940} = "Yulara";
$areanames{en}->{61889941} = "Darwin";
$areanames{en}->{61889942} = "Tennant\ Creek";
$areanames{en}->{61889943} = "Tennant\ Creek";
$areanames{en}->{61889944} = "Darwin";
$areanames{en}->{61889945} = "Katherine";
$areanames{en}->{61889946} = "Katherine";
$areanames{en}->{61889947} = "Yulara";
$areanames{en}->{61889948} = "Yulara";
$areanames{en}->{61889949} = "Yulara";
$areanames{en}->{6188995} = "Darwin";
$areanames{en}->{61889960} = "Tanami";
$areanames{en}->{61889961} = "Tanami";
$areanames{en}->{61889962} = "Nhulunbuy";
$areanames{en}->{61889963} = "Nhulunbuy";
$areanames{en}->{61889964} = "Alyangula";
$areanames{en}->{61889965} = "Alyangula";
$areanames{en}->{61889966} = "Alyangula";
$areanames{en}->{61889967} = "Jabiru";
$areanames{en}->{61889968} = "Nhulunbuy";
$areanames{en}->{61889969} = "Alice\ Springs";
$areanames{en}->{6188997} = "Darwin";
$areanames{en}->{6188998} = "Darwin";
$areanames{en}->{6188999} = "Darwin";
$areanames{en}->{61890000} = "Kalgoorlie";
$areanames{en}->{61890001} = "Kalgoorlie";
$areanames{en}->{61890002} = "Kalgoorlie";
$areanames{en}->{61890003} = "Kalgoorlie";
$areanames{en}->{61890004} = "Ardath";
$areanames{en}->{61890005} = "Ardath";
$areanames{en}->{61890006} = "Ardath";
$areanames{en}->{61890007} = "Baandee";
$areanames{en}->{61890008} = "Baandee";
$areanames{en}->{61890009} = "Baandee";
$areanames{en}->{61890010} = "Belka\ East";
$areanames{en}->{61890011} = "Belka\ East";
$areanames{en}->{61890012} = "Belka\ East";
$areanames{en}->{61890013} = "Bodallin";
$areanames{en}->{61890014} = "Bodallin";
$areanames{en}->{61890015} = "Bodallin";
$areanames{en}->{61890016} = "Bodallin\ North";
$areanames{en}->{61890017} = "Bodallin\ North";
$areanames{en}->{61890018} = "Bodallin\ North";
$areanames{en}->{61890019} = "Narembeen";
$areanames{en}->{61890020} = "Bonnie\ Rock";
$areanames{en}->{61890021} = "Bonnie\ Rock";
$areanames{en}->{61890022} = "Bonnie\ Rock";
$areanames{en}->{61890023} = "Bruce\ Rock";
$areanames{en}->{61890024} = "Bruce\ Rock";
$areanames{en}->{61890025} = "Bruce\ Rock";
$areanames{en}->{61890026} = "Bullaring";
$areanames{en}->{61890027} = "Bullaring";
$areanames{en}->{61890028} = "Bullaring";
$areanames{en}->{61890029} = "Narembeen\ East";
$areanames{en}->{61890030} = "Bullfinch";
$areanames{en}->{61890031} = "Bullfinch";
$areanames{en}->{61890032} = "Bullfinch";
$areanames{en}->{61890033} = "Burracoppin";
$areanames{en}->{61890034} = "Burracoppin";
$areanames{en}->{61890035} = "Burracoppin";
$areanames{en}->{61890036} = "Burracoppin\ South";
$areanames{en}->{61890037} = "Burracoppin\ South";
$areanames{en}->{61890038} = "Burracoppin\ South";
$areanames{en}->{61890039} = "Shackleton";
$areanames{en}->{61890040} = "Cascade";
$areanames{en}->{61890041} = "Cascade";
$areanames{en}->{61890042} = "Cascade";
$areanames{en}->{61890043} = "Collurabbie";
$areanames{en}->{61890044} = "Collurabbie";
$areanames{en}->{61890045} = "Collurabbie";
$areanames{en}->{61890046} = "Condingup";
$areanames{en}->{61890047} = "Condingup";
$areanames{en}->{61890048} = "Condingup";
$areanames{en}->{61890049} = "South\ Kumminin";
$areanames{en}->{61890050} = "Coomalbidgup";
$areanames{en}->{61890051} = "Coomalbidgup";
$areanames{en}->{61890052} = "Coomalbidgup";
$areanames{en}->{61890053} = "Corrigin";
$areanames{en}->{61890054} = "Corrigin";
$areanames{en}->{61890055} = "Corrigin";
$areanames{en}->{61890056} = "Corrigin\ West";
$areanames{en}->{61890057} = "Corrigin\ West";
$areanames{en}->{61890058} = "Corrigin\ West";
$areanames{en}->{61890059} = "Ardath";
$areanames{en}->{61890060} = "Dulyalbin";
$areanames{en}->{61890061} = "Dulyalbin";
$areanames{en}->{61890062} = "Dulyalbin";
$areanames{en}->{61890063} = "Dundas";
$areanames{en}->{61890064} = "Dundas";
$areanames{en}->{61890065} = "Dundas";
$areanames{en}->{61890066} = "Esperance";
$areanames{en}->{61890067} = "Esperance";
$areanames{en}->{61890068} = "Esperance";
$areanames{en}->{61890069} = "Belka\ East";
$areanames{en}->{61890070} = "Eyre";
$areanames{en}->{61890071} = "Eyre";
$areanames{en}->{61890072} = "Eyre";
$areanames{en}->{61890073} = "Gibson";
$areanames{en}->{61890074} = "Gibson";
$areanames{en}->{61890075} = "Gibson";
$areanames{en}->{61890076} = "Goldfields";
$areanames{en}->{61890077} = "Goldfields";
$areanames{en}->{61890078} = "Goldfields";
$areanames{en}->{61890079} = "Bruce\ Rock";
$areanames{en}->{61890080} = "Goomarin";
$areanames{en}->{61890081} = "Goomarin";
$areanames{en}->{61890082} = "Goomarin";
$areanames{en}->{61890083} = "Grass\ Patch";
$areanames{en}->{61890084} = "Grass\ Patch";
$areanames{en}->{61890085} = "Grass\ Patch";
$areanames{en}->{61890086} = "Great\ Victoria";
$areanames{en}->{61890087} = "Great\ Victoria";
$areanames{en}->{61890088} = "Great\ Victoria";
$areanames{en}->{61890089} = "Bullaring";
$areanames{en}->{61890090} = "Holleton";
$areanames{en}->{61890091} = "Holleton";
$areanames{en}->{61890092} = "Holleton";
$areanames{en}->{61890093} = "Kalgoorlie";
$areanames{en}->{61890094} = "Kalgoorlie";
$areanames{en}->{61890095} = "Kalgoorlie";
$areanames{en}->{61890096} = "Kambalda";
$areanames{en}->{61890097} = "Kambalda";
$areanames{en}->{61890098} = "Kambalda";
$areanames{en}->{61890099} = "Corrigin";
$areanames{en}->{61890100} = "Karloning";
$areanames{en}->{61890101} = "Karloning";
$areanames{en}->{61890102} = "Karloning";
$areanames{en}->{61890103} = "Kellerberrin";
$areanames{en}->{61890104} = "Kellerberrin";
$areanames{en}->{61890105} = "Kellerberrin";
$areanames{en}->{61890106} = "Korbelka";
$areanames{en}->{61890107} = "Korbelka";
$areanames{en}->{61890108} = "Korbelka";
$areanames{en}->{61890109} = "Corrigin\ West";
$areanames{en}->{61890110} = "Laverton";
$areanames{en}->{61890111} = "Laverton";
$areanames{en}->{61890112} = "Laverton";
$areanames{en}->{61890113} = "Leinster";
$areanames{en}->{61890114} = "Leinster";
$areanames{en}->{61890115} = "Leinster";
$areanames{en}->{61890116} = "Leonora";
$areanames{en}->{61890117} = "Leonora";
$areanames{en}->{61890118} = "Leonora";
$areanames{en}->{61890119} = "Holleton";
$areanames{en}->{61890120} = "Marvel\ Loch";
$areanames{en}->{61890121} = "Marvel\ Loch";
$areanames{en}->{61890122} = "Marvel\ Loch";
$areanames{en}->{61890123} = "Merredin";
$areanames{en}->{61890124} = "Merredin";
$areanames{en}->{61890125} = "Merredin";
$areanames{en}->{61890126} = "Mount\ Beaumont";
$areanames{en}->{61890127} = "Mount\ Beaumont";
$areanames{en}->{61890128} = "Mount\ Beaumont";
$areanames{en}->{61890129} = "Mount\ Walker\ South";
$areanames{en}->{61890130} = "Mount\ Hampton";
$areanames{en}->{61890131} = "Mount\ Hampton";
$areanames{en}->{61890132} = "Mount\ Hampton";
$areanames{en}->{61890133} = "Mount\ Merivale";
$areanames{en}->{61890134} = "Mount\ Merivale";
$areanames{en}->{61890135} = "Mount\ Merivale";
$areanames{en}->{61890136} = "Mount\ Stirling";
$areanames{en}->{61890137} = "Mount\ Stirling";
$areanames{en}->{61890138} = "Mount\ Stirling";
$areanames{en}->{61890139} = "Muntadgin\ East";
$areanames{en}->{61890140} = "Mount\ Walker\ South";
$areanames{en}->{61890141} = "Mount\ Walker\ South";
$areanames{en}->{61890142} = "Mount\ Walker\ South";
$areanames{en}->{61890143} = "Mukinbudin";
$areanames{en}->{61890144} = "Mukinbudin";
$areanames{en}->{61890145} = "Mukinbudin";
$areanames{en}->{61890146} = "Munglinup";
$areanames{en}->{61890147} = "Munglinup";
$areanames{en}->{61890148} = "Munglinup";
$areanames{en}->{61890149} = "Great\ Victoria";
$areanames{en}->{61890150} = "Muntadgin\ East";
$areanames{en}->{61890151} = "Muntadgin\ East";
$areanames{en}->{61890152} = "Muntadgin\ East";
$areanames{en}->{61890153} = "Narembeen";
$areanames{en}->{61890154} = "Narembeen";
$areanames{en}->{61890155} = "Narembeen";
$areanames{en}->{61890156} = "Narembeen\ East";
$areanames{en}->{61890157} = "Narembeen\ East";
$areanames{en}->{61890158} = "Narembeen\ East";
$areanames{en}->{61890159} = "Mount\ Beaumont";
$areanames{en}->{61890160} = "Neridup";
$areanames{en}->{61890161} = "Neridup";
$areanames{en}->{61890162} = "Neridup";
$areanames{en}->{61890163} = "Norseman";
$areanames{en}->{61890164} = "Norseman";
$areanames{en}->{61890165} = "Norseman";
$areanames{en}->{61890166} = "Nullarbor";
$areanames{en}->{61890167} = "Nullarbor";
$areanames{en}->{61890168} = "Nullarbor";
$areanames{en}->{61890169} = "Mount\ Merivale";
$areanames{en}->{61890170} = "Nungarin";
$areanames{en}->{61890171} = "Nungarin";
$areanames{en}->{61890172} = "Nungarin";
$areanames{en}->{61890173} = "Salmon\ Gums";
$areanames{en}->{61890174} = "Salmon\ Gums";
$areanames{en}->{61890175} = "Salmon\ Gums";
$areanames{en}->{61890176} = "Scaddan\ West";
$areanames{en}->{61890177} = "Scaddan\ West";
$areanames{en}->{61890178} = "Scaddan\ West";
$areanames{en}->{61890179} = "Munglinup";
$areanames{en}->{61890180} = "Shackleton";
$areanames{en}->{61890181} = "Shackleton";
$areanames{en}->{61890182} = "Shackleton";
$areanames{en}->{61890183} = "South\ Kumminin";
$areanames{en}->{61890184} = "South\ Kumminin";
$areanames{en}->{61890185} = "South\ Kumminin";
$areanames{en}->{61890186} = "Southern\ Cross";
$areanames{en}->{61890187} = "Southern\ Cross";
$areanames{en}->{61890188} = "Southern\ Cross";
$areanames{en}->{61890189} = "Neridup";
$areanames{en}->{61890190} = "Speddingup\ East";
$areanames{en}->{61890191} = "Speddingup\ East";
$areanames{en}->{61890192} = "Speddingup\ East";
$areanames{en}->{61890193} = "Warralakin";
$areanames{en}->{61890194} = "Warralakin";
$areanames{en}->{61890195} = "Warralakin";
$areanames{en}->{61890196} = "Westonia";
$areanames{en}->{61890197} = "Westonia";
$areanames{en}->{61890198} = "Westonia";
$areanames{en}->{61890199} = "Norseman";
$areanames{en}->{61890200} = "Kalgoorlie";
$areanames{en}->{61890201} = "Norseman";
$areanames{en}->{61890202} = "Norseman";
$areanames{en}->{61890203} = "Kellerberrin";
$areanames{en}->{61890204} = "Kellerberrin";
$areanames{en}->{61890205} = "Merredin";
$areanames{en}->{61890206} = "Merredin";
$areanames{en}->{61890208} = "Kambalda";
$areanames{en}->{61890209} = "Kambalda";
$areanames{en}->{6189021} = "Kalgoorlie";
$areanames{en}->{6189022} = "Kalgoorlie";
$areanames{en}->{61890226} = "Nullarbor";
$areanames{en}->{61890230} = "Wialki\ North";
$areanames{en}->{61890231} = "Wialki\ North";
$areanames{en}->{61890232} = "Wialki\ North";
$areanames{en}->{61890233} = "Wilgoyne";
$areanames{en}->{61890234} = "Wilgoyne";
$areanames{en}->{61890235} = "Wilgoyne";
$areanames{en}->{61890236} = "Yilgarn\ South";
$areanames{en}->{61890237} = "Yilgarn\ South";
$areanames{en}->{61890238} = "Yilgarn\ South";
$areanames{en}->{61890239} = "Nullarbor";
$areanames{en}->{61890240} = "Goldfields";
$areanames{en}->{61890241} = "Kalgoorlie";
$areanames{en}->{61890242} = "Goldfields";
$areanames{en}->{61890243} = "Goldfields";
$areanames{en}->{61890244} = "Corrigin";
$areanames{en}->{61890245} = "Corrigin";
$areanames{en}->{61890246} = "Kalgoorlie";
$areanames{en}->{61890247} = "Kalgoorlie";
$areanames{en}->{61890248} = "Goldfields";
$areanames{en}->{61890249} = "Goldfields";
$areanames{en}->{61890250} = "Kalgoorlie";
$areanames{en}->{61890251} = "Kalgoorlie";
$areanames{en}->{61890252} = "Kalgoorlie";
$areanames{en}->{61890253} = "Kalgoorlie";
$areanames{en}->{61890254} = "Salmon\ Gums";
$areanames{en}->{61890255} = "Scaddan\ West";
$areanames{en}->{61890256} = "Speddingup\ East";
$areanames{en}->{61890257} = "Esperance";
$areanames{en}->{61890258} = "Eyre";
$areanames{en}->{61890259} = "Gibson";
$areanames{en}->{6189026} = "Kalgoorlie";
$areanames{en}->{61890265} = "Leinster";
$areanames{en}->{61890268} = "Collurabbie";
$areanames{en}->{61890269} = "Collurabbie";
$areanames{en}->{6189027} = "Kambalda";
$areanames{en}->{61890274} = "Goldfields";
$areanames{en}->{61890275} = "Goldfields";
$areanames{en}->{61890277} = "Nullarbor";
$areanames{en}->{61890280} = "Goldfields";
$areanames{en}->{61890281} = "Grass\ Patch";
$areanames{en}->{61890282} = "Kalgoorlie";
$areanames{en}->{61890283} = "Kambalda";
$areanames{en}->{61890284} = "Laverton";
$areanames{en}->{61890285} = "Leinster";
$areanames{en}->{61890286} = "Leonora";
$areanames{en}->{61890287} = "Cascade";
$areanames{en}->{61890288} = "Collurabbie";
$areanames{en}->{61890289} = "Condingup";
$areanames{en}->{61890290} = "Coomalbidgup";
$areanames{en}->{61890291} = "Dundas";
$areanames{en}->{61890292} = "Wialki\ North";
$areanames{en}->{61890293} = "Wilgoyne";
$areanames{en}->{61890294} = "Yilgarn\ South";
$areanames{en}->{61890295} = "Bodallin";
$areanames{en}->{61890296} = "Korbelka";
$areanames{en}->{61890297} = "Bodallin\ North";
$areanames{en}->{61890298} = "Marvel\ Loch";
$areanames{en}->{61890299} = "Bonnie\ Rock";
$areanames{en}->{61890300} = "Merredin";
$areanames{en}->{61890301} = "Bullfinch";
$areanames{en}->{61890302} = "Mount\ Hampton";
$areanames{en}->{61890303} = "Burracoppin";
$areanames{en}->{61890304} = "Mount\ Stirling";
$areanames{en}->{61890305} = "Burracoppin\ South";
$areanames{en}->{61890306} = "Mukinbudin";
$areanames{en}->{61890307} = "Dulyalbin";
$areanames{en}->{61890308} = "Nungarin";
$areanames{en}->{61890309} = "Goomarin";
$areanames{en}->{61890310} = "Laverton";
$areanames{en}->{61890311} = "Laverton";
$areanames{en}->{61890312} = "Kalgoorlie\/Laverton";
$areanames{en}->{618903120} = "Kalgoorlie";
$areanames{en}->{61890313} = "Collurabbie";
$areanames{en}->{61890314} = "Collurabbie";
$areanames{en}->{61890315} = "Collurabbie";
$areanames{en}->{61890316} = "Ardath";
$areanames{en}->{61890317} = "Ardath";
$areanames{en}->{61890318} = "Laverton";
$areanames{en}->{61890319} = "Collurabbie";
$areanames{en}->{61890320} = "Southern\ Cross";
$areanames{en}->{61890321} = "Karloning";
$areanames{en}->{61890322} = "Warralakin";
$areanames{en}->{61890323} = "Kellerberrin";
$areanames{en}->{61890324} = "Westonia";
$areanames{en}->{61890325} = "Baandee";
$areanames{en}->{618903260} = "Ardath";
$areanames{en}->{618903261} = "Ardath";
$areanames{en}->{618903262} = "Ardath";
$areanames{en}->{618903263} = "Ardath";
$areanames{en}->{618903264} = "Ardath";
$areanames{en}->{618903265} = "Ardath";
$areanames{en}->{618903266} = "Ardath";
$areanames{en}->{618903267} = "Ardath";
$areanames{en}->{618903270} = "Belka\ East";
$areanames{en}->{618903271} = "Belka\ East";
$areanames{en}->{618903272} = "Belka\ East";
$areanames{en}->{618903273} = "Belka\ East";
$areanames{en}->{618903274} = "Belka\ East";
$areanames{en}->{618903275} = "Belka\ East";
$areanames{en}->{618903276} = "Belka\ East";
$areanames{en}->{618903277} = "Belka\ East";
$areanames{en}->{618903280} = "Bruce\ Rock";
$areanames{en}->{618903281} = "Bruce\ Rock";
$areanames{en}->{618903282} = "Bruce\ Rock";
$areanames{en}->{618903283} = "Bruce\ Rock";
$areanames{en}->{618903284} = "Bruce\ Rock";
$areanames{en}->{618903285} = "Bruce\ Rock";
$areanames{en}->{618903286} = "Bruce\ Rock";
$areanames{en}->{618903287} = "Bruce\ Rock";
$areanames{en}->{618903290} = "Bullaring";
$areanames{en}->{618903291} = "Bullaring";
$areanames{en}->{618903292} = "Bullaring";
$areanames{en}->{618903293} = "Bullaring";
$areanames{en}->{618903294} = "Bullaring";
$areanames{en}->{618903295} = "Bullaring";
$areanames{en}->{618903296} = "Bullaring";
$areanames{en}->{618903297} = "Bullaring";
$areanames{en}->{618903300} = "Corrigin";
$areanames{en}->{618903301} = "Corrigin";
$areanames{en}->{618903302} = "Corrigin";
$areanames{en}->{618903303} = "Corrigin";
$areanames{en}->{618903304} = "Corrigin";
$areanames{en}->{618903305} = "Corrigin";
$areanames{en}->{618903306} = "Corrigin";
$areanames{en}->{618903307} = "Corrigin";
$areanames{en}->{618903310} = "Corrigin\ West";
$areanames{en}->{618903311} = "Corrigin\ West";
$areanames{en}->{618903312} = "Corrigin\ West";
$areanames{en}->{618903313} = "Corrigin\ West";
$areanames{en}->{618903314} = "Corrigin\ West";
$areanames{en}->{618903315} = "Corrigin\ West";
$areanames{en}->{618903316} = "Corrigin\ West";
$areanames{en}->{618903317} = "Corrigin\ West";
$areanames{en}->{618903320} = "Holleton";
$areanames{en}->{618903321} = "Holleton";
$areanames{en}->{618903322} = "Holleton";
$areanames{en}->{618903323} = "Holleton";
$areanames{en}->{618903324} = "Holleton";
$areanames{en}->{618903325} = "Holleton";
$areanames{en}->{618903326} = "Holleton";
$areanames{en}->{618903327} = "Holleton";
$areanames{en}->{618903330} = "Mount\ Walker\ South";
$areanames{en}->{618903331} = "Mount\ Walker\ South";
$areanames{en}->{618903332} = "Mount\ Walker\ South";
$areanames{en}->{618903333} = "Mount\ Walker\ South";
$areanames{en}->{618903334} = "Mount\ Walker\ South";
$areanames{en}->{618903335} = "Mount\ Walker\ South";
$areanames{en}->{618903336} = "Mount\ Walker\ South";
$areanames{en}->{618903337} = "Mount\ Walker\ South";
$areanames{en}->{618903340} = "Muntadgin\ East";
$areanames{en}->{618903341} = "Muntadgin\ East";
$areanames{en}->{618903342} = "Muntadgin\ East";
$areanames{en}->{618903343} = "Muntadgin\ East";
$areanames{en}->{618903344} = "Muntadgin\ East";
$areanames{en}->{618903345} = "Muntadgin\ East";
$areanames{en}->{618903346} = "Muntadgin\ East";
$areanames{en}->{618903347} = "Muntadgin\ East";
$areanames{en}->{618903350} = "Narembeen";
$areanames{en}->{618903351} = "Narembeen";
$areanames{en}->{618903352} = "Narembeen";
$areanames{en}->{618903353} = "Narembeen";
$areanames{en}->{618903354} = "Narembeen";
$areanames{en}->{618903355} = "Narembeen";
$areanames{en}->{618903356} = "Narembeen";
$areanames{en}->{618903357} = "Narembeen";
$areanames{en}->{618903360} = "Narembeen\ East";
$areanames{en}->{618903361} = "Narembeen\ East";
$areanames{en}->{618903362} = "Narembeen\ East";
$areanames{en}->{618903363} = "Narembeen\ East";
$areanames{en}->{618903364} = "Narembeen\ East";
$areanames{en}->{618903365} = "Narembeen\ East";
$areanames{en}->{618903366} = "Narembeen\ East";
$areanames{en}->{618903367} = "Narembeen\ East";
$areanames{en}->{618903370} = "Shackleton";
$areanames{en}->{618903371} = "Shackleton";
$areanames{en}->{618903372} = "Shackleton";
$areanames{en}->{618903373} = "Shackleton";
$areanames{en}->{618903374} = "Shackleton";
$areanames{en}->{618903375} = "Shackleton";
$areanames{en}->{618903376} = "Shackleton";
$areanames{en}->{618903377} = "Shackleton";
$areanames{en}->{618903380} = "South\ Kumminin";
$areanames{en}->{618903381} = "South\ Kumminin";
$areanames{en}->{618903382} = "South\ Kumminin";
$areanames{en}->{618903383} = "South\ Kumminin";
$areanames{en}->{618903384} = "South\ Kumminin";
$areanames{en}->{618903385} = "South\ Kumminin";
$areanames{en}->{618903386} = "South\ Kumminin";
$areanames{en}->{618903387} = "South\ Kumminin";
$areanames{en}->{618903390} = "Great\ Victoria";
$areanames{en}->{618903391} = "Great\ Victoria";
$areanames{en}->{618903392} = "Great\ Victoria";
$areanames{en}->{618903393} = "Great\ Victoria";
$areanames{en}->{618903394} = "Great\ Victoria";
$areanames{en}->{618903395} = "Great\ Victoria";
$areanames{en}->{618903396} = "Great\ Victoria";
$areanames{en}->{618903397} = "Great\ Victoria";
$areanames{en}->{618903400} = "Cascade";
$areanames{en}->{618903401} = "Cascade";
$areanames{en}->{618903402} = "Cascade";
$areanames{en}->{618903403} = "Cascade";
$areanames{en}->{618903404} = "Cascade";
$areanames{en}->{618903405} = "Cascade";
$areanames{en}->{618903406} = "Cascade";
$areanames{en}->{618903407} = "Cascade";
$areanames{en}->{618903410} = "Collurabbie";
$areanames{en}->{618903411} = "Collurabbie";
$areanames{en}->{618903412} = "Collurabbie";
$areanames{en}->{618903413} = "Collurabbie";
$areanames{en}->{618903414} = "Collurabbie";
$areanames{en}->{618903415} = "Collurabbie";
$areanames{en}->{618903416} = "Collurabbie";
$areanames{en}->{618903417} = "Collurabbie";
$areanames{en}->{618903420} = "Condingup";
$areanames{en}->{618903421} = "Condingup";
$areanames{en}->{618903422} = "Condingup";
$areanames{en}->{618903423} = "Condingup";
$areanames{en}->{618903424} = "Condingup";
$areanames{en}->{618903425} = "Condingup";
$areanames{en}->{618903426} = "Condingup";
$areanames{en}->{618903427} = "Condingup";
$areanames{en}->{618903430} = "Coomalbidgup";
$areanames{en}->{618903431} = "Coomalbidgup";
$areanames{en}->{618903432} = "Coomalbidgup";
$areanames{en}->{618903433} = "Coomalbidgup";
$areanames{en}->{618903434} = "Coomalbidgup";
$areanames{en}->{618903435} = "Coomalbidgup";
$areanames{en}->{618903436} = "Coomalbidgup";
$areanames{en}->{618903437} = "Coomalbidgup";
$areanames{en}->{618903440} = "Dundas";
$areanames{en}->{618903441} = "Dundas";
$areanames{en}->{618903442} = "Dundas";
$areanames{en}->{618903443} = "Dundas";
$areanames{en}->{618903444} = "Dundas";
$areanames{en}->{618903445} = "Dundas";
$areanames{en}->{618903446} = "Dundas";
$areanames{en}->{618903447} = "Dundas";
$areanames{en}->{618903450} = "Esperance";
$areanames{en}->{618903451} = "Esperance";
$areanames{en}->{618903452} = "Esperance";
$areanames{en}->{618903453} = "Esperance";
$areanames{en}->{618903454} = "Esperance";
$areanames{en}->{618903455} = "Esperance";
$areanames{en}->{618903456} = "Esperance";
$areanames{en}->{618903457} = "Esperance";
$areanames{en}->{618903460} = "Eyre";
$areanames{en}->{618903461} = "Eyre";
$areanames{en}->{618903462} = "Eyre";
$areanames{en}->{618903463} = "Eyre";
$areanames{en}->{618903464} = "Eyre";
$areanames{en}->{618903465} = "Eyre";
$areanames{en}->{618903466} = "Eyre";
$areanames{en}->{618903467} = "Eyre";
$areanames{en}->{618903470} = "Gibson";
$areanames{en}->{618903471} = "Gibson";
$areanames{en}->{618903472} = "Gibson";
$areanames{en}->{618903473} = "Gibson";
$areanames{en}->{618903474} = "Gibson";
$areanames{en}->{618903475} = "Gibson";
$areanames{en}->{618903476} = "Gibson";
$areanames{en}->{618903477} = "Gibson";
$areanames{en}->{618903478} = "Gibson";
$areanames{en}->{618903480} = "Goldfields";
$areanames{en}->{618903481} = "Goldfields";
$areanames{en}->{618903482} = "Goldfields";
$areanames{en}->{618903483} = "Goldfields";
$areanames{en}->{618903484} = "Goldfields";
$areanames{en}->{618903485} = "Goldfields";
$areanames{en}->{618903486} = "Goldfields";
$areanames{en}->{618903487} = "Goldfields";
$areanames{en}->{618903490} = "Grass\ Patch";
$areanames{en}->{618903491} = "Grass\ Patch";
$areanames{en}->{618903492} = "Grass\ Patch";
$areanames{en}->{618903493} = "Grass\ Patch";
$areanames{en}->{618903494} = "Grass\ Patch";
$areanames{en}->{618903495} = "Grass\ Patch";
$areanames{en}->{618903496} = "Grass\ Patch";
$areanames{en}->{618903497} = "Grass\ Patch";
$areanames{en}->{618903500} = "Kalgoorlie";
$areanames{en}->{618903501} = "Kalgoorlie";
$areanames{en}->{618903502} = "Kalgoorlie";
$areanames{en}->{618903503} = "Kalgoorlie";
$areanames{en}->{618903504} = "Kalgoorlie";
$areanames{en}->{618903510} = "Kambalda";
$areanames{en}->{618903511} = "Kambalda";
$areanames{en}->{618903512} = "Kambalda";
$areanames{en}->{618903513} = "Kambalda";
$areanames{en}->{618903514} = "Kambalda";
$areanames{en}->{618903515} = "Kambalda";
$areanames{en}->{618903516} = "Kambalda";
$areanames{en}->{618903517} = "Kambalda";
$areanames{en}->{618903520} = "Laverton";
$areanames{en}->{618903521} = "Laverton";
$areanames{en}->{618903522} = "Laverton";
$areanames{en}->{618903523} = "Laverton";
$areanames{en}->{618903524} = "Laverton";
$areanames{en}->{618903525} = "Laverton";
$areanames{en}->{618903526} = "Laverton";
$areanames{en}->{618903527} = "Laverton";
$areanames{en}->{618903530} = "Leinster";
$areanames{en}->{618903531} = "Leinster";
$areanames{en}->{618903532} = "Leinster";
$areanames{en}->{618903533} = "Leinster";
$areanames{en}->{618903534} = "Leinster";
$areanames{en}->{618903535} = "Leinster";
$areanames{en}->{618903536} = "Leinster";
$areanames{en}->{618903537} = "Leinster";
$areanames{en}->{618903540} = "Leonora";
$areanames{en}->{618903541} = "Leonora";
$areanames{en}->{618903542} = "Leonora";
$areanames{en}->{618903543} = "Leonora";
$areanames{en}->{618903544} = "Leonora";
$areanames{en}->{618903545} = "Leonora";
$areanames{en}->{618903546} = "Leonora";
$areanames{en}->{618903547} = "Leonora";
$areanames{en}->{618903550} = "Mount\ Beaumont";
$areanames{en}->{618903551} = "Mount\ Beaumont";
$areanames{en}->{618903552} = "Mount\ Beaumont";
$areanames{en}->{618903553} = "Mount\ Beaumont";
$areanames{en}->{618903554} = "Mount\ Beaumont";
$areanames{en}->{618903555} = "Mount\ Beaumont";
$areanames{en}->{618903556} = "Mount\ Beaumont";
$areanames{en}->{618903557} = "Mount\ Beaumont";
$areanames{en}->{618903560} = "Mount\ Merivale";
$areanames{en}->{618903561} = "Mount\ Merivale";
$areanames{en}->{618903562} = "Mount\ Merivale";
$areanames{en}->{618903563} = "Mount\ Merivale";
$areanames{en}->{618903564} = "Mount\ Merivale";
$areanames{en}->{618903565} = "Mount\ Merivale";
$areanames{en}->{618903566} = "Mount\ Merivale";
$areanames{en}->{618903567} = "Mount\ Merivale";
$areanames{en}->{618903570} = "Munglinup";
$areanames{en}->{618903571} = "Munglinup";
$areanames{en}->{618903572} = "Munglinup";
$areanames{en}->{618903573} = "Munglinup";
$areanames{en}->{618903574} = "Munglinup";
$areanames{en}->{618903575} = "Munglinup";
$areanames{en}->{618903576} = "Munglinup";
$areanames{en}->{618903577} = "Munglinup";
$areanames{en}->{618903580} = "Neridup";
$areanames{en}->{618903581} = "Neridup";
$areanames{en}->{618903582} = "Neridup";
$areanames{en}->{618903583} = "Neridup";
$areanames{en}->{618903584} = "Neridup";
$areanames{en}->{618903585} = "Neridup";
$areanames{en}->{618903586} = "Neridup";
$areanames{en}->{618903587} = "Neridup";
$areanames{en}->{618903590} = "Norseman";
$areanames{en}->{618903591} = "Norseman";
$areanames{en}->{618903592} = "Norseman";
$areanames{en}->{618903593} = "Norseman";
$areanames{en}->{618903594} = "Norseman";
$areanames{en}->{618903595} = "Norseman";
$areanames{en}->{618903596} = "Norseman";
$areanames{en}->{618903597} = "Norseman";
$areanames{en}->{618903600} = "Nullarbor";
$areanames{en}->{618903601} = "Nullarbor";
$areanames{en}->{618903602} = "Nullarbor";
$areanames{en}->{618903603} = "Nullarbor";
$areanames{en}->{618903604} = "Nullarbor";
$areanames{en}->{618903605} = "Nullarbor";
$areanames{en}->{618903606} = "Nullarbor";
$areanames{en}->{618903607} = "Nullarbor";
$areanames{en}->{618903610} = "Salmon\ Gums";
$areanames{en}->{618903611} = "Salmon\ Gums";
$areanames{en}->{618903612} = "Salmon\ Gums";
$areanames{en}->{618903613} = "Salmon\ Gums";
$areanames{en}->{618903614} = "Salmon\ Gums";
$areanames{en}->{618903615} = "Salmon\ Gums";
$areanames{en}->{618903616} = "Salmon\ Gums";
$areanames{en}->{618903617} = "Salmon\ Gums";
$areanames{en}->{618903620} = "Scaddan\ West";
$areanames{en}->{618903621} = "Scaddan\ West";
$areanames{en}->{618903622} = "Scaddan\ West";
$areanames{en}->{618903623} = "Scaddan\ West";
$areanames{en}->{618903624} = "Scaddan\ West";
$areanames{en}->{618903625} = "Scaddan\ West";
$areanames{en}->{618903626} = "Scaddan\ West";
$areanames{en}->{618903627} = "Scaddan\ West";
$areanames{en}->{618903630} = "Speddingup\ East";
$areanames{en}->{618903631} = "Speddingup\ East";
$areanames{en}->{618903632} = "Speddingup\ East";
$areanames{en}->{618903633} = "Speddingup\ East";
$areanames{en}->{618903634} = "Speddingup\ East";
$areanames{en}->{618903635} = "Speddingup\ East";
$areanames{en}->{618903636} = "Speddingup\ East";
$areanames{en}->{618903637} = "Speddingup\ East";
$areanames{en}->{618903640} = "Baandee";
$areanames{en}->{618903641} = "Baandee";
$areanames{en}->{618903642} = "Baandee";
$areanames{en}->{618903643} = "Baandee";
$areanames{en}->{618903644} = "Baandee";
$areanames{en}->{618903645} = "Baandee";
$areanames{en}->{618903646} = "Baandee";
$areanames{en}->{618903647} = "Baandee";
$areanames{en}->{618903650} = "Bodallin";
$areanames{en}->{618903651} = "Bodallin";
$areanames{en}->{618903652} = "Bodallin";
$areanames{en}->{618903653} = "Bodallin";
$areanames{en}->{618903654} = "Bodallin";
$areanames{en}->{618903655} = "Bodallin";
$areanames{en}->{618903656} = "Bodallin";
$areanames{en}->{618903657} = "Bodallin";
$areanames{en}->{618903660} = "Bodallin\ North";
$areanames{en}->{618903661} = "Bodallin\ North";
$areanames{en}->{618903662} = "Bodallin\ North";
$areanames{en}->{618903663} = "Bodallin\ North";
$areanames{en}->{618903664} = "Bodallin\ North";
$areanames{en}->{618903665} = "Bodallin\ North";
$areanames{en}->{618903666} = "Bodallin\ North";
$areanames{en}->{618903667} = "Bodallin\ North";
$areanames{en}->{618903670} = "Bonnie\ Rock";
$areanames{en}->{618903671} = "Bonnie\ Rock";
$areanames{en}->{618903672} = "Bonnie\ Rock";
$areanames{en}->{618903673} = "Bonnie\ Rock";
$areanames{en}->{618903674} = "Bonnie\ Rock";
$areanames{en}->{618903675} = "Bonnie\ Rock";
$areanames{en}->{618903676} = "Bonnie\ Rock";
$areanames{en}->{618903677} = "Bonnie\ Rock";
$areanames{en}->{618903680} = "Bullfinch";
$areanames{en}->{618903681} = "Bullfinch";
$areanames{en}->{618903682} = "Bullfinch";
$areanames{en}->{618903683} = "Bullfinch";
$areanames{en}->{618903684} = "Bullfinch";
$areanames{en}->{618903685} = "Bullfinch";
$areanames{en}->{618903686} = "Bullfinch";
$areanames{en}->{618903687} = "Bullfinch";
$areanames{en}->{618903690} = "Burracoppin";
$areanames{en}->{618903691} = "Burracoppin";
$areanames{en}->{618903692} = "Burracoppin";
$areanames{en}->{618903693} = "Burracoppin";
$areanames{en}->{618903694} = "Burracoppin";
$areanames{en}->{618903695} = "Burracoppin";
$areanames{en}->{618903696} = "Burracoppin";
$areanames{en}->{618903697} = "Burracoppin";
$areanames{en}->{61890370} = "Leinster";
$areanames{en}->{61890371} = "Great\ Victoria";
$areanames{en}->{61890372} = "Leonora";
$areanames{en}->{61890373} = "Leinster";
$areanames{en}->{61890374} = "Leinster";
$areanames{en}->{61890375} = "Collurabbie";
$areanames{en}->{61890376} = "Leonora";
$areanames{en}->{61890377} = "Leonora";
$areanames{en}->{61890378} = "Leinster";
$areanames{en}->{61890379} = "Leinster";
$areanames{en}->{618903800} = "Burracoppin\ South";
$areanames{en}->{618903801} = "Burracoppin\ South";
$areanames{en}->{618903802} = "Burracoppin\ South";
$areanames{en}->{618903803} = "Burracoppin\ South";
$areanames{en}->{618903804} = "Burracoppin\ South";
$areanames{en}->{618903805} = "Burracoppin\ South";
$areanames{en}->{618903806} = "Burracoppin\ South";
$areanames{en}->{618903807} = "Burracoppin\ South";
$areanames{en}->{618903810} = "Dulyalbin";
$areanames{en}->{618903811} = "Dulyalbin";
$areanames{en}->{618903812} = "Dulyalbin";
$areanames{en}->{618903813} = "Dulyalbin";
$areanames{en}->{618903814} = "Dulyalbin";
$areanames{en}->{618903815} = "Dulyalbin";
$areanames{en}->{618903816} = "Dulyalbin";
$areanames{en}->{618903817} = "Dulyalbin";
$areanames{en}->{618903820} = "Goomarin";
$areanames{en}->{618903821} = "Goomarin";
$areanames{en}->{618903822} = "Goomarin";
$areanames{en}->{618903823} = "Goomarin";
$areanames{en}->{618903824} = "Goomarin";
$areanames{en}->{618903825} = "Goomarin";
$areanames{en}->{618903826} = "Goomarin";
$areanames{en}->{618903827} = "Goomarin";
$areanames{en}->{618903830} = "Karloning";
$areanames{en}->{618903831} = "Karloning";
$areanames{en}->{618903832} = "Karloning";
$areanames{en}->{618903833} = "Karloning";
$areanames{en}->{618903834} = "Karloning";
$areanames{en}->{618903835} = "Karloning";
$areanames{en}->{618903836} = "Karloning";
$areanames{en}->{618903837} = "Karloning";
$areanames{en}->{618903840} = "Kellerberrin";
$areanames{en}->{618903841} = "Kellerberrin";
$areanames{en}->{618903842} = "Kellerberrin";
$areanames{en}->{618903843} = "Kellerberrin";
$areanames{en}->{618903844} = "Kellerberrin";
$areanames{en}->{618903845} = "Kellerberrin";
$areanames{en}->{618903846} = "Kellerberrin";
$areanames{en}->{618903847} = "Kellerberrin";
$areanames{en}->{618903850} = "Korbelka";
$areanames{en}->{618903851} = "Korbelka";
$areanames{en}->{618903852} = "Korbelka";
$areanames{en}->{618903853} = "Korbelka";
$areanames{en}->{618903854} = "Korbelka";
$areanames{en}->{618903855} = "Korbelka";
$areanames{en}->{618903856} = "Korbelka";
$areanames{en}->{618903857} = "Korbelka";
$areanames{en}->{618903860} = "Marvel\ Loch";
$areanames{en}->{618903861} = "Marvel\ Loch";
$areanames{en}->{618903862} = "Marvel\ Loch";
$areanames{en}->{618903863} = "Marvel\ Loch";
$areanames{en}->{618903864} = "Marvel\ Loch";
$areanames{en}->{618903865} = "Marvel\ Loch";
$areanames{en}->{618903866} = "Marvel\ Loch";
$areanames{en}->{618903867} = "Marvel\ Loch";
$areanames{en}->{618903870} = "Merredin";
$areanames{en}->{618903871} = "Merredin";
$areanames{en}->{618903872} = "Merredin";
$areanames{en}->{618903873} = "Merredin";
$areanames{en}->{618903874} = "Merredin";
$areanames{en}->{618903875} = "Merredin";
$areanames{en}->{618903876} = "Merredin";
$areanames{en}->{618903877} = "Merredin";
$areanames{en}->{618903880} = "Mount\ Hampton";
$areanames{en}->{618903881} = "Mount\ Hampton";
$areanames{en}->{618903882} = "Mount\ Hampton";
$areanames{en}->{618903883} = "Mount\ Hampton";
$areanames{en}->{618903884} = "Mount\ Hampton";
$areanames{en}->{618903885} = "Mount\ Hampton";
$areanames{en}->{618903886} = "Mount\ Hampton";
$areanames{en}->{618903887} = "Mount\ Hampton";
$areanames{en}->{618903888} = "Mount\ Hampton";
$areanames{en}->{618903890} = "Mount\ Stirling";
$areanames{en}->{618903891} = "Mount\ Stirling";
$areanames{en}->{618903892} = "Mount\ Stirling";
$areanames{en}->{618903893} = "Mount\ Stirling";
$areanames{en}->{618903894} = "Mount\ Stirling";
$areanames{en}->{618903895} = "Mount\ Stirling";
$areanames{en}->{618903896} = "Mount\ Stirling";
$areanames{en}->{618903897} = "Mount\ Stirling";
$areanames{en}->{61890390} = "Norseman";
$areanames{en}->{61890391} = "Norseman";
$areanames{en}->{61890392} = "Norseman";
$areanames{en}->{61890393} = "Eyre";
$areanames{en}->{61890394} = "Dundas\/Kalgoorlie";
$areanames{en}->{61890395} = "Eyre";
$areanames{en}->{61890396} = "Dundas";
$areanames{en}->{61890397} = "Dundas";
$areanames{en}->{61890398} = "Kalgoorlie";
$areanames{en}->{61890399} = "Norseman";
$areanames{en}->{61890400} = "Norseman";
$areanames{en}->{61890401} = "Marvel\ Loch";
$areanames{en}->{61890402} = "Marvel\ Loch";
$areanames{en}->{61890403} = "Mount\ Hampton";
$areanames{en}->{61890404} = "Mount\ Hampton";
$areanames{en}->{61890406} = "Bodallin";
$areanames{en}->{61890407} = "Bodallin\ North";
$areanames{en}->{61890408} = "Dundas";
$areanames{en}->{61890409} = "Dundas";
$areanames{en}->{6189041} = "Merredin";
$areanames{en}->{61890420} = "Bullfinch";
$areanames{en}->{618904210} = "Mukinbudin";
$areanames{en}->{618904211} = "Mukinbudin";
$areanames{en}->{618904212} = "Mukinbudin";
$areanames{en}->{618904213} = "Mukinbudin";
$areanames{en}->{618904214} = "Mukinbudin";
$areanames{en}->{618904215} = "Mukinbudin";
$areanames{en}->{618904216} = "Mukinbudin";
$areanames{en}->{618904217} = "Mukinbudin";
$areanames{en}->{618904220} = "Nungarin";
$areanames{en}->{618904221} = "Nungarin";
$areanames{en}->{618904222} = "Nungarin";
$areanames{en}->{618904223} = "Nungarin";
$areanames{en}->{618904224} = "Nungarin";
$areanames{en}->{618904225} = "Nungarin";
$areanames{en}->{618904226} = "Nungarin";
$areanames{en}->{618904227} = "Nungarin";
$areanames{en}->{618904230} = "Southern\ Cross";
$areanames{en}->{618904231} = "Southern\ Cross";
$areanames{en}->{618904232} = "Southern\ Cross";
$areanames{en}->{618904233} = "Southern\ Cross";
$areanames{en}->{618904234} = "Southern\ Cross";
$areanames{en}->{618904235} = "Southern\ Cross";
$areanames{en}->{618904236} = "Southern\ Cross";
$areanames{en}->{618904237} = "Southern\ Cross";
$areanames{en}->{618904240} = "Warralakin";
$areanames{en}->{618904241} = "Warralakin";
$areanames{en}->{618904242} = "Warralakin";
$areanames{en}->{618904243} = "Warralakin";
$areanames{en}->{618904244} = "Warralakin";
$areanames{en}->{618904245} = "Warralakin";
$areanames{en}->{618904246} = "Warralakin";
$areanames{en}->{618904247} = "Warralakin";
$areanames{en}->{618904250} = "Westonia";
$areanames{en}->{618904251} = "Westonia";
$areanames{en}->{618904252} = "Westonia";
$areanames{en}->{618904253} = "Westonia";
$areanames{en}->{618904254} = "Westonia";
$areanames{en}->{618904255} = "Westonia";
$areanames{en}->{618904256} = "Westonia";
$areanames{en}->{618904257} = "Westonia";
$areanames{en}->{618904260} = "Wialki\ North";
$areanames{en}->{618904261} = "Wialki\ North";
$areanames{en}->{618904262} = "Wialki\ North";
$areanames{en}->{618904263} = "Wialki\ North";
$areanames{en}->{618904264} = "Wialki\ North";
$areanames{en}->{618904265} = "Wialki\ North";
$areanames{en}->{618904266} = "Wialki\ North";
$areanames{en}->{618904267} = "Wialki\ North";
$areanames{en}->{618904270} = "Wilgoyne";
$areanames{en}->{618904271} = "Wilgoyne";
$areanames{en}->{618904272} = "Wilgoyne";
$areanames{en}->{618904273} = "Wilgoyne";
$areanames{en}->{618904274} = "Wilgoyne";
$areanames{en}->{618904275} = "Wilgoyne";
$areanames{en}->{618904276} = "Wilgoyne";
$areanames{en}->{618904277} = "Wilgoyne";
$areanames{en}->{618904280} = "Yilgarn\ South";
$areanames{en}->{618904281} = "Yilgarn\ South";
$areanames{en}->{618904282} = "Yilgarn\ South";
$areanames{en}->{618904283} = "Yilgarn\ South";
$areanames{en}->{618904284} = "Yilgarn\ South";
$areanames{en}->{618904285} = "Yilgarn\ South";
$areanames{en}->{618904286} = "Yilgarn\ South";
$areanames{en}->{618904287} = "Yilgarn\ South";
$areanames{en}->{61890431} = "Ardath";
$areanames{en}->{61890432} = "Belka\ East";
$areanames{en}->{61890433} = "Bruce\ Rock";
$areanames{en}->{61890434} = "Bullaring";
$areanames{en}->{61890435} = "Corrigin";
$areanames{en}->{61890436} = "Corrigin\ West";
$areanames{en}->{61890437} = "Holleton";
$areanames{en}->{61890438} = "Mount\ Walker\ South";
$areanames{en}->{61890439} = "Muntadgin\ East";
$areanames{en}->{61890440} = "Merredin";
$areanames{en}->{61890441} = "Merredin";
$areanames{en}->{61890442} = "Baandee";
$areanames{en}->{61890443} = "Baandee";
$areanames{en}->{61890444} = "Baandee";
$areanames{en}->{61890445} = "Burracoppin";
$areanames{en}->{61890446} = "Burracoppin";
$areanames{en}->{61890447} = "Burracoppin\ South";
$areanames{en}->{61890449} = "Warralakin";
$areanames{en}->{6189045} = "Kellerberrin";
$areanames{en}->{61890450} = "Warralakin";
$areanames{en}->{61890451} = "Mount\ Stirling";
$areanames{en}->{61890452} = "Mount\ Stirling";
$areanames{en}->{61890453} = "Goomarin";
$areanames{en}->{61890460} = "Condingup";
$areanames{en}->{61890461} = "Condingup";
$areanames{en}->{61890462} = "Coomalbidgup";
$areanames{en}->{61890463} = "Coomalbidgup";
$areanames{en}->{61890464} = "Nungarin";
$areanames{en}->{61890465} = "Nungarin";
$areanames{en}->{61890466} = "Nungarin";
$areanames{en}->{61890467} = "Westonia";
$areanames{en}->{61890468} = "Westonia";
$areanames{en}->{61890469} = "Korbelka";
$areanames{en}->{61890470} = "Bonnie\ Rock";
$areanames{en}->{61890471} = "Mukinbudin";
$areanames{en}->{61890472} = "Mukinbudin";
$areanames{en}->{61890473} = "Eyre";
$areanames{en}->{61890474} = "Eyre";
$areanames{en}->{61890475} = "Bodallin";
$areanames{en}->{61890476} = "Bodallin";
$areanames{en}->{61890477} = "Bodallin\ North";
$areanames{en}->{61890478} = "Goldfields";
$areanames{en}->{61890479} = "Goldfields";
$areanames{en}->{61890480} = "Karloning";
$areanames{en}->{61890481} = "Cascade";
$areanames{en}->{61890482} = "Cascade";
$areanames{en}->{61890483} = "Mukinbudin";
$areanames{en}->{61890484} = "Karloning";
$areanames{en}->{61890485} = "Wialki\ North";
$areanames{en}->{61890486} = "Wialki\ North";
$areanames{en}->{61890487} = "Wilgoyne";
$areanames{en}->{61890488} = "Wilgoyne";
$areanames{en}->{61890489} = "Southern\ Cross";
$areanames{en}->{61890490} = "Southern\ Cross";
$areanames{en}->{61890491} = "Southern\ Cross";
$areanames{en}->{61890492} = "Southern\ Cross";
$areanames{en}->{61890493} = "Bullfinch";
$areanames{en}->{61890494} = "Bullfinch";
$areanames{en}->{61890495} = "Bullfinch";
$areanames{en}->{61890496} = "Bullfinch";
$areanames{en}->{61890497} = "Dulyalbin";
$areanames{en}->{61890498} = "Dulyalbin";
$areanames{en}->{61890499} = "Yilgarn\ South";
$areanames{en}->{61890500} = "Narembeen";
$areanames{en}->{61890501} = "Narembeen\ East";
$areanames{en}->{61890502} = "Shackleton";
$areanames{en}->{61890503} = "South\ Kumminin";
$areanames{en}->{61890504} = "Great\ Victoria";
$areanames{en}->{61890505} = "Cascade";
$areanames{en}->{61890506} = "Collurabbie";
$areanames{en}->{61890507} = "Condingup";
$areanames{en}->{61890508} = "Coomalbidgup";
$areanames{en}->{61890509} = "Dundas";
$areanames{en}->{61890510} = "Esperance";
$areanames{en}->{61890511} = "Eyre";
$areanames{en}->{61890512} = "Gibson";
$areanames{en}->{61890513} = "Goldfields";
$areanames{en}->{61890514} = "Grass\ Patch";
$areanames{en}->{61890515} = "Kalgoorlie";
$areanames{en}->{61890516} = "Kambalda";
$areanames{en}->{61890517} = "Laverton";
$areanames{en}->{61890518} = "Leinster";
$areanames{en}->{61890519} = "Leonora";
$areanames{en}->{61890520} = "Mount\ Beaumont";
$areanames{en}->{61890521} = "Mount\ Merivale";
$areanames{en}->{61890522} = "Munglinup";
$areanames{en}->{61890523} = "Neridup";
$areanames{en}->{61890524} = "Norseman";
$areanames{en}->{61890525} = "Nullarbor";
$areanames{en}->{61890526} = "Salmon\ Gums";
$areanames{en}->{61890527} = "Scaddan\ West";
$areanames{en}->{61890528} = "Speddingup\ East";
$areanames{en}->{61890529} = "Baandee";
$areanames{en}->{61890530} = "Bodallin";
$areanames{en}->{61890531} = "Bodallin\ North";
$areanames{en}->{61890532} = "Bonnie\ Rock";
$areanames{en}->{61890533} = "Bullfinch";
$areanames{en}->{61890534} = "Burracoppin";
$areanames{en}->{61890535} = "Burracoppin\ South";
$areanames{en}->{61890536} = "Dulyalbin";
$areanames{en}->{61890537} = "Goomarin";
$areanames{en}->{61890538} = "Karloning";
$areanames{en}->{61890539} = "Kellerberrin";
$areanames{en}->{61890540} = "Korbelka";
$areanames{en}->{61890541} = "Marvel\ Loch";
$areanames{en}->{61890542} = "Merredin";
$areanames{en}->{61890543} = "Mount\ Hampton";
$areanames{en}->{61890544} = "Mount\ Stirling";
$areanames{en}->{61890545} = "Mukinbudin";
$areanames{en}->{61890546} = "Nungarin";
$areanames{en}->{61890547} = "Southern\ Cross";
$areanames{en}->{61890548} = "Warralakin";
$areanames{en}->{61890549} = "Westonia";
$areanames{en}->{61890550} = "Wialki\ North";
$areanames{en}->{61890551} = "Wilgoyne";
$areanames{en}->{61890552} = "Yilgarn\ South";
$areanames{en}->{61890553} = "Esperance";
$areanames{en}->{61890554} = "Esperance";
$areanames{en}->{61890555} = "Gibson";
$areanames{en}->{61890556} = "Gibson";
$areanames{en}->{61890557} = "Leinster";
$areanames{en}->{61890558} = "Leinster";
$areanames{en}->{61890559} = "Leinster";
$areanames{en}->{61890560} = "Kambalda";
$areanames{en}->{61890561} = "Kambalda";
$areanames{en}->{61890562} = "Mount\ Beaumont";
$areanames{en}->{61890563} = "Mount\ Beaumont";
$areanames{en}->{61890564} = "Mount\ Merivale";
$areanames{en}->{61890565} = "Mount\ Merivale";
$areanames{en}->{61890566} = "Munglinup";
$areanames{en}->{61890567} = "Munglinup";
$areanames{en}->{61890568} = "Neridup";
$areanames{en}->{61890569} = "Neridup";
$areanames{en}->{61890570} = "Speddingup\ East";
$areanames{en}->{61890571} = "Speddingup\ East";
$areanames{en}->{61890572} = "Yilgarn\ South";
$areanames{en}->{61890573} = "Yilgarn\ South";
$areanames{en}->{61890574} = "Baandee";
$areanames{en}->{61890575} = "Baandee";
$areanames{en}->{61890576} = "Bodallin";
$areanames{en}->{61890577} = "Bodallin";
$areanames{en}->{61890578} = "Bodallin\ North";
$areanames{en}->{61890579} = "Bodallin\ North";
$areanames{en}->{61890580} = "Bullfinch";
$areanames{en}->{61890581} = "Bullfinch";
$areanames{en}->{61890582} = "Burracoppin\ South";
$areanames{en}->{61890583} = "Burracoppin\ South";
$areanames{en}->{61890584} = "Dulyalbin";
$areanames{en}->{61890585} = "Dulyalbin";
$areanames{en}->{61890586} = "Goomarin";
$areanames{en}->{61890587} = "Goomarin";
$areanames{en}->{61890588} = "Karloning";
$areanames{en}->{61890589} = "Karloning";
$areanames{en}->{61890590} = "Korbelka";
$areanames{en}->{61890591} = "Korbelka";
$areanames{en}->{61890592} = "Marvel\ Loch";
$areanames{en}->{61890593} = "Marvel\ Loch";
$areanames{en}->{61890594} = "Mount\ Hampton";
$areanames{en}->{61890595} = "Mount\ Hampton";
$areanames{en}->{61890596} = "Mount\ Stirling";
$areanames{en}->{61890597} = "Mount\ Stirling";
$areanames{en}->{61890598} = "Mukinbudin";
$areanames{en}->{61890599} = "Mukinbudin";
$areanames{en}->{61890600} = "Nungarin";
$areanames{en}->{61890601} = "Nungarin";
$areanames{en}->{61890602} = "Warralakin";
$areanames{en}->{61890603} = "Warralakin";
$areanames{en}->{61890604} = "Westonia";
$areanames{en}->{61890605} = "Westonia";
$areanames{en}->{61890606} = "Nullarbor";
$areanames{en}->{61890607} = "Nullarbor";
$areanames{en}->{61890608} = "Westonia";
$areanames{en}->{61890609} = "Kalgoorlie";
$areanames{en}->{61890610} = "Bruce\ Rock";
$areanames{en}->{61890611} = "Bruce\ Rock";
$areanames{en}->{61890612} = "Southern\ Cross";
$areanames{en}->{61890613} = "Southern\ Cross";
$areanames{en}->{61890614} = "Belka\ East";
$areanames{en}->{61890615} = "Belka\ East";
$areanames{en}->{61890616} = "Mount\ Walker\ South";
$areanames{en}->{61890617} = "Mount\ Walker\ South";
$areanames{en}->{61890618} = "Narembeen\ East";
$areanames{en}->{61890619} = "Narembeen\ East";
$areanames{en}->{61890620} = "Holleton";
$areanames{en}->{61890621} = "Holleton";
$areanames{en}->{61890622} = "Holleton";
$areanames{en}->{61890623} = "Belka\ East";
$areanames{en}->{61890624} = "Belka\ East";
$areanames{en}->{61890625} = "Belka\ East";
$areanames{en}->{61890626} = "Belka\ East";
$areanames{en}->{61890627} = "Corrigin\ West";
$areanames{en}->{61890628} = "Corrigin\ West";
$areanames{en}->{61890629} = "Corrigin\ West";
$areanames{en}->{6189063} = "Corrigin";
$areanames{en}->{61890635} = "Muntadgin\ East";
$areanames{en}->{61890636} = "Mount\ Walker\ South";
$areanames{en}->{61890638} = "Bruce\ Rock";
$areanames{en}->{61890639} = "Bruce\ Rock";
$areanames{en}->{61890640} = "Shackleton";
$areanames{en}->{61890641} = "Shackleton";
$areanames{en}->{61890642} = "Corrigin\ West";
$areanames{en}->{61890643} = "Corrigin\ West";
$areanames{en}->{61890645} = "Narembeen";
$areanames{en}->{61890646} = "Narembeen";
$areanames{en}->{61890647} = "Narembeen";
$areanames{en}->{61890648} = "Narembeen";
$areanames{en}->{61890649} = "Narembeen";
$areanames{en}->{61890650} = "Ardath";
$areanames{en}->{61890651} = "Ardath";
$areanames{en}->{61890652} = "Ardath";
$areanames{en}->{61890653} = "South\ Kumminin";
$areanames{en}->{61890654} = "South\ Kumminin";
$areanames{en}->{61890655} = "South\ Kumminin";
$areanames{en}->{61890656} = "South\ Kumminin";
$areanames{en}->{61890657} = "Bullaring";
$areanames{en}->{61890658} = "Bullaring";
$areanames{en}->{61890659} = "Bullaring";
$areanames{en}->{61890660} = "Laverton";
$areanames{en}->{61890662} = "Leinster";
$areanames{en}->{61890663} = "Leonora";
$areanames{en}->{61890664} = "Collurabbie";
$areanames{en}->{61890665} = "Collurabbie";
$areanames{en}->{61890666} = "Leinster";
$areanames{en}->{61890667} = "Leinster";
$areanames{en}->{61890668} = "Leonora";
$areanames{en}->{61890669} = "Eyre";
$areanames{en}->{61890681} = "Kalgoorlie";
$areanames{en}->{61890682} = "Kalgoorlie";
$areanames{en}->{61890683} = "Kalgoorlie";
$areanames{en}->{61890684} = "Kalgoorlie";
$areanames{en}->{61890685} = "Kalgoorlie";
$areanames{en}->{61890686} = "Kalgoorlie";
$areanames{en}->{61890687} = "Kalgoorlie";
$areanames{en}->{61890688} = "Laverton";
$areanames{en}->{61890689} = "Laverton";
$areanames{en}->{61890699} = "Westonia";
$areanames{en}->{6189071} = "Esperance";
$areanames{en}->{61890718} = "Ardath";
$areanames{en}->{61890720} = "Esperance";
$areanames{en}->{61890721} = "Esperance";
$areanames{en}->{61890722} = "Esperance";
$areanames{en}->{61890723} = "Esperance";
$areanames{en}->{61890750} = "Condingup";
$areanames{en}->{61890751} = "Munglinup";
$areanames{en}->{61890752} = "Munglinup";
$areanames{en}->{61890753} = "Coomalbidgup";
$areanames{en}->{61890754} = "Gibson";
$areanames{en}->{61890755} = "Gibson";
$areanames{en}->{61890756} = "Gibson";
$areanames{en}->{61890757} = "Grass\ Patch";
$areanames{en}->{61890758} = "Salmon\ Gums";
$areanames{en}->{61890759} = "Mount\ Merivale";
$areanames{en}->{61890760} = "Salmon\ Gums";
$areanames{en}->{61890761} = "Esperance";
$areanames{en}->{61890762} = "Esperance";
$areanames{en}->{61890763} = "Esperance";
$areanames{en}->{61890764} = "Esperance";
$areanames{en}->{61890765} = "Esperance";
$areanames{en}->{61890766} = "Condingup";
$areanames{en}->{61890767} = "Speddingup\ East";
$areanames{en}->{61890768} = "Coomalbidgup";
$areanames{en}->{61890769} = "Coomalbidgup";
$areanames{en}->{61890780} = "Neridup";
$areanames{en}->{61890781} = "Neridup";
$areanames{en}->{61890782} = "Neridup";
$areanames{en}->{61890783} = "Neridup";
$areanames{en}->{61890784} = "Salmon\ Gums";
$areanames{en}->{61890785} = "Salmon\ Gums";
$areanames{en}->{61890786} = "Scaddan\ West";
$areanames{en}->{61890787} = "Mount\ Beaumont";
$areanames{en}->{61890788} = "Mount\ Beaumont";
$areanames{en}->{61890789} = "Scaddan\ West";
$areanames{en}->{61890790} = "Mount\ Beaumont";
$areanames{en}->{61890791} = "Cascade";
$areanames{en}->{61890792} = "Cascade";
$areanames{en}->{61890793} = "Cascade";
$areanames{en}->{61890794} = "Bullaring";
$areanames{en}->{61890795} = "Bullaring";
$areanames{en}->{61890796} = "Salmon\ Gums";
$areanames{en}->{61890797} = "Salmon\ Gums";
$areanames{en}->{61890798} = "Esperance";
$areanames{en}->{61890799} = "Esperance";
$areanames{en}->{61890800} = "Kalgoorlie";
$areanames{en}->{61890801} = "Kalgoorlie";
$areanames{en}->{61890802} = "Kambalda";
$areanames{en}->{618908033} = "Leinster";
$areanames{en}->{61890804} = "Leonora";
$areanames{en}->{61890805} = "Kalgoorlie";
$areanames{en}->{618908068} = "Goldfields";
$areanames{en}->{618908069} = "Kalgoorlie";
$areanames{en}->{61890807} = "Dundas";
$areanames{en}->{61890808} = "Kalgoorlie";
$areanames{en}->{61890809} = "Kalgoorlie";
$areanames{en}->{61890810} = "Marvel\ Loch";
$areanames{en}->{61890811} = "Marvel\ Loch";
$areanames{en}->{61890812} = "Southern\ Cross";
$areanames{en}->{61890813} = "Merredin";
$areanames{en}->{61890814} = "Narembeen\ East";
$areanames{en}->{61890815} = "Narembeen\ East";
$areanames{en}->{61890816} = "Shackleton";
$areanames{en}->{61890817} = "Shackleton";
$areanames{en}->{61890818} = "South\ Kumminin";
$areanames{en}->{61890819} = "South\ Kumminin";
$areanames{en}->{61890820} = "Merredin";
$areanames{en}->{61890821} = "Bruce\ Rock";
$areanames{en}->{61890822} = "Muntadgin\ East";
$areanames{en}->{61890823} = "Muntadgin\ East";
$areanames{en}->{61890824} = "Narembeen";
$areanames{en}->{61890825} = "Narembeen";
$areanames{en}->{61890826} = "Bruce\ Rock";
$areanames{en}->{61890827} = "Kalgoorlie";
$areanames{en}->{61890828} = "Kalgoorlie";
$areanames{en}->{61890829} = "Kalgoorlie";
$areanames{en}->{61890830} = "Salmon\ Gums";
$areanames{en}->{61890831} = "Esperance";
$areanames{en}->{61890832} = "Esperance";
$areanames{en}->{61890839} = "Norseman";
$areanames{en}->{61890877} = "Collurabbie";
$areanames{en}->{61890878} = "Collurabbie";
$areanames{en}->{61890879} = "Collurabbie";
$areanames{en}->{61890880} = "Kalgoorlie";
$areanames{en}->{618908805} = "Goldfields";
$areanames{en}->{618908809} = "Goldfields";
$areanames{en}->{61890881} = "Kambalda";
$areanames{en}->{61890882} = "Laverton";
$areanames{en}->{61890883} = "Leinster";
$areanames{en}->{61890884} = "Leinster";
$areanames{en}->{61890885} = "Collurabbie";
$areanames{en}->{61890886} = "Kalgoorlie\/Goldfields";
$areanames{en}->{61890887} = "Collurabbie";
$areanames{en}->{61890888} = "Kalgoorlie\/Goldfields";
$areanames{en}->{61890889} = "Kalgoorlie\/Goldfields";
$areanames{en}->{6189091} = "Kalgoorlie";
$areanames{en}->{6189092} = "Kalgoorlie";
$areanames{en}->{61890927} = "Wialki\ North";
$areanames{en}->{61890928} = "Wilgoyne";
$areanames{en}->{61890929} = "Yilgarn\ South";
$areanames{en}->{6189093} = "Kalgoorlie";
$areanames{en}->{61890936} = "Goldfields";
$areanames{en}->{61890940} = "Bodallin";
$areanames{en}->{61890941} = "Korbelka";
$areanames{en}->{61890942} = "Bodallin\ North";
$areanames{en}->{61890943} = "Marvel\ Loch";
$areanames{en}->{61890944} = "Bonnie\ Rock";
$areanames{en}->{61890945} = "Merredin";
$areanames{en}->{61890946} = "Bullfinch";
$areanames{en}->{61890947} = "Mount\ Hampton";
$areanames{en}->{61890948} = "Burracoppin";
$areanames{en}->{61890949} = "Mount\ Stirling";
$areanames{en}->{61890950} = "Burracoppin\ South";
$areanames{en}->{61890951} = "Mukinbudin";
$areanames{en}->{61890952} = "Dulyalbin";
$areanames{en}->{61890953} = "Nungarin";
$areanames{en}->{61890954} = "Goomarin";
$areanames{en}->{61890955} = "Southern\ Cross";
$areanames{en}->{61890956} = "Karloning";
$areanames{en}->{61890957} = "Warralakin";
$areanames{en}->{61890958} = "Kellerberrin";
$areanames{en}->{61890959} = "Westonia";
$areanames{en}->{61890960} = "Mount\ Beaumont";
$areanames{en}->{61890961} = "Mount\ Merivale";
$areanames{en}->{61890962} = "Munglinup";
$areanames{en}->{61890963} = "Neridup";
$areanames{en}->{61890964} = "Norseman";
$areanames{en}->{61890965} = "Nullarbor";
$areanames{en}->{61890966} = "Salmon\ Gums";
$areanames{en}->{61890967} = "Scaddan\ West";
$areanames{en}->{61890968} = "Speddingup\ East";
$areanames{en}->{61890969} = "Baandee";
$areanames{en}->{61890970} = "Esperance";
$areanames{en}->{61890971} = "Eyre";
$areanames{en}->{61890972} = "Gibson";
$areanames{en}->{61890973} = "Goldfields";
$areanames{en}->{61890974} = "Grass\ Patch";
$areanames{en}->{61890975} = "Kalgoorlie";
$areanames{en}->{61890976} = "Kambalda";
$areanames{en}->{61890977} = "Laverton";
$areanames{en}->{61890978} = "Leinster";
$areanames{en}->{61890979} = "Leonora";
$areanames{en}->{61890980} = "Narembeen";
$areanames{en}->{61890981} = "Narembeen\ East";
$areanames{en}->{61890982} = "Shackleton";
$areanames{en}->{61890983} = "South\ Kumminin";
$areanames{en}->{61890984} = "Great\ Victoria";
$areanames{en}->{61890985} = "Cascade";
$areanames{en}->{61890986} = "Collurabbie";
$areanames{en}->{61890987} = "Condingup";
$areanames{en}->{61890988} = "Coomalbidgup";
$areanames{en}->{61890989} = "Dundas";
$areanames{en}->{61890990} = "Ardath";
$areanames{en}->{61890991} = "Belka\ East";
$areanames{en}->{61890992} = "Bruce\ Rock";
$areanames{en}->{61890993} = "Bullaring";
$areanames{en}->{61890994} = "Corrigin";
$areanames{en}->{61890995} = "Corrigin\ West";
$areanames{en}->{61890996} = "Holleton";
$areanames{en}->{61890997} = "Mount\ Walker\ South";
$areanames{en}->{61890998} = "Muntadgin\ East";
$areanames{en}->{61890999} = "Kalgoorlie";
$areanames{en}->{61891000} = "Karratha";
$areanames{en}->{61891001} = "Karratha";
$areanames{en}->{61891002} = "Karratha";
$areanames{en}->{61891003} = "Broome";
$areanames{en}->{61891004} = "Broome";
$areanames{en}->{61891005} = "Broome";
$areanames{en}->{61891006} = "Christmas\ Island";
$areanames{en}->{61891007} = "Christmas\ Island";
$areanames{en}->{61891008} = "Christmas\ Island";
$areanames{en}->{61891009} = "Christmas\ Island";
$areanames{en}->{61891010} = "Cocos\ Island";
$areanames{en}->{61891011} = "Cocos\ Island";
$areanames{en}->{61891012} = "Cocos\ Island";
$areanames{en}->{61891013} = "Dampier";
$areanames{en}->{61891014} = "Dampier";
$areanames{en}->{61891015} = "Dampier";
$areanames{en}->{61891016} = "De\ Grey";
$areanames{en}->{61891017} = "De\ Grey";
$areanames{en}->{61891018} = "De\ Grey";
$areanames{en}->{61891019} = "Broome";
$areanames{en}->{61891020} = "Derby";
$areanames{en}->{61891021} = "Derby";
$areanames{en}->{61891022} = "Derby";
$areanames{en}->{61891023} = "Fitzroy\ Crossing";
$areanames{en}->{61891024} = "Fitzroy\ Crossing";
$areanames{en}->{61891025} = "Fitzroy\ Crossing";
$areanames{en}->{61891026} = "Great\ Sandy";
$areanames{en}->{61891027} = "Great\ Sandy";
$areanames{en}->{61891028} = "Great\ Sandy";
$areanames{en}->{61891029} = "Cocos\ Island";
$areanames{en}->{61891030} = "Hall\'s\ Creek";
$areanames{en}->{61891031} = "Hall\'s\ Creek";
$areanames{en}->{61891032} = "Hall\'s\ Creek";
$areanames{en}->{61891033} = "Karratha";
$areanames{en}->{61891034} = "Karratha";
$areanames{en}->{61891035} = "Karratha";
$areanames{en}->{61891036} = "Kununurra";
$areanames{en}->{61891037} = "Kununurra";
$areanames{en}->{61891038} = "Kununurra";
$areanames{en}->{61891039} = "Broome";
$areanames{en}->{61891040} = "Leopold";
$areanames{en}->{61891041} = "Leopold";
$areanames{en}->{61891042} = "Leopold";
$areanames{en}->{61891043} = "Marble\ Bar";
$areanames{en}->{61891044} = "Marble\ Bar";
$areanames{en}->{61891045} = "Marble\ Bar";
$areanames{en}->{61891046} = "Millstream";
$areanames{en}->{61891047} = "Millstream";
$areanames{en}->{61891048} = "Millstream";
$areanames{en}->{61891049} = "Derby";
$areanames{en}->{61891050} = "Mitchell";
$areanames{en}->{61891051} = "Mitchell";
$areanames{en}->{61891052} = "Mitchell";
$areanames{en}->{61891053} = "Mount\ Bruce";
$areanames{en}->{61891054} = "Mount\ Bruce";
$areanames{en}->{61891055} = "Mount\ Bruce";
$areanames{en}->{61891056} = "Newman";
$areanames{en}->{61891057} = "Newman";
$areanames{en}->{61891058} = "Newman";
$areanames{en}->{61891059} = "Fitzroy\ Crossing";
$areanames{en}->{61891060} = "Onslow";
$areanames{en}->{61891061} = "Onslow";
$areanames{en}->{61891062} = "Onslow";
$areanames{en}->{61891063} = "Ord";
$areanames{en}->{61891064} = "Ord";
$areanames{en}->{61891065} = "Ord";
$areanames{en}->{61891066} = "Pannawonica";
$areanames{en}->{61891067} = "Pannawonica";
$areanames{en}->{61891068} = "Pannawonica";
$areanames{en}->{61891069} = "Broome";
$areanames{en}->{61891070} = "Paraburdoo";
$areanames{en}->{61891071} = "Paraburdoo";
$areanames{en}->{61891072} = "Paraburdoo";
$areanames{en}->{61891073} = "Port\ Hedland";
$areanames{en}->{61891074} = "Port\ Hedland";
$areanames{en}->{61891075} = "Port\ Hedland";
$areanames{en}->{61891076} = "Roebuck";
$areanames{en}->{61891077} = "Roebuck";
$areanames{en}->{61891078} = "Roebuck";
$areanames{en}->{61891079} = "Kununurra";
$areanames{en}->{61891080} = "Sandfire";
$areanames{en}->{61891081} = "Sandfire";
$areanames{en}->{61891082} = "Sandfire";
$areanames{en}->{61891083} = "Telfer";
$areanames{en}->{61891084} = "Telfer";
$areanames{en}->{61891085} = "Telfer";
$areanames{en}->{61891086} = "Tom\ Price";
$areanames{en}->{61891087} = "Tom\ Price";
$areanames{en}->{61891088} = "Tom\ Price";
$areanames{en}->{61891089} = "Leopold";
$areanames{en}->{61891090} = "Whaleback";
$areanames{en}->{61891091} = "Whaleback";
$areanames{en}->{61891092} = "Whaleback";
$areanames{en}->{61891093} = "Wittenoom";
$areanames{en}->{61891094} = "Wittenoom";
$areanames{en}->{61891095} = "Wittenoom";
$areanames{en}->{61891096} = "Wyndham";
$areanames{en}->{61891097} = "Wyndham";
$areanames{en}->{61891098} = "Wyndham";
$areanames{en}->{61891099} = "Mitchell";
$areanames{en}->{61891100} = "Ord";
$areanames{en}->{61891101} = "Roebuck";
$areanames{en}->{61891102} = "Wyndham";
$areanames{en}->{61891103} = "Hall\'s\ Creek";
$areanames{en}->{61891104} = "Great\ Sandy";
$areanames{en}->{61891105} = "Dampier";
$areanames{en}->{61891106} = "De\ Grey";
$areanames{en}->{61891107} = "Karratha";
$areanames{en}->{61891108} = "Marble\ Bar";
$areanames{en}->{61891109} = "Millstream";
$areanames{en}->{61891110} = "Mount\ Bruce";
$areanames{en}->{61891111} = "Newman";
$areanames{en}->{61891112} = "Onslow";
$areanames{en}->{61891113} = "Pannawonica";
$areanames{en}->{61891114} = "Paraburdoo";
$areanames{en}->{61891115} = "Port\ Hedland";
$areanames{en}->{61891116} = "Sandfire";
$areanames{en}->{61891117} = "Telfer";
$areanames{en}->{61891118} = "Tom\ Price";
$areanames{en}->{61891119} = "Whaleback";
$areanames{en}->{61891120} = "Wittenoom";
$areanames{en}->{61891122} = "Cocos\ Island";
$areanames{en}->{61891123} = "Broome";
$areanames{en}->{61891124} = "Derby";
$areanames{en}->{61891125} = "Fitzroy\ Crossing";
$areanames{en}->{61891126} = "Kununurra";
$areanames{en}->{61891127} = "Leopold";
$areanames{en}->{61891128} = "Mitchell";
$areanames{en}->{61891129} = "Ord";
$areanames{en}->{61891130} = "Roebuck";
$areanames{en}->{61891131} = "Wyndham";
$areanames{en}->{61891132} = "Great\ Sandy";
$areanames{en}->{61891133} = "Dampier";
$areanames{en}->{61891134} = "De\ Grey";
$areanames{en}->{61891135} = "Karratha";
$areanames{en}->{61891136} = "Marble\ Bar";
$areanames{en}->{61891137} = "Millstream";
$areanames{en}->{61891138} = "Mount\ Bruce";
$areanames{en}->{61891139} = "Newman";
$areanames{en}->{61891140} = "Onslow";
$areanames{en}->{61891141} = "Pannawonica";
$areanames{en}->{61891142} = "Paraburdoo";
$areanames{en}->{61891143} = "Port\ Hedland";
$areanames{en}->{61891144} = "Sandfire";
$areanames{en}->{61891145} = "Telfer";
$areanames{en}->{61891146} = "Tom\ Price";
$areanames{en}->{61891147} = "Whaleback";
$areanames{en}->{61891148} = "Wittenoom";
$areanames{en}->{61891149} = "Christmas\ Island";
$areanames{en}->{61891150} = "Cocos\ Island";
$areanames{en}->{61891151} = "Broome";
$areanames{en}->{61891152} = "Derby";
$areanames{en}->{61891153} = "Fitzroy\ Crossing";
$areanames{en}->{61891154} = "Kununurra";
$areanames{en}->{61891155} = "Leopold";
$areanames{en}->{61891156} = "Mitchell";
$areanames{en}->{61891157} = "Hall\'s\ Creek";
$areanames{en}->{61891158} = "Ord";
$areanames{en}->{61891159} = "Roebuck";
$areanames{en}->{61891160} = "Wyndham";
$areanames{en}->{61891161} = "Great\ Sandy";
$areanames{en}->{61891162} = "Dampier";
$areanames{en}->{61891163} = "De\ Grey";
$areanames{en}->{61891164} = "Karratha";
$areanames{en}->{61891165} = "Marble\ Bar";
$areanames{en}->{61891166} = "Millstream";
$areanames{en}->{61891167} = "Mount\ Bruce";
$areanames{en}->{61891168} = "Newman";
$areanames{en}->{61891169} = "Onslow";
$areanames{en}->{61891170} = "Pannawonica";
$areanames{en}->{61891171} = "Paraburdoo";
$areanames{en}->{61891172} = "Port\ Hedland";
$areanames{en}->{61891173} = "Sandfire";
$areanames{en}->{61891174} = "Telfer";
$areanames{en}->{61891175} = "Tom\ Price";
$areanames{en}->{61891176} = "Whaleback";
$areanames{en}->{61891177} = "Wittenoom";
$areanames{en}->{61891178} = "Christmas\ Island";
$areanames{en}->{61891179} = "Cocos\ Island";
$areanames{en}->{61891180} = "Broome";
$areanames{en}->{61891181} = "Christmas\ Island";
$areanames{en}->{61891182} = "Cocos\ Island";
$areanames{en}->{61891183} = "Derby";
$areanames{en}->{61891184} = "Fitzroy\ Crossing";
$areanames{en}->{61891185} = "Hall\'s\ Creek";
$areanames{en}->{61891186} = "Kununurra";
$areanames{en}->{61891187} = "Leopold";
$areanames{en}->{61891188} = "Mitchell";
$areanames{en}->{61891189} = "Ord";
$areanames{en}->{61891190} = "Roebuck";
$areanames{en}->{61891191} = "Wyndham";
$areanames{en}->{61891192} = "Great\ Sandy";
$areanames{en}->{61891193} = "Dampier";
$areanames{en}->{61891194} = "De\ Grey";
$areanames{en}->{61891195} = "Karratha";
$areanames{en}->{61891196} = "Marble\ Bar";
$areanames{en}->{61891197} = "Millstream";
$areanames{en}->{61891198} = "Mount\ Bruce";
$areanames{en}->{61891199} = "Newman";
$areanames{en}->{61891200} = "Onslow";
$areanames{en}->{61891201} = "Pannawonica";
$areanames{en}->{61891202} = "Paraburdoo";
$areanames{en}->{61891203} = "Sandfire";
$areanames{en}->{61891204} = "Telfer";
$areanames{en}->{61891205} = "Tom\ Price";
$areanames{en}->{61891206} = "Whaleback";
$areanames{en}->{61891207} = "Wittenoom";
$areanames{en}->{61891208} = "Port\ Hedland";
$areanames{en}->{61891209} = "Christmas\ Island";
$areanames{en}->{61891210} = "Cocos\ Island";
$areanames{en}->{61891211} = "Derby";
$areanames{en}->{61891212} = "Fitzroy\ Crossing";
$areanames{en}->{61891213} = "Hall\'s\ Creek";
$areanames{en}->{61891214} = "Kununurra";
$areanames{en}->{61891215} = "Leopold";
$areanames{en}->{61891216} = "Mitchell";
$areanames{en}->{61891217} = "Ord";
$areanames{en}->{61891218} = "Roebuck";
$areanames{en}->{61891219} = "Wyndham";
$areanames{en}->{61891220} = "Great\ Sandy";
$areanames{en}->{61891221} = "Dampier";
$areanames{en}->{61891222} = "De\ Grey";
$areanames{en}->{61891223} = "Karratha";
$areanames{en}->{61891224} = "Marble\ Bar";
$areanames{en}->{61891225} = "Millstream";
$areanames{en}->{61891226} = "Mount\ Bruce";
$areanames{en}->{61891227} = "Newman";
$areanames{en}->{61891228} = "Onslow";
$areanames{en}->{61891229} = "Pannawonica";
$areanames{en}->{61891230} = "Paraburdoo";
$areanames{en}->{61891231} = "Port\ Hedland";
$areanames{en}->{61891232} = "Sandfire";
$areanames{en}->{61891233} = "Telfer";
$areanames{en}->{61891234} = "Tom\ Price";
$areanames{en}->{61891235} = "Whaleback";
$areanames{en}->{61891236} = "Wittenoom";
$areanames{en}->{61891237} = "Derby";
$areanames{en}->{61891238} = "Fitzroy\ Crossing";
$areanames{en}->{61891239} = "Hall\'s\ Creek";
$areanames{en}->{61891240} = "Kununurra";
$areanames{en}->{61891241} = "Leopold";
$areanames{en}->{61891242} = "Mitchell";
$areanames{en}->{61891243} = "Ord";
$areanames{en}->{61891244} = "Roebuck";
$areanames{en}->{61891245} = "Wyndham";
$areanames{en}->{61891246} = "Great\ Sandy";
$areanames{en}->{61891247} = "Dampier";
$areanames{en}->{61891248} = "De\ Grey";
$areanames{en}->{61891249} = "Karratha";
$areanames{en}->{61891250} = "Marble\ Bar";
$areanames{en}->{61891251} = "Millstream";
$areanames{en}->{61891252} = "Mount\ Bruce";
$areanames{en}->{61891253} = "Newman";
$areanames{en}->{61891254} = "Onslow";
$areanames{en}->{61891255} = "Pannawonica";
$areanames{en}->{61891256} = "Paraburdoo";
$areanames{en}->{61891257} = "Port\ Hedland";
$areanames{en}->{61891258} = "Sandfire";
$areanames{en}->{61891259} = "Telfer";
$areanames{en}->{61891260} = "Tom\ Price";
$areanames{en}->{61891261} = "Whaleback";
$areanames{en}->{61891262} = "Wittenoom";
$areanames{en}->{61891263} = "Christmas\ Island";
$areanames{en}->{61891264} = "Cocos\ Island";
$areanames{en}->{61891265} = "Broome";
$areanames{en}->{61891266} = "Port\ Hedland";
$areanames{en}->{61891267} = "Broome";
$areanames{en}->{61891268} = "Whaleback";
$areanames{en}->{61891269} = "Derby";
$areanames{en}->{61891270} = "Kununurra";
$areanames{en}->{61891271} = "Fitzroy\ Crossing";
$areanames{en}->{61891272} = "Hall\'s\ Creek";
$areanames{en}->{61891273} = "Kununurra";
$areanames{en}->{61891274} = "Leopold";
$areanames{en}->{61891275} = "Mitchell";
$areanames{en}->{61891276} = "Ord";
$areanames{en}->{61891277} = "Roebuck";
$areanames{en}->{61891278} = "Wyndham";
$areanames{en}->{61891279} = "Karratha";
$areanames{en}->{61891280} = "Great\ Sandy";
$areanames{en}->{61891281} = "Dampier";
$areanames{en}->{61891282} = "De\ Grey";
$areanames{en}->{61891283} = "Newman";
$areanames{en}->{61891284} = "Karratha";
$areanames{en}->{61891285} = "Marble\ Bar";
$areanames{en}->{61891286} = "Millstream";
$areanames{en}->{61891287} = "Port\ Hedland";
$areanames{en}->{61891288} = "Mount\ Bruce";
$areanames{en}->{61891289} = "Newman";
$areanames{en}->{61891290} = "Tom\ Price";
$areanames{en}->{61891291} = "Onslow";
$areanames{en}->{61891292} = "Pannawonica";
$areanames{en}->{61891293} = "Whaleback";
$areanames{en}->{61891294} = "Broome";
$areanames{en}->{61891295} = "Newman";
$areanames{en}->{61891296} = "Port\ Hedland";
$areanames{en}->{61891297} = "Whaleback";
$areanames{en}->{61891298} = "Whaleback";
$areanames{en}->{61891299} = "Port\ Hedland";
$areanames{en}->{61891300} = "Whaleback";
$areanames{en}->{61891301} = "Whaleback";
$areanames{en}->{61891302} = "Whaleback";
$areanames{en}->{61891303} = "Whaleback";
$areanames{en}->{61891304} = "Broome";
$areanames{en}->{61891305} = "Port\ Hedland";
$areanames{en}->{61891306} = "Leopold";
$areanames{en}->{61891307} = "Newman";
$areanames{en}->{61891308} = "Cocos\ Island";
$areanames{en}->{61891309} = "Newman";
$areanames{en}->{61891310} = "Paraburdoo";
$areanames{en}->{61891311} = "Broome";
$areanames{en}->{61891312} = "Christmas\ Island";
$areanames{en}->{61891313} = "Mitchell";
$areanames{en}->{61891314} = "Hall\'s\ Creek";
$areanames{en}->{61891315} = "Karratha";
$areanames{en}->{61891316} = "Kununurra";
$areanames{en}->{61891317} = "Roebuck";
$areanames{en}->{61891318} = "Sandfire";
$areanames{en}->{61891319} = "Port\ Hedland";
$areanames{en}->{61891320} = "Port\ Hedland";
$areanames{en}->{61891321} = "Whaleback";
$areanames{en}->{61891322} = "Cocos\ Island";
$areanames{en}->{61891323} = "Millstream";
$areanames{en}->{61891324} = "Telfer";
$areanames{en}->{61891325} = "Marble\ Bar";
$areanames{en}->{61891326} = "Christmas\ Island";
$areanames{en}->{61891327} = "Dampier";
$areanames{en}->{61891328} = "Derby";
$areanames{en}->{61891329} = "Port\ Hedland";
$areanames{en}->{61891330} = "Sandfire";
$areanames{en}->{61891331} = "Port\ Hedland";
$areanames{en}->{61891332} = "Great\ Sandy";
$areanames{en}->{61891333} = "Wyndham";
$areanames{en}->{61891334} = "De\ Grey";
$areanames{en}->{61891335} = "Paraburdoo";
$areanames{en}->{61891336} = "Newman";
$areanames{en}->{61891337} = "Wittenoom";
$areanames{en}->{61891338} = "Onslow";
$areanames{en}->{61891339} = "Telfer";
$areanames{en}->{61891340} = "Wyndham";
$areanames{en}->{61891341} = "Whaleback";
$areanames{en}->{61891342} = "Wyndham";
$areanames{en}->{61891343} = "Wyndham";
$areanames{en}->{61891344} = "Wittenoom";
$areanames{en}->{61891345} = "Wittenoom";
$areanames{en}->{61891346} = "Pannawonica";
$areanames{en}->{61891347} = "Mitchell";
$areanames{en}->{61891348} = "Mitchell";
$areanames{en}->{61891349} = "Pannawonica";
$areanames{en}->{61891350} = "Tom\ Price";
$areanames{en}->{61891351} = "Mount\ Bruce";
$areanames{en}->{61891352} = "Tom\ Price";
$areanames{en}->{61891353} = "Fitzroy\ Crossing";
$areanames{en}->{61891354} = "Pannawonica";
$areanames{en}->{61891355} = "Broome";
$areanames{en}->{61891356} = "Ord";
$areanames{en}->{61891357} = "Leopold";
$areanames{en}->{61891358} = "Mitchell";
$areanames{en}->{61891359} = "Whaleback";
$areanames{en}->{61891360} = "Wittenoom";
$areanames{en}->{61891361} = "Hall\'s\ Creek";
$areanames{en}->{61891362} = "Karratha";
$areanames{en}->{61891363} = "Kununurra";
$areanames{en}->{61891364} = "Roebuck";
$areanames{en}->{61891365} = "Sandfire";
$areanames{en}->{61891366} = "Whaleback";
$areanames{en}->{61891367} = "Leopold";
$areanames{en}->{61891368} = "Cocos\ Island";
$areanames{en}->{61891371} = "Millstream";
$areanames{en}->{61891372} = "Telfer";
$areanames{en}->{61891373} = "Derby";
$areanames{en}->{61891374} = "Marble\ Bar";
$areanames{en}->{61891375} = "Christmas\ Island";
$areanames{en}->{61891376} = "Dampier";
$areanames{en}->{61891377} = "Derby";
$areanames{en}->{61891378} = "Port\ Hedland";
$areanames{en}->{61891381} = "Great\ Sandy";
$areanames{en}->{61891382} = "Derby";
$areanames{en}->{61891383} = "Port\ Hedland";
$areanames{en}->{61891384} = "Wyndham";
$areanames{en}->{61891385} = "De\ Grey";
$areanames{en}->{61891386} = "Paraburdoo";
$areanames{en}->{61891387} = "Broome";
$areanames{en}->{61891388} = "Newman";
$areanames{en}->{61891391} = "Wittenoom";
$areanames{en}->{61891392} = "Onslow";
$areanames{en}->{61891393} = "Mount\ Bruce";
$areanames{en}->{61891394} = "Tom\ Price";
$areanames{en}->{61891395} = "Mitchell";
$areanames{en}->{61891396} = "Fitzroy\ Crossing";
$areanames{en}->{61891397} = "Pannawonica";
$areanames{en}->{61891398} = "Broome";
$areanames{en}->{6189140} = "Port\ Hedland";
$areanames{en}->{61891410} = "Port\ Hedland";
$areanames{en}->{61891411} = "Onslow";
$areanames{en}->{61891412} = "Onslow";
$areanames{en}->{61891413} = "Pannawonica";
$areanames{en}->{61891414} = "Pannawonica";
$areanames{en}->{61891415} = "Sandfire";
$areanames{en}->{61891416} = "Sandfire";
$areanames{en}->{61891417} = "Telfer";
$areanames{en}->{61891418} = "Telfer";
$areanames{en}->{61891419} = "Karratha";
$areanames{en}->{61891420} = "Karratha";
$areanames{en}->{61891421} = "Karratha";
$areanames{en}->{61891422} = "Ord";
$areanames{en}->{61891423} = "Hall\'s\ Creek";
$areanames{en}->{61891424} = "Kununurra";
$areanames{en}->{61891425} = "Roebuck";
$areanames{en}->{61891426} = "Sandfire";
$areanames{en}->{61891427} = "Whaleback";
$areanames{en}->{61891428} = "Cocos\ Island";
$areanames{en}->{61891429} = "Broome";
$areanames{en}->{6189143} = "Karratha";
$areanames{en}->{61891433} = "Tom\ Price";
$areanames{en}->{61891434} = "Paraburdoo";
$areanames{en}->{61891438} = "Tom\ Price";
$areanames{en}->{6189144} = "Karratha";
$areanames{en}->{61891443} = "Dampier";
$areanames{en}->{61891448} = "Whaleback";
$areanames{en}->{61891450} = "Broome";
$areanames{en}->{61891451} = "Broome";
$areanames{en}->{61891452} = "Broome";
$areanames{en}->{61891453} = "Millstream";
$areanames{en}->{61891454} = "Telfer";
$areanames{en}->{61891455} = "Marble\ Bar";
$areanames{en}->{61891456} = "Christmas\ Island";
$areanames{en}->{61891457} = "Dampier";
$areanames{en}->{61891458} = "Derby";
$areanames{en}->{6189146} = "De\ Grey";
$areanames{en}->{61891470} = "Karratha";
$areanames{en}->{61891471} = "Karratha";
$areanames{en}->{61891472} = "Ord";
$areanames{en}->{61891473} = "Ord";
$areanames{en}->{61891474} = "Mount\ Bruce";
$areanames{en}->{61891475} = "Whaleback";
$areanames{en}->{61891476} = "Whaleback";
$areanames{en}->{61891477} = "Whaleback";
$areanames{en}->{61891478} = "Marble\ Bar";
$areanames{en}->{61891479} = "Marble\ Bar";
$areanames{en}->{61891481} = "Port\ Hedland";
$areanames{en}->{61891482} = "Kununurra";
$areanames{en}->{61891483} = "Great\ Sandy";
$areanames{en}->{61891484} = "Wyndham";
$areanames{en}->{61891485} = "De\ Grey";
$areanames{en}->{61891486} = "Paraburdoo";
$areanames{en}->{61891487} = "Newman";
$areanames{en}->{61891488} = "Wittenoom";
$areanames{en}->{61891491} = "Onslow";
$areanames{en}->{61891492} = "Mount\ Bruce";
$areanames{en}->{61891493} = "Tom\ Price";
$areanames{en}->{61891494} = "Fitzroy\ Crossing";
$areanames{en}->{61891495} = "Pannawonica";
$areanames{en}->{61891496} = "Ord";
$areanames{en}->{61891497} = "Christmas\ Island";
$areanames{en}->{61891498} = "Cocos\ Island";
$areanames{en}->{61891511} = "Karratha";
$areanames{en}->{61891512} = "Kununurra";
$areanames{en}->{61891513} = "Kununurra";
$areanames{en}->{61891514} = "Kununurra";
$areanames{en}->{61891518} = "Whaleback";
$areanames{en}->{61891519} = "Whaleback";
$areanames{en}->{61891521} = "Dampier";
$areanames{en}->{61891530} = "Marble\ Bar";
$areanames{en}->{61891531} = "Mount\ Bruce";
$areanames{en}->{61891532} = "Onslow";
$areanames{en}->{61891533} = "Sandfire";
$areanames{en}->{61891534} = "Newman";
$areanames{en}->{61891535} = "Port\ Hedland";
$areanames{en}->{61891536} = "Wittenoom";
$areanames{en}->{61891537} = "Onslow";
$areanames{en}->{61891539} = "Newman";
$areanames{en}->{61891542} = "Newman";
$areanames{en}->{61891543} = "Newman";
$areanames{en}->{61891546} = "De\ Grey";
$areanames{en}->{61891547} = "Whaleback";
$areanames{en}->{61891548} = "Newman";
$areanames{en}->{61891549} = "Great\ Sandy";
$areanames{en}->{61891560} = "Karratha";
$areanames{en}->{61891561} = "Roebuck";
$areanames{en}->{61891562} = "Roebuck";
$areanames{en}->{61891563} = "Broome";
$areanames{en}->{61891564} = "Broome";
$areanames{en}->{61891565} = "Derby";
$areanames{en}->{61891566} = "Derby";
$areanames{en}->{61891567} = "Millstream";
$areanames{en}->{61891568} = "Millstream";
$areanames{en}->{61891569} = "Millstream";
$areanames{en}->{6189157} = "Broome";
$areanames{en}->{61891580} = "Port\ Hedland";
$areanames{en}->{61891581} = "Port\ Hedland";
$areanames{en}->{61891582} = "Newman\/Whaleback\/Newman";
$areanames{en}->{61891583} = "Broome";
$areanames{en}->{61891584} = "Derby";
$areanames{en}->{61891585} = "Port\ Hedland";
$areanames{en}->{61891586} = "Sandfire";
$areanames{en}->{61891587} = "Karratha";
$areanames{en}->{61891588} = "Karratha";
$areanames{en}->{61891589} = "Port\ Hedland";
$areanames{en}->{61891590} = "Karratha";
$areanames{en}->{61891591} = "Karratha";
$areanames{en}->{61891592} = "Karratha";
$areanames{en}->{61891593} = "Pannawonica";
$areanames{en}->{61891594} = "Dampier";
$areanames{en}->{61891595} = "Tom\ Price";
$areanames{en}->{61891596} = "Karratha";
$areanames{en}->{61891597} = "Karratha";
$areanames{en}->{61891598} = "Paraburdoo";
$areanames{en}->{61891599} = "Onslow";
$areanames{en}->{6189160} = "Port\ Hedland";
$areanames{en}->{61891610} = "Wyndham";
$areanames{en}->{61891611} = "Wyndham";
$areanames{en}->{61891612} = "Wyndham";
$areanames{en}->{61891613} = "Wyndham";
$areanames{en}->{61891614} = "Mitchell";
$areanames{en}->{61891615} = "Derby";
$areanames{en}->{61891616} = "Derby";
$areanames{en}->{61891617} = "Derby";
$areanames{en}->{61891618} = "Derby";
$areanames{en}->{61891619} = "Derby";
$areanames{en}->{6189162} = "Cocos\ Island";
$areanames{en}->{61891630} = "Mitchell";
$areanames{en}->{61891631} = "Dampier";
$areanames{en}->{61891632} = "Dampier";
$areanames{en}->{61891633} = "Port\ Hedland";
$areanames{en}->{61891634} = "Port\ Hedland";
$areanames{en}->{61891635} = "Leopold";
$areanames{en}->{61891636} = "Leopold";
$areanames{en}->{61891637} = "Hall\'s\ Creek";
$areanames{en}->{61891638} = "Fitzroy\ Crossing";
$areanames{en}->{61891639} = "Fitzroy\ Crossing";
$areanames{en}->{6189164} = "Christmas\ Island";
$areanames{en}->{61891650} = "De\ Grey";
$areanames{en}->{61891651} = "De\ Grey";
$areanames{en}->{61891652} = "Mount\ Bruce";
$areanames{en}->{61891653} = "Mount\ Bruce";
$areanames{en}->{61891654} = "Whaleback";
$areanames{en}->{61891655} = "Whaleback";
$areanames{en}->{61891656} = "Newman";
$areanames{en}->{61891657} = "Newman";
$areanames{en}->{61891658} = "Paraburdoo";
$areanames{en}->{61891659} = "Paraburdoo";
$areanames{en}->{6189166} = "Kununurra";
$areanames{en}->{61891661} = "Fitzroy\ Crossing";
$areanames{en}->{61891663} = "Ord";
$areanames{en}->{6189167} = "Ord";
$areanames{en}->{61891680} = "Kununurra";
$areanames{en}->{61891681} = "Kununurra";
$areanames{en}->{61891682} = "Kununurra";
$areanames{en}->{61891683} = "Kununurra";
$areanames{en}->{61891684} = "Kununurra";
$areanames{en}->{61891685} = "Ord";
$areanames{en}->{61891686} = "Ord";
$areanames{en}->{61891687} = "Ord";
$areanames{en}->{61891688} = "Ord";
$areanames{en}->{61891689} = "Ord";
$areanames{en}->{6189169} = "Kununurra";
$areanames{en}->{61891700} = "Christmas\ Island";
$areanames{en}->{61891701} = "Christmas\ Island";
$areanames{en}->{61891702} = "Cocos\ Island";
$areanames{en}->{61891704} = "Fitzroy\ Crossing";
$areanames{en}->{61891705} = "Fitzroy\ Crossing";
$areanames{en}->{61891706} = "Great\ Sandy";
$areanames{en}->{61891707} = "Great\ Sandy";
$areanames{en}->{61891708} = "Hall\'s\ Creek";
$areanames{en}->{61891709} = "Hall\'s\ Creek";
$areanames{en}->{61891710} = "Christmas\ Island";
$areanames{en}->{61891711} = "Christmas\ Island";
$areanames{en}->{61891712} = "Christmas\ Island";
$areanames{en}->{61891713} = "Mitchell";
$areanames{en}->{61891714} = "Hall\'s\ Creek";
$areanames{en}->{61891715} = "Hall\'s\ Creek";
$areanames{en}->{61891716} = "Leopold";
$areanames{en}->{61891717} = "Mitchell";
$areanames{en}->{61891718} = "Roebuck";
$areanames{en}->{61891719} = "Roebuck";
$areanames{en}->{6189172} = "Port\ Hedland";
$areanames{en}->{6189173} = "Port\ Hedland";
$areanames{en}->{6189174} = "Port\ Hedland";
$areanames{en}->{61891745} = "Newman";
$areanames{en}->{6189175} = "Newman";
$areanames{en}->{61891756} = "Whaleback";
$areanames{en}->{61891757} = "Whaleback";
$areanames{en}->{61891760} = "Marble\ Bar";
$areanames{en}->{61891761} = "Marble\ Bar";
$areanames{en}->{61891762} = "Whaleback";
$areanames{en}->{61891763} = "Whaleback";
$areanames{en}->{61891764} = "De\ Grey";
$areanames{en}->{61891765} = "Sandfire";
$areanames{en}->{61891766} = "Whaleback";
$areanames{en}->{61891767} = "De\ Grey\/Sandfire\/De\ Grey";
$areanames{en}->{61891768} = "De\ Grey";
$areanames{en}->{61891769} = "Great\ Sandy";
$areanames{en}->{6189177} = "Newman";
$areanames{en}->{61891770} = "Port\ Hedland";
$areanames{en}->{61891771} = "Port\ Hedland";
$areanames{en}->{61891772} = "Port\ Hedland";
$areanames{en}->{61891773} = "Port\ Hedland";
$areanames{en}->{61891780} = "Tom\ Price";
$areanames{en}->{61891781} = "Tom\ Price";
$areanames{en}->{61891782} = "Whaleback";
$areanames{en}->{61891783} = "Millstream";
$areanames{en}->{61891784} = "Millstream";
$areanames{en}->{61891785} = "Kununurra";
$areanames{en}->{61891786} = "Kununurra";
$areanames{en}->{61891787} = "Marble\ Bar";
$areanames{en}->{61891788} = "Marble\ Bar";
$areanames{en}->{61891789} = "Millstream";
$areanames{en}->{61891790} = "Sandfire";
$areanames{en}->{61891791} = "Telfer";
$areanames{en}->{61891792} = "Telfer";
$areanames{en}->{61891793} = "Whaleback";
$areanames{en}->{61891794} = "Whaleback";
$areanames{en}->{61891795} = "Whaleback";
$areanames{en}->{61891796} = "Whaleback";
$areanames{en}->{61891797} = "Whaleback";
$areanames{en}->{61891798} = "Telfer";
$areanames{en}->{61891799} = "Telfer";
$areanames{en}->{61891800} = "Sandfire";
$areanames{en}->{61891801} = "Sandfire";
$areanames{en}->{61891802} = "Sandfire";
$areanames{en}->{61891810} = "Tom\ Price";
$areanames{en}->{61891811} = "Tom\ Price";
$areanames{en}->{61891812} = "Onslow";
$areanames{en}->{61891813} = "Onslow";
$areanames{en}->{61891814} = "Newman";
$areanames{en}->{61891815} = "Newman";
$areanames{en}->{61891816} = "Onslow";
$areanames{en}->{61891819} = "Mount\ Bruce";
$areanames{en}->{6189182} = "Karratha";
$areanames{en}->{6189183} = "Dampier";
$areanames{en}->{61891835} = "Karratha";
$areanames{en}->{61891836} = "Karratha";
$areanames{en}->{61891838} = "Karratha";
$areanames{en}->{61891839} = "Karratha";
$areanames{en}->{61891840} = "Pannawonica";
$areanames{en}->{61891841} = "Pannawonica";
$areanames{en}->{61891842} = "Pannawonica";
$areanames{en}->{61891843} = "Onslow";
$areanames{en}->{61891844} = "Millstream";
$areanames{en}->{61891845} = "Millstream";
$areanames{en}->{61891846} = "Onslow";
$areanames{en}->{61891847} = "Onslow";
$areanames{en}->{61891848} = "Millstream";
$areanames{en}->{61891849} = "Onslow";
$areanames{en}->{6189185} = "Karratha";
$areanames{en}->{6189186} = "Karratha";
$areanames{en}->{6189187} = "Karratha";
$areanames{en}->{6189188} = "Tom\ Price";
$areanames{en}->{61891888} = "Mount\ Bruce";
$areanames{en}->{61891890} = "Tom\ Price";
$areanames{en}->{61891891} = "Tom\ Price";
$areanames{en}->{61891892} = "Tom\ Price";
$areanames{en}->{61891893} = "Tom\ Price";
$areanames{en}->{61891894} = "Paraburdoo";
$areanames{en}->{61891895} = "Paraburdoo";
$areanames{en}->{61891896} = "Paraburdoo";
$areanames{en}->{61891897} = "Wittenoom";
$areanames{en}->{61891898} = "Mount\ Bruce";
$areanames{en}->{61891899} = "Wittenoom";
$areanames{en}->{61891902} = "Paraburdoo";
$areanames{en}->{61891903} = "Paraburdoo";
$areanames{en}->{61891904} = "Paraburdoo";
$areanames{en}->{61891905} = "Tom\ Price";
$areanames{en}->{61891906} = "Whaleback";
$areanames{en}->{61891907} = "Whaleback";
$areanames{en}->{61891908} = "Whaleback";
$areanames{en}->{61891909} = "Port\ Hedland";
$areanames{en}->{61891910} = "Derby";
$areanames{en}->{61891911} = "Derby";
$areanames{en}->{61891912} = "Derby";
$areanames{en}->{61891913} = "Broome";
$areanames{en}->{61891914} = "Leopold";
$areanames{en}->{61891915} = "Fitzroy\ Crossing";
$areanames{en}->{61891916} = "Leopold";
$areanames{en}->{61891917} = "Leopold";
$areanames{en}->{61891918} = "Broome";
$areanames{en}->{61891919} = "Broome";
$areanames{en}->{6189192} = "Broome";
$areanames{en}->{61891924} = "Roebuck";
$areanames{en}->{61891930} = "Fitzroy\ Crossing";
$areanames{en}->{61891931} = "Derby";
$areanames{en}->{61891932} = "Derby";
$areanames{en}->{61891933} = "Derby";
$areanames{en}->{61891934} = "Roebuck";
$areanames{en}->{61891935} = "Broome";
$areanames{en}->{61891936} = "Broome";
$areanames{en}->{61891937} = "Broome";
$areanames{en}->{61891938} = "Broome";
$areanames{en}->{61891939} = "Derby";
$areanames{en}->{6189194} = "Broome";
$areanames{en}->{61891950} = "Broome";
$areanames{en}->{61891951} = "Broome";
$areanames{en}->{61891952} = "Broome";
$areanames{en}->{61891953} = "Broome";
$areanames{en}->{61891954} = "Broome";
$areanames{en}->{61891955} = "Broome";
$areanames{en}->{61891956} = "Broome";
$areanames{en}->{61891957} = "Broome";
$areanames{en}->{61891959} = "Cocos\ Island";
$areanames{en}->{61891960} = "Broome";
$areanames{en}->{61891961} = "Derby";
$areanames{en}->{61891962} = "Fitzroy\ Crossing";
$areanames{en}->{61891963} = "Kununurra";
$areanames{en}->{61891964} = "Leopold";
$areanames{en}->{61891965} = "Mitchell";
$areanames{en}->{61891966} = "Ord";
$areanames{en}->{61891967} = "Roebuck";
$areanames{en}->{61891968} = "Wyndham";
$areanames{en}->{61891969} = "Great\ Sandy";
$areanames{en}->{61891970} = "Dampier";
$areanames{en}->{61891971} = "De\ Grey";
$areanames{en}->{61891972} = "Karratha";
$areanames{en}->{61891973} = "Marble\ Bar";
$areanames{en}->{61891974} = "Millstream";
$areanames{en}->{61891975} = "Mount\ Bruce";
$areanames{en}->{61891976} = "Newman";
$areanames{en}->{61891977} = "Onslow";
$areanames{en}->{61891978} = "Pannawonica";
$areanames{en}->{61891979} = "Paraburdoo";
$areanames{en}->{61891980} = "Sandfire";
$areanames{en}->{61891981} = "Telfer";
$areanames{en}->{61891982} = "Tom\ Price";
$areanames{en}->{61891983} = "Whaleback";
$areanames{en}->{61891984} = "Wittenoom";
$areanames{en}->{61891985} = "Millstream";
$areanames{en}->{61891986} = "Millstream";
$areanames{en}->{61891987} = "Millstream";
$areanames{en}->{61891988} = "Millstream";
$areanames{en}->{61891999} = "Karratha";
$areanames{en}->{618920} = "Perth";
$areanames{en}->{6189206} = "Wanneroo";
$areanames{en}->{6189210} = "Perth";
$areanames{en}->{618922} = "Perth";
$areanames{en}->{618923} = "Perth";
$areanames{en}->{6189233} = "Wanneroo";
$areanames{en}->{6189234} = "Armadale";
$areanames{en}->{6189236} = "Spearwood";
$areanames{en}->{6189239} = "Fremantle";
$areanames{en}->{618925} = "Perth";
$areanames{en}->{6189252} = "Kalamunda";
$areanames{en}->{6189255} = "Kalamunda";
$areanames{en}->{6189257} = "Kalamunda";
$areanames{en}->{618926} = "Perth";
$areanames{en}->{618927} = "Perth";
$areanames{en}->{618929} = "Kalamunda";
$areanames{en}->{6189292} = "Rottnest";
$areanames{en}->{6189296} = "Herne\ Hill";
$areanames{en}->{6189297} = "Herne\ Hill";
$areanames{en}->{6189308} = "Wanneroo";
$areanames{en}->{6189309} = "Wanneroo";
$areanames{en}->{61893244} = "Perth";
$areanames{en}->{618933} = "Perth";
$areanames{en}->{6189335} = "Fremantle";
$areanames{en}->{6189336} = "Fremantle";
$areanames{en}->{618934} = "Perth";
$areanames{en}->{618937} = "Perth";
$areanames{en}->{6189372} = "Rottnest";
$areanames{en}->{618938} = "Perth";
$areanames{en}->{618939} = "Armadale";
$areanames{en}->{6189392} = "Perth";
$areanames{en}->{6189395} = "Spearwood";
$areanames{en}->{61893950} = "Herne\ Hill";
$areanames{en}->{61893951} = "Herne\ Hill";
$areanames{en}->{61893952} = "Herne\ Hill";
$areanames{en}->{618940} = "Wanneroo";
$areanames{en}->{618941} = "Spearwood";
$areanames{en}->{6189413} = "Perth";
$areanames{en}->{6189415} = "Perth";
$areanames{en}->{6189416} = "Perth";
$areanames{en}->{618942} = "Perth";
$areanames{en}->{6189430} = "Fremantle";
$areanames{en}->{6189431} = "Fremantle";
$areanames{en}->{6189432} = "Fremantle";
$areanames{en}->{6189433} = "Fremantle";
$areanames{en}->{6189434} = "Spearwood";
$areanames{en}->{6189435} = "Fremantle";
$areanames{en}->{6189436} = "Perth";
$areanames{en}->{6189437} = "Spearwood";
$areanames{en}->{6189438} = "Perth";
$areanames{en}->{6189439} = "Spearwood";
$areanames{en}->{618944} = "Perth";
$areanames{en}->{6189460} = "Perth";
$areanames{en}->{6189463} = "Perth";
$areanames{en}->{6189464} = "Perth";
$areanames{en}->{6189465} = "Perth";
$areanames{en}->{6189466} = "Perth";
$areanames{en}->{61894674} = "Perth";
$areanames{en}->{6189468} = "Perth";
$areanames{en}->{6189469} = "Perth";
$areanames{en}->{61894760} = "Perth";
$areanames{en}->{6189480} = "Perth";
$areanames{en}->{61894819} = "Perth";
$areanames{en}->{61894828} = "Perth";
$areanames{en}->{61894829} = "Perth";
$areanames{en}->{61894836} = "Perth";
$areanames{en}->{6189484} = "Perth";
$areanames{en}->{61894857} = "Perth";
$areanames{en}->{6189490} = "Armadale";
$areanames{en}->{6189491} = "Perth";
$areanames{en}->{6189492} = "Perth";
$areanames{en}->{6189493} = "Perth";
$areanames{en}->{6189494} = "Spearwood";
$areanames{en}->{6189495} = "Armadale";
$areanames{en}->{6189496} = "Armadale";
$areanames{en}->{6189497} = "Armadale";
$areanames{en}->{6189498} = "Armadale";
$areanames{en}->{61894985} = "Spearwood";
$areanames{en}->{61894986} = "Spearwood";
$areanames{en}->{61894987} = "Spearwood";
$areanames{en}->{6189499} = "Spearwood";
$areanames{en}->{6189500} = "Rockingham";
$areanames{en}->{61895003} = "Mandurah";
$areanames{en}->{61895004} = "Mandurah";
$areanames{en}->{61895005} = "Mandurah";
$areanames{en}->{6189501} = "Bullsbrook\ East";
$areanames{en}->{61895019} = "Rockingham";
$areanames{en}->{61895020} = "Bakers\ Hill";
$areanames{en}->{61895021} = "Bakers\ Hill";
$areanames{en}->{61895022} = "Bakers\ Hill";
$areanames{en}->{61895023} = "Bindoon";
$areanames{en}->{61895024} = "Bindoon";
$areanames{en}->{61895025} = "Bindoon";
$areanames{en}->{61895026} = "Bullsbrook\ East";
$areanames{en}->{61895027} = "Bullsbrook\ East";
$areanames{en}->{61895028} = "Bullsbrook\ East";
$areanames{en}->{61895029} = "Yanchep";
$areanames{en}->{61895030} = "Byford";
$areanames{en}->{61895031} = "Byford";
$areanames{en}->{61895032} = "Byford";
$areanames{en}->{61895033} = "Dwellingup";
$areanames{en}->{61895034} = "Dwellingup";
$areanames{en}->{61895035} = "Dwellingup";
$areanames{en}->{61895036} = "Gidgegannup";
$areanames{en}->{61895037} = "Gidgegannup";
$areanames{en}->{61895038} = "Gidgegannup";
$areanames{en}->{61895039} = "Bindoon";
$areanames{en}->{61895040} = "Gingin";
$areanames{en}->{61895041} = "Gingin";
$areanames{en}->{61895042} = "Gingin";
$areanames{en}->{61895043} = "Guilderton";
$areanames{en}->{61895044} = "Guilderton";
$areanames{en}->{61895045} = "Guilderton";
$areanames{en}->{61895046} = "Mount\ Helena";
$areanames{en}->{61895047} = "Mount\ Helena";
$areanames{en}->{61895048} = "Mount\ Helena";
$areanames{en}->{61895049} = "Bullsbrook\ East";
$areanames{en}->{61895050} = "Mount\ Wells";
$areanames{en}->{61895051} = "Mount\ Wells";
$areanames{en}->{61895052} = "Mount\ Wells";
$areanames{en}->{61895053} = "Pinjarra";
$areanames{en}->{61895054} = "Pinjarra";
$areanames{en}->{61895055} = "Pinjarra";
$areanames{en}->{61895056} = "Rockingham";
$areanames{en}->{61895057} = "Rockingham";
$areanames{en}->{61895058} = "Rockingham";
$areanames{en}->{61895059} = "Rockingham";
$areanames{en}->{61895060} = "Toodyay";
$areanames{en}->{61895061} = "Toodyay";
$areanames{en}->{61895062} = "Toodyay";
$areanames{en}->{61895063} = "Yanchep";
$areanames{en}->{61895064} = "Yanchep";
$areanames{en}->{61895065} = "Yanchep";
$areanames{en}->{61895066} = "Gidgegannup";
$areanames{en}->{61895067} = "Gingin";
$areanames{en}->{61895068} = "Guilderton";
$areanames{en}->{61895069} = "Mount\ Helena";
$areanames{en}->{61895070} = "Bakers\ Hill";
$areanames{en}->{61895071} = "Toodyay";
$areanames{en}->{61895072} = "Byford";
$areanames{en}->{61895073} = "Dwellingup";
$areanames{en}->{61895074} = "Mount\ Wells";
$areanames{en}->{61895075} = "Pinjarra";
$areanames{en}->{61895076} = "Rockingham";
$areanames{en}->{61895077} = "Lake\ Clifton";
$areanames{en}->{61895078} = "Mandurah";
$areanames{en}->{61895079} = "Waroona";
$areanames{en}->{61895080} = "Bindoon";
$areanames{en}->{61895081} = "Bullsbrook\ East";
$areanames{en}->{61895082} = "Gidgegannup";
$areanames{en}->{61895083} = "Gingin";
$areanames{en}->{61895084} = "Guilderton";
$areanames{en}->{61895085} = "Mount\ Helena";
$areanames{en}->{61895086} = "Yanchep";
$areanames{en}->{61895087} = "Bakers\ Hill";
$areanames{en}->{61895088} = "Toodyay";
$areanames{en}->{61895089} = "Byford";
$areanames{en}->{61895090} = "Dwellingup";
$areanames{en}->{61895091} = "Lake\ Clifton";
$areanames{en}->{61895092} = "Mandurah";
$areanames{en}->{61895093} = "Mount\ Wells";
$areanames{en}->{61895094} = "Pinjarra";
$areanames{en}->{61895095} = "Rockingham";
$areanames{en}->{61895096} = "Waroona";
$areanames{en}->{61895097} = "Yanchep";
$areanames{en}->{61895098} = "Bindoon";
$areanames{en}->{61895099} = "Bullsbrook\ East";
$areanames{en}->{61895100} = "Gidgegannup";
$areanames{en}->{61895101} = "Gingin";
$areanames{en}->{61895102} = "Guilderton";
$areanames{en}->{61895103} = "Mount\ Helena";
$areanames{en}->{61895104} = "Bakers\ Hill";
$areanames{en}->{61895105} = "Toodyay";
$areanames{en}->{61895106} = "Byford";
$areanames{en}->{61895107} = "Dwellingup";
$areanames{en}->{61895108} = "Lake\ Clifton";
$areanames{en}->{61895109} = "Mandurah";
$areanames{en}->{61895110} = "Mount\ Wells";
$areanames{en}->{61895111} = "Pinjarra";
$areanames{en}->{61895112} = "Waroona";
$areanames{en}->{61895113} = "Bindoon";
$areanames{en}->{61895114} = "Bullsbrook\ East";
$areanames{en}->{61895115} = "Gidgegannup";
$areanames{en}->{61895116} = "Bindoon";
$areanames{en}->{61895117} = "Bullsbrook\ East";
$areanames{en}->{61895118} = "Gidgegannup";
$areanames{en}->{61895119} = "Gingin";
$areanames{en}->{61895120} = "Guilderton";
$areanames{en}->{61895121} = "Mount\ Helena";
$areanames{en}->{61895122} = "Yanchep";
$areanames{en}->{61895123} = "Bakers\ Hill";
$areanames{en}->{61895124} = "Toodyay";
$areanames{en}->{61895125} = "Byford";
$areanames{en}->{61895126} = "Dwellingup";
$areanames{en}->{61895127} = "Lake\ Clifton";
$areanames{en}->{61895128} = "Mandurah";
$areanames{en}->{61895129} = "Mount\ Wells";
$areanames{en}->{61895130} = "Pinjarra";
$areanames{en}->{61895131} = "Rockingham";
$areanames{en}->{61895132} = "Waroona";
$areanames{en}->{61895133} = "Bindoon";
$areanames{en}->{61895134} = "Bullsbrook\ East";
$areanames{en}->{61895135} = "Gidgegannup";
$areanames{en}->{61895136} = "Gingin";
$areanames{en}->{61895137} = "Guilderton";
$areanames{en}->{61895138} = "Mount\ Helena";
$areanames{en}->{61895139} = "Yanchep";
$areanames{en}->{61895140} = "Bakers\ Hill";
$areanames{en}->{61895141} = "Toodyay";
$areanames{en}->{61895142} = "Byford";
$areanames{en}->{61895143} = "Dwellingup";
$areanames{en}->{61895144} = "Lake\ Clifton";
$areanames{en}->{61895145} = "Mandurah";
$areanames{en}->{61895146} = "Mount\ Wells";
$areanames{en}->{61895147} = "Pinjarra";
$areanames{en}->{61895148} = "Waroona";
$areanames{en}->{61895149} = "Gingin";
$areanames{en}->{61895150} = "Guilderton";
$areanames{en}->{61895151} = "Mount\ Helena";
$areanames{en}->{61895152} = "Yanchep";
$areanames{en}->{61895153} = "Bakers\ Hill";
$areanames{en}->{61895154} = "Toodyay";
$areanames{en}->{61895155} = "Byford";
$areanames{en}->{61895156} = "Dwellingup";
$areanames{en}->{61895157} = "Lake\ Clifton";
$areanames{en}->{61895158} = "Mandurah";
$areanames{en}->{61895159} = "Mount\ Wells";
$areanames{en}->{61895160} = "Pinjarra";
$areanames{en}->{61895161} = "Rockingham";
$areanames{en}->{61895162} = "Waroona";
$areanames{en}->{61895163} = "Bindoon";
$areanames{en}->{61895164} = "Bullsbrook\ East";
$areanames{en}->{61895165} = "Gidgegannup";
$areanames{en}->{61895166} = "Gingin";
$areanames{en}->{61895167} = "Guilderton";
$areanames{en}->{61895168} = "Mount\ Helena";
$areanames{en}->{61895169} = "Yanchep";
$areanames{en}->{61895170} = "Bakers\ Hill";
$areanames{en}->{61895171} = "Toodyay";
$areanames{en}->{61895172} = "Byford";
$areanames{en}->{61895173} = "Dwellingup";
$areanames{en}->{61895174} = "Byford";
$areanames{en}->{61895175} = "Mandurah";
$areanames{en}->{61895176} = "Mount\ Wells";
$areanames{en}->{61895177} = "Pinjarra";
$areanames{en}->{61895178} = "Rockingham";
$areanames{en}->{61895179} = "Dwellingup";
$areanames{en}->{61895180} = "Byford";
$areanames{en}->{61895181} = "Mandurah";
$areanames{en}->{61895182} = "Rockingham";
$areanames{en}->{61895183} = "Rockingham";
$areanames{en}->{61895184} = "Rockingham";
$areanames{en}->{61895185} = "Yanchep";
$areanames{en}->{61895186} = "Yanchep";
$areanames{en}->{61895187} = "Pinjarra";
$areanames{en}->{61895188} = "Pinjarra";
$areanames{en}->{61895189} = "Mandurah";
$areanames{en}->{6189519} = "Mount\ Helena";
$areanames{en}->{61895200} = "Bullsbrook\ East";
$areanames{en}->{61895201} = "Rockingham";
$areanames{en}->{61895202} = "Rockingham";
$areanames{en}->{61895203} = "Pinjarra";
$areanames{en}->{61895204} = "Pinjarra";
$areanames{en}->{61895205} = "Rockingham";
$areanames{en}->{61895206} = "Mount\ Wells";
$areanames{en}->{61895207} = "Byford";
$areanames{en}->{61895208} = "Mandurah";
$areanames{en}->{61895209} = "Lake\ Clifton";
$areanames{en}->{6189521} = "Pinjarra";
$areanames{en}->{61895213} = "Dwellingup";
$areanames{en}->{61895215} = "Rockingham";
$areanames{en}->{61895216} = "Mandurah";
$areanames{en}->{61895219} = "Mandurah";
$areanames{en}->{6189522} = "Mandurah";
$areanames{en}->{6189523} = "Rockingham";
$areanames{en}->{6189524} = "Rockingham";
$areanames{en}->{6189525} = "Byford";
$areanames{en}->{6189526} = "Byford";
$areanames{en}->{6189527} = "Rockingham";
$areanames{en}->{6189528} = "Rockingham";
$areanames{en}->{6189529} = "Rockingham";
$areanames{en}->{6189530} = "Pinjarra";
$areanames{en}->{6189531} = "Pinjarra";
$areanames{en}->{61895318} = "Mandurah";
$areanames{en}->{61895319} = "Mandurah";
$areanames{en}->{61895320} = "Byford";
$areanames{en}->{61895321} = "Rockingham";
$areanames{en}->{61895322} = "Pinjarra";
$areanames{en}->{61895323} = "Guilderton";
$areanames{en}->{61895324} = "Mount\ Wells";
$areanames{en}->{61895325} = "Byford";
$areanames{en}->{61895326} = "Pinjarra";
$areanames{en}->{61895327} = "Bullsbrook\ East";
$areanames{en}->{61895328} = "Waroona";
$areanames{en}->{61895329} = "Mount\ Wells";
$areanames{en}->{6189533} = "Rockingham";
$areanames{en}->{6189534} = "Mandurah";
$areanames{en}->{6189535} = "Mandurah";
$areanames{en}->{61895360} = "Mount\ Helena";
$areanames{en}->{61895361} = "Mount\ Helena";
$areanames{en}->{61895362} = "Mandurah";
$areanames{en}->{61895363} = "Mandurah";
$areanames{en}->{61895364} = "Gidgegannup";
$areanames{en}->{61895365} = "Gidgegannup";
$areanames{en}->{61895366} = "Byford";
$areanames{en}->{61895367} = "Byford";
$areanames{en}->{61895368} = "Mandurah";
$areanames{en}->{61895369} = "Gidgegannup";
$areanames{en}->{6189537} = "Mandurah";
$areanames{en}->{6189538} = "Dwellingup";
$areanames{en}->{61895384} = "Mount\ Wells";
$areanames{en}->{61895390} = "Toodyay";
$areanames{en}->{61895391} = "Mount\ Helena";
$areanames{en}->{61895392} = "Bakers\ Hill";
$areanames{en}->{61895393} = "Lake\ Clifton";
$areanames{en}->{61895394} = "Mandurah";
$areanames{en}->{61895395} = "Toodyay";
$areanames{en}->{61895396} = "Dwellingup";
$areanames{en}->{61895397} = "Gingin";
$areanames{en}->{61895398} = "Bindoon";
$areanames{en}->{61895399} = "Pinjarra";
$areanames{en}->{61895400} = "Rockingham";
$areanames{en}->{61895401} = "Gidgegannup";
$areanames{en}->{61895402} = "Pinjarra";
$areanames{en}->{61895403} = "Yanchep";
$areanames{en}->{61895404} = "Rockingham";
$areanames{en}->{61895405} = "Guilderton";
$areanames{en}->{61895406} = "Mount\ Wells";
$areanames{en}->{61895407} = "Pinjarra";
$areanames{en}->{61895408} = "Guilderton";
$areanames{en}->{61895409} = "Waroona";
$areanames{en}->{61895410} = "Yanchep";
$areanames{en}->{61895411} = "Byford";
$areanames{en}->{61895412} = "Bullsbrook\ East";
$areanames{en}->{61895413} = "Mount\ Wells";
$areanames{en}->{61895414} = "Waroona";
$areanames{en}->{61895415} = "Mount\ Helena";
$areanames{en}->{61895416} = "Bakers\ Hill";
$areanames{en}->{61895417} = "Lake\ Clifton";
$areanames{en}->{61895418} = "Mandurah";
$areanames{en}->{61895419} = "Mount\ Wells";
$areanames{en}->{61895420} = "Pinjarra";
$areanames{en}->{61895421} = "Byford";
$areanames{en}->{61895422} = "Toodyay";
$areanames{en}->{61895423} = "Dwellingup";
$areanames{en}->{61895424} = "Gingin";
$areanames{en}->{61895425} = "Bindoon";
$areanames{en}->{61895426} = "Gidgegannup";
$areanames{en}->{61895427} = "Pinjarra";
$areanames{en}->{61895428} = "Yanchep";
$areanames{en}->{61895429} = "Mandurah";
$areanames{en}->{61895430} = "Bakers\ Hill";
$areanames{en}->{61895431} = "Bullsbrook\ East";
$areanames{en}->{61895432} = "Waroona";
$areanames{en}->{61895433} = "Mount\ Helena";
$areanames{en}->{61895434} = "Bakers\ Hill";
$areanames{en}->{61895435} = "Lake\ Clifton";
$areanames{en}->{61895436} = "Toodyay";
$areanames{en}->{61895437} = "Dwellingup";
$areanames{en}->{61895438} = "Gingin";
$areanames{en}->{61895439} = "Bindoon";
$areanames{en}->{61895440} = "Bullsbrook\ East";
$areanames{en}->{61895441} = "Bindoon";
$areanames{en}->{61895442} = "Gidgegannup";
$areanames{en}->{61895443} = "Yanchep";
$areanames{en}->{61895444} = "Pinjarra";
$areanames{en}->{61895445} = "Mandurah";
$areanames{en}->{61895446} = "Rockingham";
$areanames{en}->{61895447} = "Byford";
$areanames{en}->{61895448} = "Dwellingup";
$areanames{en}->{61895449} = "Gidgegannup";
$areanames{en}->{61895450} = "Gingin";
$areanames{en}->{61895451} = "Guilderton";
$areanames{en}->{61895452} = "Mandurah";
$areanames{en}->{61895453} = "Mount\ Helena";
$areanames{en}->{61895454} = "Mount\ Wells";
$areanames{en}->{61895455} = "Pinjarra";
$areanames{en}->{61895456} = "Rockingham";
$areanames{en}->{61895457} = "Toodyay";
$areanames{en}->{61895458} = "Yanchep";
$areanames{en}->{61895459} = "Bakers\ Hill";
$areanames{en}->{61895460} = "Bindoon";
$areanames{en}->{61895461} = "Bullsbrook\ East";
$areanames{en}->{61895462} = "Byford";
$areanames{en}->{61895463} = "Dwellingup";
$areanames{en}->{61895464} = "Gidgegannup";
$areanames{en}->{61895465} = "Gingin";
$areanames{en}->{61895466} = "Guilderton";
$areanames{en}->{61895467} = "Mandurah";
$areanames{en}->{61895468} = "Mount\ Helena";
$areanames{en}->{61895469} = "Mount\ Wells";
$areanames{en}->{61895470} = "Pinjarra";
$areanames{en}->{61895471} = "Rockingham";
$areanames{en}->{61895472} = "Toodyay";
$areanames{en}->{61895473} = "Yanchep";
$areanames{en}->{61895474} = "Mandurah";
$areanames{en}->{61895475} = "Bakers\ Hill";
$areanames{en}->{61895476} = "Bindoon";
$areanames{en}->{61895477} = "Bullsbrook\ East";
$areanames{en}->{61895478} = "Byford";
$areanames{en}->{61895479} = "Dwellingup";
$areanames{en}->{61895480} = "Gidgegannup";
$areanames{en}->{61895481} = "Gingin";
$areanames{en}->{61895482} = "Guilderton";
$areanames{en}->{61895483} = "Mandurah";
$areanames{en}->{61895484} = "Mount\ Helena";
$areanames{en}->{61895485} = "Mount\ Wells";
$areanames{en}->{61895486} = "Pinjarra";
$areanames{en}->{61895487} = "Rockingham";
$areanames{en}->{61895488} = "Toodyay";
$areanames{en}->{61895489} = "Yanchep";
$areanames{en}->{61895490} = "Bakers\ Hill";
$areanames{en}->{61895491} = "Bindoon";
$areanames{en}->{61895492} = "Bullsbrook\ East";
$areanames{en}->{61895493} = "Byford";
$areanames{en}->{61895494} = "Dwellingup";
$areanames{en}->{61895495} = "Gidgegannup";
$areanames{en}->{61895496} = "Gingin";
$areanames{en}->{61895497} = "Guilderton";
$areanames{en}->{61895498} = "Mandurah";
$areanames{en}->{61895499} = "Mount\ Helena";
$areanames{en}->{61895500} = "Rockingham";
$areanames{en}->{61895501} = "Rockingham";
$areanames{en}->{61895502} = "Mandurah";
$areanames{en}->{61895503} = "Mandurah";
$areanames{en}->{61895504} = "Mandurah";
$areanames{en}->{61895505} = "Pinjarra";
$areanames{en}->{61895506} = "Byford";
$areanames{en}->{61895507} = "Rockingham";
$areanames{en}->{61895508} = "Rockingham";
$areanames{en}->{61895509} = "Rockingham";
$areanames{en}->{61895510} = "Bindoon";
$areanames{en}->{61895511} = "Bullsbrook\ East";
$areanames{en}->{61895512} = "Gidgegannup";
$areanames{en}->{61895513} = "Gingin";
$areanames{en}->{61895514} = "Mount\ Helena";
$areanames{en}->{61895515} = "Yanchep";
$areanames{en}->{61895516} = "Guilderton";
$areanames{en}->{61895517} = "Bakers\ Hill";
$areanames{en}->{61895518} = "Bullsbrook\ East";
$areanames{en}->{61895519} = "Bullsbrook\ East";
$areanames{en}->{61895520} = "Gingin";
$areanames{en}->{61895521} = "Gingin";
$areanames{en}->{61895522} = "Guilderton";
$areanames{en}->{61895523} = "Guilderton";
$areanames{en}->{61895524} = "Bakers\ Hill";
$areanames{en}->{61895525} = "Bakers\ Hill";
$areanames{en}->{61895526} = "Dwellingup";
$areanames{en}->{61895527} = "Dwellingup";
$areanames{en}->{61895528} = "Bindoon";
$areanames{en}->{61895529} = "Bindoon";
$areanames{en}->{6189553} = "Rockingham";
$areanames{en}->{61895540} = "Yanchep";
$areanames{en}->{61895541} = "Yanchep";
$areanames{en}->{61895542} = "Yanchep";
$areanames{en}->{61895543} = "Mandurah";
$areanames{en}->{61895544} = "Mandurah";
$areanames{en}->{61895545} = "Rockingham";
$areanames{en}->{61895546} = "Rockingham";
$areanames{en}->{61895547} = "Bakers\ Hill";
$areanames{en}->{61895548} = "Bindoon";
$areanames{en}->{61895549} = "Bullsbrook\ East";
$areanames{en}->{61895550} = "Byford";
$areanames{en}->{61895551} = "Dwellingup";
$areanames{en}->{61895552} = "Gidgegannup";
$areanames{en}->{61895553} = "Mandurah";
$areanames{en}->{61895554} = "Mandurah";
$areanames{en}->{61895555} = "Pinjarra";
$areanames{en}->{61895556} = "Mount\ Wells";
$areanames{en}->{61895557} = "Mount\ Wells";
$areanames{en}->{61895558} = "Mandurah";
$areanames{en}->{61895559} = "Mandurah";
$areanames{en}->{6189556} = "Rockingham";
$areanames{en}->{61895570} = "Rockingham";
$areanames{en}->{61895571} = "Rockingham";
$areanames{en}->{61895572} = "Rockingham";
$areanames{en}->{61895573} = "Byford";
$areanames{en}->{61895574} = "Pinjarra";
$areanames{en}->{61895575} = "Mandurah";
$areanames{en}->{61895576} = "Rockingham";
$areanames{en}->{61895577} = "Pinjarra";
$areanames{en}->{61895578} = "Pinjarra";
$areanames{en}->{61895579} = "Pinjarra";
$areanames{en}->{61895580} = "Gingin";
$areanames{en}->{61895581} = "Guilderton";
$areanames{en}->{61895582} = "Mandurah";
$areanames{en}->{61895583} = "Mount\ Helena";
$areanames{en}->{61895584} = "Mount\ Wells";
$areanames{en}->{61895585} = "Pinjarra";
$areanames{en}->{61895586} = "Rockingham";
$areanames{en}->{61895587} = "Toodyay";
$areanames{en}->{61895588} = "Yanchep";
$areanames{en}->{61895589} = "Rockingham";
$areanames{en}->{61895590} = "Pinjarra";
$areanames{en}->{61895591} = "Mandurah";
$areanames{en}->{61895592} = "Mandurah";
$areanames{en}->{61895593} = "Mandurah";
$areanames{en}->{61895594} = "Mandurah";
$areanames{en}->{61895595} = "Mandurah";
$areanames{en}->{61895596} = "Rockingham";
$areanames{en}->{61895597} = "Rockingham";
$areanames{en}->{61895598} = "Rockingham";
$areanames{en}->{61895599} = "Mount\ Wells";
$areanames{en}->{61895600} = "Pinjarra";
$areanames{en}->{61895601} = "Rockingham";
$areanames{en}->{61895602} = "Toodyay";
$areanames{en}->{61895603} = "Yanchep";
$areanames{en}->{61895604} = "Bakers\ Hill";
$areanames{en}->{61895605} = "Bindoon";
$areanames{en}->{61895606} = "Bullsbrook\ East";
$areanames{en}->{61895607} = "Byford";
$areanames{en}->{61895608} = "Dwellingup";
$areanames{en}->{61895609} = "Gidgegannup";
$areanames{en}->{6189561} = "Yanchep";
$areanames{en}->{6189562} = "Yanchep";
$areanames{en}->{61895630} = "Yanchep";
$areanames{en}->{61895631} = "Yanchep";
$areanames{en}->{61895632} = "Yanchep";
$areanames{en}->{61895633} = "Yanchep";
$areanames{en}->{61895634} = "Yanchep";
$areanames{en}->{61895635} = "Gingin";
$areanames{en}->{61895636} = "Guilderton";
$areanames{en}->{61895637} = "Mandurah";
$areanames{en}->{61895638} = "Mount\ Helena";
$areanames{en}->{61895639} = "Mount\ Wells";
$areanames{en}->{61895640} = "Pinjarra";
$areanames{en}->{61895641} = "Rockingham";
$areanames{en}->{61895642} = "Toodyay";
$areanames{en}->{61895643} = "Yanchep";
$areanames{en}->{61895644} = "Bakers\ Hill";
$areanames{en}->{61895645} = "Bindoon";
$areanames{en}->{61895646} = "Bullsbrook\ East";
$areanames{en}->{61895647} = "Byford";
$areanames{en}->{61895648} = "Dwellingup";
$areanames{en}->{61895649} = "Gidgegannup";
$areanames{en}->{61895650} = "Gingin";
$areanames{en}->{61895651} = "Guilderton";
$areanames{en}->{61895652} = "Mandurah";
$areanames{en}->{61895653} = "Mount\ Helena";
$areanames{en}->{61895654} = "Mount\ Wells";
$areanames{en}->{61895655} = "Pinjarra";
$areanames{en}->{61895656} = "Rockingham";
$areanames{en}->{61895657} = "Toodyay";
$areanames{en}->{61895658} = "Yanchep";
$areanames{en}->{61895659} = "Mandurah";
$areanames{en}->{61895660} = "Bakers\ Hill";
$areanames{en}->{61895661} = "Bindoon";
$areanames{en}->{61895662} = "Bullsbrook\ East";
$areanames{en}->{61895663} = "Byford";
$areanames{en}->{61895664} = "Dwellingup";
$areanames{en}->{61895665} = "Gidgegannup";
$areanames{en}->{61895666} = "Gingin";
$areanames{en}->{61895667} = "Guilderton";
$areanames{en}->{61895668} = "Mandurah";
$areanames{en}->{61895669} = "Mount\ Helena";
$areanames{en}->{61895670} = "Mount\ Wells";
$areanames{en}->{61895671} = "Pinjarra";
$areanames{en}->{61895672} = "Rockingham";
$areanames{en}->{61895673} = "Toodyay";
$areanames{en}->{61895674} = "Yanchep";
$areanames{en}->{6189570} = "Bullsbrook\ East";
$areanames{en}->{6189571} = "Bullsbrook\ East";
$areanames{en}->{6189572} = "Mount\ Helena";
$areanames{en}->{61895729} = "Gidgegannup";
$areanames{en}->{6189573} = "Mount\ Helena";
$areanames{en}->{61895740} = "Bakers\ Hill";
$areanames{en}->{61895741} = "Bakers\ Hill";
$areanames{en}->{61895742} = "Toodyay";
$areanames{en}->{61895743} = "Bakers\ Hill";
$areanames{en}->{61895744} = "Toodyay";
$areanames{en}->{61895745} = "Toodyay";
$areanames{en}->{61895746} = "Gidgegannup";
$areanames{en}->{61895747} = "Gidgegannup";
$areanames{en}->{61895748} = "Gidgegannup";
$areanames{en}->{61895749} = "Toodyay";
$areanames{en}->{6189575} = "Gingin";
$areanames{en}->{6189576} = "Bindoon";
$areanames{en}->{6189577} = "Guilderton";
$areanames{en}->{61895780} = "Toodyay";
$areanames{en}->{61895781} = "Toodyay";
$areanames{en}->{61895782} = "Toodyay";
$areanames{en}->{61895783} = "Gidgegannup";
$areanames{en}->{61895784} = "Gidgegannup";
$areanames{en}->{61895785} = "Gidgegannup";
$areanames{en}->{61895786} = "Gingin";
$areanames{en}->{61895787} = "Gingin";
$areanames{en}->{61895788} = "Gingin";
$areanames{en}->{61895789} = "Gingin";
$areanames{en}->{6189579} = "Bindoon";
$areanames{en}->{61895796} = "Rockingham";
$areanames{en}->{61895797} = "Mount\ Helena";
$areanames{en}->{61895798} = "Mount\ Helena";
$areanames{en}->{61895799} = "Mount\ Helena";
$areanames{en}->{6189580} = "Rockingham";
$areanames{en}->{6189581} = "Mandurah";
$areanames{en}->{6189582} = "Mandurah";
$areanames{en}->{6189583} = "Mandurah";
$areanames{en}->{6189584} = "Mandurah";
$areanames{en}->{61895840} = "Toodyay";
$areanames{en}->{61895841} = "Toodyay";
$areanames{en}->{6189585} = "Mandurah";
$areanames{en}->{6189586} = "Mandurah";
$areanames{en}->{618958750} = "Mandurah";
$areanames{en}->{61895900} = "Yanchep";
$areanames{en}->{61895901} = "Bakers\ Hill";
$areanames{en}->{61895902} = "Byford";
$areanames{en}->{61895903} = "Dwellingup";
$areanames{en}->{61895904} = "Mount\ Wells";
$areanames{en}->{61895905} = "Pinjarra";
$areanames{en}->{61895906} = "Rockingham";
$areanames{en}->{61895907} = "Lake\ Clifton";
$areanames{en}->{61895908} = "Mandurah";
$areanames{en}->{61895909} = "Waroona";
$areanames{en}->{6189591} = "Rockingham";
$areanames{en}->{6189592} = "Rockingham";
$areanames{en}->{6189593} = "Rockingham";
$areanames{en}->{61895940} = "Rockingham";
$areanames{en}->{61895941} = "Rockingham";
$areanames{en}->{61895942} = "Rockingham";
$areanames{en}->{61895943} = "Toodyay";
$areanames{en}->{61895944} = "Gingin";
$areanames{en}->{61895945} = "Bindoon";
$areanames{en}->{61895946} = "Bullsbrook\ East";
$areanames{en}->{61895947} = "Gidgegannup";
$areanames{en}->{61895948} = "Guilderton";
$areanames{en}->{61895949} = "Mount\ Helena";
$areanames{en}->{61895950} = "Rockingham";
$areanames{en}->{61895951} = "Mandurah";
$areanames{en}->{61895952} = "Mandurah";
$areanames{en}->{61895953} = "Yanchep";
$areanames{en}->{61895954} = "Yanchep";
$areanames{en}->{61895955} = "Yanchep";
$areanames{en}->{61895956} = "Mandurah";
$areanames{en}->{61895957} = "Byford";
$areanames{en}->{61895958} = "Rockingham";
$areanames{en}->{61895959} = "Mandurah";
$areanames{en}->{6189599} = "Rockingham";
$areanames{en}->{61896000} = "Aldersyde";
$areanames{en}->{61896001} = "Aldersyde";
$areanames{en}->{61896002} = "Aldersyde";
$areanames{en}->{61896003} = "Badgerin\ Rock";
$areanames{en}->{61896004} = "Badgerin\ Rock";
$areanames{en}->{61896005} = "Badgerin\ Rock";
$areanames{en}->{61896006} = "Badgingarra";
$areanames{en}->{61896007} = "Badgingarra";
$areanames{en}->{61896008} = "Badgingarra";
$areanames{en}->{61896009} = "Badgingarra";
$areanames{en}->{61896010} = "Balkuling";
$areanames{en}->{61896011} = "Balkuling";
$areanames{en}->{61896012} = "Balkuling";
$areanames{en}->{61896013} = "Ballidu";
$areanames{en}->{61896014} = "Ballidu";
$areanames{en}->{61896015} = "Ballidu";
$areanames{en}->{61896016} = "Beacon";
$areanames{en}->{61896017} = "Beacon";
$areanames{en}->{61896018} = "Beacon";
$areanames{en}->{61896019} = "Bibby\ Springs";
$areanames{en}->{61896020} = "Beacon\ North";
$areanames{en}->{61896021} = "Beacon\ North";
$areanames{en}->{61896022} = "Beacon\ North";
$areanames{en}->{61896023} = "Bencubbin";
$areanames{en}->{61896024} = "Bencubbin";
$areanames{en}->{61896025} = "Bencubbin";
$areanames{en}->{61896026} = "Beverley";
$areanames{en}->{61896027} = "Beverley";
$areanames{en}->{61896028} = "Beverley";
$areanames{en}->{61896029} = "Bidaminna";
$areanames{en}->{61896030} = "Beverley\ West";
$areanames{en}->{61896031} = "Beverley\ West";
$areanames{en}->{61896032} = "Beverley\ West";
$areanames{en}->{61896033} = "Bibby\ Springs";
$areanames{en}->{61896034} = "Bibby\ Springs";
$areanames{en}->{61896035} = "Bibby\ Springs";
$areanames{en}->{61896036} = "Bidaminna";
$areanames{en}->{61896037} = "Bidaminna";
$areanames{en}->{61896038} = "Bidaminna";
$areanames{en}->{61896039} = "Coomallo";
$areanames{en}->{61896040} = "Bolgart";
$areanames{en}->{61896041} = "Bolgart";
$areanames{en}->{61896042} = "Bolgart";
$areanames{en}->{61896043} = "Brookton";
$areanames{en}->{61896044} = "Brookton";
$areanames{en}->{61896045} = "Brookton";
$areanames{en}->{61896046} = "Burakin";
$areanames{en}->{61896047} = "Burakin";
$areanames{en}->{61896048} = "Burakin";
$areanames{en}->{61896049} = "Coomberdale";
$areanames{en}->{61896050} = "Cadoux";
$areanames{en}->{61896051} = "Cadoux";
$areanames{en}->{61896052} = "Cadoux";
$areanames{en}->{61896053} = "Calingiri";
$areanames{en}->{61896054} = "Calingiri";
$areanames{en}->{61896055} = "Calingiri";
$areanames{en}->{61896056} = "Cleary\ North";
$areanames{en}->{61896057} = "Cleary\ North";
$areanames{en}->{61896058} = "Cleary\ North";
$areanames{en}->{61896059} = "Dandaragan";
$areanames{en}->{61896060} = "Coomallo";
$areanames{en}->{61896061} = "Coomallo";
$areanames{en}->{61896062} = "Coomallo";
$areanames{en}->{61896063} = "Coomberdale";
$areanames{en}->{61896064} = "Coomberdale";
$areanames{en}->{61896065} = "Coomberdale";
$areanames{en}->{61896066} = "Cunderdin";
$areanames{en}->{61896067} = "Cunderdin";
$areanames{en}->{61896068} = "Cunderdin";
$areanames{en}->{61896069} = "Gillingarra";
$areanames{en}->{61896070} = "Cunderdin\ North";
$areanames{en}->{61896071} = "Cunderdin\ North";
$areanames{en}->{61896072} = "Cunderdin\ North";
$areanames{en}->{61896073} = "Dale\ River";
$areanames{en}->{61896074} = "Dale\ River";
$areanames{en}->{61896075} = "Dale\ River";
$areanames{en}->{61896076} = "Dalwallinu";
$areanames{en}->{61896077} = "Dalwallinu";
$areanames{en}->{61896078} = "Dalwallinu";
$areanames{en}->{61896079} = "Jurien";
$areanames{en}->{61896080} = "Dalwallinu\ West";
$areanames{en}->{61896081} = "Dalwallinu\ West";
$areanames{en}->{61896082} = "Dalwallinu\ West";
$areanames{en}->{61896083} = "Dandaragan";
$areanames{en}->{61896084} = "Dandaragan";
$areanames{en}->{61896085} = "Dandaragan";
$areanames{en}->{61896086} = "Dangin";
$areanames{en}->{61896087} = "Dangin";
$areanames{en}->{61896088} = "Dangin";
$areanames{en}->{61896089} = "Lancelin";
$areanames{en}->{61896090} = "Dowerin";
$areanames{en}->{61896091} = "Dowerin";
$areanames{en}->{61896092} = "Dowerin";
$areanames{en}->{61896093} = "Dukin";
$areanames{en}->{61896094} = "Dukin";
$areanames{en}->{61896095} = "Dukin";
$areanames{en}->{61896096} = "Ejanding";
$areanames{en}->{61896097} = "Ejanding";
$areanames{en}->{61896098} = "Ejanding";
$areanames{en}->{61896099} = "Miling";
$areanames{en}->{61896100} = "Gabbin";
$areanames{en}->{61896101} = "Gabbin";
$areanames{en}->{61896102} = "Gabbin";
$areanames{en}->{61896103} = "Gabbin\ North";
$areanames{en}->{61896104} = "Gabbin\ North";
$areanames{en}->{61896105} = "Gabbin\ North";
$areanames{en}->{61896106} = "Gillingarra";
$areanames{en}->{61896107} = "Gillingarra";
$areanames{en}->{61896108} = "Gillingarra";
$areanames{en}->{61896109} = "Moora";
$areanames{en}->{61896110} = "Goodlands";
$areanames{en}->{61896111} = "Goodlands";
$areanames{en}->{61896112} = "Goodlands";
$areanames{en}->{61896113} = "Goomalling";
$areanames{en}->{61896114} = "Goomalling";
$areanames{en}->{61896115} = "Goomalling";
$areanames{en}->{61896116} = "Jelkobine";
$areanames{en}->{61896117} = "Jelkobine";
$areanames{en}->{61896118} = "Jelkobine";
$areanames{en}->{61896119} = "Regans\ Ford";
$areanames{en}->{61896120} = "Jennacubbine";
$areanames{en}->{61896121} = "Jennacubbine";
$areanames{en}->{61896122} = "Jennacubbine";
$areanames{en}->{61896123} = "Jurien";
$areanames{en}->{61896124} = "Jurien";
$areanames{en}->{61896125} = "Jurien";
$areanames{en}->{61896126} = "Kalannie";
$areanames{en}->{61896127} = "Kalannie";
$areanames{en}->{61896128} = "Kalannie";
$areanames{en}->{61896129} = "Wannamal";
$areanames{en}->{61896130} = "Kalannie\ East";
$areanames{en}->{61896131} = "Kalannie\ East";
$areanames{en}->{61896132} = "Kalannie\ East";
$areanames{en}->{61896133} = "Konnongorring";
$areanames{en}->{61896134} = "Konnongorring";
$areanames{en}->{61896135} = "Konnongorring";
$areanames{en}->{61896136} = "Koorda";
$areanames{en}->{61896137} = "Koorda";
$areanames{en}->{61896138} = "Koorda";
$areanames{en}->{61896139} = "Watheroo";
$areanames{en}->{61896140} = "Lancelin";
$areanames{en}->{61896141} = "Lancelin";
$areanames{en}->{61896142} = "Lancelin";
$areanames{en}->{61896143} = "Meckering";
$areanames{en}->{61896144} = "Meckering";
$areanames{en}->{61896145} = "Meckering";
$areanames{en}->{61896146} = "Miling";
$areanames{en}->{61896147} = "Miling";
$areanames{en}->{61896148} = "Miling";
$areanames{en}->{61896149} = "Yerecoin";
$areanames{en}->{61896150} = "Moora";
$areanames{en}->{61896151} = "Moora";
$areanames{en}->{61896152} = "Moora";
$areanames{en}->{61896153} = "Northam";
$areanames{en}->{61896154} = "Northam";
$areanames{en}->{61896155} = "Northam";
$areanames{en}->{61896156} = "Pantapin";
$areanames{en}->{61896157} = "Pantapin";
$areanames{en}->{61896158} = "Pantapin";
$areanames{en}->{61896159} = "Bolgart";
$areanames{en}->{61896160} = "Quairading";
$areanames{en}->{61896161} = "Quairading";
$areanames{en}->{61896162} = "Quairading";
$areanames{en}->{61896163} = "Regans\ Ford";
$areanames{en}->{61896164} = "Regans\ Ford";
$areanames{en}->{61896165} = "Regans\ Ford";
$areanames{en}->{61896166} = "South\ Quairading";
$areanames{en}->{61896167} = "South\ Quairading";
$areanames{en}->{61896168} = "South\ Quairading";
$areanames{en}->{61896169} = "Calingiri";
$areanames{en}->{61896170} = "Studleigh";
$areanames{en}->{61896171} = "Studleigh";
$areanames{en}->{61896172} = "Studleigh";
$areanames{en}->{61896173} = "Talbot\ Brook";
$areanames{en}->{61896174} = "Talbot\ Brook";
$areanames{en}->{61896175} = "Talbot\ Brook";
$areanames{en}->{61896176} = "Tammin";
$areanames{en}->{61896177} = "Tammin";
$areanames{en}->{61896178} = "Tammin";
$areanames{en}->{61896179} = "Cunderdin";
$areanames{en}->{61896180} = "Trayning";
$areanames{en}->{61896181} = "Trayning";
$areanames{en}->{61896182} = "Trayning";
$areanames{en}->{61896183} = "Wannamal";
$areanames{en}->{61896184} = "Wannamal";
$areanames{en}->{61896185} = "Wannamal";
$areanames{en}->{61896186} = "Watheroo";
$areanames{en}->{61896187} = "Watheroo";
$areanames{en}->{61896188} = "Watheroo";
$areanames{en}->{61896189} = "Cunderdin\ North";
$areanames{en}->{61896190} = "Wongan\ Hills";
$areanames{en}->{61896191} = "Wongan\ Hills";
$areanames{en}->{61896192} = "Wongan\ Hills";
$areanames{en}->{61896193} = "Wubin";
$areanames{en}->{61896194} = "Wubin";
$areanames{en}->{61896195} = "Wubin";
$areanames{en}->{61896196} = "Wubin\ West";
$areanames{en}->{61896197} = "Wubin\ West";
$areanames{en}->{61896198} = "Wubin\ West";
$areanames{en}->{61896199} = "Dowerin";
$areanames{en}->{61896200} = "Konnongorring";
$areanames{en}->{61896201} = "Konnongorring";
$areanames{en}->{61896202} = "Bidaminna";
$areanames{en}->{61896203} = "Bidaminna";
$areanames{en}->{61896204} = "Wongan\ Hills";
$areanames{en}->{61896205} = "Wongan\ Hills";
$areanames{en}->{61896206} = "Wyalkatchem";
$areanames{en}->{61896207} = "Wyalkatchem";
$areanames{en}->{61896208} = "Yelbeni";
$areanames{en}->{61896209} = "Yelbeni";
$areanames{en}->{6189621} = "Northam";
$areanames{en}->{6189622} = "Northam";
$areanames{en}->{61896230} = "Jennacubbine";
$areanames{en}->{61896231} = "Jennacubbine";
$areanames{en}->{61896232} = "Jennacubbine";
$areanames{en}->{61896233} = "Meckering";
$areanames{en}->{61896234} = "Tammin";
$areanames{en}->{61896235} = "Lancelin";
$areanames{en}->{61896236} = "Lancelin";
$areanames{en}->{61896237} = "Goomalling";
$areanames{en}->{61896238} = "Goomalling";
$areanames{en}->{61896239} = "Dowerin";
$areanames{en}->{61896240} = "Wyalkatchem";
$areanames{en}->{61896241} = "Wyalkatchem";
$areanames{en}->{61896242} = "Wyalkatchem";
$areanames{en}->{61896243} = "Yelbeni";
$areanames{en}->{61896244} = "Yelbeni";
$areanames{en}->{61896245} = "Yelbeni";
$areanames{en}->{61896246} = "Yerecoin";
$areanames{en}->{61896247} = "Yerecoin";
$areanames{en}->{61896248} = "Yerecoin";
$areanames{en}->{61896249} = "Ejanding";
$areanames{en}->{61896250} = "Meckering";
$areanames{en}->{61896251} = "Meckering";
$areanames{en}->{61896252} = "Gabbin\ North";
$areanames{en}->{61896253} = "Gabbin\ North";
$areanames{en}->{61896254} = "Koorda";
$areanames{en}->{61896255} = "Koorda";
$areanames{en}->{61896256} = "Trayning";
$areanames{en}->{61896257} = "Trayning";
$areanames{en}->{61896258} = "Balkuling";
$areanames{en}->{61896259} = "Balkuling";
$areanames{en}->{61896260} = "York";
$areanames{en}->{61896261} = "York";
$areanames{en}->{61896262} = "York";
$areanames{en}->{61896263} = "Yorkrakine";
$areanames{en}->{61896264} = "Yorkrakine";
$areanames{en}->{61896265} = "Yorkrakine";
$areanames{en}->{61896266} = "Goomalling";
$areanames{en}->{61896267} = "Jennacubbine";
$areanames{en}->{61896268} = "Konnongorring";
$areanames{en}->{61896269} = "Meckering";
$areanames{en}->{61896270} = "Bolgart";
$areanames{en}->{61896271} = "Badgerin\ Rock";
$areanames{en}->{61896272} = "Badgerin\ Rock";
$areanames{en}->{61896273} = "Bencubbin";
$areanames{en}->{61896274} = "Bencubbin";
$areanames{en}->{61896275} = "Bolgart";
$areanames{en}->{61896276} = "Beverley";
$areanames{en}->{61896277} = "Beverley";
$areanames{en}->{61896278} = "Beverley\ West";
$areanames{en}->{61896279} = "Beverley\ West";
$areanames{en}->{61896280} = "Dale\ River";
$areanames{en}->{61896281} = "Dale\ River";
$areanames{en}->{61896282} = "Dangin";
$areanames{en}->{61896283} = "Dangin";
$areanames{en}->{61896284} = "Jelkobine";
$areanames{en}->{61896285} = "Jelkobine";
$areanames{en}->{61896286} = "Lancelin";
$areanames{en}->{61896287} = "Calingiri";
$areanames{en}->{61896288} = "Calingiri";
$areanames{en}->{61896289} = "Calingiri";
$areanames{en}->{61896290} = "Goomalling";
$areanames{en}->{61896291} = "Goomalling";
$areanames{en}->{61896292} = "Pantapin";
$areanames{en}->{61896293} = "Pantapin";
$areanames{en}->{61896294} = "Quairading";
$areanames{en}->{61896295} = "Quairading";
$areanames{en}->{61896296} = "South\ Quairading";
$areanames{en}->{61896297} = "South\ Quairading";
$areanames{en}->{61896298} = "Talbot\ Brook";
$areanames{en}->{61896299} = "Talbot\ Brook";
$areanames{en}->{61896300} = "Northam";
$areanames{en}->{61896301} = "Studleigh";
$areanames{en}->{61896302} = "Tammin";
$areanames{en}->{61896303} = "Yorkrakine";
$areanames{en}->{61896304} = "Paynes\ Find";
$areanames{en}->{61896305} = "Ballidu";
$areanames{en}->{61896306} = "Burakin";
$areanames{en}->{61896307} = "Cadoux";
$areanames{en}->{61896308} = "Dalwallinu";
$areanames{en}->{61896309} = "Dalwallinu\ West";
$areanames{en}->{61896310} = "Dowerin";
$areanames{en}->{61896311} = "Dowerin";
$areanames{en}->{61896312} = "Dowerin";
$areanames{en}->{61896313} = "Dowerin";
$areanames{en}->{61896314} = "Dowerin";
$areanames{en}->{61896315} = "Konnongorring";
$areanames{en}->{61896316} = "Konnongorring";
$areanames{en}->{61896317} = "Studleigh";
$areanames{en}->{61896318} = "Studleigh";
$areanames{en}->{61896320} = "Ejanding";
$areanames{en}->{61896321} = "Ejanding";
$areanames{en}->{61896322} = "Ejanding";
$areanames{en}->{61896323} = "Ejanding";
$areanames{en}->{61896324} = "Brookton";
$areanames{en}->{61896325} = "Brookton";
$areanames{en}->{61896326} = "Aldersyde";
$areanames{en}->{61896327} = "Aldersyde";
$areanames{en}->{61896328} = "Bolgart";
$areanames{en}->{61896329} = "Bolgart";
$areanames{en}->{61896330} = "Goodlands";
$areanames{en}->{61896331} = "Kalannie";
$areanames{en}->{61896332} = "Kalannie\ East";
$areanames{en}->{61896333} = "Wongan\ Hills";
$areanames{en}->{61896334} = "Wubin";
$areanames{en}->{61896335} = "Wubin\ West";
$areanames{en}->{61896336} = "Badgerin\ Rock";
$areanames{en}->{61896337} = "Beacon";
$areanames{en}->{61896338} = "Beacon\ North";
$areanames{en}->{61896339} = "Bencubbin";
$areanames{en}->{61896340} = "Studleigh";
$areanames{en}->{61896341} = "Studleigh";
$areanames{en}->{61896342} = "Studleigh";
$areanames{en}->{61896343} = "Badgingarra";
$areanames{en}->{61896344} = "Badgingarra";
$areanames{en}->{61896345} = "Bibby\ Springs";
$areanames{en}->{61896346} = "Bibby\ Springs";
$areanames{en}->{61896347} = "Coomallo";
$areanames{en}->{61896348} = "Coomallo";
$areanames{en}->{61896349} = "Dandaragan";
$areanames{en}->{61896350} = "Dandaragan";
$areanames{en}->{61896351} = "Cunderdin";
$areanames{en}->{61896352} = "Cunderdin";
$areanames{en}->{61896353} = "Cunderdin";
$areanames{en}->{61896354} = "Gillingarra";
$areanames{en}->{61896355} = "Gillingarra";
$areanames{en}->{61896356} = "Jurien";
$areanames{en}->{61896357} = "Jurien";
$areanames{en}->{61896358} = "Miling";
$areanames{en}->{61896359} = "Miling";
$areanames{en}->{61896360} = "Cunderdin\ North";
$areanames{en}->{61896361} = "Cunderdin\ North";
$areanames{en}->{61896362} = "Cunderdin\ North";
$areanames{en}->{61896363} = "Tammin";
$areanames{en}->{61896364} = "Tammin";
$areanames{en}->{61896365} = "Northam";
$areanames{en}->{61896366} = "Northam";
$areanames{en}->{61896367} = "Gabbin";
$areanames{en}->{61896368} = "Gabbin";
$areanames{en}->{61896369} = "Jurien";
$areanames{en}->{61896370} = "Tammin";
$areanames{en}->{61896371} = "Tammin";
$areanames{en}->{61896372} = "Meckering";
$areanames{en}->{61896373} = "Meckering";
$areanames{en}->{61896374} = "Moora";
$areanames{en}->{61896375} = "Moora";
$areanames{en}->{61896376} = "Regans\ Ford";
$areanames{en}->{61896377} = "Regans\ Ford";
$areanames{en}->{61896378} = "Yorkrakine";
$areanames{en}->{61896379} = "Yorkrakine";
$areanames{en}->{61896380} = "Yorkrakine";
$areanames{en}->{61896381} = "Yorkrakine";
$areanames{en}->{61896382} = "Calingiri";
$areanames{en}->{61896383} = "Calingiri";
$areanames{en}->{61896384} = "Cunderdin";
$areanames{en}->{61896385} = "Cunderdin";
$areanames{en}->{61896386} = "Cunderdin\ North";
$areanames{en}->{61896387} = "Cunderdin\ North";
$areanames{en}->{61896388} = "Dowerin";
$areanames{en}->{61896389} = "Dowerin";
$areanames{en}->{61896390} = "Cleary\ North";
$areanames{en}->{61896391} = "Dukin";
$areanames{en}->{61896392} = "Gabbin";
$areanames{en}->{61896393} = "Gabbin\ North";
$areanames{en}->{61896394} = "Koorda";
$areanames{en}->{61896395} = "Trayning";
$areanames{en}->{61896396} = "Wyalkatchem";
$areanames{en}->{61896397} = "Yelbeni";
$areanames{en}->{61896398} = "Pantapin";
$areanames{en}->{61896399} = "Quairading";
$areanames{en}->{61896400} = "South\ Quairading";
$areanames{en}->{61896401} = "Talbot\ Brook";
$areanames{en}->{61896402} = "Aldersyde";
$areanames{en}->{61896403} = "Balkuling";
$areanames{en}->{61896404} = "Beverley";
$areanames{en}->{61896405} = "Beverley\ West";
$areanames{en}->{61896406} = "Brookton";
$areanames{en}->{61896407} = "Dale\ River";
$areanames{en}->{61896408} = "Dangin";
$areanames{en}->{61896409} = "Jelkobine";
$areanames{en}->{61896410} = "York";
$areanames{en}->{61896411} = "York";
$areanames{en}->{61896412} = "York";
$areanames{en}->{61896413} = "York";
$areanames{en}->{61896414} = "York";
$areanames{en}->{61896416} = "Balkuling";
$areanames{en}->{61896417} = "Balkuling";
$areanames{en}->{61896418} = "Balkuling";
$areanames{en}->{61896419} = "Talbot\ Brook";
$areanames{en}->{61896420} = "Brookton";
$areanames{en}->{61896421} = "Brookton";
$areanames{en}->{61896422} = "Brookton";
$areanames{en}->{61896423} = "Jelkobine";
$areanames{en}->{61896424} = "Jelkobine";
$areanames{en}->{61896425} = "Brookton";
$areanames{en}->{61896426} = "Aldersyde";
$areanames{en}->{61896427} = "Aldersyde";
$areanames{en}->{61896428} = "Aldersyde";
$areanames{en}->{61896429} = "Brookton";
$areanames{en}->{61896430} = "Talbot\ Brook";
$areanames{en}->{61896431} = "Talbot\ Brook";
$areanames{en}->{61896432} = "York";
$areanames{en}->{61896433} = "York";
$areanames{en}->{61896434} = "Ejanding";
$areanames{en}->{61896435} = "Ejanding";
$areanames{en}->{61896436} = "Goomalling";
$areanames{en}->{61896437} = "Goomalling";
$areanames{en}->{61896438} = "Jennacubbine";
$areanames{en}->{61896439} = "Jennacubbine";
$areanames{en}->{61896440} = "York";
$areanames{en}->{618964410} = "Badgingarra";
$areanames{en}->{618964411} = "Badgingarra";
$areanames{en}->{618964412} = "Badgingarra";
$areanames{en}->{618964413} = "Badgingarra";
$areanames{en}->{618964414} = "Badgingarra";
$areanames{en}->{618964415} = "Badgingarra";
$areanames{en}->{618964416} = "Badgingarra";
$areanames{en}->{618964417} = "Badgingarra";
$areanames{en}->{618964418} = "Badgingarra";
$areanames{en}->{618964420} = "Bibby\ Springs";
$areanames{en}->{618964421} = "Bibby\ Springs";
$areanames{en}->{618964422} = "Bibby\ Springs";
$areanames{en}->{618964423} = "Bibby\ Springs";
$areanames{en}->{618964424} = "Bibby\ Springs";
$areanames{en}->{618964425} = "Bibby\ Springs";
$areanames{en}->{618964426} = "Bibby\ Springs";
$areanames{en}->{618964427} = "Bibby\ Springs";
$areanames{en}->{618964428} = "Bibby\ Springs";
$areanames{en}->{618964430} = "Bidaminna";
$areanames{en}->{618964431} = "Bidaminna";
$areanames{en}->{618964432} = "Bidaminna";
$areanames{en}->{618964433} = "Bidaminna";
$areanames{en}->{618964434} = "Bidaminna";
$areanames{en}->{618964435} = "Bidaminna";
$areanames{en}->{618964436} = "Bidaminna";
$areanames{en}->{618964437} = "Bidaminna";
$areanames{en}->{618964438} = "Bidaminna";
$areanames{en}->{618964440} = "Coomallo";
$areanames{en}->{618964441} = "Coomallo";
$areanames{en}->{618964442} = "Coomallo";
$areanames{en}->{618964443} = "Coomallo";
$areanames{en}->{618964444} = "Coomallo";
$areanames{en}->{618964445} = "Coomallo";
$areanames{en}->{618964446} = "Coomallo";
$areanames{en}->{618964447} = "Coomallo";
$areanames{en}->{618964448} = "Coomallo";
$areanames{en}->{618964450} = "Coomberdale";
$areanames{en}->{618964451} = "Coomberdale";
$areanames{en}->{618964452} = "Coomberdale";
$areanames{en}->{618964453} = "Coomberdale";
$areanames{en}->{618964454} = "Coomberdale";
$areanames{en}->{618964455} = "Coomberdale";
$areanames{en}->{618964456} = "Coomberdale";
$areanames{en}->{618964457} = "Coomberdale";
$areanames{en}->{618964458} = "Coomberdale";
$areanames{en}->{618964460} = "Dandaragan";
$areanames{en}->{618964461} = "Dandaragan";
$areanames{en}->{618964462} = "Dandaragan";
$areanames{en}->{618964463} = "Dandaragan";
$areanames{en}->{618964464} = "Dandaragan";
$areanames{en}->{618964465} = "Dandaragan";
$areanames{en}->{618964466} = "Dandaragan";
$areanames{en}->{618964467} = "Dandaragan";
$areanames{en}->{618964468} = "Dandaragan";
$areanames{en}->{618964470} = "Gillingarra";
$areanames{en}->{618964471} = "Gillingarra";
$areanames{en}->{618964472} = "Gillingarra";
$areanames{en}->{618964473} = "Gillingarra";
$areanames{en}->{618964474} = "Gillingarra";
$areanames{en}->{618964475} = "Gillingarra";
$areanames{en}->{618964476} = "Gillingarra";
$areanames{en}->{618964477} = "Gillingarra";
$areanames{en}->{618964478} = "Gillingarra";
$areanames{en}->{618964480} = "Jurien";
$areanames{en}->{618964481} = "Jurien";
$areanames{en}->{618964482} = "Jurien";
$areanames{en}->{618964483} = "Jurien";
$areanames{en}->{618964484} = "Jurien";
$areanames{en}->{618964485} = "Jurien";
$areanames{en}->{618964486} = "Jurien";
$areanames{en}->{618964487} = "Jurien";
$areanames{en}->{618964488} = "Jurien";
$areanames{en}->{618964490} = "Lancelin";
$areanames{en}->{618964491} = "Lancelin";
$areanames{en}->{618964492} = "Lancelin";
$areanames{en}->{618964493} = "Lancelin";
$areanames{en}->{618964494} = "Lancelin";
$areanames{en}->{618964495} = "Lancelin";
$areanames{en}->{618964496} = "Lancelin";
$areanames{en}->{618964497} = "Lancelin";
$areanames{en}->{618964498} = "Lancelin";
$areanames{en}->{61896450} = "Quairading";
$areanames{en}->{61896451} = "Quairading";
$areanames{en}->{61896452} = "Quairading";
$areanames{en}->{61896453} = "Quairading";
$areanames{en}->{61896454} = "South\ Quairading";
$areanames{en}->{61896455} = "South\ Quairading";
$areanames{en}->{61896456} = "Pantapin";
$areanames{en}->{61896457} = "Pantapin";
$areanames{en}->{61896458} = "South\ Quairading";
$areanames{en}->{61896459} = "South\ Quairading";
$areanames{en}->{61896460} = "Beverley";
$areanames{en}->{61896461} = "Beverley";
$areanames{en}->{61896462} = "Beverley";
$areanames{en}->{61896463} = "Beverley";
$areanames{en}->{61896464} = "Beverley";
$areanames{en}->{61896465} = "Beverley\ West";
$areanames{en}->{61896466} = "Dangin";
$areanames{en}->{61896467} = "Dangin";
$areanames{en}->{61896468} = "Ballidu";
$areanames{en}->{61896469} = "Ballidu";
$areanames{en}->{61896470} = "Dale\ River";
$areanames{en}->{61896471} = "Dale\ River";
$areanames{en}->{61896472} = "Dale\ River";
$areanames{en}->{61896480} = "Beverley\ West";
$areanames{en}->{61896481} = "Beverley\ West";
$areanames{en}->{61896482} = "Moora";
$areanames{en}->{618964900} = "Miling";
$areanames{en}->{618964901} = "Miling";
$areanames{en}->{618964902} = "Miling";
$areanames{en}->{618964903} = "Miling";
$areanames{en}->{618964904} = "Miling";
$areanames{en}->{618964905} = "Miling";
$areanames{en}->{618964906} = "Miling";
$areanames{en}->{618964907} = "Miling";
$areanames{en}->{618964908} = "Miling";
$areanames{en}->{618964910} = "Moora";
$areanames{en}->{618964911} = "Moora";
$areanames{en}->{618964912} = "Moora";
$areanames{en}->{618964913} = "Moora";
$areanames{en}->{618964914} = "Moora";
$areanames{en}->{618964915} = "Moora";
$areanames{en}->{618964916} = "Moora";
$areanames{en}->{618964917} = "Moora";
$areanames{en}->{618964918} = "Moora";
$areanames{en}->{618964920} = "Regans\ Ford";
$areanames{en}->{618964921} = "Regans\ Ford";
$areanames{en}->{618964922} = "Regans\ Ford";
$areanames{en}->{618964923} = "Regans\ Ford";
$areanames{en}->{618964924} = "Regans\ Ford";
$areanames{en}->{618964925} = "Regans\ Ford";
$areanames{en}->{618964926} = "Regans\ Ford";
$areanames{en}->{618964927} = "Regans\ Ford";
$areanames{en}->{618964928} = "Regans\ Ford";
$areanames{en}->{618964930} = "Wannamal";
$areanames{en}->{618964931} = "Wannamal";
$areanames{en}->{618964932} = "Wannamal";
$areanames{en}->{618964933} = "Wannamal";
$areanames{en}->{618964934} = "Wannamal";
$areanames{en}->{618964935} = "Wannamal";
$areanames{en}->{618964936} = "Wannamal";
$areanames{en}->{618964937} = "Wannamal";
$areanames{en}->{618964938} = "Wannamal";
$areanames{en}->{618964940} = "Watheroo";
$areanames{en}->{618964941} = "Watheroo";
$areanames{en}->{618964942} = "Watheroo";
$areanames{en}->{618964943} = "Watheroo";
$areanames{en}->{618964944} = "Watheroo";
$areanames{en}->{618964945} = "Watheroo";
$areanames{en}->{618964946} = "Watheroo";
$areanames{en}->{618964947} = "Watheroo";
$areanames{en}->{618964948} = "Watheroo";
$areanames{en}->{618964950} = "Yerecoin";
$areanames{en}->{618964951} = "Yerecoin";
$areanames{en}->{618964952} = "Yerecoin";
$areanames{en}->{618964953} = "Yerecoin";
$areanames{en}->{618964954} = "Yerecoin";
$areanames{en}->{618964955} = "Yerecoin";
$areanames{en}->{618964956} = "Yerecoin";
$areanames{en}->{618964957} = "Yerecoin";
$areanames{en}->{618964958} = "Yerecoin";
$areanames{en}->{618964960} = "Bolgart";
$areanames{en}->{618964961} = "Bolgart";
$areanames{en}->{618964962} = "Bolgart";
$areanames{en}->{618964963} = "Bolgart";
$areanames{en}->{618964964} = "Bolgart";
$areanames{en}->{618964965} = "Bolgart";
$areanames{en}->{618964966} = "Bolgart";
$areanames{en}->{618964967} = "Bolgart";
$areanames{en}->{618964968} = "Bolgart";
$areanames{en}->{618964970} = "Calingiri";
$areanames{en}->{618964971} = "Calingiri";
$areanames{en}->{618964972} = "Calingiri";
$areanames{en}->{618964973} = "Calingiri";
$areanames{en}->{618964974} = "Calingiri";
$areanames{en}->{618964975} = "Calingiri";
$areanames{en}->{618964976} = "Calingiri";
$areanames{en}->{618964977} = "Calingiri";
$areanames{en}->{618964978} = "Calingiri";
$areanames{en}->{618964980} = "Cunderdin";
$areanames{en}->{618964981} = "Cunderdin";
$areanames{en}->{618964982} = "Cunderdin";
$areanames{en}->{618964983} = "Cunderdin";
$areanames{en}->{618964984} = "Cunderdin";
$areanames{en}->{618964985} = "Cunderdin";
$areanames{en}->{618964986} = "Cunderdin";
$areanames{en}->{618964987} = "Cunderdin";
$areanames{en}->{618964988} = "Cunderdin";
$areanames{en}->{618964990} = "Cunderdin\ North";
$areanames{en}->{618964991} = "Cunderdin\ North";
$areanames{en}->{618964992} = "Cunderdin\ North";
$areanames{en}->{618964993} = "Cunderdin\ North";
$areanames{en}->{618964994} = "Cunderdin\ North";
$areanames{en}->{618964995} = "Cunderdin\ North";
$areanames{en}->{618964996} = "Cunderdin\ North";
$areanames{en}->{618964997} = "Cunderdin\ North";
$areanames{en}->{618964998} = "Cunderdin\ North";
$areanames{en}->{61896500} = "Lancelin";
$areanames{en}->{61896501} = "Lancelin";
$areanames{en}->{61896502} = "Lancelin";
$areanames{en}->{61896503} = "Lancelin";
$areanames{en}->{61896504} = "Lancelin";
$areanames{en}->{61896505} = "Wannamal";
$areanames{en}->{61896506} = "Wannamal";
$areanames{en}->{61896507} = "Watheroo";
$areanames{en}->{61896508} = "Coomberdale";
$areanames{en}->{61896509} = "Coomberdale";
$areanames{en}->{61896510} = "Moora";
$areanames{en}->{61896511} = "Moora";
$areanames{en}->{61896512} = "Dandaragan";
$areanames{en}->{61896513} = "Dandaragan";
$areanames{en}->{61896514} = "Dandaragan";
$areanames{en}->{61896515} = "Gillingarra";
$areanames{en}->{61896516} = "Gillingarra";
$areanames{en}->{61896517} = "Watheroo";
$areanames{en}->{61896518} = "Coomberdale";
$areanames{en}->{61896519} = "Gillingarra";
$areanames{en}->{61896520} = "Jurien";
$areanames{en}->{61896521} = "Jurien";
$areanames{en}->{61896522} = "Jurien";
$areanames{en}->{61896523} = "Coomallo";
$areanames{en}->{61896524} = "Bibby\ Springs";
$areanames{en}->{61896525} = "Bibby\ Springs";
$areanames{en}->{61896526} = "Coomallo";
$areanames{en}->{61896527} = "Bibby\ Springs";
$areanames{en}->{61896528} = "Badgingarra";
$areanames{en}->{61896529} = "Badgingarra";
$areanames{en}->{61896530} = "Moora";
$areanames{en}->{61896531} = "Moora";
$areanames{en}->{61896538} = "Bibby\ Springs";
$areanames{en}->{61896539} = "Moora";
$areanames{en}->{61896540} = "Miling";
$areanames{en}->{61896541} = "Miling";
$areanames{en}->{61896542} = "Miling";
$areanames{en}->{61896543} = "Miling";
$areanames{en}->{61896544} = "Yerecoin";
$areanames{en}->{61896545} = "Yerecoin";
$areanames{en}->{61896546} = "Yerecoin";
$areanames{en}->{61896547} = "Yerecoin";
$areanames{en}->{61896548} = "Yerecoin";
$areanames{en}->{61896549} = "Miling";
$areanames{en}->{61896550} = "Regans\ Ford";
$areanames{en}->{61896551} = "Lancelin";
$areanames{en}->{61896552} = "Lancelin";
$areanames{en}->{61896553} = "Bidaminna";
$areanames{en}->{61896554} = "Bidaminna";
$areanames{en}->{61896555} = "Bidaminna";
$areanames{en}->{61896556} = "Bidaminna";
$areanames{en}->{61896557} = "Wannamal";
$areanames{en}->{61896558} = "Wannamal";
$areanames{en}->{61896559} = "Wannamal";
$areanames{en}->{618965600} = "Ballidu";
$areanames{en}->{618965601} = "Ballidu";
$areanames{en}->{618965602} = "Ballidu";
$areanames{en}->{618965603} = "Ballidu";
$areanames{en}->{618965604} = "Ballidu";
$areanames{en}->{618965605} = "Ballidu";
$areanames{en}->{618965606} = "Ballidu";
$areanames{en}->{618965607} = "Ballidu";
$areanames{en}->{618965608} = "Ballidu";
$areanames{en}->{618965610} = "Dowerin";
$areanames{en}->{618965611} = "Dowerin";
$areanames{en}->{618965612} = "Dowerin";
$areanames{en}->{618965613} = "Dowerin";
$areanames{en}->{618965614} = "Dowerin";
$areanames{en}->{618965615} = "Dowerin";
$areanames{en}->{618965616} = "Dowerin";
$areanames{en}->{618965617} = "Dowerin";
$areanames{en}->{618965618} = "Dowerin";
$areanames{en}->{618965620} = "Burakin";
$areanames{en}->{618965621} = "Burakin";
$areanames{en}->{618965622} = "Burakin";
$areanames{en}->{618965623} = "Burakin";
$areanames{en}->{618965624} = "Burakin";
$areanames{en}->{618965625} = "Burakin";
$areanames{en}->{618965626} = "Burakin";
$areanames{en}->{618965627} = "Burakin";
$areanames{en}->{618965628} = "Burakin";
$areanames{en}->{618965630} = "Ejanding";
$areanames{en}->{618965631} = "Ejanding";
$areanames{en}->{618965632} = "Ejanding";
$areanames{en}->{618965633} = "Ejanding";
$areanames{en}->{618965634} = "Ejanding";
$areanames{en}->{618965635} = "Ejanding";
$areanames{en}->{618965636} = "Ejanding";
$areanames{en}->{618965637} = "Ejanding";
$areanames{en}->{618965638} = "Ejanding";
$areanames{en}->{618965640} = "Cadoux";
$areanames{en}->{618965641} = "Cadoux";
$areanames{en}->{618965642} = "Cadoux";
$areanames{en}->{618965643} = "Cadoux";
$areanames{en}->{618965644} = "Cadoux";
$areanames{en}->{618965645} = "Cadoux";
$areanames{en}->{618965646} = "Cadoux";
$areanames{en}->{618965647} = "Cadoux";
$areanames{en}->{618965648} = "Cadoux";
$areanames{en}->{618965650} = "Goomalling";
$areanames{en}->{618965651} = "Goomalling";
$areanames{en}->{618965652} = "Goomalling";
$areanames{en}->{618965653} = "Goomalling";
$areanames{en}->{618965654} = "Goomalling";
$areanames{en}->{618965655} = "Goomalling";
$areanames{en}->{618965656} = "Goomalling";
$areanames{en}->{618965657} = "Goomalling";
$areanames{en}->{618965658} = "Goomalling";
$areanames{en}->{618965660} = "Dalwallinu";
$areanames{en}->{618965661} = "Dalwallinu";
$areanames{en}->{618965662} = "Dalwallinu";
$areanames{en}->{618965663} = "Dalwallinu";
$areanames{en}->{618965664} = "Dalwallinu";
$areanames{en}->{618965665} = "Dalwallinu";
$areanames{en}->{618965666} = "Dalwallinu";
$areanames{en}->{618965667} = "Dalwallinu";
$areanames{en}->{618965668} = "Dalwallinu";
$areanames{en}->{618965670} = "Jennacubbine";
$areanames{en}->{618965671} = "Jennacubbine";
$areanames{en}->{618965672} = "Jennacubbine";
$areanames{en}->{618965673} = "Jennacubbine";
$areanames{en}->{618965674} = "Jennacubbine";
$areanames{en}->{618965675} = "Jennacubbine";
$areanames{en}->{618965676} = "Jennacubbine";
$areanames{en}->{618965677} = "Jennacubbine";
$areanames{en}->{618965678} = "Jennacubbine";
$areanames{en}->{618965680} = "Dalwallinu\ West";
$areanames{en}->{618965681} = "Dalwallinu\ West";
$areanames{en}->{618965682} = "Dalwallinu\ West";
$areanames{en}->{618965683} = "Dalwallinu\ West";
$areanames{en}->{618965684} = "Dalwallinu\ West";
$areanames{en}->{618965685} = "Dalwallinu\ West";
$areanames{en}->{618965686} = "Dalwallinu\ West";
$areanames{en}->{618965687} = "Dalwallinu\ West";
$areanames{en}->{618965688} = "Dalwallinu\ West";
$areanames{en}->{618965690} = "Konnongorring";
$areanames{en}->{618965691} = "Konnongorring";
$areanames{en}->{618965692} = "Konnongorring";
$areanames{en}->{618965693} = "Konnongorring";
$areanames{en}->{618965694} = "Konnongorring";
$areanames{en}->{618965695} = "Konnongorring";
$areanames{en}->{618965696} = "Konnongorring";
$areanames{en}->{618965697} = "Konnongorring";
$areanames{en}->{618965698} = "Konnongorring";
$areanames{en}->{61896571} = "Badgingarra";
$areanames{en}->{61896572} = "Badgingarra";
$areanames{en}->{61896573} = "Bibby\ Springs";
$areanames{en}->{61896574} = "Bidaminna";
$areanames{en}->{61896575} = "Coomallo";
$areanames{en}->{61896576} = "Coomberdale";
$areanames{en}->{61896577} = "Dandaragan";
$areanames{en}->{61896578} = "Gillingarra";
$areanames{en}->{61896579} = "Jurien";
$areanames{en}->{61896580} = "Lancelin";
$areanames{en}->{61896581} = "Miling";
$areanames{en}->{61896582} = "Moora";
$areanames{en}->{61896583} = "Regans\ Ford";
$areanames{en}->{61896584} = "Wannamal";
$areanames{en}->{61896585} = "Watheroo";
$areanames{en}->{61896586} = "Yerecoin";
$areanames{en}->{61896587} = "Bolgart";
$areanames{en}->{61896588} = "Calingiri";
$areanames{en}->{61896589} = "Cunderdin";
$areanames{en}->{61896590} = "Cunderdin\ North";
$areanames{en}->{61896591} = "Dowerin";
$areanames{en}->{61896592} = "Ejanding";
$areanames{en}->{61896593} = "Goomalling";
$areanames{en}->{61896594} = "Jennacubbine";
$areanames{en}->{61896595} = "Konnongorring";
$areanames{en}->{61896596} = "Meckering";
$areanames{en}->{61896597} = "Northam";
$areanames{en}->{61896598} = "Studleigh";
$areanames{en}->{61896599} = "Tammin";
$areanames{en}->{61896600} = "Yorkrakine";
$areanames{en}->{61896601} = "Ballidu";
$areanames{en}->{61896602} = "Burakin";
$areanames{en}->{61896603} = "Cadoux";
$areanames{en}->{61896604} = "Dalwallinu";
$areanames{en}->{61896605} = "Dalwallinu\ West";
$areanames{en}->{61896606} = "Goodlands";
$areanames{en}->{61896607} = "Kalannie";
$areanames{en}->{61896608} = "Kalannie\ East";
$areanames{en}->{61896609} = "Paynes\ Find";
$areanames{en}->{61896610} = "Dalwallinu";
$areanames{en}->{61896611} = "Dalwallinu";
$areanames{en}->{61896612} = "Dalwallinu";
$areanames{en}->{61896621} = "Dalwallinu";
$areanames{en}->{61896622} = "Dalwallinu";
$areanames{en}->{61896624} = "Paynes\ Find";
$areanames{en}->{61896630} = "Dalwallinu\ West";
$areanames{en}->{61896631} = "Dalwallinu\ West";
$areanames{en}->{61896640} = "Wubin";
$areanames{en}->{61896641} = "Wubin";
$areanames{en}->{61896642} = "Wubin";
$areanames{en}->{61896643} = "Wubin";
$areanames{en}->{61896644} = "Wubin";
$areanames{en}->{61896645} = "Wubin";
$areanames{en}->{61896650} = "Kalannie\ East";
$areanames{en}->{61896651} = "Kalannie\ East";
$areanames{en}->{61896660} = "Kalannie";
$areanames{en}->{61896661} = "Kalannie";
$areanames{en}->{61896662} = "Kalannie";
$areanames{en}->{61896663} = "Kalannie";
$areanames{en}->{61896670} = "Goodlands";
$areanames{en}->{61896671} = "Goodlands";
$areanames{en}->{61896680} = "Wubin\ West";
$areanames{en}->{61896681} = "Wubin\ West";
$areanames{en}->{618967000} = "Goodlands";
$areanames{en}->{618967001} = "Goodlands";
$areanames{en}->{618967002} = "Goodlands";
$areanames{en}->{618967003} = "Goodlands";
$areanames{en}->{618967004} = "Goodlands";
$areanames{en}->{618967005} = "Goodlands";
$areanames{en}->{618967006} = "Goodlands";
$areanames{en}->{618967007} = "Goodlands";
$areanames{en}->{618967008} = "Goodlands";
$areanames{en}->{618967010} = "Meckering";
$areanames{en}->{618967011} = "Meckering";
$areanames{en}->{618967012} = "Meckering";
$areanames{en}->{618967013} = "Meckering";
$areanames{en}->{618967014} = "Meckering";
$areanames{en}->{618967015} = "Meckering";
$areanames{en}->{618967016} = "Meckering";
$areanames{en}->{618967017} = "Meckering";
$areanames{en}->{618967018} = "Meckering";
$areanames{en}->{618967020} = "Kalannie";
$areanames{en}->{618967021} = "Kalannie";
$areanames{en}->{618967022} = "Kalannie";
$areanames{en}->{618967023} = "Kalannie";
$areanames{en}->{618967024} = "Kalannie";
$areanames{en}->{618967025} = "Kalannie";
$areanames{en}->{618967026} = "Kalannie";
$areanames{en}->{618967027} = "Kalannie";
$areanames{en}->{618967028} = "Kalannie";
$areanames{en}->{618967030} = "Northam";
$areanames{en}->{618967031} = "Northam";
$areanames{en}->{618967032} = "Northam";
$areanames{en}->{618967033} = "Northam";
$areanames{en}->{618967034} = "Northam";
$areanames{en}->{618967035} = "Northam";
$areanames{en}->{618967036} = "Northam";
$areanames{en}->{618967037} = "Northam";
$areanames{en}->{618967038} = "Northam";
$areanames{en}->{618967040} = "Kalannie\ East";
$areanames{en}->{618967041} = "Kalannie\ East";
$areanames{en}->{618967042} = "Kalannie\ East";
$areanames{en}->{618967043} = "Kalannie\ East";
$areanames{en}->{618967044} = "Kalannie\ East";
$areanames{en}->{618967045} = "Kalannie\ East";
$areanames{en}->{618967046} = "Kalannie\ East";
$areanames{en}->{618967047} = "Kalannie\ East";
$areanames{en}->{618967048} = "Kalannie\ East";
$areanames{en}->{618967050} = "Studleigh";
$areanames{en}->{618967051} = "Studleigh";
$areanames{en}->{618967052} = "Studleigh";
$areanames{en}->{618967053} = "Studleigh";
$areanames{en}->{618967054} = "Studleigh";
$areanames{en}->{618967055} = "Studleigh";
$areanames{en}->{618967056} = "Studleigh";
$areanames{en}->{618967057} = "Studleigh";
$areanames{en}->{618967058} = "Studleigh";
$areanames{en}->{618967060} = "Tammin";
$areanames{en}->{618967061} = "Tammin";
$areanames{en}->{618967062} = "Tammin";
$areanames{en}->{618967063} = "Tammin";
$areanames{en}->{618967064} = "Tammin";
$areanames{en}->{618967065} = "Tammin";
$areanames{en}->{618967066} = "Tammin";
$areanames{en}->{618967067} = "Tammin";
$areanames{en}->{618967068} = "Tammin";
$areanames{en}->{618967070} = "Wongan\ Hills";
$areanames{en}->{618967071} = "Wongan\ Hills";
$areanames{en}->{618967072} = "Wongan\ Hills";
$areanames{en}->{618967073} = "Wongan\ Hills";
$areanames{en}->{618967074} = "Wongan\ Hills";
$areanames{en}->{618967075} = "Wongan\ Hills";
$areanames{en}->{618967076} = "Wongan\ Hills";
$areanames{en}->{618967077} = "Wongan\ Hills";
$areanames{en}->{618967078} = "Wongan\ Hills";
$areanames{en}->{618967080} = "Wubin";
$areanames{en}->{618967081} = "Wubin";
$areanames{en}->{618967082} = "Wubin";
$areanames{en}->{618967083} = "Wubin";
$areanames{en}->{618967084} = "Wubin";
$areanames{en}->{618967085} = "Wubin";
$areanames{en}->{618967086} = "Wubin";
$areanames{en}->{618967087} = "Wubin";
$areanames{en}->{618967088} = "Wubin";
$areanames{en}->{618967090} = "Yorkrakine";
$areanames{en}->{618967091} = "Yorkrakine";
$areanames{en}->{618967092} = "Yorkrakine";
$areanames{en}->{618967093} = "Yorkrakine";
$areanames{en}->{618967094} = "Yorkrakine";
$areanames{en}->{618967095} = "Yorkrakine";
$areanames{en}->{618967096} = "Yorkrakine";
$areanames{en}->{618967097} = "Yorkrakine";
$areanames{en}->{618967098} = "Yorkrakine";
$areanames{en}->{61896710} = "Wongan\ Hills";
$areanames{en}->{61896711} = "Wongan\ Hills";
$areanames{en}->{61896712} = "Wongan\ Hills";
$areanames{en}->{61896720} = "Wongan\ Hills";
$areanames{en}->{61896721} = "Wongan\ Hills";
$areanames{en}->{61896722} = "Wongan\ Hills";
$areanames{en}->{61896723} = "Wongan\ Hills";
$areanames{en}->{61896730} = "Cadoux";
$areanames{en}->{61896731} = "Cadoux";
$areanames{en}->{61896732} = "Cadoux";
$areanames{en}->{61896741} = "Ballidu";
$areanames{en}->{61896743} = "Ballidu";
$areanames{en}->{61896744} = "Ballidu";
$areanames{en}->{61896746} = "Dalwallinu";
$areanames{en}->{61896750} = "Burakin";
$areanames{en}->{61896751} = "Burakin";
$areanames{en}->{618967600} = "Wubin\ West";
$areanames{en}->{618967601} = "Wubin\ West";
$areanames{en}->{618967602} = "Wubin\ West";
$areanames{en}->{618967603} = "Wubin\ West";
$areanames{en}->{618967604} = "Wubin\ West";
$areanames{en}->{618967605} = "Wubin\ West";
$areanames{en}->{618967606} = "Wubin\ West";
$areanames{en}->{618967607} = "Wubin\ West";
$areanames{en}->{618967608} = "Wubin\ West";
$areanames{en}->{618967610} = "Badgerin\ Rock";
$areanames{en}->{618967611} = "Badgerin\ Rock";
$areanames{en}->{618967612} = "Badgerin\ Rock";
$areanames{en}->{618967613} = "Badgerin\ Rock";
$areanames{en}->{618967614} = "Badgerin\ Rock";
$areanames{en}->{618967615} = "Badgerin\ Rock";
$areanames{en}->{618967616} = "Badgerin\ Rock";
$areanames{en}->{618967617} = "Badgerin\ Rock";
$areanames{en}->{618967618} = "Badgerin\ Rock";
$areanames{en}->{618967620} = "Beacon";
$areanames{en}->{618967621} = "Beacon";
$areanames{en}->{618967622} = "Beacon";
$areanames{en}->{618967623} = "Beacon";
$areanames{en}->{618967624} = "Beacon";
$areanames{en}->{618967625} = "Beacon";
$areanames{en}->{618967626} = "Beacon";
$areanames{en}->{618967627} = "Beacon";
$areanames{en}->{618967628} = "Beacon";
$areanames{en}->{618967630} = "Beacon\ North";
$areanames{en}->{618967631} = "Beacon\ North";
$areanames{en}->{618967632} = "Beacon\ North";
$areanames{en}->{618967633} = "Beacon\ North";
$areanames{en}->{618967634} = "Beacon\ North";
$areanames{en}->{618967635} = "Beacon\ North";
$areanames{en}->{618967636} = "Beacon\ North";
$areanames{en}->{618967637} = "Beacon\ North";
$areanames{en}->{618967638} = "Beacon\ North";
$areanames{en}->{618967640} = "Bencubbin";
$areanames{en}->{618967641} = "Bencubbin";
$areanames{en}->{618967642} = "Bencubbin";
$areanames{en}->{618967643} = "Bencubbin";
$areanames{en}->{618967644} = "Bencubbin";
$areanames{en}->{618967645} = "Bencubbin";
$areanames{en}->{618967646} = "Bencubbin";
$areanames{en}->{618967647} = "Bencubbin";
$areanames{en}->{618967648} = "Bencubbin";
$areanames{en}->{618967650} = "Cleary\ North";
$areanames{en}->{618967651} = "Cleary\ North";
$areanames{en}->{618967652} = "Cleary\ North";
$areanames{en}->{618967653} = "Cleary\ North";
$areanames{en}->{618967654} = "Cleary\ North";
$areanames{en}->{618967655} = "Cleary\ North";
$areanames{en}->{618967656} = "Cleary\ North";
$areanames{en}->{618967657} = "Cleary\ North";
$areanames{en}->{618967658} = "Cleary\ North";
$areanames{en}->{618967660} = "Dukin";
$areanames{en}->{618967661} = "Dukin";
$areanames{en}->{618967662} = "Dukin";
$areanames{en}->{618967663} = "Dukin";
$areanames{en}->{618967664} = "Dukin";
$areanames{en}->{618967665} = "Dukin";
$areanames{en}->{618967666} = "Dukin";
$areanames{en}->{618967667} = "Dukin";
$areanames{en}->{618967668} = "Dukin";
$areanames{en}->{618967670} = "Gabbin";
$areanames{en}->{618967671} = "Gabbin";
$areanames{en}->{618967672} = "Gabbin";
$areanames{en}->{618967673} = "Gabbin";
$areanames{en}->{618967674} = "Gabbin";
$areanames{en}->{618967675} = "Gabbin";
$areanames{en}->{618967676} = "Gabbin";
$areanames{en}->{618967677} = "Gabbin";
$areanames{en}->{618967678} = "Gabbin";
$areanames{en}->{618967680} = "Gabbin\ North";
$areanames{en}->{618967681} = "Gabbin\ North";
$areanames{en}->{618967682} = "Gabbin\ North";
$areanames{en}->{618967683} = "Gabbin\ North";
$areanames{en}->{618967684} = "Gabbin\ North";
$areanames{en}->{618967685} = "Gabbin\ North";
$areanames{en}->{618967686} = "Gabbin\ North";
$areanames{en}->{618967687} = "Gabbin\ North";
$areanames{en}->{618967688} = "Gabbin\ North";
$areanames{en}->{618967690} = "Koorda";
$areanames{en}->{618967691} = "Koorda";
$areanames{en}->{618967692} = "Koorda";
$areanames{en}->{618967693} = "Koorda";
$areanames{en}->{618967694} = "Koorda";
$areanames{en}->{618967695} = "Koorda";
$areanames{en}->{618967696} = "Koorda";
$areanames{en}->{618967697} = "Koorda";
$areanames{en}->{618967698} = "Koorda";
$areanames{en}->{618967700} = "Trayning";
$areanames{en}->{618967701} = "Trayning";
$areanames{en}->{618967702} = "Trayning";
$areanames{en}->{618967703} = "Trayning";
$areanames{en}->{618967704} = "Trayning";
$areanames{en}->{618967705} = "Trayning";
$areanames{en}->{618967706} = "Trayning";
$areanames{en}->{618967707} = "Trayning";
$areanames{en}->{618967708} = "Trayning";
$areanames{en}->{618967710} = "Wyalkatchem";
$areanames{en}->{618967711} = "Wyalkatchem";
$areanames{en}->{618967712} = "Wyalkatchem";
$areanames{en}->{618967713} = "Wyalkatchem";
$areanames{en}->{618967714} = "Wyalkatchem";
$areanames{en}->{618967715} = "Wyalkatchem";
$areanames{en}->{618967716} = "Wyalkatchem";
$areanames{en}->{618967717} = "Wyalkatchem";
$areanames{en}->{618967718} = "Wyalkatchem";
$areanames{en}->{618967720} = "Yelbeni";
$areanames{en}->{618967721} = "Yelbeni";
$areanames{en}->{618967722} = "Yelbeni";
$areanames{en}->{618967723} = "Yelbeni";
$areanames{en}->{618967724} = "Yelbeni";
$areanames{en}->{618967725} = "Yelbeni";
$areanames{en}->{618967726} = "Yelbeni";
$areanames{en}->{618967727} = "Yelbeni";
$areanames{en}->{618967728} = "Yelbeni";
$areanames{en}->{618967730} = "Aldersyde";
$areanames{en}->{618967731} = "Aldersyde";
$areanames{en}->{618967732} = "Aldersyde";
$areanames{en}->{618967733} = "Aldersyde";
$areanames{en}->{618967734} = "Aldersyde";
$areanames{en}->{618967735} = "Aldersyde";
$areanames{en}->{618967736} = "Aldersyde";
$areanames{en}->{618967737} = "Aldersyde";
$areanames{en}->{618967738} = "Aldersyde";
$areanames{en}->{618967740} = "Balkuling";
$areanames{en}->{618967741} = "Balkuling";
$areanames{en}->{618967742} = "Balkuling";
$areanames{en}->{618967743} = "Balkuling";
$areanames{en}->{618967744} = "Balkuling";
$areanames{en}->{618967745} = "Balkuling";
$areanames{en}->{618967746} = "Balkuling";
$areanames{en}->{618967747} = "Balkuling";
$areanames{en}->{618967748} = "Balkuling";
$areanames{en}->{618967750} = "Beverley";
$areanames{en}->{618967751} = "Beverley";
$areanames{en}->{618967752} = "Beverley";
$areanames{en}->{618967753} = "Beverley";
$areanames{en}->{618967754} = "Beverley";
$areanames{en}->{618967755} = "Beverley";
$areanames{en}->{618967756} = "Beverley";
$areanames{en}->{618967757} = "Beverley";
$areanames{en}->{618967758} = "Beverley";
$areanames{en}->{618967760} = "Beverley\ West";
$areanames{en}->{618967761} = "Beverley\ West";
$areanames{en}->{618967762} = "Beverley\ West";
$areanames{en}->{618967763} = "Beverley\ West";
$areanames{en}->{618967764} = "Beverley\ West";
$areanames{en}->{618967765} = "Beverley\ West";
$areanames{en}->{618967766} = "Beverley\ West";
$areanames{en}->{618967767} = "Beverley\ West";
$areanames{en}->{618967768} = "Beverley\ West";
$areanames{en}->{618967770} = "Brookton";
$areanames{en}->{618967771} = "Brookton";
$areanames{en}->{618967772} = "Brookton";
$areanames{en}->{618967773} = "Brookton";
$areanames{en}->{618967774} = "Brookton";
$areanames{en}->{618967775} = "Brookton";
$areanames{en}->{618967776} = "Brookton";
$areanames{en}->{618967777} = "Brookton";
$areanames{en}->{618967778} = "Brookton";
$areanames{en}->{618967780} = "Dale\ River";
$areanames{en}->{618967781} = "Dale\ River";
$areanames{en}->{618967782} = "Dale\ River";
$areanames{en}->{618967783} = "Dale\ River";
$areanames{en}->{618967784} = "Dale\ River";
$areanames{en}->{618967785} = "Dale\ River";
$areanames{en}->{618967786} = "Dale\ River";
$areanames{en}->{618967787} = "Dale\ River";
$areanames{en}->{618967788} = "Dale\ River";
$areanames{en}->{618967790} = "Dangin";
$areanames{en}->{618967791} = "Dangin";
$areanames{en}->{618967792} = "Dangin";
$areanames{en}->{618967793} = "Dangin";
$areanames{en}->{618967794} = "Dangin";
$areanames{en}->{618967795} = "Dangin";
$areanames{en}->{618967796} = "Dangin";
$areanames{en}->{618967797} = "Dangin";
$areanames{en}->{618967798} = "Dangin";
$areanames{en}->{618967800} = "Jelkobine";
$areanames{en}->{618967801} = "Jelkobine";
$areanames{en}->{618967802} = "Jelkobine";
$areanames{en}->{618967803} = "Jelkobine";
$areanames{en}->{618967804} = "Jelkobine";
$areanames{en}->{618967805} = "Jelkobine";
$areanames{en}->{618967806} = "Jelkobine";
$areanames{en}->{618967807} = "Jelkobine";
$areanames{en}->{618967808} = "Jelkobine";
$areanames{en}->{618967810} = "Pantapin";
$areanames{en}->{618967811} = "Pantapin";
$areanames{en}->{618967812} = "Pantapin";
$areanames{en}->{618967813} = "Pantapin";
$areanames{en}->{618967814} = "Pantapin";
$areanames{en}->{618967815} = "Pantapin";
$areanames{en}->{618967816} = "Pantapin";
$areanames{en}->{618967817} = "Pantapin";
$areanames{en}->{618967818} = "Pantapin";
$areanames{en}->{618967820} = "Quairading";
$areanames{en}->{618967821} = "Quairading";
$areanames{en}->{618967822} = "Quairading";
$areanames{en}->{618967823} = "Quairading";
$areanames{en}->{618967824} = "Quairading";
$areanames{en}->{618967825} = "Quairading";
$areanames{en}->{618967826} = "Quairading";
$areanames{en}->{618967827} = "Quairading";
$areanames{en}->{618967828} = "Quairading";
$areanames{en}->{618967830} = "South\ Quairading";
$areanames{en}->{618967831} = "South\ Quairading";
$areanames{en}->{618967832} = "South\ Quairading";
$areanames{en}->{618967833} = "South\ Quairading";
$areanames{en}->{618967834} = "South\ Quairading";
$areanames{en}->{618967835} = "South\ Quairading";
$areanames{en}->{618967836} = "South\ Quairading";
$areanames{en}->{618967837} = "South\ Quairading";
$areanames{en}->{618967838} = "South\ Quairading";
$areanames{en}->{618967840} = "Talbot\ Brook";
$areanames{en}->{618967841} = "Talbot\ Brook";
$areanames{en}->{618967842} = "Talbot\ Brook";
$areanames{en}->{618967843} = "Talbot\ Brook";
$areanames{en}->{618967844} = "Talbot\ Brook";
$areanames{en}->{618967845} = "Talbot\ Brook";
$areanames{en}->{618967846} = "Talbot\ Brook";
$areanames{en}->{618967847} = "Talbot\ Brook";
$areanames{en}->{618967848} = "Talbot\ Brook";
$areanames{en}->{618967850} = "York";
$areanames{en}->{618967851} = "York";
$areanames{en}->{618967852} = "York";
$areanames{en}->{618967853} = "York";
$areanames{en}->{618967854} = "York";
$areanames{en}->{618967855} = "York";
$areanames{en}->{618967856} = "York";
$areanames{en}->{618967857} = "York";
$areanames{en}->{618967858} = "York";
$areanames{en}->{61896786} = "Wongan\ Hills";
$areanames{en}->{61896787} = "Wubin";
$areanames{en}->{61896788} = "Wubin\ West";
$areanames{en}->{61896789} = "Badgerin\ Rock";
$areanames{en}->{61896790} = "Beacon";
$areanames{en}->{61896791} = "Beacon\ North";
$areanames{en}->{61896792} = "Bencubbin";
$areanames{en}->{61896793} = "Cleary\ North";
$areanames{en}->{61896794} = "Dukin";
$areanames{en}->{61896795} = "Gabbin";
$areanames{en}->{61896796} = "Gabbin\ North";
$areanames{en}->{61896797} = "Koorda";
$areanames{en}->{61896798} = "Trayning";
$areanames{en}->{61896799} = "Wyalkatchem";
$areanames{en}->{61896800} = "Yelbeni";
$areanames{en}->{61896801} = "Aldersyde";
$areanames{en}->{61896802} = "Balkuling";
$areanames{en}->{61896803} = "Beverley";
$areanames{en}->{61896804} = "Beverley\ West";
$areanames{en}->{61896805} = "Brookton";
$areanames{en}->{61896806} = "Dale\ River";
$areanames{en}->{61896807} = "Dangin";
$areanames{en}->{61896808} = "Jelkobine";
$areanames{en}->{61896809} = "Pantapin";
$areanames{en}->{61896810} = "Wyalkatchem";
$areanames{en}->{61896811} = "Wyalkatchem";
$areanames{en}->{61896812} = "Wyalkatchem";
$areanames{en}->{61896813} = "York";
$areanames{en}->{61896814} = "Wyalkatchem";
$areanames{en}->{61896815} = "Wyalkatchem";
$areanames{en}->{61896820} = "Dukin";
$areanames{en}->{61896821} = "Dukin";
$areanames{en}->{61896825} = "Yelbeni";
$areanames{en}->{61896826} = "Koorda";
$areanames{en}->{61896830} = "Trayning";
$areanames{en}->{61896831} = "Trayning";
$areanames{en}->{61896832} = "Trayning";
$areanames{en}->{61896840} = "Koorda";
$areanames{en}->{61896841} = "Koorda";
$areanames{en}->{61896842} = "Koorda";
$areanames{en}->{61896843} = "Badgerin\ Rock";
$areanames{en}->{61896844} = "Badgerin\ Rock";
$areanames{en}->{61896845} = "Badgerin\ Rock";
$areanames{en}->{61896846} = "Gabbin\ North";
$areanames{en}->{61896847} = "Gabbin\ North";
$areanames{en}->{61896848} = "Gabbin";
$areanames{en}->{61896849} = "Gabbin";
$areanames{en}->{61896850} = "Bencubbin";
$areanames{en}->{61896851} = "Bencubbin";
$areanames{en}->{61896852} = "Bencubbin";
$areanames{en}->{61896860} = "Beacon";
$areanames{en}->{61896861} = "Beacon";
$areanames{en}->{61896862} = "Bencubbin";
$areanames{en}->{61896863} = "Bencubbin";
$areanames{en}->{61896864} = "Beacon\ North";
$areanames{en}->{61896865} = "Beacon\ North";
$areanames{en}->{61896866} = "Cleary\ North";
$areanames{en}->{61896867} = "Cleary\ North";
$areanames{en}->{61896868} = "Cadoux";
$areanames{en}->{61896869} = "Cadoux";
$areanames{en}->{61896870} = "Quairading";
$areanames{en}->{61896871} = "South\ Quairading";
$areanames{en}->{61896872} = "Talbot\ Brook";
$areanames{en}->{61896873} = "York";
$areanames{en}->{61896885} = "Bibby\ Springs";
$areanames{en}->{61896886} = "Jurien";
$areanames{en}->{61896887} = "Jurien";
$areanames{en}->{61896888} = "Jurien";
$areanames{en}->{61896889} = "Dandaragan";
$areanames{en}->{61896890} = "Pantapin";
$areanames{en}->{61896891} = "Quairading";
$areanames{en}->{61896892} = "South\ Quairading";
$areanames{en}->{61896893} = "Talbot\ Brook";
$areanames{en}->{61896894} = "York";
$areanames{en}->{61896895} = "Paynes\ Find";
$areanames{en}->{61896901} = "Northam";
$areanames{en}->{61896902} = "Northam";
$areanames{en}->{61896903} = "Cunderdin";
$areanames{en}->{61896904} = "Cunderdin";
$areanames{en}->{61896908} = "Moora";
$areanames{en}->{61896909} = "Dandaragan";
$areanames{en}->{61896911} = "Wongan\ Hills";
$areanames{en}->{61896921} = "Wyalkatchem";
$areanames{en}->{61896931} = "York";
$areanames{en}->{61896940} = "Badgingarra";
$areanames{en}->{61896941} = "Bibby\ Springs";
$areanames{en}->{61896942} = "Bidaminna";
$areanames{en}->{61896943} = "Coomallo";
$areanames{en}->{61896944} = "Coomberdale";
$areanames{en}->{61896945} = "Dandaragan";
$areanames{en}->{61896946} = "Gillingarra";
$areanames{en}->{61896947} = "Jurien";
$areanames{en}->{61896948} = "Lancelin";
$areanames{en}->{61896949} = "Miling";
$areanames{en}->{61896950} = "Moora";
$areanames{en}->{61896951} = "Regans\ Ford";
$areanames{en}->{61896952} = "Wannamal";
$areanames{en}->{61896953} = "Watheroo";
$areanames{en}->{61896954} = "Yerecoin";
$areanames{en}->{61896955} = "Bolgart";
$areanames{en}->{61896956} = "Calingiri";
$areanames{en}->{61896957} = "Cunderdin";
$areanames{en}->{61896958} = "Cunderdin\ North";
$areanames{en}->{61896959} = "Dowerin";
$areanames{en}->{61896960} = "Ejanding";
$areanames{en}->{61896961} = "Goomalling";
$areanames{en}->{61896962} = "Jennacubbine";
$areanames{en}->{61896963} = "Konnongorring";
$areanames{en}->{61896964} = "Meckering";
$areanames{en}->{61896965} = "Northam";
$areanames{en}->{61896966} = "Studleigh";
$areanames{en}->{61896967} = "Tammin";
$areanames{en}->{61896968} = "Yorkrakine";
$areanames{en}->{61896969} = "Ballidu";
$areanames{en}->{61896970} = "Burakin";
$areanames{en}->{61896971} = "Cadoux";
$areanames{en}->{61896972} = "Dalwallinu";
$areanames{en}->{61896973} = "Dalwallinu\ West";
$areanames{en}->{61896974} = "Goodlands";
$areanames{en}->{61896975} = "Kalannie";
$areanames{en}->{61896976} = "Kalannie\ East";
$areanames{en}->{61896977} = "Wongan\ Hills";
$areanames{en}->{61896978} = "Wubin";
$areanames{en}->{61896979} = "Wubin\ West";
$areanames{en}->{61896980} = "Badgerin\ Rock";
$areanames{en}->{61896981} = "Beacon";
$areanames{en}->{61896982} = "Beacon\ North";
$areanames{en}->{61896983} = "Bencubbin";
$areanames{en}->{61896984} = "Cleary\ North";
$areanames{en}->{61896985} = "Dukin";
$areanames{en}->{61896986} = "Gabbin";
$areanames{en}->{61896987} = "Gabbin\ North";
$areanames{en}->{61896988} = "Koorda";
$areanames{en}->{61896989} = "Trayning";
$areanames{en}->{61896990} = "Wyalkatchem";
$areanames{en}->{61896991} = "Yelbeni";
$areanames{en}->{61896992} = "Aldersyde";
$areanames{en}->{61896993} = "Balkuling";
$areanames{en}->{61896994} = "Beverley";
$areanames{en}->{61896995} = "Beverley\ West";
$areanames{en}->{61896996} = "Brookton";
$areanames{en}->{61896997} = "Dale\ River";
$areanames{en}->{61896998} = "Dangin";
$areanames{en}->{61896999} = "Jelkobine";
$areanames{en}->{61897000} = "Augusta";
$areanames{en}->{61897001} = "Augusta";
$areanames{en}->{61897002} = "Augusta";
$areanames{en}->{61897003} = "Balingup";
$areanames{en}->{61897004} = "Balingup";
$areanames{en}->{61897005} = "Balingup";
$areanames{en}->{61897006} = "Beedelup";
$areanames{en}->{61897007} = "Beedelup";
$areanames{en}->{61897008} = "Beedelup";
$areanames{en}->{61897009} = "Manjimup";
$areanames{en}->{61897010} = "Boyup\ Brook";
$areanames{en}->{61897011} = "Boyup\ Brook";
$areanames{en}->{61897012} = "Boyup\ Brook";
$areanames{en}->{61897013} = "Bridgetown";
$areanames{en}->{61897014} = "Bridgetown";
$areanames{en}->{61897015} = "Bridgetown";
$areanames{en}->{61897016} = "Brunswick\ Junction";
$areanames{en}->{61897017} = "Brunswick\ Junction";
$areanames{en}->{61897018} = "Brunswick\ Junction";
$areanames{en}->{61897019} = "Bunbury";
$areanames{en}->{61897020} = "Bunbury";
$areanames{en}->{61897021} = "Bunbury";
$areanames{en}->{61897022} = "Bunbury";
$areanames{en}->{61897023} = "Busselton";
$areanames{en}->{61897024} = "Busselton";
$areanames{en}->{61897025} = "Busselton";
$areanames{en}->{61897026} = "Capel";
$areanames{en}->{61897027} = "Capel";
$areanames{en}->{61897028} = "Capel";
$areanames{en}->{61897029} = "Wilga";
$areanames{en}->{61897030} = "Collie";
$areanames{en}->{61897031} = "Collie";
$areanames{en}->{61897032} = "Collie";
$areanames{en}->{61897033} = "Cundinup";
$areanames{en}->{61897034} = "Cundinup";
$areanames{en}->{61897035} = "Cundinup";
$areanames{en}->{61897036} = "Dardanup";
$areanames{en}->{61897037} = "Dardanup";
$areanames{en}->{61897038} = "Dardanup";
$areanames{en}->{61897039} = "Balingup";
$areanames{en}->{61897040} = "Darkan";
$areanames{en}->{61897041} = "Darkan";
$areanames{en}->{61897042} = "Darkan";
$areanames{en}->{61897043} = "Dinninup";
$areanames{en}->{61897044} = "Dinninup";
$areanames{en}->{61897045} = "Dinninup";
$areanames{en}->{61897046} = "Dinninup\ North";
$areanames{en}->{61897047} = "Dinninup\ North";
$areanames{en}->{61897048} = "Dinninup\ North";
$areanames{en}->{61897049} = "Beedelup";
$areanames{en}->{61897050} = "Donnybrook";
$areanames{en}->{61897051} = "Donnybrook";
$areanames{en}->{61897052} = "Donnybrook";
$areanames{en}->{61897053} = "Harvey";
$areanames{en}->{61897054} = "Harvey";
$areanames{en}->{61897055} = "Harvey";
$areanames{en}->{61897056} = "Jangardup";
$areanames{en}->{61897057} = "Jangardup";
$areanames{en}->{61897058} = "Jangardup";
$areanames{en}->{61897059} = "Boyup\ Brook";
$areanames{en}->{61897060} = "Lake\ Clifton";
$areanames{en}->{61897061} = "Lake\ Clifton";
$areanames{en}->{61897062} = "Lake\ Clifton";
$areanames{en}->{61897063} = "Manjimup";
$areanames{en}->{61897064} = "Manjimup";
$areanames{en}->{61897065} = "Manjimup";
$areanames{en}->{61897066} = "Margaret\ River";
$areanames{en}->{61897067} = "Margaret\ River";
$areanames{en}->{61897068} = "Margaret\ River";
$areanames{en}->{61897069} = "Margaret\ River";
$areanames{en}->{61897070} = "Bunbury";
$areanames{en}->{61897071} = "Bunbury";
$areanames{en}->{61897072} = "Bunbury";
$areanames{en}->{61897073} = "Bunbury";
$areanames{en}->{61897074} = "Marybrook";
$areanames{en}->{61897075} = "Marybrook";
$areanames{en}->{61897076} = "Marybrook";
$areanames{en}->{61897077} = "Myalup";
$areanames{en}->{61897078} = "Myalup";
$areanames{en}->{61897079} = "Myalup";
$areanames{en}->{61897080} = "Nannup";
$areanames{en}->{61897081} = "Nannup";
$areanames{en}->{61897082} = "Nannup";
$areanames{en}->{61897083} = "Nyamup";
$areanames{en}->{61897084} = "Nyamup";
$areanames{en}->{61897085} = "Nyamup";
$areanames{en}->{61897086} = "Pemberton";
$areanames{en}->{61897087} = "Pemberton";
$areanames{en}->{61897088} = "Pemberton";
$areanames{en}->{61897089} = "Pemberton";
$areanames{en}->{61897090} = "Tonebridge";
$areanames{en}->{61897091} = "Tonebridge";
$areanames{en}->{61897092} = "Tonebridge";
$areanames{en}->{61897093} = "Upper\ Preston";
$areanames{en}->{61897094} = "Upper\ Preston";
$areanames{en}->{61897095} = "Upper\ Preston";
$areanames{en}->{61897096} = "Waroona";
$areanames{en}->{61897097} = "Waroona";
$areanames{en}->{61897098} = "Waroona";
$areanames{en}->{61897099} = "Bridgetown";
$areanames{en}->{61897100} = "Wilga";
$areanames{en}->{61897101} = "Wilga";
$areanames{en}->{61897102} = "Wilga";
$areanames{en}->{61897103} = "Dinninup";
$areanames{en}->{61897104} = "Dinninup\ North";
$areanames{en}->{61897105} = "Manjimup";
$areanames{en}->{61897106} = "Nyamup";
$areanames{en}->{61897107} = "Pemberton";
$areanames{en}->{61897108} = "Tonebridge";
$areanames{en}->{61897109} = "Upper\ Preston";
$areanames{en}->{61897110} = "Brunswick\ Junction";
$areanames{en}->{61897111} = "Bunbury";
$areanames{en}->{61897112} = "Capel";
$areanames{en}->{61897113} = "Collie";
$areanames{en}->{61897114} = "Dardanup";
$areanames{en}->{61897115} = "Darkan";
$areanames{en}->{61897116} = "Donnybrook";
$areanames{en}->{61897117} = "Harvey";
$areanames{en}->{61897118} = "Myalup";
$areanames{en}->{61897119} = "Augusta";
$areanames{en}->{61897120} = "Busselton";
$areanames{en}->{61897121} = "Cundinup";
$areanames{en}->{61897122} = "Jangardup";
$areanames{en}->{61897123} = "Margaret\ River";
$areanames{en}->{61897124} = "Marybrook";
$areanames{en}->{61897125} = "Nannup";
$areanames{en}->{61897126} = "Balingup";
$areanames{en}->{61897127} = "Beedelup";
$areanames{en}->{61897128} = "Boyup\ Brook";
$areanames{en}->{61897129} = "Bridgetown";
$areanames{en}->{61897130} = "Dinninup";
$areanames{en}->{61897131} = "Dinninup\ North";
$areanames{en}->{61897132} = "Manjimup";
$areanames{en}->{61897133} = "Nyamup";
$areanames{en}->{61897134} = "Pemberton";
$areanames{en}->{61897135} = "Tonebridge";
$areanames{en}->{61897136} = "Wilga";
$areanames{en}->{61897137} = "Brunswick\ Junction";
$areanames{en}->{61897138} = "Bunbury";
$areanames{en}->{61897139} = "Capel";
$areanames{en}->{61897140} = "Collie";
$areanames{en}->{61897141} = "Dardanup";
$areanames{en}->{61897142} = "Darkan";
$areanames{en}->{61897143} = "Donnybrook";
$areanames{en}->{61897144} = "Harvey";
$areanames{en}->{61897145} = "Myalup";
$areanames{en}->{61897146} = "Upper\ Preston";
$areanames{en}->{61897147} = "Augusta";
$areanames{en}->{61897148} = "Busselton";
$areanames{en}->{61897149} = "Cundinup";
$areanames{en}->{61897150} = "Jangardup";
$areanames{en}->{61897151} = "Margaret\ River";
$areanames{en}->{61897152} = "Marybrook";
$areanames{en}->{61897153} = "Nannup";
$areanames{en}->{61897154} = "Wilga";
$areanames{en}->{61897155} = "Balingup";
$areanames{en}->{61897156} = "Beedelup";
$areanames{en}->{61897157} = "Boyup\ Brook";
$areanames{en}->{61897158} = "Bridgetown";
$areanames{en}->{61897159} = "Dinninup";
$areanames{en}->{61897160} = "Dinninup\ North";
$areanames{en}->{61897161} = "Manjimup";
$areanames{en}->{61897162} = "Nyamup";
$areanames{en}->{61897163} = "Pemberton";
$areanames{en}->{61897164} = "Tonebridge";
$areanames{en}->{61897165} = "Upper\ Preston";
$areanames{en}->{61897166} = "Brunswick\ Junction";
$areanames{en}->{61897167} = "Bunbury";
$areanames{en}->{61897168} = "Capel";
$areanames{en}->{61897169} = "Collie";
$areanames{en}->{61897170} = "Dardanup";
$areanames{en}->{61897171} = "Darkan";
$areanames{en}->{61897172} = "Donnybrook";
$areanames{en}->{61897173} = "Harvey";
$areanames{en}->{61897174} = "Myalup";
$areanames{en}->{61897175} = "Augusta";
$areanames{en}->{61897176} = "Busselton";
$areanames{en}->{61897177} = "Cundinup";
$areanames{en}->{61897178} = "Jangardup";
$areanames{en}->{61897179} = "Margaret\ River";
$areanames{en}->{61897180} = "Marybrook";
$areanames{en}->{61897181} = "Nannup";
$areanames{en}->{61897182} = "Balingup";
$areanames{en}->{61897183} = "Balingup";
$areanames{en}->{61897184} = "Beedelup";
$areanames{en}->{61897185} = "Balingup";
$areanames{en}->{61897186} = "Beedelup";
$areanames{en}->{61897187} = "Boyup\ Brook";
$areanames{en}->{61897188} = "Bridgetown";
$areanames{en}->{61897189} = "Dinninup";
$areanames{en}->{61897190} = "Dinninup\ North";
$areanames{en}->{61897191} = "Manjimup";
$areanames{en}->{61897192} = "Nyamup";
$areanames{en}->{61897193} = "Pemberton";
$areanames{en}->{61897194} = "Tonebridge";
$areanames{en}->{61897195} = "Wilga";
$areanames{en}->{61897196} = "Brunswick\ Junction";
$areanames{en}->{61897197} = "Capel";
$areanames{en}->{61897198} = "Collie";
$areanames{en}->{61897199} = "Dardanup";
$areanames{en}->{618972} = "Bunbury";
$areanames{en}->{61897200} = "Myalup";
$areanames{en}->{61897201} = "Myalup";
$areanames{en}->{61897202} = "Myalup";
$areanames{en}->{61897230} = "Brunswick\ Junction";
$areanames{en}->{61897231} = "Darkan";
$areanames{en}->{61897232} = "Donnybrook";
$areanames{en}->{61897233} = "Harvey";
$areanames{en}->{61897234} = "Myalup";
$areanames{en}->{61897235} = "Upper\ Preston";
$areanames{en}->{61897236} = "Augusta";
$areanames{en}->{61897237} = "Busselton";
$areanames{en}->{61897238} = "Cundinup";
$areanames{en}->{61897239} = "Jangardup";
$areanames{en}->{61897261} = "Brunswick\ Junction";
$areanames{en}->{61897263} = "Brunswick\ Junction";
$areanames{en}->{61897268} = "Brunswick\ Junction";
$areanames{en}->{61897269} = "Brunswick\ Junction";
$areanames{en}->{6189727} = "Capel";
$areanames{en}->{6189728} = "Dardanup";
$areanames{en}->{61897290} = "Harvey";
$areanames{en}->{61897291} = "Harvey";
$areanames{en}->{61897292} = "Harvey";
$areanames{en}->{61897293} = "Harvey";
$areanames{en}->{61897298} = "Harvey";
$areanames{en}->{61897300} = "Margaret\ River";
$areanames{en}->{61897301} = "Marybrook";
$areanames{en}->{61897302} = "Nannup";
$areanames{en}->{61897303} = "Bunbury";
$areanames{en}->{61897304} = "Beedelup";
$areanames{en}->{61897305} = "Boyup\ Brook";
$areanames{en}->{61897306} = "Bridgetown";
$areanames{en}->{61897307} = "Dinninup";
$areanames{en}->{61897308} = "Dinninup\ North";
$areanames{en}->{61897309} = "Nyamup";
$areanames{en}->{6189731} = "Donnybrook";
$areanames{en}->{6189732} = "Donnybrook";
$areanames{en}->{61897322} = "Upper\ Preston";
$areanames{en}->{6189733} = "Waroona";
$areanames{en}->{61897339} = "Collie";
$areanames{en}->{6189734} = "Collie";
$areanames{en}->{6189735} = "Collie";
$areanames{en}->{6189736} = "Upper\ Preston";
$areanames{en}->{61897360} = "Darkan";
$areanames{en}->{61897361} = "Darkan";
$areanames{en}->{61897362} = "Darkan";
$areanames{en}->{61897363} = "Darkan";
$areanames{en}->{61897370} = "Tonebridge";
$areanames{en}->{61897371} = "Wilga";
$areanames{en}->{61897372} = "Brunswick\ Junction";
$areanames{en}->{61897373} = "Capel";
$areanames{en}->{61897374} = "Collie";
$areanames{en}->{61897375} = "Dardanup";
$areanames{en}->{61897376} = "Darkan";
$areanames{en}->{61897377} = "Donnybrook";
$areanames{en}->{61897378} = "Harvey";
$areanames{en}->{61897379} = "Myalup";
$areanames{en}->{61897380} = "Upper\ Preston";
$areanames{en}->{61897381} = "Augusta";
$areanames{en}->{61897382} = "Cundinup";
$areanames{en}->{61897383} = "Jangardup";
$areanames{en}->{61897384} = "Nannup";
$areanames{en}->{61897385} = "Boyup\ Brook";
$areanames{en}->{61897386} = "Bridgetown";
$areanames{en}->{61897387} = "Dinninup";
$areanames{en}->{61897388} = "Dinninup\ North";
$areanames{en}->{61897389} = "Manjimup";
$areanames{en}->{6189739} = "Lake\ Clifton";
$areanames{en}->{61897400} = "Nyamup";
$areanames{en}->{61897401} = "Pemberton";
$areanames{en}->{61897402} = "Tonebridge";
$areanames{en}->{61897403} = "Wilga";
$areanames{en}->{61897404} = "Brunswick\ Junction";
$areanames{en}->{61897405} = "Bunbury";
$areanames{en}->{61897406} = "Capel";
$areanames{en}->{61897407} = "Collie";
$areanames{en}->{61897408} = "Dardanup";
$areanames{en}->{61897409} = "Darkan";
$areanames{en}->{61897410} = "Donnybrook";
$areanames{en}->{61897411} = "Harvey";
$areanames{en}->{61897412} = "Myalup";
$areanames{en}->{61897413} = "Upper\ Preston";
$areanames{en}->{61897414} = "Augusta";
$areanames{en}->{61897415} = "Busselton";
$areanames{en}->{61897416} = "Cundinup";
$areanames{en}->{61897417} = "Jangardup";
$areanames{en}->{61897418} = "Margaret\ River";
$areanames{en}->{61897419} = "Marybrook";
$areanames{en}->{61897420} = "Nannup";
$areanames{en}->{61897421} = "Bunbury";
$areanames{en}->{61897422} = "Bridgetown";
$areanames{en}->{61897423} = "Balingup";
$areanames{en}->{61897424} = "Bridgetown";
$areanames{en}->{61897425} = "Beedelup";
$areanames{en}->{61897426} = "Boyup\ Brook";
$areanames{en}->{61897427} = "Manjimup";
$areanames{en}->{61897428} = "Bridgetown";
$areanames{en}->{61897429} = "Pemberton";
$areanames{en}->{61897430} = "Dinninup";
$areanames{en}->{61897431} = "Dinninup\ North";
$areanames{en}->{61897432} = "Brunswick\ Junction";
$areanames{en}->{61897433} = "Bunbury";
$areanames{en}->{61897434} = "Capel";
$areanames{en}->{61897435} = "Collie";
$areanames{en}->{61897436} = "Manjimup";
$areanames{en}->{61897437} = "Nyamup";
$areanames{en}->{61897438} = "Donnybrook";
$areanames{en}->{61897439} = "Harvey";
$areanames{en}->{61897440} = "Myalup";
$areanames{en}->{61897441} = "Pemberton";
$areanames{en}->{61897442} = "Augusta";
$areanames{en}->{61897443} = "Busselton";
$areanames{en}->{61897444} = "Tonebridge";
$areanames{en}->{61897445} = "Wilga";
$areanames{en}->{61897446} = "Margaret\ River";
$areanames{en}->{61897447} = "Marybrook";
$areanames{en}->{61897448} = "Brunswick\ Junction";
$areanames{en}->{61897449} = "Busselton";
$areanames{en}->{6189745} = "Bunbury";
$areanames{en}->{61897460} = "Bunbury";
$areanames{en}->{61897461} = "Augusta";
$areanames{en}->{61897462} = "Bunbury";
$areanames{en}->{61897463} = "Marybrook";
$areanames{en}->{61897464} = "Marybrook";
$areanames{en}->{61897465} = "Margaret\ River";
$areanames{en}->{61897466} = "Manjimup";
$areanames{en}->{61897467} = "Nannup";
$areanames{en}->{61897468} = "Nannup";
$areanames{en}->{61897469} = "Capel";
$areanames{en}->{61897470} = "Collie";
$areanames{en}->{61897471} = "Dinninup";
$areanames{en}->{61897472} = "Dinninup\ North";
$areanames{en}->{61897473} = "Nyamup";
$areanames{en}->{61897474} = "Upper\ Preston";
$areanames{en}->{61897475} = "Nannup";
$areanames{en}->{61897476} = "Margaret\ River";
$areanames{en}->{61897477} = "Bunbury";
$areanames{en}->{61897478} = "Cundinup";
$areanames{en}->{61897479} = "Dardanup";
$areanames{en}->{61897480} = "Darkan";
$areanames{en}->{61897481} = "Donnybrook";
$areanames{en}->{61897482} = "Capel";
$areanames{en}->{61897483} = "Harvey";
$areanames{en}->{61897484} = "Pemberton";
$areanames{en}->{61897485} = "Beedelup";
$areanames{en}->{61897486} = "Myalup";
$areanames{en}->{61897487} = "Wilga";
$areanames{en}->{61897488} = "Dardanup";
$areanames{en}->{61897489} = "Donnybrook";
$areanames{en}->{61897490} = "Harvey";
$areanames{en}->{61897491} = "Marybrook";
$areanames{en}->{61897492} = "Manjimup";
$areanames{en}->{61897493} = "Boyup\ Brook";
$areanames{en}->{61897494} = "Darkan";
$areanames{en}->{61897495} = "Collie";
$areanames{en}->{61897496} = "Balingup";
$areanames{en}->{61897497} = "Busselton";
$areanames{en}->{61897498} = "Bridgetown";
$areanames{en}->{61897499} = "Myalup";
$areanames{en}->{6189750} = "Marybrook";
$areanames{en}->{6189751} = "Busselton";
$areanames{en}->{6189752} = "Busselton";
$areanames{en}->{6189753} = "Busselton";
$areanames{en}->{6189754} = "Busselton";
$areanames{en}->{6189755} = "Marybrook";
$areanames{en}->{61897560} = "Nannup";
$areanames{en}->{61897561} = "Nannup";
$areanames{en}->{61897562} = "Cundinup";
$areanames{en}->{61897563} = "Nannup";
$areanames{en}->{61897564} = "Jangardup";
$areanames{en}->{61897565} = "Marybrook";
$areanames{en}->{61897566} = "Marybrook";
$areanames{en}->{61897567} = "Marybrook";
$areanames{en}->{61897568} = "Marybrook";
$areanames{en}->{61897569} = "Marybrook";
$areanames{en}->{6189757} = "Margaret\ River";
$areanames{en}->{6189758} = "Augusta";
$areanames{en}->{61897587} = "Margaret\ River";
$areanames{en}->{61897588} = "Margaret\ River";
$areanames{en}->{61897589} = "Margaret\ River";
$areanames{en}->{6189759} = "Margaret\ River";
$areanames{en}->{61897591} = "Marybrook";
$areanames{en}->{61897600} = "Margaret\ River";
$areanames{en}->{61897601} = "Bunbury";
$areanames{en}->{61897602} = "Balingup";
$areanames{en}->{61897603} = "Balingup";
$areanames{en}->{61897604} = "Nyamup";
$areanames{en}->{61897605} = "Nyamup";
$areanames{en}->{61897606} = "Beedelup";
$areanames{en}->{61897607} = "Beedelup";
$areanames{en}->{61897608} = "Manjimup";
$areanames{en}->{61897609} = "Manjimup";
$areanames{en}->{6189761} = "Bridgetown";
$areanames{en}->{61897620} = "Bridgetown";
$areanames{en}->{61897621} = "Boyup\ Brook";
$areanames{en}->{61897622} = "Bunbury";
$areanames{en}->{61897623} = "Bunbury";
$areanames{en}->{61897624} = "Bunbury";
$areanames{en}->{61897625} = "Brunswick\ Junction";
$areanames{en}->{61897626} = "Collie";
$areanames{en}->{61897627} = "Bridgetown";
$areanames{en}->{61897628} = "Bridgetown";
$areanames{en}->{61897629} = "Dinninup";
$areanames{en}->{61897630} = "Dinninup";
$areanames{en}->{61897631} = "Dinninup\ North";
$areanames{en}->{61897632} = "Dinninup\ North";
$areanames{en}->{61897633} = "Pemberton";
$areanames{en}->{61897634} = "Pemberton";
$areanames{en}->{61897635} = "Tonebridge";
$areanames{en}->{61897636} = "Tonebridge";
$areanames{en}->{61897637} = "Wilga";
$areanames{en}->{61897638} = "Wilga";
$areanames{en}->{61897639} = "Upper\ Preston";
$areanames{en}->{61897640} = "Balingup";
$areanames{en}->{61897641} = "Balingup";
$areanames{en}->{61897642} = "Balingup";
$areanames{en}->{61897643} = "Balingup";
$areanames{en}->{61897644} = "Balingup";
$areanames{en}->{61897645} = "Bridgetown";
$areanames{en}->{61897646} = "Bridgetown";
$areanames{en}->{61897647} = "Bridgetown";
$areanames{en}->{61897648} = "Bridgetown";
$areanames{en}->{61897649} = "Bridgetown";
$areanames{en}->{6189765} = "Manjimup";
$areanames{en}->{61897650} = "Boyup\ Brook";
$areanames{en}->{61897651} = "Boyup\ Brook";
$areanames{en}->{61897652} = "Boyup\ Brook";
$areanames{en}->{61897653} = "Boyup\ Brook";
$areanames{en}->{6189766} = "Wilga";
$areanames{en}->{61897670} = "Dinninup";
$areanames{en}->{61897671} = "Dinninup";
$areanames{en}->{61897672} = "Dinninup\ North";
$areanames{en}->{61897673} = "Dinninup";
$areanames{en}->{61897674} = "Dinninup\ North";
$areanames{en}->{61897675} = "Dinninup";
$areanames{en}->{61897676} = "Manjimup";
$areanames{en}->{61897677} = "Manjimup";
$areanames{en}->{61897678} = "Manjimup";
$areanames{en}->{61897679} = "Manjimup";
$areanames{en}->{61897680} = "Bunbury";
$areanames{en}->{61897681} = "Bunbury";
$areanames{en}->{61897682} = "Capel";
$areanames{en}->{61897683} = "Capel";
$areanames{en}->{61897684} = "Dardanup";
$areanames{en}->{61897685} = "Dardanup";
$areanames{en}->{61897686} = "Donnybrook";
$areanames{en}->{61897687} = "Donnybrook";
$areanames{en}->{61897688} = "Harvey";
$areanames{en}->{61897689} = "Harvey";
$areanames{en}->{6189769} = "Tonebridge";
$areanames{en}->{6189770} = "Bunbury";
$areanames{en}->{6189771} = "Manjimup";
$areanames{en}->{6189772} = "Manjimup";
$areanames{en}->{6189773} = "Nyamup";
$areanames{en}->{61897740} = "Bunbury";
$areanames{en}->{61897741} = "Augusta";
$areanames{en}->{61897742} = "Augusta";
$areanames{en}->{61897743} = "Busselton";
$areanames{en}->{61897744} = "Busselton";
$areanames{en}->{61897745} = "Margaret\ River";
$areanames{en}->{61897746} = "Margaret\ River";
$areanames{en}->{61897747} = "Marybrook";
$areanames{en}->{61897748} = "Marybrook";
$areanames{en}->{61897749} = "Augusta";
$areanames{en}->{6189775} = "Pemberton";
$areanames{en}->{6189776} = "Pemberton";
$areanames{en}->{61897762} = "Beedelup";
$areanames{en}->{61897763} = "Beedelup";
$areanames{en}->{61897769} = "Beedelup";
$areanames{en}->{6189777} = "Pemberton";
$areanames{en}->{61897770} = "Manjimup";
$areanames{en}->{61897771} = "Manjimup";
$areanames{en}->{61897772} = "Manjimup";
$areanames{en}->{61897780} = "Bunbury";
$areanames{en}->{61897781} = "Cundinup";
$areanames{en}->{61897782} = "Cundinup";
$areanames{en}->{61897783} = "Jangardup";
$areanames{en}->{61897784} = "Jangardup";
$areanames{en}->{61897785} = "Bunbury";
$areanames{en}->{61897786} = "Busselton";
$areanames{en}->{61897787} = "Busselton";
$areanames{en}->{61897788} = "Busselton";
$areanames{en}->{61897789} = "Busselton";
$areanames{en}->{61897790} = "Cundinup";
$areanames{en}->{61897791} = "Jangardup";
$areanames{en}->{61897792} = "Tonebridge";
$areanames{en}->{61897793} = "Augusta";
$areanames{en}->{61897794} = "Augusta";
$areanames{en}->{61897795} = "Dinninup";
$areanames{en}->{61897796} = "Collie";
$areanames{en}->{61897797} = "Dinninup\ North";
$areanames{en}->{61897798} = "Nyamup";
$areanames{en}->{61897799} = "Bunbury";
$areanames{en}->{6189780} = "Bunbury";
$areanames{en}->{61897802} = "Collie";
$areanames{en}->{61897803} = "Capel";
$areanames{en}->{61897804} = "Donnybrook";
$areanames{en}->{61897805} = "Margaret\ River";
$areanames{en}->{61897810} = "Busselton";
$areanames{en}->{61897811} = "Busselton";
$areanames{en}->{61897812} = "Bunbury";
$areanames{en}->{61897813} = "Marybrook";
$areanames{en}->{61897814} = "Bunbury";
$areanames{en}->{61897815} = "Augusta";
$areanames{en}->{61897816} = "Collie";
$areanames{en}->{61897817} = "Collie";
$areanames{en}->{61897818} = "Collie";
$areanames{en}->{61897819} = "Collie";
$areanames{en}->{61897820} = "Manjimup";
$areanames{en}->{61897821} = "Bridgetown";
$areanames{en}->{61897822} = "Harvey";
$areanames{en}->{61897823} = "Harvey";
$areanames{en}->{61897824} = "Harvey";
$areanames{en}->{61897825} = "Balingup";
$areanames{en}->{61897826} = "Waroona";
$areanames{en}->{61897827} = "Waroona";
$areanames{en}->{61897828} = "Waroona";
$areanames{en}->{61897829} = "Waroona";
$areanames{en}->{61897830} = "Jangardup";
$areanames{en}->{61897831} = "Upper\ Preston";
$areanames{en}->{61897832} = "Nannup";
$areanames{en}->{61897833} = "Dinninup";
$areanames{en}->{61897834} = "Margaret\ River";
$areanames{en}->{61897835} = "Bunbury";
$areanames{en}->{61897836} = "Dinninup\ North";
$areanames{en}->{61897837} = "Cundinup";
$areanames{en}->{61897838} = "Donnybrook";
$areanames{en}->{61897839} = "Margaret\ River";
$areanames{en}->{61897840} = "Myalup";
$areanames{en}->{61897841} = "Nyamup";
$areanames{en}->{61897842} = "Capel";
$areanames{en}->{61897843} = "Harvey";
$areanames{en}->{61897844} = "Pemberton";
$areanames{en}->{61897845} = "Beedelup";
$areanames{en}->{61897846} = "Myalup";
$areanames{en}->{61897847} = "Upper\ Preston";
$areanames{en}->{61897848} = "Wilga";
$areanames{en}->{61897849} = "Myalup";
$areanames{en}->{61897850} = "Marybrook";
$areanames{en}->{61897851} = "Nannup";
$areanames{en}->{61897852} = "Margaret\ River";
$areanames{en}->{61897853} = "Cundinup";
$areanames{en}->{61897854} = "Donnybrook";
$areanames{en}->{61897855} = "Capel";
$areanames{en}->{61897856} = "Dardanup";
$areanames{en}->{61897857} = "Marybrook";
$areanames{en}->{61897858} = "Manjimup";
$areanames{en}->{61897859} = "Nannup";
$areanames{en}->{61897860} = "Brunswick\ Junction";
$areanames{en}->{61897861} = "Boyup\ Brook";
$areanames{en}->{61897862} = "Darkan";
$areanames{en}->{61897863} = "Collie";
$areanames{en}->{61897864} = "Balingup";
$areanames{en}->{61897865} = "Busselton";
$areanames{en}->{61897866} = "Bridgetown";
$areanames{en}->{61897867} = "Brunswick\ Junction";
$areanames{en}->{61897868} = "Jangardup";
$areanames{en}->{61897869} = "Brunswick\ Junction";
$areanames{en}->{61897870} = "Cundinup";
$areanames{en}->{61897871} = "Tonebridge";
$areanames{en}->{61897872} = "Harvey";
$areanames{en}->{61897873} = "Pemberton";
$areanames{en}->{61897874} = "Beedelup";
$areanames{en}->{61897875} = "Myalup";
$areanames{en}->{61897876} = "Wilga";
$areanames{en}->{61897877} = "Dardanup";
$areanames{en}->{61897878} = "Marybrook";
$areanames{en}->{61897879} = "Bunbury";
$areanames{en}->{61897880} = "Bunbury";
$areanames{en}->{61897881} = "Manjimup";
$areanames{en}->{61897882} = "Boyup\ Brook";
$areanames{en}->{61897883} = "Darkan";
$areanames{en}->{61897884} = "Collie";
$areanames{en}->{61897885} = "Balingup";
$areanames{en}->{61897886} = "Busselton";
$areanames{en}->{61897887} = "Bridgetown";
$areanames{en}->{61897888} = "Brunswick\ Junction";
$areanames{en}->{61897889} = "Brunswick\ Junction";
$areanames{en}->{6189789} = "Bunbury";
$areanames{en}->{61897890} = "Jangardup";
$areanames{en}->{61897891} = "Jangardup";
$areanames{en}->{61897892} = "Tonebridge";
$areanames{en}->{61897895} = "Boyup\ Brook";
$areanames{en}->{61897900} = "Bunbury";
$areanames{en}->{61897901} = "Boyup\ Brook";
$areanames{en}->{61897902} = "Boyup\ Brook";
$areanames{en}->{61897903} = "Nannup";
$areanames{en}->{61897904} = "Nannup";
$areanames{en}->{61897905} = "Lake\ Clifton";
$areanames{en}->{61897906} = "Lake\ Clifton";
$areanames{en}->{61897907} = "Waroona";
$areanames{en}->{61897908} = "Waroona";
$areanames{en}->{61897909} = "Boyup\ Brook";
$areanames{en}->{6189791} = "Bunbury";
$areanames{en}->{6189792} = "Bunbury";
$areanames{en}->{61897930} = "Myalup";
$areanames{en}->{61897931} = "Myalup";
$areanames{en}->{61897932} = "Collie";
$areanames{en}->{61897933} = "Collie";
$areanames{en}->{61897934} = "Brunswick\ Junction";
$areanames{en}->{61897935} = "Brunswick\ Junction";
$areanames{en}->{61897936} = "Darkan";
$areanames{en}->{61897937} = "Darkan";
$areanames{en}->{61897938} = "Upper\ Preston";
$areanames{en}->{61897939} = "Upper\ Preston";
$areanames{en}->{61897940} = "Upper\ Preston";
$areanames{en}->{61897941} = "Augusta";
$areanames{en}->{61897942} = "Busselton";
$areanames{en}->{61897943} = "Cundinup";
$areanames{en}->{61897944} = "Jangardup";
$areanames{en}->{61897945} = "Margaret\ River";
$areanames{en}->{61897946} = "Marybrook";
$areanames{en}->{61897947} = "Nannup";
$areanames{en}->{61897948} = "Marybrook";
$areanames{en}->{61897949} = "Busselton";
$areanames{en}->{6189795} = "Bunbury";
$areanames{en}->{6189796} = "Bunbury";
$areanames{en}->{6189797} = "Bunbury";
$areanames{en}->{61897980} = "Wilga";
$areanames{en}->{61897981} = "Brunswick\ Junction";
$areanames{en}->{61897982} = "Bunbury";
$areanames{en}->{61897983} = "Capel";
$areanames{en}->{61897984} = "Collie";
$areanames{en}->{61897985} = "Dardanup";
$areanames{en}->{61897986} = "Darkan";
$areanames{en}->{61897987} = "Donnybrook";
$areanames{en}->{61897988} = "Harvey";
$areanames{en}->{61897989} = "Myalup";
$areanames{en}->{61897990} = "Balingup";
$areanames{en}->{61897991} = "Beedelup";
$areanames{en}->{61897992} = "Boyup\ Brook";
$areanames{en}->{61897993} = "Bridgetown";
$areanames{en}->{61897994} = "Dinninup";
$areanames{en}->{61897995} = "Dinninup\ North";
$areanames{en}->{61897996} = "Manjimup";
$areanames{en}->{61897997} = "Nyamup";
$areanames{en}->{61897998} = "Pemberton";
$areanames{en}->{61897999} = "Tonebridge";
$areanames{en}->{61898000} = "Albany";
$areanames{en}->{61898001} = "Albany";
$areanames{en}->{61898002} = "Albany";
$areanames{en}->{61898003} = "Amelup";
$areanames{en}->{61898004} = "Amelup";
$areanames{en}->{61898005} = "Amelup";
$areanames{en}->{61898006} = "Arthur\ River";
$areanames{en}->{61898007} = "Arthur\ River";
$areanames{en}->{61898008} = "Arthur\ River";
$areanames{en}->{61898009} = "Albany";
$areanames{en}->{61898010} = "Badgebup";
$areanames{en}->{61898011} = "Badgebup";
$areanames{en}->{61898012} = "Badgebup";
$areanames{en}->{61898013} = "Badgebup\ North";
$areanames{en}->{61898014} = "Badgebup\ North";
$areanames{en}->{61898015} = "Badgebup\ North";
$areanames{en}->{61898016} = "Beaufort\ River";
$areanames{en}->{61898017} = "Beaufort\ River";
$areanames{en}->{61898018} = "Beaufort\ River";
$areanames{en}->{61898019} = "Wagin";
$areanames{en}->{61898020} = "Bedford\ Harbour";
$areanames{en}->{61898021} = "Bedford\ Harbour";
$areanames{en}->{61898022} = "Bedford\ Harbour";
$areanames{en}->{61898023} = "Boddington";
$areanames{en}->{61898024} = "Boddington";
$areanames{en}->{61898025} = "Boddington";
$areanames{en}->{61898026} = "Bokerup";
$areanames{en}->{61898027} = "Bokerup";
$areanames{en}->{61898028} = "Bokerup";
$areanames{en}->{61898029} = "Varley";
$areanames{en}->{61898030} = "Borden";
$areanames{en}->{61898031} = "Borden";
$areanames{en}->{61898032} = "Borden";
$areanames{en}->{61898033} = "Boscabel";
$areanames{en}->{61898034} = "Boscabel";
$areanames{en}->{61898035} = "Boscabel";
$areanames{en}->{61898036} = "Bow\ Bridge";
$areanames{en}->{61898037} = "Bow\ Bridge";
$areanames{en}->{61898038} = "Bow\ Bridge";
$areanames{en}->{61898039} = "Tarin\ Rock";
$areanames{en}->{61898040} = "Bradfords";
$areanames{en}->{61898041} = "Bradfords";
$areanames{en}->{61898042} = "Bradfords";
$areanames{en}->{61898043} = "Bremer\ Bay";
$areanames{en}->{61898044} = "Bremer\ Bay";
$areanames{en}->{61898045} = "Bremer\ Bay";
$areanames{en}->{61898046} = "Broomehill";
$areanames{en}->{61898047} = "Broomehill";
$areanames{en}->{61898048} = "Broomehill";
$areanames{en}->{61898049} = "Pingaring";
$areanames{en}->{61898050} = "Cairlocup";
$areanames{en}->{61898051} = "Cairlocup";
$areanames{en}->{61898052} = "Cairlocup";
$areanames{en}->{61898053} = "Chittinup";
$areanames{en}->{61898054} = "Chittinup";
$areanames{en}->{61898055} = "Chittinup";
$areanames{en}->{61898056} = "Congee";
$areanames{en}->{61898057} = "Congee";
$areanames{en}->{61898058} = "Congee";
$areanames{en}->{61898059} = "Newdegate\ North";
$areanames{en}->{61898060} = "Corackerup";
$areanames{en}->{61898061} = "Corackerup";
$areanames{en}->{61898062} = "Corackerup";
$areanames{en}->{61898063} = "Cranbrook";
$areanames{en}->{61898064} = "Cranbrook";
$areanames{en}->{61898065} = "Cranbrook";
$areanames{en}->{61898066} = "Cuballing";
$areanames{en}->{61898067} = "Cuballing";
$areanames{en}->{61898068} = "Cuballing";
$areanames{en}->{61898069} = "Newdegate\ East";
$areanames{en}->{61898070} = "Denbarker";
$areanames{en}->{61898071} = "Denbarker";
$areanames{en}->{61898072} = "Denbarker";
$areanames{en}->{61898073} = "Denmark";
$areanames{en}->{61898074} = "Denmark";
$areanames{en}->{61898075} = "Denmark";
$areanames{en}->{61898076} = "Dongolocking";
$areanames{en}->{61898077} = "Dongolocking";
$areanames{en}->{61898078} = "Dongolocking";
$areanames{en}->{61898079} = "Newdegate";
$areanames{en}->{61898080} = "Dudinin";
$areanames{en}->{61898081} = "Dudinin";
$areanames{en}->{61898082} = "Dudinin";
$areanames{en}->{61898083} = "Dumbleyung";
$areanames{en}->{61898084} = "Dumbleyung";
$areanames{en}->{61898085} = "Dumbleyung";
$areanames{en}->{61898086} = "Fitzgerald";
$areanames{en}->{61898087} = "Fitzgerald";
$areanames{en}->{61898088} = "Fitzgerald";
$areanames{en}->{61898089} = "Moulyinning";
$areanames{en}->{61898090} = "Gairdner";
$areanames{en}->{61898091} = "Gairdner";
$areanames{en}->{61898092} = "Gairdner";
$areanames{en}->{61898093} = "Gnowangerup";
$areanames{en}->{61898094} = "Gnowangerup";
$areanames{en}->{61898095} = "Gnowangerup";
$areanames{en}->{61898096} = "Gnowellen";
$areanames{en}->{61898097} = "Gnowellen";
$areanames{en}->{61898098} = "Gnowellen";
$areanames{en}->{61898099} = "Moodiarrup";
$areanames{en}->{61898100} = "Harrismith";
$areanames{en}->{61898101} = "Harrismith";
$areanames{en}->{61898102} = "Harrismith";
$areanames{en}->{61898103} = "Hartville";
$areanames{en}->{61898104} = "Hartville";
$areanames{en}->{61898105} = "Hartville";
$areanames{en}->{61898106} = "Holland\ Rocks";
$areanames{en}->{61898107} = "Holland\ Rocks";
$areanames{en}->{61898108} = "Holland\ Rocks";
$areanames{en}->{61898109} = "Lake\ Magenta";
$areanames{en}->{61898110} = "Hopetoun";
$areanames{en}->{61898111} = "Hopetoun";
$areanames{en}->{61898112} = "Hopetoun";
$areanames{en}->{61898113} = "Hyden";
$areanames{en}->{61898114} = "Hyden";
$areanames{en}->{61898115} = "Hyden";
$areanames{en}->{61898116} = "Hyden\ East";
$areanames{en}->{61898117} = "Hyden\ East";
$areanames{en}->{61898118} = "Hyden\ East";
$areanames{en}->{61898119} = "Lake\ King";
$areanames{en}->{61898120} = "Jacup";
$areanames{en}->{61898121} = "Jacup";
$areanames{en}->{61898122} = "Jacup";
$areanames{en}->{61898123} = "Jaloran";
$areanames{en}->{61898124} = "Jaloran";
$areanames{en}->{61898125} = "Jaloran";
$areanames{en}->{61898126} = "Jerdacuttup";
$areanames{en}->{61898127} = "Jerdacuttup";
$areanames{en}->{61898128} = "Jerdacuttup";
$areanames{en}->{61898129} = "Lake\ Grace";
$areanames{en}->{61898130} = "Jerramungup";
$areanames{en}->{61898131} = "Jerramungup";
$areanames{en}->{61898132} = "Jerramungup";
$areanames{en}->{61898133} = "Jingalup";
$areanames{en}->{61898134} = "Jingalup";
$areanames{en}->{61898135} = "Jingalup";
$areanames{en}->{61898136} = "Karlgarin";
$areanames{en}->{61898137} = "Karlgarin";
$areanames{en}->{61898138} = "Karlgarin";
$areanames{en}->{61898139} = "Kukerin";
$areanames{en}->{61898140} = "Katanning";
$areanames{en}->{61898141} = "Katanning";
$areanames{en}->{61898142} = "Katanning";
$areanames{en}->{61898143} = "Kojaneerup";
$areanames{en}->{61898144} = "Kojaneerup";
$areanames{en}->{61898145} = "Kojaneerup";
$areanames{en}->{61898146} = "Kojonup";
$areanames{en}->{61898147} = "Kojonup";
$areanames{en}->{61898148} = "Kojonup";
$areanames{en}->{61898149} = "Jaloran";
$areanames{en}->{61898150} = "Kondinin";
$areanames{en}->{61898151} = "Kondinin";
$areanames{en}->{61898152} = "Kondinin";
$areanames{en}->{61898153} = "Kronkup";
$areanames{en}->{61898154} = "Kronkup";
$areanames{en}->{61898155} = "Kronkup";
$areanames{en}->{61898156} = "Kukerin";
$areanames{en}->{61898157} = "Kukerin";
$areanames{en}->{61898158} = "Kukerin";
$areanames{en}->{61898159} = "Holland\ Rocks";
$areanames{en}->{61898160} = "Kulin";
$areanames{en}->{61898161} = "Kulin";
$areanames{en}->{61898162} = "Kulin";
$areanames{en}->{61898163} = "Kulin\ West";
$areanames{en}->{61898164} = "Kulin\ West";
$areanames{en}->{61898165} = "Kulin\ West";
$areanames{en}->{61898166} = "Kuringup";
$areanames{en}->{61898167} = "Kuringup";
$areanames{en}->{61898168} = "Kuringup";
$areanames{en}->{61898169} = "Dumbleyung";
$areanames{en}->{61898170} = "Lake\ Grace";
$areanames{en}->{61898171} = "Lake\ Grace";
$areanames{en}->{61898172} = "Lake\ Grace";
$areanames{en}->{61898173} = "Lake\ King";
$areanames{en}->{61898174} = "Lake\ King";
$areanames{en}->{61898175} = "Lake\ King";
$areanames{en}->{61898176} = "Lake\ Magenta";
$areanames{en}->{61898177} = "Lake\ Magenta";
$areanames{en}->{61898178} = "Lake\ Magenta";
$areanames{en}->{61898179} = "Dongolocking";
$areanames{en}->{61898180} = "Lake\ Oconnor";
$areanames{en}->{61898181} = "Lake\ Oconnor";
$areanames{en}->{61898182} = "Lake\ Oconnor";
$areanames{en}->{61898183} = "Lake\ Toolbrunup";
$areanames{en}->{61898184} = "Lake\ Toolbrunup";
$areanames{en}->{61898185} = "Lake\ Toolbrunup";
$areanames{en}->{61898186} = "Lumeah";
$areanames{en}->{61898187} = "Lumeah";
$areanames{en}->{61898188} = "Lumeah";
$areanames{en}->{61898189} = "Beaufort\ River";
$areanames{en}->{61898190} = "Magitup";
$areanames{en}->{61898191} = "Magitup";
$areanames{en}->{61898192} = "Magitup";
$areanames{en}->{61898193} = "Manypeaks";
$areanames{en}->{61898194} = "Manypeaks";
$areanames{en}->{61898195} = "Manypeaks";
$areanames{en}->{61898196} = "Manypeaks\ North";
$areanames{en}->{61898197} = "Manypeaks\ North";
$areanames{en}->{61898198} = "Manypeaks\ North";
$areanames{en}->{61898199} = "Arthur\ River";
$areanames{en}->{61898200} = "Pingrup";
$areanames{en}->{61898201} = "Pingrup";
$areanames{en}->{61898202} = "Albany";
$areanames{en}->{61898203} = "Albany";
$areanames{en}->{61898204} = "Cairlocup";
$areanames{en}->{61898205} = "Cairlocup";
$areanames{en}->{61898206} = "Pingrup\ East";
$areanames{en}->{61898207} = "Katanning";
$areanames{en}->{61898208} = "Katanning";
$areanames{en}->{61898209} = "Katanning";
$areanames{en}->{6189821} = "Katanning";
$areanames{en}->{61898220} = "Badgebup";
$areanames{en}->{61898221} = "Badgebup";
$areanames{en}->{618982220} = "Albany";
$areanames{en}->{618982221} = "Albany";
$areanames{en}->{618982222} = "Albany";
$areanames{en}->{618982223} = "Albany";
$areanames{en}->{618982224} = "Albany";
$areanames{en}->{618982225} = "Albany";
$areanames{en}->{618982226} = "Albany";
$areanames{en}->{618982230} = "Bokerup";
$areanames{en}->{618982233} = "Bokerup";
$areanames{en}->{618982236} = "Bokerup";
$areanames{en}->{618982237} = "Bokerup";
$areanames{en}->{618982238} = "Bokerup";
$areanames{en}->{618982240} = "Bow\ Bridge";
$areanames{en}->{618982243} = "Bow\ Bridge";
$areanames{en}->{618982246} = "Bow\ Bridge";
$areanames{en}->{618982247} = "Bow\ Bridge";
$areanames{en}->{618982248} = "Bow\ Bridge";
$areanames{en}->{618982250} = "Denbarker";
$areanames{en}->{618982253} = "Denbarker";
$areanames{en}->{618982256} = "Denbarker";
$areanames{en}->{618982257} = "Denbarker";
$areanames{en}->{618982258} = "Denbarker";
$areanames{en}->{618982260} = "Denmark";
$areanames{en}->{618982261} = "Denmark";
$areanames{en}->{618982262} = "Denmark";
$areanames{en}->{618982263} = "Denmark";
$areanames{en}->{618982264} = "Denmark";
$areanames{en}->{618982265} = "Denmark";
$areanames{en}->{618982266} = "Denmark";
$areanames{en}->{618982267} = "Denmark";
$areanames{en}->{618982268} = "Denmark";
$areanames{en}->{61898227} = "Congee";
$areanames{en}->{61898228} = "Congee";
$areanames{en}->{61898229} = "Congee";
$areanames{en}->{61898230} = "Woodanilling";
$areanames{en}->{61898231} = "Woodanilling";
$areanames{en}->{61898232} = "Woodanilling";
$areanames{en}->{61898233} = "Badgebup\ North";
$areanames{en}->{61898234} = "Badgebup\ North";
$areanames{en}->{61898235} = "Badgebup\ North";
$areanames{en}->{618982360} = "Gnowellen";
$areanames{en}->{618982363} = "Gnowellen";
$areanames{en}->{618982366} = "Gnowellen";
$areanames{en}->{618982367} = "Gnowellen";
$areanames{en}->{618982368} = "Gnowellen";
$areanames{en}->{618982370} = "Kojaneerup";
$areanames{en}->{618982373} = "Kojaneerup";
$areanames{en}->{618982376} = "Kojaneerup";
$areanames{en}->{618982377} = "Kojaneerup";
$areanames{en}->{618982378} = "Kojaneerup";
$areanames{en}->{618982380} = "Kronkup";
$areanames{en}->{618982383} = "Kronkup";
$areanames{en}->{618982386} = "Kronkup";
$areanames{en}->{618982387} = "Kronkup";
$areanames{en}->{618982388} = "Kronkup";
$areanames{en}->{618982390} = "Manypeaks";
$areanames{en}->{618982393} = "Manypeaks";
$areanames{en}->{618982396} = "Manypeaks";
$areanames{en}->{618982397} = "Manypeaks";
$areanames{en}->{618982398} = "Manypeaks";
$areanames{en}->{61898240} = "Broomehill";
$areanames{en}->{61898241} = "Broomehill";
$areanames{en}->{618982420} = "Manypeaks\ North";
$areanames{en}->{618982421} = "Manypeaks\ North";
$areanames{en}->{618982422} = "Manypeaks\ North";
$areanames{en}->{618982423} = "Manypeaks\ North";
$areanames{en}->{618982426} = "Manypeaks\ North";
$areanames{en}->{618982427} = "Manypeaks\ North";
$areanames{en}->{618982428} = "Manypeaks\ North";
$areanames{en}->{618982430} = "Mettler";
$areanames{en}->{618982433} = "Mettler";
$areanames{en}->{618982436} = "Mettler";
$areanames{en}->{618982437} = "Mettler";
$areanames{en}->{618982438} = "Mettler";
$areanames{en}->{618982440} = "Mount\ Barker";
$areanames{en}->{618982441} = "Mount\ Barker";
$areanames{en}->{618982442} = "Mount\ Barker";
$areanames{en}->{618982443} = "Mount\ Barker";
$areanames{en}->{618982446} = "Mount\ Barker";
$areanames{en}->{618982447} = "Mount\ Barker";
$areanames{en}->{618982448} = "Mount\ Barker";
$areanames{en}->{618982449} = "Mount\ Barker";
$areanames{en}->{618982450} = "Perillup";
$areanames{en}->{618982453} = "Perillup";
$areanames{en}->{618982456} = "Perillup";
$areanames{en}->{618982457} = "Perillup";
$areanames{en}->{618982458} = "Perillup";
$areanames{en}->{618982460} = "Porongurup";
$areanames{en}->{618982463} = "Porongurup";
$areanames{en}->{618982466} = "Porongurup";
$areanames{en}->{618982467} = "Porongurup";
$areanames{en}->{618982468} = "Porongurup";
$areanames{en}->{618982470} = "Rocky\ Gully";
$areanames{en}->{618982473} = "Rocky\ Gully";
$areanames{en}->{618982476} = "Rocky\ Gully";
$areanames{en}->{618982477} = "Rocky\ Gully";
$areanames{en}->{618982478} = "Rocky\ Gully";
$areanames{en}->{618982480} = "Tenterden";
$areanames{en}->{618982483} = "Tenterden";
$areanames{en}->{618982486} = "Tenterden";
$areanames{en}->{618982487} = "Tenterden";
$areanames{en}->{618982488} = "Tenterden";
$areanames{en}->{618982490} = "Unicup";
$areanames{en}->{618982493} = "Unicup";
$areanames{en}->{618982496} = "Unicup";
$areanames{en}->{618982497} = "Unicup";
$areanames{en}->{618982498} = "Unicup";
$areanames{en}->{618982500} = "Walpole";
$areanames{en}->{618982501} = "Walpole";
$areanames{en}->{618982502} = "Walpole";
$areanames{en}->{618982503} = "Walpole";
$areanames{en}->{618982504} = "Walpole";
$areanames{en}->{618982505} = "Walpole";
$areanames{en}->{618982506} = "Walpole";
$areanames{en}->{618982507} = "Walpole";
$areanames{en}->{618982508} = "Walpole";
$areanames{en}->{61898251} = "Tambellup";
$areanames{en}->{618982520} = "Woogenilup";
$areanames{en}->{618982523} = "Woogenilup";
$areanames{en}->{618982526} = "Woogenilup";
$areanames{en}->{618982527} = "Woogenilup";
$areanames{en}->{618982528} = "Woogenilup";
$areanames{en}->{61898253} = "Tambellup";
$areanames{en}->{61898254} = "Tambellup";
$areanames{en}->{61898255} = "Tambellup";
$areanames{en}->{61898256} = "Kuringup";
$areanames{en}->{61898257} = "Kuringup";
$areanames{en}->{61898258} = "Lake\ Toolbrunup";
$areanames{en}->{61898259} = "Lake\ Toolbrunup";
$areanames{en}->{61898260} = "Cranbrook";
$areanames{en}->{61898261} = "Cranbrook";
$areanames{en}->{61898262} = "Cranbrook";
$areanames{en}->{61898263} = "Kojonup";
$areanames{en}->{61898264} = "Kojonup";
$areanames{en}->{61898265} = "Denmark";
$areanames{en}->{61898266} = "Denmark";
$areanames{en}->{61898267} = "Hartville";
$areanames{en}->{61898268} = "Hartville";
$areanames{en}->{61898269} = "Hartville";
$areanames{en}->{61898270} = "Gnowangerup";
$areanames{en}->{61898271} = "Gnowangerup";
$areanames{en}->{61898272} = "Gnowangerup";
$areanames{en}->{61898273} = "Gnowangerup";
$areanames{en}->{61898274} = "Amelup";
$areanames{en}->{61898275} = "Amelup";
$areanames{en}->{61898276} = "Magitup";
$areanames{en}->{61898277} = "Magitup";
$areanames{en}->{61898278} = "Magitup";
$areanames{en}->{61898279} = "Amelup";
$areanames{en}->{61898280} = "Borden";
$areanames{en}->{61898281} = "Borden";
$areanames{en}->{61898282} = "Borden";
$areanames{en}->{61898283} = "Borden";
$areanames{en}->{61898284} = "Ongerup\ North";
$areanames{en}->{61898285} = "Ongerup\ North";
$areanames{en}->{61898286} = "Ongerup\ North";
$areanames{en}->{61898287} = "Nalyerlup";
$areanames{en}->{61898288} = "Nalyerlup";
$areanames{en}->{61898289} = "Nalyerlup";
$areanames{en}->{61898290} = "Nyabing";
$areanames{en}->{61898291} = "Nyabing";
$areanames{en}->{618982920} = "Amelup";
$areanames{en}->{618982923} = "Amelup";
$areanames{en}->{618982926} = "Amelup";
$areanames{en}->{618982927} = "Amelup";
$areanames{en}->{618982928} = "Amelup";
$areanames{en}->{618982930} = "Badgebup";
$areanames{en}->{618982933} = "Badgebup";
$areanames{en}->{618982936} = "Badgebup";
$areanames{en}->{618982937} = "Badgebup";
$areanames{en}->{618982938} = "Badgebup";
$areanames{en}->{618982940} = "Badgebup\ North";
$areanames{en}->{618982943} = "Badgebup\ North";
$areanames{en}->{618982946} = "Badgebup\ North";
$areanames{en}->{618982947} = "Badgebup\ North";
$areanames{en}->{618982948} = "Badgebup\ North";
$areanames{en}->{618982950} = "Bedford\ Harbour";
$areanames{en}->{618982953} = "Bedford\ Harbour";
$areanames{en}->{618982956} = "Bedford\ Harbour";
$areanames{en}->{618982957} = "Bedford\ Harbour";
$areanames{en}->{618982958} = "Bedford\ Harbour";
$areanames{en}->{61898296} = "Kuringup";
$areanames{en}->{618982970} = "Borden";
$areanames{en}->{618982973} = "Borden";
$areanames{en}->{618982976} = "Borden";
$areanames{en}->{618982977} = "Borden";
$areanames{en}->{618982978} = "Borden";
$areanames{en}->{618982980} = "Boscabel";
$areanames{en}->{618982983} = "Boscabel";
$areanames{en}->{618982986} = "Boscabel";
$areanames{en}->{618982987} = "Boscabel";
$areanames{en}->{618982988} = "Boscabel";
$areanames{en}->{618982990} = "Bremer\ Bay";
$areanames{en}->{618982991} = "Bremer\ Bay";
$areanames{en}->{618982992} = "Bremer\ Bay";
$areanames{en}->{618982993} = "Bremer\ Bay";
$areanames{en}->{618982994} = "Bremer\ Bay";
$areanames{en}->{618982995} = "Bremer\ Bay";
$areanames{en}->{618982996} = "Bremer\ Bay";
$areanames{en}->{618982997} = "Bremer\ Bay";
$areanames{en}->{618982998} = "Bremer\ Bay";
$areanames{en}->{61898300} = "Mettler";
$areanames{en}->{61898301} = "Mettler";
$areanames{en}->{61898302} = "Mettler";
$areanames{en}->{61898303} = "Moodiarrup";
$areanames{en}->{61898304} = "Moodiarrup";
$areanames{en}->{61898305} = "Moodiarrup";
$areanames{en}->{61898306} = "Moulyinning";
$areanames{en}->{61898307} = "Moulyinning";
$areanames{en}->{61898308} = "Moulyinning";
$areanames{en}->{61898309} = "Williams";
$areanames{en}->{61898310} = "Kojonup";
$areanames{en}->{61898311} = "Kojonup";
$areanames{en}->{61898312} = "Kojonup";
$areanames{en}->{61898313} = "Kojonup";
$areanames{en}->{61898314} = "Boscabel";
$areanames{en}->{61898315} = "Badgebup\ North";
$areanames{en}->{61898316} = "Badgebup\ North";
$areanames{en}->{61898317} = "Borden";
$areanames{en}->{61898318} = "Borden";
$areanames{en}->{61898319} = "Kojonup";
$areanames{en}->{61898320} = "Muradup";
$areanames{en}->{61898321} = "Muradup";
$areanames{en}->{61898322} = "Muradup";
$areanames{en}->{61898323} = "Muradup";
$areanames{en}->{61898324} = "Amelup";
$areanames{en}->{61898325} = "Amelup";
$areanames{en}->{61898326} = "Badgebup";
$areanames{en}->{61898327} = "Badgebup";
$areanames{en}->{61898328} = "Boscabel";
$areanames{en}->{61898329} = "Boscabel";
$areanames{en}->{61898330} = "Chittinup";
$areanames{en}->{61898331} = "Chittinup";
$areanames{en}->{61898332} = "Chittinup";
$areanames{en}->{618983330} = "Broomehill";
$areanames{en}->{618983333} = "Broomehill";
$areanames{en}->{618983336} = "Broomehill";
$areanames{en}->{618983337} = "Broomehill";
$areanames{en}->{618983338} = "Broomehill";
$areanames{en}->{618983340} = "Cairlocup";
$areanames{en}->{618983343} = "Cairlocup";
$areanames{en}->{618983346} = "Cairlocup";
$areanames{en}->{618983347} = "Cairlocup";
$areanames{en}->{618983348} = "Cairlocup";
$areanames{en}->{618983350} = "Chittinup";
$areanames{en}->{618983353} = "Chittinup";
$areanames{en}->{618983356} = "Chittinup";
$areanames{en}->{618983357} = "Chittinup";
$areanames{en}->{618983358} = "Chittinup";
$areanames{en}->{61898336} = "Jingalup";
$areanames{en}->{61898337} = "Jingalup";
$areanames{en}->{61898338} = "Jingalup";
$areanames{en}->{61898339} = "Jingalup";
$areanames{en}->{61898340} = "Lumeah";
$areanames{en}->{61898341} = "Lumeah";
$areanames{en}->{61898342} = "Lumeah";
$areanames{en}->{61898343} = "Lumeah";
$areanames{en}->{618983440} = "Congee";
$areanames{en}->{618983443} = "Congee";
$areanames{en}->{618983446} = "Congee";
$areanames{en}->{618983447} = "Congee";
$areanames{en}->{618983448} = "Congee";
$areanames{en}->{618983450} = "Corackerup";
$areanames{en}->{618983453} = "Corackerup";
$areanames{en}->{618983456} = "Corackerup";
$areanames{en}->{618983457} = "Corackerup";
$areanames{en}->{618983458} = "Corackerup";
$areanames{en}->{61898346} = "Lumeah";
$areanames{en}->{618983470} = "Fitzgerald";
$areanames{en}->{618983473} = "Fitzgerald";
$areanames{en}->{618983476} = "Fitzgerald";
$areanames{en}->{618983477} = "Fitzgerald";
$areanames{en}->{618983478} = "Fitzgerald";
$areanames{en}->{618983480} = "Gairdner";
$areanames{en}->{618983483} = "Gairdner";
$areanames{en}->{618983486} = "Gairdner";
$areanames{en}->{618983487} = "Gairdner";
$areanames{en}->{618983488} = "Gairdner";
$areanames{en}->{618983490} = "Gnowangerup";
$areanames{en}->{618983491} = "Gnowangerup";
$areanames{en}->{618983492} = "Gnowangerup";
$areanames{en}->{618983493} = "Gnowangerup";
$areanames{en}->{618983494} = "Gnowangerup";
$areanames{en}->{618983495} = "Gnowangerup";
$areanames{en}->{618983496} = "Gnowangerup";
$areanames{en}->{618983497} = "Gnowangerup";
$areanames{en}->{618983498} = "Gnowangerup";
$areanames{en}->{61898350} = "Jerramungup";
$areanames{en}->{61898351} = "Jerramungup";
$areanames{en}->{61898352} = "Jerramungup";
$areanames{en}->{61898353} = "Corackerup";
$areanames{en}->{61898354} = "Jacup";
$areanames{en}->{61898355} = "Jacup";
$areanames{en}->{61898356} = "Fitzgerald";
$areanames{en}->{61898357} = "West\ River";
$areanames{en}->{61898358} = "West\ River";
$areanames{en}->{61898359} = "West\ River";
$areanames{en}->{61898360} = "Gairdner";
$areanames{en}->{61898361} = "Gairdner";
$areanames{en}->{61898362} = "Gairdner";
$areanames{en}->{618983630} = "Hartville";
$areanames{en}->{618983633} = "Hartville";
$areanames{en}->{618983636} = "Hartville";
$areanames{en}->{618983637} = "Hartville";
$areanames{en}->{618983638} = "Hartville";
$areanames{en}->{618983640} = "Hopetoun";
$areanames{en}->{618983641} = "Hopetoun";
$areanames{en}->{618983642} = "Hopetoun";
$areanames{en}->{618983643} = "Hopetoun";
$areanames{en}->{618983644} = "Hopetoun";
$areanames{en}->{618983645} = "Hopetoun";
$areanames{en}->{618983646} = "Hopetoun";
$areanames{en}->{618983647} = "Hopetoun";
$areanames{en}->{618983650} = "Jacup";
$areanames{en}->{618983653} = "Jacup";
$areanames{en}->{618983656} = "Jacup";
$areanames{en}->{618983657} = "Jacup";
$areanames{en}->{618983658} = "Jacup";
$areanames{en}->{61898366} = "Gairdner";
$areanames{en}->{618983670} = "Jerdacuttup";
$areanames{en}->{618983673} = "Jerdacuttup";
$areanames{en}->{618983676} = "Jerdacuttup";
$areanames{en}->{618983677} = "Jerdacuttup";
$areanames{en}->{618983678} = "Jerdacuttup";
$areanames{en}->{618983680} = "Jerramungup";
$areanames{en}->{618983681} = "Jerramungup";
$areanames{en}->{618983682} = "Jerramungup";
$areanames{en}->{618983683} = "Jerramungup";
$areanames{en}->{618983684} = "Jerramungup";
$areanames{en}->{618983685} = "Jerramungup";
$areanames{en}->{618983686} = "Jerramungup";
$areanames{en}->{618983687} = "Jerramungup";
$areanames{en}->{618983688} = "Jerramungup";
$areanames{en}->{618983690} = "Jingalup";
$areanames{en}->{618983693} = "Jingalup";
$areanames{en}->{618983696} = "Jingalup";
$areanames{en}->{618983697} = "Jingalup";
$areanames{en}->{618983698} = "Jingalup";
$areanames{en}->{61898370} = "Bremer\ Bay";
$areanames{en}->{61898371} = "Bremer\ Bay";
$areanames{en}->{618983720} = "Katanning";
$areanames{en}->{618983721} = "Katanning";
$areanames{en}->{618983722} = "Katanning";
$areanames{en}->{618983723} = "Katanning";
$areanames{en}->{618983724} = "Katanning";
$areanames{en}->{618983725} = "Katanning";
$areanames{en}->{618983726} = "Katanning";
$areanames{en}->{618983728} = "Katanning";
$areanames{en}->{618983730} = "Kojonup";
$areanames{en}->{618983731} = "Kojonup";
$areanames{en}->{618983732} = "Kojonup";
$areanames{en}->{618983733} = "Kojonup";
$areanames{en}->{618983734} = "Kojonup";
$areanames{en}->{618983735} = "Kojonup";
$areanames{en}->{618983736} = "Kojonup";
$areanames{en}->{618983737} = "Kojonup";
$areanames{en}->{618983738} = "Kojonup";
$areanames{en}->{61898374} = "Bremer\ Bay";
$areanames{en}->{618983750} = "Kuringup";
$areanames{en}->{618983753} = "Kuringup";
$areanames{en}->{618983756} = "Kuringup";
$areanames{en}->{618983757} = "Kuringup";
$areanames{en}->{618983758} = "Kuringup";
$areanames{en}->{618983760} = "Lake\ Toolbrunup";
$areanames{en}->{618983763} = "Lake\ Toolbrunup";
$areanames{en}->{618983766} = "Lake\ Toolbrunup";
$areanames{en}->{618983767} = "Lake\ Toolbrunup";
$areanames{en}->{618983768} = "Lake\ Toolbrunup";
$areanames{en}->{618983770} = "Lumeah";
$areanames{en}->{618983773} = "Lumeah";
$areanames{en}->{618983776} = "Lumeah";
$areanames{en}->{618983777} = "Lumeah";
$areanames{en}->{618983778} = "Lumeah";
$areanames{en}->{618983780} = "Magitup";
$areanames{en}->{618983783} = "Magitup";
$areanames{en}->{618983786} = "Magitup";
$areanames{en}->{618983787} = "Magitup";
$areanames{en}->{618983788} = "Magitup";
$areanames{en}->{618983790} = "Mount\ Madden";
$areanames{en}->{618983793} = "Mount\ Madden";
$areanames{en}->{618983796} = "Mount\ Madden";
$areanames{en}->{618983797} = "Mount\ Madden";
$areanames{en}->{618983798} = "Mount\ Madden";
$areanames{en}->{61898380} = "Mount\ Madden";
$areanames{en}->{61898381} = "Ravensthorpe";
$areanames{en}->{61898382} = "Ravensthorpe";
$areanames{en}->{61898383} = "Hopetoun";
$areanames{en}->{61898384} = "Hopetoun";
$areanames{en}->{61898385} = "Jerdacuttup";
$areanames{en}->{61898386} = "Jerdacuttup";
$areanames{en}->{61898387} = "Mount\ Madden";
$areanames{en}->{61898388} = "Ravensthorpe\ West";
$areanames{en}->{61898389} = "Ravensthorpe\ West";
$areanames{en}->{61898390} = "Ravensthorpe";
$areanames{en}->{61898391} = "Corackerup";
$areanames{en}->{61898392} = "Corackerup";
$areanames{en}->{61898393} = "Gnowangerup";
$areanames{en}->{61898394} = "Gnowangerup";
$areanames{en}->{61898395} = "Hopetoun";
$areanames{en}->{61898396} = "Bedford\ Harbour";
$areanames{en}->{61898397} = "Bedford\ Harbour";
$areanames{en}->{61898398} = "Bedford\ Harbour";
$areanames{en}->{61898399} = "Bedford\ Harbour";
$areanames{en}->{61898400} = "Walpole";
$areanames{en}->{61898401} = "Walpole";
$areanames{en}->{61898402} = "Walpole";
$areanames{en}->{61898403} = "Congee";
$areanames{en}->{61898404} = "Congee";
$areanames{en}->{61898405} = "Albany";
$areanames{en}->{61898406} = "Bow\ Bridge";
$areanames{en}->{61898407} = "Bow\ Bridge";
$areanames{en}->{61898408} = "Bow\ Bridge";
$areanames{en}->{61898409} = "Bow\ Bridge";
$areanames{en}->{6189841} = "Albany";
$areanames{en}->{6189842} = "Albany";
$areanames{en}->{61898430} = "Albany";
$areanames{en}->{61898431} = "Narrakine";
$areanames{en}->{61898432} = "Narrogin";
$areanames{en}->{61898433} = "Nomans\ Lake";
$areanames{en}->{61898434} = "Pingelly";
$areanames{en}->{61898435} = "Pingelly\ East";
$areanames{en}->{61898436} = "Pumphreys";
$areanames{en}->{61898437} = "Quindanning";
$areanames{en}->{61898438} = "Tarwonga";
$areanames{en}->{61898439} = "Wickepin";
$areanames{en}->{6189844} = "Albany";
$areanames{en}->{61898450} = "Kronkup";
$areanames{en}->{61898451} = "Kronkup";
$areanames{en}->{61898452} = "Kronkup";
$areanames{en}->{61898453} = "Kronkup";
$areanames{en}->{61898454} = "Kronkup";
$areanames{en}->{61898455} = "Albany";
$areanames{en}->{61898456} = "Albany";
$areanames{en}->{61898457} = "Albany";
$areanames{en}->{61898458} = "Albany";
$areanames{en}->{61898459} = "Albany";
$areanames{en}->{61898460} = "Manypeaks";
$areanames{en}->{61898461} = "Manypeaks";
$areanames{en}->{61898462} = "Gairdner";
$areanames{en}->{61898463} = "Gairdner";
$areanames{en}->{61898464} = "Manypeaks";
$areanames{en}->{61898465} = "Kojaneerup";
$areanames{en}->{61898466} = "Kojaneerup";
$areanames{en}->{61898467} = "Manypeaks\ North";
$areanames{en}->{61898468} = "Manypeaks\ North";
$areanames{en}->{61898469} = "Manypeaks\ North";
$areanames{en}->{61898470} = "Gnowellen";
$areanames{en}->{61898471} = "Gnowellen";
$areanames{en}->{61898472} = "Gnowellen";
$areanames{en}->{61898473} = "Mettler";
$areanames{en}->{61898474} = "Albany";
$areanames{en}->{61898475} = "Broomehill";
$areanames{en}->{61898476} = "Broomehill";
$areanames{en}->{61898477} = "Kojaneerup";
$areanames{en}->{61898478} = "Chittinup";
$areanames{en}->{61898479} = "Chittinup";
$areanames{en}->{61898480} = "Denmark";
$areanames{en}->{61898481} = "Denmark";
$areanames{en}->{61898482} = "Denmark";
$areanames{en}->{61898483} = "Denmark";
$areanames{en}->{61898484} = "Denmark";
$areanames{en}->{61898485} = "Hartville";
$areanames{en}->{61898486} = "Hartville";
$areanames{en}->{61898487} = "Lake\ Toolbrunup";
$areanames{en}->{61898488} = "Lake\ Toolbrunup";
$areanames{en}->{61898489} = "Broomehill";
$areanames{en}->{61898490} = "Mount\ Barker";
$areanames{en}->{61898491} = "Mount\ Barker";
$areanames{en}->{61898492} = "Mount\ Barker";
$areanames{en}->{61898493} = "Mount\ Madden";
$areanames{en}->{61898494} = "Mount\ Madden";
$areanames{en}->{61898495} = "Mount\ Madden";
$areanames{en}->{61898496} = "Muradup";
$areanames{en}->{61898497} = "Muradup";
$areanames{en}->{61898498} = "Muradup";
$areanames{en}->{61898499} = "Cuballing";
$areanames{en}->{61898500} = "Nalyerlup";
$areanames{en}->{61898501} = "Nalyerlup";
$areanames{en}->{61898502} = "Nalyerlup";
$areanames{en}->{61898503} = "Narrakine";
$areanames{en}->{61898504} = "Narrakine";
$areanames{en}->{61898505} = "Narrakine";
$areanames{en}->{61898506} = "Narrogin";
$areanames{en}->{61898507} = "Narrogin";
$areanames{en}->{61898508} = "Narrogin";
$areanames{en}->{61898509} = "Bradfords";
$areanames{en}->{61898510} = "Mount\ Barker";
$areanames{en}->{61898511} = "Mount\ Barker";
$areanames{en}->{61898512} = "Mount\ Barker";
$areanames{en}->{61898513} = "Mount\ Barker";
$areanames{en}->{61898514} = "Mount\ Barker";
$areanames{en}->{61898515} = "Mount\ Barker";
$areanames{en}->{618985160} = "Muradup";
$areanames{en}->{618985163} = "Muradup";
$areanames{en}->{618985166} = "Muradup";
$areanames{en}->{618985167} = "Muradup";
$areanames{en}->{618985168} = "Muradup";
$areanames{en}->{61898517} = "Tenterden";
$areanames{en}->{618985180} = "Nalyerlup";
$areanames{en}->{618985183} = "Nalyerlup";
$areanames{en}->{618985186} = "Nalyerlup";
$areanames{en}->{618985187} = "Nalyerlup";
$areanames{en}->{618985188} = "Nalyerlup";
$areanames{en}->{618985190} = "Nyabing";
$areanames{en}->{618985191} = "Nyabing";
$areanames{en}->{618985192} = "Nyabing";
$areanames{en}->{618985193} = "Nyabing";
$areanames{en}->{618985196} = "Nyabing";
$areanames{en}->{618985197} = "Nyabing";
$areanames{en}->{618985198} = "Nyabing";
$areanames{en}->{61898520} = "Wagin";
$areanames{en}->{61898521} = "Narrogin";
$areanames{en}->{61898522} = "Katanning";
$areanames{en}->{61898523} = "Ravensthorpe";
$areanames{en}->{61898524} = "Tenterden";
$areanames{en}->{61898525} = "Magitup";
$areanames{en}->{61898526} = "Magitup";
$areanames{en}->{61898527} = "Muradup";
$areanames{en}->{61898528} = "Muradup";
$areanames{en}->{61898529} = "Hopetoun";
$areanames{en}->{61898530} = "Porongurup";
$areanames{en}->{61898531} = "Porongurup";
$areanames{en}->{61898532} = "Porongurup";
$areanames{en}->{61898533} = "Katanning";
$areanames{en}->{61898534} = "Katanning";
$areanames{en}->{61898535} = "Narrogin";
$areanames{en}->{61898536} = "Narrogin";
$areanames{en}->{61898537} = "Nomans\ Lake";
$areanames{en}->{61898538} = "Nomans\ Lake";
$areanames{en}->{61898539} = "Narrogin";
$areanames{en}->{61898540} = "Woogenilup";
$areanames{en}->{61898541} = "Woogenilup";
$areanames{en}->{61898542} = "Woogenilup";
$areanames{en}->{61898543} = "Woogenilup";
$areanames{en}->{618985440} = "Ongerup\ North";
$areanames{en}->{618985443} = "Ongerup\ North";
$areanames{en}->{618985446} = "Ongerup\ North";
$areanames{en}->{618985447} = "Ongerup\ North";
$areanames{en}->{618985448} = "Ongerup\ North";
$areanames{en}->{618985450} = "Pingrup";
$areanames{en}->{618985453} = "Pingrup";
$areanames{en}->{618985456} = "Pingrup";
$areanames{en}->{618985457} = "Pingrup";
$areanames{en}->{618985458} = "Pingrup";
$areanames{en}->{618985460} = "Pingrup\ East";
$areanames{en}->{618985463} = "Pingrup\ East";
$areanames{en}->{618985466} = "Pingrup\ East";
$areanames{en}->{618985467} = "Pingrup\ East";
$areanames{en}->{618985468} = "Pingrup\ East";
$areanames{en}->{618985470} = "Ravensthorpe";
$areanames{en}->{618985473} = "Ravensthorpe";
$areanames{en}->{618985474} = "Ravensthorpe";
$areanames{en}->{618985475} = "Ravensthorpe";
$areanames{en}->{618985476} = "Ravensthorpe";
$areanames{en}->{618985478} = "Ravensthorpe";
$areanames{en}->{618985480} = "Ravensthorpe\ West";
$areanames{en}->{618985481} = "Ravensthorpe";
$areanames{en}->{618985482} = "Ravensthorpe\ West";
$areanames{en}->{618985483} = "Ravensthorpe\ West";
$areanames{en}->{618985484} = "Ravensthorpe\ West";
$areanames{en}->{618985487} = "Ravensthorpe\ West";
$areanames{en}->{618985488} = "Ravensthorpe\ West";
$areanames{en}->{618985489} = "Ravensthorpe\ West";
$areanames{en}->{618985490} = "Tambellup";
$areanames{en}->{618985491} = "Tambellup";
$areanames{en}->{618985492} = "Tambellup";
$areanames{en}->{618985493} = "Tambellup";
$areanames{en}->{618985494} = "Tambellup";
$areanames{en}->{618985495} = "Tambellup";
$areanames{en}->{618985496} = "Tambellup";
$areanames{en}->{618985497} = "Tambellup";
$areanames{en}->{618985498} = "Tambellup";
$areanames{en}->{61898550} = "Rocky\ Gully";
$areanames{en}->{61898551} = "Rocky\ Gully";
$areanames{en}->{61898552} = "Rocky\ Gully";
$areanames{en}->{618985530} = "West\ River";
$areanames{en}->{618985533} = "West\ River";
$areanames{en}->{618985536} = "West\ River";
$areanames{en}->{618985537} = "West\ River";
$areanames{en}->{618985538} = "West\ River";
$areanames{en}->{618985540} = "Woodanilling";
$areanames{en}->{618985543} = "Woodanilling";
$areanames{en}->{618985546} = "Woodanilling";
$areanames{en}->{618985547} = "Woodanilling";
$areanames{en}->{618985548} = "Woodanilling";
$areanames{en}->{618985550} = "Dudinin";
$areanames{en}->{618985553} = "Dudinin";
$areanames{en}->{618985556} = "Dudinin";
$areanames{en}->{618985557} = "Dudinin";
$areanames{en}->{618985558} = "Dudinin";
$areanames{en}->{618985560} = "Harrismith";
$areanames{en}->{618985563} = "Harrismith";
$areanames{en}->{618985566} = "Harrismith";
$areanames{en}->{618985567} = "Harrismith";
$areanames{en}->{618985568} = "Harrismith";
$areanames{en}->{618985570} = "Hyden";
$areanames{en}->{618985571} = "Hyden";
$areanames{en}->{618985572} = "Hyden";
$areanames{en}->{618985573} = "Hyden";
$areanames{en}->{618985574} = "Hyden";
$areanames{en}->{618985575} = "Hyden";
$areanames{en}->{618985576} = "Hyden";
$areanames{en}->{618985577} = "Hyden";
$areanames{en}->{618985578} = "Hyden";
$areanames{en}->{618985580} = "Hyden\ East";
$areanames{en}->{618985583} = "Hyden\ East";
$areanames{en}->{618985586} = "Hyden\ East";
$areanames{en}->{618985587} = "Hyden\ East";
$areanames{en}->{618985588} = "Hyden\ East";
$areanames{en}->{618985590} = "Karlgarin";
$areanames{en}->{618985593} = "Karlgarin";
$areanames{en}->{618985596} = "Karlgarin";
$areanames{en}->{618985597} = "Karlgarin";
$areanames{en}->{618985598} = "Karlgarin";
$areanames{en}->{61898560} = "Perillup";
$areanames{en}->{61898561} = "Perillup";
$areanames{en}->{61898562} = "Kulin";
$areanames{en}->{61898563} = "Kulin";
$areanames{en}->{61898564} = "Kulin\ West";
$areanames{en}->{61898565} = "Kulin\ West";
$areanames{en}->{61898566} = "Bokerup";
$areanames{en}->{61898567} = "Bokerup";
$areanames{en}->{61898568} = "Nalyerlup";
$areanames{en}->{61898569} = "Nalyerlup";
$areanames{en}->{61898570} = "Unicup";
$areanames{en}->{61898571} = "Unicup";
$areanames{en}->{61898572} = "Walyurin";
$areanames{en}->{61898573} = "Walyurin";
$areanames{en}->{61898574} = "Wickepin\ East";
$areanames{en}->{61898575} = "Wickepin\ East";
$areanames{en}->{61898576} = "Denbarker";
$areanames{en}->{61898577} = "Denbarker";
$areanames{en}->{61898578} = "Nyabing";
$areanames{en}->{61898579} = "Nyabing";
$areanames{en}->{61898580} = "Newdegate";
$areanames{en}->{61898581} = "Newdegate";
$areanames{en}->{61898582} = "Newdegate";
$areanames{en}->{61898583} = "Newdegate\ East";
$areanames{en}->{61898584} = "Newdegate\ East";
$areanames{en}->{61898585} = "Newdegate\ East";
$areanames{en}->{61898586} = "Newdegate\ North";
$areanames{en}->{61898587} = "Newdegate\ North";
$areanames{en}->{61898588} = "Newdegate\ North";
$areanames{en}->{61898589} = "Albany";
$areanames{en}->{61898590} = "Nomans\ Lake";
$areanames{en}->{61898591} = "Nomans\ Lake";
$areanames{en}->{61898592} = "Nomans\ Lake";
$areanames{en}->{61898593} = "Nyabing";
$areanames{en}->{61898594} = "Nyabing";
$areanames{en}->{61898595} = "Nyabing";
$areanames{en}->{61898596} = "Ongerup\ North";
$areanames{en}->{61898597} = "Ongerup\ North";
$areanames{en}->{61898598} = "Ongerup\ North";
$areanames{en}->{61898599} = "Boddington";
$areanames{en}->{61898600} = "Perillup";
$areanames{en}->{61898601} = "Perillup";
$areanames{en}->{61898602} = "Perillup";
$areanames{en}->{61898603} = "Pingaring";
$areanames{en}->{61898604} = "Pingaring";
$areanames{en}->{61898605} = "Pingaring";
$areanames{en}->{61898606} = "Pingelly";
$areanames{en}->{61898607} = "Pingelly";
$areanames{en}->{61898608} = "Pingelly";
$areanames{en}->{61898609} = "Yealering";
$areanames{en}->{61898610} = "Wagin";
$areanames{en}->{61898611} = "Wagin";
$areanames{en}->{61898612} = "Wagin";
$areanames{en}->{61898613} = "Wagin";
$areanames{en}->{618986140} = "Kondinin";
$areanames{en}->{618986141} = "Kondinin";
$areanames{en}->{618986142} = "Kondinin";
$areanames{en}->{618986143} = "Kondinin";
$areanames{en}->{618986144} = "Kondinin";
$areanames{en}->{618986145} = "Kondinin";
$areanames{en}->{618986146} = "Kondinin";
$areanames{en}->{618986147} = "Kondinin";
$areanames{en}->{618986148} = "Kondinin";
$areanames{en}->{618986150} = "Kulin";
$areanames{en}->{618986151} = "Kulin";
$areanames{en}->{618986152} = "Kulin";
$areanames{en}->{618986153} = "Kulin";
$areanames{en}->{618986154} = "Kulin";
$areanames{en}->{618986155} = "Kulin";
$areanames{en}->{618986156} = "Kulin";
$areanames{en}->{618986157} = "Kulin";
$areanames{en}->{618986158} = "Kulin";
$areanames{en}->{61898616} = "Jaloran";
$areanames{en}->{61898617} = "Jaloran";
$areanames{en}->{61898618} = "Jaloran";
$areanames{en}->{61898619} = "Wagin";
$areanames{en}->{61898620} = "Arthur\ River";
$areanames{en}->{61898621} = "Arthur\ River";
$areanames{en}->{61898622} = "Arthur\ River";
$areanames{en}->{61898623} = "Beaufort\ River";
$areanames{en}->{61898624} = "Beaufort\ River";
$areanames{en}->{61898625} = "Beaufort\ River";
$areanames{en}->{61898626} = "Arthur\ River";
$areanames{en}->{61898627} = "Ongerup\ North";
$areanames{en}->{61898628} = "Ongerup\ North";
$areanames{en}->{61898629} = "Moodiarrup";
$areanames{en}->{61898630} = "Moodiarrup";
$areanames{en}->{61898631} = "Moodiarrup";
$areanames{en}->{61898632} = "Dumbleyung";
$areanames{en}->{61898633} = "Dumbleyung";
$areanames{en}->{61898634} = "Dumbleyung";
$areanames{en}->{61898635} = "Dumbleyung";
$areanames{en}->{61898636} = "Dongolocking";
$areanames{en}->{61898637} = "Dongolocking";
$areanames{en}->{61898638} = "Tambellup";
$areanames{en}->{61898639} = "Tambellup";
$areanames{en}->{61898640} = "Moulyinning";
$areanames{en}->{61898641} = "Moulyinning";
$areanames{en}->{61898642} = "Moulyinning";
$areanames{en}->{61898643} = "Kukerin";
$areanames{en}->{61898644} = "Woodanilling";
$areanames{en}->{61898645} = "Woodanilling";
$areanames{en}->{61898646} = "Kukerin";
$areanames{en}->{61898647} = "Kukerin";
$areanames{en}->{61898648} = "Tarin\ Rock";
$areanames{en}->{61898649} = "Tarin\ Rock";
$areanames{en}->{61898650} = "Lake\ Grace";
$areanames{en}->{61898651} = "Lake\ Grace";
$areanames{en}->{61898652} = "Lake\ Grace";
$areanames{en}->{61898653} = "Lake\ Grace";
$areanames{en}->{61898654} = "Lake\ Grace";
$areanames{en}->{61898655} = "Pingelly";
$areanames{en}->{61898656} = "Pingelly";
$areanames{en}->{61898657} = "Pingelly\ East";
$areanames{en}->{61898658} = "Pingelly\ East";
$areanames{en}->{61898659} = "Williams";
$areanames{en}->{61898660} = "Williams";
$areanames{en}->{61898661} = "Arthur\ River";
$areanames{en}->{61898662} = "Arthur\ River";
$areanames{en}->{61898663} = "Beaufort\ River";
$areanames{en}->{61898664} = "Beaufort\ River";
$areanames{en}->{61898665} = "Wagin";
$areanames{en}->{61898666} = "Wagin";
$areanames{en}->{61898667} = "Albany";
$areanames{en}->{61898668} = "Pingaring";
$areanames{en}->{61898669} = "Pingaring";
$areanames{en}->{61898670} = "Pingelly\ East";
$areanames{en}->{61898671} = "Pingelly\ East";
$areanames{en}->{61898672} = "Pingelly\ East";
$areanames{en}->{61898673} = "Pingrup";
$areanames{en}->{61898674} = "Pingrup";
$areanames{en}->{61898675} = "Pingrup";
$areanames{en}->{61898676} = "Pingrup\ East";
$areanames{en}->{61898677} = "Pingrup\ East";
$areanames{en}->{61898678} = "Pingrup\ East";
$areanames{en}->{61898679} = "Hopetoun";
$areanames{en}->{61898680} = "Porongurup";
$areanames{en}->{61898681} = "Porongurup";
$areanames{en}->{61898682} = "Porongurup";
$areanames{en}->{61898683} = "Pumphreys";
$areanames{en}->{61898684} = "Pumphreys";
$areanames{en}->{61898685} = "Pumphreys";
$areanames{en}->{61898686} = "Quindanning";
$areanames{en}->{61898687} = "Quindanning";
$areanames{en}->{61898688} = "Quindanning";
$areanames{en}->{61898689} = "Wickepin\ East";
$areanames{en}->{61898690} = "Ravensthorpe";
$areanames{en}->{61898691} = "Ravensthorpe";
$areanames{en}->{61898692} = "Ravensthorpe";
$areanames{en}->{61898693} = "Ravensthorpe\ West";
$areanames{en}->{61898694} = "Ravensthorpe\ West";
$areanames{en}->{61898695} = "Ravensthorpe\ West";
$areanames{en}->{61898696} = "Rocky\ Gully";
$areanames{en}->{61898697} = "Rocky\ Gully";
$areanames{en}->{61898698} = "Rocky\ Gully";
$areanames{en}->{61898699} = "Walyurin";
$areanames{en}->{61898700} = "Tambellup";
$areanames{en}->{61898701} = "Tambellup";
$areanames{en}->{61898702} = "Tambellup";
$areanames{en}->{61898703} = "Tarin\ Rock";
$areanames{en}->{61898704} = "Tarin\ Rock";
$areanames{en}->{61898705} = "Tarin\ Rock";
$areanames{en}->{61898706} = "Tarwonga";
$areanames{en}->{61898707} = "Tarwonga";
$areanames{en}->{61898708} = "Tarwonga";
$areanames{en}->{61898709} = "Lake\ Oconnor";
$areanames{en}->{61898710} = "Newdegate";
$areanames{en}->{61898711} = "Newdegate";
$areanames{en}->{61898712} = "Newdegate";
$areanames{en}->{61898713} = "Newdegate";
$areanames{en}->{61898714} = "Lake\ Magenta";
$areanames{en}->{61898715} = "Lake\ Magenta";
$areanames{en}->{61898716} = "Newdegate\ North";
$areanames{en}->{61898717} = "Newdegate\ North";
$areanames{en}->{61898718} = "Holland\ Rocks";
$areanames{en}->{61898719} = "Holland\ Rocks";
$areanames{en}->{61898720} = "Lake\ Magenta";
$areanames{en}->{61898721} = "Boddington";
$areanames{en}->{61898722} = "Boddington";
$areanames{en}->{61898723} = "Bradfords";
$areanames{en}->{61898724} = "Bradfords";
$areanames{en}->{61898725} = "Cuballing";
$areanames{en}->{61898726} = "Cuballing";
$areanames{en}->{61898727} = "Narrakine";
$areanames{en}->{61898728} = "Narrakine";
$areanames{en}->{61898729} = "Denmark";
$areanames{en}->{61898730} = "Tenterden";
$areanames{en}->{61898731} = "Tenterden";
$areanames{en}->{61898732} = "Tenterden";
$areanames{en}->{61898733} = "Unicup";
$areanames{en}->{61898734} = "Unicup";
$areanames{en}->{61898735} = "Unicup";
$areanames{en}->{61898736} = "Varley";
$areanames{en}->{61898737} = "Varley";
$areanames{en}->{61898738} = "Varley";
$areanames{en}->{61898739} = "Kulin\ West";
$areanames{en}->{61898740} = "Dudinin";
$areanames{en}->{61898741} = "Dudinin";
$areanames{en}->{61898742} = "Harrismith";
$areanames{en}->{61898743} = "Harrismith";
$areanames{en}->{61898744} = "Lake\ King";
$areanames{en}->{61898745} = "Lake\ King";
$areanames{en}->{61898746} = "Lake\ King";
$areanames{en}->{61898747} = "Newdegate\ East";
$areanames{en}->{61898748} = "Yealering";
$areanames{en}->{61898749} = "Yealering";
$areanames{en}->{61898750} = "Varley";
$areanames{en}->{61898751} = "Varley";
$areanames{en}->{61898752} = "Varley";
$areanames{en}->{61898753} = "Pumphreys";
$areanames{en}->{61898754} = "Pumphreys";
$areanames{en}->{61898755} = "Quindanning";
$areanames{en}->{61898756} = "Quindanning";
$areanames{en}->{61898757} = "Tarwonga";
$areanames{en}->{61898758} = "Tarwonga";
$areanames{en}->{61898759} = "Pingelly";
$areanames{en}->{61898760} = "Wagin";
$areanames{en}->{61898761} = "Wagin";
$areanames{en}->{61898762} = "Wagin";
$areanames{en}->{61898763} = "Walpole";
$areanames{en}->{61898764} = "Walpole";
$areanames{en}->{61898765} = "Walpole";
$areanames{en}->{61898766} = "Walyurin";
$areanames{en}->{61898767} = "Walyurin";
$areanames{en}->{61898768} = "Walyurin";
$areanames{en}->{61898769} = "Kulin";
$areanames{en}->{61898770} = "West\ River";
$areanames{en}->{61898771} = "West\ River";
$areanames{en}->{61898772} = "West\ River";
$areanames{en}->{61898773} = "Wickepin";
$areanames{en}->{61898774} = "Wickepin";
$areanames{en}->{61898775} = "Wickepin";
$areanames{en}->{61898776} = "Wickepin\ East";
$areanames{en}->{61898777} = "Wickepin\ East";
$areanames{en}->{61898778} = "Wickepin\ East";
$areanames{en}->{61898779} = "Kondinin";
$areanames{en}->{61898780} = "Williams";
$areanames{en}->{61898781} = "Williams";
$areanames{en}->{61898782} = "Williams";
$areanames{en}->{61898783} = "Woodanilling";
$areanames{en}->{61898784} = "Woodanilling";
$areanames{en}->{61898785} = "Woodanilling";
$areanames{en}->{61898786} = "Woogenilup";
$areanames{en}->{61898787} = "Woogenilup";
$areanames{en}->{61898788} = "Woogenilup";
$areanames{en}->{61898789} = "Karlgarin";
$areanames{en}->{61898790} = "Yealering";
$areanames{en}->{61898791} = "Yealering";
$areanames{en}->{61898792} = "Yealering";
$areanames{en}->{61898793} = "Tambellup";
$areanames{en}->{61898794} = "West\ River";
$areanames{en}->{61898795} = "Woodanilling";
$areanames{en}->{61898796} = "Dudinin";
$areanames{en}->{61898797} = "Harrismith";
$areanames{en}->{61898798} = "Hyden";
$areanames{en}->{61898799} = "Hyden\ East";
$areanames{en}->{61898800} = "Lake\ Oconnor";
$areanames{en}->{61898801} = "Kulin";
$areanames{en}->{61898802} = "Kulin";
$areanames{en}->{61898803} = "Kulin";
$areanames{en}->{61898804} = "Kulin";
$areanames{en}->{61898805} = "Hyden";
$areanames{en}->{61898806} = "Hyden";
$areanames{en}->{61898807} = "Hyden\ East";
$areanames{en}->{61898808} = "Hyden\ East";
$areanames{en}->{61898809} = "Kulin\ West";
$areanames{en}->{6189881} = "Narrogin";
$areanames{en}->{61898817} = "Karlgarin";
$areanames{en}->{61898818} = "Karlgarin";
$areanames{en}->{61898820} = "Narrogin";
$areanames{en}->{61898821} = "Narrogin";
$areanames{en}->{61898822} = "Narrogin";
$areanames{en}->{61898823} = "Nomans\ Lake";
$areanames{en}->{61898824} = "Nomans\ Lake";
$areanames{en}->{61898825} = "Nomans\ Lake";
$areanames{en}->{61898826} = "Nomans\ Lake";
$areanames{en}->{61898827} = "Nomans\ Lake";
$areanames{en}->{61898828} = "Kondinin";
$areanames{en}->{61898829} = "Kondinin";
$areanames{en}->{61898830} = "Harrismith";
$areanames{en}->{61898831} = "Harrismith";
$areanames{en}->{61898832} = "Harrismith";
$areanames{en}->{61898833} = "Boddington";
$areanames{en}->{61898834} = "Boddington";
$areanames{en}->{61898835} = "Cuballing";
$areanames{en}->{61898836} = "Cuballing";
$areanames{en}->{61898837} = "Cuballing";
$areanames{en}->{61898838} = "Boddington";
$areanames{en}->{61898839} = "Boddington";
$areanames{en}->{61898840} = "Boddington";
$areanames{en}->{61898841} = "Boddington";
$areanames{en}->{61898842} = "Boddington";
$areanames{en}->{61898843} = "Boddington";
$areanames{en}->{61898844} = "Mount\ Barker";
$areanames{en}->{61898845} = "Bradfords";
$areanames{en}->{61898846} = "Dongolocking";
$areanames{en}->{61898847} = "Dongolocking";
$areanames{en}->{61898848} = "Dumbleyung";
$areanames{en}->{61898849} = "Dumbleyung";
$areanames{en}->{61898850} = "Williams";
$areanames{en}->{61898851} = "Williams";
$areanames{en}->{61898852} = "Williams";
$areanames{en}->{61898853} = "Tarwonga";
$areanames{en}->{61898854} = "Quindanning";
$areanames{en}->{61898855} = "Narrakine";
$areanames{en}->{61898856} = "Narrakine";
$areanames{en}->{61898857} = "Quindanning";
$areanames{en}->{61898858} = "Tarwonga";
$areanames{en}->{61898859} = "Narrogin";
$areanames{en}->{61898860} = "Magitup";
$areanames{en}->{61898861} = "Mount\ Madden";
$areanames{en}->{61898862} = "Muradup";
$areanames{en}->{61898863} = "Nalyerlup";
$areanames{en}->{61898864} = "Nyabing";
$areanames{en}->{61898865} = "Ongerup\ North";
$areanames{en}->{61898866} = "Pingrup";
$areanames{en}->{61898867} = "Pingrup\ East";
$areanames{en}->{61898868} = "Ravensthorpe";
$areanames{en}->{61898869} = "Ravensthorpe\ West";
$areanames{en}->{61898870} = "Pingelly";
$areanames{en}->{61898871} = "Pingelly";
$areanames{en}->{61898872} = "Pingelly";
$areanames{en}->{61898873} = "Wickepin";
$areanames{en}->{61898874} = "Wickepin";
$areanames{en}->{61898875} = "Cuballing";
$areanames{en}->{61898876} = "Pumphreys";
$areanames{en}->{61898877} = "Pumphreys";
$areanames{en}->{61898878} = "Pumphreys";
$areanames{en}->{61898879} = "Pingelly\ East";
$areanames{en}->{61898880} = "Wickepin";
$areanames{en}->{61898881} = "Wickepin";
$areanames{en}->{61898882} = "Wickepin";
$areanames{en}->{61898883} = "Wickepin";
$areanames{en}->{61898884} = "Wickepin";
$areanames{en}->{61898885} = "Wickepin\ East";
$areanames{en}->{61898886} = "Wickepin\ East";
$areanames{en}->{61898887} = "Yealering";
$areanames{en}->{61898888} = "Wickepin\ East";
$areanames{en}->{61898889} = "Yealering";
$areanames{en}->{61898890} = "Dudinin";
$areanames{en}->{61898891} = "Kondinin";
$areanames{en}->{61898892} = "Amelup";
$areanames{en}->{61898893} = "Kondinin";
$areanames{en}->{61898894} = "Karlgarin";
$areanames{en}->{61898895} = "Karlgarin";
$areanames{en}->{61898896} = "Karlgarin";
$areanames{en}->{61898897} = "Walyurin";
$areanames{en}->{61898898} = "Walyurin";
$areanames{en}->{61898899} = "Walyurin";
$areanames{en}->{61898900} = "Narrogin";
$areanames{en}->{61898901} = "Lake\ Grace";
$areanames{en}->{61898902} = "Lake\ Grace";
$areanames{en}->{618989030} = "Kulin\ West";
$areanames{en}->{618989033} = "Kulin\ West";
$areanames{en}->{618989036} = "Kulin\ West";
$areanames{en}->{618989037} = "Kulin\ West";
$areanames{en}->{618989038} = "Kulin\ West";
$areanames{en}->{618989040} = "Lake\ Oconnor";
$areanames{en}->{618989043} = "Lake\ Oconnor";
$areanames{en}->{618989046} = "Lake\ Oconnor";
$areanames{en}->{618989047} = "Lake\ Oconnor";
$areanames{en}->{618989048} = "Lake\ Oconnor";
$areanames{en}->{618989050} = "Walyurin";
$areanames{en}->{618989053} = "Walyurin";
$areanames{en}->{618989056} = "Walyurin";
$areanames{en}->{618989057} = "Walyurin";
$areanames{en}->{618989058} = "Walyurin";
$areanames{en}->{618989060} = "Wickepin\ East";
$areanames{en}->{618989063} = "Wickepin\ East";
$areanames{en}->{618989066} = "Wickepin\ East";
$areanames{en}->{618989067} = "Wickepin\ East";
$areanames{en}->{618989068} = "Wickepin\ East";
$areanames{en}->{618989070} = "Yealering";
$areanames{en}->{618989073} = "Yealering";
$areanames{en}->{618989076} = "Yealering";
$areanames{en}->{618989077} = "Yealering";
$areanames{en}->{618989078} = "Yealering";
$areanames{en}->{61898908} = "Boddington";
$areanames{en}->{618989090} = "Bradfords";
$areanames{en}->{618989093} = "Bradfords";
$areanames{en}->{618989096} = "Bradfords";
$areanames{en}->{618989097} = "Bradfords";
$areanames{en}->{618989098} = "Bradfords";
$areanames{en}->{61898910} = "Katanning";
$areanames{en}->{61898911} = "Katanning";
$areanames{en}->{618989120} = "Cuballing";
$areanames{en}->{618989121} = "Cuballing";
$areanames{en}->{618989122} = "Cuballing";
$areanames{en}->{618989123} = "Cuballing";
$areanames{en}->{618989124} = "Cuballing";
$areanames{en}->{618989125} = "Cuballing";
$areanames{en}->{618989126} = "Cuballing";
$areanames{en}->{618989127} = "Cuballing";
$areanames{en}->{618989128} = "Cuballing";
$areanames{en}->{618989130} = "Narrakine";
$areanames{en}->{618989133} = "Narrakine";
$areanames{en}->{618989136} = "Narrakine";
$areanames{en}->{618989137} = "Narrakine";
$areanames{en}->{618989138} = "Narrakine";
$areanames{en}->{618989140} = "Narrogin";
$areanames{en}->{618989141} = "Narrogin";
$areanames{en}->{618989142} = "Narrogin";
$areanames{en}->{618989143} = "Narrogin";
$areanames{en}->{618989144} = "Narrogin";
$areanames{en}->{618989145} = "Narrogin";
$areanames{en}->{618989146} = "Narrogin";
$areanames{en}->{618989147} = "Narrogin";
$areanames{en}->{618989148} = "Narrogin";
$areanames{en}->{618989150} = "Nomans\ Lake";
$areanames{en}->{618989151} = "Nomans\ Lake";
$areanames{en}->{618989152} = "Nomans\ Lake";
$areanames{en}->{618989153} = "Nomans\ Lake";
$areanames{en}->{618989156} = "Nomans\ Lake";
$areanames{en}->{618989157} = "Nomans\ Lake";
$areanames{en}->{618989158} = "Nomans\ Lake";
$areanames{en}->{618989159} = "Nomans\ Lake";
$areanames{en}->{618989160} = "Pingelly";
$areanames{en}->{618989161} = "Pingelly";
$areanames{en}->{618989162} = "Pingelly";
$areanames{en}->{618989163} = "Pingelly";
$areanames{en}->{618989164} = "Pingelly";
$areanames{en}->{618989165} = "Pingelly";
$areanames{en}->{618989166} = "Pingelly";
$areanames{en}->{618989167} = "Pingelly";
$areanames{en}->{618989168} = "Pingelly";
$areanames{en}->{618989170} = "Pingelly\ East";
$areanames{en}->{618989173} = "Pingelly\ East";
$areanames{en}->{618989176} = "Pingelly\ East";
$areanames{en}->{618989177} = "Pingelly\ East";
$areanames{en}->{618989178} = "Pingelly\ East";
$areanames{en}->{618989180} = "Pumphreys";
$areanames{en}->{618989183} = "Pumphreys";
$areanames{en}->{618989186} = "Pumphreys";
$areanames{en}->{618989187} = "Pumphreys";
$areanames{en}->{618989188} = "Pumphreys";
$areanames{en}->{618989190} = "Quindanning";
$areanames{en}->{618989193} = "Quindanning";
$areanames{en}->{618989196} = "Quindanning";
$areanames{en}->{618989197} = "Quindanning";
$areanames{en}->{618989198} = "Quindanning";
$areanames{en}->{6189892} = "Albany";
$areanames{en}->{61898921} = "Mount\ Barker";
$areanames{en}->{61898923} = "Denmark";
$areanames{en}->{61898924} = "Porongurup";
$areanames{en}->{61898930} = "Wagin";
$areanames{en}->{618989310} = "Tarwonga";
$areanames{en}->{618989313} = "Tarwonga";
$areanames{en}->{618989316} = "Tarwonga";
$areanames{en}->{618989317} = "Tarwonga";
$areanames{en}->{618989318} = "Tarwonga";
$areanames{en}->{618989320} = "Wickepin";
$areanames{en}->{618989321} = "Wickepin";
$areanames{en}->{618989322} = "Wickepin";
$areanames{en}->{618989323} = "Wickepin";
$areanames{en}->{618989324} = "Wickepin";
$areanames{en}->{618989325} = "Wickepin";
$areanames{en}->{618989326} = "Wickepin";
$areanames{en}->{618989327} = "Wickepin";
$areanames{en}->{618989328} = "Wickepin";
$areanames{en}->{618989330} = "Williams";
$areanames{en}->{618989331} = "Williams";
$areanames{en}->{618989332} = "Williams";
$areanames{en}->{618989333} = "Williams";
$areanames{en}->{618989334} = "Williams";
$areanames{en}->{618989335} = "Williams";
$areanames{en}->{618989336} = "Williams";
$areanames{en}->{618989337} = "Williams";
$areanames{en}->{618989338} = "Williams";
$areanames{en}->{618989340} = "Arthur\ River";
$areanames{en}->{618989343} = "Arthur\ River";
$areanames{en}->{618989346} = "Arthur\ River";
$areanames{en}->{618989347} = "Arthur\ River";
$areanames{en}->{618989348} = "Arthur\ River";
$areanames{en}->{618989350} = "Beaufort\ River";
$areanames{en}->{618989353} = "Beaufort\ River";
$areanames{en}->{618989356} = "Beaufort\ River";
$areanames{en}->{618989357} = "Beaufort\ River";
$areanames{en}->{618989358} = "Beaufort\ River";
$areanames{en}->{618989360} = "Dongolocking";
$areanames{en}->{618989363} = "Dongolocking";
$areanames{en}->{618989366} = "Dongolocking";
$areanames{en}->{618989367} = "Dongolocking";
$areanames{en}->{618989368} = "Dongolocking";
$areanames{en}->{618989370} = "Dumbleyung";
$areanames{en}->{618989371} = "Dumbleyung";
$areanames{en}->{618989372} = "Dumbleyung";
$areanames{en}->{618989373} = "Dumbleyung";
$areanames{en}->{618989374} = "Dumbleyung";
$areanames{en}->{618989375} = "Dumbleyung";
$areanames{en}->{618989376} = "Dumbleyung";
$areanames{en}->{618989377} = "Dumbleyung";
$areanames{en}->{618989378} = "Dumbleyung";
$areanames{en}->{618989380} = "Holland\ Rocks";
$areanames{en}->{618989383} = "Holland\ Rocks";
$areanames{en}->{618989386} = "Holland\ Rocks";
$areanames{en}->{618989387} = "Holland\ Rocks";
$areanames{en}->{618989388} = "Holland\ Rocks";
$areanames{en}->{618989390} = "Jaloran";
$areanames{en}->{618989393} = "Jaloran";
$areanames{en}->{618989396} = "Jaloran";
$areanames{en}->{618989397} = "Jaloran";
$areanames{en}->{618989398} = "Jaloran";
$areanames{en}->{61898940} = "Kondinin";
$areanames{en}->{61898941} = "Kondinin";
$areanames{en}->{61898942} = "Mount\ Barker";
$areanames{en}->{61898943} = "Mount\ Barker";
$areanames{en}->{61898944} = "Porongurup";
$areanames{en}->{61898945} = "Porongurup";
$areanames{en}->{61898946} = "Boscabel";
$areanames{en}->{61898947} = "Boscabel";
$areanames{en}->{61898948} = "Cranbrook";
$areanames{en}->{61898949} = "Cranbrook";
$areanames{en}->{61898950} = "Hopetoun";
$areanames{en}->{61898951} = "Jacup";
$areanames{en}->{61898952} = "Jerdacuttup";
$areanames{en}->{61898953} = "Jerramungup";
$areanames{en}->{61898954} = "Jingalup";
$areanames{en}->{61898955} = "Katanning";
$areanames{en}->{61898956} = "Kojonup";
$areanames{en}->{61898957} = "Kuringup";
$areanames{en}->{61898958} = "Lake\ Toolbrunup";
$areanames{en}->{61898959} = "Lumeah";
$areanames{en}->{61898960} = "Broomehill";
$areanames{en}->{61898961} = "Cairlocup";
$areanames{en}->{61898962} = "Chittinup";
$areanames{en}->{61898963} = "Congee";
$areanames{en}->{61898964} = "Corackerup";
$areanames{en}->{61898965} = "Cranbrook";
$areanames{en}->{61898966} = "Fitzgerald";
$areanames{en}->{61898967} = "Gairdner";
$areanames{en}->{61898968} = "Gnowangerup";
$areanames{en}->{61898969} = "Hartville";
$areanames{en}->{61898970} = "Unicup";
$areanames{en}->{61898971} = "Walpole";
$areanames{en}->{61898972} = "Woogenilup";
$areanames{en}->{61898973} = "Amelup";
$areanames{en}->{61898974} = "Badgebup";
$areanames{en}->{61898975} = "Badgebup\ North";
$areanames{en}->{61898976} = "Bedford\ Harbour";
$areanames{en}->{61898977} = "Borden";
$areanames{en}->{61898978} = "Boscabel";
$areanames{en}->{61898979} = "Bremer\ Bay";
$areanames{en}->{61898980} = "Katanning";
$areanames{en}->{61898981} = "Katanning";
$areanames{en}->{61898982} = "Katanning";
$areanames{en}->{61898983} = "Katanning";
$areanames{en}->{61898984} = "Mettler";
$areanames{en}->{61898985} = "Mount\ Barker";
$areanames{en}->{61898986} = "Perillup";
$areanames{en}->{61898987} = "Porongurup";
$areanames{en}->{61898988} = "Rocky\ Gully";
$areanames{en}->{61898989} = "Tenterden";
$areanames{en}->{61898990} = "Albany";
$areanames{en}->{61898991} = "Bokerup";
$areanames{en}->{61898992} = "Bow\ Bridge";
$areanames{en}->{61898993} = "Denbarker";
$areanames{en}->{61898994} = "Denmark";
$areanames{en}->{61898995} = "Gnowellen";
$areanames{en}->{61898996} = "Kojaneerup";
$areanames{en}->{61898997} = "Kronkup";
$areanames{en}->{61898998} = "Manypeaks";
$areanames{en}->{61898999} = "Manypeaks\ North";
$areanames{en}->{61899000} = "Ajana";
$areanames{en}->{61899001} = "Ajana";
$areanames{en}->{61899002} = "Ajana";
$areanames{en}->{61899003} = "Balla";
$areanames{en}->{61899004} = "Balla";
$areanames{en}->{61899005} = "Balla";
$areanames{en}->{61899006} = "Carnamah";
$areanames{en}->{61899007} = "Carnamah";
$areanames{en}->{61899008} = "Carnamah";
$areanames{en}->{61899009} = "Arrowsmith";
$areanames{en}->{618990098} = "Ajana";
$areanames{en}->{618990099} = "Geraldton";
$areanames{en}->{61899010} = "Carnamah\ West";
$areanames{en}->{61899011} = "Carnamah\ West";
$areanames{en}->{61899012} = "Carnamah\ West";
$areanames{en}->{61899013} = "Carnarvon";
$areanames{en}->{61899014} = "Carnarvon";
$areanames{en}->{61899015} = "Carnarvon";
$areanames{en}->{61899016} = "Coorow";
$areanames{en}->{61899017} = "Coorow";
$areanames{en}->{61899018} = "Coorow";
$areanames{en}->{61899019} = "Arrowsmith";
$areanames{en}->{61899020} = "Coorow\ West";
$areanames{en}->{61899021} = "Coorow\ West";
$areanames{en}->{61899022} = "Coorow\ West";
$areanames{en}->{61899023} = "Cue";
$areanames{en}->{61899024} = "Cue";
$areanames{en}->{61899025} = "Cue";
$areanames{en}->{61899026} = "Denham";
$areanames{en}->{61899027} = "Denham";
$areanames{en}->{61899028} = "Denham";
$areanames{en}->{61899029} = "Eneabba\ South";
$areanames{en}->{61899030} = "Dongara";
$areanames{en}->{61899031} = "Dongara";
$areanames{en}->{61899032} = "Dongara";
$areanames{en}->{61899033} = "Eneabba";
$areanames{en}->{61899034} = "Eneabba";
$areanames{en}->{61899035} = "Eneabba";
$areanames{en}->{61899036} = "Eneabba\ North";
$areanames{en}->{61899037} = "Eneabba\ North";
$areanames{en}->{61899038} = "Eneabba\ North";
$areanames{en}->{61899039} = "Leeman";
$areanames{en}->{61899040} = "Eneabba\ South";
$areanames{en}->{61899041} = "Eneabba\ South";
$areanames{en}->{61899042} = "Eneabba\ South";
$areanames{en}->{61899043} = "Exmouth";
$areanames{en}->{61899044} = "Exmouth";
$areanames{en}->{61899045} = "Exmouth";
$areanames{en}->{61899046} = "Geraldton";
$areanames{en}->{61899047} = "Geraldton";
$areanames{en}->{61899048} = "Geraldton";
$areanames{en}->{61899049} = "Geraldton";
$areanames{en}->{61899050} = "Guranu";
$areanames{en}->{61899051} = "Guranu";
$areanames{en}->{61899052} = "Guranu";
$areanames{en}->{61899053} = "Gutha\ West";
$areanames{en}->{61899054} = "Gutha\ West";
$areanames{en}->{61899055} = "Gutha\ West";
$areanames{en}->{61899056} = "Howatharra";
$areanames{en}->{61899057} = "Howatharra";
$areanames{en}->{61899058} = "Howatharra";
$areanames{en}->{61899059} = "Marchagee";
$areanames{en}->{61899060} = "Kalbarri";
$areanames{en}->{61899061} = "Kalbarri";
$areanames{en}->{61899062} = "Kalbarri";
$areanames{en}->{61899063} = "Lake\ Mason";
$areanames{en}->{61899064} = "Lake\ Mason";
$areanames{en}->{61899065} = "Lake\ Mason";
$areanames{en}->{61899066} = "Latham";
$areanames{en}->{61899067} = "Latham";
$areanames{en}->{61899068} = "Latham";
$areanames{en}->{61899069} = "Three\ Springs";
$areanames{en}->{61899070} = "Leeman";
$areanames{en}->{61899071} = "Leeman";
$areanames{en}->{61899072} = "Leeman";
$areanames{en}->{61899073} = "Lynton";
$areanames{en}->{61899074} = "Lynton";
$areanames{en}->{61899075} = "Lynton";
$areanames{en}->{61899076} = "Marchagee";
$areanames{en}->{61899077} = "Marchagee";
$areanames{en}->{61899078} = "Marchagee";
$areanames{en}->{61899079} = "Warradarge";
$areanames{en}->{61899080} = "Meekatharra";
$areanames{en}->{61899081} = "Meekatharra";
$areanames{en}->{61899082} = "Meekatharra";
$areanames{en}->{61899083} = "Mendel";
$areanames{en}->{61899084} = "Mendel";
$areanames{en}->{61899085} = "Mendel";
$areanames{en}->{61899086} = "Mingenew";
$areanames{en}->{61899087} = "Mingenew";
$areanames{en}->{61899088} = "Mingenew";
$areanames{en}->{61899089} = "Carnamah";
$areanames{en}->{61899090} = "Morawa";
$areanames{en}->{61899091} = "Morawa";
$areanames{en}->{61899092} = "Morawa";
$areanames{en}->{61899093} = "Mount\ George";
$areanames{en}->{61899094} = "Mount\ George";
$areanames{en}->{61899095} = "Mount\ George";
$areanames{en}->{61899096} = "Mount\ Magnet";
$areanames{en}->{61899097} = "Mount\ Magnet";
$areanames{en}->{61899098} = "Mount\ Magnet";
$areanames{en}->{61899099} = "Carnamah\ West";
$areanames{en}->{61899100} = "Mullewa";
$areanames{en}->{61899101} = "Mullewa";
$areanames{en}->{61899102} = "Mullewa";
$areanames{en}->{61899103} = "Nabawa";
$areanames{en}->{61899104} = "Nabawa";
$areanames{en}->{61899105} = "Nabawa";
$areanames{en}->{61899106} = "Nangetty";
$areanames{en}->{61899107} = "Nangetty";
$areanames{en}->{61899108} = "Nangetty";
$areanames{en}->{61899109} = "Coorow";
$areanames{en}->{61899110} = "Northampton";
$areanames{en}->{61899111} = "Northampton";
$areanames{en}->{61899112} = "Northampton";
$areanames{en}->{61899113} = "Northern\ Gully";
$areanames{en}->{61899114} = "Northern\ Gully";
$areanames{en}->{61899115} = "Northern\ Gully";
$areanames{en}->{61899116} = "Paynes\ Find";
$areanames{en}->{61899117} = "Paynes\ Find";
$areanames{en}->{61899118} = "Paynes\ Find";
$areanames{en}->{61899119} = "Coorow\ West";
$areanames{en}->{61899120} = "Perenjori";
$areanames{en}->{61899121} = "Perenjori";
$areanames{en}->{61899122} = "Perenjori";
$areanames{en}->{61899123} = "Perenjori\ East";
$areanames{en}->{61899124} = "Perenjori\ East";
$areanames{en}->{61899125} = "Perenjori\ East";
$areanames{en}->{61899126} = "Pindar\ South";
$areanames{en}->{61899127} = "Pindar\ South";
$areanames{en}->{61899128} = "Pindar\ South";
$areanames{en}->{61899129} = "Eneabba";
$areanames{en}->{61899130} = "Tenindewa";
$areanames{en}->{61899131} = "Tenindewa";
$areanames{en}->{61899132} = "Tenindewa";
$areanames{en}->{61899133} = "Three\ Springs";
$areanames{en}->{61899134} = "Three\ Springs";
$areanames{en}->{61899135} = "Three\ Springs";
$areanames{en}->{61899136} = "Upper\ Gascoyne";
$areanames{en}->{61899137} = "Upper\ Gascoyne";
$areanames{en}->{61899138} = "Upper\ Gascoyne";
$areanames{en}->{61899139} = "Eneabba\ North";
$areanames{en}->{61899140} = "Walkaway";
$areanames{en}->{61899141} = "Walkaway";
$areanames{en}->{61899142} = "Walkaway";
$areanames{en}->{61899143} = "Warradarge";
$areanames{en}->{61899144} = "Warradarge";
$areanames{en}->{61899145} = "Warradarge";
$areanames{en}->{61899146} = "Wiluna";
$areanames{en}->{61899147} = "Wiluna";
$areanames{en}->{61899148} = "Wiluna";
$areanames{en}->{61899149} = "Carnarvon";
$areanames{en}->{61899150} = "Yalgoo";
$areanames{en}->{61899151} = "Yalgoo";
$areanames{en}->{61899152} = "Yalgoo";
$areanames{en}->{61899153} = "Yallalong";
$areanames{en}->{61899154} = "Yallalong";
$areanames{en}->{61899155} = "Yallalong";
$areanames{en}->{61899156} = "Yandanooka";
$areanames{en}->{61899157} = "Yandanooka";
$areanames{en}->{61899158} = "Yandanooka";
$areanames{en}->{61899159} = "Denham";
$areanames{en}->{61899160} = "Yaringa";
$areanames{en}->{61899161} = "Yaringa";
$areanames{en}->{61899162} = "Yaringa";
$areanames{en}->{61899163} = "Yuna";
$areanames{en}->{61899164} = "Yuna";
$areanames{en}->{61899165} = "Yuna";
$areanames{en}->{61899166} = "Yuna\ East";
$areanames{en}->{61899167} = "Yuna\ East";
$areanames{en}->{61899168} = "Yuna\ East";
$areanames{en}->{61899169} = "Exmouth";
$areanames{en}->{61899170} = "Upper\ Gascoyne";
$areanames{en}->{61899171} = "Yaringa";
$areanames{en}->{61899172} = "Northern\ Gully";
$areanames{en}->{61899173} = "Walkaway";
$areanames{en}->{61899174} = "Yuna";
$areanames{en}->{61899175} = "Yuna\ East";
$areanames{en}->{61899176} = "Northampton";
$areanames{en}->{61899177} = "Ajana";
$areanames{en}->{61899178} = "Balla";
$areanames{en}->{61899179} = "Dongara";
$areanames{en}->{61899180} = "Geraldton";
$areanames{en}->{61899181} = "Howatharra";
$areanames{en}->{61899182} = "Kalbarri";
$areanames{en}->{61899183} = "Lynton";
$areanames{en}->{61899184} = "Mingenew";
$areanames{en}->{61899185} = "Nabawa";
$areanames{en}->{61899186} = "Nangetty";
$areanames{en}->{61899187} = "Meekatharra";
$areanames{en}->{61899188} = "Mount\ George";
$areanames{en}->{61899189} = "Wiluna";
$areanames{en}->{61899190} = "Morawa";
$areanames{en}->{61899191} = "Perenjori";
$areanames{en}->{61899192} = "Perenjori\ East";
$areanames{en}->{61899193} = "Yandanooka";
$areanames{en}->{61899194} = "Guranu";
$areanames{en}->{61899195} = "Gutha\ West";
$areanames{en}->{61899196} = "Latham";
$areanames{en}->{61899197} = "Tenindewa";
$areanames{en}->{61899198} = "Yalgoo";
$areanames{en}->{61899199} = "Yallalong";
$areanames{en}->{61899200} = "Geraldton";
$areanames{en}->{61899201} = "Yuna";
$areanames{en}->{61899202} = "Yuna";
$areanames{en}->{61899203} = "Nabawa";
$areanames{en}->{61899204} = "Geraldton";
$areanames{en}->{61899205} = "Nabawa";
$areanames{en}->{61899206} = "Yuna\ East";
$areanames{en}->{61899207} = "Geraldton";
$areanames{en}->{61899208} = "Geraldton";
$areanames{en}->{61899209} = "Geraldton";
$areanames{en}->{6189921} = "Geraldton";
$areanames{en}->{61899220} = "Geraldton";
$areanames{en}->{61899221} = "Cue";
$areanames{en}->{61899222} = "Lake\ Mason";
$areanames{en}->{61899223} = "Mendel";
$areanames{en}->{61899224} = "Mount\ Magnet";
$areanames{en}->{61899225} = "Mullewa";
$areanames{en}->{61899226} = "Pindar\ South";
$areanames{en}->{61899227} = "Carnamah";
$areanames{en}->{618992278} = "Arrowsmith";
$areanames{en}->{618992279} = "Balla";
$areanames{en}->{61899228} = "Carnamah\ West";
$areanames{en}->{618992288} = "Carnamah";
$areanames{en}->{61899229} = "Coorow";
$areanames{en}->{618992298} = "Carnarvon";
$areanames{en}->{6189923} = "Geraldton";
$areanames{en}->{61899240} = "Northern\ Gully";
$areanames{en}->{61899241} = "Northern\ Gully";
$areanames{en}->{61899242} = "Northern\ Gully";
$areanames{en}->{61899243} = "Northern\ Gully";
$areanames{en}->{61899244} = "Northern\ Gully";
$areanames{en}->{61899245} = "Geraldton";
$areanames{en}->{61899246} = "Geraldton";
$areanames{en}->{61899247} = "Geraldton";
$areanames{en}->{61899248} = "Howatharra";
$areanames{en}->{61899249} = "Howatharra";
$areanames{en}->{61899250} = "Howatharra";
$areanames{en}->{61899251} = "Howatharra";
$areanames{en}->{61899252} = "Warradarge";
$areanames{en}->{61899253} = "Warradarge";
$areanames{en}->{61899254} = "Upper\ Gascoyne";
$areanames{en}->{61899255} = "Upper\ Gascoyne";
$areanames{en}->{61899256} = "Yaringa";
$areanames{en}->{61899257} = "Yaringa";
$areanames{en}->{61899258} = "Carnarvon";
$areanames{en}->{61899259} = "Carnarvon";
$areanames{en}->{61899260} = "Walkaway";
$areanames{en}->{61899261} = "Walkaway";
$areanames{en}->{61899262} = "Walkaway";
$areanames{en}->{61899263} = "Walkaway";
$areanames{en}->{61899264} = "Walkaway";
$areanames{en}->{61899265} = "Leeman";
$areanames{en}->{61899266} = "Leeman";
$areanames{en}->{61899267} = "Denham";
$areanames{en}->{61899268} = "Denham";
$areanames{en}->{61899269} = "Geraldton";
$areanames{en}->{6189927} = "Dongara";
$areanames{en}->{61899280} = "Mingenew";
$areanames{en}->{61899281} = "Mingenew";
$areanames{en}->{61899282} = "Mingenew";
$areanames{en}->{61899283} = "Eneabba";
$areanames{en}->{61899284} = "Eneabba";
$areanames{en}->{61899285} = "Eneabba\ North";
$areanames{en}->{61899286} = "Eneabba\ North";
$areanames{en}->{61899287} = "Eneabba\ South";
$areanames{en}->{61899288} = "Eneabba\ South";
$areanames{en}->{61899289} = "Carnarvon";
$areanames{en}->{61899290} = "Nangetty";
$areanames{en}->{61899291} = "Nangetty";
$areanames{en}->{61899292} = "Carnamah";
$areanames{en}->{61899293} = "Carnamah";
$areanames{en}->{61899294} = "Carnamah\ West";
$areanames{en}->{61899295} = "Carnamah\ West";
$areanames{en}->{61899296} = "Coorow";
$areanames{en}->{61899297} = "Coorow";
$areanames{en}->{61899298} = "Coorow\ West";
$areanames{en}->{61899299} = "Coorow\ West";
$areanames{en}->{61899300} = "Coorow\ West";
$areanames{en}->{618993009} = "Cue";
$areanames{en}->{61899301} = "Eneabba";
$areanames{en}->{618993018} = "Denham";
$areanames{en}->{618993019} = "Dongara";
$areanames{en}->{61899302} = "Eneabba\ North";
$areanames{en}->{618993028} = "Eneabba";
$areanames{en}->{61899303} = "Eneabba\ South";
$areanames{en}->{618993039} = "Exmouth";
$areanames{en}->{61899304} = "Leeman";
$areanames{en}->{618993048} = "Geraldton";
$areanames{en}->{618993049} = "Guranu";
$areanames{en}->{61899305} = "Marchagee";
$areanames{en}->{618993058} = "Gutha\ West";
$areanames{en}->{618993059} = "Howatharra";
$areanames{en}->{61899306} = "Three\ Springs";
$areanames{en}->{618993068} = "Kalbarri";
$areanames{en}->{618993069} = "Lake\ Mason";
$areanames{en}->{61899307} = "Warradarge";
$areanames{en}->{618993078} = "Latham";
$areanames{en}->{618993079} = "Leeman";
$areanames{en}->{61899308} = "Carnarvon";
$areanames{en}->{618993088} = "Lynton";
$areanames{en}->{618993089} = "Marchagee";
$areanames{en}->{61899309} = "Denham";
$areanames{en}->{618993098} = "Meekatharra";
$areanames{en}->{618993099} = "Mendel";
$areanames{en}->{61899310} = "Yuna\ East";
$areanames{en}->{61899311} = "Yuna\ East";
$areanames{en}->{61899312} = "Exmouth";
$areanames{en}->{61899313} = "Exmouth";
$areanames{en}->{61899314} = "Yuna";
$areanames{en}->{61899315} = "Yuna";
$areanames{en}->{61899316} = "Yuna\ East";
$areanames{en}->{61899317} = "Yuna\ East";
$areanames{en}->{61899318} = "Ajana";
$areanames{en}->{61899319} = "Ajana";
$areanames{en}->{61899320} = "Exmouth";
$areanames{en}->{618993209} = "Mingenew";
$areanames{en}->{61899321} = "Upper\ Gascoyne";
$areanames{en}->{618993218} = "Morawa";
$areanames{en}->{618993219} = "Mount\ George";
$areanames{en}->{61899322} = "Yaringa";
$areanames{en}->{618993228} = "Mount\ Magnet";
$areanames{en}->{618993229} = "Mullewa";
$areanames{en}->{61899323} = "Ajana";
$areanames{en}->{618993238} = "Nabawa";
$areanames{en}->{618993239} = "Nangetty";
$areanames{en}->{61899324} = "Balla";
$areanames{en}->{618993248} = "Northampton";
$areanames{en}->{618993249} = "Northern\ Gully";
$areanames{en}->{61899325} = "Dongara";
$areanames{en}->{618993258} = "Perenjori";
$areanames{en}->{618993259} = "Perenjori\ East";
$areanames{en}->{618993260} = "Geraldton";
$areanames{en}->{618993261} = "Geraldton";
$areanames{en}->{618993262} = "Geraldton";
$areanames{en}->{618993263} = "Geraldton";
$areanames{en}->{618993264} = "Geraldton";
$areanames{en}->{618993267} = "Pindar\ South";
$areanames{en}->{618993268} = "Tenindewa";
$areanames{en}->{618993269} = "Three\ Springs";
$areanames{en}->{61899327} = "Howatharra";
$areanames{en}->{618993278} = "Upper\ Gascoyne";
$areanames{en}->{618993279} = "Walkaway";
$areanames{en}->{61899328} = "Kalbarri";
$areanames{en}->{618993288} = "Warradarge";
$areanames{en}->{618993289} = "Wiluna";
$areanames{en}->{61899329} = "Lynton";
$areanames{en}->{618993298} = "Yalgoo";
$areanames{en}->{618993299} = "Yallalong";
$areanames{en}->{61899330} = "Balla";
$areanames{en}->{61899331} = "Balla";
$areanames{en}->{61899332} = "Eneabba";
$areanames{en}->{61899333} = "Eneabba";
$areanames{en}->{61899334} = "Eneabba";
$areanames{en}->{61899335} = "Eneabba\ South";
$areanames{en}->{61899336} = "Arrowsmith";
$areanames{en}->{61899337} = "Eneabba\ South";
$areanames{en}->{61899338} = "Arrowsmith";
$areanames{en}->{61899339} = "Arrowsmith";
$areanames{en}->{61899340} = "Northampton";
$areanames{en}->{61899341} = "Northampton";
$areanames{en}->{61899342} = "Northampton";
$areanames{en}->{61899343} = "Northampton";
$areanames{en}->{61899344} = "Dongara";
$areanames{en}->{61899345} = "Dongara";
$areanames{en}->{61899346} = "Geraldton";
$areanames{en}->{61899347} = "Northampton";
$areanames{en}->{61899348} = "Kalbarri";
$areanames{en}->{61899349} = "Kalbarri";
$areanames{en}->{61899350} = "Lynton";
$areanames{en}->{61899351} = "Lynton";
$areanames{en}->{61899352} = "Lynton";
$areanames{en}->{61899353} = "Lynton";
$areanames{en}->{61899354} = "Lynton";
$areanames{en}->{61899355} = "Mingenew";
$areanames{en}->{61899356} = "Mingenew";
$areanames{en}->{61899357} = "Nabawa";
$areanames{en}->{61899358} = "Nabawa";
$areanames{en}->{61899359} = "Geraldton";
$areanames{en}->{61899360} = "Ajana";
$areanames{en}->{61899361} = "Ajana";
$areanames{en}->{61899362} = "Ajana";
$areanames{en}->{61899363} = "Kalbarri";
$areanames{en}->{61899364} = "Kalbarri";
$areanames{en}->{61899365} = "Kalbarri";
$areanames{en}->{61899366} = "Lynton";
$areanames{en}->{61899367} = "Carnarvon";
$areanames{en}->{61899368} = "Nangetty";
$areanames{en}->{61899369} = "Nangetty";
$areanames{en}->{61899370} = "Kalbarri";
$areanames{en}->{61899371} = "Kalbarri";
$areanames{en}->{61899372} = "Kalbarri";
$areanames{en}->{61899373} = "Yandanooka";
$areanames{en}->{61899374} = "Yandanooka";
$areanames{en}->{61899375} = "Guranu";
$areanames{en}->{61899376} = "Guranu";
$areanames{en}->{61899377} = "Morawa";
$areanames{en}->{61899378} = "Morawa";
$areanames{en}->{61899379} = "Geraldton";
$areanames{en}->{6189938} = "Geraldton";
$areanames{en}->{61899385} = "Northampton";
$areanames{en}->{61899386} = "Northampton";
$areanames{en}->{61899387} = "Northern\ Gully";
$areanames{en}->{61899388} = "Northern\ Gully";
$areanames{en}->{61899390} = "Mingenew";
$areanames{en}->{618993908} = "Yandanooka";
$areanames{en}->{618993909} = "Yaringa";
$areanames{en}->{61899391} = "Nabawa";
$areanames{en}->{618993918} = "Yuna";
$areanames{en}->{618993919} = "Yuna\ East";
$areanames{en}->{61899392} = "Nangetty";
$areanames{en}->{618993928} = "Ajana";
$areanames{en}->{618993929} = "Arrowsmith";
$areanames{en}->{61899393} = "Northampton";
$areanames{en}->{618993938} = "Balla";
$areanames{en}->{618993939} = "Carnamah";
$areanames{en}->{61899394} = "Northern\ Gully";
$areanames{en}->{618993948} = "Carnamah\ West";
$areanames{en}->{618993949} = "Carnarvon";
$areanames{en}->{61899395} = "Walkaway";
$areanames{en}->{618993958} = "Coorow";
$areanames{en}->{618993959} = "Coorow\ West";
$areanames{en}->{61899396} = "Yuna";
$areanames{en}->{618993968} = "Cue";
$areanames{en}->{618993969} = "Denham";
$areanames{en}->{61899397} = "Yuna\ East";
$areanames{en}->{618993978} = "Dongara";
$areanames{en}->{618993979} = "Eneabba";
$areanames{en}->{61899398} = "Meekatharra";
$areanames{en}->{618993988} = "Eneabba\ North";
$areanames{en}->{618993989} = "Eneabba\ South";
$areanames{en}->{61899399} = "Mount\ George";
$areanames{en}->{618993998} = "Exmouth";
$areanames{en}->{618993999} = "Geraldton";
$areanames{en}->{61899400} = "Mendel";
$areanames{en}->{618994008} = "Guranu";
$areanames{en}->{618994009} = "Gutha\ West";
$areanames{en}->{61899401} = "Wiluna";
$areanames{en}->{618994018} = "Howatharra";
$areanames{en}->{618994019} = "Kalbarri";
$areanames{en}->{61899402} = "Guranu";
$areanames{en}->{618994028} = "Lake\ Mason";
$areanames{en}->{618994029} = "Latham";
$areanames{en}->{61899403} = "Mount\ Magnet";
$areanames{en}->{618994038} = "Leeman";
$areanames{en}->{618994039} = "Lynton";
$areanames{en}->{61899404} = "Gutha\ West";
$areanames{en}->{618994048} = "Marchagee";
$areanames{en}->{618994049} = "Meekatharra";
$areanames{en}->{61899405} = "Mullewa";
$areanames{en}->{618994058} = "Mendel";
$areanames{en}->{618994059} = "Mingenew";
$areanames{en}->{61899406} = "Latham";
$areanames{en}->{618994068} = "Morawa";
$areanames{en}->{618994069} = "Mount\ George";
$areanames{en}->{61899407} = "Pindar\ South";
$areanames{en}->{618994078} = "Mount\ Magnet";
$areanames{en}->{618994079} = "Mullewa";
$areanames{en}->{61899408} = "Morawa";
$areanames{en}->{618994088} = "Nabawa";
$areanames{en}->{618994089} = "Nangetty";
$areanames{en}->{61899409} = "Tenindewa";
$areanames{en}->{618994098} = "Northampton";
$areanames{en}->{618994099} = "Northern\ Gully";
$areanames{en}->{6189941} = "Carnarvon";
$areanames{en}->{61899420} = "Yallalong";
$areanames{en}->{61899421} = "Yallalong";
$areanames{en}->{61899422} = "Mendel";
$areanames{en}->{61899423} = "Mendel";
$areanames{en}->{61899424} = "Dongara";
$areanames{en}->{61899425} = "Yaringa";
$areanames{en}->{61899426} = "Yaringa";
$areanames{en}->{61899427} = "Mullewa";
$areanames{en}->{61899428} = "Mullewa";
$areanames{en}->{61899429} = "Carnarvon";
$areanames{en}->{61899430} = "Upper\ Gascoyne";
$areanames{en}->{61899431} = "Upper\ Gascoyne";
$areanames{en}->{61899432} = "Tenindewa";
$areanames{en}->{61899433} = "Tenindewa";
$areanames{en}->{61899434} = "Marchagee";
$areanames{en}->{61899435} = "Marchagee";
$areanames{en}->{61899436} = "Geraldton";
$areanames{en}->{61899437} = "Carnarvon";
$areanames{en}->{61899438} = "Geraldton";
$areanames{en}->{61899439} = "Upper\ Gascoyne";
$areanames{en}->{61899440} = "Perenjori";
$areanames{en}->{618994409} = "Perenjori\ East";
$areanames{en}->{61899441} = "Yalgoo";
$areanames{en}->{618994418} = "Pindar\ South";
$areanames{en}->{618994419} = "Tenindewa";
$areanames{en}->{61899442} = "Perenjori\ East";
$areanames{en}->{618994428} = "Three\ Springs";
$areanames{en}->{618994429} = "Upper\ Gascoyne";
$areanames{en}->{61899443} = "Yallalong";
$areanames{en}->{618994438} = "Walkaway";
$areanames{en}->{618994439} = "Warradarge";
$areanames{en}->{61899444} = "Paynes\ Find";
$areanames{en}->{618994449} = "Wiluna";
$areanames{en}->{61899445} = "Yandanooka";
$areanames{en}->{618994458} = "Yalgoo";
$areanames{en}->{618994459} = "Yallalong";
$areanames{en}->{61899446} = "Cue";
$areanames{en}->{618994468} = "Yandanooka";
$areanames{en}->{618994469} = "Yaringa";
$areanames{en}->{61899447} = "Lake\ Mason";
$areanames{en}->{618994478} = "Yuna";
$areanames{en}->{618994479} = "Yuna\ East";
$areanames{en}->{61899448} = "Geraldton";
$areanames{en}->{61899449} = "Geraldton";
$areanames{en}->{61899450} = "Arrowsmith";
$areanames{en}->{61899451} = "Carnamah";
$areanames{en}->{61899452} = "Carnamah\ West";
$areanames{en}->{61899453} = "Coorow";
$areanames{en}->{61899454} = "Coorow\ West";
$areanames{en}->{61899455} = "Eneabba";
$areanames{en}->{61899456} = "Eneabba\ North";
$areanames{en}->{61899457} = "Eneabba\ South";
$areanames{en}->{61899458} = "Leeman";
$areanames{en}->{61899459} = "Marchagee";
$areanames{en}->{61899460} = "Three\ Springs";
$areanames{en}->{61899461} = "Warradarge";
$areanames{en}->{61899462} = "Carnarvon";
$areanames{en}->{61899463} = "Denham";
$areanames{en}->{61899464} = "Exmouth";
$areanames{en}->{61899465} = "Upper\ Gascoyne";
$areanames{en}->{61899466} = "Yaringa";
$areanames{en}->{61899467} = "Ajana";
$areanames{en}->{61899468} = "Balla";
$areanames{en}->{61899469} = "Dongara";
$areanames{en}->{61899470} = "Carnarvon";
$areanames{en}->{61899471} = "Carnarvon";
$areanames{en}->{61899472} = "Carnarvon";
$areanames{en}->{61899473} = "Meekatharra";
$areanames{en}->{61899474} = "Balla";
$areanames{en}->{61899475} = "Coorow";
$areanames{en}->{61899476} = "Coorow\ West";
$areanames{en}->{61899477} = "Cue";
$areanames{en}->{61899478} = "Exmouth";
$areanames{en}->{61899479} = "Exmouth";
$areanames{en}->{61899480} = "Denham";
$areanames{en}->{61899481} = "Denham";
$areanames{en}->{61899482} = "Denham";
$areanames{en}->{61899483} = "Denham";
$areanames{en}->{61899484} = "Denham";
$areanames{en}->{61899485} = "Yaringa";
$areanames{en}->{61899486} = "Yaringa";
$areanames{en}->{61899487} = "Geraldton";
$areanames{en}->{61899488} = "Geraldton";
$areanames{en}->{61899489} = "Geraldton";
$areanames{en}->{61899490} = "Exmouth";
$areanames{en}->{61899491} = "Exmouth";
$areanames{en}->{61899492} = "Exmouth";
$areanames{en}->{61899493} = "Exmouth";
$areanames{en}->{61899494} = "Exmouth";
$areanames{en}->{61899495} = "Geraldton";
$areanames{en}->{61899496} = "Geraldton";
$areanames{en}->{61899497} = "Geraldton";
$areanames{en}->{61899498} = "Geraldton";
$areanames{en}->{61899499} = "Geraldton";
$areanames{en}->{61899500} = "Geraldton";
$areanames{en}->{61899501} = "Howatharra";
$areanames{en}->{61899502} = "Kalbarri";
$areanames{en}->{61899503} = "Lynton";
$areanames{en}->{61899504} = "Mingenew";
$areanames{en}->{61899505} = "Nabawa";
$areanames{en}->{61899506} = "Nangetty";
$areanames{en}->{61899507} = "Northampton";
$areanames{en}->{61899508} = "Northern\ Gully";
$areanames{en}->{61899509} = "Walkaway";
$areanames{en}->{61899510} = "Carnamah";
$areanames{en}->{61899511} = "Carnamah";
$areanames{en}->{61899512} = "Three\ Springs";
$areanames{en}->{61899513} = "Three\ Springs";
$areanames{en}->{61899514} = "Denham";
$areanames{en}->{61899515} = "Eneabba";
$areanames{en}->{61899516} = "Carnamah";
$areanames{en}->{61899517} = "Carnamah";
$areanames{en}->{61899518} = "Marchagee";
$areanames{en}->{61899519} = "Marchagee";
$areanames{en}->{61899520} = "Coorow";
$areanames{en}->{61899521} = "Coorow";
$areanames{en}->{61899522} = "Coorow";
$areanames{en}->{61899523} = "Coorow";
$areanames{en}->{61899524} = "Coorow\ West";
$areanames{en}->{61899525} = "Coorow\ West";
$areanames{en}->{61899526} = "Carnamah\ West";
$areanames{en}->{61899527} = "Carnamah\ West";
$areanames{en}->{61899528} = "Warradarge";
$areanames{en}->{61899529} = "Warradarge";
$areanames{en}->{61899530} = "Leeman";
$areanames{en}->{61899531} = "Leeman";
$areanames{en}->{61899532} = "Leeman";
$areanames{en}->{61899533} = "Leeman";
$areanames{en}->{61899534} = "Eneabba\ North";
$areanames{en}->{61899535} = "Eneabba\ South";
$areanames{en}->{61899536} = "Guranu";
$areanames{en}->{61899537} = "Gutha\ West";
$areanames{en}->{61899538} = "Howatharra";
$areanames{en}->{61899539} = "Lake\ Mason";
$areanames{en}->{6189954} = "Three\ Springs";
$areanames{en}->{61899540} = "Lake\ Mason";
$areanames{en}->{61899542} = "Latham";
$areanames{en}->{61899548} = "Arrowsmith";
$areanames{en}->{61899549} = "Arrowsmith";
$areanames{en}->{61899550} = "Ajana";
$areanames{en}->{61899551} = "Eneabba";
$areanames{en}->{61899552} = "Eneabba\ North";
$areanames{en}->{61899553} = "Leeman";
$areanames{en}->{61899554} = "Lynton";
$areanames{en}->{61899555} = "Morawa";
$areanames{en}->{61899556} = "Eneabba\ South";
$areanames{en}->{61899557} = "Eneabba\ South";
$areanames{en}->{61899558} = "Arrowsmith";
$areanames{en}->{61899559} = "Dongara";
$areanames{en}->{61899560} = "Geraldton";
$areanames{en}->{61899561} = "Geraldton";
$areanames{en}->{61899562} = "Geraldton\/Northern\ Gully\/Geraldton";
$areanames{en}->{61899563} = "Carnarvon\/Yaringa";
$areanames{en}->{618995632} = "Yaringa";
$areanames{en}->{61899564} = "Yallalong";
$areanames{en}->{61899565} = "Meekatharra";
$areanames{en}->{61899566} = "Geraldton";
$areanames{en}->{61899567} = "Mount\ George\/Wiluna";
$areanames{en}->{61899568} = "Geraldton";
$areanames{en}->{61899569} = "Eneabba";
$areanames{en}->{61899570} = "Arrowsmith";
$areanames{en}->{61899571} = "Mount\ Magnet";
$areanames{en}->{61899572} = "Cue";
$areanames{en}->{61899573} = "Mount\ Magnet";
$areanames{en}->{61899574} = "Mount\ Magnet";
$areanames{en}->{61899575} = "Mullewa";
$areanames{en}->{61899576} = "Nabawa";
$areanames{en}->{61899577} = "Nangetty";
$areanames{en}->{61899578} = "Exmouth";
$areanames{en}->{61899579} = "Exmouth";
$areanames{en}->{61899580} = "Yuna";
$areanames{en}->{61899581} = "Yuna\ East";
$areanames{en}->{61899582} = "Meekatharra";
$areanames{en}->{61899583} = "Mount\ George";
$areanames{en}->{61899584} = "Wiluna";
$areanames{en}->{61899585} = "Guranu";
$areanames{en}->{61899586} = "Gutha\ West";
$areanames{en}->{61899587} = "Latham";
$areanames{en}->{61899588} = "Morawa";
$areanames{en}->{61899589} = "Perenjori";
$areanames{en}->{61899590} = "Perenjori\ East";
$areanames{en}->{61899591} = "Yandanooka";
$areanames{en}->{61899592} = "Cue";
$areanames{en}->{61899593} = "Lake\ Mason";
$areanames{en}->{61899594} = "Mendel";
$areanames{en}->{61899595} = "Mount\ Magnet";
$areanames{en}->{61899596} = "Mullewa";
$areanames{en}->{61899597} = "Pindar\ South";
$areanames{en}->{61899598} = "Tenindewa";
$areanames{en}->{61899599} = "Yalgoo";
$areanames{en}->{61899600} = "Yallalong";
$areanames{en}->{61899601} = "Morawa";
$areanames{en}->{61899602} = "Northern\ Gully";
$areanames{en}->{61899603} = "Perenjori\ East";
$areanames{en}->{61899604} = "Pindar\ South";
$areanames{en}->{61899605} = "Geraldton";
$areanames{en}->{61899606} = "Geraldton";
$areanames{en}->{61899607} = "Geraldton";
$areanames{en}->{61899608} = "Geraldton";
$areanames{en}->{61899609} = "Geraldton";
$areanames{en}->{61899610} = "Yallalong";
$areanames{en}->{61899611} = "Mullewa";
$areanames{en}->{61899612} = "Mullewa";
$areanames{en}->{61899613} = "Yallalong";
$areanames{en}->{61899614} = "Tenindewa";
$areanames{en}->{61899615} = "Mendel";
$areanames{en}->{61899616} = "Mullewa";
$areanames{en}->{61899617} = "Mullewa";
$areanames{en}->{61899618} = "Yallalong";
$areanames{en}->{61899619} = "Mendel";
$areanames{en}->{61899620} = "Yalgoo";
$areanames{en}->{61899621} = "Geraldton";
$areanames{en}->{61899622} = "Pindar\ South";
$areanames{en}->{61899623} = "Pindar\ South";
$areanames{en}->{61899624} = "Tenindewa";
$areanames{en}->{61899625} = "Tenindewa";
$areanames{en}->{61899626} = "Yallalong";
$areanames{en}->{61899627} = "Yallalong";
$areanames{en}->{61899628} = "Pindar\ South";
$areanames{en}->{61899629} = "Yallalong";
$areanames{en}->{61899630} = "Cue";
$areanames{en}->{61899631} = "Cue";
$areanames{en}->{61899632} = "Lake\ Mason";
$areanames{en}->{61899633} = "Mount\ Magnet";
$areanames{en}->{61899634} = "Mount\ Magnet";
$areanames{en}->{61899635} = "Lake\ Mason";
$areanames{en}->{61899636} = "Paynes\ Find";
$areanames{en}->{61899637} = "Yallalong";
$areanames{en}->{61899638} = "Cue";
$areanames{en}->{61899639} = "Cue";
$areanames{en}->{6189964} = "Geraldton";
$areanames{en}->{6189965} = "Geraldton";
$areanames{en}->{61899660} = "Tenindewa";
$areanames{en}->{61899661} = "Three\ Springs";
$areanames{en}->{61899662} = "Upper\ Gascoyne";
$areanames{en}->{61899663} = "Walkaway";
$areanames{en}->{61899664} = "Warradarge";
$areanames{en}->{61899665} = "Wiluna";
$areanames{en}->{61899666} = "Yalgoo";
$areanames{en}->{61899667} = "Yallalong";
$areanames{en}->{61899668} = "Yandanooka";
$areanames{en}->{61899669} = "Yuna";
$areanames{en}->{61899670} = "Yuna\ East";
$areanames{en}->{618996710} = "Ajana";
$areanames{en}->{618996711} = "Arrowsmith";
$areanames{en}->{618996712} = "Balla";
$areanames{en}->{618996713} = "Carnamah";
$areanames{en}->{618996714} = "Carnamah\ West";
$areanames{en}->{618996715} = "Carnarvon";
$areanames{en}->{618996716} = "Coorow";
$areanames{en}->{618996717} = "Coorow\ West";
$areanames{en}->{618996718} = "Cue";
$areanames{en}->{618996719} = "Denham";
$areanames{en}->{618996720} = "Dongara";
$areanames{en}->{618996721} = "Eneabba";
$areanames{en}->{618996722} = "Eneabba\ North";
$areanames{en}->{618996723} = "Eneabba\ South";
$areanames{en}->{618996724} = "Exmouth";
$areanames{en}->{618996725} = "Geraldton";
$areanames{en}->{618996726} = "Guranu";
$areanames{en}->{618996727} = "Gutha\ West";
$areanames{en}->{618996728} = "Howatharra";
$areanames{en}->{618996729} = "Kalbarri";
$areanames{en}->{618996730} = "Lake\ Mason";
$areanames{en}->{618996731} = "Latham";
$areanames{en}->{618996732} = "Leeman";
$areanames{en}->{618996733} = "Lynton";
$areanames{en}->{618996734} = "Marchagee";
$areanames{en}->{618996735} = "Meekatharra";
$areanames{en}->{618996736} = "Mendel";
$areanames{en}->{618996737} = "Mingenew";
$areanames{en}->{618996738} = "Morawa";
$areanames{en}->{618996739} = "Mount\ George";
$areanames{en}->{618996740} = "Mount\ Magnet";
$areanames{en}->{618996741} = "Mullewa";
$areanames{en}->{618996742} = "Nabawa";
$areanames{en}->{618996743} = "Nangetty";
$areanames{en}->{618996744} = "Northampton";
$areanames{en}->{618996745} = "Northern\ Gully";
$areanames{en}->{618996746} = "Paynes\ Find";
$areanames{en}->{618996747} = "Perenjori";
$areanames{en}->{618996748} = "Perenjori\ East";
$areanames{en}->{618996749} = "Pindar\ South";
$areanames{en}->{618996750} = "Tenindewa";
$areanames{en}->{618996751} = "Three\ Springs";
$areanames{en}->{618996752} = "Upper\ Gascoyne";
$areanames{en}->{618996753} = "Walkaway";
$areanames{en}->{618996754} = "Warradarge";
$areanames{en}->{618996755} = "Wiluna";
$areanames{en}->{618996756} = "Yalgoo";
$areanames{en}->{618996757} = "Yallalong";
$areanames{en}->{618996758} = "Yandanooka";
$areanames{en}->{618996759} = "Yaringa";
$areanames{en}->{618996760} = "Yuna";
$areanames{en}->{618996761} = "Yuna\ East";
$areanames{en}->{618996762} = "Ajana";
$areanames{en}->{618996763} = "Arrowsmith";
$areanames{en}->{618996764} = "Balla";
$areanames{en}->{618996765} = "Carnamah";
$areanames{en}->{618996766} = "Carnamah\ West";
$areanames{en}->{618996767} = "Carnarvon";
$areanames{en}->{618996768} = "Coorow";
$areanames{en}->{618996769} = "Coorow\ West";
$areanames{en}->{61899677} = "Dongara";
$areanames{en}->{61899678} = "Geraldton";
$areanames{en}->{61899679} = "Geraldton";
$areanames{en}->{618996800} = "Cue";
$areanames{en}->{618996801} = "Denham";
$areanames{en}->{618996802} = "Dongara";
$areanames{en}->{618996803} = "Eneabba";
$areanames{en}->{618996804} = "Eneabba\ North";
$areanames{en}->{618996805} = "Eneabba\ South";
$areanames{en}->{618996806} = "Exmouth";
$areanames{en}->{618996807} = "Geraldton";
$areanames{en}->{618996808} = "Guranu";
$areanames{en}->{618996809} = "Gutha\ West";
$areanames{en}->{61899681} = "Geraldton";
$areanames{en}->{61899682} = "Geraldton";
$areanames{en}->{618996830} = "Howatharra";
$areanames{en}->{618996831} = "Kalbarri";
$areanames{en}->{618996832} = "Lake\ Mason";
$areanames{en}->{618996833} = "Latham";
$areanames{en}->{618996834} = "Leeman";
$areanames{en}->{618996835} = "Lynton";
$areanames{en}->{618996836} = "Marchagee";
$areanames{en}->{618996837} = "Meekatharra";
$areanames{en}->{618996838} = "Mendel";
$areanames{en}->{618996839} = "Mingenew";
$areanames{en}->{618996840} = "Morawa";
$areanames{en}->{618996841} = "Mount\ George";
$areanames{en}->{618996842} = "Mount\ Magnet";
$areanames{en}->{618996843} = "Mullewa";
$areanames{en}->{618996844} = "Nabawa";
$areanames{en}->{618996845} = "Nangetty";
$areanames{en}->{618996846} = "Northampton";
$areanames{en}->{618996847} = "Northern\ Gully";
$areanames{en}->{618996848} = "Paynes\ Find";
$areanames{en}->{618996849} = "Perenjori";
$areanames{en}->{618996850} = "Perenjori\ East";
$areanames{en}->{618996851} = "Pindar\ South";
$areanames{en}->{618996852} = "Tenindewa";
$areanames{en}->{618996853} = "Ajana";
$areanames{en}->{618996854} = "Arrowsmith";
$areanames{en}->{618996855} = "Balla";
$areanames{en}->{618996856} = "Carnamah";
$areanames{en}->{618996857} = "Carnamah\ West";
$areanames{en}->{618996858} = "Carnarvon";
$areanames{en}->{618996859} = "Coorow";
$areanames{en}->{618996860} = "Coorow\ West";
$areanames{en}->{618996861} = "Cue";
$areanames{en}->{618996862} = "Denham";
$areanames{en}->{618996863} = "Dongara";
$areanames{en}->{618996864} = "Eneabba";
$areanames{en}->{618996865} = "Eneabba\ North";
$areanames{en}->{618996866} = "Eneabba\ South";
$areanames{en}->{618996867} = "Exmouth";
$areanames{en}->{618996868} = "Geraldton";
$areanames{en}->{618996869} = "Guranu";
$areanames{en}->{618996870} = "Gutha\ West";
$areanames{en}->{618996871} = "Howatharra";
$areanames{en}->{618996872} = "Kalbarri";
$areanames{en}->{618996873} = "Lake\ Mason";
$areanames{en}->{618996874} = "Latham";
$areanames{en}->{618996875} = "Leeman";
$areanames{en}->{618996876} = "Lynton";
$areanames{en}->{618996877} = "Marchagee";
$areanames{en}->{618996878} = "Meekatharra";
$areanames{en}->{618996879} = "Mendel";
$areanames{en}->{618996880} = "Mingenew";
$areanames{en}->{618996881} = "Morawa";
$areanames{en}->{618996882} = "Mount\ George";
$areanames{en}->{618996883} = "Mount\ Magnet";
$areanames{en}->{618996884} = "Mullewa";
$areanames{en}->{618996885} = "Nabawa";
$areanames{en}->{618996886} = "Nangetty";
$areanames{en}->{618996887} = "Northampton";
$areanames{en}->{618996888} = "Northern\ Gully";
$areanames{en}->{618996889} = "Paynes\ Find";
$areanames{en}->{618996890} = "Perenjori";
$areanames{en}->{618996891} = "Perenjori\ East";
$areanames{en}->{618996892} = "Pindar\ South";
$areanames{en}->{618996893} = "Tenindewa";
$areanames{en}->{618996894} = "Three\ Springs";
$areanames{en}->{618996895} = "Upper\ Gascoyne";
$areanames{en}->{618996896} = "Walkaway";
$areanames{en}->{618996897} = "Warradarge";
$areanames{en}->{618996898} = "Wiluna";
$areanames{en}->{618996899} = "Yalgoo";
$areanames{en}->{618996900} = "Yallalong";
$areanames{en}->{618996901} = "Yandanooka";
$areanames{en}->{618996902} = "Yaringa";
$areanames{en}->{618996903} = "Yuna";
$areanames{en}->{618996904} = "Yuna\ East";
$areanames{en}->{618996905} = "Three\ Springs";
$areanames{en}->{618996906} = "Upper\ Gascoyne";
$areanames{en}->{618996907} = "Walkaway";
$areanames{en}->{618996908} = "Warradarge";
$areanames{en}->{618996909} = "Wiluna";
$areanames{en}->{618996910} = "Yalgoo";
$areanames{en}->{618996911} = "Yallalong";
$areanames{en}->{618996912} = "Yandanooka";
$areanames{en}->{618996913} = "Yaringa";
$areanames{en}->{618996914} = "Yuna";
$areanames{en}->{618996915} = "Yuna\ East";
$areanames{en}->{618996916} = "Ajana";
$areanames{en}->{618996917} = "Arrowsmith";
$areanames{en}->{618996918} = "Balla";
$areanames{en}->{618996919} = "Carnamah";
$areanames{en}->{618996920} = "Carnamah\ West";
$areanames{en}->{618996921} = "Carnarvon";
$areanames{en}->{618996922} = "Coorow";
$areanames{en}->{618996923} = "Coorow\ West";
$areanames{en}->{618996924} = "Cue";
$areanames{en}->{618996925} = "Denham";
$areanames{en}->{618996926} = "Dongara";
$areanames{en}->{618996927} = "Eneabba";
$areanames{en}->{618996928} = "Eneabba\ North";
$areanames{en}->{618996929} = "Eneabba\ South";
$areanames{en}->{618996930} = "Exmouth";
$areanames{en}->{618996931} = "Geraldton";
$areanames{en}->{618996932} = "Guranu";
$areanames{en}->{618996933} = "Gutha\ West";
$areanames{en}->{618996934} = "Howatharra";
$areanames{en}->{618996935} = "Kalbarri";
$areanames{en}->{618996936} = "Lake\ Mason";
$areanames{en}->{618996937} = "Latham";
$areanames{en}->{618996938} = "Leeman";
$areanames{en}->{618996939} = "Lynton";
$areanames{en}->{618996940} = "Marchagee";
$areanames{en}->{618996941} = "Meekatharra";
$areanames{en}->{618996942} = "Mendel";
$areanames{en}->{618996943} = "Mingenew";
$areanames{en}->{618996944} = "Morawa";
$areanames{en}->{618996945} = "Mount\ George";
$areanames{en}->{618996946} = "Mount\ Magnet";
$areanames{en}->{618996947} = "Mullewa";
$areanames{en}->{618996948} = "Nabawa";
$areanames{en}->{618996949} = "Nangetty";
$areanames{en}->{618996950} = "Northampton";
$areanames{en}->{618996951} = "Northern\ Gully";
$areanames{en}->{618996952} = "Paynes\ Find";
$areanames{en}->{618996953} = "Perenjori";
$areanames{en}->{618996954} = "Perenjori\ East";
$areanames{en}->{618996955} = "Pindar\ South";
$areanames{en}->{618996956} = "Tenindewa";
$areanames{en}->{618996957} = "Three\ Springs";
$areanames{en}->{618996958} = "Upper\ Gascoyne";
$areanames{en}->{618996959} = "Walkaway";
$areanames{en}->{618996960} = "Warradarge";
$areanames{en}->{618996961} = "Wiluna";
$areanames{en}->{618996962} = "Yalgoo";
$areanames{en}->{618996963} = "Yallalong";
$areanames{en}->{618996964} = "Yandanooka";
$areanames{en}->{618996965} = "Yaringa";
$areanames{en}->{618996966} = "Yuna";
$areanames{en}->{618996967} = "Yuna\ East";
$areanames{en}->{618996968} = "Ajana";
$areanames{en}->{618996969} = "Arrowsmith";
$areanames{en}->{618996970} = "Balla";
$areanames{en}->{618996971} = "Carnamah";
$areanames{en}->{618996972} = "Carnamah\ West";
$areanames{en}->{618996973} = "Carnarvon";
$areanames{en}->{618996974} = "Coorow";
$areanames{en}->{618996975} = "Coorow\ West";
$areanames{en}->{618996976} = "Cue";
$areanames{en}->{618996977} = "Denham";
$areanames{en}->{618996978} = "Dongara";
$areanames{en}->{618996979} = "Eneabba";
$areanames{en}->{618996980} = "Eneabba\ North";
$areanames{en}->{618996981} = "Eneabba\ South";
$areanames{en}->{618996982} = "Exmouth";
$areanames{en}->{618996983} = "Geraldton";
$areanames{en}->{618996984} = "Guranu";
$areanames{en}->{618996985} = "Gutha\ West";
$areanames{en}->{618996986} = "Howatharra";
$areanames{en}->{618996987} = "Kalbarri";
$areanames{en}->{618996988} = "Lake\ Mason";
$areanames{en}->{618996989} = "Latham";
$areanames{en}->{618996990} = "Leeman";
$areanames{en}->{618996991} = "Lynton";
$areanames{en}->{618996992} = "Marchagee";
$areanames{en}->{618996993} = "Meekatharra";
$areanames{en}->{618996994} = "Mendel";
$areanames{en}->{618996995} = "Mingenew";
$areanames{en}->{618996996} = "Morawa";
$areanames{en}->{618996997} = "Mount\ George";
$areanames{en}->{618996998} = "Mount\ Magnet";
$areanames{en}->{618996999} = "Mullewa";
$areanames{en}->{618997000} = "Nabawa";
$areanames{en}->{618997001} = "Nangetty";
$areanames{en}->{618997002} = "Northampton";
$areanames{en}->{618997003} = "Northern\ Gully";
$areanames{en}->{618997004} = "Paynes\ Find";
$areanames{en}->{618997005} = "Perenjori";
$areanames{en}->{618997006} = "Perenjori\ East";
$areanames{en}->{618997007} = "Pindar\ South";
$areanames{en}->{618997008} = "Tenindewa";
$areanames{en}->{618997009} = "Three\ Springs";
$areanames{en}->{618997010} = "Upper\ Gascoyne";
$areanames{en}->{618997011} = "Walkaway";
$areanames{en}->{618997012} = "Warradarge";
$areanames{en}->{618997013} = "Wiluna";
$areanames{en}->{618997014} = "Yalgoo";
$areanames{en}->{618997015} = "Yallalong";
$areanames{en}->{618997016} = "Yandanooka";
$areanames{en}->{618997017} = "Yaringa";
$areanames{en}->{618997018} = "Yuna";
$areanames{en}->{618997019} = "Yuna\ East";
$areanames{en}->{618997020} = "Ajana";
$areanames{en}->{618997021} = "Arrowsmith";
$areanames{en}->{618997022} = "Balla";
$areanames{en}->{618997023} = "Carnamah";
$areanames{en}->{618997024} = "Carnamah\ West";
$areanames{en}->{618997025} = "Carnarvon";
$areanames{en}->{618997026} = "Coorow";
$areanames{en}->{618997027} = "Coorow\ West";
$areanames{en}->{618997028} = "Cue";
$areanames{en}->{618997029} = "Denham";
$areanames{en}->{618997030} = "Dongara";
$areanames{en}->{618997031} = "Eneabba";
$areanames{en}->{618997032} = "Eneabba\ North";
$areanames{en}->{618997033} = "Eneabba\ South";
$areanames{en}->{618997034} = "Exmouth";
$areanames{en}->{618997035} = "Geraldton";
$areanames{en}->{618997036} = "Guranu";
$areanames{en}->{618997037} = "Gutha\ West";
$areanames{en}->{618997038} = "Howatharra";
$areanames{en}->{618997039} = "Kalbarri";
$areanames{en}->{618997040} = "Lake\ Mason";
$areanames{en}->{618997041} = "Latham";
$areanames{en}->{618997042} = "Leeman";
$areanames{en}->{618997043} = "Lynton";
$areanames{en}->{618997044} = "Marchagee";
$areanames{en}->{618997045} = "Meekatharra";
$areanames{en}->{618997046} = "Mendel";
$areanames{en}->{618997047} = "Mingenew";
$areanames{en}->{618997048} = "Morawa";
$areanames{en}->{618997049} = "Mount\ George";
$areanames{en}->{61899705} = "Geraldton";
$areanames{en}->{61899706} = "Geraldton";
$areanames{en}->{61899707} = "Geraldton";
$areanames{en}->{61899708} = "Geraldton";
$areanames{en}->{61899709} = "Geraldton";
$areanames{en}->{6189971} = "Morawa";
$areanames{en}->{61899718} = "Perenjori";
$areanames{en}->{61899719} = "Perenjori\ East";
$areanames{en}->{61899720} = "Gutha\ West";
$areanames{en}->{61899721} = "Gutha\ West";
$areanames{en}->{61899722} = "Gutha\ West";
$areanames{en}->{61899723} = "Gutha\ West";
$areanames{en}->{61899724} = "Yandanooka";
$areanames{en}->{61899725} = "Yandanooka";
$areanames{en}->{61899726} = "Yandanooka";
$areanames{en}->{61899727} = "Guranu";
$areanames{en}->{61899728} = "Guranu";
$areanames{en}->{61899729} = "Perenjori";
$areanames{en}->{61899730} = "Perenjori";
$areanames{en}->{61899731} = "Perenjori";
$areanames{en}->{61899732} = "Perenjori\ East";
$areanames{en}->{61899733} = "Perenjori\ East";
$areanames{en}->{61899734} = "Perenjori\ East";
$areanames{en}->{61899735} = "Perenjori";
$areanames{en}->{61899736} = "Latham";
$areanames{en}->{61899737} = "Latham";
$areanames{en}->{618997380} = "Mount\ Magnet";
$areanames{en}->{618997381} = "Mullewa";
$areanames{en}->{618997382} = "Nabawa";
$areanames{en}->{618997383} = "Nangetty";
$areanames{en}->{618997384} = "Northampton";
$areanames{en}->{618997385} = "Northern\ Gully";
$areanames{en}->{618997386} = "Perenjori";
$areanames{en}->{618997387} = "Perenjori\ East";
$areanames{en}->{618997388} = "Pindar\ South";
$areanames{en}->{618997389} = "Tenindewa";
$areanames{en}->{618997390} = "Three\ Springs";
$areanames{en}->{618997391} = "Upper\ Gascoyne";
$areanames{en}->{618997392} = "Walkaway";
$areanames{en}->{618997393} = "Warradarge";
$areanames{en}->{618997394} = "Wiluna";
$areanames{en}->{618997395} = "Yalgoo";
$areanames{en}->{618997396} = "Yallalong";
$areanames{en}->{618997397} = "Yandanooka";
$areanames{en}->{618997398} = "Yaringa";
$areanames{en}->{618997399} = "Yuna";
$areanames{en}->{618997400} = "Yuna\ East";
$areanames{en}->{61899741} = "Exmouth";
$areanames{en}->{61899750} = "Dongara";
$areanames{en}->{61899769} = "Mount\ Magnet";
$areanames{en}->{61899780} = "Mount\ George";
$areanames{en}->{61899800} = "Meekatharra";
$areanames{en}->{61899801} = "Meekatharra";
$areanames{en}->{61899802} = "Meekatharra";
$areanames{en}->{61899803} = "Meekatharra";
$areanames{en}->{61899804} = "Geraldton";
$areanames{en}->{61899806} = "Wiluna";
$areanames{en}->{61899807} = "Wiluna";
$areanames{en}->{61899808} = "Yalgoo";
$areanames{en}->{61899809} = "Yalgoo";
$areanames{en}->{61899810} = "Meekatharra";
$areanames{en}->{61899811} = "Meekatharra";
$areanames{en}->{61899812} = "Mount\ George";
$areanames{en}->{61899813} = "Mount\ George";
$areanames{en}->{61899814} = "Mount\ George";
$areanames{en}->{61899815} = "Lake\ Mason";
$areanames{en}->{61899816} = "Mount\ George";
$areanames{en}->{61899817} = "Wiluna";
$areanames{en}->{61899818} = "Wiluna";
$areanames{en}->{61899819} = "Mount\ George";
$areanames{en}->{61899820} = "Geraldton";
$areanames{en}->{61899821} = "Geraldton";
$areanames{en}->{61899822} = "Geraldton";
$areanames{en}->{61899823} = "Geraldton";
$areanames{en}->{61899824} = "Geraldton";
$areanames{en}->{6189983} = "Mount\ George";
$areanames{en}->{61899920} = "Arrowsmith";
$areanames{en}->{61899930} = "Tenindewa";
$areanames{en}->{61899931} = "Yalgoo";
$areanames{en}->{61899932} = "Yallalong";
$areanames{en}->{61899940} = "Morawa";
$areanames{en}->{61899941} = "Perenjori";
$areanames{en}->{61899942} = "Perenjori\ East";
$areanames{en}->{61899943} = "Yandanooka";
$areanames{en}->{61899944} = "Cue";
$areanames{en}->{61899945} = "Lake\ Mason";
$areanames{en}->{61899946} = "Mendel";
$areanames{en}->{61899947} = "Mount\ Magnet";
$areanames{en}->{61899948} = "Mullewa";
$areanames{en}->{61899949} = "Pindar\ South";
$areanames{en}->{61899950} = "Northern\ Gully";
$areanames{en}->{61899951} = "Walkaway";
$areanames{en}->{61899952} = "Yuna";
$areanames{en}->{61899953} = "Yuna\ East";
$areanames{en}->{61899954} = "Meekatharra";
$areanames{en}->{61899955} = "Mount\ George";
$areanames{en}->{61899956} = "Wiluna";
$areanames{en}->{61899957} = "Guranu";
$areanames{en}->{61899958} = "Gutha\ West";
$areanames{en}->{61899959} = "Latham";
$areanames{en}->{61899967} = "Northampton";
$areanames{en}->{61899968} = "Northampton";
$areanames{en}->{61899969} = "Northampton";
$areanames{en}->{61899970} = "Ajana";
$areanames{en}->{61899971} = "Balla";
$areanames{en}->{61899972} = "Dongara";
$areanames{en}->{61899973} = "Geraldton";
$areanames{en}->{61899974} = "Howatharra";
$areanames{en}->{61899975} = "Kalbarri";
$areanames{en}->{61899976} = "Lynton";
$areanames{en}->{61899977} = "Mingenew";
$areanames{en}->{61899978} = "Nabawa";
$areanames{en}->{61899979} = "Nangetty";
$areanames{en}->{61899980} = "Eneabba\ South";
$areanames{en}->{61899981} = "Leeman";
$areanames{en}->{61899982} = "Marchagee";
$areanames{en}->{61899983} = "Three\ Springs";
$areanames{en}->{61899984} = "Warradarge";
$areanames{en}->{61899985} = "Carnarvon";
$areanames{en}->{61899986} = "Denham";
$areanames{en}->{61899987} = "Exmouth";
$areanames{en}->{61899988} = "Upper\ Gascoyne";
$areanames{en}->{61899989} = "Yaringa";
$areanames{en}->{61899990} = "Geraldton";
$areanames{en}->{61899991} = "Geraldton";
$areanames{en}->{61899992} = "Geraldton";
$areanames{en}->{61899993} = "Geraldton";
$areanames{en}->{61899994} = "Carnamah";
$areanames{en}->{61899995} = "Carnamah\ West";
$areanames{en}->{61899996} = "Coorow";
$areanames{en}->{61899997} = "Coorow\ West";
$areanames{en}->{61899998} = "Eneabba";
$areanames{en}->{61899999} = "Eneabba\ North";

    sub new {
      my $class = shift;
      my $number = shift;
      $number =~ s/(^\+61|\D)//g;
      my $self = bless({ number => $number, formatters => $formatters, validators => $validators, areanames => \%areanames}, $class);
      return $self if ($self->is_valid());
      $number =~ s/^(?:0|(183[12]))//;
      $self = bless({ number => $number, formatters => $formatters, validators => $validators, areanames => \%areanames}, $class);
      return $self->is_valid() ? $self : undef;
    }
1;