# automatically generated file, don't edit



# Copyright 2011 David Cantrell, derived from data from libphonenumber
# http://code.google.com/p/libphonenumber/
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
package Number::Phone::StubCountry::FR;
use base qw(Number::Phone::StubCountry);

use strict;
use warnings;
use utf8;
our $VERSION = 1.20200904144532;

my $formatters = [
                {
                  'format' => '$1',
                  'intl_format' => 'NA',
                  'leading_digits' => '10',
                  'pattern' => '(\\d{4})'
                },
                {
                  'format' => '$1 $2',
                  'intl_format' => 'NA',
                  'leading_digits' => '1',
                  'pattern' => '(\\d{3})(\\d{3})'
                },
                {
                  'format' => '$1 $2 $3 $4',
                  'leading_digits' => '8',
                  'national_rule' => '0 $1',
                  'pattern' => '(\\d{3})(\\d{2})(\\d{2})(\\d{2})'
                },
                {
                  'format' => '$1 $2 $3 $4 $5',
                  'leading_digits' => '[1-79]',
                  'national_rule' => '0$1',
                  'pattern' => '(\\d)(\\d{2})(\\d{2})(\\d{2})(\\d{2})'
                }
              ];

my $validators = {
                'fixed_line' => '
          (?:
            [1-35]\\d|
            4[1-9]
          )\\d{7}
        ',
                'geographic' => '
          (?:
            [1-35]\\d|
            4[1-9]
          )\\d{7}
        ',
                'mobile' => '
          700\\d{6}|
          (?:
            6\\d|
            7[3-9]
          )\\d{7}
        ',
                'pager' => '',
                'personal_number' => '',
                'specialrate' => '(
          8(?:
            1[01]|
            2[0156]|
            84
          )\\d{6}
        )|(
          836(?:
            0[0-36-9]|
            [1-9]\\d
          )\\d{4}|
          8(?:
            1[2-9]|
            2[2-47-9]|
            3[0-57-9]|
            [569]\\d|
            8[0-35-9]
          )\\d{6}
        )|(80[6-9]\\d{6})',
                'toll_free' => '80[0-5]\\d{6}',
                'voip' => '9\\d{8}'
              };
my %areanames = ();
$areanames{en}->{33105} = "Ile\ de\ France";
$areanames{en}->{331241} = "Ile\ de\ France";
$areanames{en}->{331242} = "Ile\ de\ France";
$areanames{en}->{3313005} = "Coignières";
$areanames{en}->{3313006} = "Poissy";
$areanames{en}->{3313007} = "Plaisir";
$areanames{en}->{3313008} = "Marly\-le\-Roi";
$areanames{en}->{3313009} = "Chatou";
$areanames{en}->{3313010} = "Cormeilles\-en\-Parisis";
$areanames{en}->{3313011} = "Gonesse";
$areanames{en}->{3313013} = "Trappes";
$areanames{en}->{3313015} = "Montesson";
$areanames{en}->{3313016} = "Trappes";
$areanames{en}->{3313017} = "Cergy";
$areanames{en}->{3313018} = "Goussainville";
$areanames{en}->{3313021} = "Versailles";
$areanames{en}->{3313022} = "Les\ Mureaux";
$areanames{en}->{3313023} = "Bois\-d\'Arcy";
$areanames{en}->{3313024} = "Viroflay";
$areanames{en}->{3313025} = "Argenteuil";
$areanames{en}->{3313026} = "Herblay";
$areanames{en}->{3313028} = "Chambly";
$areanames{en}->{3313029} = "Luzarches";
$areanames{en}->{3313030} = "Cergy";
$areanames{en}->{3313031} = "Cergy";
$areanames{en}->{3313032} = "Cergy";
$areanames{en}->{3313033} = "Mantes\-la\-Jolie";
$areanames{en}->{3313034} = "Chambly";
$areanames{en}->{3313035} = "Viarmes";
$areanames{en}->{3313036} = "Auvers\-sur\-Oise";
$areanames{en}->{3313037} = "Saint\-Ouen\-l\'Aumône";
$areanames{en}->{3313038} = "Cergy";
$areanames{en}->{3313039} = "Marines";
$areanames{en}->{3313040} = "Taverny";
$areanames{en}->{3313041} = "Rambouillet";
$areanames{en}->{3313042} = "Rosny\-sur\-Seine";
$areanames{en}->{3313043} = "Montigny\-le\-Bretonneux";
$areanames{en}->{3313044} = "Montigny\-le\-Bretonneux";
$areanames{en}->{3313045} = "Saint\-Cyr\-l\'École";
$areanames{en}->{3313046} = "Houdan";
$areanames{en}->{3313047} = "Saint\-Rémy\-lès\-Chevreuse";
$areanames{en}->{3313048} = "Montigny\-le\-Bretonneux";
$areanames{en}->{3313049} = "Coignières";
$areanames{en}->{3313050} = "Maurepas";
$areanames{en}->{3313051} = "Trappes";
$areanames{en}->{3313052} = "Chevreuse";
$areanames{en}->{3313053} = "Chatou";
$areanames{en}->{3313054} = "Plaisir";
$areanames{en}->{3313055} = "Plaisir";
$areanames{en}->{3313056} = "Villepreux";
$areanames{en}->{3313057} = "Montigny\-le\-Bretonneux";
$areanames{en}->{3313058} = "Saint\-Cyr\-l\'École";
$areanames{en}->{3313059} = "Houdan";
$areanames{en}->{3313060} = "Montigny\-le\-Bretonneux";
$areanames{en}->{3313061} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3313062} = "Trappes";
$areanames{en}->{3313063} = "Mantes\-la\-Jolie";
$areanames{en}->{3313064} = "Montigny\-le\-Bretonneux";
$areanames{en}->{3313065} = "Poissy";
$areanames{en}->{3313066} = "Trappes";
$areanames{en}->{3313068} = "Élancourt";
$areanames{en}->{3313069} = "Trappes";
$areanames{en}->{3313070} = "Vélizy\-Villacoublay";
$areanames{en}->{3313071} = "Chatou";
$areanames{en}->{3313072} = "Franconville";
$areanames{en}->{3313073} = "Cergy";
$areanames{en}->{3313074} = "Poissy";
$areanames{en}->{3313075} = "Cergy";
$areanames{en}->{3313076} = "Argenteuil";
$areanames{en}->{3313079} = "Plaisir";
$areanames{en}->{3313080} = "Saint\-Nom\-la\-Bretèche";
$areanames{en}->{3313081} = "Plaisir";
$areanames{en}->{3313082} = "La\ Celle\ Saint\ Cloud";
$areanames{en}->{3313083} = "Versailles";
$areanames{en}->{3313086} = "Sartrouville";
$areanames{en}->{3313087} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3313088} = "Rambouillet";
$areanames{en}->{3313090} = "Maule";
$areanames{en}->{3313092} = "Mantes\-la\-Ville";
$areanames{en}->{3313094} = "Mantes\-la\-Jolie";
$areanames{en}->{3313095} = "Aubergenville";
$areanames{en}->{3313096} = "Montigny\-le\-Bretonneux";
$areanames{en}->{3313098} = "Mantes\-la\-Jolie";
$areanames{en}->{3313099} = "Les\ Mureaux";
$areanames{en}->{3313402} = "Saint\-Ouen\-l\'Aumône";
$areanames{en}->{3313404} = "Sarcelles";
$areanames{en}->{3313405} = "Deuil\-la\-Barre";
$areanames{en}->{3313407} = "Gonesse";
$areanames{en}->{3313408} = "L\'Isle\ Adam";
$areanames{en}->{3313409} = "Viarmes";
$areanames{en}->{3313410} = "Argenteuil";
$areanames{en}->{3313411} = "Argenteuil";
$areanames{en}->{3313412} = "Enghien\-les\-Bains";
$areanames{en}->{3313413} = "Franconville";
$areanames{en}->{3313414} = "Franconville";
$areanames{en}->{3313415} = "Ermont";
$areanames{en}->{3313416} = "Eaubonne";
$areanames{en}->{3313417} = "Saint\-Gratien";
$areanames{en}->{3313418} = "Taverny";
$areanames{en}->{3313419} = "Sarcelles";
$areanames{en}->{3313420} = "Cergy";
$areanames{en}->{3313421} = "Saint\-Ouen\-l\'Aumône";
$areanames{en}->{3313422} = "Cergy";
$areanames{en}->{3313424} = "Cergy";
$areanames{en}->{3313425} = "Cergy";
$areanames{en}->{3313427} = "Eaubonne";
$areanames{en}->{3313428} = "Deuil\-la\-Barre";
$areanames{en}->{3313429} = "Roissy\-en\-France";
$areanames{en}->{3313430} = "Saint\-Ouen\-l\'Aumône";
$areanames{en}->{3313431} = "Fosses";
$areanames{en}->{3313432} = "Cergy";
$areanames{en}->{3313434} = "Argenteuil";
$areanames{en}->{3313435} = "Cergy";
$areanames{en}->{3313437} = "Ermont";
$areanames{en}->{3313438} = "Sarcelles";
$areanames{en}->{3313440} = "Saint\-Ouen\-l\'Aumône";
$areanames{en}->{3313441} = "Cergy";
$areanames{en}->{3313442} = "Boissy\-l\'Aillerie";
$areanames{en}->{3313443} = "Jouy\-le\-Moutier";
$areanames{en}->{3313444} = "Franconville";
$areanames{en}->{3313445} = "Garges\-lès\-Gonesse";
$areanames{en}->{3313446} = "Cergy";
$areanames{en}->{3313448} = "Auvers\-sur\-Oise";
$areanames{en}->{3313450} = "Herblay";
$areanames{en}->{3313451} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3313452} = "Montigny\-le\-Bretonneux";
$areanames{en}->{3313453} = "Gonesse";
$areanames{en}->{3313457} = "Rambouillet";
$areanames{en}->{3313459} = "Plaisir";
$areanames{en}->{3313460} = "Fontenay\-le\-Fleury";
$areanames{en}->{3313461} = "Coignières";
$areanames{en}->{3313462} = "Noisy\-le\-Roi";
$areanames{en}->{3313464} = "Saint\-Ouen\-l\'Aumône";
$areanames{en}->{3313465} = "Vélizy\-Villacoublay";
$areanames{en}->{3313467} = "Magny\-en\-Vexin";
$areanames{en}->{3313468} = "Louvres";
$areanames{en}->{3313469} = "L\'Isle\ Adam";
$areanames{en}->{3313470} = "Beaumont\-sur\-Oise";
$areanames{en}->{3313471} = "Luzarches";
$areanames{en}->{3313472} = "Fosses";
$areanames{en}->{3313473} = "Parmain";
$areanames{en}->{3313474} = "Les\ Mureaux";
$areanames{en}->{3313475} = "Ecquevilly";
$areanames{en}->{3313477} = "Mantes\-la\-Jolie";
$areanames{en}->{3313479} = "Porcheville";
$areanames{en}->{3313480} = "Chatou";
$areanames{en}->{3313481} = "Plaisir";
$areanames{en}->{3313482} = "Trappes";
$areanames{en}->{3313483} = "Rambouillet";
$areanames{en}->{3313484} = "Le\ Perray\ en\ Yvelines";
$areanames{en}->{3313485} = "Rambouillet";
$areanames{en}->{3313486} = "Montfort\-l\'Amaury";
$areanames{en}->{3313489} = "Beynes";
$areanames{en}->{3313490} = "Conflans\-Sainte\-Honorine";
$areanames{en}->{3313492} = "Les\ Mureaux";
$areanames{en}->{3313493} = "Maisons\-Laffitte";
$areanames{en}->{3313902} = "Versailles";
$areanames{en}->{3313904} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3313907} = "Versailles";
$areanames{en}->{3313908} = "Orgeval";
$areanames{en}->{3313909} = "Saint\-Ouen\-l\'Aumône";
$areanames{en}->{3313911} = "Achères";
$areanames{en}->{3313912} = "Maisons\-Laffitte";
$areanames{en}->{3313913} = "Sartrouville";
$areanames{en}->{3313914} = "Sartrouville";
$areanames{en}->{3313915} = "Sartrouville";
$areanames{en}->{3313916} = "Marly\-le\-Roi";
$areanames{en}->{3313917} = "Marly\-le\-Roi";
$areanames{en}->{3313918} = "La\ Celle\ Saint\ Cloud";
$areanames{en}->{3313919} = "Conflans\-Sainte\-Honorine";
$areanames{en}->{3313920} = "Versailles";
$areanames{en}->{3313921} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3313922} = "Achères";
$areanames{en}->{3313923} = "Le\ Chesnay";
$areanames{en}->{3313924} = "Versailles";
$areanames{en}->{3313925} = "Versailles";
$areanames{en}->{3313927} = "Triel\-sur\-Seine";
$areanames{en}->{3313928} = "Verneuil\-sur\-Seine";
$areanames{en}->{3313930} = "Montigny\-le\-Bretonneux";
$areanames{en}->{3313931} = "Herblay";
$areanames{en}->{3313932} = "Taverny";
$areanames{en}->{3313933} = "Sarcelles";
$areanames{en}->{3313934} = "Enghien\-les\-Bains";
$areanames{en}->{3313935} = "Domont";
$areanames{en}->{3313937} = "Chambly";
$areanames{en}->{3313943} = "Le\ Chesnay";
$areanames{en}->{3313944} = "Montigny\-le\-Bretonneux";
$areanames{en}->{3313946} = "Vélizy\-Villacoublay";
$areanames{en}->{3313947} = "Argenteuil";
$areanames{en}->{3313949} = "Versailles";
$areanames{en}->{3313950} = "Versailles";
$areanames{en}->{3313951} = "Versailles";
$areanames{en}->{3313952} = "Chatou";
$areanames{en}->{3313953} = "Versailles";
$areanames{en}->{3313954} = "Le\ Chesnay";
$areanames{en}->{3313955} = "Le\ Chesnay";
$areanames{en}->{3313956} = "Buc";
$areanames{en}->{3313957} = "Sartrouville";
$areanames{en}->{3313958} = "Marly\-le\-Roi";
$areanames{en}->{3313959} = "Eaubonne";
$areanames{en}->{3313960} = "Taverny";
$areanames{en}->{3313961} = "Argenteuil";
$areanames{en}->{3313962} = "Maisons\-Laffitte";
$areanames{en}->{3313963} = "Le\ Chesnay";
$areanames{en}->{3313964} = "Montmorency";
$areanames{en}->{3313965} = "Poissy";
$areanames{en}->{3313966} = "Le\ Chesnay";
$areanames{en}->{3313967} = "Versailles";
$areanames{en}->{3313968} = "Houilles";
$areanames{en}->{3313969} = "La\ Celle\ Saint\ Cloud";
$areanames{en}->{3313970} = "Triel\-sur\-Seine";
$areanames{en}->{3313971} = "Verneuil\-sur\-Seine";
$areanames{en}->{3313972} = "Conflans\-Sainte\-Honorine";
$areanames{en}->{3313973} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3313974} = "Andrésy";
$areanames{en}->{3313975} = "Orgeval";
$areanames{en}->{3313976} = "Le\ Vésinet";
$areanames{en}->{3313978} = "Cormeilles\-en\-Parisis";
$areanames{en}->{3313979} = "Poissy";
$areanames{en}->{3313980} = "Argenteuil";
$areanames{en}->{3313981} = "Argenteuil";
$areanames{en}->{3313982} = "Argenteuil";
$areanames{en}->{3313983} = "Deuil\-la\-Barre";
$areanames{en}->{3313984} = "Deuil\-la\-Barre";
$areanames{en}->{3313985} = "Gonesse";
$areanames{en}->{3313986} = "Garges\-lès\-Gonesse";
$areanames{en}->{3313987} = "Gonesse";
$areanames{en}->{3313988} = "Goussainville";
$areanames{en}->{3313989} = "Saint\-Gratien";
$areanames{en}->{3313990} = "Sarcelles";
$areanames{en}->{3313991} = "Domont";
$areanames{en}->{3313992} = "Sarcelles";
$areanames{en}->{3313993} = "Garges\-lès\-Gonesse";
$areanames{en}->{3313994} = "Sarcelles";
$areanames{en}->{3313995} = "Taverny";
$areanames{en}->{3313996} = "Argenteuil";
$areanames{en}->{3313997} = "Herblay";
$areanames{en}->{3313998} = "Argenteuil";
$areanames{en}->{331400} = "Paris";
$areanames{en}->{3314010} = "Saint\-Ouen";
$areanames{en}->{3314011} = "Saint\-Ouen";
$areanames{en}->{3314012} = "Saint\-Ouen";
$areanames{en}->{3314013} = "Paris";
$areanames{en}->{3314015} = "Paris";
$areanames{en}->{3314016} = "Paris";
$areanames{en}->{3314017} = "Paris";
$areanames{en}->{3314018} = "Paris";
$areanames{en}->{3314019} = "Paris";
$areanames{en}->{331402} = "Paris";
$areanames{en}->{331403} = "Paris";
$areanames{en}->{331404} = "Paris";
$areanames{en}->{331405} = "Paris";
$areanames{en}->{331406} = "Paris";
$areanames{en}->{331407} = "Paris";
$areanames{en}->{3314080} = "Asnières\-sur\-Seine";
$areanames{en}->{3314082} = "Paris";
$areanames{en}->{3314083} = "Clamart";
$areanames{en}->{3314084} = "Montrouge";
$areanames{en}->{3314085} = "Gennevilliers";
$areanames{en}->{3314086} = "Asnières\-sur\-Seine";
$areanames{en}->{3314087} = "Clichy";
$areanames{en}->{3314088} = "Neuilly\-sur\-Seine";
$areanames{en}->{3314089} = "Levallois\-Perret";
$areanames{en}->{3314090} = "Puteaux";
$areanames{en}->{3314091} = "Sceaux";
$areanames{en}->{3314092} = "Montrouge";
$areanames{en}->{3314093} = "Issy\-les\-Moulineaux";
$areanames{en}->{3314094} = "Clamart";
$areanames{en}->{3314095} = "Issy\-les\-Moulineaux";
$areanames{en}->{3314096} = "Antony";
$areanames{en}->{3314099} = "Suresnes";
$areanames{en}->{3314105} = "Levallois\-Perret";
$areanames{en}->{3314106} = "Clichy";
$areanames{en}->{3314108} = "Issy\-les\-Moulineaux";
$areanames{en}->{3314109} = "Issy\-les\-Moulineaux";
$areanames{en}->{3314110} = "Boulogne\-Billancourt";
$areanames{en}->{3314111} = "Asnières\-sur\-Seine";
$areanames{en}->{3314112} = "Saint\-Cloud";
$areanames{en}->{3314113} = "Sceaux";
$areanames{en}->{3314114} = "Meudon";
$areanames{en}->{3314115} = "Chaville";
$areanames{en}->{3314116} = "Courbevoie";
$areanames{en}->{3314117} = "Montrouge";
$areanames{en}->{3314118} = "Suresnes";
$areanames{en}->{3314119} = "Colombes";
$areanames{en}->{3314120} = "Nanterre";
$areanames{en}->{3314121} = "Gennevilliers";
$areanames{en}->{3314122} = "Boulogne\-Billancourt";
$areanames{en}->{3314124} = "Arcueil";
$areanames{en}->{3314127} = "Clichy";
$areanames{en}->{3314129} = "Rueil\-Malmaison";
$areanames{en}->{3314131} = "Boulogne\-Billancourt";
$areanames{en}->{3314132} = "Asnières\-sur\-Seine";
$areanames{en}->{3314134} = "Levallois\-Perret";
$areanames{en}->{3314137} = "Nanterre";
$areanames{en}->{3314138} = "Suresnes";
$areanames{en}->{3314139} = "Rueil\-Malmaison";
$areanames{en}->{3314140} = "Clichy";
$areanames{en}->{3314141} = "Boulogne\-Billancourt";
$areanames{en}->{3314142} = "Rueil\-Malmaison";
$areanames{en}->{3314143} = "Neuilly\-sur\-Seine";
$areanames{en}->{3314144} = "Suresnes";
$areanames{en}->{3314146} = "Issy\-les\-Moulineaux";
$areanames{en}->{3314147} = "Gennevilliers";
$areanames{en}->{3314150} = "Drancy";
$areanames{en}->{3314152} = "Sevran";
$areanames{en}->{3314153} = "Gagny";
$areanames{en}->{3314155} = "Bondy";
$areanames{en}->{3314157} = "Aubervilliers";
$areanames{en}->{3314158} = "Montreuil";
$areanames{en}->{3314160} = "Drancy";
$areanames{en}->{3314161} = "Aubervilliers";
$areanames{en}->{3314170} = "Montfermeil";
$areanames{en}->{3314171} = "Pantin";
$areanames{en}->{3314173} = "Rungis\ Complexe";
$areanames{en}->{3314174} = "Vincennes";
$areanames{en}->{3314177} = "Champigny\-sur\-Marne";
$areanames{en}->{3314178} = "Créteil";
$areanames{en}->{3314179} = "Maisons\-Alfort";
$areanames{en}->{3314180} = "Rungis\ Complexe";
$areanames{en}->{3314181} = "Saint\-Maur\-des\-Fossés";
$areanames{en}->{3314183} = "Pantin";
$areanames{en}->{3314187} = "Bourg\-la\-Reine";
$areanames{en}->{3314190} = "Issy\-les\-Moulineaux";
$areanames{en}->{3314192} = "Neuilly\-sur\-Seine";
$areanames{en}->{3314193} = "Vincennes";
$areanames{en}->{3314194} = "Créteil";
$areanames{en}->{3314195} = "Fontenay\-sous\-Bois";
$areanames{en}->{331420} = "Paris";
$areanames{en}->{3314204} = "Suresnes";
$areanames{en}->{3314207} = "Créteil";
$areanames{en}->{3314211} = "Villejuif";
$areanames{en}->{3314212} = "Paris";
$areanames{en}->{3314215} = "Paris";
$areanames{en}->{3314216} = "Paris";
$areanames{en}->{3314217} = "Paris";
$areanames{en}->{3314218} = "Paris";
$areanames{en}->{3314219} = "Paris";
$areanames{en}->{331422} = "Paris";
$areanames{en}->{3314230} = "Paris";
$areanames{en}->{3314233} = "Paris";
$areanames{en}->{3314235} = "Saint\-Denis";
$areanames{en}->{3314236} = "Paris";
$areanames{en}->{3314237} = "Antony";
$areanames{en}->{3314238} = "Paris";
$areanames{en}->{3314239} = "Paris";
$areanames{en}->{3314240} = "Paris";
$areanames{en}->{3314241} = "Paris";
$areanames{en}->{3314242} = "Colombes";
$areanames{en}->{3314243} = "Saint\-Denis";
$areanames{en}->{3314245} = "Paris";
$areanames{en}->{3314246} = "Paris";
$areanames{en}->{3314247} = "Paris";
$areanames{en}->{3314249} = "Paris";
$areanames{en}->{331425} = "Paris";
$areanames{en}->{3314253} = "Montrouge";
$areanames{en}->{331426} = "Paris";
$areanames{en}->{3314270} = "Clichy";
$areanames{en}->{3314271} = "Paris";
$areanames{en}->{3314272} = "Paris";
$areanames{en}->{3314273} = "Paris";
$areanames{en}->{3314274} = "Paris";
$areanames{en}->{3314276} = "Paris";
$areanames{en}->{3314277} = "Paris";
$areanames{en}->{3314278} = "Paris";
$areanames{en}->{3314279} = "Paris";
$areanames{en}->{331428} = "Paris";
$areanames{en}->{3314283} = "Saint\-Maur\-des\-Fossés";
$areanames{en}->{3314287} = "Montreuil";
$areanames{en}->{331429} = "Paris";
$areanames{en}->{3314291} = "Nanterre";
$areanames{en}->{3314295} = "Boulogne\-Billancourt";
$areanames{en}->{3314300} = "Neuilly\-Plaisance";
$areanames{en}->{3314301} = "Gagny";
$areanames{en}->{3314302} = "Gagny";
$areanames{en}->{3314303} = "Noisy\-le\-Grand";
$areanames{en}->{3314304} = "Noisy\-le\-Grand";
$areanames{en}->{3314305} = "Noisy\-le\-Grand";
$areanames{en}->{3314306} = "Paris";
$areanames{en}->{3314307} = "Paris";
$areanames{en}->{3314308} = "Neuilly\-sur\-Marne";
$areanames{en}->{3314309} = "Neuilly\-sur\-Marne";
$areanames{en}->{3314310} = "Sevran";
$areanames{en}->{3314311} = "La\ Courneuve";
$areanames{en}->{3314312} = "Paris";
$areanames{en}->{3314314} = "Paris";
$areanames{en}->{3314315} = "Paris";
$areanames{en}->{3314318} = "Paris";
$areanames{en}->{3314320} = "Paris";
$areanames{en}->{3314321} = "Paris";
$areanames{en}->{3314322} = "Paris";
$areanames{en}->{3314324} = "Le\ Perreux\ sur\ Marne";
$areanames{en}->{3314325} = "Paris";
$areanames{en}->{3314326} = "Paris";
$areanames{en}->{3314327} = "Paris";
$areanames{en}->{3314328} = "Vincennes";
$areanames{en}->{3314329} = "Paris";
$areanames{en}->{3314330} = "Livry\-Gargan";
$areanames{en}->{3314331} = "Paris";
$areanames{en}->{3314332} = "Montfermeil";
$areanames{en}->{3314333} = "Courbevoie";
$areanames{en}->{3314334} = "Courbevoie";
$areanames{en}->{3314335} = "Paris";
$areanames{en}->{3314336} = "Paris";
$areanames{en}->{3314337} = "Paris";
$areanames{en}->{3314338} = "Paris";
$areanames{en}->{3314339} = "Créteil";
$areanames{en}->{331434} = "Paris";
$areanames{en}->{331435} = "Paris";
$areanames{en}->{3314350} = "Sceaux";
$areanames{en}->{3314351} = "Montfermeil";
$areanames{en}->{3314352} = "Aubervilliers";
$areanames{en}->{3314353} = "Alfortville";
$areanames{en}->{3314360} = "Bagnolet";
$areanames{en}->{3314361} = "Paris";
$areanames{en}->{3314362} = "Bagnolet";
$areanames{en}->{3314363} = "Bagnolet";
$areanames{en}->{3314364} = "Paris";
$areanames{en}->{3314365} = "Vincennes";
$areanames{en}->{3314366} = "Paris";
$areanames{en}->{3314367} = "Paris";
$areanames{en}->{3314368} = "Charenton\-le\-Pont";
$areanames{en}->{3314370} = "Paris";
$areanames{en}->{3314371} = "Paris";
$areanames{en}->{3314372} = "Paris";
$areanames{en}->{3314373} = "Paris";
$areanames{en}->{3314374} = "Vincennes";
$areanames{en}->{3314375} = "Alfortville";
$areanames{en}->{3314376} = "Maisons\-Alfort";
$areanames{en}->{3314377} = "Créteil";
$areanames{en}->{3314378} = "Maisons\-Alfort";
$areanames{en}->{3314379} = "Paris";
$areanames{en}->{3314380} = "Paris";
$areanames{en}->{3314381} = "Gagny";
$areanames{en}->{3314382} = "Villeneuve\-Saint\-Georges";
$areanames{en}->{3314383} = "Sevran";
$areanames{en}->{3314384} = "Sevran";
$areanames{en}->{3314385} = "Sevran";
$areanames{en}->{3314386} = "Villeneuve\-Saint\-Georges";
$areanames{en}->{3314387} = "Paris";
$areanames{en}->{3314388} = "Montfermeil";
$areanames{en}->{3314389} = "Villeneuve\-Saint\-Georges";
$areanames{en}->{3314390} = "Ivry\-sur\-Seine";
$areanames{en}->{3314391} = "Vitry\-sur\-Seine";
$areanames{en}->{3314394} = "Fontenay\-sous\-Bois";
$areanames{en}->{3314396} = "Maisons\-Alfort";
$areanames{en}->{3314397} = "Saint\-Maur\-des\-Fossés";
$areanames{en}->{3314398} = "Vincennes";
$areanames{en}->{3314399} = "Créteil";
$areanames{en}->{33144} = "Paris";
$areanames{en}->{3314400} = "Ile\ de\ France";
$areanames{en}->{3314402} = "Bobigny";
$areanames{en}->{3314403} = "Ile\ de\ France";
$areanames{en}->{3314404} = "Bobigny";
$areanames{en}->{3314422} = "Nanterre";
$areanames{en}->{3314433} = "Créteil";
$areanames{en}->{3314445} = "Nanterre";
$areanames{en}->{3314447} = "Bobigny";
$areanames{en}->{3314448} = "Boulogne\-Billancourt";
$areanames{en}->{3314460} = "Ile\ de\ France";
$areanames{en}->{3314466} = "Ile\ de\ France";
$areanames{en}->{3314498} = "Créteil";
$areanames{en}->{3314499} = "Ile\ de\ France";
$areanames{en}->{331450} = "Paris";
$areanames{en}->{3314506} = "Suresnes";
$areanames{en}->{3314507} = "Meudon";
$areanames{en}->{3314509} = "Montfermeil";
$areanames{en}->{3314510} = "Boissy\-Saint\-Léger";
$areanames{en}->{3314511} = "Saint\-Maur\-des\-Fossés";
$areanames{en}->{3314512} = "Rungis\ Complexe";
$areanames{en}->{3314513} = "Bonneuil\-sur\-Marne";
$areanames{en}->{3314515} = "Ivry\-sur\-Seine";
$areanames{en}->{3314516} = "Champigny\-sur\-Marne";
$areanames{en}->{3314517} = "Créteil";
$areanames{en}->{3314518} = "Maisons\-Alfort";
$areanames{en}->{331452} = "Paris";
$areanames{en}->{3314521} = "Ivry\-sur\-Seine";
$areanames{en}->{3314528} = "Rosny\-Sous\-Bois";
$areanames{en}->{3314529} = "Issy\-les\-Moulineaux";
$areanames{en}->{331453} = "Paris";
$areanames{en}->{3314534} = "Meudon";
$areanames{en}->{3314536} = "Bagneux";
$areanames{en}->{3314537} = "Clamart";
$areanames{en}->{331454} = "Paris";
$areanames{en}->{3314546} = "Cachan";
$areanames{en}->{3314547} = "Cachan";
$areanames{en}->{331455} = "Paris";
$areanames{en}->{3314559} = "Créteil";
$areanames{en}->{3314560} = "Rungis\ Complexe";
$areanames{en}->{3314561} = "Paris";
$areanames{en}->{3314562} = "Paris";
$areanames{en}->{3314563} = "Paris";
$areanames{en}->{3314565} = "Paris";
$areanames{en}->{3314566} = "Paris";
$areanames{en}->{3314567} = "Paris";
$areanames{en}->{3314569} = "Boissy\-Saint\-Léger";
$areanames{en}->{331457} = "Paris";
$areanames{en}->{3314573} = "Vitry\-sur\-Seine";
$areanames{en}->{3314576} = "Chennevières\-sur\-Marne";
$areanames{en}->{331458} = "Paris";
$areanames{en}->{3314590} = "Sucy\-en\-Brie";
$areanames{en}->{3314591} = "Le\ Blanc\ Mesnil";
$areanames{en}->{3314592} = "Noisy\-le\-Grand";
$areanames{en}->{3314593} = "Chennevières\-sur\-Marne";
$areanames{en}->{3314594} = "Chennevières\-sur\-Marne";
$areanames{en}->{3314595} = "Limeil\-Brévannes";
$areanames{en}->{3314597} = "Villeneuve\-le\-Roi";
$areanames{en}->{3314598} = "Mandres\-les\-Roses";
$areanames{en}->{3314599} = "Villecresnes";
$areanames{en}->{3314601} = "Le\ Plessis\-Robinson";
$areanames{en}->{3314602} = "Saint\-Cloud";
$areanames{en}->{3314603} = "Boulogne\-Billancourt";
$areanames{en}->{3314604} = "Boulogne\-Billancourt";
$areanames{en}->{3314605} = "Boulogne\-Billancourt";
$areanames{en}->{3314606} = "Paris";
$areanames{en}->{3314607} = "Paris";
$areanames{en}->{3314608} = "Boulogne\-Billancourt";
$areanames{en}->{3314609} = "Boulogne\-Billancourt";
$areanames{en}->{3314610} = "Boulogne\-Billancourt";
$areanames{en}->{3314612} = "Montrouge";
$areanames{en}->{3314615} = "Fresnes";
$areanames{en}->{3314620} = "Boulogne\-Billancourt";
$areanames{en}->{3314621} = "Boulogne\-Billancourt";
$areanames{en}->{3314622} = "Paris";
$areanames{en}->{3314623} = "Meudon";
$areanames{en}->{3314624} = "Neuilly\-sur\-Seine";
$areanames{en}->{3314625} = "Suresnes";
$areanames{en}->{3314626} = "Meudon";
$areanames{en}->{3314627} = "Paris";
$areanames{en}->{3314628} = "Paris";
$areanames{en}->{3314630} = "Clamart";
$areanames{en}->{3314631} = "Clamart";
$areanames{en}->{3314632} = "Clamart";
$areanames{en}->{3314633} = "Paris";
$areanames{en}->{3314634} = "Paris";
$areanames{en}->{3314636} = "Paris";
$areanames{en}->{3314637} = "Neuilly\-sur\-Seine";
$areanames{en}->{3314638} = "Issy\-les\-Moulineaux";
$areanames{en}->{3314640} = "Neuilly\-sur\-Seine";
$areanames{en}->{3314642} = "Issy\-les\-Moulineaux";
$areanames{en}->{3314644} = "Issy\-les\-Moulineaux";
$areanames{en}->{3314645} = "Issy\-les\-Moulineaux";
$areanames{en}->{3314647} = "Paris";
$areanames{en}->{3314648} = "Issy\-les\-Moulineaux";
$areanames{en}->{3314649} = "Colombes";
$areanames{en}->{3314651} = "Paris";
$areanames{en}->{3314652} = "Colombes";
$areanames{en}->{3314654} = "Montrouge";
$areanames{en}->{3314655} = "Montrouge";
$areanames{en}->{3314656} = "Montrouge";
$areanames{en}->{3314657} = "Montrouge";
$areanames{en}->{3314658} = "Ivry\-sur\-Seine";
$areanames{en}->{3314659} = "Paris";
$areanames{en}->{3314660} = "Sceaux";
$areanames{en}->{3314661} = "Sceaux";
$areanames{en}->{3314662} = "Issy\-les\-Moulineaux";
$areanames{en}->{3314663} = "Cachan";
$areanames{en}->{3314664} = "Bagneux";
$areanames{en}->{3314665} = "Bagneux";
$areanames{en}->{3314666} = "Antony";
$areanames{en}->{3314667} = "Courbevoie";
$areanames{en}->{3314668} = "Antony";
$areanames{en}->{3314670} = "Ivry\-sur\-Seine";
$areanames{en}->{3314671} = "Ivry\-sur\-Seine";
$areanames{en}->{3314672} = "Ivry\-sur\-Seine";
$areanames{en}->{3314674} = "Antony";
$areanames{en}->{3314675} = "Rungis\ Complexe";
$areanames{en}->{3314677} = "Villejuif";
$areanames{en}->{3314678} = "Villejuif";
$areanames{en}->{3314680} = "Vitry\-sur\-Seine";
$areanames{en}->{3314681} = "Vitry\-sur\-Seine";
$areanames{en}->{3314682} = "Vitry\-sur\-Seine";
$areanames{en}->{3314683} = "Sceaux";
$areanames{en}->{3314684} = "Boulogne\-Billancourt";
$areanames{en}->{3314686} = "Rungis\ Complexe";
$areanames{en}->{3314687} = "Rungis\ Complexe";
$areanames{en}->{3314688} = "Asnières\-sur\-Seine";
$areanames{en}->{3314689} = "Antony";
$areanames{en}->{3314691} = "Courbevoie";
$areanames{en}->{3314694} = "Boulogne\-Billancourt";
$areanames{en}->{3314695} = "Nanterre";
$areanames{en}->{3314697} = "Suresnes";
$areanames{en}->{3314698} = "Puteaux";
$areanames{en}->{3314699} = "Boulogne\-Billancourt";
$areanames{en}->{3314700} = "Paris";
$areanames{en}->{3314701} = "Garches";
$areanames{en}->{3314702} = "Sceaux";
$areanames{en}->{3314703} = "Paris";
$areanames{en}->{3314704} = "Paris";
$areanames{en}->{3314705} = "Paris";
$areanames{en}->{3314706} = "Champigny\-sur\-Marne";
$areanames{en}->{3314707} = "Paris";
$areanames{en}->{3314708} = "Rueil\-Malmaison";
$areanames{en}->{3314709} = "Chaville";
$areanames{en}->{3314712} = "Boulogne\-Billancourt";
$areanames{en}->{3314714} = "Rueil\-Malmaison";
$areanames{en}->{3314715} = "Levallois\-Perret";
$areanames{en}->{3314716} = "Rueil\-Malmaison";
$areanames{en}->{3314717} = "Courbevoie";
$areanames{en}->{3314718} = "Vitry\-sur\-Seine";
$areanames{en}->{3314720} = "Paris";
$areanames{en}->{3314721} = "Nanterre";
$areanames{en}->{3314722} = "Neuilly\-sur\-Seine";
$areanames{en}->{3314723} = "Paris";
$areanames{en}->{3314724} = "Nanterre";
$areanames{en}->{3314725} = "Nanterre";
$areanames{en}->{3314726} = "Villejuif";
$areanames{en}->{3314727} = "Paris";
$areanames{en}->{3314728} = "Suresnes";
$areanames{en}->{3314729} = "Nanterre";
$areanames{en}->{3314730} = "Clichy";
$areanames{en}->{3314731} = "Clichy";
$areanames{en}->{3314732} = "Rueil\-Malmaison";
$areanames{en}->{3314733} = "Asnières\-sur\-Seine";
$areanames{en}->{3314734} = "Paris";
$areanames{en}->{3314735} = "Montrouge";
$areanames{en}->{3314736} = "Issy\-les\-Moulineaux";
$areanames{en}->{3314737} = "Clichy";
$areanames{en}->{3314738} = "Neuilly\-sur\-Seine";
$areanames{en}->{3314739} = "Clichy";
$areanames{en}->{3314740} = "Cachan";
$areanames{en}->{3314741} = "Garches";
$areanames{en}->{3314742} = "Paris";
$areanames{en}->{3314743} = "Paris";
$areanames{en}->{3314745} = "Neuilly\-sur\-Seine";
$areanames{en}->{3314746} = "Montrouge";
$areanames{en}->{3314747} = "Neuilly\-sur\-Seine";
$areanames{en}->{3314748} = "Levallois\-Perret";
$areanames{en}->{3314749} = "Rueil\-Malmaison";
$areanames{en}->{3314750} = "Chaville";
$areanames{en}->{3314751} = "Rueil\-Malmaison";
$areanames{en}->{3314752} = "Rueil\-Malmaison";
$areanames{en}->{3314753} = "Paris";
$areanames{en}->{3314754} = "Paris";
$areanames{en}->{3314755} = "Paris";
$areanames{en}->{3314756} = "Clichy";
$areanames{en}->{3314757} = "Levallois\-Perret";
$areanames{en}->{3314758} = "Levallois\-Perret";
$areanames{en}->{3314759} = "Levallois\-Perret";
$areanames{en}->{3314760} = "Colombes";
$areanames{en}->{3314761} = "Boulogne\-Billancourt";
$areanames{en}->{3314763} = "Paris";
$areanames{en}->{3314764} = "Paris";
$areanames{en}->{3314765} = "Issy\-les\-Moulineaux";
$areanames{en}->{3314766} = "Paris";
$areanames{en}->{3314768} = "Courbevoie";
$areanames{en}->{3314769} = "Colombes";
$areanames{en}->{3314770} = "Paris";
$areanames{en}->{3314771} = "Saint\-Cloud";
$areanames{en}->{3314772} = "Suresnes";
$areanames{en}->{3314773} = "Puteaux";
$areanames{en}->{3314774} = "Puteaux";
$areanames{en}->{3314775} = "Puteaux";
$areanames{en}->{3314776} = "Puteaux";
$areanames{en}->{3314778} = "Puteaux";
$areanames{en}->{3314780} = "Colombes";
$areanames{en}->{3314781} = "Colombes";
$areanames{en}->{3314782} = "Colombes";
$areanames{en}->{3314783} = "Paris";
$areanames{en}->{3314784} = "Colombes";
$areanames{en}->{3314785} = "Colombes";
$areanames{en}->{3314786} = "Colombes";
$areanames{en}->{3314788} = "Courbevoie";
$areanames{en}->{3314789} = "Courbevoie";
$areanames{en}->{3314790} = "Asnières\-sur\-Seine";
$areanames{en}->{3314791} = "Asnières\-sur\-Seine";
$areanames{en}->{3314792} = "Gennevilliers";
$areanames{en}->{3314793} = "Asnières\-sur\-Seine";
$areanames{en}->{3314794} = "Gennevilliers";
$areanames{en}->{3314795} = "Garches";
$areanames{en}->{3314797} = "Paris";
$areanames{en}->{3314798} = "Gennevilliers";
$areanames{en}->{3314799} = "Gennevilliers";
$areanames{en}->{331480} = "Paris";
$areanames{en}->{3314802} = "Bondy";
$areanames{en}->{3314808} = "Vincennes";
$areanames{en}->{3314809} = "Saint\-Denis";
$areanames{en}->{3314811} = "Aubervilliers";
$areanames{en}->{3314812} = "Rosny\-Sous\-Bois";
$areanames{en}->{3314813} = "Saint\-Denis";
$areanames{en}->{3314815} = "Noisy\-le\-Grand";
$areanames{en}->{3314817} = "Villepinte";
$areanames{en}->{3314818} = "Montreuil";
$areanames{en}->{3314819} = "Aulnay\-sous\-Bois";
$areanames{en}->{3314820} = "Saint\-Denis";
$areanames{en}->{3314821} = "Stains";
$areanames{en}->{3314822} = "Saint\-Denis";
$areanames{en}->{3314823} = "Saint\-Denis";
$areanames{en}->{3314824} = "Paris";
$areanames{en}->{3314825} = "Boulogne\-Billancourt";
$areanames{en}->{3314826} = "Stains";
$areanames{en}->{3314827} = "Saint\-Denis";
$areanames{en}->{3314828} = "Paris";
$areanames{en}->{3314829} = "Stains";
$areanames{en}->{3314830} = "Drancy";
$areanames{en}->{3314831} = "Drancy";
$areanames{en}->{3314832} = "Drancy";
$areanames{en}->{3314833} = "Aubervilliers";
$areanames{en}->{3314834} = "Aubervilliers";
$areanames{en}->{3314835} = "La\ Courneuve";
$areanames{en}->{3314836} = "La\ Courneuve";
$areanames{en}->{3314837} = "Le\ Bourget";
$areanames{en}->{3314838} = "La\ Courneuve";
$areanames{en}->{3314839} = "Aubervilliers";
$areanames{en}->{3314840} = "Pantin";
$areanames{en}->{3314841} = "Épinay\-sur\-Seine";
$areanames{en}->{3314842} = "Paris";
$areanames{en}->{3314843} = "Pantin";
$areanames{en}->{3314844} = "Pantin";
$areanames{en}->{3314845} = "Pantin";
$areanames{en}->{3314846} = "Pantin";
$areanames{en}->{3314847} = "Bondy";
$areanames{en}->{3314848} = "Bondy";
$areanames{en}->{3314849} = "Bondy";
$areanames{en}->{3314850} = "Bondy";
$areanames{en}->{3314851} = "Montreuil";
$areanames{en}->{3314852} = "Choisy\-le\-Roi";
$areanames{en}->{3314853} = "Choisy\-le\-Roi";
$areanames{en}->{3314854} = "Rosny\-Sous\-Bois";
$areanames{en}->{3314855} = "Villemomble";
$areanames{en}->{3314856} = "Paris";
$areanames{en}->{3314857} = "Montreuil";
$areanames{en}->{3314858} = "Montreuil";
$areanames{en}->{3314859} = "Montreuil";
$areanames{en}->{3314860} = "Tremblay\-en\-France";
$areanames{en}->{3314861} = "Tremblay\-en\-France";
$areanames{en}->{3314863} = "Villepinte";
$areanames{en}->{3314865} = "Le\ Blanc\ Mesnil";
$areanames{en}->{3314866} = "Aulnay\-sous\-Bois";
$areanames{en}->{3314867} = "Le\ Blanc\ Mesnil";
$areanames{en}->{3314868} = "Aulnay\-sous\-Bois";
$areanames{en}->{3314869} = "Aulnay\-sous\-Bois";
$areanames{en}->{3314870} = "Montreuil";
$areanames{en}->{3314871} = "Le\ Perreux\ sur\ Marne";
$areanames{en}->{3314872} = "Le\ Perreux\ sur\ Marne";
$areanames{en}->{3314873} = "Nogent\-sur\-Marne";
$areanames{en}->{3314874} = "Paris";
$areanames{en}->{3314875} = "Fontenay\-sous\-Bois";
$areanames{en}->{3314876} = "Fontenay\-sous\-Bois";
$areanames{en}->{3314877} = "Fontenay\-sous\-Bois";
$areanames{en}->{3314878} = "Paris";
$areanames{en}->{3314879} = "Aulnay\-sous\-Bois";
$areanames{en}->{3314880} = "Champigny\-sur\-Marne";
$areanames{en}->{3314881} = "Champigny\-sur\-Marne";
$areanames{en}->{3314882} = "Champigny\-sur\-Marne";
$areanames{en}->{3314883} = "Saint\-Maur\-des\-Fossés";
$areanames{en}->{3314884} = "Choisy\-le\-Roi";
$areanames{en}->{3314885} = "Saint\-Maur\-des\-Fossés";
$areanames{en}->{3314886} = "Saint\-Maur\-des\-Fossés";
$areanames{en}->{3314887} = "Paris";
$areanames{en}->{3314888} = "Paris";
$areanames{en}->{3314889} = "Saint\-Maur\-des\-Fossés";
$areanames{en}->{3314890} = "Choisy\-le\-Roi";
$areanames{en}->{3314891} = "Pantin";
$areanames{en}->{3314892} = "Choisy\-le\-Roi";
$areanames{en}->{3314893} = "Charenton\-le\-Pont";
$areanames{en}->{3314894} = "Rosny\-Sous\-Bois";
$areanames{en}->{3314895} = "Drancy";
$areanames{en}->{3314896} = "Drancy";
$areanames{en}->{3314897} = "Bagnolet";
$areanames{en}->{3314898} = "Créteil";
$areanames{en}->{3314899} = "Créteil";
$areanames{en}->{3314900} = "Puteaux";
$areanames{en}->{3314901} = "Puteaux";
$areanames{en}->{3314908} = "Gentilly";
$areanames{en}->{3314909} = "Boulogne\-Billancourt";
$areanames{en}->{3314910} = "Boulogne\-Billancourt";
$areanames{en}->{3314911} = "Saint\-Cloud";
$areanames{en}->{3314912} = "Arcueil";
$areanames{en}->{3314917} = "Saint\-Denis";
$areanames{en}->{331492} = "Paris";
$areanames{en}->{3314920} = "Bobigny";
$areanames{en}->{3314921} = "Bobigny";
$areanames{en}->{3314922} = "Bobigny";
$areanames{en}->{3314930} = "Villiers\-sur\-Marne";
$areanames{en}->{3314932} = "Noisy\-le\-Grand";
$areanames{en}->{3314933} = "Saint\-Denis";
$areanames{en}->{3314934} = "La\ Courneuve";
$areanames{en}->{3314935} = "Rosny\-Sous\-Bois";
$areanames{en}->{3314936} = "Sevran";
$areanames{en}->{3314937} = "Aubervilliers";
$areanames{en}->{3314938} = "Villepinte";
$areanames{en}->{3314941} = "Villiers\-sur\-Marne";
$areanames{en}->{3314942} = "Noisy\-le\-Sec";
$areanames{en}->{3314944} = "Neuilly\-sur\-Marne";
$areanames{en}->{3314945} = "Saint\-Ouen";
$areanames{en}->{3314946} = "Saint\-Denis";
$areanames{en}->{3314947} = "Roissy\-en\-France";
$areanames{en}->{3314948} = "Saint\-Ouen";
$areanames{en}->{3314951} = "Saint\-Denis";
$areanames{en}->{3314952} = "Paris";
$areanames{en}->{3314953} = "Paris";
$areanames{en}->{3314956} = "Créteil";
$areanames{en}->{3314957} = "Vincennes";
$areanames{en}->{3314958} = "Villejuif";
$areanames{en}->{3314959} = "Ivry\-sur\-Seine";
$areanames{en}->{3314960} = "Ivry\-sur\-Seine";
$areanames{en}->{3314961} = "Villeneuve\-le\-Roi";
$areanames{en}->{3314962} = "Chennevières\-sur\-Marne";
$areanames{en}->{3314963} = "Tremblay\-en\-France";
$areanames{en}->{3314965} = "Montrouge";
$areanames{en}->{3314966} = "Sèvres";
$areanames{en}->{3314968} = "Levallois\-Perret";
$areanames{en}->{3314969} = "Cachan";
$areanames{en}->{3314970} = "Paris";
$areanames{en}->{3314971} = "Saint\-Denis";
$areanames{en}->{3314972} = "Bagnolet";
$areanames{en}->{3314974} = "Fontenay\-sous\-Bois";
$areanames{en}->{3314976} = "Saint\-Maur\-des\-Fossés";
$areanames{en}->{3314977} = "Maisons\-Alfort";
$areanames{en}->{3314978} = "Rungis\ Complexe";
$areanames{en}->{3314979} = "Rungis\ Complexe";
$areanames{en}->{3314980} = "Créteil";
$areanames{en}->{3314981} = "Créteil";
$areanames{en}->{3314982} = "Sucy\-en\-Brie";
$areanames{en}->{3314983} = "Champigny\-sur\-Marne";
$areanames{en}->{3314984} = "Fresnes";
$areanames{en}->{3314985} = "Arcueil";
$areanames{en}->{3314986} = "Gentilly";
$areanames{en}->{3314988} = "Montreuil";
$areanames{en}->{3314993} = "Bagnolet";
$areanames{en}->{3314995} = "Paris";
$areanames{en}->{3314996} = "Paris";
$areanames{en}->{3314997} = "Courbevoie";
$areanames{en}->{3314998} = "Saint\-Denis";
$areanames{en}->{33150} = "Ile\ de\ France";
$areanames{en}->{3315010} = "Le\ Raincy";
$areanames{en}->{3315013} = "Paris";
$areanames{en}->{3315015} = "Boulogne\-Billancourt";
$areanames{en}->{3315016} = "Paris";
$areanames{en}->{3315017} = "Nanterre";
$areanames{en}->{3315018} = "Le\ Raincy";
$areanames{en}->{3315038} = "Paris";
$areanames{en}->{3315040} = "Paris";
$areanames{en}->{3315041} = "Paris";
$areanames{en}->{331530} = "Paris";
$areanames{en}->{3315303} = "Ile\ de\ France";
$areanames{en}->{3315310} = "Paris";
$areanames{en}->{3315311} = "Paris";
$areanames{en}->{3315314} = "Villejuif";
$areanames{en}->{3315316} = "Paris";
$areanames{en}->{3315317} = "Paris";
$areanames{en}->{3315319} = "Paris";
$areanames{en}->{331532} = "Paris";
$areanames{en}->{3315322} = "Ile\ de\ France";
$areanames{en}->{331533} = "Paris";
$areanames{en}->{3315337} = "Ile\ de\ France";
$areanames{en}->{331534} = "Paris";
$areanames{en}->{3315347} = "Ile\ de\ France";
$areanames{en}->{3315348} = "Créteil";
$areanames{en}->{3315349} = "Ile\ de\ France";
$areanames{en}->{3315353} = "Paris";
$areanames{en}->{3315356} = "Aubervilliers";
$areanames{en}->{3315357} = "Paris";
$areanames{en}->{3315358} = "Paris";
$areanames{en}->{3315359} = "Paris";
$areanames{en}->{331536} = "Paris";
$areanames{en}->{3315366} = "Vincennes";
$areanames{en}->{331537} = "Paris";
$areanames{en}->{331538} = "Paris";
$areanames{en}->{3315387} = "Ile\ de\ France";
$areanames{en}->{3315388} = "Créteil";
$areanames{en}->{331539} = "Paris";
$areanames{en}->{3315397} = "Ile\ de\ France";
$areanames{en}->{3315399} = "Créteil";
$areanames{en}->{3315502} = "Asnières\-sur\-Seine";
$areanames{en}->{3315504} = "Paris";
$areanames{en}->{3315506} = "Paris";
$areanames{en}->{3315507} = "Paris";
$areanames{en}->{3315512} = "Saint\-Maur\-des\-Fossés";
$areanames{en}->{3315520} = "Boulogne\-Billancourt";
$areanames{en}->{3315521} = "Nanterre";
$areanames{en}->{3315522} = "Boulogne\-Billancourt";
$areanames{en}->{3315523} = "Nanterre";
$areanames{en}->{3315524} = "Nanterre";
$areanames{en}->{3315525} = "Paris";
$areanames{en}->{3315526} = "Paris";
$areanames{en}->{3315527} = "Paris";
$areanames{en}->{3315528} = "Paris";
$areanames{en}->{3315529} = "Paris";
$areanames{en}->{331553} = "Paris";
$areanames{en}->{3315536} = "Ile\ de\ France";
$areanames{en}->{3315538} = "Boulogne\-Billancourt";
$areanames{en}->{3315539} = "Boulogne\-Billancourt";
$areanames{en}->{3315542} = "Paris";
$areanames{en}->{3315543} = "Paris";
$areanames{en}->{3315546} = "Clichy";
$areanames{en}->{3315552} = "Fontenay\-aux\-Roses";
$areanames{en}->{3315559} = "Antony";
$areanames{en}->{3315560} = "Boulogne\-Billancourt";
$areanames{en}->{3315562} = "Neuilly\-sur\-Seine";
$areanames{en}->{3315564} = "Sèvres";
$areanames{en}->{331557} = "Paris";
$areanames{en}->{3315570} = "Nanterre";
$areanames{en}->{3315571} = "Boulogne\-Billancourt";
$areanames{en}->{3315572} = "Nanterre";
$areanames{en}->{3315580} = "Paris";
$areanames{en}->{3315585} = "Noisy\-le\-Grand";
$areanames{en}->{3315586} = "Montreuil";
$areanames{en}->{3315587} = "Saint\-Denis";
$areanames{en}->{3315590} = "Levallois\-Perret";
$areanames{en}->{3315593} = "Saint\-Denis";
$areanames{en}->{3315595} = "Issy\-les\-Moulineaux";
$areanames{en}->{3315596} = "Saint\-Maur\-des\-Fossés";
$areanames{en}->{3315597} = "Saint\-Maur\-des\-Fossés";
$areanames{en}->{3315598} = "Champigny\-sur\-Marne";
$areanames{en}->{3315605} = "Colombes";
$areanames{en}->{3315608} = "Paris";
$areanames{en}->{331561} = "Ile\ de\ France";
$areanames{en}->{3315610} = "Paris";
$areanames{en}->{3315620} = "Ivry\-sur\-Seine";
$areanames{en}->{3315624} = "Paris";
$areanames{en}->{3315626} = "Paris";
$areanames{en}->{3315629} = "Alfortville";
$areanames{en}->{3315630} = "Rungis\ Complexe";
$areanames{en}->{3315631} = "Chennevières\-sur\-Marne";
$areanames{en}->{3315633} = "Paris";
$areanames{en}->{3315643} = "Paris";
$areanames{en}->{3315645} = "Antony";
$areanames{en}->{331565} = "Paris";
$areanames{en}->{3315650} = "Le\ Raincy";
$areanames{en}->{3315651} = "Ile\ de\ France";
$areanames{en}->{3315657} = "Nanterre";
$areanames{en}->{331566} = "Paris";
$areanames{en}->{3315663} = "Bobigny";
$areanames{en}->{3315665} = "Nanterre";
$areanames{en}->{3315670} = "Rungis\ Complexe";
$areanames{en}->{3315671} = "Créteil";
$areanames{en}->{3315673} = "Sucy\-en\-Brie";
$areanames{en}->{3315674} = "Sucy\-en\-Brie";
$areanames{en}->{3315679} = "Paris";
$areanames{en}->{3315681} = "Paris";
$areanames{en}->{3315683} = "Colombes";
$areanames{en}->{3315686} = "Chennevières\-sur\-Marne";
$areanames{en}->{3315688} = "Paris";
$areanames{en}->{331569} = "Paris";
$areanames{en}->{3315693} = "Bobigny";
$areanames{en}->{3315694} = "Ile\ de\ France";
$areanames{en}->{3315696} = "Bobigny";
$areanames{en}->{3315697} = "Boulogne\-Billancourt";
$areanames{en}->{331570} = "Paris";
$areanames{en}->{3315700} = "Nanterre";
$areanames{en}->{3315702} = "Créteil";
$areanames{en}->{3315706} = "Bobigny";
$areanames{en}->{3315707} = "Boulogne\-Billancourt";
$areanames{en}->{3315714} = "Pantin";
$areanames{en}->{3315719} = "Antony";
$areanames{en}->{3315721} = "Montrouge";
$areanames{en}->{331573} = "Paris";
$areanames{en}->{3315732} = "Nanterre";
$areanames{en}->{3315733} = "Le\ Raincy";
$areanames{en}->{3315736} = "Bobigny";
$areanames{en}->{3315739} = "Boulogne\-Billancourt";
$areanames{en}->{3315742} = "Pantin";
$areanames{en}->{331575} = "Paris";
$areanames{en}->{3315753} = "Bobigny";
$areanames{en}->{3315758} = "Boulogne\-Billancourt";
$areanames{en}->{3315759} = "Boulogne\-Billancourt";
$areanames{en}->{3315763} = "Montrouge";
$areanames{en}->{3315769} = "Rueil\-Malmaison";
$areanames{en}->{3315770} = "Boulogne\-Billancourt";
$areanames{en}->{3315771} = "Nanterre";
$areanames{en}->{3315772} = "Boulogne\-Billancourt";
$areanames{en}->{3315773} = "Paris";
$areanames{en}->{3315774} = "Paris";
$areanames{en}->{3315775} = "Boulogne\-Billancourt";
$areanames{en}->{3315776} = "Paris";
$areanames{en}->{3315777} = "Nanterre";
$areanames{en}->{3315778} = "Paris";
$areanames{en}->{3315779} = "Paris";
$areanames{en}->{331578} = "Paris";
$areanames{en}->{3315784} = "Nanterre";
$areanames{en}->{3315787} = "Nanterre";
$areanames{en}->{331579} = "Paris";
$areanames{en}->{3315798} = "Nanterre";
$areanames{en}->{3315799} = "Boulogne\-Billancourt";
$areanames{en}->{3315805} = "Paris";
$areanames{en}->{3315818} = "Paris";
$areanames{en}->{331582} = "Paris";
$areanames{en}->{3315826} = "Ile\ de\ France";
$areanames{en}->{3315830} = "Paris";
$areanames{en}->{3315834} = "Saint\-Denis";
$areanames{en}->{3315836} = "Paris";
$areanames{en}->{3315842} = "Choisy\-le\-Roi";
$areanames{en}->{331585} = "Paris";
$areanames{en}->{3315858} = "Nanterre";
$areanames{en}->{3315860} = "Paris";
$areanames{en}->{3315862} = "Paris";
$areanames{en}->{3315864} = "Vincennes";
$areanames{en}->{3315869} = "Saint\-Denis";
$areanames{en}->{331587} = "Paris";
$areanames{en}->{3315873} = "Créteil";
$areanames{en}->{3315874} = "Nanterre";
$areanames{en}->{3315875} = "Nanterre";
$areanames{en}->{3315879} = "Bobigny";
$areanames{en}->{3315888} = "Issy\-les\-Moulineaux";
$areanames{en}->{3315890} = "Paris";
$areanames{en}->{3315891} = "Créteil";
$areanames{en}->{3315892} = "Bobigny";
$areanames{en}->{3315893} = "Créteil";
$areanames{en}->{3315894} = "Créteil";
$areanames{en}->{3315895} = "Paris";
$areanames{en}->{3315896} = "Le\ Raincy";
$areanames{en}->{3315897} = "Paris";
$areanames{en}->{3315898} = "Nanterre";
$areanames{en}->{3315899} = "Paris";
$areanames{en}->{3316002} = "Ozoir\-la\-Ferrière";
$areanames{en}->{3316003} = "Dammartin\-en\-Goële";
$areanames{en}->{3316005} = "Torcy";
$areanames{en}->{3316006} = "Torcy";
$areanames{en}->{3316007} = "Lagny\-sur\-Marne";
$areanames{en}->{3316008} = "Chelles";
$areanames{en}->{3316009} = "Meaux";
$areanames{en}->{3316010} = "Palaiseau";
$areanames{en}->{3316011} = "Massy";
$areanames{en}->{3316012} = "Gif\-sur\-Yvette";
$areanames{en}->{3316013} = "Massy";
$areanames{en}->{3316014} = "Palaiseau";
$areanames{en}->{3316015} = "Sainte\-Geneviève\-des\-Bois";
$areanames{en}->{3316016} = "Sainte\-Geneviève\-des\-Bois";
$areanames{en}->{3316017} = "Torcy";
$areanames{en}->{3316018} = "Lieusaint";
$areanames{en}->{3316019} = "Igny";
$areanames{en}->{3316020} = "Chelles";
$areanames{en}->{3316021} = "Mitry\-Mory";
$areanames{en}->{3316022} = "La\ Ferté\ sous\ Jouarre";
$areanames{en}->{3316023} = "Meaux";
$areanames{en}->{3316024} = "Meaux";
$areanames{en}->{3316025} = "Meaux";
$areanames{en}->{3316026} = "Claye\-Souilly";
$areanames{en}->{3316027} = "Claye\-Souilly";
$areanames{en}->{3316028} = "Pontault\-Combault";
$areanames{en}->{3316029} = "Pontault\-Combault";
$areanames{en}->{3316031} = "Lagny\-sur\-Marne";
$areanames{en}->{3316032} = "Meaux";
$areanames{en}->{3316034} = "Pontault\-Combault";
$areanames{en}->{3316035} = "Saint\-Thibault\-des\-Vignes";
$areanames{en}->{3316036} = "Montévrain";
$areanames{en}->{3316037} = "Torcy";
$areanames{en}->{3316039} = "Fontainebleau";
$areanames{en}->{3316042} = "Serris";
$areanames{en}->{3316043} = "Serris";
$areanames{en}->{3316044} = "Meaux";
$areanames{en}->{3316046} = "Brunoy";
$areanames{en}->{3316047} = "Brunoy";
$areanames{en}->{3316048} = "Athis\-Mons";
$areanames{en}->{3316054} = "Dammartin\-en\-Goële";
$areanames{en}->{3316055} = "Nemours";
$areanames{en}->{3316056} = "Melun";
$areanames{en}->{3316057} = "Montereau\-Fault\-Yonne";
$areanames{en}->{3316058} = "Provins";
$areanames{en}->{3316059} = "Melun";
$areanames{en}->{3316060} = "Combs\-la\-Ville";
$areanames{en}->{3316062} = "Brie\-Comte\-Robert";
$areanames{en}->{3316063} = "Savigny\-le\-Temple";
$areanames{en}->{3316065} = "Saint\-Fargeau\-Ponthierry";
$areanames{en}->{3316068} = "Melun";
$areanames{en}->{3316069} = "Bois\-le\-Roi";
$areanames{en}->{3316070} = "Moret\-sur\-Loing";
$areanames{en}->{3316071} = "Fontainebleau";
$areanames{en}->{3316072} = "Fontainebleau";
$areanames{en}->{3316074} = "Fontainebleau";
$areanames{en}->{3316075} = "Soisy\-sur\-Seine";
$areanames{en}->{3316077} = "Évry";
$areanames{en}->{3316078} = "Évry";
$areanames{en}->{3316079} = "Évry";
$areanames{en}->{3316080} = "Étréchy";
$areanames{en}->{3316081} = "Dourdan";
$areanames{en}->{3316082} = "Lardy";
$areanames{en}->{3316083} = "Arpajon";
$areanames{en}->{3316084} = "Brétigny\-sur\-Orge";
$areanames{en}->{3316085} = "Brétigny\-sur\-Orge";
$areanames{en}->{3316086} = "Bondoufle";
$areanames{en}->{3316087} = "Évry";
$areanames{en}->{3316088} = "Corbeil\-Essonnes";
$areanames{en}->{3316089} = "Corbeil\-Essonnes";
$areanames{en}->{3316091} = "Évry";
$areanames{en}->{3316092} = "Villebon\-sur\-Yvette";
$areanames{en}->{3316096} = "Montereau\-Fault\-Yonne";
$areanames{en}->{3316104} = "Sartrouville";
$areanames{en}->{331611} = "Ile\ de\ France";
$areanames{en}->{3316110} = "Meaux";
$areanames{en}->{3316111} = "Poissy";
$areanames{en}->{3316112} = "Versailles";
$areanames{en}->{331612} = "Ile\ de\ France";
$areanames{en}->{3316130} = "Sartrouville";
$areanames{en}->{3316137} = "Montigny\-le\-Bretonneux";
$areanames{en}->{3316138} = "Montigny\-le\-Bretonneux";
$areanames{en}->{331614} = "Ile\ de\ France";
$areanames{en}->{3316140} = "Lagny\-sur\-Marne";
$areanames{en}->{3316144} = "Lagny\-sur\-Marne";
$areanames{en}->{3316145} = "Poissy";
$areanames{en}->{331615} = "Ile\ de\ France";
$areanames{en}->{331616} = "Ile\ de\ France";
$areanames{en}->{3316161} = "Corbeil\-Essonnes";
$areanames{en}->{3316162} = "Versailles";
$areanames{en}->{3316169} = "Corbeil\-Essonnes";
$areanames{en}->{331617} = "Ile\ de\ France";
$areanames{en}->{3316178} = "Guyancourt";
$areanames{en}->{331618} = "Ile\ de\ France";
$areanames{en}->{331619} = "Ile\ de\ France";
$areanames{en}->{3316400} = "Provins";
$areanames{en}->{3316402} = "Lagny\-sur\-Marne";
$areanames{en}->{3316403} = "Coulommiers";
$areanames{en}->{3316405} = "Brie\-Comte\-Robert";
$areanames{en}->{3316407} = "Tournan\-en\-Brie";
$areanames{en}->{3316408} = "Nangis";
$areanames{en}->{3316409} = "Melun";
$areanames{en}->{3316410} = "Melun";
$areanames{en}->{3316411} = "Torcy";
$areanames{en}->{3316412} = "Lagny\-sur\-Marne";
$areanames{en}->{3316413} = "Moissy\-Cramayel";
$areanames{en}->{3316414} = "Melun";
$areanames{en}->{3316417} = "Serris";
$areanames{en}->{3316419} = "Savigny\-le\-Temple";
$areanames{en}->{3316420} = "Coulommiers";
$areanames{en}->{3316421} = "Chelles";
$areanames{en}->{3316422} = "Fontainebleau";
$areanames{en}->{3316425} = "Fontenay\-Trésigny";
$areanames{en}->{3316426} = "Chelles";
$areanames{en}->{3316427} = "Villeparisis";
$areanames{en}->{3316428} = "Nemours";
$areanames{en}->{3316430} = "Lagny\-sur\-Marne";
$areanames{en}->{3316432} = "Montereau\-Fault\-Yonne";
$areanames{en}->{3316433} = "Meaux";
$areanames{en}->{3316434} = "Meaux";
$areanames{en}->{3316435} = "Meaux";
$areanames{en}->{3316437} = "Melun";
$areanames{en}->{3316439} = "Melun";
$areanames{en}->{3316440} = "Ozoir\-la\-Ferrière";
$areanames{en}->{3316441} = "Savigny\-le\-Temple";
$areanames{en}->{3316443} = "Pontault\-Combault";
$areanames{en}->{3316445} = "Montigny\-sur\-Loing";
$areanames{en}->{3316446} = "Orsay";
$areanames{en}->{3316447} = "Massy";
$areanames{en}->{3316448} = "Longjumeau";
$areanames{en}->{3316449} = "Marcoussis";
$areanames{en}->{3316452} = "Melun";
$areanames{en}->{3316454} = "Longjumeau";
$areanames{en}->{3316456} = "Saint\-Chéron";
$areanames{en}->{3316457} = "Mennecy";
$areanames{en}->{3316458} = "Breuillet";
$areanames{en}->{3316459} = "Dourdan";
$areanames{en}->{3316460} = "Provins";
$areanames{en}->{3316461} = "Champs\-sur\-Marne";
$areanames{en}->{3316462} = "Lognes";
$areanames{en}->{3316463} = "Crécy\-la\-Chapelle";
$areanames{en}->{3316464} = "Melun";
$areanames{en}->{3316465} = "Coulommiers";
$areanames{en}->{3316466} = "Bussy\-Saint\-Georges";
$areanames{en}->{3316467} = "Villeparisis";
$areanames{en}->{3316468} = "Champs\-sur\-Marne";
$areanames{en}->{3316469} = "Fontainebleau";
$areanames{en}->{3316470} = "Montereau\-Fault\-Yonne";
$areanames{en}->{3316471} = "Melun";
$areanames{en}->{3316472} = "Chelles";
$areanames{en}->{3316475} = "Coulommiers";
$areanames{en}->{3316476} = "Bussy\-Saint\-Georges";
$areanames{en}->{3316477} = "Bussy\-Saint\-Georges";
$areanames{en}->{3316478} = "Nemours";
$areanames{en}->{3316479} = "Dammarie\-les\-Lys";
$areanames{en}->{3316480} = "Lognes";
$areanames{en}->{3316486} = "Les\ Ulis";
$areanames{en}->{3316487} = "Melun";
$areanames{en}->{3316488} = "Moissy\-Cramayel";
$areanames{en}->{3316490} = "Arpajon";
$areanames{en}->{3316491} = "Limours\ en\ Hurepoix";
$areanames{en}->{3316492} = "Arpajon";
$areanames{en}->{3316493} = "Ballancourt\-sur\-Essonne";
$areanames{en}->{3316494} = "Étampes";
$areanames{en}->{3316496} = "Corbeil\-Essonnes";
$areanames{en}->{3316497} = "Évry";
$areanames{en}->{3316498} = "Milly\-la\-Forêt";
$areanames{en}->{3316499} = "Mennecy";
$areanames{en}->{3316900} = "Quincy\-sous\-Sénart";
$areanames{en}->{3316901} = "Montlhéry";
$areanames{en}->{3316902} = "Ris\-Orangis";
$areanames{en}->{3316903} = "Montgeron";
$areanames{en}->{3316904} = "Morsang\-sur\-Orge";
$areanames{en}->{3316905} = "Savigny\-sur\-Orge";
$areanames{en}->{3316906} = "Ris\-Orangis";
$areanames{en}->{3316907} = "Gif\-sur\-Yvette";
$areanames{en}->{3316909} = "Chilly\-Mazarin";
$areanames{en}->{3316910} = "Chilly\-Mazarin";
$areanames{en}->{3316911} = "Lisses";
$areanames{en}->{3316912} = "Viry\-Châtillon";
$areanames{en}->{3316914} = "Marolles\-en\-Hurepoix";
$areanames{en}->{3316918} = "Les\ Ulis";
$areanames{en}->{3316920} = "Massy";
$areanames{en}->{3316921} = "Juvisy\-sur\-Orge";
$areanames{en}->{3316923} = "Cerny";
$areanames{en}->{3316924} = "Viry\-Châtillon";
$areanames{en}->{3316925} = "Sainte\-Geneviève\-des\-Bois";
$areanames{en}->{3316926} = "Arpajon";
$areanames{en}->{3316927} = "Lardy";
$areanames{en}->{3316928} = "Orsay";
$areanames{en}->{3316929} = "Orsay";
$areanames{en}->{3316930} = "Massy";
$areanames{en}->{3316931} = "Palaiseau";
$areanames{en}->{3316932} = "Massy";
$areanames{en}->{3316934} = "Longjumeau";
$areanames{en}->{3316935} = "Bièvres";
$areanames{en}->{3316936} = "Évry";
$areanames{en}->{3316938} = "Athis\-Mons";
$areanames{en}->{3316939} = "Brunoy";
$areanames{en}->{3316940} = "Draveil";
$areanames{en}->{3316941} = "Igny";
$areanames{en}->{3316942} = "Draveil";
$areanames{en}->{3316943} = "Ris\-Orangis";
$areanames{en}->{3316944} = "Savigny\-sur\-Orge";
$areanames{en}->{3316945} = "Juvisy\-sur\-Orge";
$areanames{en}->{3316946} = "Sainte\-Geneviève\-des\-Bois";
$areanames{en}->{3316947} = "Évry";
$areanames{en}->{3316948} = "Yerres";
$areanames{en}->{3316949} = "Yerres";
$areanames{en}->{3316951} = "Sainte\-Geneviève\-des\-Bois";
$areanames{en}->{3316952} = "Montgeron";
$areanames{en}->{3316953} = "Massy";
$areanames{en}->{3316956} = "Juvisy\-sur\-Orge";
$areanames{en}->{3316957} = "Athis\-Mons";
$areanames{en}->{3316960} = "Ile\ de\ France";
$areanames{en}->{3316961} = "Ile\ de\ France";
$areanames{en}->{3316962} = "Massy";
$areanames{en}->{3316963} = "Massy";
$areanames{en}->{3316964} = "Corbeil\-Essonnes";
$areanames{en}->{3316965} = "Massy";
$areanames{en}->{3316966} = "Ile\ de\ France";
$areanames{en}->{3316967} = "Lagny\-sur\-Marne";
$areanames{en}->{3316968} = "Melun";
$areanames{en}->{3316969} = "Ile\ de\ France";
$areanames{en}->{3316975} = "Massy";
$areanames{en}->{3316978} = "Étampes";
$areanames{en}->{3316979} = "Chilly\-Mazarin";
$areanames{en}->{3316980} = "Montlhéry";
$areanames{en}->{3316981} = "Massy";
$areanames{en}->{3316983} = "Yerres";
$areanames{en}->{3316986} = "Gif\-sur\-Yvette";
$areanames{en}->{3316988} = "Brétigny\-sur\-Orge";
$areanames{en}->{3316989} = "Soisy\-sur\-Seine";
$areanames{en}->{3316990} = "Mennecy";
$areanames{en}->{3316991} = "Évry";
$areanames{en}->{3316992} = "Étampes";
$areanames{en}->{3316995} = "Angerville";
$areanames{en}->{3316996} = "Savigny\-sur\-Orge";
$areanames{en}->{3317000} = "Chelles";
$areanames{en}->{3317010} = "Brie\-Comte\-Robert";
$areanames{en}->{3317011} = "Cergy";
$areanames{en}->{3317012} = "Paris";
$areanames{en}->{3317013} = "Créteil";
$areanames{en}->{3317014} = "Enghien\-les\-Bains";
$areanames{en}->{3317015} = "Nanterre";
$areanames{en}->{3317016} = "Nanterre";
$areanames{en}->{3317017} = "Lagny\-sur\-Marne";
$areanames{en}->{3317018} = "Boulogne\-Billancourt";
$areanames{en}->{3317019} = "Boulogne\-Billancourt";
$areanames{en}->{3317028} = "Boulogne\-Billancourt";
$areanames{en}->{3317030} = "Sarcelles";
$areanames{en}->{3317031} = "Les\ Mureaux";
$areanames{en}->{3317032} = "Bobigny";
$areanames{en}->{3317033} = "Brie\-Comte\-Robert";
$areanames{en}->{3317034} = "Poissy";
$areanames{en}->{3317035} = "Coulommiers";
$areanames{en}->{3317036} = "Paris";
$areanames{en}->{3317037} = "Paris";
$areanames{en}->{3317038} = "Paris";
$areanames{en}->{3317039} = "Paris";
$areanames{en}->{3317040} = "Le\ Raincy";
$areanames{en}->{3317041} = "Rambouillet";
$areanames{en}->{3317042} = "Guyancourt";
$areanames{en}->{3317043} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3317044} = "Versailles";
$areanames{en}->{3317045} = "Fontainebleau";
$areanames{en}->{3317046} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3317047} = "Meaux";
$areanames{en}->{3317048} = "Nanterre";
$areanames{en}->{3317049} = "Cergy";
$areanames{en}->{3317050} = "Bobigny";
$areanames{en}->{3317051} = "Les\ Mureaux";
$areanames{en}->{3317052} = "Paris";
$areanames{en}->{3317053} = "Rambouillet";
$areanames{en}->{3317054} = "Brie\-Comte\-Robert";
$areanames{en}->{3317055} = "Massy";
$areanames{en}->{3317056} = "Massy";
$areanames{en}->{3317057} = "Sarcelles";
$areanames{en}->{3317058} = "Juvisy\-sur\-Orge";
$areanames{en}->{3317059} = "Bobigny";
$areanames{en}->{331706} = "Paris";
$areanames{en}->{3317062} = "Arpajon";
$areanames{en}->{3317068} = "Boulogne\-Billancourt";
$areanames{en}->{3317070} = "Paris";
$areanames{en}->{3317071} = "Paris";
$areanames{en}->{3317072} = "Nanterre";
$areanames{en}->{3317073} = "Nanterre";
$areanames{en}->{3317074} = "Boulogne\-Billancourt";
$areanames{en}->{3317075} = "Paris";
$areanames{en}->{3317076} = "Le\ Raincy";
$areanames{en}->{3317077} = "Lagny\-sur\-Marne";
$areanames{en}->{3317078} = "Nanterre";
$areanames{en}->{3317079} = "Paris";
$areanames{en}->{3317080} = "Paris";
$areanames{en}->{3317081} = "Paris";
$areanames{en}->{3317082} = "Nanterre";
$areanames{en}->{3317083} = "Boulogne\-Billancourt";
$areanames{en}->{3317084} = "Massy";
$areanames{en}->{3317085} = "Lagny\-sur\-Marne";
$areanames{en}->{3317086} = "Le\ Raincy";
$areanames{en}->{3317087} = "Corbeil\-Essonnes";
$areanames{en}->{3317088} = "Les\ Mureaux";
$areanames{en}->{3317089} = "Tournan\-en\-Brie";
$areanames{en}->{3317090} = "Paris";
$areanames{en}->{3317091} = "Paris";
$areanames{en}->{3317092} = "Nanterre";
$areanames{en}->{3317093} = "Bobigny";
$areanames{en}->{3317094} = "Nanterre";
$areanames{en}->{3317095} = "Boulogne\-Billancourt";
$areanames{en}->{3317096} = "Nanterre";
$areanames{en}->{3317097} = "Créteil";
$areanames{en}->{3317098} = "Paris";
$areanames{en}->{3317099} = "Paris";
$areanames{en}->{331710} = "Nanterre";
$areanames{en}->{3317117} = "Boulogne\-Billancourt";
$areanames{en}->{3317118} = "Paris";
$areanames{en}->{3317119} = "Paris";
$areanames{en}->{331712} = "Paris";
$areanames{en}->{3317122} = "Boulogne\-Billancourt";
$areanames{en}->{3317123} = "Nanterre";
$areanames{en}->{3317129} = "Bobigny";
$areanames{en}->{3317130} = "Tournan\-en\-Brie";
$areanames{en}->{3317131} = "Tournan\-en\-Brie";
$areanames{en}->{3317132} = "Paris";
$areanames{en}->{3317133} = "Créteil";
$areanames{en}->{3317134} = "Boissy\-Saint\-Léger";
$areanames{en}->{3317135} = "Boulogne\-Billancourt";
$areanames{en}->{3317136} = "Créteil";
$areanames{en}->{3317137} = "Paris";
$areanames{en}->{3317138} = "Paris";
$areanames{en}->{3317139} = "Paris";
$areanames{en}->{3317140} = "Lagny\-sur\-Marne";
$areanames{en}->{3317141} = "Versailles";
$areanames{en}->{3317142} = "Versailles";
$areanames{en}->{3317143} = "Mantes\-la\-Jolie";
$areanames{en}->{3317144} = "Versailles";
$areanames{en}->{3317145} = "Versailles";
$areanames{en}->{3317146} = "Mantes\-la\-Jolie";
$areanames{en}->{3317147} = "Versailles";
$areanames{en}->{3317148} = "Mantes\-la\-Jolie";
$areanames{en}->{3317149} = "Guyancourt";
$areanames{en}->{3317150} = "Paris";
$areanames{en}->{3317151} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3317152} = "Poissy";
$areanames{en}->{3317153} = "Nanterre";
$areanames{en}->{3317154} = "Boulogne\-Billancourt";
$areanames{en}->{3317155} = "Tournan\-en\-Brie";
$areanames{en}->{3317156} = "Créteil";
$areanames{en}->{3317157} = "Boissy\-Saint\-Léger";
$areanames{en}->{3317158} = "Lagny\-sur\-Marne";
$areanames{en}->{3317159} = "Versailles";
$areanames{en}->{3317160} = "Paris";
$areanames{en}->{3317161} = "Mantes\-la\-Jolie";
$areanames{en}->{3317162} = "Corbeil\-Essonnes";
$areanames{en}->{3317163} = "Corbeil\-Essonnes";
$areanames{en}->{3317164} = "Guyancourt";
$areanames{en}->{3317165} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3317166} = "Cergy";
$areanames{en}->{3317167} = "Enghien\-les\-Bains";
$areanames{en}->{3317168} = "Enghien\-les\-Bains";
$areanames{en}->{3317169} = "Sarcelles";
$areanames{en}->{331717} = "Paris";
$areanames{en}->{3317174} = "Poissy";
$areanames{en}->{3317177} = "Nanterre";
$areanames{en}->{3317178} = "Corbeil\-Essonnes";
$areanames{en}->{3317179} = "Cergy";
$areanames{en}->{331718} = "Le\ Raincy";
$areanames{en}->{3317186} = "Bobigny";
$areanames{en}->{3317187} = "Sarcelles";
$areanames{en}->{3317189} = "Bobigny";
$areanames{en}->{331719} = "Paris";
$areanames{en}->{3317190} = "Nanterre";
$areanames{en}->{3317191} = "Nanterre";
$areanames{en}->{3317192} = "Bobigny";
$areanames{en}->{3317200} = "Cergy";
$areanames{en}->{3317201} = "Enghien\-les\-Bains";
$areanames{en}->{3317202} = "Sarcelles";
$areanames{en}->{3317203} = "Bobigny";
$areanames{en}->{3317204} = "Créteil";
$areanames{en}->{3317205} = "Boissy\-Saint\-Léger";
$areanames{en}->{3317206} = "Juvisy\-sur\-Orge";
$areanames{en}->{3317207} = "Corbeil\-Essonnes";
$areanames{en}->{3317208} = "Brie\-Comte\-Robert";
$areanames{en}->{3317209} = "Bobigny";
$areanames{en}->{3317210} = "Versailles";
$areanames{en}->{3317211} = "Guyancourt";
$areanames{en}->{3317212} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3317213} = "Poissy";
$areanames{en}->{3317214} = "Mantes\-la\-Jolie";
$areanames{en}->{3317215} = "Rambouillet";
$areanames{en}->{3317216} = "Arpajon";
$areanames{en}->{3317217} = "Melun";
$areanames{en}->{3317218} = "Tournan\-en\-Brie";
$areanames{en}->{3317219} = "Meaux";
$areanames{en}->{3317220} = "Coulommiers";
$areanames{en}->{3317221} = "Provins";
$areanames{en}->{3317222} = "Fontainebleau";
$areanames{en}->{3317223} = "Beaumont\-sur\-Oise";
$areanames{en}->{3317224} = "Versailles";
$areanames{en}->{3317225} = "Nanterre";
$areanames{en}->{3317226} = "Nanterre";
$areanames{en}->{3317227} = "Nanterre";
$areanames{en}->{3317228} = "Nanterre";
$areanames{en}->{3317229} = "Boulogne\-Billancourt";
$areanames{en}->{3317234} = "Paris";
$areanames{en}->{3317240} = "Bobigny";
$areanames{en}->{3317241} = "Nanterre";
$areanames{en}->{3317242} = "Nanterre";
$areanames{en}->{3317243} = "Créteil";
$areanames{en}->{3317244} = "Boulogne\-Billancourt";
$areanames{en}->{3317245} = "Créteil";
$areanames{en}->{3317246} = "Créteil";
$areanames{en}->{3317247} = "Boulogne\-Billancourt";
$areanames{en}->{3317248} = "Massy";
$areanames{en}->{3317249} = "Juvisy\-sur\-Orge";
$areanames{en}->{3317250} = "Boissy\-Saint\-Léger";
$areanames{en}->{3317251} = "Le\ Raincy";
$areanames{en}->{3317252} = "Sarcelles";
$areanames{en}->{3317253} = "Enghien\-les\-Bains";
$areanames{en}->{3317254} = "Poissy";
$areanames{en}->{3317255} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3317256} = "Guyancourt";
$areanames{en}->{3317257} = "Boulogne\-Billancourt";
$areanames{en}->{3317258} = "Cergy";
$areanames{en}->{3317259} = "Bobigny";
$areanames{en}->{3317260} = "Paris";
$areanames{en}->{3317261} = "Nanterre";
$areanames{en}->{3317262} = "Brie\-Comte\-Robert";
$areanames{en}->{3317263} = "Paris";
$areanames{en}->{3317264} = "Bobigny";
$areanames{en}->{3317265} = "Bobigny";
$areanames{en}->{3317266} = "Fontainebleau";
$areanames{en}->{3317267} = "Guyancourt";
$areanames{en}->{3317268} = "Paris";
$areanames{en}->{3317269} = "Paris";
$areanames{en}->{331727} = "Paris";
$areanames{en}->{3317270} = "Créteil";
$areanames{en}->{3317277} = "Bobigny";
$areanames{en}->{3317278} = "Versailles";
$areanames{en}->{3317279} = "Fontainebleau";
$areanames{en}->{3317280} = "Bobigny";
$areanames{en}->{3317281} = "Versailles";
$areanames{en}->{3317282} = "Guyancourt";
$areanames{en}->{3317283} = "Melun";
$areanames{en}->{3317284} = "Lagny\-sur\-Marne";
$areanames{en}->{3317285} = "Cergy";
$areanames{en}->{3317286} = "Massy";
$areanames{en}->{3317287} = "Guyancourt";
$areanames{en}->{3317288} = "Le\ Raincy";
$areanames{en}->{3317289} = "Nanterre";
$areanames{en}->{3317290} = "Boulogne\-Billancourt";
$areanames{en}->{3317291} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3317292} = "Nanterre";
$areanames{en}->{3317293} = "Bobigny";
$areanames{en}->{3317294} = "Créteil";
$areanames{en}->{3317295} = "Paris";
$areanames{en}->{3317296} = "Lagny\-sur\-Marne";
$areanames{en}->{3317297} = "Guyancourt";
$areanames{en}->{3317298} = "Paris";
$areanames{en}->{3317299} = "Lagny\-sur\-Marne";
$areanames{en}->{3317300} = "Paris";
$areanames{en}->{3317301} = "Paris";
$areanames{en}->{3317302} = "Paris";
$areanames{en}->{3317303} = "Paris";
$areanames{en}->{3317304} = "Paris";
$areanames{en}->{3317305} = "Brie\-Comte\-Robert";
$areanames{en}->{3317306} = "Coulommiers";
$areanames{en}->{3317307} = "Fontainebleau";
$areanames{en}->{3317308} = "Lagny\-sur\-Marne";
$areanames{en}->{3317309} = "Meaux";
$areanames{en}->{3317310} = "Melun";
$areanames{en}->{3317311} = "Provins";
$areanames{en}->{3317312} = "Tournan\-en\-Brie";
$areanames{en}->{3317313} = "Guyancourt";
$areanames{en}->{3317314} = "Mantes\-la\-Jolie";
$areanames{en}->{3317315} = "Les\ Mureaux";
$areanames{en}->{3317316} = "Poissy";
$areanames{en}->{3317317} = "Rambouillet";
$areanames{en}->{3317318} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3317319} = "Versailles";
$areanames{en}->{3317320} = "Arpajon";
$areanames{en}->{3317321} = "Corbeil\-Essonnes";
$areanames{en}->{3317322} = "Juvisy\-sur\-Orge";
$areanames{en}->{3317323} = "Massy";
$areanames{en}->{3317324} = "Beaumont\-sur\-Oise";
$areanames{en}->{3317325} = "Cergy";
$areanames{en}->{3317326} = "Enghien\-les\-Bains";
$areanames{en}->{3317327} = "Sarcelles";
$areanames{en}->{3317328} = "Boulogne\-Billancourt";
$areanames{en}->{3317329} = "Nanterre";
$areanames{en}->{3317330} = "Bobigny";
$areanames{en}->{3317331} = "Le\ Raincy";
$areanames{en}->{3317332} = "Boissy\-Saint\-Léger";
$areanames{en}->{3317333} = "Paris";
$areanames{en}->{3317334} = "Nanterre";
$areanames{en}->{3317335} = "Boulogne\-Billancourt";
$areanames{en}->{3317336} = "Guyancourt";
$areanames{en}->{3317337} = "Massy";
$areanames{en}->{3317338} = "Lagny\-sur\-Marne";
$areanames{en}->{3317339} = "Le\ Raincy";
$areanames{en}->{3317348} = "Boulogne\-Billancourt";
$areanames{en}->{3317350} = "Paris";
$areanames{en}->{3317351} = "Melun";
$areanames{en}->{3317352} = "Melun";
$areanames{en}->{3317353} = "Le\ Raincy";
$areanames{en}->{3317354} = "Paris";
$areanames{en}->{3317355} = "Bobigny";
$areanames{en}->{3317356} = "Bobigny";
$areanames{en}->{3317357} = "Bobigny";
$areanames{en}->{3317358} = "Lagny\-sur\-Marne";
$areanames{en}->{3317359} = "Brie\-Comte\-Robert";
$areanames{en}->{3317360} = "Nanterre";
$areanames{en}->{3317361} = "Poissy";
$areanames{en}->{3317362} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3317363} = "Nanterre";
$areanames{en}->{3317364} = "Nanterre";
$areanames{en}->{3317365} = "Enghien\-les\-Bains";
$areanames{en}->{3317366} = "Juvisy\-sur\-Orge";
$areanames{en}->{3317367} = "Paris";
$areanames{en}->{3317368} = "Paris";
$areanames{en}->{3317369} = "Brie\-Comte\-Robert";
$areanames{en}->{331737} = "Paris";
$areanames{en}->{3317380} = "Coulommiers";
$areanames{en}->{3317381} = "Fontainebleau";
$areanames{en}->{3317382} = "Lagny\-sur\-Marne";
$areanames{en}->{3317383} = "Meaux";
$areanames{en}->{3317384} = "Melun";
$areanames{en}->{3317385} = "Provins";
$areanames{en}->{3317386} = "Tournan\-en\-Brie";
$areanames{en}->{3317387} = "Guyancourt";
$areanames{en}->{3317388} = "Mantes\-la\-Jolie";
$areanames{en}->{3317389} = "Les\ Mureaux";
$areanames{en}->{3317390} = "Poissy";
$areanames{en}->{3317391} = "Rambouillet";
$areanames{en}->{3317392} = "Nanterre";
$areanames{en}->{3317393} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3317394} = "Versailles";
$areanames{en}->{3317395} = "Versailles";
$areanames{en}->{3317396} = "Arpajon";
$areanames{en}->{3317397} = "Corbeil\-Essonnes";
$areanames{en}->{3317398} = "Boulogne\-Billancourt";
$areanames{en}->{3317399} = "Nanterre";
$areanames{en}->{3317400} = "Enghien\-les\-Bains";
$areanames{en}->{3317401} = "Boissy\-Saint\-Léger";
$areanames{en}->{3317402} = "Créteil";
$areanames{en}->{3317403} = "Enghien\-les\-Bains";
$areanames{en}->{3317404} = "Sarcelles";
$areanames{en}->{3317405} = "Corbeil\-Essonnes";
$areanames{en}->{3317406} = "Juvisy\-sur\-Orge";
$areanames{en}->{3317407} = "Versailles";
$areanames{en}->{3317408} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3317409} = "Guyancourt";
$areanames{en}->{3317413} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3317420} = "Bobigny";
$areanames{en}->{3317421} = "Bobigny";
$areanames{en}->{3317422} = "Créteil";
$areanames{en}->{3317423} = "Bobigny";
$areanames{en}->{3317424} = "Le\ Raincy";
$areanames{en}->{3317425} = "Le\ Raincy";
$areanames{en}->{3317426} = "Le\ Raincy";
$areanames{en}->{3317427} = "Boissy\-Saint\-Léger";
$areanames{en}->{3317428} = "Boissy\-Saint\-Léger";
$areanames{en}->{3317429} = "Le\ Raincy";
$areanames{en}->{3317430} = "Paris";
$areanames{en}->{3317440} = "Bobigny";
$areanames{en}->{3317441} = "Le\ Raincy";
$areanames{en}->{3317442} = "Boissy\-Saint\-Léger";
$areanames{en}->{3317443} = "Créteil";
$areanames{en}->{3317444} = "Créteil";
$areanames{en}->{3317445} = "Beaumont\-sur\-Oise";
$areanames{en}->{3317446} = "Cergy";
$areanames{en}->{3317447} = "Enghien\-les\-Bains";
$areanames{en}->{3317448} = "Sarcelles";
$areanames{en}->{3317449} = "Juvisy\-sur\-Orge";
$areanames{en}->{3317450} = "Créteil";
$areanames{en}->{3317451} = "Corbeil\-Essonnes";
$areanames{en}->{3317452} = "Massy";
$areanames{en}->{3317453} = "Nanterre";
$areanames{en}->{3317454} = "Nanterre";
$areanames{en}->{3317455} = "Nanterre";
$areanames{en}->{3317456} = "Beaumont\-sur\-Oise";
$areanames{en}->{3317457} = "Corbeil\-Essonnes";
$areanames{en}->{3317458} = "Mantes\-la\-Jolie";
$areanames{en}->{3317459} = "Brie\-Comte\-Robert";
$areanames{en}->{3317462} = "Boulogne\-Billancourt";
$areanames{en}->{3317463} = "Levallois\-Perret";
$areanames{en}->{3317464} = "Paris";
$areanames{en}->{3317470} = "Nanterre";
$areanames{en}->{3317471} = "Boulogne\-Billancourt";
$areanames{en}->{3317472} = "Le\ Raincy";
$areanames{en}->{3317473} = "Bobigny";
$areanames{en}->{3317474} = "Boulogne\-Billancourt";
$areanames{en}->{3317475} = "Massy";
$areanames{en}->{3317476} = "Meaux";
$areanames{en}->{3317477} = "Melun";
$areanames{en}->{3317478} = "Provins";
$areanames{en}->{3317479} = "Tournan\-en\-Brie";
$areanames{en}->{3317480} = "Fontainebleau";
$areanames{en}->{3317481} = "Meaux";
$areanames{en}->{3317482} = "Melun";
$areanames{en}->{3317483} = "Guyancourt";
$areanames{en}->{3317484} = "Mantes\-la\-Jolie";
$areanames{en}->{3317485} = "Massy";
$areanames{en}->{3317486} = "Juvisy\-sur\-Orge";
$areanames{en}->{3317487} = "Corbeil\-Essonnes";
$areanames{en}->{3317488} = "Bobigny";
$areanames{en}->{3317489} = "Versailles";
$areanames{en}->{3317490} = "Paris";
$areanames{en}->{3317491} = "Arpajon";
$areanames{en}->{3317492} = "Lagny\-sur\-Marne";
$areanames{en}->{3317493} = "Sarcelles";
$areanames{en}->{3317494} = "Corbeil\-Essonnes";
$areanames{en}->{3317495} = "Paris";
$areanames{en}->{3317496} = "Bobigny";
$areanames{en}->{3317497} = "Juvisy\-sur\-Orge";
$areanames{en}->{3317498} = "Massy";
$areanames{en}->{3317499} = "Beaumont\-sur\-Oise";
$areanames{en}->{3317500} = "Paris";
$areanames{en}->{3317501} = "Beaumont\-sur\-Oise";
$areanames{en}->{3317502} = "Arpajon";
$areanames{en}->{3317503} = "Rambouillet";
$areanames{en}->{3317504} = "Poissy";
$areanames{en}->{3317505} = "Meaux";
$areanames{en}->{3317506} = "Brie\-Comte\-Robert";
$areanames{en}->{3317507} = "Les\ Mureaux";
$areanames{en}->{3317508} = "Coulommiers";
$areanames{en}->{3317509} = "Mantes\-la\-Jolie";
$areanames{en}->{3317510} = "Fontainebleau";
$areanames{en}->{3317511} = "Tournan\-en\-Brie";
$areanames{en}->{3317512} = "Provins";
$areanames{en}->{3317513} = "Brie\-Comte\-Robert";
$areanames{en}->{3317514} = "Coulommiers";
$areanames{en}->{3317515} = "Fontainebleau";
$areanames{en}->{3317516} = "Lagny\-sur\-Marne";
$areanames{en}->{3317517} = "Meaux";
$areanames{en}->{3317518} = "Melun";
$areanames{en}->{3317519} = "Provins";
$areanames{en}->{3317520} = "Tournan\-en\-Brie";
$areanames{en}->{3317521} = "Guyancourt";
$areanames{en}->{3317522} = "Mantes\-la\-Jolie";
$areanames{en}->{3317523} = "Les\ Mureaux";
$areanames{en}->{3317524} = "Poissy";
$areanames{en}->{3317525} = "Rambouillet";
$areanames{en}->{3317526} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3317527} = "Versailles";
$areanames{en}->{3317528} = "Arpajon";
$areanames{en}->{3317529} = "Corbeil\-Essonnes";
$areanames{en}->{3317530} = "Juvisy\-sur\-Orge";
$areanames{en}->{3317531} = "Massy";
$areanames{en}->{3317532} = "Boulogne\-Billancourt";
$areanames{en}->{3317533} = "Nanterre";
$areanames{en}->{3317534} = "Bobigny";
$areanames{en}->{3317535} = "Le\ Raincy";
$areanames{en}->{3317536} = "Boissy\-Saint\-Léger";
$areanames{en}->{3317537} = "Créteil";
$areanames{en}->{3317538} = "Beaumont\-sur\-Oise";
$areanames{en}->{3317539} = "Cergy";
$areanames{en}->{3317540} = "Argenteuil";
$areanames{en}->{3317542} = "Paris";
$areanames{en}->{3317549} = "Boulogne\-Billancourt";
$areanames{en}->{3317550} = "Paris";
$areanames{en}->{3317551} = "Paris";
$areanames{en}->{3317552} = "Bobigny";
$areanames{en}->{3317553} = "Boulogne\-Billancourt";
$areanames{en}->{3317554} = "Nanterre";
$areanames{en}->{3317555} = "Paris";
$areanames{en}->{3317556} = "Bobigny";
$areanames{en}->{3317557} = "Paris";
$areanames{en}->{3317558} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3317559} = "Arpajon";
$areanames{en}->{3317560} = "Boulogne\-Billancourt";
$areanames{en}->{3317561} = "Nanterre";
$areanames{en}->{3317562} = "Bobigny";
$areanames{en}->{3317563} = "Le\ Raincy";
$areanames{en}->{3317564} = "Créteil";
$areanames{en}->{3317565} = "Boissy\-Saint\-Léger";
$areanames{en}->{3317566} = "Corbeil\-Essonnes";
$areanames{en}->{3317567} = "Mantes\-la\-Jolie";
$areanames{en}->{3317568} = "Enghien\-les\-Bains";
$areanames{en}->{3317569} = "Sarcelles";
$areanames{en}->{3317570} = "Beaumont\-sur\-Oise";
$areanames{en}->{3317571} = "Les\ Mureaux";
$areanames{en}->{3317572} = "Cergy";
$areanames{en}->{3317573} = "Lagny\-sur\-Marne";
$areanames{en}->{3317574} = "Mantes\-la\-Jolie";
$areanames{en}->{3317575} = "Paris";
$areanames{en}->{3317576} = "Paris";
$areanames{en}->{3317577} = "Paris";
$areanames{en}->{3317578} = "Meaux";
$areanames{en}->{3317579} = "Melun";
$areanames{en}->{3317581} = "Cergy";
$areanames{en}->{3317590} = "Tournan\-en\-Brie";
$areanames{en}->{3317591} = "Le\ Raincy";
$areanames{en}->{3317592} = "Rambouillet";
$areanames{en}->{3317593} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3317594} = "Sarcelles";
$areanames{en}->{3317595} = "Boulogne\-Billancourt";
$areanames{en}->{3317596} = "Nanterre";
$areanames{en}->{3317597} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3317598} = "Tournan\-en\-Brie";
$areanames{en}->{3317599} = "Coulommiers";
$areanames{en}->{3317600} = "Paris";
$areanames{en}->{3317601} = "Les\ Mureaux";
$areanames{en}->{3317602} = "Poissy";
$areanames{en}->{3317603} = "Rambouillet";
$areanames{en}->{3317604} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3317605} = "Versailles";
$areanames{en}->{3317606} = "Arpajon";
$areanames{en}->{3317607} = "Corbeil\-Essonnes";
$areanames{en}->{3317608} = "Juvisy\-sur\-Orge";
$areanames{en}->{3317609} = "Massy";
$areanames{en}->{3317610} = "Boulogne\-Billancourt";
$areanames{en}->{3317611} = "Nanterre";
$areanames{en}->{3317612} = "Bobigny";
$areanames{en}->{3317613} = "Le\ Raincy";
$areanames{en}->{3317614} = "Boissy\-Saint\-Léger";
$areanames{en}->{3317615} = "Créteil";
$areanames{en}->{3317616} = "Beaumont\-sur\-Oise";
$areanames{en}->{3317617} = "Cergy";
$areanames{en}->{3317618} = "Enghien\-les\-Bains";
$areanames{en}->{3317619} = "Sarcelles";
$areanames{en}->{3317620} = "Boulogne\-Billancourt";
$areanames{en}->{3317621} = "Paris";
$areanames{en}->{3317622} = "Le\ Raincy";
$areanames{en}->{3317623} = "Nanterre";
$areanames{en}->{3317624} = "Paris";
$areanames{en}->{3317625} = "Paris";
$areanames{en}->{3317626} = "Paris";
$areanames{en}->{3317627} = "Nanterre";
$areanames{en}->{3317628} = "Créteil";
$areanames{en}->{3317629} = "Enghien\-les\-Bains";
$areanames{en}->{3317630} = "Boissy\-Saint\-Léger";
$areanames{en}->{3317631} = "Corbeil\-Essonnes";
$areanames{en}->{3317632} = "Paris";
$areanames{en}->{3317633} = "Guyancourt";
$areanames{en}->{3317634} = "Meaux";
$areanames{en}->{3317635} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3317636} = "Bobigny";
$areanames{en}->{3317637} = "Paris";
$areanames{en}->{3317638} = "Versailles";
$areanames{en}->{3317639} = "Cergy";
$areanames{en}->{3317640} = "Nanterre";
$areanames{en}->{3317641} = "Le\ Raincy";
$areanames{en}->{3317642} = "Sarcelles";
$areanames{en}->{3317643} = "Boulogne\-Billancourt";
$areanames{en}->{3317644} = "Enghien\-les\-Bains";
$areanames{en}->{3317645} = "Paris";
$areanames{en}->{3317646} = "Créteil";
$areanames{en}->{3317647} = "Nanterre";
$areanames{en}->{3317648} = "Paris";
$areanames{en}->{3317649} = "Paris";
$areanames{en}->{3317650} = "Paris";
$areanames{en}->{3317652} = "Guyancourt";
$areanames{en}->{3317653} = "Paris";
$areanames{en}->{3317654} = "Nanterre";
$areanames{en}->{3317655} = "Meaux";
$areanames{en}->{3317656} = "Paris";
$areanames{en}->{3317657} = "Créteil";
$areanames{en}->{3317658} = "Bobigny";
$areanames{en}->{3317659} = "Brie\-Comte\-Robert";
$areanames{en}->{331766} = "Paris";
$areanames{en}->{3317661} = "Boulogne\-Billancourt";
$areanames{en}->{3317666} = "Nanterre";
$areanames{en}->{3317669} = "Nanterre";
$areanames{en}->{331767} = "Paris";
$areanames{en}->{3317678} = "Guyancourt";
$areanames{en}->{3317679} = "Mantes\-la\-Jolie";
$areanames{en}->{3317680} = "Boulogne\-Billancourt";
$areanames{en}->{3317681} = "Cergy";
$areanames{en}->{3317682} = "Les\ Mureaux";
$areanames{en}->{3317683} = "Arpajon";
$areanames{en}->{3317684} = "Boulogne\-Billancourt";
$areanames{en}->{3317685} = "Nanterre";
$areanames{en}->{3317686} = "Guyancourt";
$areanames{en}->{3317687} = "Guyancourt";
$areanames{en}->{3317688} = "Guyancourt";
$areanames{en}->{3317689} = "Boulogne\-Billancourt";
$areanames{en}->{3317690} = "Paris";
$areanames{en}->{3317691} = "Massy";
$areanames{en}->{3317692} = "Coulommiers";
$areanames{en}->{3317693} = "Fontainebleau";
$areanames{en}->{3317694} = "Lagny\-sur\-Marne";
$areanames{en}->{3317695} = "Cergy";
$areanames{en}->{3317696} = "Melun";
$areanames{en}->{3317697} = "Provins";
$areanames{en}->{3317698} = "Tournan\-en\-Brie";
$areanames{en}->{3317699} = "Guyancourt";
$areanames{en}->{3317702} = "Argenteuil";
$areanames{en}->{331771} = "Paris";
$areanames{en}->{3317720} = "Créteil";
$areanames{en}->{3317721} = "Créteil";
$areanames{en}->{3317722} = "Créteil";
$areanames{en}->{3317723} = "Créteil";
$areanames{en}->{3317724} = "Boulogne\-Billancourt";
$areanames{en}->{3317725} = "Boulogne\-Billancourt";
$areanames{en}->{3317726} = "Boulogne\-Billancourt";
$areanames{en}->{3317727} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3317728} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3317729} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3317730} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3317731} = "Massy";
$areanames{en}->{3317732} = "Paris";
$areanames{en}->{3317733} = "Cergy";
$areanames{en}->{3317734} = "Arpajon";
$areanames{en}->{3317735} = "Meaux";
$areanames{en}->{3317736} = "Versailles";
$areanames{en}->{3317737} = "Corbeil\-Essonnes";
$areanames{en}->{3317738} = "Boulogne\-Billancourt";
$areanames{en}->{3317739} = "Bobigny";
$areanames{en}->{331774} = "Paris";
$areanames{en}->{3317741} = "Bobigny";
$areanames{en}->{3317746} = "Boulogne\-Billancourt";
$areanames{en}->{3317747} = "Créteil";
$areanames{en}->{3317749} = "Nanterre";
$areanames{en}->{3317750} = "Enghien\-les\-Bains";
$areanames{en}->{3317751} = "Nanterre";
$areanames{en}->{3317752} = "Mantes\-la\-Jolie";
$areanames{en}->{3317753} = "Les\ Mureaux";
$areanames{en}->{3317754} = "Poissy";
$areanames{en}->{3317755} = "Rambouillet";
$areanames{en}->{3317756} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3317757} = "Arpajon";
$areanames{en}->{3317758} = "Corbeil\-Essonnes";
$areanames{en}->{3317759} = "Fontainebleau";
$areanames{en}->{3317760} = "Bobigny";
$areanames{en}->{3317761} = "Boissy\-Saint\-Léger";
$areanames{en}->{3317762} = "Beaumont\-sur\-Oise";
$areanames{en}->{3317763} = "Cergy";
$areanames{en}->{3317764} = "Paris";
$areanames{en}->{3317765} = "Sarcelles";
$areanames{en}->{3317766} = "Enghien\-les\-Bains";
$areanames{en}->{3317767} = "Créteil";
$areanames{en}->{3317768} = "Nanterre";
$areanames{en}->{3317769} = "Nanterre";
$areanames{en}->{3317770} = "Boulogne\-Billancourt";
$areanames{en}->{3317771} = "Versailles";
$areanames{en}->{3317772} = "Paris";
$areanames{en}->{3317773} = "Nanterre";
$areanames{en}->{3317774} = "Créteil";
$areanames{en}->{3317775} = "Paris";
$areanames{en}->{3317776} = "Le\ Raincy";
$areanames{en}->{3317777} = "Melun";
$areanames{en}->{3317778} = "Versailles";
$areanames{en}->{3317779} = "Boissy\-Saint\-Léger";
$areanames{en}->{3317780} = "Sarcelles";
$areanames{en}->{3317781} = "Boissy\-Saint\-Léger";
$areanames{en}->{3317782} = "Lagny\-sur\-Marne";
$areanames{en}->{3317783} = "Melun";
$areanames{en}->{3317784} = "Melun";
$areanames{en}->{3317785} = "Créteil";
$areanames{en}->{3317786} = "Boulogne\-Billancourt";
$areanames{en}->{3317787} = "Boulogne\-Billancourt";
$areanames{en}->{3317788} = "Nanterre";
$areanames{en}->{3317789} = "Juvisy\-sur\-Orge";
$areanames{en}->{3317790} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3317791} = "Corbeil\-Essonnes";
$areanames{en}->{3317792} = "Boulogne\-Billancourt";
$areanames{en}->{3317793} = "Bobigny";
$areanames{en}->{3317794} = "Créteil";
$areanames{en}->{3317795} = "Cergy";
$areanames{en}->{3317796} = "Massy";
$areanames{en}->{3317797} = "Corbeil\-Essonnes";
$areanames{en}->{3317798} = "Bobigny";
$areanames{en}->{3317799} = "Créteil";
$areanames{en}->{3317800} = "Meaux";
$areanames{en}->{3317801} = "Paris";
$areanames{en}->{3317802} = "Paris";
$areanames{en}->{3317803} = "Paris";
$areanames{en}->{3317804} = "Tournan\-en\-Brie";
$areanames{en}->{3317805} = "Corbeil\-Essonnes";
$areanames{en}->{3317806} = "Enghien\-les\-Bains";
$areanames{en}->{3317807} = "Le\ Raincy";
$areanames{en}->{3317808} = "Bobigny";
$areanames{en}->{3317809} = "Paris";
$areanames{en}->{3317810} = "Paris";
$areanames{en}->{3317811} = "Paris";
$areanames{en}->{3317812} = "Créteil";
$areanames{en}->{3317813} = "Créteil";
$areanames{en}->{3317814} = "Nanterre";
$areanames{en}->{3317815} = "Nanterre";
$areanames{en}->{3317816} = "Boulogne\-Billancourt";
$areanames{en}->{3317817} = "Enghien\-les\-Bains";
$areanames{en}->{3317818} = "Juvisy\-sur\-Orge";
$areanames{en}->{3317819} = "Massy";
$areanames{en}->{3317820} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3317821} = "Guyancourt";
$areanames{en}->{3317822} = "Versailles";
$areanames{en}->{3317823} = "Poissy";
$areanames{en}->{3317824} = "Mantes\-la\-Jolie";
$areanames{en}->{3317825} = "Boulogne\-Billancourt";
$areanames{en}->{3317826} = "Nanterre";
$areanames{en}->{3317827} = "Bobigny";
$areanames{en}->{3317828} = "Créteil";
$areanames{en}->{3317829} = "Créteil";
$areanames{en}->{3317830} = "Enghien\-les\-Bains";
$areanames{en}->{3317831} = "Cergy";
$areanames{en}->{3317832} = "Sarcelles";
$areanames{en}->{3317833} = "Paris";
$areanames{en}->{3317834} = "Paris";
$areanames{en}->{3317835} = "Le\ Raincy";
$areanames{en}->{3317836} = "Corbeil\-Essonnes";
$areanames{en}->{3317837} = "Lagny\-sur\-Marne";
$areanames{en}->{3317838} = "Guyancourt";
$areanames{en}->{3317839} = "Versailles";
$areanames{en}->{3317840} = "Paris";
$areanames{en}->{3317841} = "Paris";
$areanames{en}->{3317842} = "Paris";
$areanames{en}->{3317843} = "Cergy";
$areanames{en}->{3317844} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3317845} = "Bobigny";
$areanames{en}->{3317846} = "Boulogne\-Billancourt";
$areanames{en}->{3317847} = "Cergy";
$areanames{en}->{3317848} = "Brie\-Comte\-Robert";
$areanames{en}->{3317849} = "Melun";
$areanames{en}->{3317852} = "Versailles";
$areanames{en}->{3317853} = "Asnières\-sur\-Seine";
$areanames{en}->{3317854} = "Créteil";
$areanames{en}->{3317860} = "Arpajon";
$areanames{en}->{3317861} = "Corbeil\-Essonnes";
$areanames{en}->{3317862} = "Lagny\-sur\-Marne";
$areanames{en}->{3317863} = "Poissy";
$areanames{en}->{3317864} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3317865} = "Arpajon";
$areanames{en}->{3317866} = "Nanterre";
$areanames{en}->{3317867} = "Paris";
$areanames{en}->{3317868} = "Créteil";
$areanames{en}->{3317869} = "Beaumont\-sur\-Oise";
$areanames{en}->{3317870} = "Enghien\-les\-Bains";
$areanames{en}->{3317871} = "Meaux";
$areanames{en}->{3317872} = "Mantes\-la\-Jolie";
$areanames{en}->{3317873} = "Les\ Mureaux";
$areanames{en}->{3317874} = "Versailles";
$areanames{en}->{3317875} = "Juvisy\-sur\-Orge";
$areanames{en}->{3317876} = "Boulogne\-Billancourt";
$areanames{en}->{3317877} = "Le\ Raincy";
$areanames{en}->{3317878} = "Le\ Raincy";
$areanames{en}->{3317879} = "Provins";
$areanames{en}->{3317880} = "Les\ Mureaux";
$areanames{en}->{3317881} = "Nanterre";
$areanames{en}->{3317882} = "Rambouillet";
$areanames{en}->{3317883} = "Arpajon";
$areanames{en}->{3317884} = "Juvisy\-sur\-Orge";
$areanames{en}->{3317885} = "Massy";
$areanames{en}->{3317886} = "Beaumont\-sur\-Oise";
$areanames{en}->{3317887} = "Bobigny";
$areanames{en}->{3317888} = "Boissy\-Saint\-Léger";
$areanames{en}->{3317889} = "Boulogne\-Billancourt";
$areanames{en}->{3317890} = "Paris";
$areanames{en}->{3317891} = "Paris";
$areanames{en}->{3317892} = "Boulogne\-Billancourt";
$areanames{en}->{3317893} = "Enghien\-les\-Bains";
$areanames{en}->{3317894} = "Paris";
$areanames{en}->{3317895} = "Paris";
$areanames{en}->{3317896} = "Paris";
$areanames{en}->{3317897} = "Rambouillet";
$areanames{en}->{3317898} = "Nanterre";
$areanames{en}->{3317899} = "Nanterre";
$areanames{en}->{3317900} = "Arpajon";
$areanames{en}->{3317901} = "Brie\-Comte\-Robert";
$areanames{en}->{3317902} = "Arpajon";
$areanames{en}->{3317903} = "Beaumont\-sur\-Oise";
$areanames{en}->{3317904} = "Bobigny";
$areanames{en}->{3317905} = "Boissy\-Saint\-Léger";
$areanames{en}->{3317906} = "Boulogne\-Billancourt";
$areanames{en}->{3317907} = "Brie\-Comte\-Robert";
$areanames{en}->{3317908} = "Cergy";
$areanames{en}->{3317909} = "Provins";
$areanames{en}->{3317910} = "Corbeil\-Essonnes";
$areanames{en}->{3317911} = "Créteil";
$areanames{en}->{3317912} = "Enghien\-les\-Bains";
$areanames{en}->{3317913} = "Fontainebleau";
$areanames{en}->{3317914} = "Guyancourt";
$areanames{en}->{3317915} = "Juvisy\-sur\-Orge";
$areanames{en}->{3317916} = "Lagny\-sur\-Marne";
$areanames{en}->{3317917} = "Le\ Raincy";
$areanames{en}->{3317918} = "Les\ Mureaux";
$areanames{en}->{3317919} = "Fontainebleau";
$areanames{en}->{3317920} = "Mantes\-la\-Jolie";
$areanames{en}->{3317921} = "Massy";
$areanames{en}->{3317922} = "Meaux";
$areanames{en}->{3317923} = "Melun";
$areanames{en}->{3317924} = "Nanterre";
$areanames{en}->{3317925} = "Paris";
$areanames{en}->{3317926} = "Poissy";
$areanames{en}->{3317927} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3317928} = "Sarcelles";
$areanames{en}->{3317929} = "Versailles";
$areanames{en}->{3317930} = "Rueil\-Malmaison";
$areanames{en}->{3317940} = "Boissy\-Saint\-Léger";
$areanames{en}->{3317941} = "Boulogne\-Billancourt";
$areanames{en}->{3317942} = "Cergy";
$areanames{en}->{3317943} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3317944} = "Beaumont\-sur\-Oise";
$areanames{en}->{3317945} = "Meaux";
$areanames{en}->{3317946} = "Boulogne\-Billancourt";
$areanames{en}->{3317947} = "Corbeil\-Essonnes";
$areanames{en}->{3317948} = "Coulommiers";
$areanames{en}->{3317949} = "Juvisy\-sur\-Orge";
$areanames{en}->{3317951} = "Argenteuil";
$areanames{en}->{3317956} = "Créteil";
$areanames{en}->{3317960} = "Créteil";
$areanames{en}->{3317961} = "Créteil";
$areanames{en}->{3317962} = "Nanterre";
$areanames{en}->{3317963} = "Bobigny";
$areanames{en}->{3317964} = "Bobigny";
$areanames{en}->{3317965} = "Sarcelles";
$areanames{en}->{3317966} = "Cergy";
$areanames{en}->{3317967} = "Les\ Mureaux";
$areanames{en}->{3317968} = "Boissy\-Saint\-Léger";
$areanames{en}->{3317969} = "Mantes\-la\-Jolie";
$areanames{en}->{3317970} = "Nanterre";
$areanames{en}->{3317971} = "Boulogne\-Billancourt";
$areanames{en}->{3317972} = "Nanterre";
$areanames{en}->{3317973} = "Boulogne\-Billancourt";
$areanames{en}->{3317974} = "Brie\-Comte\-Robert";
$areanames{en}->{3317975} = "Paris";
$areanames{en}->{3317976} = "Melun";
$areanames{en}->{3317977} = "Coulommiers";
$areanames{en}->{3317978} = "Lagny\-sur\-Marne";
$areanames{en}->{3317979} = "Meaux";
$areanames{en}->{3317980} = "Tournan\-en\-Brie";
$areanames{en}->{3317981} = "Cergy";
$areanames{en}->{3317982} = "Corbeil\-Essonnes";
$areanames{en}->{3317983} = "Coulommiers";
$areanames{en}->{3317984} = "Créteil";
$areanames{en}->{3317985} = "Paris";
$areanames{en}->{3317986} = "Créteil";
$areanames{en}->{3317987} = "Enghien\-les\-Bains";
$areanames{en}->{3317988} = "Corbeil\-Essonnes";
$areanames{en}->{3317989} = "Guyancourt";
$areanames{en}->{3317990} = "Le\ Raincy";
$areanames{en}->{3317991} = "Fontainebleau";
$areanames{en}->{3317992} = "Guyancourt";
$areanames{en}->{3317993} = "Juvisy\-sur\-Orge";
$areanames{en}->{3317994} = "Lagny\-sur\-Marne";
$areanames{en}->{3317995} = "Le\ Raincy";
$areanames{en}->{3317996} = "Les\ Mureaux";
$areanames{en}->{3317997} = "Paris";
$areanames{en}->{3317998} = "Mantes\-la\-Jolie";
$areanames{en}->{3317999} = "Paris";
$areanames{en}->{3318000} = "Massy";
$areanames{en}->{3318001} = "Meaux";
$areanames{en}->{3318002} = "Melun";
$areanames{en}->{3318003} = "Nanterre";
$areanames{en}->{3318004} = "Nanterre";
$areanames{en}->{3318005} = "Paris";
$areanames{en}->{3318006} = "Paris";
$areanames{en}->{3318007} = "Poissy";
$areanames{en}->{3318008} = "Provins";
$areanames{en}->{3318009} = "Rambouillet";
$areanames{en}->{3318010} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3318011} = "Sarcelles";
$areanames{en}->{3318012} = "Tournan\-en\-Brie";
$areanames{en}->{3318013} = "Versailles";
$areanames{en}->{3318014} = "Paris";
$areanames{en}->{3318015} = "Arpajon";
$areanames{en}->{3318016} = "Créteil";
$areanames{en}->{3318017} = "Le\ Raincy";
$areanames{en}->{3318018} = "Paris";
$areanames{en}->{3318019} = "Sarcelles";
$areanames{en}->{3318020} = "Paris";
$areanames{en}->{3318021} = "Nanterre";
$areanames{en}->{3318022} = "Boulogne\-Billancourt";
$areanames{en}->{3318023} = "Bobigny";
$areanames{en}->{3318024} = "Le\ Raincy";
$areanames{en}->{3318025} = "Créteil";
$areanames{en}->{3318026} = "Boissy\-Saint\-Léger";
$areanames{en}->{3318027} = "Paris";
$areanames{en}->{3318028} = "Guyancourt";
$areanames{en}->{3318029} = "Guyancourt";
$areanames{en}->{3318030} = "Nanterre";
$areanames{en}->{3318031} = "Massy";
$areanames{en}->{3318032} = "Juvisy\-sur\-Orge";
$areanames{en}->{3318033} = "Corbeil\-Essonnes";
$areanames{en}->{3318034} = "Cergy";
$areanames{en}->{3318035} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3318036} = "Arpajon";
$areanames{en}->{3318037} = "Juvisy\-sur\-Orge";
$areanames{en}->{3318038} = "Massy";
$areanames{en}->{3318039} = "Melun";
$areanames{en}->{3318040} = "Paris";
$areanames{en}->{3318041} = "Boulogne\-Billancourt";
$areanames{en}->{3318042} = "Nanterre";
$areanames{en}->{3318043} = "Bobigny";
$areanames{en}->{3318044} = "Le\ Raincy";
$areanames{en}->{3318045} = "Créteil";
$areanames{en}->{3318046} = "Nanterre";
$areanames{en}->{3318047} = "Juvisy\-sur\-Orge";
$areanames{en}->{3318048} = "Paris";
$areanames{en}->{3318049} = "Paris";
$areanames{en}->{3318050} = "Paris";
$areanames{en}->{3318051} = "Créteil";
$areanames{en}->{3318052} = "Paris";
$areanames{en}->{3318053} = "Paris";
$areanames{en}->{3318054} = "Paris";
$areanames{en}->{3318055} = "Guyancourt";
$areanames{en}->{3318056} = "Massy";
$areanames{en}->{3318057} = "Juvisy\-sur\-Orge";
$areanames{en}->{3318058} = "Corbeil\-Essonnes";
$areanames{en}->{3318059} = "Cergy";
$areanames{en}->{3318060} = "Bobigny";
$areanames{en}->{3318061} = "Guyancourt";
$areanames{en}->{3318062} = "Le\ Raincy";
$areanames{en}->{3318063} = "Brie\-Comte\-Robert";
$areanames{en}->{3318064} = "Coulommiers";
$areanames{en}->{3318065} = "Fontainebleau";
$areanames{en}->{3318066} = "Lagny\-sur\-Marne";
$areanames{en}->{3318067} = "Meaux";
$areanames{en}->{3318068} = "Melun";
$areanames{en}->{3318069} = "Provins";
$areanames{en}->{3318070} = "Tournan\-en\-Brie";
$areanames{en}->{3318071} = "Guyancourt";
$areanames{en}->{3318072} = "Mantes\-la\-Jolie";
$areanames{en}->{3318073} = "Boulogne\-Billancourt";
$areanames{en}->{3318074} = "Arpajon";
$areanames{en}->{3318075} = "Massy";
$areanames{en}->{3318076} = "Rambouillet";
$areanames{en}->{3318077} = "Versailles";
$areanames{en}->{3318078} = "Guyancourt";
$areanames{en}->{3318079} = "Juvisy\-sur\-Orge";
$areanames{en}->{3318080} = "Boulogne\-Billancourt";
$areanames{en}->{3318081} = "Lagny\-sur\-Marne";
$areanames{en}->{3318082} = "Guyancourt";
$areanames{en}->{3318083} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3318084} = "Versailles";
$areanames{en}->{3318085} = "Corbeil\-Essonnes";
$areanames{en}->{3318086} = "Massy";
$areanames{en}->{3318087} = "Boulogne\-Billancourt";
$areanames{en}->{3318088} = "Nanterre";
$areanames{en}->{3318089} = "Bobigny";
$areanames{en}->{3318090} = "Le\ Raincy";
$areanames{en}->{3318091} = "Créteil";
$areanames{en}->{3318092} = "Cergy";
$areanames{en}->{3318093} = "Boulogne\-Billancourt";
$areanames{en}->{3318094} = "Paris";
$areanames{en}->{3318095} = "Paris";
$areanames{en}->{3318096} = "Paris";
$areanames{en}->{3318097} = "Paris";
$areanames{en}->{3318098} = "Paris";
$areanames{en}->{3318099} = "Les\ Mureaux";
$areanames{en}->{3318100} = "Guyancourt";
$areanames{en}->{3318101} = "Mantes\-la\-Jolie";
$areanames{en}->{3318102} = "Les\ Mureaux";
$areanames{en}->{3318103} = "Poissy";
$areanames{en}->{3318104} = "Rambouillet";
$areanames{en}->{3318105} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3318106} = "Arpajon";
$areanames{en}->{3318107} = "Corbeil\-Essonnes";
$areanames{en}->{3318108} = "Juvisy\-sur\-Orge";
$areanames{en}->{3318109} = "Le\ Raincy";
$areanames{en}->{3318110} = "Boissy\-Saint\-Léger";
$areanames{en}->{3318111} = "Beaumont\-sur\-Oise";
$areanames{en}->{3318112} = "Enghien\-les\-Bains";
$areanames{en}->{3318113} = "Sarcelles";
$areanames{en}->{3318114} = "Brie\-Comte\-Robert";
$areanames{en}->{3318115} = "Coulommiers";
$areanames{en}->{3318116} = "Lagny\-sur\-Marne";
$areanames{en}->{3318117} = "Meaux";
$areanames{en}->{3318118} = "Melun";
$areanames{en}->{3318119} = "Provins";
$areanames{en}->{3318120} = "Tournan\-en\-Brie";
$areanames{en}->{3318121} = "Le\ Raincy";
$areanames{en}->{3318122} = "Massy";
$areanames{en}->{3318123} = "Poissy";
$areanames{en}->{3318124} = "Rambouillet";
$areanames{en}->{3318125} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3318126} = "Versailles";
$areanames{en}->{3318127} = "Arpajon";
$areanames{en}->{3318128} = "Corbeil\-Essonnes";
$areanames{en}->{3318129} = "Paris";
$areanames{en}->{3318130} = "Massy";
$areanames{en}->{3318131} = "Beaumont\-sur\-Oise";
$areanames{en}->{3318132} = "Cergy";
$areanames{en}->{3318133} = "Enghien\-les\-Bains";
$areanames{en}->{3318134} = "Sarcelles";
$areanames{en}->{3318135} = "Melun";
$areanames{en}->{3318136} = "Provins";
$areanames{en}->{3318137} = "Tournan\-en\-Brie";
$areanames{en}->{3318138} = "Guyancourt";
$areanames{en}->{3318139} = "Mantes\-la\-Jolie";
$areanames{en}->{3318140} = "Les\ Mureaux";
$areanames{en}->{3318141} = "Poissy";
$areanames{en}->{3318142} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3318143} = "Versailles";
$areanames{en}->{3318144} = "Arpajon";
$areanames{en}->{3318145} = "Corbeil\-Essonnes";
$areanames{en}->{3318146} = "Juvisy\-sur\-Orge";
$areanames{en}->{3318147} = "Massy";
$areanames{en}->{3318148} = "Boulogne\-Billancourt";
$areanames{en}->{3318149} = "Nanterre";
$areanames{en}->{3318150} = "Paris";
$areanames{en}->{3318151} = "Paris";
$areanames{en}->{3318152} = "Boissy\-Saint\-Léger";
$areanames{en}->{3318153} = "Créteil";
$areanames{en}->{3318154} = "Beaumont\-sur\-Oise";
$areanames{en}->{3318155} = "Cergy";
$areanames{en}->{3318156} = "Enghien\-les\-Bains";
$areanames{en}->{3318157} = "Sarcelles";
$areanames{en}->{3318158} = "Brie\-Comte\-Robert";
$areanames{en}->{3318159} = "Bobigny";
$areanames{en}->{3318160} = "Le\ Raincy";
$areanames{en}->{3318161} = "Paris";
$areanames{en}->{3318162} = "Paris";
$areanames{en}->{3318163} = "Paris";
$areanames{en}->{3318164} = "Boulogne\-Billancourt";
$areanames{en}->{3318165} = "Fontainebleau";
$areanames{en}->{3318166} = "Lagny\-sur\-Marne";
$areanames{en}->{3318167} = "Meaux";
$areanames{en}->{3318168} = "Nanterre";
$areanames{en}->{3318169} = "Paris";
$areanames{en}->{3318170} = "Paris";
$areanames{en}->{3318171} = "Nanterre";
$areanames{en}->{3318172} = "Paris";
$areanames{en}->{3318173} = "Meaux";
$areanames{en}->{3318174} = "Melun";
$areanames{en}->{3318175} = "Guyancourt";
$areanames{en}->{3318176} = "Poissy";
$areanames{en}->{3318177} = "Fontainebleau";
$areanames{en}->{3318178} = "Versailles";
$areanames{en}->{3318179} = "Corbeil\-Essonnes";
$areanames{en}->{3318180} = "Paris";
$areanames{en}->{3318181} = "Bobigny";
$areanames{en}->{3318182} = "Rambouillet";
$areanames{en}->{3318183} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3318184} = "Arpajon";
$areanames{en}->{3318185} = "Corbeil\-Essonnes";
$areanames{en}->{3318186} = "Juvisy\-sur\-Orge";
$areanames{en}->{3318187} = "Massy";
$areanames{en}->{3318188} = "Guyancourt";
$areanames{en}->{3318189} = "Boulogne\-Billancourt";
$areanames{en}->{3318190} = "Paris";
$areanames{en}->{3318191} = "Massy";
$areanames{en}->{3318192} = "Nanterre";
$areanames{en}->{3318193} = "Nanterre";
$areanames{en}->{3318194} = "Créteil";
$areanames{en}->{3318195} = "Cergy";
$areanames{en}->{3318196} = "Nanterre";
$areanames{en}->{3318197} = "Nanterre";
$areanames{en}->{3318198} = "Boulogne\-Billancourt";
$areanames{en}->{3318199} = "Boulogne\-Billancourt";
$areanames{en}->{3318200} = "Boulogne\-Billancourt";
$areanames{en}->{3318201} = "Créteil";
$areanames{en}->{3318202} = "Bobigny";
$areanames{en}->{3318203} = "Poissy";
$areanames{en}->{3318204} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3318205} = "Corbeil\-Essonnes";
$areanames{en}->{3318206} = "Enghien\-les\-Bains";
$areanames{en}->{3318207} = "Paris";
$areanames{en}->{3318208} = "Versailles";
$areanames{en}->{3318209} = "Paris";
$areanames{en}->{3318210} = "Paris";
$areanames{en}->{3318211} = "Paris";
$areanames{en}->{3318212} = "Paris";
$areanames{en}->{3318213} = "Bobigny";
$areanames{en}->{3318214} = "Nanterre";
$areanames{en}->{3318215} = "Boulogne\-Billancourt";
$areanames{en}->{3318216} = "Provins";
$areanames{en}->{3318217} = "Mantes\-la\-Jolie";
$areanames{en}->{3318218} = "Rambouillet";
$areanames{en}->{3318219} = "Poissy";
$areanames{en}->{3318220} = "Guyancourt";
$areanames{en}->{3318221} = "Tournan\-en\-Brie";
$areanames{en}->{3318222} = "Meaux";
$areanames{en}->{3318223} = "Coulommiers";
$areanames{en}->{3318224} = "Nanterre";
$areanames{en}->{3318225} = "Melun";
$areanames{en}->{3318226} = "Juvisy\-sur\-Orge";
$areanames{en}->{3318227} = "Enghien\-les\-Bains";
$areanames{en}->{3318228} = "Paris";
$areanames{en}->{3318229} = "Beaumont\-sur\-Oise";
$areanames{en}->{3318230} = "Bobigny";
$areanames{en}->{3318231} = "Cergy";
$areanames{en}->{3318232} = "Sarcelles";
$areanames{en}->{3318233} = "Brie\-Comte\-Robert";
$areanames{en}->{3318234} = "Fontainebleau";
$areanames{en}->{3318235} = "Lagny\-sur\-Marne";
$areanames{en}->{3318236} = "Mantes\-la\-Jolie";
$areanames{en}->{3318237} = "Le\ Raincy";
$areanames{en}->{3318238} = "Boissy\-Saint\-Léger";
$areanames{en}->{3318239} = "Créteil";
$areanames{en}->{3318240} = "Beaumont\-sur\-Oise";
$areanames{en}->{3318241} = "Enghien\-les\-Bains";
$areanames{en}->{3318242} = "Poissy";
$areanames{en}->{3318243} = "Corbeil\-Essonnes";
$areanames{en}->{3318244} = "Cergy";
$areanames{en}->{3318245} = "Sarcelles";
$areanames{en}->{3318246} = "Bobigny";
$areanames{en}->{3318247} = "Lagny\-sur\-Marne";
$areanames{en}->{3318248} = "Boulogne\-Billancourt";
$areanames{en}->{3318249} = "Versailles";
$areanames{en}->{3318250} = "Paris";
$areanames{en}->{3318251} = "Paris";
$areanames{en}->{3318252} = "Paris";
$areanames{en}->{3318253} = "Paris";
$areanames{en}->{3318254} = "Boulogne\-Billancourt";
$areanames{en}->{3318255} = "Boulogne\-Billancourt";
$areanames{en}->{3318256} = "Nanterre";
$areanames{en}->{3318257} = "Nanterre";
$areanames{en}->{3318258} = "Nanterre";
$areanames{en}->{3318259} = "Les\ Mureaux";
$areanames{en}->{3318260} = "Arpajon";
$areanames{en}->{3318261} = "Guyancourt";
$areanames{en}->{3318262} = "Fontainebleau";
$areanames{en}->{3318263} = "Paris";
$areanames{en}->{3318264} = "Nanterre";
$areanames{en}->{3318265} = "Créteil";
$areanames{en}->{3318266} = "Boissy\-Saint\-Léger";
$areanames{en}->{3318267} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3318268} = "Les\ Mureaux";
$areanames{en}->{3318269} = "Créteil";
$areanames{en}->{3318270} = "Brie\-Comte\-Robert";
$areanames{en}->{3318271} = "Le\ Raincy";
$areanames{en}->{3318272} = "Massy";
$areanames{en}->{3318273} = "Paris";
$areanames{en}->{3318274} = "Brie\-Comte\-Robert";
$areanames{en}->{3318275} = "Coulommiers";
$areanames{en}->{3318276} = "Fontainebleau";
$areanames{en}->{3318277} = "Lagny\-sur\-Marne";
$areanames{en}->{3318278} = "Meaux";
$areanames{en}->{3318279} = "Melun";
$areanames{en}->{3318280} = "Provins";
$areanames{en}->{3318281} = "Tournan\-en\-Brie";
$areanames{en}->{3318282} = "Paris";
$areanames{en}->{3318283} = "Paris";
$areanames{en}->{3318284} = "Guyancourt";
$areanames{en}->{3318285} = "Mantes\-la\-Jolie";
$areanames{en}->{3318286} = "Les\ Mureaux";
$areanames{en}->{3318287} = "Poissy";
$areanames{en}->{3318288} = "Paris";
$areanames{en}->{3318289} = "Rambouillet";
$areanames{en}->{3318290} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3318291} = "Versailles";
$areanames{en}->{3318292} = "Arpajon";
$areanames{en}->{3318293} = "Corbeil\-Essonnes";
$areanames{en}->{3318294} = "Juvisy\-sur\-Orge";
$areanames{en}->{3318295} = "Massy";
$areanames{en}->{3318296} = "Boulogne\-Billancourt";
$areanames{en}->{3318297} = "Nanterre";
$areanames{en}->{3318298} = "Bobigny";
$areanames{en}->{3318299} = "Le\ Raincy";
$areanames{en}->{3318300} = "Boissy\-Saint\-Léger";
$areanames{en}->{3318301} = "Créteil";
$areanames{en}->{3318302} = "Beaumont\-sur\-Oise";
$areanames{en}->{3318303} = "Cergy";
$areanames{en}->{3318304} = "Enghien\-les\-Bains";
$areanames{en}->{3318305} = "Sarcelles";
$areanames{en}->{3318306} = "Paris";
$areanames{en}->{3318307} = "Arpajon";
$areanames{en}->{3318308} = "Beaumont\-sur\-Oise";
$areanames{en}->{3318309} = "Bobigny";
$areanames{en}->{3318310} = "Boissy\-Saint\-Léger";
$areanames{en}->{3318311} = "Boulogne\-Billancourt";
$areanames{en}->{3318312} = "Brie\-Comte\-Robert";
$areanames{en}->{3318313} = "Cergy";
$areanames{en}->{3318314} = "Corbeil\-Essonnes";
$areanames{en}->{3318315} = "Coulommiers";
$areanames{en}->{3318316} = "Melun";
$areanames{en}->{3318317} = "Nanterre";
$areanames{en}->{3318318} = "Paris";
$areanames{en}->{3318319} = "Poissy";
$areanames{en}->{3318320} = "Provins";
$areanames{en}->{3318321} = "Rambouillet";
$areanames{en}->{3318322} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3318323} = "Sarcelles";
$areanames{en}->{3318324} = "Tournan\-en\-Brie";
$areanames{en}->{3318325} = "Versailles";
$areanames{en}->{3318326} = "Meaux";
$areanames{en}->{3318327} = "Enghien\-les\-Bains";
$areanames{en}->{3318328} = "Fontainebleau";
$areanames{en}->{3318329} = "Guyancourt";
$areanames{en}->{3318330} = "Juvisy\-sur\-Orge";
$areanames{en}->{3318331} = "Lagny\-sur\-Marne";
$areanames{en}->{3318332} = "Les\ Mureaux";
$areanames{en}->{3318333} = "Mantes\-la\-Jolie";
$areanames{en}->{3318334} = "Massy";
$areanames{en}->{3318335} = "Paris";
$areanames{en}->{3318336} = "Rambouillet";
$areanames{en}->{3318337} = "Bobigny";
$areanames{en}->{3318338} = "Meaux";
$areanames{en}->{3318339} = "Boulogne\-Billancourt";
$areanames{en}->{3318340} = "Brie\-Comte\-Robert";
$areanames{en}->{3318341} = "Corbeil\-Essonnes";
$areanames{en}->{3318342} = "Créteil";
$areanames{en}->{3318343} = "Poissy";
$areanames{en}->{3318344} = "Enghien\-les\-Bains";
$areanames{en}->{3318345} = "Guyancourt";
$areanames{en}->{3318346} = "Juvisy\-sur\-Orge";
$areanames{en}->{3318347} = "Lagny\-sur\-Marne";
$areanames{en}->{3318348} = "Le\ Raincy";
$areanames{en}->{3318349} = "Mantes\-la\-Jolie";
$areanames{en}->{3318350} = "Massy";
$areanames{en}->{3318351} = "Meaux";
$areanames{en}->{3318352} = "Melun";
$areanames{en}->{3318353} = "Juvisy\-sur\-Orge";
$areanames{en}->{3318354} = "Les\ Mureaux";
$areanames{en}->{3318355} = "Nanterre";
$areanames{en}->{3318356} = "Paris";
$areanames{en}->{3318357} = "Poissy";
$areanames{en}->{3318358} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3318359} = "Versailles";
$areanames{en}->{3318360} = "Sarcelles";
$areanames{en}->{3318361} = "Juvisy\-sur\-Orge";
$areanames{en}->{3318362} = "Paris";
$areanames{en}->{3318363} = "Arpajon";
$areanames{en}->{3318364} = "Paris";
$areanames{en}->{3318365} = "Paris";
$areanames{en}->{3318366} = "Bobigny";
$areanames{en}->{3318367} = "Nanterre";
$areanames{en}->{3318368} = "Créteil";
$areanames{en}->{3318369} = "Meaux";
$areanames{en}->{3318372} = "Saint\-Denis";
$areanames{en}->{3318380} = "Paris";
$areanames{en}->{3318381} = "Paris";
$areanames{en}->{3318382} = "Versailles";
$areanames{en}->{3318383} = "Sarcelles";
$areanames{en}->{3318384} = "Enghien\-les\-Bains";
$areanames{en}->{3318385} = "Brie\-Comte\-Robert";
$areanames{en}->{3318386} = "Melun";
$areanames{en}->{3318387} = "Paris";
$areanames{en}->{3318388} = "Fontainebleau";
$areanames{en}->{3318389} = "Paris";
$areanames{en}->{331839} = "Paris";
$areanames{en}->{3318393} = "Beaumont\-sur\-Oise";
$areanames{en}->{3318399} = "Melun";
$areanames{en}->{3318400} = "Massy";
$areanames{en}->{3318401} = "Boulogne\-Billancourt";
$areanames{en}->{3318402} = "Nanterre";
$areanames{en}->{3318403} = "Bobigny";
$areanames{en}->{3318404} = "Créteil";
$areanames{en}->{3318405} = "Paris";
$areanames{en}->{3318406} = "Paris";
$areanames{en}->{3318407} = "Créteil";
$areanames{en}->{3318408} = "Bobigny";
$areanames{en}->{3318409} = "Le\ Raincy";
$areanames{en}->{3318410} = "Paris";
$areanames{en}->{3318411} = "Nanterre";
$areanames{en}->{3318412} = "Mantes\-la\-Jolie";
$areanames{en}->{3318413} = "Paris";
$areanames{en}->{3318414} = "Paris";
$areanames{en}->{3318415} = "Cergy";
$areanames{en}->{3318416} = "Paris";
$areanames{en}->{3318417} = "Paris";
$areanames{en}->{3318418} = "Corbeil\-Essonnes";
$areanames{en}->{3318419} = "Boulogne\-Billancourt";
$areanames{en}->{3318420} = "Nanterre";
$areanames{en}->{3318421} = "Bobigny";
$areanames{en}->{3318422} = "Boulogne\-Billancourt";
$areanames{en}->{3318423} = "Créteil";
$areanames{en}->{3318424} = "Cergy";
$areanames{en}->{3318425} = "Paris";
$areanames{en}->{3318426} = "Melun";
$areanames{en}->{3318427} = "Versailles";
$areanames{en}->{3318428} = "Cergy";
$areanames{en}->{3318429} = "Cergy";
$areanames{en}->{3318430} = "Nanterre";
$areanames{en}->{3318431} = "Brie\-Comte\-Robert";
$areanames{en}->{3318432} = "Coulommiers";
$areanames{en}->{3318433} = "Fontainebleau";
$areanames{en}->{3318434} = "Meaux";
$areanames{en}->{3318435} = "Melun";
$areanames{en}->{3318436} = "Provins";
$areanames{en}->{3318437} = "Tournan\-en\-Brie";
$areanames{en}->{3318438} = "Paris";
$areanames{en}->{3318439} = "Guyancourt";
$areanames{en}->{3318440} = "Versailles";
$areanames{en}->{3318441} = "Mantes\-la\-Jolie";
$areanames{en}->{3318442} = "Les\ Mureaux";
$areanames{en}->{3318443} = "Poissy";
$areanames{en}->{3318444} = "Rambouillet";
$areanames{en}->{3318445} = "Arpajon";
$areanames{en}->{3318446} = "Corbeil\-Essonnes";
$areanames{en}->{3318447} = "Boissy\-Saint\-Léger";
$areanames{en}->{3318448} = "Beaumont\-sur\-Oise";
$areanames{en}->{3318449} = "Brie\-Comte\-Robert";
$areanames{en}->{3318450} = "Coulommiers";
$areanames{en}->{3318451} = "Fontainebleau";
$areanames{en}->{3318452} = "Meaux";
$areanames{en}->{3318453} = "Melun";
$areanames{en}->{3318454} = "Provins";
$areanames{en}->{3318455} = "Mantes\-la\-Jolie";
$areanames{en}->{3318456} = "Les\ Mureaux";
$areanames{en}->{3318457} = "Poissy";
$areanames{en}->{3318458} = "Rambouillet";
$areanames{en}->{3318459} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3318460} = "Boulogne\-Billancourt";
$areanames{en}->{3318461} = "Guyancourt";
$areanames{en}->{3318462} = "Versailles";
$areanames{en}->{3318463} = "Arpajon";
$areanames{en}->{3318464} = "Corbeil\-Essonnes";
$areanames{en}->{3318465} = "Juvisy\-sur\-Orge";
$areanames{en}->{3318466} = "Massy";
$areanames{en}->{3318467} = "Bobigny";
$areanames{en}->{3318468} = "Le\ Raincy";
$areanames{en}->{3318469} = "Boissy\-Saint\-Léger";
$areanames{en}->{3318470} = "Beaumont\-sur\-Oise";
$areanames{en}->{3318471} = "Enghien\-les\-Bains";
$areanames{en}->{3318472} = "Paris";
$areanames{en}->{3318473} = "Versailles";
$areanames{en}->{3318474} = "Bobigny";
$areanames{en}->{3318475} = "Boissy\-Saint\-Léger";
$areanames{en}->{3318476} = "Boulogne\-Billancourt";
$areanames{en}->{3318477} = "Créteil";
$areanames{en}->{3318478} = "Nanterre";
$areanames{en}->{3318479} = "Paris";
$areanames{en}->{331848} = "Paris";
$areanames{en}->{3318480} = "Nanterre";
$areanames{en}->{3318481} = "Le\ Raincy";
$areanames{en}->{3318487} = "Bobigny";
$areanames{en}->{3318489} = "Beaumont\-sur\-Oise";
$areanames{en}->{3318490} = "Bobigny";
$areanames{en}->{3318491} = "Cergy";
$areanames{en}->{3318492} = "Enghien\-les\-Bains";
$areanames{en}->{3318493} = "Le\ Raincy";
$areanames{en}->{3318494} = "Nanterre";
$areanames{en}->{3318495} = "Paris";
$areanames{en}->{3318496} = "Poissy";
$areanames{en}->{3318497} = "Sarcelles";
$areanames{en}->{3318498} = "Boissy\-Saint\-Léger";
$areanames{en}->{3318499} = "Boulogne\-Billancourt";
$areanames{en}->{3318500} = "Créteil";
$areanames{en}->{3318501} = "Nanterre";
$areanames{en}->{3318502} = "Le\ Raincy";
$areanames{en}->{3318503} = "Fontainebleau";
$areanames{en}->{3318504} = "Bobigny";
$areanames{en}->{3318505} = "Paris";
$areanames{en}->{3318506} = "Bobigny";
$areanames{en}->{3318507} = "Bobigny";
$areanames{en}->{3318508} = "Paris";
$areanames{en}->{3318509} = "Paris";
$areanames{en}->{3318510} = "Le\ Raincy";
$areanames{en}->{3318511} = "Enghien\-les\-Bains";
$areanames{en}->{3318512} = "Juvisy\-sur\-Orge";
$areanames{en}->{3318513} = "Brie\-Comte\-Robert";
$areanames{en}->{3318514} = "Paris";
$areanames{en}->{3318515} = "Paris";
$areanames{en}->{3318516} = "Créteil";
$areanames{en}->{3318517} = "Bobigny";
$areanames{en}->{3318518} = "Boulogne\-Billancourt";
$areanames{en}->{3318519} = "Le\ Raincy";
$areanames{en}->{3318520} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3318521} = "Enghien\-les\-Bains";
$areanames{en}->{3318522} = "Sarcelles";
$areanames{en}->{3318523} = "Juvisy\-sur\-Orge";
$areanames{en}->{3318524} = "Versailles";
$areanames{en}->{3318525} = "Poissy";
$areanames{en}->{3318526} = "Cergy";
$areanames{en}->{3318527} = "Meaux";
$areanames{en}->{3318528} = "Les\ Mureaux";
$areanames{en}->{3318529} = "Corbeil\-Essonnes";
$areanames{en}->{3318530} = "Nanterre";
$areanames{en}->{3318531} = "Boulogne\-Billancourt";
$areanames{en}->{3318532} = "Boulogne\-Billancourt";
$areanames{en}->{3318533} = "Créteil";
$areanames{en}->{3318534} = "Paris";
$areanames{en}->{3318535} = "Brie\-Comte\-Robert";
$areanames{en}->{3318536} = "Versailles";
$areanames{en}->{3318537} = "Massy";
$areanames{en}->{3318538} = "Cergy";
$areanames{en}->{3318539} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3318540} = "Guyancourt";
$areanames{en}->{3318541} = "Massy";
$areanames{en}->{3318542} = "Lagny\-sur\-Marne";
$areanames{en}->{3318543} = "Sarcelles";
$areanames{en}->{3318544} = "Boissy\-Saint\-Léger";
$areanames{en}->{3318545} = "Melun";
$areanames{en}->{3318546} = "Arpajon";
$areanames{en}->{3318547} = "Poissy";
$areanames{en}->{3318548} = "Fontainebleau";
$areanames{en}->{3318549} = "Meaux";
$areanames{en}->{3318550} = "Mantes\-la\-Jolie";
$areanames{en}->{3318551} = "Brie\-Comte\-Robert";
$areanames{en}->{3318552} = "Beaumont\-sur\-Oise";
$areanames{en}->{3318553} = "Paris";
$areanames{en}->{3318554} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3318555} = "Paris";
$areanames{en}->{3318556} = "Paris";
$areanames{en}->{3318557} = "Bobigny";
$areanames{en}->{3318558} = "Bobigny";
$areanames{en}->{3318559} = "Guyancourt";
$areanames{en}->{331856} = "Paris";
$areanames{en}->{3318562} = "Boulogne\-Billancourt";
$areanames{en}->{3318563} = "Nanterre";
$areanames{en}->{3318566} = "Lagny\-sur\-Marne";
$areanames{en}->{3318567} = "Nanterre";
$areanames{en}->{3318570} = "Boissy\-Saint\-Léger";
$areanames{en}->{3318571} = "Nanterre";
$areanames{en}->{3318572} = "Créteil";
$areanames{en}->{3318573} = "Paris";
$areanames{en}->{3318574} = "Boulogne\-Billancourt";
$areanames{en}->{3318575} = "Paris";
$areanames{en}->{3318576} = "Enghien\-les\-Bains";
$areanames{en}->{3318577} = "Rambouillet";
$areanames{en}->{3318578} = "Nanterre";
$areanames{en}->{3318579} = "Les\ Mureaux";
$areanames{en}->{3318580} = "Provins";
$areanames{en}->{3318581} = "Coulommiers";
$areanames{en}->{3318582} = "Massy";
$areanames{en}->{3318583} = "Guyancourt";
$areanames{en}->{3318584} = "Meaux";
$areanames{en}->{3318585} = "Paris";
$areanames{en}->{3318586} = "Melun";
$areanames{en}->{3318587} = "Arpajon";
$areanames{en}->{3318588} = "Paris";
$areanames{en}->{3318589} = "Paris";
$areanames{en}->{3318590} = "Lagny\-sur\-Marne";
$areanames{en}->{3318591} = "Beaumont\-sur\-Oise";
$areanames{en}->{3318592} = "Sarcelles";
$areanames{en}->{3318593} = "Paris";
$areanames{en}->{3318594} = "Tournan\-en\-Brie";
$areanames{en}->{3318595} = "Nanterre";
$areanames{en}->{3318596} = "Boulogne\-Billancourt";
$areanames{en}->{3318597} = "Cergy";
$areanames{en}->{3318598} = "Paris";
$areanames{en}->{3318599} = "Coulommiers";
$areanames{en}->{3318600} = "Fontainebleau";
$areanames{en}->{3318601} = "Lagny\-sur\-Marne";
$areanames{en}->{3318602} = "Meaux";
$areanames{en}->{3318603} = "Melun";
$areanames{en}->{3318604} = "Provins";
$areanames{en}->{3318605} = "Tournan\-en\-Brie";
$areanames{en}->{3318606} = "Guyancourt";
$areanames{en}->{3318607} = "Mantes\-la\-Jolie";
$areanames{en}->{3318608} = "Les\ Mureaux";
$areanames{en}->{3318609} = "Poissy";
$areanames{en}->{3318610} = "Rambouillet";
$areanames{en}->{3318611} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3318612} = "Versailles";
$areanames{en}->{3318613} = "Arpajon";
$areanames{en}->{3318614} = "Corbeil\-Essonnes";
$areanames{en}->{3318615} = "Juvisy\-sur\-Orge";
$areanames{en}->{3318616} = "Massy";
$areanames{en}->{3318617} = "Beaumont\-sur\-Oise";
$areanames{en}->{3318618} = "Cergy";
$areanames{en}->{3318619} = "Enghien\-les\-Bains";
$areanames{en}->{3318620} = "Sarcelles";
$areanames{en}->{3318621} = "Paris";
$areanames{en}->{3318622} = "Paris";
$areanames{en}->{3318623} = "Enghien\-les\-Bains";
$areanames{en}->{3318624} = "Juvisy\-sur\-Orge";
$areanames{en}->{3318625} = "Nanterre";
$areanames{en}->{3318626} = "Paris";
$areanames{en}->{3318627} = "Paris";
$areanames{en}->{3318628} = "Corbeil\-Essonnes";
$areanames{en}->{3318629} = "Fontainebleau";
$areanames{en}->{3318630} = "Sarcelles";
$areanames{en}->{3318631} = "Paris";
$areanames{en}->{3318632} = "Coulommiers";
$areanames{en}->{3318633} = "Lagny\-sur\-Marne";
$areanames{en}->{3318634} = "Provins";
$areanames{en}->{3318635} = "Mantes\-la\-Jolie";
$areanames{en}->{3318636} = "Les\ Mureaux";
$areanames{en}->{3318637} = "Poissy";
$areanames{en}->{3318638} = "Rambouillet";
$areanames{en}->{3318639} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3318640} = "Paris";
$areanames{en}->{3318641} = "Versailles";
$areanames{en}->{3318642} = "Boulogne\-Billancourt";
$areanames{en}->{3318643} = "Cergy";
$areanames{en}->{3318644} = "Créteil";
$areanames{en}->{3318645} = "Sarcelles";
$areanames{en}->{3318646} = "Paris";
$areanames{en}->{3318647} = "Paris";
$areanames{en}->{3318648} = "Boulogne\-Billancourt";
$areanames{en}->{3318649} = "Versailles";
$areanames{en}->{3318650} = "Cergy";
$areanames{en}->{3318651} = "Melun";
$areanames{en}->{3318652} = "Nanterre";
$areanames{en}->{3318653} = "Enghien\-les\-Bains";
$areanames{en}->{3318654} = "Paris";
$areanames{en}->{3318655} = "Paris";
$areanames{en}->{3318656} = "Corbeil\-Essonnes";
$areanames{en}->{3318657} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3318658} = "Corbeil\-Essonnes";
$areanames{en}->{3318659} = "Versailles";
$areanames{en}->{331866} = "Paris";
$areanames{en}->{3318660} = "Créteil";
$areanames{en}->{3318663} = "Boulogne\-Billancourt";
$areanames{en}->{3318667} = "Boulogne\-Billancourt";
$areanames{en}->{331867} = "Paris";
$areanames{en}->{3318674} = "Lagny\-sur\-Marne";
$areanames{en}->{3318675} = "Mantes\-la\-Jolie";
$areanames{en}->{3318678} = "Bobigny";
$areanames{en}->{3318679} = "Brie\-Comte\-Robert";
$areanames{en}->{3318680} = "Corbeil\-Essonnes";
$areanames{en}->{3318681} = "Créteil";
$areanames{en}->{3318682} = "Coulommiers";
$areanames{en}->{3318683} = "Fontainebleau";
$areanames{en}->{3318684} = "Lagny\-sur\-Marne";
$areanames{en}->{3318685} = "Paris";
$areanames{en}->{3318686} = "Paris";
$areanames{en}->{3318687} = "Paris";
$areanames{en}->{3318688} = "Paris";
$areanames{en}->{3318689} = "Paris";
$areanames{en}->{331869} = "Paris";
$areanames{en}->{3318693} = "Créteil";
$areanames{en}->{3318694} = "Nanterre";
$areanames{en}->{3318699} = "Nanterre";
$areanames{en}->{3318700} = "Bobigny";
$areanames{en}->{3318701} = "Bobigny";
$areanames{en}->{3318702} = "Paris";
$areanames{en}->{3318703} = "Paris";
$areanames{en}->{3318704} = "Paris";
$areanames{en}->{3318705} = "Paris";
$areanames{en}->{3318706} = "Lagny\-sur\-Marne";
$areanames{en}->{3318707} = "Lagny\-sur\-Marne";
$areanames{en}->{3318708} = "Guyancourt";
$areanames{en}->{3318709} = "Nanterre";
$areanames{en}->{3318710} = "Nanterre";
$areanames{en}->{3318711} = "Provins";
$areanames{en}->{3318712} = "Boulogne\-Billancourt";
$areanames{en}->{3318713} = "Cergy";
$areanames{en}->{3318714} = "Créteil";
$areanames{en}->{3318715} = "Nanterre";
$areanames{en}->{3318716} = "Paris";
$areanames{en}->{3318717} = "Paris";
$areanames{en}->{3318718} = "Nanterre";
$areanames{en}->{3318719} = "Boulogne\-Billancourt";
$areanames{en}->{331872} = "Paris";
$areanames{en}->{3318723} = "Beaumont\-sur\-Oise";
$areanames{en}->{3318728} = "Melun";
$areanames{en}->{3318729} = "Provins";
$areanames{en}->{3318730} = "Tournan\-en\-Brie";
$areanames{en}->{3318731} = "Mantes\-la\-Jolie";
$areanames{en}->{3318732} = "Rambouillet";
$areanames{en}->{3318733} = "Arpajon";
$areanames{en}->{3318734} = "Boissy\-Saint\-Léger";
$areanames{en}->{3318735} = "Beaumont\-sur\-Oise";
$areanames{en}->{3318736} = "Créteil";
$areanames{en}->{3318737} = "Nanterre";
$areanames{en}->{3318738} = "Guyancourt";
$areanames{en}->{3318739} = "Paris";
$areanames{en}->{3318740} = "Paris";
$areanames{en}->{3318741} = "Boulogne\-Billancourt";
$areanames{en}->{3318742} = "Boulogne\-Billancourt";
$areanames{en}->{3318743} = "Boulogne\-Billancourt";
$areanames{en}->{3318744} = "Paris";
$areanames{en}->{3318745} = "Fontainebleau";
$areanames{en}->{3318746} = "Paris";
$areanames{en}->{3318747} = "Lagny\-sur\-Marne";
$areanames{en}->{3318748} = "Enghien\-les\-Bains";
$areanames{en}->{3318749} = "Massy";
$areanames{en}->{3318750} = "Guyancourt";
$areanames{en}->{3318751} = "Créteil";
$areanames{en}->{3318752} = "Paris";
$areanames{en}->{3318753} = "Paris";
$areanames{en}->{3318754} = "Massy";
$areanames{en}->{3318755} = "Nanterre";
$areanames{en}->{3318756} = "Boulogne\-Billancourt";
$areanames{en}->{3318757} = "Lagny\-sur\-Marne";
$areanames{en}->{3318758} = "Paris";
$areanames{en}->{3318759} = "Massy";
$areanames{en}->{3318760} = "Boulogne\-Billancourt";
$areanames{en}->{3318761} = "Meaux";
$areanames{en}->{3318762} = "Lagny\-sur\-Marne";
$areanames{en}->{3318763} = "Enghien\-les\-Bains";
$areanames{en}->{3318764} = "Paris";
$areanames{en}->{3318765} = "Paris";
$areanames{en}->{3318766} = "Paris";
$areanames{en}->{3318767} = "Paris";
$areanames{en}->{3318768} = "Paris";
$areanames{en}->{3318769} = "Boulogne\-Billancourt";
$areanames{en}->{3318770} = "Brie\-Comte\-Robert";
$areanames{en}->{3318771} = "Melun";
$areanames{en}->{3318772} = "Guyancourt";
$areanames{en}->{3318773} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3318774} = "Bobigny";
$areanames{en}->{3318775} = "Paris";
$areanames{en}->{3318776} = "Nanterre";
$areanames{en}->{3318777} = "Paris";
$areanames{en}->{3318778} = "Paris";
$areanames{en}->{3318779} = "Paris";
$areanames{en}->{3318780} = "Versailles";
$areanames{en}->{3318781} = "Paris";
$areanames{en}->{3318782} = "Massy";
$areanames{en}->{3318783} = "Boulogne\-Billancourt";
$areanames{en}->{3318784} = "Créteil";
$areanames{en}->{3318785} = "Bobigny";
$areanames{en}->{3318786} = "Paris";
$areanames{en}->{3318787} = "Paris";
$areanames{en}->{3318788} = "Versailles";
$areanames{en}->{3318789} = "Paris";
$areanames{en}->{3318790} = "Juvisy\-sur\-Orge";
$areanames{en}->{3318791} = "Brie\-Comte\-Robert";
$areanames{en}->{3318792} = "Coulommiers";
$areanames{en}->{3318793} = "Fontainebleau";
$areanames{en}->{3318794} = "Lagny\-sur\-Marne";
$areanames{en}->{3318795} = "Meaux";
$areanames{en}->{3318796} = "Melun";
$areanames{en}->{3318797} = "Provins";
$areanames{en}->{3318798} = "Provins";
$areanames{en}->{3318799} = "Tournan\-en\-Brie";
$areanames{en}->{3318800} = "Guyancourt";
$areanames{en}->{3318801} = "Les\ Mureaux";
$areanames{en}->{3318802} = "Mantes\-la\-Jolie";
$areanames{en}->{3318803} = "Poissy";
$areanames{en}->{3318804} = "Rambouillet";
$areanames{en}->{3318805} = "Saint\-Germain\-en\-Laye";
$areanames{en}->{3318806} = "Versailles";
$areanames{en}->{3318807} = "Arpajon";
$areanames{en}->{3318808} = "Corbeil\-Essonnes";
$areanames{en}->{3318809} = "Juvisy\-sur\-Orge";
$areanames{en}->{3318810} = "Massy";
$areanames{en}->{3318811} = "Boulogne\-Billancourt";
$areanames{en}->{3318812} = "Bobigny";
$areanames{en}->{3318813} = "Le\ Raincy";
$areanames{en}->{3318814} = "Boissy\-Saint\-Léger";
$areanames{en}->{3318815} = "Créteil";
$areanames{en}->{3318816} = "Beaumont\-sur\-Oise";
$areanames{en}->{3318817} = "Cergy";
$areanames{en}->{3318818} = "Enghien\-les\-Bains";
$areanames{en}->{3318819} = "Sarcelles";
$areanames{en}->{3318820} = "Enghien\-les\-Bains";
$areanames{en}->{3318821} = "Paris";
$areanames{en}->{3318822} = "Paris";
$areanames{en}->{3318823} = "Paris";
$areanames{en}->{3318824} = "Paris";
$areanames{en}->{3318825} = "Paris";
$areanames{en}->{3318826} = "Cergy";
$areanames{en}->{3318827} = "Créteil";
$areanames{en}->{3318828} = "Créteil";
$areanames{en}->{3318829} = "Créteil";
$areanames{en}->{331883} = "Paris";
$areanames{en}->{3318837} = "Melun";
$areanames{en}->{3318838} = "Versailles";
$areanames{en}->{3318839} = "Guyancourt";
$areanames{en}->{331884} = "Paris";
$areanames{en}->{3318842} = "Nanterre";
$areanames{en}->{3318849} = "Bobigny";
$areanames{en}->{3318850} = "Bobigny";
$areanames{en}->{3318851} = "Bobigny";
$areanames{en}->{3318852} = "Paris";
$areanames{en}->{3318854} = "Nanterre";
$areanames{en}->{3318855} = "Paris";
$areanames{en}->{3318856} = "Paris";
$areanames{en}->{3318857} = "Paris";
$areanames{en}->{3318858} = "Paris";
$areanames{en}->{33190} = "Ile\ de\ France";
$areanames{en}->{33191} = "Ile\ de\ France";
$areanames{en}->{3321400} = "Alençon";
$areanames{en}->{3321401} = "Argentan";
$areanames{en}->{3321402} = "Falaise";
$areanames{en}->{3321403} = "Flers";
$areanames{en}->{3321404} = "Lisieux";
$areanames{en}->{3321405} = "Mortagne\-au\-Perche";
$areanames{en}->{3321406} = "Saint\-Lô";
$areanames{en}->{3321407} = "Vire";
$areanames{en}->{3321408} = "Bayeux";
$areanames{en}->{3321409} = "Deauville";
$areanames{en}->{3321410} = "Falaise";
$areanames{en}->{3321411} = "Lisieux";
$areanames{en}->{3321412} = "Vire";
$areanames{en}->{3321413} = "Avranches";
$areanames{en}->{3321414} = "Carentan\-les\-Marais";
$areanames{en}->{3321415} = "Coutances";
$areanames{en}->{3321416} = "Saint\-Lô";
$areanames{en}->{3321417} = "Alençon";
$areanames{en}->{3321418} = "Argentan";
$areanames{en}->{3321419} = "Flers";
$areanames{en}->{3321420} = "L\'Aigle";
$areanames{en}->{3321421} = "Mortagne\-au\-Perche";
$areanames{en}->{3321422} = "Alençon";
$areanames{en}->{3321423} = "Argentan";
$areanames{en}->{3321424} = "Avranches";
$areanames{en}->{3321425} = "Carentan\-les\-Marais";
$areanames{en}->{3321426} = "Deauville";
$areanames{en}->{3321427} = "Flers";
$areanames{en}->{3321428} = "Mortagne\-au\-Perche";
$areanames{en}->{3321429} = "Saint\-Lô";
$areanames{en}->{3321430} = "Vire";
$areanames{en}->{3321431} = "Alençon";
$areanames{en}->{3321432} = "Avranches";
$areanames{en}->{3321433} = "Caen";
$areanames{en}->{3321434} = "Carentan\-les\-Marais";
$areanames{en}->{3321435} = "Coutances";
$areanames{en}->{3321436} = "Saint\-Lô";
$areanames{en}->{3321437} = "Caen";
$areanames{en}->{3321438} = "Alençon";
$areanames{en}->{3321439} = "Saint\-Lô";
$areanames{en}->{3321440} = "Caen";
$areanames{en}->{3321441} = "Caen";
$areanames{en}->{3321442} = "Alençon";
$areanames{en}->{3321443} = "Alençon";
$areanames{en}->{3321444} = "Argentan";
$areanames{en}->{3321445} = "Avranches";
$areanames{en}->{3321446} = "Bayeux";
$areanames{en}->{3321447} = "Caen";
$areanames{en}->{3321448} = "Carentan\-les\-Marais";
$areanames{en}->{3321449} = "Coutances";
$areanames{en}->{3321450} = "Avranches";
$areanames{en}->{3321451} = "Deauville";
$areanames{en}->{3321452} = "Falaise";
$areanames{en}->{3321453} = "Flers";
$areanames{en}->{3321454} = "L\'Aigle";
$areanames{en}->{3321455} = "Saint\-Lô";
$areanames{en}->{3321456} = "Lisieux";
$areanames{en}->{3321457} = "Mortagne\-au\-Perche";
$areanames{en}->{3321458} = "Saint\-Lô";
$areanames{en}->{3321459} = "Vire";
$areanames{en}->{3321460} = "Caen";
$areanames{en}->{3321461} = "Caen";
$areanames{en}->{3321462} = "Lisieux";
$areanames{en}->{3321463} = "Deauville";
$areanames{en}->{3321464} = "Lisieux";
$areanames{en}->{3321465} = "Bayeux";
$areanames{en}->{3321466} = "Caen";
$areanames{en}->{3321467} = "Deauville";
$areanames{en}->{3321468} = "Falaise";
$areanames{en}->{3321469} = "Lisieux";
$areanames{en}->{3321470} = "Carentan\-les\-Marais";
$areanames{en}->{3321471} = "Carentan\-les\-Marais";
$areanames{en}->{3321472} = "Avranches";
$areanames{en}->{3321473} = "Vire";
$areanames{en}->{3321474} = "Caen";
$areanames{en}->{3321475} = "Avranches";
$areanames{en}->{3321476} = "Carentan\-les\-Marais";
$areanames{en}->{3321477} = "Coutances";
$areanames{en}->{3321478} = "Saint\-Lô";
$areanames{en}->{3321479} = "Alençon";
$areanames{en}->{3321480} = "Coutances";
$areanames{en}->{3321481} = "Argentan";
$areanames{en}->{3321482} = "Flers";
$areanames{en}->{3321483} = "L\'Aigle";
$areanames{en}->{3321484} = "Mortagne\-au\-Perche";
$areanames{en}->{3321485} = "Caen";
$areanames{en}->{3321486} = "Carentan\-les\-Marais";
$areanames{en}->{3321487} = "Coutances";
$areanames{en}->{3321488} = "Saint\-Lô";
$areanames{en}->{3321489} = "Coutances";
$areanames{en}->{3321490} = "Avranches";
$areanames{en}->{3321491} = "Alençon";
$areanames{en}->{3321492} = "Lisieux";
$areanames{en}->{3321493} = "Coutances";
$areanames{en}->{3321494} = "Caen";
$areanames{en}->{3321495} = "Argentan";
$areanames{en}->{3321496} = "Flers";
$areanames{en}->{3321497} = "L\'Aigle";
$areanames{en}->{3321498} = "Mortagne\-au\-Perche";
$areanames{en}->{3321499} = "Caen";
$areanames{en}->{3321800} = "Nogent\-le\-Rotrou";
$areanames{en}->{3321801} = "Le\ Blanc";
$areanames{en}->{3321802} = "Châteauroux";
$areanames{en}->{3321803} = "La\ Châtre";
$areanames{en}->{3321804} = "Issoudun";
$areanames{en}->{3321805} = "Valençay";
$areanames{en}->{3321806} = "Amboise";
$areanames{en}->{3321807} = "Chinon";
$areanames{en}->{3321808} = "Loches";
$areanames{en}->{3321809} = "Saint\-Aignan";
$areanames{en}->{3321810} = "Vendôme";
$areanames{en}->{3321811} = "Gien";
$areanames{en}->{3321812} = "Montargis";
$areanames{en}->{3321813} = "Pithiviers";
$areanames{en}->{3321814} = "Blois";
$areanames{en}->{3321815} = "Bourges";
$areanames{en}->{3321816} = "Chartres";
$areanames{en}->{3321817} = "Châteaudun";
$areanames{en}->{3321818} = "Gien";
$areanames{en}->{3321819} = "La\ Guerche\-sur\-lAubois";
$areanames{en}->{3321820} = "Montargis";
$areanames{en}->{3321821} = "Orléans";
$areanames{en}->{3321822} = "Pithiviers";
$areanames{en}->{3321823} = "Romorantin\-Lanthenay";
$areanames{en}->{3321824} = "Tours";
$areanames{en}->{3321825} = "Vendôme";
$areanames{en}->{3321826} = "Vierzon";
$areanames{en}->{3321827} = "Le\ Blanc";
$areanames{en}->{3321828} = "Issoudun";
$areanames{en}->{3321829} = "Romorantin\-Lanthenay";
$areanames{en}->{3321830} = "Tours";
$areanames{en}->{3321831} = "Blois";
$areanames{en}->{3321832} = "Bourges";
$areanames{en}->{3321833} = "Chartres";
$areanames{en}->{3321834} = "Montargis";
$areanames{en}->{3321835} = "Orléans";
$areanames{en}->{3321836} = "Tours";
$areanames{en}->{3321837} = "Tours";
$areanames{en}->{3321838} = "Pithiviers";
$areanames{en}->{3321839} = "Orléans";
$areanames{en}->{3321840} = "Chartres";
$areanames{en}->{3321841} = "Tours";
$areanames{en}->{3321842} = "Blois";
$areanames{en}->{3321843} = "Bourges";
$areanames{en}->{3321844} = "Chartres";
$areanames{en}->{3321845} = "Orléans";
$areanames{en}->{3321846} = "Châteaudun";
$areanames{en}->{3321847} = "Châteauroux";
$areanames{en}->{3321848} = "Dreux";
$areanames{en}->{3321849} = "Gien";
$areanames{en}->{3321850} = "Montargis";
$areanames{en}->{3321851} = "Vendôme";
$areanames{en}->{3321852} = "Amboise";
$areanames{en}->{3321853} = "Aubigny\-sur\-Nère";
$areanames{en}->{3321854} = "Blois";
$areanames{en}->{3321855} = "Bourges";
$areanames{en}->{3321856} = "Chartres";
$areanames{en}->{3321857} = "Châteaudun";
$areanames{en}->{3321858} = "Châteauroux";
$areanames{en}->{3321859} = "Chinon";
$areanames{en}->{3321860} = "Dreux";
$areanames{en}->{3321861} = "Gien";
$areanames{en}->{3321862} = "Issoudun";
$areanames{en}->{3321863} = "La\ Châtre";
$areanames{en}->{3321864} = "La\ Guerche\-sur\-lAubois";
$areanames{en}->{3321865} = "Le\ Blanc";
$areanames{en}->{3321866} = "Loches";
$areanames{en}->{3321867} = "Montargis";
$areanames{en}->{3321868} = "Nogent\-le\-Rotrou";
$areanames{en}->{3321869} = "Orléans";
$areanames{en}->{3321870} = "Pithiviers";
$areanames{en}->{3321871} = "Romorantin\-Lanthenay";
$areanames{en}->{3321872} = "Saint\-Aignan";
$areanames{en}->{3321873} = "Saint\-Amand\-Montrond";
$areanames{en}->{3321874} = "Sancerre";
$areanames{en}->{3321875} = "Tours";
$areanames{en}->{3321876} = "Valençay";
$areanames{en}->{3321877} = "Vendôme";
$areanames{en}->{3321878} = "Vierzon";
$areanames{en}->{3321879} = "Blois";
$areanames{en}->{3321880} = "La\ Guerche\-sur\-lAubois";
$areanames{en}->{3321881} = "Bourges";
$areanames{en}->{3321882} = "Nogent\-le\-Rotrou";
$areanames{en}->{3321883} = "Blois";
$areanames{en}->{3321884} = "Orléans";
$areanames{en}->{3321885} = "Montargis";
$areanames{en}->{3321886} = "Aubigny\-sur\-Nère";
$areanames{en}->{3321887} = "Bourges";
$areanames{en}->{3321888} = "Orléans";
$areanames{en}->{3321889} = "Bourges";
$areanames{en}->{3321890} = "Chartres";
$areanames{en}->{3321891} = "La\ Guerche\-sur\-lAubois";
$areanames{en}->{3321892} = "Saint\-Amand\-Montrond";
$areanames{en}->{3321893} = "Châteauroux";
$areanames{en}->{3321894} = "Sancerre";
$areanames{en}->{3321895} = "Vierzon";
$areanames{en}->{3321896} = "Tours";
$areanames{en}->{3321897} = "Chartres";
$areanames{en}->{3321898} = "Châteaudun";
$areanames{en}->{3321899} = "Dreux";
$areanames{en}->{3321900} = "Bourges";
$areanames{en}->{3321901} = "Orléans";
$areanames{en}->{3321902} = "Chartres";
$areanames{en}->{3321903} = "Tours";
$areanames{en}->{3321904} = "Blois";
$areanames{en}->{3321905} = "Orléans";
$areanames{en}->{3321906} = "Vierzon";
$areanames{en}->{3321907} = "Issoudun";
$areanames{en}->{3321908} = "Châteauroux";
$areanames{en}->{3322100} = "Rennes";
$areanames{en}->{3322101} = "Saint\-Malo";
$areanames{en}->{3322102} = "Vannes";
$areanames{en}->{3322103} = "Carhaix\-Plouguer";
$areanames{en}->{3322104} = "Rennes";
$areanames{en}->{3322105} = "Rennes";
$areanames{en}->{3322106} = "Brest";
$areanames{en}->{3322107} = "Rennes";
$areanames{en}->{3322108} = "Saint\-Brieuc";
$areanames{en}->{3322109} = "Brest";
$areanames{en}->{3322110} = "Brest";
$areanames{en}->{3322111} = "Rennes";
$areanames{en}->{3322112} = "Guingamp";
$areanames{en}->{3322113} = "Lamballe";
$areanames{en}->{3322114} = "Loudéac";
$areanames{en}->{3322115} = "Paimpol";
$areanames{en}->{3322116} = "Rostrenen";
$areanames{en}->{3322117} = "Morlaix";
$areanames{en}->{3322118} = "Quimperlé";
$areanames{en}->{3322119} = "Fougères";
$areanames{en}->{3322120} = "Janzé";
$areanames{en}->{3322121} = "Montfort\-sur\-Meu";
$areanames{en}->{3322122} = "Redon";
$areanames{en}->{3322123} = "Vitré";
$areanames{en}->{3322124} = "Le\ Faouet";
$areanames{en}->{3322125} = "Ploërmel";
$areanames{en}->{3322126} = "Pontivy";
$areanames{en}->{3322127} = "Saint\-Brieuc";
$areanames{en}->{3322128} = "Morlaix";
$areanames{en}->{3322129} = "Vitré";
$areanames{en}->{3322130} = "Auray";
$areanames{en}->{3322131} = "Rennes";
$areanames{en}->{3322132} = "Auray";
$areanames{en}->{3322133} = "Carhaix\-Plouguer";
$areanames{en}->{3322134} = "Rennes";
$areanames{en}->{3322135} = "Dinan";
$areanames{en}->{3322136} = "Guingamp";
$areanames{en}->{3322137} = "Lamballe";
$areanames{en}->{3322138} = "Loudéac";
$areanames{en}->{3322139} = "Paimpol";
$areanames{en}->{3322140} = "Rostrenen";
$areanames{en}->{3322141} = "Saint\-Brieuc";
$areanames{en}->{3322142} = "Brest";
$areanames{en}->{3322143} = "Carhaix\-Plouguer";
$areanames{en}->{3322144} = "Morlaix";
$areanames{en}->{3322145} = "Quimperlé";
$areanames{en}->{3322146} = "Fougères";
$areanames{en}->{3322147} = "Janzé";
$areanames{en}->{3322148} = "Montfort\-sur\-Meu";
$areanames{en}->{3322149} = "Redon";
$areanames{en}->{3322150} = "Rennes";
$areanames{en}->{3322151} = "Saint\-Malo";
$areanames{en}->{3322152} = "Vitré";
$areanames{en}->{3322153} = "Auray";
$areanames{en}->{3322154} = "Le\ Faouet";
$areanames{en}->{3322155} = "Ploërmel";
$areanames{en}->{3322156} = "Pontivy";
$areanames{en}->{3322157} = "Vannes";
$areanames{en}->{3322158} = "Carhaix\-Plouguer";
$areanames{en}->{3322159} = "Quimperlé";
$areanames{en}->{3322160} = "Saint\-Brieuc";
$areanames{en}->{3322161} = "Dinan";
$areanames{en}->{3322162} = "Carhaix\-Plouguer";
$areanames{en}->{3322163} = "Paimpol";
$areanames{en}->{3322164} = "Brest";
$areanames{en}->{3322165} = "Rennes";
$areanames{en}->{3322166} = "Saint\-Brieuc";
$areanames{en}->{3322167} = "Rennes";
$areanames{en}->{3322168} = "Rennes";
$areanames{en}->{3322169} = "Redon";
$areanames{en}->{3322170} = "Rennes";
$areanames{en}->{3322171} = "Guingamp";
$areanames{en}->{3322200} = "Brest";
$areanames{en}->{3322201} = "Carhaix\-Plouguer";
$areanames{en}->{3322202} = "Janzé";
$areanames{en}->{3322203} = "Rennes";
$areanames{en}->{3322204} = "Saint\-Brieuc";
$areanames{en}->{3322205} = "Vannes";
$areanames{en}->{3322206} = "Rennes";
$areanames{en}->{3322207} = "Vannes";
$areanames{en}->{3322208} = "Brest";
$areanames{en}->{3322209} = "Montfort\-sur\-Meu";
$areanames{en}->{3322210} = "Saint\-Brieuc";
$areanames{en}->{3322211} = "Auray";
$areanames{en}->{3322212} = "Carhaix\-Plouguer";
$areanames{en}->{3322213} = "Dinan";
$areanames{en}->{3322214} = "Fougères";
$areanames{en}->{3322215} = "Janzé";
$areanames{en}->{3322216} = "Ploërmel";
$areanames{en}->{3322217} = "Quimperlé";
$areanames{en}->{3322218} = "Redon";
$areanames{en}->{3322219} = "Vitré";
$areanames{en}->{3322220} = "Janzé";
$areanames{en}->{3322221} = "Auray";
$areanames{en}->{3322222} = "Saint\-Brieuc";
$areanames{en}->{3322223} = "Vannes";
$areanames{en}->{3322224} = "Brest";
$areanames{en}->{3322225} = "Carhaix\-Plouguer";
$areanames{en}->{3322226} = "Dinan";
$areanames{en}->{3322227} = "Fougères";
$areanames{en}->{3322228} = "Guingamp";
$areanames{en}->{3322229} = "Carhaix\-Plouguer";
$areanames{en}->{3322230} = "Janzé";
$areanames{en}->{3322231} = "Lamballe";
$areanames{en}->{3322232} = "Le\ Faouet";
$areanames{en}->{3322233} = "Brest";
$areanames{en}->{3322234} = "Loudéac";
$areanames{en}->{3322235} = "Rennes";
$areanames{en}->{3322236} = "Montfort\-sur\-Meu";
$areanames{en}->{3322237} = "Morlaix";
$areanames{en}->{3322238} = "Paimpol";
$areanames{en}->{3322239} = "Ploërmel";
$areanames{en}->{3322240} = "Pontivy";
$areanames{en}->{3322241} = "Quimperlé";
$areanames{en}->{3322242} = "Redon";
$areanames{en}->{3322243} = "Rennes";
$areanames{en}->{3322244} = "Rennes";
$areanames{en}->{3322245} = "Rostrenen";
$areanames{en}->{3322246} = "Saint\-Brieuc";
$areanames{en}->{3322247} = "Saint\-Malo";
$areanames{en}->{3322248} = "Vannes";
$areanames{en}->{3322249} = "Vitré";
$areanames{en}->{3322250} = "Brest";
$areanames{en}->{3322251} = "Rennes";
$areanames{en}->{3322252} = "Brest";
$areanames{en}->{3322253} = "Carhaix\-Plouguer";
$areanames{en}->{3322254} = "Rennes";
$areanames{en}->{3322255} = "Morlaix";
$areanames{en}->{3322256} = "Pontivy";
$areanames{en}->{3322257} = "Dinan";
$areanames{en}->{3322258} = "Guingamp";
$areanames{en}->{3322259} = "Lamballe";
$areanames{en}->{3322260} = "Loudéac";
$areanames{en}->{3322261} = "Paimpol";
$areanames{en}->{3322262} = "Rostrenen";
$areanames{en}->{3322263} = "Saint\-Brieuc";
$areanames{en}->{3322264} = "Brest";
$areanames{en}->{3322265} = "Carhaix\-Plouguer";
$areanames{en}->{3322266} = "Rennes";
$areanames{en}->{3322267} = "Morlaix";
$areanames{en}->{3322268} = "Quimperlé";
$areanames{en}->{3322269} = "Fougères";
$areanames{en}->{3322270} = "Saint\-Brieuc";
$areanames{en}->{3322271} = "Guingamp";
$areanames{en}->{3322272} = "Carhaix\-Plouguer";
$areanames{en}->{3322273} = "Brest";
$areanames{en}->{3322274} = "Rennes";
$areanames{en}->{3322275} = "Saint\-Malo";
$areanames{en}->{3322276} = "Auray";
$areanames{en}->{3322277} = "Vannes";
$areanames{en}->{3322278} = "Janzé";
$areanames{en}->{3322279} = "Montfort\-sur\-Meu";
$areanames{en}->{3322280} = "Redon";
$areanames{en}->{3322281} = "Saint\-Malo";
$areanames{en}->{3322282} = "Vitré";
$areanames{en}->{3322283} = "Auray";
$areanames{en}->{3322284} = "Le\ Faouet";
$areanames{en}->{3322285} = "Ploërmel";
$areanames{en}->{3322286} = "Pontivy";
$areanames{en}->{3322287} = "Vannes";
$areanames{en}->{3322288} = "Brest";
$areanames{en}->{3322289} = "Carhaix\-Plouguer";
$areanames{en}->{3322290} = "Brest";
$areanames{en}->{3322291} = "Rennes";
$areanames{en}->{3322292} = "Rostrenen";
$areanames{en}->{3322293} = "Rennes";
$areanames{en}->{3322294} = "Carhaix\-Plouguer";
$areanames{en}->{3322295} = "Saint\-Brieuc";
$areanames{en}->{3322296} = "Brest";
$areanames{en}->{3322297} = "Carhaix\-Plouguer";
$areanames{en}->{3322298} = "Rennes";
$areanames{en}->{3322299} = "Auray";
$areanames{en}->{332230} = "Nord\ Ouest";
$areanames{en}->{3322305} = "Rennes";
$areanames{en}->{3322306} = "Rennes";
$areanames{en}->{3322307} = "Rennes";
$areanames{en}->{3322308} = "Janzé";
$areanames{en}->{3322310} = "Pénestin";
$areanames{en}->{3322315} = "Cancale";
$areanames{en}->{3322316} = "Combourg";
$areanames{en}->{3322318} = "Saint\-Malo";
$areanames{en}->{3322320} = "Rennes";
$areanames{en}->{3322321} = "Rennes";
$areanames{en}->{3322322} = "Montreuil\-sur\-Ille";
$areanames{en}->{3322325} = "Saint\-Grégoire";
$areanames{en}->{3322330} = "Rennes";
$areanames{en}->{3322331} = "Bain\-de\-Bretagne";
$areanames{en}->{3322335} = "Rennes";
$areanames{en}->{3322340} = "Rennes";
$areanames{en}->{3322341} = "Bréal\-sous\-Montfort";
$areanames{en}->{3322342} = "Rennes";
$areanames{en}->{3322343} = "Montfort\-sur\-Meu";
$areanames{en}->{3322344} = "Rennes";
$areanames{en}->{3322345} = "Cesson\-Sévigné";
$areanames{en}->{3322346} = "Rennes";
$areanames{en}->{3322348} = "Rennes";
$areanames{en}->{3322350} = "Bruz";
$areanames{en}->{3322351} = "Fougères";
$areanames{en}->{3322352} = "Saint\-Malo";
$areanames{en}->{3322355} = "Vitré";
$areanames{en}->{332236} = "Nord\ Ouest";
$areanames{en}->{3322361} = "Rennes";
$areanames{en}->{3322362} = "Rennes";
$areanames{en}->{3322363} = "Redon";
$areanames{en}->{3322364} = "Montfort\-sur\-Meu";
$areanames{en}->{332237} = "Nord\ Ouest";
$areanames{en}->{332238} = "Nord\ Ouest";
$areanames{en}->{332239} = "Nord\ Ouest";
$areanames{en}->{332270} = "Nord\ Ouest";
$areanames{en}->{3322700} = "Rouen";
$areanames{en}->{3322705} = "Rouen";
$areanames{en}->{3322708} = "Rouen";
$areanames{en}->{332271} = "Nord\ Ouest";
$areanames{en}->{3322713} = "Fécamp";
$areanames{en}->{3322719} = "Bernay";
$areanames{en}->{3322728} = "Eu";
$areanames{en}->{332273} = "Nord\ Ouest";
$areanames{en}->{3322730} = "Fécamp";
$areanames{en}->{3322734} = "Evreux";
$areanames{en}->{3322736} = "Pont\-Audemer";
$areanames{en}->{332274} = "Nord\ Ouest";
$areanames{en}->{3322743} = "Fécamp";
$areanames{en}->{332275} = "Nord\ Ouest";
$areanames{en}->{332276} = "Nord\ Ouest";
$areanames{en}->{332277} = "Nord\ Ouest";
$areanames{en}->{3322776} = "Rouen";
$areanames{en}->{332278} = "Nord\ Ouest";
$areanames{en}->{332279} = "Nord\ Ouest";
$areanames{en}->{3322802} = "Vigneux\-de\-Bretagne";
$areanames{en}->{3322803} = "Saint\-Herblain";
$areanames{en}->{3322808} = "Nantes";
$areanames{en}->{3322811} = "Saint\-Jean\-de\-Monts";
$areanames{en}->{3322812} = "Challans";
$areanames{en}->{3322813} = "Fontenay\-le\-Comte";
$areanames{en}->{332282} = "Nantes";
$areanames{en}->{332283} = "Nord\ Ouest";
$areanames{en}->{3322830} = "Nantes";
$areanames{en}->{3322834} = "Nantes";
$areanames{en}->{3322844} = "Nantes";
$areanames{en}->{3322853} = "Saint\-Brevin\-les\-Pins";
$areanames{en}->{3322854} = "Saint\-Nazaire";
$areanames{en}->{332286} = "Nord\ Ouest";
$areanames{en}->{332287} = "Nord\ Ouest";
$areanames{en}->{332288} = "Nord\ Ouest";
$areanames{en}->{3322885} = "La\ Roche\-sur\-Yon";
$areanames{en}->{332289} = "Nord\ Ouest";
$areanames{en}->{3322891} = "Nantes";
$areanames{en}->{3322896} = "Nantes";
$areanames{en}->{3322897} = "La\ Roche\-sur\-Yon";
$areanames{en}->{332290} = "Nord\ Ouest";
$areanames{en}->{3322900} = "Brest";
$areanames{en}->{3322902} = "Brest";
$areanames{en}->{3322905} = "Brest";
$areanames{en}->{332291} = "Nord\ Ouest";
$areanames{en}->{3322915} = "Carhaix\-Plouguer";
$areanames{en}->{332292} = "Nord\ Ouest";
$areanames{en}->{3322920} = "Carhaix\-Plouguer";
$areanames{en}->{3322925} = "Carhaix\-Plouguer";
$areanames{en}->{332293} = "Nord\ Ouest";
$areanames{en}->{3322940} = "Briec";
$areanames{en}->{332295} = "Nord\ Ouest";
$areanames{en}->{3322962} = "Landerneau";
$areanames{en}->{332297} = "Nord\ Ouest";
$areanames{en}->{332298} = "Nord\ Ouest";
$areanames{en}->{332299} = "Nord\ Ouest";
$areanames{en}->{3323002} = "Rennes";
$areanames{en}->{3323010} = "Dinan";
$areanames{en}->{3323011} = "Lamballe";
$areanames{en}->{3323012} = "Loudéac";
$areanames{en}->{3323013} = "Brest";
$areanames{en}->{3323014} = "Carhaix\-Plouguer";
$areanames{en}->{3323015} = "Quimperlé";
$areanames{en}->{3323016} = "Fougères";
$areanames{en}->{3323017} = "Auray";
$areanames{en}->{3323018} = "Le\ Faouet";
$areanames{en}->{3323019} = "Ploërmel";
$areanames{en}->{3323020} = "Pontivy";
$areanames{en}->{3323021} = "Rennes";
$areanames{en}->{3323022} = "Janzé";
$areanames{en}->{3323023} = "Montfort\-sur\-Meu";
$areanames{en}->{3323024} = "Redon";
$areanames{en}->{3323025} = "Saint\-Malo";
$areanames{en}->{3323026} = "Vitré";
$areanames{en}->{3323027} = "Auray";
$areanames{en}->{3323028} = "Le\ Faouet";
$areanames{en}->{3323029} = "Ploërmel";
$areanames{en}->{3323030} = "Pontivy";
$areanames{en}->{3323031} = "Vannes";
$areanames{en}->{3323032} = "Rennes";
$areanames{en}->{3323033} = "Carhaix\-Plouguer";
$areanames{en}->{3323034} = "Montfort\-sur\-Meu";
$areanames{en}->{3323035} = "Morlaix";
$areanames{en}->{3323036} = "Le\ Faouet";
$areanames{en}->{3323037} = "Rennes";
$areanames{en}->{3323038} = "Rostrenen";
$areanames{en}->{3323039} = "Auray";
$areanames{en}->{3323040} = "Janzé";
$areanames{en}->{3323041} = "Vannes";
$areanames{en}->{3323042} = "Saint\-Malo";
$areanames{en}->{3323043} = "Fougères";
$areanames{en}->{3323044} = "Loudéac";
$areanames{en}->{3323045} = "Saint\-Brieuc";
$areanames{en}->{3323046} = "Quimperlé";
$areanames{en}->{3323047} = "Dinan";
$areanames{en}->{3323048} = "Lamballe";
$areanames{en}->{3323049} = "Vitré";
$areanames{en}->{3323050} = "Brest";
$areanames{en}->{3323051} = "Ploërmel";
$areanames{en}->{3323052} = "Guingamp";
$areanames{en}->{3323053} = "Paimpol";
$areanames{en}->{3323054} = "Pontivy";
$areanames{en}->{3323055} = "Redon";
$areanames{en}->{3323056} = "Dinan";
$areanames{en}->{3323057} = "Guingamp";
$areanames{en}->{3323058} = "Lamballe";
$areanames{en}->{3323059} = "Loudéac";
$areanames{en}->{3323060} = "Paimpol";
$areanames{en}->{3323061} = "Rostrenen";
$areanames{en}->{3323062} = "Saint\-Brieuc";
$areanames{en}->{3323063} = "Brest";
$areanames{en}->{3323064} = "Carhaix\-Plouguer";
$areanames{en}->{3323065} = "Morlaix";
$areanames{en}->{3323066} = "Quimperlé";
$areanames{en}->{3323067} = "Fougères";
$areanames{en}->{3323068} = "Janzé";
$areanames{en}->{3323069} = "Montfort\-sur\-Meu";
$areanames{en}->{3323070} = "Redon";
$areanames{en}->{3323071} = "Rennes";
$areanames{en}->{3323072} = "Saint\-Malo";
$areanames{en}->{3323073} = "Vitré";
$areanames{en}->{3323074} = "Auray";
$areanames{en}->{3323075} = "Le\ Faouet";
$areanames{en}->{3323076} = "Ploërmel";
$areanames{en}->{3323077} = "Pontivy";
$areanames{en}->{3323078} = "Vannes";
$areanames{en}->{3323079} = "Brest";
$areanames{en}->{3323080} = "Morlaix";
$areanames{en}->{3323081} = "Pontivy";
$areanames{en}->{3323082} = "Brest";
$areanames{en}->{3323083} = "Rennes";
$areanames{en}->{3323084} = "Lamballe";
$areanames{en}->{3323085} = "Vannes";
$areanames{en}->{3323086} = "Brest";
$areanames{en}->{3323087} = "Loudéac";
$areanames{en}->{3323088} = "Rennes";
$areanames{en}->{3323089} = "Paimpol";
$areanames{en}->{3323096} = "Rennes";
$areanames{en}->{3323106} = "Caen";
$areanames{en}->{3323109} = "Vire";
$areanames{en}->{3323110} = "Bayeux";
$areanames{en}->{3323114} = "Deauville";
$areanames{en}->{3323115} = "Caen";
$areanames{en}->{3323120} = "Saint\-Pierre\-sur\-Dives";
$areanames{en}->{3323127} = "Caen";
$areanames{en}->{3323128} = "Houlgate";
$areanames{en}->{3323129} = "Caen";
$areanames{en}->{3323130} = "Caen";
$areanames{en}->{3323131} = "Lisieux";
$areanames{en}->{3323134} = "Caen";
$areanames{en}->{3323135} = "Mondeville";
$areanames{en}->{3323137} = "Courseulles\-sur\-Mer";
$areanames{en}->{3323138} = "Caen";
$areanames{en}->{3323140} = "Falaise";
$areanames{en}->{3323143} = "Caen";
$areanames{en}->{3323144} = "Caen";
$areanames{en}->{3323146} = "Caen";
$areanames{en}->{3323147} = "Caen";
$areanames{en}->{3323148} = "Lisieux";
$areanames{en}->{3323150} = "Caen";
$areanames{en}->{3323151} = "Bayeux";
$areanames{en}->{3323152} = "Caen";
$areanames{en}->{3323153} = "Caen";
$areanames{en}->{3323154} = "Hérouville\-Saint\-Clair";
$areanames{en}->{3323161} = "Lisieux";
$areanames{en}->{3323162} = "Lisieux";
$areanames{en}->{3323164} = "Pont\-l\'Évêque";
$areanames{en}->{3323165} = "Pont\-l\'Évêque";
$areanames{en}->{3323166} = "Vire";
$areanames{en}->{3323167} = "Vire";
$areanames{en}->{3323168} = "Vire";
$areanames{en}->{3323169} = "Condé\-sur\-Noireau";
$areanames{en}->{3323170} = "Caen";
$areanames{en}->{3323171} = "Carpiquet";
$areanames{en}->{3323172} = "Colombelles";
$areanames{en}->{3323173} = "Caen";
$areanames{en}->{3323174} = "Caen";
$areanames{en}->{3323175} = "Caen";
$areanames{en}->{3323181} = "Deauville";
$areanames{en}->{3323182} = "Caen";
$areanames{en}->{3323183} = "Caen";
$areanames{en}->{3323184} = "Caen";
$areanames{en}->{3323185} = "Caen";
$areanames{en}->{3323186} = "Caen";
$areanames{en}->{3323187} = "Villers\-sur\-Mer";
$areanames{en}->{3323188} = "Deauville";
$areanames{en}->{3323189} = "Honfleur";
$areanames{en}->{3323190} = "Falaise";
$areanames{en}->{3323191} = "Cabourg";
$areanames{en}->{3323192} = "Bayeux";
$areanames{en}->{3323193} = "Caen";
$areanames{en}->{3323194} = "Caen";
$areanames{en}->{3323195} = "Hérouville\-Saint\-Clair";
$areanames{en}->{3323196} = "Ouistreham";
$areanames{en}->{3323197} = "Ouistreham";
$areanames{en}->{3323198} = "Deauville";
$areanames{en}->{3323208} = "Rouen";
$areanames{en}->{3323209} = "Louviers";
$areanames{en}->{3323210} = "Rouen";
$areanames{en}->{3323211} = "Le\ Grand\ Quevilly";
$areanames{en}->{3323212} = "Rouen";
$areanames{en}->{3323214} = "Dieppe";
$areanames{en}->{3323218} = "Rouen";
$areanames{en}->{3323220} = "Pont\-Audemer";
$areanames{en}->{3323221} = "Vernon";
$areanames{en}->{3323223} = "Évreux";
$areanames{en}->{3323225} = "Louviers";
$areanames{en}->{3323227} = "Gisors";
$areanames{en}->{3323228} = "Évreux";
$areanames{en}->{3323229} = "Breteuil\ sur\ Iton";
$areanames{en}->{3323230} = "Conches\-en\-Ouche";
$areanames{en}->{3323231} = "Évreux";
$areanames{en}->{3323232} = "Verneuil\-sur\-Avre";
$areanames{en}->{3323233} = "Évreux";
$areanames{en}->{3323238} = "Évreux";
$areanames{en}->{3323239} = "Évreux";
$areanames{en}->{3323240} = "Louviers";
$areanames{en}->{3323241} = "Pont\-Audemer";
$areanames{en}->{3323243} = "Bernay";
$areanames{en}->{3323246} = "Bernay";
$areanames{en}->{3323247} = "Bernay";
$areanames{en}->{3323250} = "Louviers";
$areanames{en}->{3323251} = "Vernon";
$areanames{en}->{3323253} = "Gaillon";
$areanames{en}->{3323254} = "Les\ Andelys";
$areanames{en}->{3323255} = "Gisors";
$areanames{en}->{3323258} = "Nonancourt";
$areanames{en}->{3323259} = "Val\-de\-Reuil";
$areanames{en}->{3323261} = "Val\-de\-Reuil";
$areanames{en}->{3323262} = "Évreux";
$areanames{en}->{3323264} = "Vernon";
$areanames{en}->{3323269} = "Écouis";
$areanames{en}->{3323270} = "Yvetot";
$areanames{en}->{3323271} = "Vernon";
$areanames{en}->{3323274} = "Le\ Havre";
$areanames{en}->{3323276} = "Rouen";
$areanames{en}->{3323277} = "Gaillon";
$areanames{en}->{3323279} = "Montivilliers";
$areanames{en}->{3323281} = "Rouen";
$areanames{en}->{3323282} = "Maromme";
$areanames{en}->{3323283} = "Rouen";
$areanames{en}->{3323284} = "Notre\-Dame\-de\-Gravenchon";
$areanames{en}->{3323289} = "Gournay\-en\-Bray";
$areanames{en}->{3323290} = "Dieppe";
$areanames{en}->{3323291} = "Saint\-Étienne\-du\-Rouvray";
$areanames{en}->{3323294} = "Barentin";
$areanames{en}->{3323296} = "Elbeuf";
$areanames{en}->{3323297} = "Neufchâtel\-en\-Bray";
$areanames{en}->{3323301} = "Cherbourg\-Octeville";
$areanames{en}->{3323303} = "Équeurdreville\-Hainneville";
$areanames{en}->{3323305} = "Saint\-Lô";
$areanames{en}->{3323306} = "Saint\-Lô";
$areanames{en}->{3323308} = "Équeurdreville\-Hainneville";
$areanames{en}->{3323310} = "Cherbourg\-Octeville";
$areanames{en}->{3323312} = "Argentan";
$areanames{en}->{3323317} = "Coutances";
$areanames{en}->{3323319} = "Coutances";
$areanames{en}->{3323320} = "Cherbourg\-Octeville";
$areanames{en}->{3323322} = "Tourlaville";
$areanames{en}->{3323323} = "Cherbourg\-Octeville";
$areanames{en}->{3323324} = "L\'Aigle";
$areanames{en}->{3323326} = "Alençon";
$areanames{en}->{3323328} = "Alençon";
$areanames{en}->{3323329} = "Alençon";
$areanames{en}->{3323331} = "Alençon";
$areanames{en}->{3323332} = "Alençon";
$areanames{en}->{3323336} = "Argentan";
$areanames{en}->{3323340} = "Valognes";
$areanames{en}->{3323342} = "Carentan";
$areanames{en}->{3323343} = "Cherbourg\-Octeville";
$areanames{en}->{3323344} = "Cherbourg\-Octeville";
$areanames{en}->{3323345} = "Coutances";
$areanames{en}->{3323350} = "Granville";
$areanames{en}->{3323353} = "Cherbourg\-Octeville";
$areanames{en}->{3323357} = "Saint\-Lô";
$areanames{en}->{3323358} = "Avranches";
$areanames{en}->{3323362} = "Flers";
$areanames{en}->{3323364} = "Flers";
$areanames{en}->{3323365} = "Flers";
$areanames{en}->{3323367} = "Argentan";
$areanames{en}->{3323368} = "Avranches";
$areanames{en}->{3323371} = "Carentan";
$areanames{en}->{3323372} = "Saint\-Lô";
$areanames{en}->{3323376} = "Coutances";
$areanames{en}->{3323377} = "Saint\-Lô";
$areanames{en}->{3323378} = "Cherbourg\-Octeville";
$areanames{en}->{3323379} = "Avranches";
$areanames{en}->{3323380} = "Alençon";
$areanames{en}->{3323381} = "Alençon";
$areanames{en}->{3323382} = "Alençon";
$areanames{en}->{3323384} = "L\'Aigle";
$areanames{en}->{3323385} = "Mortagne\-au\-Perche";
$areanames{en}->{3323387} = "Cherbourg\-Octeville";
$areanames{en}->{3323388} = "Cherbourg\-Octeville";
$areanames{en}->{3323389} = "Avranches";
$areanames{en}->{3323390} = "Granville";
$areanames{en}->{3323391} = "Granville";
$areanames{en}->{3323393} = "Cherbourg\-Octeville";
$areanames{en}->{3323394} = "Cherbourg\-Octeville";
$areanames{en}->{3323395} = "Valognes";
$areanames{en}->{3323400} = "Pithiviers";
$areanames{en}->{3323401} = "Nogent\-le\-Rotrou";
$areanames{en}->{3323402} = "Montargis";
$areanames{en}->{3323403} = "Blois";
$areanames{en}->{3323404} = "Gien";
$areanames{en}->{3323405} = "Montargis";
$areanames{en}->{3323406} = "Romorantin\-Lanthenay";
$areanames{en}->{3323407} = "Vierzon";
$areanames{en}->{3323408} = "Orléans";
$areanames{en}->{3323409} = "Orléans";
$areanames{en}->{3323410} = "Le\ Blanc";
$areanames{en}->{3323411} = "Châteauroux";
$areanames{en}->{3323412} = "La\ Châtre";
$areanames{en}->{3323413} = "Issoudun";
$areanames{en}->{3323414} = "Valençay";
$areanames{en}->{3323415} = "Amboise";
$areanames{en}->{3323416} = "Chinon";
$areanames{en}->{3323417} = "Loches";
$areanames{en}->{3323418} = "Tours";
$areanames{en}->{3323419} = "Blois";
$areanames{en}->{3323420} = "Romorantin\-Lanthenay";
$areanames{en}->{3323421} = "Saint\-Aignan";
$areanames{en}->{3323422} = "Vendôme";
$areanames{en}->{3323423} = "Gien";
$areanames{en}->{3323424} = "Châteaudun";
$areanames{en}->{3323425} = "Orléans";
$areanames{en}->{3323426} = "Montargis";
$areanames{en}->{3323427} = "Pithiviers";
$areanames{en}->{3323428} = "Orléans";
$areanames{en}->{3323429} = "Bourges";
$areanames{en}->{3323430} = "Tours";
$areanames{en}->{3323431} = "Saint\-Amand\-Montrond";
$areanames{en}->{3323432} = "Orléans";
$areanames{en}->{3323433} = "Romorantin\-Lanthenay";
$areanames{en}->{3323434} = "Bourges";
$areanames{en}->{3323435} = "Blois";
$areanames{en}->{3323436} = "Tours";
$areanames{en}->{3323437} = "Tours";
$areanames{en}->{3323438} = "Tours";
$areanames{en}->{3323439} = "Vierzon";
$areanames{en}->{3323440} = "Chartres";
$areanames{en}->{3323441} = "Vierzon";
$areanames{en}->{3323442} = "Chartres";
$areanames{en}->{3323443} = "Chartres";
$areanames{en}->{3323444} = "Vendôme";
$areanames{en}->{3323445} = "Romorantin\-Lanthenay";
$areanames{en}->{3323446} = "Blois";
$areanames{en}->{3323447} = "Vendôme";
$areanames{en}->{3323448} = "Gien";
$areanames{en}->{3323449} = "Montargis";
$areanames{en}->{3323453} = "Tours";
$areanames{en}->{3323460} = "Tours";
$areanames{en}->{3323461} = "Aubigny\-sur\-Nère";
$areanames{en}->{3323462} = "Orléans";
$areanames{en}->{3323463} = "Chartres";
$areanames{en}->{3323464} = "Bourges";
$areanames{en}->{3323465} = "Dreux";
$areanames{en}->{3323466} = "Nogent\-le\-Rotrou";
$areanames{en}->{3323467} = "Saint\-Amand\-Montrond";
$areanames{en}->{3323468} = "Châteauroux";
$areanames{en}->{3323469} = "Dreux";
$areanames{en}->{3323470} = "Nogent\-le\-Rotrou";
$areanames{en}->{3323471} = "Nogent\-le\-Rotrou";
$areanames{en}->{3323472} = "Amboise";
$areanames{en}->{3323473} = "Le\ Blanc";
$areanames{en}->{3323474} = "Tours";
$areanames{en}->{3323475} = "Tours";
$areanames{en}->{3323476} = "Blois";
$areanames{en}->{3323477} = "Châteauroux";
$areanames{en}->{3323478} = "La\ Châtre";
$areanames{en}->{3323479} = "Vendôme";
$areanames{en}->{3323480} = "Issoudun";
$areanames{en}->{3323481} = "Montargis";
$areanames{en}->{3323482} = "Orléans";
$areanames{en}->{3323483} = "Pithiviers";
$areanames{en}->{3323484} = "Valençay";
$areanames{en}->{3323485} = "Amboise";
$areanames{en}->{3323486} = "Chinon";
$areanames{en}->{3323487} = "Loches";
$areanames{en}->{3323488} = "Tours";
$areanames{en}->{3323489} = "Blois";
$areanames{en}->{3323490} = "Orléans";
$areanames{en}->{3323491} = "Aubigny\-sur\-Nère";
$areanames{en}->{3323492} = "Bourges";
$areanames{en}->{3323493} = "La\ Guerche\-sur\-lAubois";
$areanames{en}->{3323494} = "Saint\-Amand\-Montrond";
$areanames{en}->{3323495} = "Sancerre";
$areanames{en}->{3323496} = "Vierzon";
$areanames{en}->{3323497} = "Chartres";
$areanames{en}->{3323498} = "Châteaudun";
$areanames{en}->{3323499} = "Dreux";
$areanames{en}->{3323503} = "Rouen";
$areanames{en}->{3323506} = "Dieppe";
$areanames{en}->{3323507} = "Rouen";
$areanames{en}->{3323508} = "Darnétal";
$areanames{en}->{3323509} = "Gournay\-en\-Bray";
$areanames{en}->{3323510} = "Fécamp";
$areanames{en}->{3323512} = "Mont\-Saint\-Aignan";
$areanames{en}->{3323514} = "Rouen";
$areanames{en}->{3323515} = "Rouen";
$areanames{en}->{3323519} = "Le\ Havre";
$areanames{en}->{3323521} = "Le\ Havre";
$areanames{en}->{3323522} = "Le\ Havre";
$areanames{en}->{3323524} = "Le\ Havre";
$areanames{en}->{3323525} = "Le\ Havre";
$areanames{en}->{3323526} = "Le\ Havre";
$areanames{en}->{3323528} = "Fécamp";
$areanames{en}->{3323529} = "Fécamp";
$areanames{en}->{3323530} = "Montivilliers";
$areanames{en}->{3323531} = "Bolbec";
$areanames{en}->{3323536} = "Canteleu";
$areanames{en}->{3323537} = "Duclair";
$areanames{en}->{3323538} = "Lillebonne";
$areanames{en}->{332354} = "Le\ Havre";
$areanames{en}->{3323540} = "Dieppe";
$areanames{en}->{3323550} = "Eu";
$areanames{en}->{3323551} = "Le\ Havre";
$areanames{en}->{3323552} = "Rouen";
$areanames{en}->{3323553} = "Le\ Havre";
$areanames{en}->{3323554} = "Le\ Havre";
$areanames{en}->{3323556} = "Yvetot";
$areanames{en}->{3323557} = "Saint\-Valery\-en\-Caux";
$areanames{en}->{3323559} = "Bois\-Guillaume";
$areanames{en}->{3323560} = "Bois\-Guillaume";
$areanames{en}->{3323561} = "Bois\-Guillaume";
$areanames{en}->{3323562} = "Rouen";
$areanames{en}->{3323563} = "Rouen";
$areanames{en}->{3323564} = "Oissel";
$areanames{en}->{3323565} = "Saint\-Étienne\-du\-Rouvray";
$areanames{en}->{3323566} = "Saint\-Étienne\-du\-Rouvray";
$areanames{en}->{3323567} = "Grand\-Couronne";
$areanames{en}->{3323568} = "Petit\-Couronne";
$areanames{en}->{3323569} = "Le\ Grand\ Quevilly";
$areanames{en}->{3323570} = "Rouen";
$areanames{en}->{3323571} = "Rouen";
$areanames{en}->{3323572} = "Rouen";
$areanames{en}->{3323573} = "Rouen";
$areanames{en}->{3323574} = "Déville\-lès\-Rouen";
$areanames{en}->{3323577} = "Elbeuf";
$areanames{en}->{3323578} = "Elbeuf";
$areanames{en}->{3323581} = "Elbeuf";
$areanames{en}->{3323582} = "Dieppe";
$areanames{en}->{3323584} = "Dieppe";
$areanames{en}->{3323586} = "Eu";
$areanames{en}->{3323588} = "Rouen";
$areanames{en}->{3323589} = "Rouen";
$areanames{en}->{3323590} = "Gournay\-en\-Bray";
$areanames{en}->{3323591} = "Barentin";
$areanames{en}->{3323592} = "Barentin";
$areanames{en}->{3323595} = "Yvetot";
$areanames{en}->{3323597} = "Saint\-Valery\-en\-Caux";
$areanames{en}->{3323598} = "Rouen";
$areanames{en}->{3323600} = "Tours";
$areanames{en}->{3323601} = "La\ Châtre";
$areanames{en}->{3323602} = "Valençay";
$areanames{en}->{3323603} = "Amboise";
$areanames{en}->{3323604} = "Chinon";
$areanames{en}->{3323605} = "Loches";
$areanames{en}->{3323606} = "Saint\-Aignan";
$areanames{en}->{3323607} = "Tours";
$areanames{en}->{3323608} = "Bourges";
$areanames{en}->{3323609} = "La\ Guerche\-sur\-lAubois";
$areanames{en}->{3323610} = "Orléans";
$areanames{en}->{3323611} = "Orléans";
$areanames{en}->{3323612} = "Orléans";
$areanames{en}->{3323613} = "Orléans";
$areanames{en}->{3323614} = "Romorantin\-Lanthenay";
$areanames{en}->{3323615} = "Chartres";
$areanames{en}->{3323616} = "Tours";
$areanames{en}->{3323617} = "Orléans";
$areanames{en}->{3323618} = "Bourges";
$areanames{en}->{3323619} = "Chinon";
$areanames{en}->{3323620} = "Amboise";
$areanames{en}->{3323621} = "Aubigny\-sur\-Nère";
$areanames{en}->{3323622} = "Le\ Blanc";
$areanames{en}->{3323623} = "Blois";
$areanames{en}->{3323624} = "Bourges";
$areanames{en}->{3323625} = "Chartres";
$areanames{en}->{3323626} = "Châteaudun";
$areanames{en}->{3323627} = "Châteauroux";
$areanames{en}->{3323628} = "La\ Châtre";
$areanames{en}->{3323629} = "Chinon";
$areanames{en}->{3323630} = "Dreux";
$areanames{en}->{3323631} = "La\ Guerche\-sur\-lAubois";
$areanames{en}->{3323632} = "Issoudun";
$areanames{en}->{3323633} = "Loches";
$areanames{en}->{3323634} = "Montargis";
$areanames{en}->{3323635} = "Nogent\-le\-Rotrou";
$areanames{en}->{3323636} = "Dreux";
$areanames{en}->{3323637} = "Pithiviers";
$areanames{en}->{3323638} = "Romorantin\-Lanthenay";
$areanames{en}->{3323639} = "Saint\-Aignan";
$areanames{en}->{3323640} = "Saint\-Amand\-Montrond";
$areanames{en}->{3323641} = "Blois";
$areanames{en}->{3323642} = "Sancerre";
$areanames{en}->{3323643} = "Tours";
$areanames{en}->{3323644} = "Valençay";
$areanames{en}->{3323645} = "Vendôme";
$areanames{en}->{3323646} = "Vierzon";
$areanames{en}->{3323647} = "Orléans";
$areanames{en}->{3323648} = "Gien";
$areanames{en}->{3323649} = "Tours";
$areanames{en}->{3323650} = "Orléans";
$areanames{en}->{3323651} = "Aubigny\-sur\-Nère";
$areanames{en}->{3323652} = "La\ Guerche\-sur\-lAubois";
$areanames{en}->{3323653} = "Saint\-Amand\-Montrond";
$areanames{en}->{3323654} = "Sancerre";
$areanames{en}->{3323655} = "Vierzon";
$areanames{en}->{3323656} = "Orléans";
$areanames{en}->{3323657} = "Châteauroux";
$areanames{en}->{3323658} = "Chartres";
$areanames{en}->{3323659} = "Amboise";
$areanames{en}->{3323660} = "Tours";
$areanames{en}->{3323661} = "Orléans";
$areanames{en}->{3323662} = "Aubigny\-sur\-Nère";
$areanames{en}->{3323663} = "Nogent\-le\-Rotrou";
$areanames{en}->{3323664} = "Le\ Blanc";
$areanames{en}->{3323665} = "Blois";
$areanames{en}->{3323666} = "Sancerre";
$areanames{en}->{3323667} = "Chartres";
$areanames{en}->{3323668} = "Châteaudun";
$areanames{en}->{3323669} = "Dreux";
$areanames{en}->{3323670} = "Tours";
$areanames{en}->{3323671} = "Bourges";
$areanames{en}->{3323672} = "Chartres";
$areanames{en}->{3323673} = "Châteaudun";
$areanames{en}->{3323674} = "Châteauroux";
$areanames{en}->{3323675} = "La\ Châtre";
$areanames{en}->{3323676} = "Chinon";
$areanames{en}->{3323677} = "Dreux";
$areanames{en}->{3323678} = "Bourges";
$areanames{en}->{3323679} = "Gien";
$areanames{en}->{3323680} = "La\ Guerche\-sur\-lAubois";
$areanames{en}->{3323681} = "Orléans";
$areanames{en}->{3323682} = "Issoudun";
$areanames{en}->{3323683} = "Loches";
$areanames{en}->{3323684} = "Montargis";
$areanames{en}->{3323685} = "Nogent\-le\-Rotrou";
$areanames{en}->{3323686} = "Orléans";
$areanames{en}->{3323687} = "Pithiviers";
$areanames{en}->{3323688} = "Romorantin\-Lanthenay";
$areanames{en}->{3323689} = "Saint\-Aignan";
$areanames{en}->{3323690} = "Châteauroux";
$areanames{en}->{3323691} = "Saint\-Amand\-Montrond";
$areanames{en}->{3323692} = "Sancerre";
$areanames{en}->{3323693} = "Tours";
$areanames{en}->{3323694} = "Valençay";
$areanames{en}->{3323695} = "Vendôme";
$areanames{en}->{3323696} = "Vierzon";
$areanames{en}->{3323697} = "Tours";
$areanames{en}->{3323698} = "Dreux";
$areanames{en}->{3323699} = "Orléans";
$areanames{en}->{332370} = "Nord\ Ouest";
$areanames{en}->{3323718} = "Chartres";
$areanames{en}->{3323720} = "Chartres";
$areanames{en}->{3323721} = "Chartres";
$areanames{en}->{3323723} = "Courville\-sur\-Eure";
$areanames{en}->{3323724} = "Illiers\-Combray";
$areanames{en}->{3323727} = "Maintenon";
$areanames{en}->{3323728} = "Chartres";
$areanames{en}->{3323730} = "Chartres";
$areanames{en}->{3323731} = "Auneau";
$areanames{en}->{3323733} = "Chartres";
$areanames{en}->{3323734} = "Chartres";
$areanames{en}->{3323735} = "Chartres";
$areanames{en}->{3323736} = "Chartres";
$areanames{en}->{3323737} = "Senonches";
$areanames{en}->{3323741} = "Anet";
$areanames{en}->{3323742} = "Dreux";
$areanames{en}->{3323744} = "Châteaudun";
$areanames{en}->{3323745} = "Châteaudun";
$areanames{en}->{3323746} = "Dreux";
$areanames{en}->{3323747} = "Bonneval";
$areanames{en}->{3323750} = "Dreux";
$areanames{en}->{3323751} = "Nogent\-le\-Roi";
$areanames{en}->{3323752} = "Nogent\-le\-Rotrou";
$areanames{en}->{3323753} = "Nogent\-le\-Rotrou";
$areanames{en}->{3323764} = "Ézy\-sur\-Eure";
$areanames{en}->{3323765} = "Tremblay\-les\-Villages";
$areanames{en}->{3323766} = "Châteaudun";
$areanames{en}->{332377} = "Nord\ Ouest";
$areanames{en}->{3323781} = "La\ Loupe";
$areanames{en}->{3323783} = "Épernon";
$areanames{en}->{3323784} = "Chartres";
$areanames{en}->{3323788} = "Chartres";
$areanames{en}->{3323791} = "Chartres";
$areanames{en}->{3323797} = "Arrou";
$areanames{en}->{3323798} = "Cloyes\-sur\-le\-Loir";
$areanames{en}->{3323799} = "Voves";
$areanames{en}->{3323807} = "Montargis";
$areanames{en}->{332381} = "Nord\ Ouest";
$areanames{en}->{3323814} = "Orléans";
$areanames{en}->{3323815} = "Orléans";
$areanames{en}->{3323816} = "Montargis";
$areanames{en}->{3323821} = "Saint\-Jean\-de\-Braye";
$areanames{en}->{3323822} = "Orléans";
$areanames{en}->{3323824} = "Orléans";
$areanames{en}->{3323825} = "Olivet";
$areanames{en}->{3323828} = "Montargis";
$areanames{en}->{3323830} = "Pithiviers";
$areanames{en}->{3323831} = "Briare";
$areanames{en}->{3323833} = "Puiseaux";
$areanames{en}->{3323834} = "Malesherbes";
$areanames{en}->{3323835} = "Saint\-Benoît\-sur\-Loire";
$areanames{en}->{3323836} = "Sully\-sur\-Loire";
$areanames{en}->{3323837} = "Briare";
$areanames{en}->{3323838} = "Gien";
$areanames{en}->{3323841} = "Sandillon";
$areanames{en}->{3323842} = "Orléans";
$areanames{en}->{3323843} = "Orléans";
$areanames{en}->{3323844} = "Beaugency";
$areanames{en}->{3323845} = "Cléry\-Saint\-André";
$areanames{en}->{3323849} = "Olivet";
$areanames{en}->{3323851} = "Orléans";
$areanames{en}->{3323852} = "Orléans";
$areanames{en}->{3323853} = "Orléans";
$areanames{en}->{3323854} = "Orléans";
$areanames{en}->{3323855} = "Saint\-Jean\-de\-Braye";
$areanames{en}->{3323856} = "Orléans";
$areanames{en}->{3323858} = "Châteauneuf\-sur\-Loire";
$areanames{en}->{3323859} = "Jargeau";
$areanames{en}->{3323861} = "Saint\-Jean\-de\-Braye";
$areanames{en}->{3323862} = "Orléans";
$areanames{en}->{3323863} = "Olivet";
$areanames{en}->{3323864} = "Saint\-Denis\-en\-Val";
$areanames{en}->{3323865} = "Loury";
$areanames{en}->{3323866} = "Orléans";
$areanames{en}->{3323867} = "Gien";
$areanames{en}->{3323868} = "Orléans";
$areanames{en}->{3323869} = "Olivet";
$areanames{en}->{3323873} = "Saran";
$areanames{en}->{3323874} = "Ingré";
$areanames{en}->{3323877} = "Orléans";
$areanames{en}->{3323879} = "Orléans";
$areanames{en}->{3323881} = "Orléans";
$areanames{en}->{3323883} = "Orléans";
$areanames{en}->{3323884} = "Orléans";
$areanames{en}->{3323885} = "Montargis";
$areanames{en}->{3323886} = "Orléans";
$areanames{en}->{3323888} = "Orléans";
$areanames{en}->{3323889} = "Montargis";
$areanames{en}->{3323890} = "Bellegarde";
$areanames{en}->{3323891} = "Neuville\-aux\-Bois";
$areanames{en}->{3323892} = "Dordives";
$areanames{en}->{3323893} = "Montargis";
$areanames{en}->{3323895} = "Château\-Renard";
$areanames{en}->{3323896} = "Ferrières\-en\-Gâtinais";
$areanames{en}->{3323897} = "Courtenay";
$areanames{en}->{3323898} = "Montargis";
$areanames{en}->{3324000} = "Saint\-Nazaire";
$areanames{en}->{3324001} = "Saint\-Nazaire";
$areanames{en}->{3324002} = "Sainte\-Pazanne";
$areanames{en}->{3324007} = "Derval";
$areanames{en}->{3324008} = "Nantes";
$areanames{en}->{3324009} = "Liré";
$areanames{en}->{3324011} = "La\ Baule\ Escoublac";
$areanames{en}->{3324012} = "Nantes";
$areanames{en}->{3324013} = "Rezé";
$areanames{en}->{3324014} = "Nantes";
$areanames{en}->{3324015} = "Guérande";
$areanames{en}->{3324016} = "Nantes";
$areanames{en}->{3324017} = "Saint\-Nazaire";
$areanames{en}->{3324018} = "Nantes";
$areanames{en}->{3324019} = "Saint\-Nazaire";
$areanames{en}->{3324020} = "Nantes";
$areanames{en}->{3324022} = "Saint\-Nazaire";
$areanames{en}->{3324023} = "Batz\-sur\-Mer";
$areanames{en}->{3324024} = "Guérande";
$areanames{en}->{3324025} = "Sainte\-Luce\-sur\-Loire";
$areanames{en}->{3324027} = "Saint\-Brevin\-les\-Pins";
$areanames{en}->{3324028} = "Châteaubriant";
$areanames{en}->{3324029} = "Nantes";
$areanames{en}->{3324030} = "Nantes";
$areanames{en}->{3324034} = "Vertou";
$areanames{en}->{3324035} = "Nantes";
$areanames{en}->{3324036} = "Vallet";
$areanames{en}->{3324037} = "Nantes";
$areanames{en}->{3324038} = "Couëron";
$areanames{en}->{3324039} = "Saint\-Brevin\-les\-Pins";
$areanames{en}->{3324040} = "Nantes";
$areanames{en}->{3324041} = "Nantes";
$areanames{en}->{3324042} = "Le\ Pouliguen";
$areanames{en}->{3324043} = "Nantes";
$areanames{en}->{3324045} = "Donges";
$areanames{en}->{3324046} = "Nantes";
$areanames{en}->{3324047} = "Nantes";
$areanames{en}->{3324048} = "Nantes";
$areanames{en}->{3324049} = "Nantes";
$areanames{en}->{3324050} = "Nantes";
$areanames{en}->{3324052} = "Nantes";
$areanames{en}->{3324053} = "Saint\-Nazaire";
$areanames{en}->{3324054} = "Clisson";
$areanames{en}->{3324057} = "Héric";
$areanames{en}->{3324058} = "Nantes";
$areanames{en}->{3324059} = "Nantes";
$areanames{en}->{3324060} = "La\ Baule\ Escoublac";
$areanames{en}->{3324061} = "Pornichet";
$areanames{en}->{3324062} = "Guérande";
$areanames{en}->{3324063} = "Orvault";
$areanames{en}->{3324065} = "Bouguenais";
$areanames{en}->{3324066} = "Saint\-Nazaire";
$areanames{en}->{3324068} = "Carquefou";
$areanames{en}->{3324069} = "Nantes";
$areanames{en}->{3324070} = "Saint\-Nazaire";
$areanames{en}->{3324071} = "Nantes";
$areanames{en}->{3324072} = "Nort\-sur\-Erdre";
$areanames{en}->{3324073} = "Nantes";
$areanames{en}->{3324074} = "Nantes";
$areanames{en}->{3324075} = "Rezé";
$areanames{en}->{3324076} = "Nantes";
$areanames{en}->{3324077} = "Sucé\-sur\-Erdre";
$areanames{en}->{3324078} = "Saint\-Philbert\-de\-Grand\-Lieu";
$areanames{en}->{3324079} = "Blain";
$areanames{en}->{3324080} = "Saint\-Sébastien\-sur\-Loire";
$areanames{en}->{3324081} = "Châteaubriant";
$areanames{en}->{3324082} = "Pornic";
$areanames{en}->{3324083} = "Ancenis";
$areanames{en}->{3324084} = "Nantes";
$areanames{en}->{3324085} = "Saint\-Herblain";
$areanames{en}->{3324086} = "Couëron";
$areanames{en}->{3324089} = "Nantes";
$areanames{en}->{3324090} = "Trignac";
$areanames{en}->{3324091} = "Saint\-Nazaire";
$areanames{en}->{3324092} = "Saint\-Herblain";
$areanames{en}->{3324093} = "Nantes";
$areanames{en}->{3324094} = "Treillières";
$areanames{en}->{3324095} = "Nantes";
$areanames{en}->{3324096} = "Ancenis";
$areanames{en}->{3324105} = "Angers";
$areanames{en}->{3324118} = "Angers";
$areanames{en}->{3324119} = "Angers";
$areanames{en}->{3324120} = "Angers";
$areanames{en}->{3324122} = "Angers";
$areanames{en}->{3324123} = "Angers";
$areanames{en}->{3324124} = "Angers";
$areanames{en}->{3324125} = "Angers";
$areanames{en}->{3324127} = "Angers";
$areanames{en}->{3324129} = "Cholet";
$areanames{en}->{3324130} = "Chemillé";
$areanames{en}->{3324131} = "Angers";
$areanames{en}->{3324134} = "Angers";
$areanames{en}->{3324135} = "Angers";
$areanames{en}->{3324136} = "Angers";
$areanames{en}->{3324137} = "Angers";
$areanames{en}->{3324140} = "Saumur";
$areanames{en}->{3324143} = "Angers";
$areanames{en}->{3324144} = "Angers";
$areanames{en}->{3324146} = "Cholet";
$areanames{en}->{3324147} = "Angers";
$areanames{en}->{3324148} = "Angers";
$areanames{en}->{3324149} = "Cholet";
$areanames{en}->{3324150} = "Saumur";
$areanames{en}->{3324151} = "Saumur";
$areanames{en}->{3324153} = "Saumur";
$areanames{en}->{3324158} = "Cholet";
$areanames{en}->{3324159} = "Doué\-la\-Fontaine";
$areanames{en}->{3324160} = "Angers";
$areanames{en}->{3324162} = "Cholet";
$areanames{en}->{3324163} = "Beaupreau";
$areanames{en}->{3324165} = "Cholet";
$areanames{en}->{3324166} = "Angers";
$areanames{en}->{3324167} = "Saumur";
$areanames{en}->{3324168} = "Angers";
$areanames{en}->{3324169} = "Avrillé";
$areanames{en}->{3324171} = "Cholet";
$areanames{en}->{3324172} = "Angers";
$areanames{en}->{3324173} = "Angers";
$areanames{en}->{3324178} = "Chalonnes\-sur\-Loire";
$areanames{en}->{3324179} = "Angers";
$areanames{en}->{3324180} = "Maze";
$areanames{en}->{3324181} = "Angers";
$areanames{en}->{3324183} = "Saumur";
$areanames{en}->{3324186} = "Angers";
$areanames{en}->{3324187} = "Angers";
$areanames{en}->{3324188} = "Angers";
$areanames{en}->{3324189} = "Baugé";
$areanames{en}->{3324190} = "Chevire\-le\-Rouge";
$areanames{en}->{3324191} = "Brissac\-Quince";
$areanames{en}->{3324192} = "Segre";
$areanames{en}->{3324193} = "Saint\-Barthelemy\-dAnjou";
$areanames{en}->{3324200} = "Châteauroux";
$areanames{en}->{3324201} = "Montargis";
$areanames{en}->{3324202} = "Vendôme";
$areanames{en}->{3324203} = "Romorantin\-Lanthenay";
$areanames{en}->{3324204} = "Gien";
$areanames{en}->{3324205} = "Châteauroux";
$areanames{en}->{3324206} = "Tours";
$areanames{en}->{3324207} = "Orléans";
$areanames{en}->{3324208} = "Tours";
$areanames{en}->{3324209} = "Aubigny\-sur\-Nère";
$areanames{en}->{3324210} = "La\ Guerche\-sur\-lAubois";
$areanames{en}->{3324211} = "Saint\-Amand\-Montrond";
$areanames{en}->{3324212} = "Sancerre";
$areanames{en}->{3324213} = "Vierzon";
$areanames{en}->{3324214} = "Châteaudun";
$areanames{en}->{3324215} = "Nogent\-le\-Rotrou";
$areanames{en}->{3324216} = "Le\ Blanc";
$areanames{en}->{3324217} = "La\ Châtre";
$areanames{en}->{3324218} = "Issoudun";
$areanames{en}->{3324219} = "Valençay";
$areanames{en}->{3324220} = "Amboise";
$areanames{en}->{3324221} = "Chinon";
$areanames{en}->{3324222} = "Loches";
$areanames{en}->{3324223} = "Saint\-Aignan";
$areanames{en}->{3324224} = "Pithiviers";
$areanames{en}->{3324225} = "Chartres";
$areanames{en}->{3324226} = "Dreux";
$areanames{en}->{3324227} = "Tours";
$areanames{en}->{3324228} = "Châteaudun";
$areanames{en}->{3324229} = "Orléans";
$areanames{en}->{3324230} = "Bourges";
$areanames{en}->{3324231} = "Tours";
$areanames{en}->{3324232} = "Valençay";
$areanames{en}->{3324233} = "Vendôme";
$areanames{en}->{3324234} = "Chinon";
$areanames{en}->{3324235} = "Sancerre";
$areanames{en}->{3324236} = "Saint\-Amand\-Montrond";
$areanames{en}->{3324237} = "Amboise";
$areanames{en}->{3324238} = "Issoudun";
$areanames{en}->{3324239} = "Nogent\-le\-Rotrou";
$areanames{en}->{3324240} = "La\ Châtre";
$areanames{en}->{3324241} = "Saint\-Aignan";
$areanames{en}->{3324242} = "Pithiviers";
$areanames{en}->{3324243} = "Montargis";
$areanames{en}->{3324244} = "Blois";
$areanames{en}->{3324245} = "Aubigny\-sur\-Nère";
$areanames{en}->{3324246} = "La\ Guerche\-sur\-lAubois";
$areanames{en}->{3324247} = "Saint\-Amand\-Montrond";
$areanames{en}->{3324248} = "Sancerre";
$areanames{en}->{3324249} = "Vierzon";
$areanames{en}->{3324250} = "Chartres";
$areanames{en}->{3324251} = "Châteaudun";
$areanames{en}->{3324252} = "Nogent\-le\-Rotrou";
$areanames{en}->{3324253} = "Le\ Blanc";
$areanames{en}->{3324254} = "La\ Châtre";
$areanames{en}->{3324255} = "Issoudun";
$areanames{en}->{3324256} = "Valençay";
$areanames{en}->{3324257} = "Amboise";
$areanames{en}->{3324258} = "Chinon";
$areanames{en}->{3324259} = "Loches";
$areanames{en}->{3324260} = "Romorantin\-Lanthenay";
$areanames{en}->{3324261} = "Saint\-Aignan";
$areanames{en}->{3324262} = "Vendôme";
$areanames{en}->{3324263} = "Gien";
$areanames{en}->{3324264} = "Montargis";
$areanames{en}->{3324265} = "Pithiviers";
$areanames{en}->{3324266} = "Châteauroux";
$areanames{en}->{3324267} = "Tours";
$areanames{en}->{3324268} = "Blois";
$areanames{en}->{3324269} = "Chartres";
$areanames{en}->{3324270} = "Aubigny\-sur\-Nère";
$areanames{en}->{3324271} = "Bourges";
$areanames{en}->{3324272} = "La\ Guerche\-sur\-lAubois";
$areanames{en}->{3324273} = "Sancerre";
$areanames{en}->{3324274} = "Saint\-Amand\-Montrond";
$areanames{en}->{3324275} = "Vierzon";
$areanames{en}->{3324276} = "Chartres";
$areanames{en}->{3324277} = "Châteaudun";
$areanames{en}->{3324278} = "Dreux";
$areanames{en}->{3324279} = "Nogent\-le\-Rotrou";
$areanames{en}->{3324280} = "Châteauroux";
$areanames{en}->{3324281} = "Issoudun";
$areanames{en}->{3324282} = "La\ Châtre";
$areanames{en}->{3324283} = "Le\ Blanc";
$areanames{en}->{3324284} = "Valençay";
$areanames{en}->{3324285} = "Amboise";
$areanames{en}->{3324286} = "Chinon";
$areanames{en}->{3324287} = "Loches";
$areanames{en}->{3324288} = "Tours";
$areanames{en}->{3324289} = "Blois";
$areanames{en}->{3324290} = "Romorantin\-Lanthenay";
$areanames{en}->{3324291} = "Saint\-Aignan";
$areanames{en}->{3324292} = "Vendôme";
$areanames{en}->{3324293} = "Gien";
$areanames{en}->{3324294} = "Montargis";
$areanames{en}->{3324295} = "Orléans";
$areanames{en}->{3324296} = "Pithiviers";
$areanames{en}->{3324297} = "Tours";
$areanames{en}->{3324298} = "Saint\-Aignan";
$areanames{en}->{3324299} = "Romorantin\-Lanthenay";
$areanames{en}->{3324301} = "evron";
$areanames{en}->{3324304} = "Mayenne";
$areanames{en}->{3324305} = "Ernée";
$areanames{en}->{3324307} = "Château\-Gontier";
$areanames{en}->{3324308} = "Gorron";
$areanames{en}->{3324309} = "Château\-Gontier";
$areanames{en}->{3324314} = "Le\ Mans";
$areanames{en}->{3324316} = "Le\ Mans";
$areanames{en}->{3324321} = "Arnage";
$areanames{en}->{3324323} = "Le\ Mans";
$areanames{en}->{3324324} = "Le\ Mans";
$areanames{en}->{3324326} = "Laval";
$areanames{en}->{3324328} = "Le\ Mans";
$areanames{en}->{3324329} = "Bonnétable";
$areanames{en}->{3324330} = "Mayenne";
$areanames{en}->{3324332} = "Mayenne";
$areanames{en}->{3324339} = "Le\ Mans";
$areanames{en}->{3324340} = "Changé";
$areanames{en}->{3324341} = "Le\ Mans";
$areanames{en}->{3324342} = "Écommoy";
$areanames{en}->{3324343} = "Le\ Mans";
$areanames{en}->{3324344} = "Château\-du\-Loir";
$areanames{en}->{3324348} = "La\ Flèche";
$areanames{en}->{3324349} = "Laval";
$areanames{en}->{3324350} = "Le\ Mans";
$areanames{en}->{3324352} = "Le\ Mans";
$areanames{en}->{3324353} = "Laval";
$areanames{en}->{3324354} = "Le\ Mans";
$areanames{en}->{3324356} = "Laval";
$areanames{en}->{3324358} = "Laval";
$areanames{en}->{3324359} = "Laval";
$areanames{en}->{3324360} = "La\ Ferté\ Bernard";
$areanames{en}->{3324362} = "Sablé\-sur\-Sarthe";
$areanames{en}->{3324363} = "Saint\-Calais";
$areanames{en}->{3324366} = "Laval";
$areanames{en}->{3324367} = "Laval";
$areanames{en}->{3324369} = "Laval";
$areanames{en}->{3324371} = "La\ Ferté\ Bernard";
$areanames{en}->{3324372} = "Le\ Mans";
$areanames{en}->{3324374} = "Le\ Mans";
$areanames{en}->{3324375} = "Le\ Mans";
$areanames{en}->{3324377} = "Le\ Mans";
$areanames{en}->{3324378} = "Le\ Mans";
$areanames{en}->{3324380} = "Allonnes";
$areanames{en}->{3324381} = "Le\ Mans";
$areanames{en}->{3324382} = "Le\ Mans";
$areanames{en}->{3324383} = "Le\ Mans";
$areanames{en}->{3324384} = "Le\ Mans";
$areanames{en}->{3324385} = "Le\ Mans";
$areanames{en}->{3324386} = "Le\ Mans";
$areanames{en}->{3324389} = "Connerré";
$areanames{en}->{3324391} = "Laval";
$areanames{en}->{3324392} = "Sablé\-sur\-Sarthe";
$areanames{en}->{3324394} = "La\ Flèche";
$areanames{en}->{3324395} = "Sablé\-sur\-Sarthe";
$areanames{en}->{3324400} = "Le\ Mans";
$areanames{en}->{3324401} = "Angers";
$areanames{en}->{3324402} = "Le\ Mans";
$areanames{en}->{3324403} = "Ancenis";
$areanames{en}->{3324404} = "Blain";
$areanames{en}->{3324405} = "Châteaubriant";
$areanames{en}->{3324406} = "Pornic";
$areanames{en}->{3324407} = "Saint\-Nazaire";
$areanames{en}->{3324408} = "Baugé\-en\-Anjou";
$areanames{en}->{3324409} = "Cholet";
$areanames{en}->{3324410} = "Angers";
$areanames{en}->{3324411} = "Baugé\-en\-Anjou";
$areanames{en}->{3324412} = "Beaumont\-sur\-Sarthe";
$areanames{en}->{3324413} = "Château\-du\-Loir";
$areanames{en}->{3324414} = "Château\-Gontier";
$areanames{en}->{3324415} = "La\ Ferte\-Bernard";
$areanames{en}->{3324416} = "La\ Flèche";
$areanames{en}->{3324417} = "Fontenay\-le\-Comte";
$areanames{en}->{3324418} = "Les\ Herbiers";
$areanames{en}->{3324419} = "Laval";
$areanames{en}->{3324420} = "Luçon";
$areanames{en}->{3324421} = "Le\ Mans";
$areanames{en}->{3324422} = "Mayenne";
$areanames{en}->{3324423} = "Les\ Sables\ d\'Olonne";
$areanames{en}->{3324424} = "Sablé\-sur\-Sarthe";
$areanames{en}->{3324425} = "Saint\-Calais";
$areanames{en}->{3324426} = "Saumur";
$areanames{en}->{3324427} = "Saumur";
$areanames{en}->{3324428} = "Segre";
$areanames{en}->{3324429} = "Mayenne";
$areanames{en}->{3324430} = "Beaumont\-sur\-Sarthe";
$areanames{en}->{3324431} = "Château\-du\-Loir";
$areanames{en}->{3324432} = "La\ Ferte\-Bernard";
$areanames{en}->{3324433} = "La\ Flèche";
$areanames{en}->{3324434} = "Sablé\-sur\-Sarthe";
$areanames{en}->{3324435} = "Saint\-Calais";
$areanames{en}->{3324436} = "Challans";
$areanames{en}->{3324437} = "Fontenay\-le\-Comte";
$areanames{en}->{3324438} = "Les\ Herbiers";
$areanames{en}->{3324439} = "Luçon";
$areanames{en}->{3324440} = "La\ Roche\-sur\-Yon";
$areanames{en}->{3324441} = "Les\ Sables\ d\'Olonne";
$areanames{en}->{3324442} = "Ancenis";
$areanames{en}->{3324443} = "Blain";
$areanames{en}->{3324444} = "Châteaubriant";
$areanames{en}->{3324445} = "Fontenay\-le\-Comte";
$areanames{en}->{3324446} = "La\ Flèche";
$areanames{en}->{3324447} = "Laval";
$areanames{en}->{3324448} = "Pornic";
$areanames{en}->{3324449} = "Sablé\-sur\-Sarthe";
$areanames{en}->{3324450} = "Segre";
$areanames{en}->{3324451} = "Nantes";
$areanames{en}->{3324452} = "Château\-du\-Loir";
$areanames{en}->{3324453} = "La\ Ferte\-Bernard";
$areanames{en}->{3324454} = "La\ Flèche";
$areanames{en}->{3324455} = "Sablé\-sur\-Sarthe";
$areanames{en}->{3324456} = "Saint\-Calais";
$areanames{en}->{3324457} = "Fontenay\-le\-Comte";
$areanames{en}->{3324458} = "Les\ Herbiers";
$areanames{en}->{3324459} = "Luçon";
$areanames{en}->{3324460} = "Les\ Sables\ d\'Olonne";
$areanames{en}->{3324461} = "Angers";
$areanames{en}->{3324462} = "Saint\-Nazaire";
$areanames{en}->{3324463} = "Angers";
$areanames{en}->{3324464} = "Laval";
$areanames{en}->{3324465} = "Le\ Mans";
$areanames{en}->{3324466} = "Nantes";
$areanames{en}->{3324467} = "Saint\-Nazaire";
$areanames{en}->{3324468} = "Angers";
$areanames{en}->{3324469} = "Cholet";
$areanames{en}->{3324470} = "Nantes";
$areanames{en}->{3324471} = "Le\ Mans";
$areanames{en}->{3324472} = "Laval";
$areanames{en}->{3324473} = "Saint\-Nazaire";
$areanames{en}->{3324474} = "Ancenis";
$areanames{en}->{3324475} = "Blain";
$areanames{en}->{3324476} = "Nantes";
$areanames{en}->{3324477} = "Nantes";
$areanames{en}->{3324478} = "Challans";
$areanames{en}->{3324479} = "Châteaubriant";
$areanames{en}->{3324480} = "La\ Roche\-sur\-Yon";
$areanames{en}->{3324481} = "Le\ Mans";
$areanames{en}->{3324482} = "Pornic";
$areanames{en}->{3324483} = "Segre";
$areanames{en}->{3324484} = "Nantes";
$areanames{en}->{3324485} = "Angers";
$areanames{en}->{3324486} = "Ancenis";
$areanames{en}->{3324487} = "Angers";
$areanames{en}->{3324488} = "Angers";
$areanames{en}->{3324489} = "Baugé\-en\-Anjou";
$areanames{en}->{3324490} = "Saint\-Nazaire";
$areanames{en}->{3324491} = "Beaumont\-sur\-Sarthe";
$areanames{en}->{3324492} = "Blain";
$areanames{en}->{3324493} = "Challans";
$areanames{en}->{3324494} = "Châteaubriant";
$areanames{en}->{3324495} = "Château\-du\-Loir";
$areanames{en}->{3324496} = "Château\-Gontier";
$areanames{en}->{3324497} = "Cholet";
$areanames{en}->{3324498} = "Fontenay\-le\-Comte";
$areanames{en}->{3324499} = "Le\ Mans";
$areanames{en}->{3324500} = "Nogent\-le\-Rotrou";
$areanames{en}->{3324501} = "Le\ Blanc";
$areanames{en}->{3324502} = "Châteauroux";
$areanames{en}->{3324503} = "La\ Châtre";
$areanames{en}->{3324504} = "Issoudun";
$areanames{en}->{3324505} = "Valençay";
$areanames{en}->{3324506} = "Amboise";
$areanames{en}->{3324507} = "Chinon";
$areanames{en}->{3324508} = "Loches";
$areanames{en}->{3324509} = "Tours";
$areanames{en}->{3324510} = "Blois";
$areanames{en}->{3324511} = "Romorantin\-Lanthenay";
$areanames{en}->{3324512} = "Saint\-Aignan";
$areanames{en}->{3324513} = "Vendôme";
$areanames{en}->{3324514} = "Gien";
$areanames{en}->{3324515} = "Montargis";
$areanames{en}->{3324516} = "Pithiviers";
$areanames{en}->{3324517} = "Blois";
$areanames{en}->{3324518} = "Bourges";
$areanames{en}->{3324519} = "La\ Guerche\-sur\-lAubois";
$areanames{en}->{3324520} = "Châteauroux";
$areanames{en}->{3324521} = "Blois";
$areanames{en}->{3324522} = "Montargis";
$areanames{en}->{3324523} = "Orléans";
$areanames{en}->{3324524} = "Châteauroux";
$areanames{en}->{3324525} = "Tours";
$areanames{en}->{3324526} = "Chartres";
$areanames{en}->{3324527} = "Châteaudun";
$areanames{en}->{3324528} = "Le\ Blanc";
$areanames{en}->{3324529} = "La\ Châtre";
$areanames{en}->{3324530} = "Orléans";
$areanames{en}->{3324531} = "Valençay";
$areanames{en}->{3324532} = "Chinon";
$areanames{en}->{3324533} = "Loches";
$areanames{en}->{3324534} = "Tours";
$areanames{en}->{3324535} = "Blois";
$areanames{en}->{3324536} = "Romorantin\-Lanthenay";
$areanames{en}->{3324537} = "Saint\-Aignan";
$areanames{en}->{3324538} = "Gien";
$areanames{en}->{3324539} = "Montargis";
$areanames{en}->{3324540} = "Orléans";
$areanames{en}->{3324541} = "Bourges";
$areanames{en}->{3324542} = "La\ Guerche\-sur\-lAubois";
$areanames{en}->{3324543} = "Saint\-Amand\-Montrond";
$areanames{en}->{3324544} = "Sancerre";
$areanames{en}->{3324545} = "Vierzon";
$areanames{en}->{3324546} = "Issoudun";
$areanames{en}->{3324547} = "Tours";
$areanames{en}->{3324548} = "Orléans";
$areanames{en}->{3324549} = "Chinon";
$areanames{en}->{3324550} = "Blois";
$areanames{en}->{3324551} = "Saint\-Aignan";
$areanames{en}->{3324552} = "Châteauroux";
$areanames{en}->{3324553} = "La\ Guerche\-sur\-lAubois";
$areanames{en}->{3324554} = "Issoudun";
$areanames{en}->{3324555} = "Tours";
$areanames{en}->{3324556} = "Vendôme";
$areanames{en}->{3324557} = "Nogent\-le\-Rotrou";
$areanames{en}->{3324558} = "Saint\-Amand\-Montrond";
$areanames{en}->{3324559} = "Chinon";
$areanames{en}->{3324560} = "Aubigny\-sur\-Nère";
$areanames{en}->{3324561} = "Loches";
$areanames{en}->{3324562} = "Gien";
$areanames{en}->{3324563} = "Romorantin\-Lanthenay";
$areanames{en}->{3324564} = "Amboise";
$areanames{en}->{3324565} = "Bourges";
$areanames{en}->{3324566} = "Pithiviers";
$areanames{en}->{3324567} = "Aubigny\-sur\-Nère";
$areanames{en}->{3324568} = "Montargis";
$areanames{en}->{3324569} = "Orléans";
$areanames{en}->{3324570} = "Valençay";
$areanames{en}->{3324571} = "Châteaudun";
$areanames{en}->{3324572} = "Le\ Blanc";
$areanames{en}->{3324573} = "Chartres";
$areanames{en}->{3324574} = "Dreux";
$areanames{en}->{3324575} = "Sancerre";
$areanames{en}->{3324576} = "La\ Châtre";
$areanames{en}->{3324577} = "Vierzon";
$areanames{en}->{3324578} = "Aubigny\-sur\-Nère";
$areanames{en}->{3324579} = "Bourges";
$areanames{en}->{3324580} = "La\ Guerche\-sur\-lAubois";
$areanames{en}->{3324581} = "Chartres";
$areanames{en}->{3324582} = "Châteaudun";
$areanames{en}->{3324583} = "Dreux";
$areanames{en}->{3324584} = "Nogent\-le\-Rotrou";
$areanames{en}->{3324585} = "Le\ Blanc";
$areanames{en}->{3324586} = "Châteauroux";
$areanames{en}->{3324587} = "La\ Châtre";
$areanames{en}->{3324588} = "Issoudun";
$areanames{en}->{3324589} = "Valençay";
$areanames{en}->{3324590} = "Amboise";
$areanames{en}->{3324591} = "Chinon";
$areanames{en}->{3324592} = "Loches";
$areanames{en}->{3324593} = "Tours";
$areanames{en}->{3324594} = "Blois";
$areanames{en}->{3324595} = "Romorantin\-Lanthenay";
$areanames{en}->{3324596} = "Saint\-Aignan";
$areanames{en}->{3324597} = "Vendôme";
$areanames{en}->{3324598} = "Gien";
$areanames{en}->{3324599} = "Montargis";
$areanames{en}->{3324600} = "Orléans";
$areanames{en}->{3324601} = "Pithiviers";
$areanames{en}->{3324602} = "Orléans";
$areanames{en}->{3324603} = "Loches";
$areanames{en}->{3324604} = "Dreux";
$areanames{en}->{3324605} = "Saint\-Amand\-Montrond";
$areanames{en}->{3324606} = "Sancerre";
$areanames{en}->{3324607} = "Vierzon";
$areanames{en}->{3324608} = "Bourges";
$areanames{en}->{3324609} = "Orléans";
$areanames{en}->{3324610} = "Tours";
$areanames{en}->{3324611} = "Aubigny\-sur\-Nère";
$areanames{en}->{3324612} = "Saint\-Amand\-Montrond";
$areanames{en}->{3324613} = "Sancerre";
$areanames{en}->{3324614} = "Nogent\-le\-Rotrou";
$areanames{en}->{3324615} = "Le\ Blanc";
$areanames{en}->{3324616} = "Châteauroux";
$areanames{en}->{3324617} = "La\ Châtre";
$areanames{en}->{3324618} = "Issoudun";
$areanames{en}->{3324619} = "Valençay";
$areanames{en}->{3324620} = "Amboise";
$areanames{en}->{3324621} = "Chinon";
$areanames{en}->{3324622} = "Saint\-Aignan";
$areanames{en}->{3324623} = "Tours";
$areanames{en}->{3324624} = "Gien";
$areanames{en}->{3324625} = "Montargis";
$areanames{en}->{3324626} = "Orléans";
$areanames{en}->{3324627} = "Pithiviers";
$areanames{en}->{3324628} = "Aubigny\-sur\-Nère";
$areanames{en}->{3324629} = "Bourges";
$areanames{en}->{3324630} = "La\ Guerche\-sur\-lAubois";
$areanames{en}->{3324631} = "Saint\-Amand\-Montrond";
$areanames{en}->{3324632} = "Sancerre";
$areanames{en}->{3324633} = "Vierzon";
$areanames{en}->{3324634} = "Chartres";
$areanames{en}->{3324635} = "Châteaudun";
$areanames{en}->{3324636} = "Châteaudun";
$areanames{en}->{3324637} = "Nogent\-le\-Rotrou";
$areanames{en}->{3324638} = "Le\ Blanc";
$areanames{en}->{3324639} = "Châteauroux";
$areanames{en}->{3324640} = "La\ Châtre";
$areanames{en}->{3324641} = "Issoudun";
$areanames{en}->{3324642} = "Valençay";
$areanames{en}->{3324643} = "Amboise";
$areanames{en}->{3324644} = "Chinon";
$areanames{en}->{3324645} = "Loches";
$areanames{en}->{3324646} = "Tours";
$areanames{en}->{3324647} = "Orléans";
$areanames{en}->{3324648} = "Tours";
$areanames{en}->{3324649} = "Blois";
$areanames{en}->{3324650} = "Romorantin\-Lanthenay";
$areanames{en}->{3324651} = "Saint\-Aignan";
$areanames{en}->{3324652} = "Vendôme";
$areanames{en}->{3324653} = "Gien";
$areanames{en}->{3324654} = "Montargis";
$areanames{en}->{3324655} = "Orléans";
$areanames{en}->{3324656} = "Chartres";
$areanames{en}->{3324657} = "Pithiviers";
$areanames{en}->{3324658} = "Aubigny\-sur\-Nère";
$areanames{en}->{3324659} = "Bourges";
$areanames{en}->{3324660} = "La\ Guerche\-sur\-lAubois";
$areanames{en}->{3324661} = "Saint\-Amand\-Montrond";
$areanames{en}->{3324662} = "Sancerre";
$areanames{en}->{3324663} = "Vierzon";
$areanames{en}->{3324664} = "Chartres";
$areanames{en}->{3324665} = "Tours";
$areanames{en}->{3324666} = "Montargis";
$areanames{en}->{3324667} = "Tours";
$areanames{en}->{3324668} = "Blois";
$areanames{en}->{3324669} = "Dreux";
$areanames{en}->{3324670} = "Nogent\-le\-Rotrou";
$areanames{en}->{3324671} = "Tours";
$areanames{en}->{3324672} = "Orléans";
$areanames{en}->{3324673} = "Châteaudun";
$areanames{en}->{3324674} = "Amboise";
$areanames{en}->{3324675} = "Le\ Blanc";
$areanames{en}->{3324676} = "Châteaudun";
$areanames{en}->{3324677} = "Chinon";
$areanames{en}->{3324678} = "Loches";
$areanames{en}->{3324679} = "Blois";
$areanames{en}->{3324680} = "Bourges";
$areanames{en}->{3324681} = "Chartres";
$areanames{en}->{3324682} = "Dreux";
$areanames{en}->{3324683} = "Dreux";
$areanames{en}->{3324684} = "Orléans";
$areanames{en}->{3324685} = "Orléans";
$areanames{en}->{3324686} = "Châteauroux";
$areanames{en}->{3324687} = "Blois";
$areanames{en}->{3324688} = "Tours";
$areanames{en}->{3324689} = "Dreux";
$areanames{en}->{3324690} = "Orléans";
$areanames{en}->{3324691} = "Orléans";
$areanames{en}->{3324692} = "Blois";
$areanames{en}->{3324693} = "Tours";
$areanames{en}->{3324694} = "Bourges";
$areanames{en}->{3324695} = "Châteauroux";
$areanames{en}->{3324696} = "Bourges";
$areanames{en}->{3324697} = "Dreux";
$areanames{en}->{3324698} = "Blois";
$areanames{en}->{3324699} = "Tours";
$areanames{en}->{3324705} = "Tours";
$areanames{en}->{332471} = "Nord\ Ouest";
$areanames{en}->{3324719} = "Loches";
$areanames{en}->{3324720} = "Tours";
$areanames{en}->{3324721} = "Tours";
$areanames{en}->{3324723} = "Amboise";
$areanames{en}->{3324725} = "Chambray\-lès\-Tours";
$areanames{en}->{3324727} = "Saint\-Avertin";
$areanames{en}->{3324728} = "Chambray\-lès\-Tours";
$areanames{en}->{3324730} = "Amboise";
$areanames{en}->{3324731} = "Tours";
$areanames{en}->{3324732} = "Saint\-Pierre\-des\-Corps";
$areanames{en}->{3324736} = "Tours";
$areanames{en}->{3324737} = "Tours";
$areanames{en}->{3324738} = "Tours";
$areanames{en}->{3324739} = "Tours";
$areanames{en}->{3324741} = "Tours";
$areanames{en}->{3324742} = "Fondettes";
$areanames{en}->{3324743} = "Truyes";
$areanames{en}->{3324744} = "Saint\-Pierre\-des\-Corps";
$areanames{en}->{3324745} = "Azay\-le\-Rideau";
$areanames{en}->{3324746} = "Tours";
$areanames{en}->{3324747} = "Tours";
$areanames{en}->{3324748} = "Chambray\-lès\-Tours";
$areanames{en}->{3324749} = "Fondettes";
$areanames{en}->{3324750} = "Montlouis\-sur\-Loire";
$areanames{en}->{3324751} = "Tours";
$areanames{en}->{3324752} = "Vouvray";
$areanames{en}->{3324753} = "Joué\-lès\-Tours";
$areanames{en}->{3324754} = "Tours";
$areanames{en}->{3324755} = "Luynes";
$areanames{en}->{3324757} = "Amboise";
$areanames{en}->{3324759} = "Loches";
$areanames{en}->{3324760} = "Tours";
$areanames{en}->{3324761} = "Tours";
$areanames{en}->{3324763} = "Saint\-Pierre\-des\-Corps";
$areanames{en}->{3324764} = "Tours";
$areanames{en}->{3324765} = "Sainte\-Maure\-de\-Touraine";
$areanames{en}->{3324766} = "Tours";
$areanames{en}->{3324767} = "Joué\-lès\-Tours";
$areanames{en}->{3324768} = "Joué\-lès\-Tours";
$areanames{en}->{3324770} = "Tours";
$areanames{en}->{3324771} = "Chambray\-lès\-Tours";
$areanames{en}->{3324773} = "Joué\-lès\-Tours";
$areanames{en}->{3324774} = "Saint\-Avertin";
$areanames{en}->{3324775} = "Tours";
$areanames{en}->{3324776} = "Tours";
$areanames{en}->{3324780} = "Joué\-lès\-Tours";
$areanames{en}->{3324785} = "Tours";
$areanames{en}->{3324786} = "Tours";
$areanames{en}->{3324788} = "Tours";
$areanames{en}->{3324791} = "Loches";
$areanames{en}->{3324793} = "Chinon";
$areanames{en}->{3324796} = "Langeais";
$areanames{en}->{3324797} = "Bourgueil";
$areanames{en}->{3324798} = "Chinon";
$areanames{en}->{3324802} = "Bourges";
$areanames{en}->{332481} = "Nord\ Ouest";
$areanames{en}->{3324816} = "Bourges";
$areanames{en}->{332482} = "Bourges";
$areanames{en}->{3324828} = "Nord\ Ouest";
$areanames{en}->{3324829} = "Nord\ Ouest";
$areanames{en}->{3324830} = "Saint\-Germain\-du\-Puy";
$areanames{en}->{332484} = "Nord\ Ouest";
$areanames{en}->{3324848} = "Bourges";
$areanames{en}->{3324850} = "Bourges";
$areanames{en}->{3324852} = "Vierzon";
$areanames{en}->{3324854} = "Sancerre";
$areanames{en}->{3324855} = "Saint\-Florent\-sur\-Cher";
$areanames{en}->{3324857} = "Mehun\-sur\-Yèvre";
$areanames{en}->{3324858} = "Aubigny\-sur\-Nère";
$areanames{en}->{3324859} = "Dun\-sur\-Auron";
$areanames{en}->{3324861} = "Châteaumeillant";
$areanames{en}->{3324865} = "Bourges";
$areanames{en}->{3324866} = "Bourges";
$areanames{en}->{3324867} = "Bourges";
$areanames{en}->{3324868} = "Bourges";
$areanames{en}->{3324869} = "Bourges";
$areanames{en}->{3324870} = "Bourges";
$areanames{en}->{3324871} = "Vierzon";
$areanames{en}->{3324873} = "Argent\-sur\-Sauldre";
$areanames{en}->{3324874} = "Sancoins";
$areanames{en}->{3324875} = "Vierzon";
$areanames{en}->{3324878} = "Sancerre";
$areanames{en}->{3324880} = "Cuffy";
$areanames{en}->{3324881} = "Aubigny\-sur\-Nère";
$areanames{en}->{3324896} = "Saint\-Amand\-Montrond";
$areanames{en}->{3324900} = "La\ Ferte\-Bernard";
$areanames{en}->{3324901} = "La\ Flèche";
$areanames{en}->{3324902} = "La\ Roche\-sur\-Yon";
$areanames{en}->{3324903} = "Laval";
$areanames{en}->{3324904} = "Le\ Mans";
$areanames{en}->{3324905} = "Les\ Herbiers";
$areanames{en}->{3324906} = "Les\ Sables\ d\'Olonne";
$areanames{en}->{3324907} = "Luçon";
$areanames{en}->{3324908} = "Mayenne";
$areanames{en}->{3324909} = "Nantes";
$areanames{en}->{3324910} = "Nantes";
$areanames{en}->{3324911} = "Pornic";
$areanames{en}->{3324912} = "Sablé\-sur\-Sarthe";
$areanames{en}->{3324913} = "Saint\-Calais";
$areanames{en}->{3324914} = "Saint\-Nazaire";
$areanames{en}->{3324915} = "Saumur";
$areanames{en}->{3324916} = "Segre";
$areanames{en}->{3324917} = "Nantes";
$areanames{en}->{3324918} = "Angers";
$areanames{en}->{3324919} = "Saumur";
$areanames{en}->{3324920} = "Mayenne";
$areanames{en}->{3324921} = "La\ Flèche";
$areanames{en}->{3324922} = "Les\ Herbiers";
$areanames{en}->{3324923} = "Le\ Mans";
$areanames{en}->{3324924} = "Ancenis";
$areanames{en}->{3324925} = "Blain";
$areanames{en}->{3324926} = "Châteaubriant";
$areanames{en}->{3324927} = "Pornic";
$areanames{en}->{3324928} = "Saint\-Nazaire";
$areanames{en}->{3324929} = "Angers";
$areanames{en}->{3324930} = "Baugé\-en\-Anjou";
$areanames{en}->{3324931} = "Cholet";
$areanames{en}->{3324932} = "Saumur";
$areanames{en}->{3324933} = "Segre";
$areanames{en}->{3324934} = "Château\-Gontier";
$areanames{en}->{3324935} = "Laval";
$areanames{en}->{3324936} = "Mayenne";
$areanames{en}->{3324937} = "Beaumont\-sur\-Sarthe";
$areanames{en}->{3324938} = "Château\-du\-Loir";
$areanames{en}->{3324939} = "La\ Ferte\-Bernard";
$areanames{en}->{3324944} = "Nantes";
$areanames{en}->{3324950} = "La\ Roche\-sur\-Yon";
$areanames{en}->{3324951} = "Les\ Sables\ d\'Olonne";
$areanames{en}->{3324952} = "Saint\-Nazaire";
$areanames{en}->{3324953} = "Nantes";
$areanames{en}->{3324954} = "Le\ Mans";
$areanames{en}->{3324955} = "Sablé\-sur\-Sarthe";
$areanames{en}->{3324956} = "Saint\-Calais";
$areanames{en}->{3324957} = "Fontenay\-le\-Comte";
$areanames{en}->{3324958} = "Luçon";
$areanames{en}->{3324959} = "Les\ Sables\ d\'Olonne";
$areanames{en}->{3324960} = "Ancenis";
$areanames{en}->{3324961} = "Nantes";
$areanames{en}->{3324962} = "Nantes";
$areanames{en}->{3324963} = "Saint\-Nazaire";
$areanames{en}->{3324964} = "Baugé\-en\-Anjou";
$areanames{en}->{3324965} = "Saumur";
$areanames{en}->{3324966} = "Mayenne";
$areanames{en}->{3324967} = "Beaumont\-sur\-Sarthe";
$areanames{en}->{3324968} = "La\ Ferte\-Bernard";
$areanames{en}->{3324969} = "La\ Flèche";
$areanames{en}->{3324970} = "Saint\-Nazaire";
$areanames{en}->{3324971} = "Angers";
$areanames{en}->{3324972} = "Cholet";
$areanames{en}->{3324973} = "Saumur";
$areanames{en}->{3324974} = "Laval";
$areanames{en}->{3324975} = "Angers";
$areanames{en}->{3324976} = "Cholet";
$areanames{en}->{3324977} = "Saint\-Nazaire";
$areanames{en}->{3324978} = "Le\ Mans";
$areanames{en}->{3324979} = "Nantes";
$areanames{en}->{3324980} = "Château\-Gontier";
$areanames{en}->{3324981} = "Saumur";
$areanames{en}->{3324982} = "Le\ Mans";
$areanames{en}->{3324983} = "Laval";
$areanames{en}->{3324984} = "Nantes";
$areanames{en}->{3324985} = "La\ Roche\-sur\-Yon";
$areanames{en}->{3324986} = "Blain";
$areanames{en}->{3324987} = "Angers";
$areanames{en}->{3324988} = "Nantes";
$areanames{en}->{3324989} = "Angers";
$areanames{en}->{3324990} = "Baugé\-en\-Anjou";
$areanames{en}->{3324991} = "Châteaubriant";
$areanames{en}->{3324992} = "Saint\-Nazaire";
$areanames{en}->{3324993} = "Segre";
$areanames{en}->{3324994} = "La\ Roche\-sur\-Yon";
$areanames{en}->{3324995} = "Saint\-Calais";
$areanames{en}->{3324996} = "Laval";
$areanames{en}->{3324997} = "La\ Flèche";
$areanames{en}->{3324998} = "Les\ Sables\ d\'Olonne";
$areanames{en}->{3324999} = "Mayenne";
$areanames{en}->{3325000} = "L\'Aigle";
$areanames{en}->{3325001} = "Caen";
$areanames{en}->{3325002} = "Alençon";
$areanames{en}->{3325003} = "Argentan";
$areanames{en}->{3325004} = "Flers";
$areanames{en}->{3325005} = "Mortagne\-au\-Perche";
$areanames{en}->{3325006} = "Avranches";
$areanames{en}->{3325007} = "L\'Aigle";
$areanames{en}->{3325008} = "Caen";
$areanames{en}->{3325009} = "Bayeux";
$areanames{en}->{3325010} = "Caen";
$areanames{en}->{3325011} = "Deauville";
$areanames{en}->{3325012} = "Falaise";
$areanames{en}->{3325013} = "Lisieux";
$areanames{en}->{3325014} = "Vire";
$areanames{en}->{3325015} = "Caen";
$areanames{en}->{3325016} = "Carentan\-les\-Marais";
$areanames{en}->{3325017} = "Coutances";
$areanames{en}->{3325018} = "Saint\-Lô";
$areanames{en}->{3325019} = "Alençon";
$areanames{en}->{3325020} = "Argentan";
$areanames{en}->{3325021} = "Flers";
$areanames{en}->{3325022} = "Caen";
$areanames{en}->{3325023} = "Mortagne\-au\-Perche";
$areanames{en}->{3325024} = "Alençon";
$areanames{en}->{3325025} = "Argentan";
$areanames{en}->{3325026} = "Avranches";
$areanames{en}->{3325027} = "Bayeux";
$areanames{en}->{3325028} = "Caen";
$areanames{en}->{3325029} = "Carentan\-les\-Marais";
$areanames{en}->{3325030} = "Caen";
$areanames{en}->{3325031} = "Deauville";
$areanames{en}->{3325032} = "Caen";
$areanames{en}->{3325033} = "Bayeux";
$areanames{en}->{3325034} = "Falaise";
$areanames{en}->{3325035} = "Bayeux";
$areanames{en}->{3325036} = "Lisieux";
$areanames{en}->{3325037} = "Vire";
$areanames{en}->{3325038} = "L\'Aigle";
$areanames{en}->{3325039} = "Alençon";
$areanames{en}->{3325040} = "Argentan";
$areanames{en}->{3325041} = "Flers";
$areanames{en}->{3325042} = "Mortagne\-au\-Perche";
$areanames{en}->{3325043} = "Deauville";
$areanames{en}->{3325044} = "Falaise";
$areanames{en}->{3325045} = "Flers";
$areanames{en}->{3325046} = "Lisieux";
$areanames{en}->{3325047} = "Mortagne\-au\-Perche";
$areanames{en}->{3325048} = "Saint\-Lô";
$areanames{en}->{3325049} = "Vire";
$areanames{en}->{3325050} = "Caen";
$areanames{en}->{3325051} = "Alençon";
$areanames{en}->{3325052} = "Coutances";
$areanames{en}->{3325053} = "Caen";
$areanames{en}->{3325054} = "Caen";
$areanames{en}->{3325055} = "Bayeux";
$areanames{en}->{3325056} = "Caen";
$areanames{en}->{3325057} = "Caen";
$areanames{en}->{3325058} = "Falaise";
$areanames{en}->{3325059} = "Bayeux";
$areanames{en}->{3325065} = "Caen";
$areanames{en}->{3325070} = "Carentan\-les\-Marais";
$areanames{en}->{3325071} = "Saint\-Lô";
$areanames{en}->{3325072} = "Alençon";
$areanames{en}->{3325073} = "Vire";
$areanames{en}->{3325074} = "Argentan";
$areanames{en}->{3325075} = "Flers";
$areanames{en}->{3325076} = "L\'Aigle";
$areanames{en}->{3325077} = "Mortagne\-au\-Perche";
$areanames{en}->{3325078} = "Caen";
$areanames{en}->{3325079} = "Carentan\-les\-Marais";
$areanames{en}->{3325080} = "Saint\-Lô";
$areanames{en}->{3325081} = "Avranches";
$areanames{en}->{3325082} = "L\'Aigle";
$areanames{en}->{3325083} = "Avranches";
$areanames{en}->{3325084} = "Bayeux";
$areanames{en}->{3325085} = "Caen";
$areanames{en}->{3325086} = "Carentan\-les\-Marais";
$areanames{en}->{3325087} = "Coutances";
$areanames{en}->{3325088} = "Bayeux";
$areanames{en}->{3325089} = "Deauville";
$areanames{en}->{3325090} = "Alençon";
$areanames{en}->{3325091} = "Caen";
$areanames{en}->{3325092} = "Deauville";
$areanames{en}->{3325093} = "Falaise";
$areanames{en}->{3325094} = "Lisieux";
$areanames{en}->{3325095} = "Vire";
$areanames{en}->{3325096} = "Avranches";
$areanames{en}->{3325097} = "Carentan\-les\-Marais";
$areanames{en}->{3325098} = "Coutances";
$areanames{en}->{3325099} = "Saint\-Lô";
$areanames{en}->{3325105} = "La\ Roche\ sur\ Yon";
$areanames{en}->{3325108} = "La\ Roche\ sur\ Yon";
$areanames{en}->{3325110} = "Saint\-Nazaire";
$areanames{en}->{3325111} = "Rezé";
$areanames{en}->{3325112} = "La\ Chapelle\ sur\ Erdre";
$areanames{en}->{3325113} = "Nantes";
$areanames{en}->{3325116} = "Saint\-Nazaire";
$areanames{en}->{3325121} = "Les\ Sables\ d\'Olonne";
$areanames{en}->{3325123} = "Les\ Sables\ d\'Olonne";
$areanames{en}->{3325124} = "La\ Roche\ sur\ Yon";
$areanames{en}->{3325126} = "Saint\-Gilles\-Croix\-de\-Vie";
$areanames{en}->{3325129} = "Luçon";
$areanames{en}->{3325130} = "La\ Tranche\ sur\ Mer";
$areanames{en}->{3325132} = "Les\ Sables\ d\'Olonne";
$areanames{en}->{3325133} = "Jard\-sur\-Mer";
$areanames{en}->{3325135} = "Challans";
$areanames{en}->{3325136} = "La\ Roche\ sur\ Yon";
$areanames{en}->{3325137} = "La\ Roche\ sur\ Yon";
$areanames{en}->{3325138} = "Mouilleron\-le\-Captif";
$areanames{en}->{3325139} = "Noirmoutier\-en\-l\'Île";
$areanames{en}->{3325144} = "La\ Roche\ sur\ Yon";
$areanames{en}->{3325147} = "La\ Roche\ sur\ Yon";
$areanames{en}->{3325149} = "Challans";
$areanames{en}->{3325150} = "Fontenay\-le\-Comte";
$areanames{en}->{3325153} = "Saint\-Martin\-de\-Fraigneau";
$areanames{en}->{3325154} = "Saint\-Hilaire\-de\-Riez";
$areanames{en}->{3325155} = "Saint\-Gilles\-Croix\-de\-Vie";
$areanames{en}->{3325156} = "Luçon";
$areanames{en}->{3325157} = "Pouzauges";
$areanames{en}->{3325158} = "Saint\-Jean\-de\-Monts";
$areanames{en}->{3325159} = "Saint\-Jean\-de\-Monts";
$areanames{en}->{3325160} = "Saint\-Gilles\-Croix\-de\-Vie";
$areanames{en}->{3325162} = "La\ Roche\ sur\ Yon";
$areanames{en}->{3325163} = "Mortagne\-sur\-Sèvre";
$areanames{en}->{3325164} = "Les\ Herbiers";
$areanames{en}->{3325165} = "Mortagne\-sur\-Sèvre";
$areanames{en}->{3325166} = "Les\ Herbiers";
$areanames{en}->{3325167} = "Les\ Herbiers";
$areanames{en}->{3325168} = "Challans";
$areanames{en}->{3325169} = "Fontenay\-le\-Comte";
$areanames{en}->{3325170} = "Rezé";
$areanames{en}->{3325172} = "Nantes";
$areanames{en}->{3325173} = "Guérande";
$areanames{en}->{3325174} = "Pornic";
$areanames{en}->{3325175} = "La\ Baule\ Escoublac";
$areanames{en}->{3325176} = "Saint\-Nazaire";
$areanames{en}->{3325177} = "Nantes";
$areanames{en}->{3325178} = "Orvault";
$areanames{en}->{3325179} = "Vertou";
$areanames{en}->{3325180} = "Nantes";
$areanames{en}->{3325181} = "Nantes";
$areanames{en}->{3325182} = "Nantes";
$areanames{en}->{3325183} = "Nantes";
$areanames{en}->{3325184} = "Nantes";
$areanames{en}->{3325185} = "Sainte\-Luce\-sur\-Loire";
$areanames{en}->{3325186} = "Nantes";
$areanames{en}->{3325189} = "Nantes";
$areanames{en}->{3325190} = "Bretignolles\-sur\-Mer";
$areanames{en}->{3325193} = "Challans";
$areanames{en}->{3325194} = "Chantonnay";
$areanames{en}->{3325195} = "Les\ Sables\ d\'Olonne";
$areanames{en}->{3325200} = "Saint\-Calais";
$areanames{en}->{3325201} = "Challans";
$areanames{en}->{3325202} = "Fontenay\-le\-Comte";
$areanames{en}->{3325203} = "Les\ Herbiers";
$areanames{en}->{3325204} = "Luçon";
$areanames{en}->{3325205} = "La\ Roche\-sur\-Yon";
$areanames{en}->{3325206} = "Les\ Sables\ d\'Olonne";
$areanames{en}->{3325207} = "Nantes";
$areanames{en}->{3325208} = "La\ Roche\-sur\-Yon";
$areanames{en}->{3325209} = "Angers";
$areanames{en}->{3325210} = "Nantes";
$areanames{en}->{3325211} = "Saint\-Calais";
$areanames{en}->{3325212} = "Challans";
$areanames{en}->{3325213} = "Fontenay\-le\-Comte";
$areanames{en}->{3325214} = "Les\ Herbiers";
$areanames{en}->{3325215} = "Luçon";
$areanames{en}->{3325216} = "La\ Roche\-sur\-Yon";
$areanames{en}->{3325217} = "Les\ Sables\ d\'Olonne";
$areanames{en}->{3325218} = "Le\ Mans";
$areanames{en}->{3325219} = "Le\ Mans";
$areanames{en}->{3325220} = "Nantes";
$areanames{en}->{3325221} = "Angers";
$areanames{en}->{3325222} = "Le\ Mans";
$areanames{en}->{3325223} = "Ancenis";
$areanames{en}->{3325224} = "Blain";
$areanames{en}->{3325225} = "Pornic";
$areanames{en}->{3325226} = "Saumur";
$areanames{en}->{3325227} = "Segre";
$areanames{en}->{3325228} = "Fontenay\-le\-Comte";
$areanames{en}->{3325229} = "Luçon";
$areanames{en}->{3325230} = "Les\ Sables\ d\'Olonne";
$areanames{en}->{3325231} = "Châteaubriant";
$areanames{en}->{3325232} = "Nantes";
$areanames{en}->{3325233} = "Nantes";
$areanames{en}->{3325234} = "Laval";
$areanames{en}->{3325235} = "Angers";
$areanames{en}->{3325236} = "Le\ Mans";
$areanames{en}->{3325237} = "Saumur";
$areanames{en}->{3325238} = "Le\ Mans";
$areanames{en}->{3325239} = "Cholet";
$areanames{en}->{3325240} = "La\ Roche\-sur\-Yon";
$areanames{en}->{3325241} = "Saint\-Nazaire";
$areanames{en}->{3325242} = "Cholet";
$areanames{en}->{3325243} = "La\ Roche\-sur\-Yon";
$areanames{en}->{3325244} = "Nantes";
$areanames{en}->{3325245} = "Cholet";
$areanames{en}->{3325246} = "Laval";
$areanames{en}->{3325247} = "Saumur";
$areanames{en}->{3325248} = "Saint\-Nazaire";
$areanames{en}->{3325249} = "La\ Flèche";
$areanames{en}->{3325250} = "Château\-du\-Loir";
$areanames{en}->{3325251} = "Sablé\-sur\-Sarthe";
$areanames{en}->{3325252} = "Nantes";
$areanames{en}->{3325253} = "La\ Ferte\-Bernard";
$areanames{en}->{3325254} = "Saint\-Calais";
$areanames{en}->{3325255} = "Baugé\-en\-Anjou";
$areanames{en}->{3325256} = "Nantes";
$areanames{en}->{3325257} = "Angers";
$areanames{en}->{3325258} = "Nantes";
$areanames{en}->{3325259} = "Nantes";
$areanames{en}->{3325260} = "Angers";
$areanames{en}->{3325261} = "Fontenay\-le\-Comte";
$areanames{en}->{3325262} = "Nantes";
$areanames{en}->{3325263} = "Challans";
$areanames{en}->{3325264} = "Mayenne";
$areanames{en}->{3325265} = "Les\ Herbiers";
$areanames{en}->{3325266} = "Fontenay\-le\-Comte";
$areanames{en}->{3325267} = "Les\ Sables\ d\'Olonne";
$areanames{en}->{3325268} = "Nantes";
$areanames{en}->{3325269} = "Segre";
$areanames{en}->{3325270} = "Nantes";
$areanames{en}->{3325271} = "Saint\-Nazaire";
$areanames{en}->{3325272} = "Le\ Mans";
$areanames{en}->{3325273} = "Pornic";
$areanames{en}->{3325274} = "Luçon";
$areanames{en}->{3325275} = "Angers";
$areanames{en}->{3325276} = "Ancenis";
$areanames{en}->{3325277} = "Ancenis";
$areanames{en}->{3325278} = "Blain";
$areanames{en}->{3325279} = "Châteaubriant";
$areanames{en}->{3325280} = "Pornic";
$areanames{en}->{3325281} = "Segre";
$areanames{en}->{3325282} = "Château\-Gontier";
$areanames{en}->{3325283} = "Beaumont\-sur\-Sarthe";
$areanames{en}->{3325284} = "Le\ Mans";
$areanames{en}->{3325285} = "Nantes";
$areanames{en}->{3325286} = "Laval";
$areanames{en}->{3325287} = "Nantes";
$areanames{en}->{3325288} = "Angers";
$areanames{en}->{3325289} = "Beaumont\-sur\-Sarthe";
$areanames{en}->{3325290} = "Sablé\-sur\-Sarthe";
$areanames{en}->{3325291} = "Mayenne";
$areanames{en}->{3325292} = "Le\ Mans";
$areanames{en}->{3325293} = "Laval";
$areanames{en}->{3325294} = "La\ Ferte\-Bernard";
$areanames{en}->{3325295} = "La\ Flèche";
$areanames{en}->{3325296} = "Château\-Gontier";
$areanames{en}->{3325297} = "Château\-du\-Loir";
$areanames{en}->{3325298} = "Laval";
$areanames{en}->{3325299} = "Le\ Mans";
$areanames{en}->{3325300} = "Nantes";
$areanames{en}->{3325301} = "Angers";
$areanames{en}->{3325302} = "Cholet";
$areanames{en}->{3325303} = "Fontenay\-le\-Comte";
$areanames{en}->{3325304} = "Le\ Mans";
$areanames{en}->{3325305} = "Les\ Herbiers";
$areanames{en}->{3325306} = "Luçon";
$areanames{en}->{3325307} = "La\ Roche\-sur\-Yon";
$areanames{en}->{3325308} = "Les\ Sables\ d\'Olonne";
$areanames{en}->{3325309} = "Mayenne";
$areanames{en}->{3325310} = "Beaumont\-sur\-Sarthe";
$areanames{en}->{3325311} = "Château\-du\-Loir";
$areanames{en}->{3325312} = "La\ Ferte\-Bernard";
$areanames{en}->{3325313} = "La\ Flèche";
$areanames{en}->{3325314} = "Baugé\-en\-Anjou";
$areanames{en}->{3325315} = "Le\ Mans";
$areanames{en}->{3325316} = "Sablé\-sur\-Sarthe";
$areanames{en}->{3325317} = "Saint\-Calais";
$areanames{en}->{3325318} = "Challans";
$areanames{en}->{3325319} = "Saint\-Nazaire";
$areanames{en}->{3325320} = "Angers";
$areanames{en}->{3325330} = "Saint\-Nazaire";
$areanames{en}->{3325331} = "Luçon";
$areanames{en}->{3325332} = "Les\ Sables\ d\'Olonne";
$areanames{en}->{3325333} = "La\ Roche\-sur\-Yon";
$areanames{en}->{3325334} = "Fontenay\-le\-Comte";
$areanames{en}->{3325335} = "Nantes";
$areanames{en}->{3325336} = "Challans";
$areanames{en}->{3325337} = "Les\ Herbiers";
$areanames{en}->{3325338} = "Saint\-Calais";
$areanames{en}->{3325339} = "Nantes";
$areanames{en}->{3325345} = "Nantes";
$areanames{en}->{3325355} = "Nantes";
$areanames{en}->{3325360} = "Challans";
$areanames{en}->{3325361} = "Angers";
$areanames{en}->{3325362} = "Baugé\-en\-Anjou";
$areanames{en}->{3325363} = "Beaumont\-sur\-Sarthe";
$areanames{en}->{3325364} = "Blain";
$areanames{en}->{3325365} = "Challans";
$areanames{en}->{3325366} = "Châteaubriant";
$areanames{en}->{3325367} = "Château\-du\-Loir";
$areanames{en}->{3325368} = "Château\-Gontier";
$areanames{en}->{3325369} = "Cholet";
$areanames{en}->{3325378} = "Nantes";
$areanames{en}->{3325380} = "La\ Roche\-sur\-Yon";
$areanames{en}->{3325381} = "Les\ Sables\ d\'Olonne";
$areanames{en}->{3325382} = "Les\ Sables\ d\'Olonne";
$areanames{en}->{3325383} = "Saint\-Calais";
$areanames{en}->{3325384} = "Saint\-Nazaire";
$areanames{en}->{3325385} = "Saumur";
$areanames{en}->{3325386} = "Segre";
$areanames{en}->{3325387} = "Ancenis";
$areanames{en}->{3325388} = "La\ Roche\-sur\-Yon";
$areanames{en}->{3325389} = "La\ Roche\-sur\-Yon";
$areanames{en}->{3325397} = "Nantes";
$areanames{en}->{3325400} = "Valençay";
$areanames{en}->{3325401} = "Argenton\-sur\-Creuse";
$areanames{en}->{3325402} = "Buzançais";
$areanames{en}->{3325403} = "Issoudun";
$areanames{en}->{3325406} = "Aigurande";
$areanames{en}->{3325407} = "Châteauroux";
$areanames{en}->{3325408} = "Châteauroux";
$areanames{en}->{332541} = "Nord\ Ouest";
$areanames{en}->{3325421} = "Issoudun";
$areanames{en}->{3325422} = "Châteauroux";
$areanames{en}->{3325424} = "Argenton\-sur\-Creuse";
$areanames{en}->{3325426} = "Villedieu\-sur\-Indre";
$areanames{en}->{3325427} = "Châteauroux";
$areanames{en}->{3325428} = "Le\ Blanc";
$areanames{en}->{3325429} = "Niherne";
$areanames{en}->{3325431} = "Cluis";
$areanames{en}->{3325432} = "Montrichard";
$areanames{en}->{3325434} = "Châteauroux";
$areanames{en}->{3325435} = "Levroux";
$areanames{en}->{3325436} = "Ardentes";
$areanames{en}->{3325437} = "Le\ Blanc";
$areanames{en}->{3325438} = "Châtillon\-sur\-Indre";
$areanames{en}->{3325441} = "Lye";
$areanames{en}->{3325442} = "Blois";
$areanames{en}->{3325443} = "Blois";
$areanames{en}->{3325445} = "Blois";
$areanames{en}->{3325448} = "La\ Châtre";
$areanames{en}->{3325450} = "Vineuil";
$areanames{en}->{3325451} = "Blois";
$areanames{en}->{3325453} = "Châteauroux";
$areanames{en}->{3325455} = "Blois";
$areanames{en}->{3325456} = "Blois";
$areanames{en}->{3325458} = "Blois";
$areanames{en}->{3325460} = "Châteauroux";
$areanames{en}->{3325461} = "Châteauroux";
$areanames{en}->{3325467} = "Vendôme";
$areanames{en}->{3325470} = "Mont\-prés\-Chambord";
$areanames{en}->{3325473} = "Vendôme";
$areanames{en}->{3325474} = "Blois";
$areanames{en}->{3325475} = "Saint\-Aignan";
$areanames{en}->{3325476} = "Romorantin\-Lanthenay";
$areanames{en}->{3325477} = "Vendôme";
$areanames{en}->{3325478} = "Blois";
$areanames{en}->{3325479} = "Contres";
$areanames{en}->{3325481} = "Mer";
$areanames{en}->{3325484} = "Buzançais";
$areanames{en}->{3325485} = "Montoire\-sur\-le\-Loir";
$areanames{en}->{3325487} = "Saint\-Laurent\-Nouan";
$areanames{en}->{3325488} = "Lamotte\-Beuvron";
$areanames{en}->{3325489} = "Vendôme";
$areanames{en}->{3325490} = "Blois";
$areanames{en}->{3325495} = "Romorantin\-Lanthenay";
$areanames{en}->{3325497} = "Salbris";
$areanames{en}->{332550} = "Nantes";
$areanames{en}->{3325500} = "Château\-Gontier";
$areanames{en}->{3325508} = "Ancenis";
$areanames{en}->{3325510} = "Nantes";
$areanames{en}->{3325511} = "Nantes";
$areanames{en}->{3325512} = "Nantes";
$areanames{en}->{3325513} = "Ancenis";
$areanames{en}->{3325514} = "Blain";
$areanames{en}->{3325515} = "Châteaubriant";
$areanames{en}->{3325516} = "Nantes";
$areanames{en}->{3325517} = "Pornic";
$areanames{en}->{3325518} = "Saint\-Nazaire";
$areanames{en}->{3325519} = "Angers";
$areanames{en}->{3325520} = "Baugé\-en\-Anjou";
$areanames{en}->{3325521} = "Cholet";
$areanames{en}->{3325522} = "Saumur";
$areanames{en}->{3325523} = "Segre";
$areanames{en}->{3325524} = "Château\-Gontier";
$areanames{en}->{3325525} = "Laval";
$areanames{en}->{3325526} = "Mayenne";
$areanames{en}->{3325527} = "Beaumont\-sur\-Sarthe";
$areanames{en}->{3325528} = "Château\-du\-Loir";
$areanames{en}->{3325529} = "La\ Ferte\-Bernard";
$areanames{en}->{3325530} = "La\ Flèche";
$areanames{en}->{3325531} = "Le\ Mans";
$areanames{en}->{3325532} = "Sablé\-sur\-Sarthe";
$areanames{en}->{3325533} = "Saint\-Calais";
$areanames{en}->{3325534} = "Challans";
$areanames{en}->{3325535} = "Fontenay\-le\-Comte";
$areanames{en}->{3325536} = "La\ Roche\-sur\-Yon";
$areanames{en}->{3325537} = "Les\ Herbiers";
$areanames{en}->{3325538} = "Les\ Sables\ d\'Olonne";
$areanames{en}->{3325539} = "Luçon";
$areanames{en}->{3325540} = "Saint\-Nazaire";
$areanames{en}->{3325541} = "Angers";
$areanames{en}->{3325542} = "Nantes";
$areanames{en}->{3325543} = "Mayenne";
$areanames{en}->{3325544} = "Nantes";
$areanames{en}->{3325545} = "Nantes";
$areanames{en}->{3325546} = "Le\ Mans";
$areanames{en}->{3325547} = "Nantes";
$areanames{en}->{3325548} = "Le\ Mans";
$areanames{en}->{3325549} = "Les\ Sables\ d\'Olonne";
$areanames{en}->{332555} = "Nantes";
$areanames{en}->{3325552} = "Pornic";
$areanames{en}->{3325553} = "Cholet";
$areanames{en}->{3325555} = "Châteaubriant";
$areanames{en}->{3325557} = "Ancenis";
$areanames{en}->{3325560} = "Nantes";
$areanames{en}->{3325561} = "Nantes";
$areanames{en}->{3325562} = "Angers";
$areanames{en}->{3325563} = "Cholet";
$areanames{en}->{3325564} = "Saint\-Nazaire";
$areanames{en}->{3325565} = "Challans";
$areanames{en}->{3325566} = "Nantes";
$areanames{en}->{3325567} = "Blain";
$areanames{en}->{3325568} = "Châteaubriant";
$areanames{en}->{3325569} = "Pornic";
$areanames{en}->{3325570} = "Saint\-Nazaire";
$areanames{en}->{3325571} = "Baugé\-en\-Anjou";
$areanames{en}->{3325572} = "Saumur";
$areanames{en}->{3325573} = "Segre";
$areanames{en}->{3325574} = "Château\-Gontier";
$areanames{en}->{3325575} = "Laval";
$areanames{en}->{3325576} = "Mayenne";
$areanames{en}->{3325577} = "Beaumont\-sur\-Sarthe";
$areanames{en}->{3325578} = "Château\-du\-Loir";
$areanames{en}->{3325579} = "La\ Ferte\-Bernard";
$areanames{en}->{3325580} = "La\ Flèche";
$areanames{en}->{3325581} = "Sablé\-sur\-Sarthe";
$areanames{en}->{3325582} = "Saint\-Calais";
$areanames{en}->{3325583} = "Challans";
$areanames{en}->{3325584} = "Fontenay\-le\-Comte";
$areanames{en}->{3325585} = "Les\ Herbiers";
$areanames{en}->{3325586} = "Luçon";
$areanames{en}->{3325587} = "Les\ Sables\ d\'Olonne";
$areanames{en}->{3325588} = "Saumur";
$areanames{en}->{3325589} = "Les\ Sables\ d\'Olonne";
$areanames{en}->{3325590} = "La\ Roche\-sur\-Yon";
$areanames{en}->{3325591} = "Châteaubriant";
$areanames{en}->{3325592} = "Cholet";
$areanames{en}->{3325593} = "Sablé\-sur\-Sarthe";
$areanames{en}->{3325594} = "La\ Roche\-sur\-Yon";
$areanames{en}->{3325595} = "Nantes";
$areanames{en}->{3325596} = "Nantes";
$areanames{en}->{3325597} = "Angers";
$areanames{en}->{3325598} = "Angers";
$areanames{en}->{3325599} = "Nantes";
$areanames{en}->{3325600} = "Rennes";
$areanames{en}->{3325601} = "Rennes";
$areanames{en}->{3325602} = "Brest";
$areanames{en}->{3325603} = "Rennes";
$areanames{en}->{3325604} = "Carhaix\-Plouguer";
$areanames{en}->{3325605} = "Quimperlé";
$areanames{en}->{3325606} = "Carhaix\-Plouguer";
$areanames{en}->{3325607} = "Loudéac";
$areanames{en}->{3325608} = "Paimpol";
$areanames{en}->{3325609} = "Rostrenen";
$areanames{en}->{3325610} = "Carhaix\-Plouguer";
$areanames{en}->{3325611} = "Dinan";
$areanames{en}->{3325612} = "Le\ Faouet";
$areanames{en}->{3325613} = "Fougères";
$areanames{en}->{3325614} = "Guingamp";
$areanames{en}->{3325615} = "Janzé";
$areanames{en}->{3325616} = "Lamballe";
$areanames{en}->{3325617} = "Loudéac";
$areanames{en}->{3325618} = "Montfort\-sur\-Meu";
$areanames{en}->{3325619} = "Morlaix";
$areanames{en}->{3325629} = "Brest";
$areanames{en}->{3325630} = "Auray";
$areanames{en}->{3325631} = "Brest";
$areanames{en}->{3325632} = "Rennes";
$areanames{en}->{3325633} = "Le\ Faouet";
$areanames{en}->{3325634} = "Pontivy";
$areanames{en}->{3325635} = "Rennes";
$areanames{en}->{3325636} = "Morlaix";
$areanames{en}->{3325637} = "Auray";
$areanames{en}->{3325638} = "Dinan";
$areanames{en}->{3325639} = "Guingamp";
$areanames{en}->{3325640} = "Lamballe";
$areanames{en}->{3325641} = "Loudéac";
$areanames{en}->{3325642} = "Paimpol";
$areanames{en}->{3325643} = "Rostrenen";
$areanames{en}->{3325644} = "Saint\-Brieuc";
$areanames{en}->{3325645} = "Morlaix";
$areanames{en}->{3325646} = "Quimperlé";
$areanames{en}->{3325647} = "Fougères";
$areanames{en}->{3325648} = "Janzé";
$areanames{en}->{3325649} = "Montfort\-sur\-Meu";
$areanames{en}->{3325651} = "Rennes";
$areanames{en}->{3325654} = "Lorient";
$areanames{en}->{3325660} = "Auray";
$areanames{en}->{3325661} = "Ploërmel";
$areanames{en}->{3325662} = "Pontivy";
$areanames{en}->{3325663} = "Vannes";
$areanames{en}->{3325664} = "Carhaix\-Plouguer";
$areanames{en}->{3325665} = "Fougères";
$areanames{en}->{3325666} = "Guingamp";
$areanames{en}->{3325667} = "Janzé";
$areanames{en}->{3325668} = "Auray";
$areanames{en}->{3325669} = "Brest";
$areanames{en}->{3325670} = "Carhaix\-Plouguer";
$areanames{en}->{3325671} = "Dinan";
$areanames{en}->{3325672} = "Le\ Faouet";
$areanames{en}->{3325673} = "Fougères";
$areanames{en}->{3325674} = "Guingamp";
$areanames{en}->{3325675} = "Janzé";
$areanames{en}->{3325676} = "Lamballe";
$areanames{en}->{3325677} = "Loudéac";
$areanames{en}->{3325678} = "Montfort\-sur\-Meu";
$areanames{en}->{3325679} = "Morlaix";
$areanames{en}->{3325680} = "Paimpol";
$areanames{en}->{3325681} = "Ploërmel";
$areanames{en}->{3325682} = "Pontivy";
$areanames{en}->{3325683} = "Quimperlé";
$areanames{en}->{3325684} = "Redon";
$areanames{en}->{3325685} = "Rennes";
$areanames{en}->{3325686} = "Rostrenen";
$areanames{en}->{3325687} = "Saint\-Brieuc";
$areanames{en}->{3325688} = "Saint\-Malo";
$areanames{en}->{3325689} = "Vannes";
$areanames{en}->{3325690} = "Vitré";
$areanames{en}->{3325691} = "Montfort\-sur\-Meu";
$areanames{en}->{3325692} = "Ploërmel";
$areanames{en}->{3325693} = "Redon";
$areanames{en}->{3325694} = "Carhaix\-Plouguer";
$areanames{en}->{3325695} = "Vitré";
$areanames{en}->{3325696} = "Vannes";
$areanames{en}->{3325697} = "Rennes";
$areanames{en}->{3325698} = "Auray";
$areanames{en}->{3325699} = "Lamballe";
$areanames{en}->{3325700} = "Guingamp";
$areanames{en}->{3325701} = "Lamballe";
$areanames{en}->{3325702} = "Loudéac";
$areanames{en}->{3325703} = "Paimpol";
$areanames{en}->{3325704} = "Rostrenen";
$areanames{en}->{3325705} = "Saint\-Brieuc";
$areanames{en}->{3325706} = "Fougères";
$areanames{en}->{3325707} = "Janzé";
$areanames{en}->{3325708} = "Montfort\-sur\-Meu";
$areanames{en}->{3325709} = "Redon";
$areanames{en}->{3325710} = "Rennes";
$areanames{en}->{3325711} = "Saint\-Malo";
$areanames{en}->{3325712} = "Vitré";
$areanames{en}->{3325713} = "Auray";
$areanames{en}->{3325714} = "Le\ Faouet";
$areanames{en}->{3325715} = "Ploërmel";
$areanames{en}->{3325716} = "Pontivy";
$areanames{en}->{3325717} = "Vannes";
$areanames{en}->{3325718} = "Saint\-Brieuc";
$areanames{en}->{3325719} = "Guingamp";
$areanames{en}->{3325720} = "Rennes";
$areanames{en}->{3325721} = "Rennes";
$areanames{en}->{3325722} = "Rennes";
$areanames{en}->{3325723} = "Brest";
$areanames{en}->{3325724} = "Rennes";
$areanames{en}->{3325725} = "Saint\-Brieuc";
$areanames{en}->{3325726} = "Rennes";
$areanames{en}->{3325727} = "Dinan";
$areanames{en}->{3325728} = "Vannes";
$areanames{en}->{3325729} = "Brest";
$areanames{en}->{3325730} = "Carhaix\-Plouguer";
$areanames{en}->{3325731} = "Fougères";
$areanames{en}->{3325732} = "Guingamp";
$areanames{en}->{3325733} = "Janzé";
$areanames{en}->{3325734} = "Lamballe";
$areanames{en}->{3325735} = "Dinan";
$areanames{en}->{3325736} = "Loudéac";
$areanames{en}->{3325737} = "Montfort\-sur\-Meu";
$areanames{en}->{3325738} = "Morlaix";
$areanames{en}->{3325739} = "Paimpol";
$areanames{en}->{3325740} = "Brest";
$areanames{en}->{3325741} = "Redon";
$areanames{en}->{3325742} = "Rennes";
$areanames{en}->{3325743} = "Rostrenen";
$areanames{en}->{3325744} = "Saint\-Brieuc";
$areanames{en}->{3325745} = "Saint\-Malo";
$areanames{en}->{3325746} = "Vitré";
$areanames{en}->{3325747} = "Auray";
$areanames{en}->{3325748} = "Saint\-Malo";
$areanames{en}->{3325749} = "Brest";
$areanames{en}->{3325750} = "Morlaix";
$areanames{en}->{3325751} = "Quimperlé";
$areanames{en}->{3325752} = "Brest";
$areanames{en}->{3325753} = "Rennes";
$areanames{en}->{3325754} = "Rennes";
$areanames{en}->{3325755} = "Brest";
$areanames{en}->{3325756} = "Carhaix\-Plouguer";
$areanames{en}->{3325757} = "Saint\-Brieuc";
$areanames{en}->{3325758} = "Auray";
$areanames{en}->{3325759} = "Vannes";
$areanames{en}->{3325760} = "Saint\-Malo";
$areanames{en}->{3325761} = "Saint\-Brieuc";
$areanames{en}->{3325762} = "Vannes";
$areanames{en}->{3325763} = "Guingamp";
$areanames{en}->{3325764} = "Saint\-Malo";
$areanames{en}->{3325765} = "Morlaix";
$areanames{en}->{3325766} = "Rennes";
$areanames{en}->{3325767} = "Rennes";
$areanames{en}->{3325768} = "Brest";
$areanames{en}->{3325769} = "Dinan";
$areanames{en}->{3325770} = "Fougères";
$areanames{en}->{3325771} = "Redon";
$areanames{en}->{3325772} = "Pontivy";
$areanames{en}->{3325773} = "Ploërmel";
$areanames{en}->{3325774} = "Vitré";
$areanames{en}->{3325775} = "Rennes";
$areanames{en}->{3325776} = "Guingamp";
$areanames{en}->{3325777} = "Lamballe";
$areanames{en}->{3325778} = "Loudéac";
$areanames{en}->{3325779} = "Paimpol";
$areanames{en}->{3325780} = "Rostrenen";
$areanames{en}->{3325781} = "Quimperlé";
$areanames{en}->{3325782} = "Janzé";
$areanames{en}->{3325783} = "Montfort\-sur\-Meu";
$areanames{en}->{3325784} = "Auray";
$areanames{en}->{3325785} = "Rennes";
$areanames{en}->{3325786} = "Le\ Faouet";
$areanames{en}->{3325787} = "Rennes";
$areanames{en}->{3325788} = "Carhaix\-Plouguer";
$areanames{en}->{3325789} = "Quimperlé";
$areanames{en}->{3325790} = "Auray";
$areanames{en}->{3325791} = "Ploërmel";
$areanames{en}->{3325792} = "Vannes";
$areanames{en}->{3325794} = "Auray";
$areanames{en}->{3325795} = "Saint\-Malo";
$areanames{en}->{3325796} = "Vannes";
$areanames{en}->{3325797} = "Pontivy";
$areanames{en}->{3325798} = "Guingamp";
$areanames{en}->{3325799} = "Vitré";
$areanames{en}->{3325800} = "Saint\-Lô";
$areanames{en}->{3325801} = "Alençon";
$areanames{en}->{3325802} = "Argentan";
$areanames{en}->{3325803} = "Flers";
$areanames{en}->{3325804} = "L\'Aigle";
$areanames{en}->{3325805} = "Mortagne\-au\-Perche";
$areanames{en}->{3325806} = "Deauville";
$areanames{en}->{3325807} = "Caen";
$areanames{en}->{3325808} = "Bayeux";
$areanames{en}->{3325809} = "Caen";
$areanames{en}->{3325810} = "Deauville";
$areanames{en}->{3325811} = "Falaise";
$areanames{en}->{3325812} = "Lisieux";
$areanames{en}->{3325813} = "Vire";
$areanames{en}->{3325814} = "Avranches";
$areanames{en}->{3325815} = "Carentan\-les\-Marais";
$areanames{en}->{3325816} = "Coutances";
$areanames{en}->{3325817} = "Saint\-Lô";
$areanames{en}->{3325818} = "Alençon";
$areanames{en}->{3325819} = "Argentan";
$areanames{en}->{3325820} = "Flers";
$areanames{en}->{3325821} = "L\'Aigle";
$areanames{en}->{3325822} = "Mortagne\-au\-Perche";
$areanames{en}->{3325823} = "Caen";
$areanames{en}->{3325824} = "Carentan\-les\-Marais";
$areanames{en}->{3325825} = "Vire";
$areanames{en}->{3325826} = "Bayeux";
$areanames{en}->{3325900} = "La\ Roche\-sur\-Yon";
$areanames{en}->{3325901} = "Nantes";
$areanames{en}->{3326100} = "Deauville";
$areanames{en}->{3326101} = "Mortagne\-au\-Perche";
$areanames{en}->{3326102} = "Flers";
$areanames{en}->{3326103} = "Falaise";
$areanames{en}->{3326104} = "Avranches";
$areanames{en}->{3326105} = "Bayeux";
$areanames{en}->{3326106} = "Argentan";
$areanames{en}->{3326107} = "Lisieux";
$areanames{en}->{3326108} = "Carentan\-les\-Marais";
$areanames{en}->{3326109} = "Caen";
$areanames{en}->{3326110} = "Caen";
$areanames{en}->{3326111} = "Deauville";
$areanames{en}->{3326112} = "Alençon";
$areanames{en}->{3326113} = "L\'Aigle";
$areanames{en}->{3326114} = "Vire";
$areanames{en}->{3326115} = "Saint\-Lô";
$areanames{en}->{3326116} = "Alençon";
$areanames{en}->{3326117} = "Bayeux";
$areanames{en}->{3326118} = "Caen";
$areanames{en}->{3326119} = "Deauville";
$areanames{en}->{3326120} = "Falaise";
$areanames{en}->{3326121} = "Lisieux";
$areanames{en}->{3326122} = "Vire";
$areanames{en}->{3326123} = "Avranches";
$areanames{en}->{3326124} = "Carentan\-les\-Marais";
$areanames{en}->{3326125} = "Coutances";
$areanames{en}->{3326126} = "Saint\-Lô";
$areanames{en}->{3326127} = "Alençon";
$areanames{en}->{3326128} = "Argentan";
$areanames{en}->{3326129} = "Flers";
$areanames{en}->{3326130} = "L\'Aigle";
$areanames{en}->{3326131} = "Mortagne\-au\-Perche";
$areanames{en}->{3326132} = "Caen";
$areanames{en}->{3326133} = "Bayeux";
$areanames{en}->{3326134} = "Falaise";
$areanames{en}->{3326135} = "Lisieux";
$areanames{en}->{3326136} = "Coutances";
$areanames{en}->{3326137} = "L\'Aigle";
$areanames{en}->{3326138} = "Caen";
$areanames{en}->{3326139} = "Saint\-Lô";
$areanames{en}->{3326140} = "Alençon";
$areanames{en}->{3326141} = "Avranches";
$areanames{en}->{3326142} = "Carentan\-les\-Marais";
$areanames{en}->{3326143} = "Coutances";
$areanames{en}->{3326144} = "Saint\-Lô";
$areanames{en}->{3326145} = "Caen";
$areanames{en}->{3326146} = "Deauville";
$areanames{en}->{3326147} = "Falaise";
$areanames{en}->{3326148} = "Lisieux";
$areanames{en}->{3326149} = "Vire";
$areanames{en}->{3326150} = "Alençon";
$areanames{en}->{3326151} = "Carentan\-les\-Marais";
$areanames{en}->{3326152} = "Caen";
$areanames{en}->{3326153} = "Caen";
$areanames{en}->{3326154} = "Alençon";
$areanames{en}->{3326155} = "Argentan";
$areanames{en}->{3326156} = "Avranches";
$areanames{en}->{3326157} = "Flers";
$areanames{en}->{3326158} = "Carentan\-les\-Marais";
$areanames{en}->{3326159} = "Saint\-Lô";
$areanames{en}->{3326160} = "Mortagne\-au\-Perche";
$areanames{en}->{3326161} = "L\'Aigle";
$areanames{en}->{3326162} = "Coutances";
$areanames{en}->{3326163} = "L\'Aigle";
$areanames{en}->{3326164} = "Argentan";
$areanames{en}->{3326165} = "Flers";
$areanames{en}->{3326166} = "Mortagne\-au\-Perche";
$areanames{en}->{3326167} = "Caen";
$areanames{en}->{3326168} = "Caen";
$areanames{en}->{3326169} = "Avranches";
$areanames{en}->{3326170} = "Flers";
$areanames{en}->{3326171} = "Alençon";
$areanames{en}->{3326172} = "Alençon";
$areanames{en}->{3326173} = "Argentan";
$areanames{en}->{3326174} = "Saint\-Lô";
$areanames{en}->{3326175} = "Lisieux";
$areanames{en}->{3326176} = "Coutances";
$areanames{en}->{3326177} = "Bayeux";
$areanames{en}->{3326178} = "Vire";
$areanames{en}->{3326179} = "Caen";
$areanames{en}->{3326180} = "Caen";
$areanames{en}->{3326181} = "Saint\-Lô";
$areanames{en}->{3326182} = "Deauville";
$areanames{en}->{3326183} = "Falaise";
$areanames{en}->{3326184} = "L\'Aigle";
$areanames{en}->{3326185} = "Mortagne\-au\-Perche";
$areanames{en}->{3326186} = "Bayeux";
$areanames{en}->{3326187} = "Caen";
$areanames{en}->{3326188} = "Caen";
$areanames{en}->{3326189} = "Deauville";
$areanames{en}->{3326190} = "Avranches";
$areanames{en}->{3326192} = "Caen";
$areanames{en}->{3326193} = "Deauville";
$areanames{en}->{3326194} = "Falaise";
$areanames{en}->{3326195} = "Lisieux";
$areanames{en}->{3326196} = "Vire";
$areanames{en}->{3326197} = "Avranches";
$areanames{en}->{3326198} = "Carentan\-les\-Marais";
$areanames{en}->{3326199} = "Coutances";
$areanames{en}->{3326300} = "Saint\-Denis";
$areanames{en}->{3327202} = "Nantes";
$areanames{en}->{3327210} = "Cholet";
$areanames{en}->{3327211} = "Challans";
$areanames{en}->{3327212} = "Blain";
$areanames{en}->{3327213} = "Cholet";
$areanames{en}->{3327214} = "Château\-Gontier";
$areanames{en}->{3327215} = "Saumur";
$areanames{en}->{3327216} = "Le\ Mans";
$areanames{en}->{3327217} = "Nantes";
$areanames{en}->{3327218} = "Nantes";
$areanames{en}->{3327219} = "La\ Roche\-sur\-Yon";
$areanames{en}->{3327220} = "Nantes";
$areanames{en}->{3327221} = "Segre";
$areanames{en}->{3327222} = "Nantes";
$areanames{en}->{3327223} = "Château\-Gontier";
$areanames{en}->{3327224} = "Nantes";
$areanames{en}->{3327225} = "Nantes";
$areanames{en}->{3327226} = "Laval";
$areanames{en}->{3327227} = "Saint\-Nazaire";
$areanames{en}->{3327228} = "Mayenne";
$areanames{en}->{3327229} = "Beaumont\-sur\-Sarthe";
$areanames{en}->{3327230} = "Château\-du\-Loir";
$areanames{en}->{3327231} = "La\ Ferte\-Bernard";
$areanames{en}->{3327232} = "Châteaubriant";
$areanames{en}->{3327233} = "La\ Flèche";
$areanames{en}->{3327234} = "Nantes";
$areanames{en}->{3327235} = "Le\ Mans";
$areanames{en}->{3327236} = "Sablé\-sur\-Sarthe";
$areanames{en}->{3327237} = "Saint\-Calais";
$areanames{en}->{3327238} = "Challans";
$areanames{en}->{3327239} = "Fontenay\-le\-Comte";
$areanames{en}->{3327240} = "Les\ Herbiers";
$areanames{en}->{3327241} = "Châteaubriant";
$areanames{en}->{3327242} = "Segre";
$areanames{en}->{3327243} = "Nantes";
$areanames{en}->{3327244} = "Luçon";
$areanames{en}->{3327245} = "Pornic";
$areanames{en}->{3327246} = "Saint\-Nazaire";
$areanames{en}->{3327247} = "Angers";
$areanames{en}->{3327248} = "La\ Roche\-sur\-Yon";
$areanames{en}->{3327249} = "Cholet";
$areanames{en}->{3327250} = "Saumur";
$areanames{en}->{3327251} = "Segre";
$areanames{en}->{3327252} = "Ancenis";
$areanames{en}->{3327253} = "Château\-Gontier";
$areanames{en}->{3327254} = "Laval";
$areanames{en}->{3327255} = "Les\ Sables\ d\'Olonne";
$areanames{en}->{3327256} = "Nantes";
$areanames{en}->{3327257} = "Beaumont\-sur\-Sarthe";
$areanames{en}->{3327258} = "Château\-du\-Loir";
$areanames{en}->{3327259} = "Ancenis";
$areanames{en}->{3327260} = "Nantes";
$areanames{en}->{3327261} = "Le\ Mans";
$areanames{en}->{3327262} = "Cholet";
$areanames{en}->{3327263} = "Châteaubriant";
$areanames{en}->{3327264} = "Nantes";
$areanames{en}->{3327265} = "Nantes";
$areanames{en}->{3327266} = "Pornic";
$areanames{en}->{3327267} = "Les\ Herbiers";
$areanames{en}->{3327268} = "Nantes";
$areanames{en}->{3327269} = "La\ Roche\-sur\-Yon";
$areanames{en}->{3327270} = "Châteaubriant";
$areanames{en}->{3327271} = "La\ Roche\-sur\-Yon";
$areanames{en}->{3327272} = "Angers";
$areanames{en}->{3327273} = "Angers";
$areanames{en}->{3327274} = "Nantes";
$areanames{en}->{3327275} = "Challans";
$areanames{en}->{3327276} = "Le\ Mans";
$areanames{en}->{3327277} = "Cholet";
$areanames{en}->{3327278} = "La\ Roche\-sur\-Yon";
$areanames{en}->{3327279} = "Angers";
$areanames{en}->{3327280} = "Les\ Sables\ d\'Olonne";
$areanames{en}->{3327281} = "Cholet";
$areanames{en}->{3327282} = "Challans";
$areanames{en}->{3327283} = "Nantes";
$areanames{en}->{3327284} = "Nantes";
$areanames{en}->{3327285} = "Nantes";
$areanames{en}->{3327286} = "Saumur";
$areanames{en}->{3327287} = "Segre";
$areanames{en}->{3327288} = "Le\ Mans";
$areanames{en}->{3327289} = "Laval";
$areanames{en}->{3327290} = "Nantes";
$areanames{en}->{3327291} = "Le\ Mans";
$areanames{en}->{3327292} = "Pornic";
$areanames{en}->{3327293} = "Ancenis";
$areanames{en}->{3327294} = "Blain";
$areanames{en}->{3327295} = "Laval";
$areanames{en}->{3327296} = "Nantes";
$areanames{en}->{3327297} = "Pornic";
$areanames{en}->{3327298} = "Saint\-Nazaire";
$areanames{en}->{3327299} = "Angers";
$areanames{en}->{3327600} = "Rouen";
$areanames{en}->{3327601} = "Rouen";
$areanames{en}->{3327602} = "Yvetot";
$areanames{en}->{3327603} = "Fécamp";
$areanames{en}->{3327604} = "Gournay\-en\-Bray";
$areanames{en}->{3327605} = "Le\ Havre";
$areanames{en}->{3327606} = "Neufchâtel\-en\-Bray";
$areanames{en}->{3327607} = "Yvetot";
$areanames{en}->{3327608} = "Rouen";
$areanames{en}->{3327609} = "Bernay";
$areanames{en}->{3327610} = "Fleury\-sur\-Andelle";
$areanames{en}->{3327611} = "Neufchâtel\-en\-Bray";
$areanames{en}->{3327612} = "Evreux";
$areanames{en}->{3327613} = "Fleury\-sur\-Andelle";
$areanames{en}->{3327614} = "Gisors";
$areanames{en}->{3327615} = "Louviers";
$areanames{en}->{3327616} = "Bolbec";
$areanames{en}->{3327617} = "Dieppe";
$areanames{en}->{3327618} = "Pont\-Audemer";
$areanames{en}->{3327619} = "Vernon";
$areanames{en}->{3327620} = "Rouen";
$areanames{en}->{3327621} = "Dieppe";
$areanames{en}->{3327622} = "Gournay\-en\-Bray";
$areanames{en}->{3327623} = "Fécamp";
$areanames{en}->{3327624} = "Gournay\-en\-Bray";
$areanames{en}->{3327625} = "Le\ Havre";
$areanames{en}->{3327626} = "Neufchâtel\-en\-Bray";
$areanames{en}->{3327627} = "Rouen";
$areanames{en}->{3327628} = "Rouen";
$areanames{en}->{3327629} = "Yvetot";
$areanames{en}->{3327630} = "Rouen";
$areanames{en}->{3327631} = "Bolbec";
$areanames{en}->{3327632} = "Le\ Havre";
$areanames{en}->{3327633} = "Fleury\-sur\-Andelle";
$areanames{en}->{3327634} = "Rouen";
$areanames{en}->{3327635} = "Bernay";
$areanames{en}->{3327636} = "Bolbec";
$areanames{en}->{3327637} = "Dieppe";
$areanames{en}->{3327638} = "Evreux";
$areanames{en}->{3327639} = "Fécamp";
$areanames{en}->{3327640} = "Le\ Havre";
$areanames{en}->{3327641} = "Bernay";
$areanames{en}->{3327642} = "Evreux";
$areanames{en}->{3327643} = "Fleury\-sur\-Andelle";
$areanames{en}->{3327644} = "Louviers";
$areanames{en}->{3327645} = "Gisors";
$areanames{en}->{3327646} = "Louviers";
$areanames{en}->{3327647} = "Pont\-Audemer";
$areanames{en}->{3327648} = "Vernon";
$areanames{en}->{3327649} = "Louviers";
$areanames{en}->{3327650} = "Neufchâtel\-en\-Bray";
$areanames{en}->{3327651} = "Rouen";
$areanames{en}->{3327652} = "Rouen";
$areanames{en}->{3327653} = "Yvetot";
$areanames{en}->{3327654} = "Dieppe";
$areanames{en}->{3327655} = "Evreux";
$areanames{en}->{3327656} = "Bernay";
$areanames{en}->{3327657} = "Evreux";
$areanames{en}->{3327658} = "Gournay\-en\-Bray";
$areanames{en}->{3327659} = "Gisors";
$areanames{en}->{3327660} = "Louviers";
$areanames{en}->{3327661} = "Rouen";
$areanames{en}->{3327662} = "Vernon";
$areanames{en}->{3327663} = "Bolbec";
$areanames{en}->{3327664} = "Nantes";
$areanames{en}->{3327665} = "Fécamp";
$areanames{en}->{3327666} = "Pont\-Audemer";
$areanames{en}->{3327667} = "Rouen";
$areanames{en}->{3327668} = "Rouen";
$areanames{en}->{3327669} = "Bolbec";
$areanames{en}->{3327670} = "Rouen";
$areanames{en}->{3327671} = "Yvetot";
$areanames{en}->{3327672} = "Dieppe";
$areanames{en}->{3327673} = "Gournay\-en\-Bray";
$areanames{en}->{3327674} = "Le\ Havre";
$areanames{en}->{3327675} = "Bolbec";
$areanames{en}->{3327676} = "Vernon";
$areanames{en}->{3327677} = "Dieppe";
$areanames{en}->{3327678} = "Rouen";
$areanames{en}->{3327679} = "Gisors";
$areanames{en}->{3327680} = "Le\ Havre";
$areanames{en}->{3327681} = "Le\ Havre";
$areanames{en}->{3327682} = "Gournay\-en\-Bray";
$areanames{en}->{3327683} = "Fécamp";
$areanames{en}->{3327684} = "Le\ Havre";
$areanames{en}->{3327685} = "Neufchâtel\-en\-Bray";
$areanames{en}->{3327686} = "Rouen";
$areanames{en}->{3327687} = "Rouen";
$areanames{en}->{3327688} = "Rouen";
$areanames{en}->{3327689} = "Le\ Havre";
$areanames{en}->{3327690} = "Bernay";
$areanames{en}->{3327691} = "Evreux";
$areanames{en}->{3327692} = "Fleury\-sur\-Andelle";
$areanames{en}->{3327693} = "Gisors";
$areanames{en}->{3327694} = "Louviers";
$areanames{en}->{3327695} = "Rouen";
$areanames{en}->{3327696} = "Pont\-Audemer";
$areanames{en}->{3327697} = "Vernon";
$areanames{en}->{3327698} = "Bolbec";
$areanames{en}->{3327699} = "Dieppe";
$areanames{en}->{3327700} = "Le\ Havre";
$areanames{en}->{3327701} = "Pont\-Audemer";
$areanames{en}->{3327702} = "Vernon";
$areanames{en}->{3327703} = "Yvetot";
$areanames{en}->{3327704} = "Le\ Havre";
$areanames{en}->{3327705} = "Bernay";
$areanames{en}->{3327706} = "Rouen";
$areanames{en}->{3327707} = "Rouen";
$areanames{en}->{3327708} = "Louviers";
$areanames{en}->{3327709} = "Bernay";
$areanames{en}->{3327710} = "Le\ Havre";
$areanames{en}->{3327711} = "Rouen";
$areanames{en}->{3327712} = "Evreux";
$areanames{en}->{3327713} = "Fleury\-sur\-Andelle";
$areanames{en}->{3327714} = "Gisors";
$areanames{en}->{3327715} = "Le\ Havre";
$areanames{en}->{3327716} = "Louviers";
$areanames{en}->{3327717} = "Bolbec";
$areanames{en}->{3327718} = "Pont\-Audemer";
$areanames{en}->{3327719} = "Vernon";
$areanames{en}->{3327720} = "Rouen";
$areanames{en}->{3327721} = "Le\ Havre";
$areanames{en}->{3327722} = "Bolbec";
$areanames{en}->{3327723} = "Dieppe";
$areanames{en}->{3327724} = "Fécamp";
$areanames{en}->{3327725} = "Gournay\-en\-Bray";
$areanames{en}->{3327726} = "Neufchâtel\-en\-Bray";
$areanames{en}->{3327727} = "Evreux";
$areanames{en}->{3327728} = "Yvetot";
$areanames{en}->{3327729} = "Dieppe";
$areanames{en}->{3327730} = "Bernay";
$areanames{en}->{3327731} = "Bolbec";
$areanames{en}->{3327732} = "Dieppe";
$areanames{en}->{3327733} = "Evreux";
$areanames{en}->{3327734} = "Fécamp";
$areanames{en}->{3327735} = "Fleury\-sur\-Andelle";
$areanames{en}->{3327736} = "Gisors";
$areanames{en}->{3327737} = "Gournay\-en\-Bray";
$areanames{en}->{3327738} = "Le\ Havre";
$areanames{en}->{3327739} = "Neufchâtel\-en\-Bray";
$areanames{en}->{3327740} = "Pont\-Audemer";
$areanames{en}->{3327741} = "Rouen";
$areanames{en}->{3327742} = "Vernon";
$areanames{en}->{3327743} = "Yvetot";
$areanames{en}->{3327744} = "Evreux";
$areanames{en}->{3327745} = "Fleury\-sur\-Andelle";
$areanames{en}->{3327746} = "Gournay\-en\-Bray";
$areanames{en}->{3327747} = "Louviers";
$areanames{en}->{3327748} = "Neufchâtel\-en\-Bray";
$areanames{en}->{3327749} = "Pont\-Audemer";
$areanames{en}->{3327750} = "Rouen";
$areanames{en}->{3327751} = "Yvetot";
$areanames{en}->{3327752} = "Rouen";
$areanames{en}->{3327753} = "Bernay";
$areanames{en}->{3327754} = "Dieppe";
$areanames{en}->{3327755} = "Evreux";
$areanames{en}->{3327756} = "Le\ Havre";
$areanames{en}->{3327757} = "Louviers";
$areanames{en}->{3327758} = "Rouen";
$areanames{en}->{3327759} = "Vernon";
$areanames{en}->{3327760} = "Evreux";
$areanames{en}->{3327761} = "Le\ Havre";
$areanames{en}->{3327762} = "Rouen";
$areanames{en}->{3327763} = "Evreux";
$areanames{en}->{3327764} = "Fleury\-sur\-Andelle";
$areanames{en}->{3327765} = "Gournay\-en\-Bray";
$areanames{en}->{3327766} = "Le\ Havre";
$areanames{en}->{3327767} = "Le\ Havre";
$areanames{en}->{3327768} = "Louviers";
$areanames{en}->{3327769} = "Vernon";
$areanames{en}->{3327776} = "Rouen";
$areanames{en}->{3327780} = "Bernay";
$areanames{en}->{3327781} = "Le\ Havre";
$areanames{en}->{3327782} = "Bernay";
$areanames{en}->{3327783} = "Bolbec";
$areanames{en}->{3327784} = "Dieppe";
$areanames{en}->{3327785} = "Evreux";
$areanames{en}->{3327786} = "Fécamp";
$areanames{en}->{3327787} = "Dieppe";
$areanames{en}->{3327788} = "Evreux";
$areanames{en}->{3327789} = "Louviers";
$areanames{en}->{3327790} = "Gisors";
$areanames{en}->{3327791} = "Fleury\-sur\-Andelle";
$areanames{en}->{3327792} = "Gisors";
$areanames{en}->{3327793} = "Gournay\-en\-Bray";
$areanames{en}->{3327794} = "Le\ Havre";
$areanames{en}->{3327795} = "Louviers";
$areanames{en}->{3327796} = "Neufchâtel\-en\-Bray";
$areanames{en}->{3327797} = "Pont\-Audemer";
$areanames{en}->{3327798} = "Rouen";
$areanames{en}->{3327799} = "Fécamp";
$areanames{en}->{3327800} = "Vernon";
$areanames{en}->{3327801} = "Yvetot";
$areanames{en}->{3327802} = "Gisors";
$areanames{en}->{3327803} = "Bernay";
$areanames{en}->{3327804} = "Evreux";
$areanames{en}->{3327805} = "Fleury\-sur\-Andelle";
$areanames{en}->{3327806} = "Gisors";
$areanames{en}->{3327807} = "Louviers";
$areanames{en}->{3327808} = "Rouen";
$areanames{en}->{3327809} = "Pont\-Audemer";
$areanames{en}->{3327810} = "Vernon";
$areanames{en}->{3327811} = "Bolbec";
$areanames{en}->{3327812} = "Dieppe";
$areanames{en}->{3327813} = "Fécamp";
$areanames{en}->{3327814} = "Gournay\-en\-Bray";
$areanames{en}->{3327815} = "Le\ Havre";
$areanames{en}->{3327816} = "Neufchâtel\-en\-Bray";
$areanames{en}->{3327817} = "Yvetot";
$areanames{en}->{3327818} = "Dieppe";
$areanames{en}->{3327819} = "Le\ Havre";
$areanames{en}->{3327820} = "Rouen";
$areanames{en}->{3327821} = "Bernay";
$areanames{en}->{3327822} = "Evreux";
$areanames{en}->{3327823} = "Louviers";
$areanames{en}->{3327824} = "Vernon";
$areanames{en}->{3327825} = "Neufchâtel\-en\-Bray";
$areanames{en}->{3327826} = "Rouen";
$areanames{en}->{3327827} = "Le\ Havre";
$areanames{en}->{3327828} = "Gisors";
$areanames{en}->{3327829} = "Bernay";
$areanames{en}->{3327830} = "Fleury\-sur\-Andelle";
$areanames{en}->{3327831} = "Pont\-Audemer";
$areanames{en}->{3327832} = "Vernon";
$areanames{en}->{3327833} = "Fécamp";
$areanames{en}->{3327834} = "Le\ Havre";
$areanames{en}->{3327835} = "Fleury\-sur\-Andelle";
$areanames{en}->{3327836} = "Gournay\-en\-Bray";
$areanames{en}->{3327837} = "Dieppe";
$areanames{en}->{3327838} = "Neufchâtel\-en\-Bray";
$areanames{en}->{3327839} = "Yvetot";
$areanames{en}->{3327840} = "Dieppe";
$areanames{en}->{3327841} = "Vernon";
$areanames{en}->{3327842} = "Fécamp";
$areanames{en}->{3327843} = "Bolbec";
$areanames{en}->{3327844} = "Evreux";
$areanames{en}->{3327845} = "Le\ Havre";
$areanames{en}->{3327846} = "Louviers";
$areanames{en}->{3327847} = "Rouen";
$areanames{en}->{3327848} = "Bolbec";
$areanames{en}->{3327849} = "Dieppe";
$areanames{en}->{3327850} = "Fécamp";
$areanames{en}->{3327851} = "Pont\-Audemer";
$areanames{en}->{3327852} = "Bernay";
$areanames{en}->{3327853} = "Evreux";
$areanames{en}->{3327854} = "Fleury\-sur\-Andelle";
$areanames{en}->{3327855} = "Gisors";
$areanames{en}->{3327856} = "Louviers";
$areanames{en}->{3327857} = "Pont\-Audemer";
$areanames{en}->{3327858} = "Vernon";
$areanames{en}->{3327859} = "Fécamp";
$areanames{en}->{3327860} = "Gournay\-en\-Bray";
$areanames{en}->{3327861} = "Gournay\-en\-Bray";
$areanames{en}->{3327862} = "Rouen";
$areanames{en}->{3327863} = "Le\ Havre";
$areanames{en}->{3327864} = "Neufchâtel\-en\-Bray";
$areanames{en}->{3327865} = "Rouen";
$areanames{en}->{3327866} = "Yvetot";
$areanames{en}->{3327867} = "Rouen";
$areanames{en}->{3327868} = "Gisors";
$areanames{en}->{3327869} = "Le\ Havre";
$areanames{en}->{3327870} = "Neufchâtel\-en\-Bray";
$areanames{en}->{3327871} = "Rouen";
$areanames{en}->{3327872} = "Bernay";
$areanames{en}->{3327873} = "Vernon";
$areanames{en}->{3327874} = "Fécamp";
$areanames{en}->{3327875} = "Rouen";
$areanames{en}->{3327876} = "Evreux";
$areanames{en}->{3327877} = "Rouen";
$areanames{en}->{3327878} = "Le\ Havre";
$areanames{en}->{3327879} = "Evreux";
$areanames{en}->{3327880} = "Yvetot";
$areanames{en}->{3327881} = "Rouen";
$areanames{en}->{3327882} = "Bernay";
$areanames{en}->{3327883} = "Evreux";
$areanames{en}->{3327884} = "Rouen";
$areanames{en}->{3327885} = "Fleury\-sur\-Andelle";
$areanames{en}->{3327886} = "Gisors";
$areanames{en}->{3327887} = "Louviers";
$areanames{en}->{3327888} = "Evreux";
$areanames{en}->{3327889} = "Pont\-Audemer";
$areanames{en}->{3327890} = "Bolbec";
$areanames{en}->{3327891} = "Vernon";
$areanames{en}->{3327892} = "Le\ Havre";
$areanames{en}->{3327893} = "Le\ Havre";
$areanames{en}->{3327894} = "Rouen";
$areanames{en}->{3327895} = "Le\ Havre";
$areanames{en}->{3327896} = "Rouen";
$areanames{en}->{3327897} = "Evreux";
$areanames{en}->{3327898} = "Evreux";
$areanames{en}->{3327899} = "Evreux";
$areanames{en}->{3327900} = "Dieppe";
$areanames{en}->{3327901} = "Le\ Havre";
$areanames{en}->{3327902} = "Rouen";
$areanames{en}->{3327903} = "Fécamp";
$areanames{en}->{3327904} = "Vernon";
$areanames{en}->{3327905} = "Pont\-Audemer";
$areanames{en}->{3327906} = "Bernay";
$areanames{en}->{3327907} = "Yvetot";
$areanames{en}->{3327908} = "Bolbec";
$areanames{en}->{3327909} = "Louviers";
$areanames{en}->{3327910} = "Evreux";
$areanames{en}->{3327911} = "Fleury\-sur\-Andelle";
$areanames{en}->{3327912} = "Gisors";
$areanames{en}->{3327913} = "Gournay\-en\-Bray";
$areanames{en}->{3327914} = "Neufchâtel\-en\-Bray";
$areanames{en}->{3327915} = "Le\ Havre";
$areanames{en}->{3327916} = "Rouen";
$areanames{en}->{3327917} = "Le\ Havre";
$areanames{en}->{3327918} = "Rouen";
$areanames{en}->{3327919} = "Evreux";
$areanames{en}->{3327920} = "Bernay";
$areanames{en}->{3327921} = "Fleury\-sur\-Andelle";
$areanames{en}->{3327922} = "Gisors";
$areanames{en}->{3327923} = "Louviers";
$areanames{en}->{3327924} = "Pont\-Audemer";
$areanames{en}->{3327925} = "Vernon";
$areanames{en}->{3327926} = "Bernay";
$areanames{en}->{3327927} = "Fleury\-sur\-Andelle";
$areanames{en}->{3327928} = "Gisors";
$areanames{en}->{3327929} = "Louviers";
$areanames{en}->{3327930} = "Pont\-Audemer";
$areanames{en}->{3327931} = "Vernon";
$areanames{en}->{3327932} = "Bolbec";
$areanames{en}->{3327933} = "Dieppe";
$areanames{en}->{3327934} = "Fécamp";
$areanames{en}->{3327935} = "Gournay\-en\-Bray";
$areanames{en}->{3327936} = "Neufchâtel\-en\-Bray";
$areanames{en}->{3327937} = "Rouen";
$areanames{en}->{3327938} = "Yvetot";
$areanames{en}->{3327979} = "Le\ Havre";
$areanames{en}->{3327980} = "Rouen";
$areanames{en}->{3327981} = "Rouen";
$areanames{en}->{3327982} = "Le\ Havre";
$areanames{en}->{3327983} = "Le\ Havre";
$areanames{en}->{3327984} = "Bolbec";
$areanames{en}->{3327985} = "Dieppe";
$areanames{en}->{3327986} = "Fécamp";
$areanames{en}->{3327987} = "Gournay\-en\-Bray";
$areanames{en}->{3327988} = "Neufchâtel\-en\-Bray";
$areanames{en}->{3327989} = "Yvetot";
$areanames{en}->{3327990} = "Rouen";
$areanames{en}->{3327991} = "Rouen";
$areanames{en}->{3327992} = "Le\ Havre";
$areanames{en}->{3327993} = "Rouen";
$areanames{en}->{3327994} = "Vernon";
$areanames{en}->{3327995} = "Evreux";
$areanames{en}->{3327996} = "Fleury\-sur\-Andelle";
$areanames{en}->{3328500} = "Sablé\-sur\-Sarthe";
$areanames{en}->{3328501} = "La\ Ferte\-Bernard";
$areanames{en}->{3328502} = "Ancenis";
$areanames{en}->{3328503} = "Blain";
$areanames{en}->{3328504} = "Châteaubriant";
$areanames{en}->{3328505} = "Nantes";
$areanames{en}->{3328506} = "Pornic";
$areanames{en}->{3328507} = "Saint\-Nazaire";
$areanames{en}->{3328508} = "Angers";
$areanames{en}->{3328509} = "Baugé\-en\-Anjou";
$areanames{en}->{3328510} = "Cholet";
$areanames{en}->{3328511} = "Saumur";
$areanames{en}->{3328512} = "Segre";
$areanames{en}->{3328513} = "Château\-Gontier";
$areanames{en}->{3328514} = "Laval";
$areanames{en}->{3328515} = "Mayenne";
$areanames{en}->{3328516} = "Beaumont\-sur\-Sarthe";
$areanames{en}->{3328517} = "Château\-du\-Loir";
$areanames{en}->{3328518} = "La\ Ferte\-Bernard";
$areanames{en}->{3328519} = "La\ Flèche";
$areanames{en}->{3328520} = "Le\ Mans";
$areanames{en}->{3328521} = "Sablé\-sur\-Sarthe";
$areanames{en}->{3328522} = "Saint\-Calais";
$areanames{en}->{3328523} = "Challans";
$areanames{en}->{3328524} = "Fontenay\-le\-Comte";
$areanames{en}->{3328525} = "Les\ Herbiers";
$areanames{en}->{3328526} = "Luçon";
$areanames{en}->{3328527} = "La\ Roche\-sur\-Yon";
$areanames{en}->{3328528} = "Les\ Sables\ d\'Olonne";
$areanames{en}->{3328529} = "Le\ Mans";
$areanames{en}->{3328537} = "Nantes";
$areanames{en}->{3328540} = "Château\-Gontier";
$areanames{en}->{3328541} = "Mayenne";
$areanames{en}->{3328542} = "Château\-du\-Loir";
$areanames{en}->{3328543} = "La\ Ferte\-Bernard";
$areanames{en}->{3328544} = "Saint\-Calais";
$areanames{en}->{3328545} = "Cholet";
$areanames{en}->{3328546} = "Les\ Herbiers";
$areanames{en}->{3328547} = "Luçon";
$areanames{en}->{3328548} = "Les\ Sables\ d\'Olonne";
$areanames{en}->{3328549} = "Laval";
$areanames{en}->{3328552} = "Nantes";
$areanames{en}->{3328560} = "Château\-du\-Loir";
$areanames{en}->{3328561} = "La\ Ferte\-Bernard";
$areanames{en}->{3328562} = "La\ Flèche";
$areanames{en}->{3328563} = "Le\ Mans";
$areanames{en}->{3328564} = "Sablé\-sur\-Sarthe";
$areanames{en}->{3328565} = "Laval";
$areanames{en}->{3328566} = "Saint\-Calais";
$areanames{en}->{3328567} = "Nantes";
$areanames{en}->{3328568} = "Laval";
$areanames{en}->{3328569} = "Ancenis";
$areanames{en}->{3328570} = "Blain";
$areanames{en}->{3328571} = "Châteaubriant";
$areanames{en}->{3328572} = "Nantes";
$areanames{en}->{3328573} = "Nantes";
$areanames{en}->{3328574} = "Saint\-Nazaire";
$areanames{en}->{3328575} = "La\ Roche\-sur\-Yon";
$areanames{en}->{3328576} = "Les\ Herbiers";
$areanames{en}->{3328577} = "Fontenay\-le\-Comte";
$areanames{en}->{3328578} = "Challans";
$areanames{en}->{3328579} = "Angers";
$areanames{en}->{3328580} = "Baugé\-en\-Anjou";
$areanames{en}->{3328581} = "Cholet";
$areanames{en}->{3328582} = "Saumur";
$areanames{en}->{3328583} = "Segre";
$areanames{en}->{3328584} = "Château\-du\-Loir";
$areanames{en}->{3328585} = "Le\ Mans";
$areanames{en}->{3328586} = "Château\-Gontier";
$areanames{en}->{3328587} = "Laval";
$areanames{en}->{3328588} = "Château\-Gontier";
$areanames{en}->{3328589} = "Mayenne";
$areanames{en}->{3328590} = "Beaumont\-sur\-Sarthe";
$areanames{en}->{3328591} = "Château\-du\-Loir";
$areanames{en}->{3328592} = "La\ Ferte\-Bernard";
$areanames{en}->{3328593} = "Pornic";
$areanames{en}->{3328594} = "La\ Flèche";
$areanames{en}->{3328595} = "Saint\-Nazaire";
$areanames{en}->{3328596} = "Le\ Mans";
$areanames{en}->{3328597} = "Sablé\-sur\-Sarthe";
$areanames{en}->{3328598} = "Blain";
$areanames{en}->{3328599} = "Ancenis";
$areanames{en}->{3329000} = "Rostrenen";
$areanames{en}->{3329001} = "Rennes";
$areanames{en}->{3329002} = "Rennes";
$areanames{en}->{3329003} = "Saint\-Brieuc";
$areanames{en}->{3329004} = "Saint\-Malo";
$areanames{en}->{3329005} = "Saint\-Brieuc";
$areanames{en}->{3329006} = "Brest";
$areanames{en}->{3329007} = "Carhaix\-Plouguer";
$areanames{en}->{3329008} = "Rennes";
$areanames{en}->{3329009} = "Rennes";
$areanames{en}->{3329010} = "Saint\-Malo";
$areanames{en}->{3329011} = "Morlaix";
$areanames{en}->{3329012} = "Quimperlé";
$areanames{en}->{3329013} = "Fougères";
$areanames{en}->{3329014} = "Janzé";
$areanames{en}->{3329015} = "Montfort\-sur\-Meu";
$areanames{en}->{3329016} = "Redon";
$areanames{en}->{3329017} = "Saint\-Malo";
$areanames{en}->{3329018} = "Vitré";
$areanames{en}->{3329019} = "Auray";
$areanames{en}->{3329020} = "Dinan";
$areanames{en}->{3329021} = "Le\ Faouet";
$areanames{en}->{3329022} = "Rennes";
$areanames{en}->{3329023} = "Ploërmel";
$areanames{en}->{3329024} = "Pontivy";
$areanames{en}->{3329025} = "Vannes";
$areanames{en}->{3329026} = "Brest";
$areanames{en}->{3329027} = "Guingamp";
$areanames{en}->{3329028} = "Lamballe";
$areanames{en}->{3329029} = "Loudéac";
$areanames{en}->{3329030} = "Montfort\-sur\-Meu";
$areanames{en}->{3329031} = "Paimpol";
$areanames{en}->{3329032} = "Rennes";
$areanames{en}->{3329033} = "Paimpol";
$areanames{en}->{3329034} = "Loudéac";
$areanames{en}->{3329035} = "Dinan";
$areanames{en}->{3329036} = "Saint\-Brieuc";
$areanames{en}->{3329037} = "Dinan";
$areanames{en}->{3329038} = "Auray";
$areanames{en}->{3329039} = "Brest";
$areanames{en}->{3329040} = "Ploërmel";
$areanames{en}->{3329041} = "Carhaix\-Plouguer";
$areanames{en}->{3329042} = "Morlaix";
$areanames{en}->{3329043} = "Quimperlé";
$areanames{en}->{3329044} = "Fougères";
$areanames{en}->{3329045} = "Janzé";
$areanames{en}->{3329046} = "Guingamp";
$areanames{en}->{3329047} = "Montfort\-sur\-Meu";
$areanames{en}->{3329048} = "Redon";
$areanames{en}->{3329049} = "Paimpol";
$areanames{en}->{3329056} = "Rennes";
$areanames{en}->{3329060} = "Janzé";
$areanames{en}->{3329061} = "Auray";
$areanames{en}->{3329062} = "Rennes";
$areanames{en}->{3329063} = "Saint\-Malo";
$areanames{en}->{3329064} = "Vitré";
$areanames{en}->{3329065} = "Auray";
$areanames{en}->{3329066} = "Le\ Faouet";
$areanames{en}->{3329067} = "Le\ Faouet";
$areanames{en}->{3329068} = "Ploërmel";
$areanames{en}->{3329069} = "Vannes";
$areanames{en}->{3329078} = "Rennes";
$areanames{en}->{3329080} = "Fougères";
$areanames{en}->{3329081} = "Saint\-Brieuc";
$areanames{en}->{3329082} = "Brest";
$areanames{en}->{3329083} = "Dinan";
$areanames{en}->{3329084} = "Auray";
$areanames{en}->{3329085} = "Brest";
$areanames{en}->{3329086} = "Saint\-Malo";
$areanames{en}->{3329087} = "Rennes";
$areanames{en}->{3329088} = "Brest";
$areanames{en}->{3329089} = "Rennes";
$areanames{en}->{3329090} = "Saint\-Brieuc";
$areanames{en}->{3329091} = "Brest";
$areanames{en}->{3329092} = "Rennes";
$areanames{en}->{3329093} = "Guingamp";
$areanames{en}->{3329094} = "Carhaix\-Plouguer";
$areanames{en}->{3329095} = "Rennes";
$areanames{en}->{3329096} = "Guingamp";
$areanames{en}->{3329097} = "Lamballe";
$areanames{en}->{3329098} = "Auray";
$areanames{en}->{3329099} = "Vannes";
$areanames{en}->{3329601} = "Saint\-Brieuc";
$areanames{en}->{3329611} = "Ploumagoar";
$areanames{en}->{3329614} = "Lannion";
$areanames{en}->{3329615} = "Trébeurden";
$areanames{en}->{3329616} = "Plouézec";
$areanames{en}->{3329620} = "Paimpol";
$areanames{en}->{3329623} = "Perros\-Guirec";
$areanames{en}->{3329628} = "Loudéac";
$areanames{en}->{3329629} = "Rostrenen";
$areanames{en}->{3329630} = "Lamballe";
$areanames{en}->{3329631} = "Lamballe";
$areanames{en}->{3329633} = "Saint\-Brieuc";
$areanames{en}->{3329635} = "Plestin\-les\-Grèves";
$areanames{en}->{3329636} = "Plouguernevel";
$areanames{en}->{3329637} = "Lannion";
$areanames{en}->{3329638} = "Plouaret";
$areanames{en}->{3329639} = "Dinan";
$areanames{en}->{3329640} = "Guingamp";
$areanames{en}->{3329641} = "Saint\-Cast\-le\-Guildo";
$areanames{en}->{3329644} = "Guingamp";
$areanames{en}->{3329645} = "Bégard";
$areanames{en}->{3329646} = "Lannion";
$areanames{en}->{3329647} = "Ploubezre";
$areanames{en}->{3329648} = "Lannion";
$areanames{en}->{3329649} = "Perros\-Guirec";
$areanames{en}->{3329650} = "Lamballe";
$areanames{en}->{3329652} = "Langueux";
$areanames{en}->{3329654} = "Plestin\-les\-Grèves";
$areanames{en}->{3329655} = "Paimpol";
$areanames{en}->{3329656} = "Illifaut";
$areanames{en}->{3329658} = "Plérin";
$areanames{en}->{3329660} = "Saint\-Brieuc";
$areanames{en}->{3329661} = "Saint\-Brieuc";
$areanames{en}->{3329662} = "Saint\-Brieuc";
$areanames{en}->{3329663} = "Pléneuf\-Val\-André";
$areanames{en}->{3329664} = "Plédran";
$areanames{en}->{3329665} = "Lanvollon";
$areanames{en}->{3329666} = "Loudéac";
$areanames{en}->{3329668} = "Saint\-Brieuc";
$areanames{en}->{3329669} = "Binic";
$areanames{en}->{3329670} = "Saint\-Quay\-Portrieux";
$areanames{en}->{3329671} = "Trégueux";
$areanames{en}->{3329672} = "Erquy";
$areanames{en}->{3329673} = "Binic";
$areanames{en}->{3329674} = "Plérin";
$areanames{en}->{3329675} = "Saint\-Brieuc";
$areanames{en}->{3329676} = "Ploufragan";
$areanames{en}->{3329677} = "Saint\-Brieuc";
$areanames{en}->{3329678} = "Saint\-Brieuc";
$areanames{en}->{3329679} = "Pordic";
$areanames{en}->{3329680} = "Broons";
$areanames{en}->{3329684} = "Plancoët";
$areanames{en}->{3329685} = "Dinan";
$areanames{en}->{3329687} = "Dinan";
$areanames{en}->{3329691} = "Perros\-Guirec";
$areanames{en}->{3329692} = "Treguier";
$areanames{en}->{3329694} = "Saint\-Brieuc";
$areanames{en}->{3329695} = "Pontrieux";
$areanames{en}->{3329701} = "Vannes";
$areanames{en}->{3329702} = "Guidel";
$areanames{en}->{3329705} = "Queven";
$areanames{en}->{3329708} = "Baud";
$areanames{en}->{3329711} = "Plouay";
$areanames{en}->{3329721} = "Lorient";
$areanames{en}->{3329722} = "Guer";
$areanames{en}->{3329723} = "Gourin";
$areanames{en}->{3329724} = "Auray";
$areanames{en}->{3329725} = "Pontivy";
$areanames{en}->{3329726} = "Questembert";
$areanames{en}->{3329727} = "Pontivy";
$areanames{en}->{3329728} = "Seglien";
$areanames{en}->{3329729} = "Auray";
$areanames{en}->{3329730} = "Quiberon";
$areanames{en}->{3329731} = "Le\ Palais";
$areanames{en}->{3329732} = "Pont\-Scorff";
$areanames{en}->{3329733} = "Plouay";
$areanames{en}->{3329734} = "Guiscriff";
$areanames{en}->{3329735} = "Lorient";
$areanames{en}->{3329736} = "Hennebont";
$areanames{en}->{3329737} = "Lorient";
$areanames{en}->{3329740} = "Vannes";
$areanames{en}->{3329741} = "Sarzeau";
$areanames{en}->{3329742} = "Vannes";
$areanames{en}->{3329743} = "Theix";
$areanames{en}->{3329744} = "Arradon";
$areanames{en}->{3329746} = "Vannes";
$areanames{en}->{3329747} = "Vannes";
$areanames{en}->{3329748} = "Sarzeau";
$areanames{en}->{3329749} = "Questembert";
$areanames{en}->{3329750} = "Quiberon";
$areanames{en}->{3329752} = "Carnac";
$areanames{en}->{3329753} = "Elven";
$areanames{en}->{3329754} = "Vannes";
$areanames{en}->{3329755} = "Belz";
$areanames{en}->{3329756} = "Auray";
$areanames{en}->{3329757} = "Baden";
$areanames{en}->{3329758} = "Baden";
$areanames{en}->{3329762} = "Vannes";
$areanames{en}->{3329763} = "Vannes";
$areanames{en}->{3329764} = "Lorient";
$areanames{en}->{3329765} = "Languidic";
$areanames{en}->{3329766} = "Grand\-Champ";
$areanames{en}->{3329768} = "Vannes";
$areanames{en}->{3329769} = "Vannes";
$areanames{en}->{3329770} = "Guer";
$areanames{en}->{3329772} = "Ploërmel";
$areanames{en}->{3329773} = "Ploërmel";
$areanames{en}->{3329774} = "Ploërmel";
$areanames{en}->{3329776} = "Lanester";
$areanames{en}->{3329780} = "Queven";
$areanames{en}->{3329781} = "Lanester";
$areanames{en}->{3329782} = "Ploërmel";
$areanames{en}->{3329783} = "Lorient";
$areanames{en}->{3329784} = "Lorient";
$areanames{en}->{3329785} = "Hennebont";
$areanames{en}->{3329786} = "Ploërmel";
$areanames{en}->{3329787} = "Lorient";
$areanames{en}->{3329788} = "Lorient";
$areanames{en}->{3329789} = "Lanester";
$areanames{en}->{332979} = "Nord\ Ouest";
$areanames{en}->{3329800} = "Brest";
$areanames{en}->{3329801} = "Brest";
$areanames{en}->{3329802} = "Brest";
$areanames{en}->{3329803} = "Brest";
$areanames{en}->{3329804} = "Lannilis";
$areanames{en}->{3329805} = "Brest";
$areanames{en}->{3329806} = "Riec\-sur\-Bélon";
$areanames{en}->{3329807} = "Guilers";
$areanames{en}->{3329809} = "Pont\-Aven";
$areanames{en}->{3329810} = "Quimper";
$areanames{en}->{3329811} = "Douarnenez";
$areanames{en}->{3329815} = "Morlaix";
$areanames{en}->{3329816} = "Crozon";
$areanames{en}->{3329817} = "Crozon";
$areanames{en}->{3329819} = "Saint\-Pol\-de\-Léon";
$areanames{en}->{3329821} = "Landerneau";
$areanames{en}->{3329824} = "Landivisiau";
$areanames{en}->{3329826} = "Pleyben";
$areanames{en}->{3329827} = "Crozon";
$areanames{en}->{3329828} = "Le\ Relecq\ Kerhuon";
$areanames{en}->{3329829} = "Saint\-Pol\-de\-Léon";
$areanames{en}->{3329830} = "Landerneau";
$areanames{en}->{3329832} = "Saint\-Renan";
$areanames{en}->{3329833} = "Brest";
$areanames{en}->{3329834} = "Brest";
$areanames{en}->{3329835} = "Quimperlé";
$areanames{en}->{3329837} = "Plabennec";
$areanames{en}->{3329838} = "Ploudalmézeau";
$areanames{en}->{3329839} = "Bannalec";
$areanames{en}->{332984} = "Brest";
$areanames{en}->{3329840} = "Plougastel\-Daoulas";
$areanames{en}->{3329848} = "Ploudalmézeau";
$areanames{en}->{3329850} = "Concarneau";
$areanames{en}->{3329851} = "Fouesnant";
$areanames{en}->{3329852} = "Quimper";
$areanames{en}->{3329853} = "Quimper";
$areanames{en}->{3329854} = "Plogastel\-Saint\-Germain";
$areanames{en}->{3329855} = "Quimper";
$areanames{en}->{3329856} = "Fouesnant";
$areanames{en}->{3329857} = "Briec";
$areanames{en}->{3329858} = "Penmarch";
$areanames{en}->{3329859} = "Rosporden";
$areanames{en}->{3329860} = "Concarneau";
$areanames{en}->{3329861} = "Plounévez\-Lochrist";
$areanames{en}->{3329862} = "Morlaix";
$areanames{en}->{3329863} = "Morlaix";
$areanames{en}->{3329864} = "Quimper";
$areanames{en}->{3329866} = "Pont\-l\'Abbé";
$areanames{en}->{3329868} = "Landivisiau";
$areanames{en}->{3329869} = "Saint\-Pol\-de\-Léon";
$areanames{en}->{3329870} = "Audierne";
$areanames{en}->{3329871} = "Clohars\-Carnoët";
$areanames{en}->{3329872} = "Guerlesquin";
$areanames{en}->{3329874} = "Douarnenez";
$areanames{en}->{3329875} = "Douarnenez";
$areanames{en}->{3329878} = "Pleyber\-Christ";
$areanames{en}->{3329880} = "Brest";
$areanames{en}->{3329881} = "Châteauneuf\-du\-Faou";
$areanames{en}->{3329882} = "Pont\-l\'Abbé";
$areanames{en}->{3329883} = "Lesneven";
$areanames{en}->{3329884} = "Guipavas";
$areanames{en}->{3329885} = "Landerneau";
$areanames{en}->{3329886} = "Chateaulin";
$areanames{en}->{3329887} = "Pont\-l\'Abbé";
$areanames{en}->{3329888} = "Morlaix";
$areanames{en}->{3329890} = "Quimper";
$areanames{en}->{3329891} = "Plozévet";
$areanames{en}->{3329892} = "Douarnenez";
$areanames{en}->{3329893} = "Carhaix\-Plouguer";
$areanames{en}->{3329895} = "Quimper";
$areanames{en}->{3329896} = "Quimperlé";
$areanames{en}->{3329897} = "Concarneau";
$areanames{en}->{3329898} = "Quimper";
$areanames{en}->{3329899} = "Carhaix\-Plouguer";
$areanames{en}->{3329900} = "Châteaubourg";
$areanames{en}->{3329905} = "Bruz";
$areanames{en}->{3329906} = "Montauban\-de\-Bretagne";
$areanames{en}->{3329909} = "Montfort\-sur\-Meu";
$areanames{en}->{3329913} = "Melesse";
$areanames{en}->{3329914} = "Rennes";
$areanames{en}->{3329916} = "Dinard";
$areanames{en}->{3329917} = "Fougères";
$areanames{en}->{3329918} = "Saint\-Brice\-en\-Coglès";
$areanames{en}->{3329919} = "Saint\-Malo";
$areanames{en}->{3329920} = "Saint\-Malo";
$areanames{en}->{3329921} = "Saint\-Malo";
$areanames{en}->{3329922} = "Rennes";
$areanames{en}->{3329923} = "Saint\-Grégoire";
$areanames{en}->{3329926} = "Rennes";
$areanames{en}->{3329927} = "Rennes";
$areanames{en}->{3329929} = "Rennes";
$areanames{en}->{3329930} = "Rennes";
$areanames{en}->{3329931} = "Rennes";
$areanames{en}->{3329932} = "Rennes";
$areanames{en}->{3329933} = "Rennes";
$areanames{en}->{3329935} = "Rennes";
$areanames{en}->{3329936} = "Rennes";
$areanames{en}->{3329937} = "Chateaugiron";
$areanames{en}->{3329938} = "Rennes";
$areanames{en}->{3329939} = "Saint\-Aubin\-du\-Cormier";
$areanames{en}->{3329940} = "Saint\-Malo";
$areanames{en}->{3329941} = "Chantepie";
$areanames{en}->{3329942} = "Laillé";
$areanames{en}->{3329943} = "Bain\-de\-Bretagne";
$areanames{en}->{3329946} = "Dinard";
$areanames{en}->{3329947} = "Janzé";
$areanames{en}->{3329948} = "Dol\-de\-Bretagne";
$areanames{en}->{3329949} = "Val\-d\'Izé";
$areanames{en}->{3329950} = "Rennes";
$areanames{en}->{3329951} = "Rennes";
$areanames{en}->{3329952} = "Bruz";
$areanames{en}->{3329953} = "Rennes";
$areanames{en}->{3329954} = "Rennes";
$areanames{en}->{3329955} = "Betton";
$areanames{en}->{3329956} = "Saint\-Malo";
$areanames{en}->{3329957} = "Guichen";
$areanames{en}->{3329959} = "Rennes";
$areanames{en}->{3329960} = "Pacé";
$areanames{en}->{3329961} = "Plélan\-le\-Grand";
$areanames{en}->{3329962} = "Vern\-sur\-Seiche";
$areanames{en}->{3329963} = "Rennes";
$areanames{en}->{3329964} = "Saint\-Gilles";
$areanames{en}->{3329965} = "Rennes";
$areanames{en}->{3329966} = "Melesse";
$areanames{en}->{3329967} = "Rennes";
$areanames{en}->{3329968} = "Liffré";
$areanames{en}->{3329969} = "Gévezé";
$areanames{en}->{3329970} = "Sixt\-sur\-Aff";
$areanames{en}->{3329971} = "Redon";
$areanames{en}->{3329972} = "Redon";
$areanames{en}->{3329973} = "Combourg";
$areanames{en}->{3329974} = "Vitré";
$areanames{en}->{3329975} = "Vitré";
$areanames{en}->{3329977} = "Chartres\-de\-Bretagne";
$areanames{en}->{3329978} = "Rennes";
$areanames{en}->{3329979} = "Rennes";
$areanames{en}->{3329981} = "Saint\-Malo";
$areanames{en}->{3329982} = "Saint\-Malo";
$areanames{en}->{3329983} = "Cesson\-Sévigné";
$areanames{en}->{3329984} = "Rennes";
$areanames{en}->{3329985} = "Pacé";
$areanames{en}->{3329986} = "Rennes";
$areanames{en}->{3329987} = "Rennes";
$areanames{en}->{3329988} = "Pleurtuit";
$areanames{en}->{3329989} = "Cancale";
$areanames{en}->{3329990} = "Nivillac";
$areanames{en}->{3329992} = "Guignen";
$areanames{en}->{3329993} = "Carentoir";
$areanames{en}->{3329994} = "Fougères";
$areanames{en}->{3329998} = "Louvigné\-du\-Désert";
$areanames{en}->{3329999} = "Fougères";
$areanames{en}->{3331000} = "Reims";
$areanames{en}->{3331001} = "Epernay";
$areanames{en}->{3331002} = "Sainte\-Menehould";
$areanames{en}->{3331003} = "Sézanne";
$areanames{en}->{3331004} = "Troyes";
$areanames{en}->{3331005} = "Vitry\-le\-François";
$areanames{en}->{3331006} = "Vouziers";
$areanames{en}->{3331007} = "Charleville\-Mézières";
$areanames{en}->{3331008} = "Rethel";
$areanames{en}->{3331009} = "Vouziers";
$areanames{en}->{3331010} = "Arcis\-sur\-Aube";
$areanames{en}->{3331011} = "Bar\-sur\-Aube";
$areanames{en}->{3331012} = "Bar\-sur\-Seine";
$areanames{en}->{3331013} = "Romilly\-sur\-Seine";
$areanames{en}->{3331014} = "Châlons\-en\-Champagne";
$areanames{en}->{3331015} = "Epernay";
$areanames{en}->{3331016} = "Reims";
$areanames{en}->{3331017} = "Sainte\-Menehould";
$areanames{en}->{3331018} = "Sézanne";
$areanames{en}->{3331019} = "Vitry\-le\-François";
$areanames{en}->{3331020} = "Chaumont";
$areanames{en}->{3331021} = "Saint\-Dizier";
$areanames{en}->{3331022} = "Châlons\-en\-Champagne";
$areanames{en}->{3331023} = "Charleville\-Mézières";
$areanames{en}->{3331024} = "Chaumont";
$areanames{en}->{3331025} = "Epernay";
$areanames{en}->{3331026} = "Rethel";
$areanames{en}->{3331027} = "Sainte\-Menehould";
$areanames{en}->{3331028} = "Vitry\-le\-François";
$areanames{en}->{3331029} = "Vouziers";
$areanames{en}->{3331030} = "Troyes";
$areanames{en}->{3331031} = "Reims";
$areanames{en}->{3331032} = "Châlons\-en\-Champagne";
$areanames{en}->{3331033} = "Epernay";
$areanames{en}->{3331034} = "Reims";
$areanames{en}->{3331035} = "Vitry\-le\-François";
$areanames{en}->{3331036} = "Reims";
$areanames{en}->{3331037} = "Chaumont";
$areanames{en}->{3331038} = "Rethel";
$areanames{en}->{3331039} = "Vitry\-le\-François";
$areanames{en}->{3331040} = "Charleville\-Mézières";
$areanames{en}->{3331041} = "Epernay";
$areanames{en}->{3331042} = "Châlons\-en\-Champagne";
$areanames{en}->{3331043} = "Charleville\-Mézières";
$areanames{en}->{3331044} = "Chaumont";
$areanames{en}->{3331045} = "Reims";
$areanames{en}->{3331046} = "Vitry\-le\-François";
$areanames{en}->{3331047} = "Vouziers";
$areanames{en}->{3331048} = "Arcis\-sur\-Aube";
$areanames{en}->{3331049} = "Bar\-sur\-Aube";
$areanames{en}->{3331050} = "Epernay";
$areanames{en}->{3331051} = "Reims";
$areanames{en}->{3331052} = "Bar\-sur\-Seine";
$areanames{en}->{3331053} = "Châlons\-en\-Champagne";
$areanames{en}->{3331054} = "Charleville\-Mézières";
$areanames{en}->{3331055} = "Chaumont";
$areanames{en}->{3331056} = "Epernay";
$areanames{en}->{3331057} = "Reims";
$areanames{en}->{3331058} = "Rethel";
$areanames{en}->{3331059} = "Romilly\-sur\-Seine";
$areanames{en}->{3331060} = "Vitry\-le\-François";
$areanames{en}->{3331061} = "Saint\-Dizier";
$areanames{en}->{3331062} = "Sainte\-Menehould";
$areanames{en}->{3331063} = "Sézanne";
$areanames{en}->{3331064} = "Troyes";
$areanames{en}->{3331065} = "Vitry\-le\-François";
$areanames{en}->{3331066} = "Vouziers";
$areanames{en}->{3331067} = "Châlons\-en\-Champagne";
$areanames{en}->{3331068} = "Sézanne";
$areanames{en}->{3331069} = "Saint\-Dizier";
$areanames{en}->{3331070} = "Châlons\-en\-Champagne";
$areanames{en}->{3331071} = "Charleville\-Mézières";
$areanames{en}->{3331072} = "Troyes";
$areanames{en}->{3331073} = "Reims";
$areanames{en}->{3331074} = "Chaumont";
$areanames{en}->{3331075} = "Charleville\-Mézières";
$areanames{en}->{3331076} = "Rethel";
$areanames{en}->{3331077} = "Vouziers";
$areanames{en}->{3331078} = "Arcis\-sur\-Aube";
$areanames{en}->{3331079} = "Bar\-sur\-Aube";
$areanames{en}->{3331080} = "Bar\-sur\-Seine";
$areanames{en}->{3331081} = "Romilly\-sur\-Seine";
$areanames{en}->{3331082} = "Troyes";
$areanames{en}->{3331083} = "Châlons\-en\-Champagne";
$areanames{en}->{3331084} = "Epernay";
$areanames{en}->{3331085} = "Sainte\-Menehould";
$areanames{en}->{3331086} = "Sézanne";
$areanames{en}->{3331087} = "Vitry\-le\-François";
$areanames{en}->{3331088} = "Chaumont";
$areanames{en}->{3331089} = "Saint\-Dizier";
$areanames{en}->{3331090} = "Charleville\-Mézières";
$areanames{en}->{3331091} = "Châlons\-en\-Champagne";
$areanames{en}->{3331092} = "Troyes";
$areanames{en}->{3331093} = "Charleville\-Mézières";
$areanames{en}->{3331094} = "Troyes";
$areanames{en}->{3331095} = "Troyes";
$areanames{en}->{3331096} = "Chaumont";
$areanames{en}->{3331097} = "Troyes";
$areanames{en}->{3331098} = "Epernay";
$areanames{en}->{3331099} = "Reims";
$areanames{en}->{3332001} = "Tourcoing";
$areanames{en}->{3332002} = "Roubaix";
$areanames{en}->{3332003} = "Tourcoing";
$areanames{en}->{3332004} = "Mons\-en\-Barœul";
$areanames{en}->{3332005} = "Villeneuve\-d\'Ascq";
$areanames{en}->{3332006} = "Lille";
$areanames{en}->{3332007} = "Loos";
$areanames{en}->{3332008} = "Pérenchies";
$areanames{en}->{3332009} = "Lomme";
$areanames{en}->{3332011} = "Tourcoing";
$areanames{en}->{3332012} = "Lille";
$areanames{en}->{3332013} = "Lille";
$areanames{en}->{3332014} = "Lille";
$areanames{en}->{3332015} = "Lille";
$areanames{en}->{3332017} = "Lille";
$areanames{en}->{3332018} = "Lille";
$areanames{en}->{3332019} = "Villeneuve\-d\'Ascq";
$areanames{en}->{3332020} = "Roubaix";
$areanames{en}->{3332021} = "Lille";
$areanames{en}->{3332022} = "Lomme";
$areanames{en}->{3332023} = "Bondues";
$areanames{en}->{3332024} = "Tourcoing";
$areanames{en}->{3332025} = "Tourcoing";
$areanames{en}->{3332026} = "Tourcoing";
$areanames{en}->{3332027} = "Tourcoing";
$areanames{en}->{3332028} = "Tourcoing";
$areanames{en}->{3332029} = "La\ Bassée";
$areanames{en}->{3332030} = "Lille";
$areanames{en}->{3332031} = "Lille";
$areanames{en}->{3332032} = "Seclin";
$areanames{en}->{3332033} = "Villeneuve\-d\'Ascq";
$areanames{en}->{3332034} = "Villeneuve\-d\'Ascq";
$areanames{en}->{3332035} = "Armentières";
$areanames{en}->{3332036} = "Tourcoing";
$areanames{en}->{3332039} = "Comines";
$areanames{en}->{3332040} = "Lille";
$areanames{en}->{3332041} = "Villeneuve\-d\'Ascq";
$areanames{en}->{3332042} = "Lille";
$areanames{en}->{3332043} = "Villeneuve\-d\'Ascq";
$areanames{en}->{3332045} = "Roubaix";
$areanames{en}->{3332047} = "Villeneuve\-d\'Ascq";
$areanames{en}->{3332048} = "Nieppe";
$areanames{en}->{3332049} = "Lille";
$areanames{en}->{3332051} = "Lille";
$areanames{en}->{3332052} = "Lille";
$areanames{en}->{3332053} = "Lille";
$areanames{en}->{3332054} = "Lille";
$areanames{en}->{3332055} = "Lille";
$areanames{en}->{3332056} = "Lille";
$areanames{en}->{3332057} = "Lille";
$areanames{en}->{3332058} = "Wavrin";
$areanames{en}->{3332060} = "Wattignies";
$areanames{en}->{3332062} = "Seclin";
$areanames{en}->{3332063} = "Lille";
$areanames{en}->{3332065} = "Marcq\-en\-Barœul";
$areanames{en}->{3332066} = "Roubaix";
$areanames{en}->{3332067} = "Villeneuve\-d\'Ascq";
$areanames{en}->{3332068} = "Tourcoing";
$areanames{en}->{3332069} = "Tourcoing";
$areanames{en}->{3332070} = "Roubaix";
$areanames{en}->{3332071} = "Orchies";
$areanames{en}->{3332072} = "Marcq\-en\-Barœul";
$areanames{en}->{3332073} = "Roubaix";
$areanames{en}->{3332074} = "Lille";
$areanames{en}->{3332075} = "Roubaix";
$areanames{en}->{3332076} = "Tourcoing";
$areanames{en}->{3332077} = "Armentières";
$areanames{en}->{3332078} = "Lille";
$areanames{en}->{3332080} = "Roubaix";
$areanames{en}->{3332081} = "Roubaix";
$areanames{en}->{3332082} = "Roubaix";
$areanames{en}->{3332083} = "Roubaix";
$areanames{en}->{3332085} = "Annœullin";
$areanames{en}->{3332087} = "Lesquin";
$areanames{en}->{3332088} = "Lille";
$areanames{en}->{3332089} = "Marcq\-en\-Barœul";
$areanames{en}->{3332090} = "Seclin";
$areanames{en}->{3332091} = "Villeneuve\-d\'Ascq";
$areanames{en}->{3332092} = "Lomme";
$areanames{en}->{3332093} = "Lille";
$areanames{en}->{3332094} = "Tourcoing";
$areanames{en}->{3332095} = "Wattignies";
$areanames{en}->{3332098} = "Marcq\-en\-Barœul";
$areanames{en}->{3332099} = "Roubaix";
$areanames{en}->{3332100} = "Calais";
$areanames{en}->{3332101} = "Béthune";
$areanames{en}->{3332103} = "Saint\-Pol\-sur\-Ternoise";
$areanames{en}->{3332105} = "Le\ Touquet\ Paris\ Plage";
$areanames{en}->{3332106} = "Montreuil";
$areanames{en}->{3332109} = "Berck\ sur\ Mer";
$areanames{en}->{3332110} = "Boulogne\-sur\-Mer";
$areanames{en}->{3332113} = "Lens";
$areanames{en}->{3332114} = "Lens";
$areanames{en}->{3332115} = "Arras";
$areanames{en}->{3332116} = "Arras";
$areanames{en}->{3332117} = "Calais";
$areanames{en}->{3332119} = "Calais";
$areanames{en}->{3332120} = "Hénin\-Beaumont";
$areanames{en}->{3332121} = "Arras";
$areanames{en}->{3332123} = "Arras";
$areanames{en}->{3332128} = "Lens";
$areanames{en}->{3332129} = "Bully\-les\-Mines";
$areanames{en}->{3332130} = "Boulogne\-sur\-Mer";
$areanames{en}->{3332131} = "Boulogne\-sur\-Mer";
$areanames{en}->{3332134} = "Calais";
$areanames{en}->{3332136} = "Calais";
$areanames{en}->{3332137} = "Carvin";
$areanames{en}->{3332138} = "Saint\-Omer";
$areanames{en}->{3332142} = "Lens";
$areanames{en}->{3332143} = "Lens";
$areanames{en}->{3332144} = "Liévin";
$areanames{en}->{3332145} = "Liévin";
$areanames{en}->{3332146} = "Calais";
$areanames{en}->{3332149} = "Hénin\-Beaumont";
$areanames{en}->{3332151} = "Arras";
$areanames{en}->{3332153} = "Bruay\-la\-Buissière";
$areanames{en}->{3332154} = "Lillers";
$areanames{en}->{3332156} = "Béthune";
$areanames{en}->{3332157} = "Béthune";
$areanames{en}->{3332160} = "Arras";
$areanames{en}->{3332162} = "Bruay\-la\-Buissière";
$areanames{en}->{3332163} = "Béthune";
$areanames{en}->{3332167} = "Lens";
$areanames{en}->{3332168} = "Béthune";
$areanames{en}->{3332169} = "Wingles";
$areanames{en}->{3332170} = "Lens";
$areanames{en}->{3332171} = "Arras";
$areanames{en}->{3332172} = "Liévin";
$areanames{en}->{3332174} = "Carvin";
$areanames{en}->{3332175} = "Hénin\-Beaumont";
$areanames{en}->{3332176} = "Hénin\-Beaumont";
$areanames{en}->{3332177} = "Leforest";
$areanames{en}->{3332178} = "Lens";
$areanames{en}->{3332180} = "Boulogne\-sur\-Mer";
$areanames{en}->{3332185} = "Calais";
$areanames{en}->{3332187} = "Boulogne\-sur\-Mer";
$areanames{en}->{3332188} = "Saint\-Omer";
$areanames{en}->{3332194} = "Étaples";
$areanames{en}->{3332196} = "Calais";
$areanames{en}->{3332197} = "Calais";
$areanames{en}->{3332198} = "Saint\-Omer";
$areanames{en}->{3332199} = "Boulogne\-sur\-Mer";
$areanames{en}->{3332209} = "Moreuil";
$areanames{en}->{3332219} = "Abbeville";
$areanames{en}->{3332220} = "Abbeville";
$areanames{en}->{3332222} = "Amiens";
$areanames{en}->{3332224} = "Abbeville";
$areanames{en}->{3332225} = "Rue";
$areanames{en}->{3332226} = "Cayeux\-sur\-Mer";
$areanames{en}->{3332227} = "Le\ Crotoy";
$areanames{en}->{3332231} = "Abbeville";
$areanames{en}->{3332232} = "Doullens";
$areanames{en}->{3332233} = "Amiens";
$areanames{en}->{3332235} = "Moreuil";
$areanames{en}->{3332241} = "Ailly\-sur\-Noye";
$areanames{en}->{3332243} = "Amiens";
$areanames{en}->{3332244} = "Amiens";
$areanames{en}->{3332245} = "Amiens";
$areanames{en}->{3332246} = "Amiens";
$areanames{en}->{3332247} = "Amiens";
$areanames{en}->{3332248} = "Corbie";
$areanames{en}->{3332249} = "Camon";
$areanames{en}->{333225} = "Amiens";
$areanames{en}->{3332256} = "Nord\ Est";
$areanames{en}->{3332257} = "Nord\ Est";
$areanames{en}->{3332258} = "Nord\ Est";
$areanames{en}->{3332259} = "Nord\ Est";
$areanames{en}->{3332260} = "Saint\-Valery\-sur\-Somme";
$areanames{en}->{3332261} = "Friville\-Escarbotin";
$areanames{en}->{3332266} = "Amiens";
$areanames{en}->{3332270} = "Rivery";
$areanames{en}->{3332271} = "Amiens";
$areanames{en}->{3332272} = "Amiens";
$areanames{en}->{3332274} = "Albert";
$areanames{en}->{3332275} = "Albert";
$areanames{en}->{3332277} = "Doullens";
$areanames{en}->{3332278} = "Montdidier";
$areanames{en}->{3332280} = "Amiens";
$areanames{en}->{3332283} = "Chaulnes";
$areanames{en}->{3332284} = "Péronne";
$areanames{en}->{3332286} = "Roisel";
$areanames{en}->{3332287} = "Roye";
$areanames{en}->{3332288} = "Rosières\-en\-Santerre";
$areanames{en}->{3332289} = "Amiens";
$areanames{en}->{3332291} = "Amiens";
$areanames{en}->{3332292} = "Amiens";
$areanames{en}->{3332294} = "Hangest\-en\-Santerre";
$areanames{en}->{3332295} = "Amiens";
$areanames{en}->{3332296} = "Corbie";
$areanames{en}->{3332297} = "Amiens";
$areanames{en}->{3332304} = "Saint\-Quentin";
$areanames{en}->{3332305} = "Saint\-Quentin";
$areanames{en}->{3332306} = "Saint\-Quentin";
$areanames{en}->{3332307} = "Bohain\-en\-Vermandois";
$areanames{en}->{3332308} = "Saint\-Quentin";
$areanames{en}->{333231} = "Nord\ Est";
$areanames{en}->{333232} = "Laon";
$areanames{en}->{3332336} = "Ham";
$areanames{en}->{3332338} = "Chauny";
$areanames{en}->{3332339} = "Chauny";
$areanames{en}->{3332340} = "Chauny";
$areanames{en}->{3332352} = "Chauny";
$areanames{en}->{3332353} = "Soissons";
$areanames{en}->{3332354} = "Vailly\-sur\-Aisne";
$areanames{en}->{3332356} = "La\ Fère";
$areanames{en}->{3332357} = "Tergnier";
$areanames{en}->{3332358} = "Hirson";
$areanames{en}->{3332359} = "Soissons";
$areanames{en}->{3332361} = "Guise";
$areanames{en}->{3332362} = "Saint\-Quentin";
$areanames{en}->{3332364} = "Saint\-Quentin";
$areanames{en}->{3332365} = "Saint\-Quentin";
$areanames{en}->{3332367} = "Saint\-Quentin";
$areanames{en}->{3332368} = "Saint\-Quentin";
$areanames{en}->{3332369} = "Château\-Thierry";
$areanames{en}->{3332373} = "Soissons";
$areanames{en}->{3332375} = "Soissons";
$areanames{en}->{3332376} = "Soissons";
$areanames{en}->{3332379} = "Laon";
$areanames{en}->{3332381} = "Ham";
$areanames{en}->{3332383} = "Château\-Thierry";
$areanames{en}->{3332384} = "Château\-Thierry";
$areanames{en}->{3332393} = "Soissons";
$areanames{en}->{3332396} = "Villers\-Cotterêts";
$areanames{en}->{333240} = "Nord\ Est";
$areanames{en}->{333241} = "Nord\ Est";
$areanames{en}->{3332427} = "Sedan";
$areanames{en}->{3332429} = "Sedan";
$areanames{en}->{3332433} = "Charleville\-Mézières";
$areanames{en}->{3332436} = "Charleville\-Mézières";
$areanames{en}->{3332437} = "Charleville\-Mézières";
$areanames{en}->{3332438} = "Rethel";
$areanames{en}->{3332439} = "Rethel";
$areanames{en}->{3332440} = "Revin";
$areanames{en}->{3332441} = "Fumay";
$areanames{en}->{3332442} = "Givet";
$areanames{en}->{3332453} = "Nouzonville";
$areanames{en}->{3332455} = "Charleville\-Mézières";
$areanames{en}->{3332456} = "Charleville\-Mézières";
$areanames{en}->{3332457} = "Charleville\-Mézières";
$areanames{en}->{3332458} = "Charleville\-Mézières";
$areanames{en}->{3332459} = "Charleville\-Mézières";
$areanames{en}->{333246} = "Nord\ Est";
$areanames{en}->{3332471} = "Vouziers";
$areanames{en}->{333248} = "Nord\ Est";
$areanames{en}->{333249} = "Nord\ Est";
$areanames{en}->{3332501} = "Chaumont";
$areanames{en}->{3332502} = "Chaumont";
$areanames{en}->{3332503} = "Chaumont";
$areanames{en}->{3332505} = "Saint\-Dizier";
$areanames{en}->{3332506} = "Saint\-Dizier";
$areanames{en}->{3332507} = "Saint\-Dizier";
$areanames{en}->{333251} = "Nord\ Est";
$areanames{en}->{3332524} = "Romilly\-sur\-Seine";
$areanames{en}->{3332525} = "Romilly\-sur\-Seine";
$areanames{en}->{3332527} = "Bar\-sur\-Aube";
$areanames{en}->{3332529} = "Bar\-sur\-Seine";
$areanames{en}->{3332530} = "Chaumont";
$areanames{en}->{3332532} = "Chaumont";
$areanames{en}->{3332535} = "Chaumont";
$areanames{en}->{3332539} = "Nogent\-sur\-Seine";
$areanames{en}->{333254} = "Troyes";
$areanames{en}->{3332544} = "Nord\ Est";
$areanames{en}->{3332547} = "Arcis\-sur\-Aube";
$areanames{en}->{3332548} = "Nord\ Est";
$areanames{en}->{3332556} = "Saint\-Dizier";
$areanames{en}->{333256} = "Nord\ Est";
$areanames{en}->{3332571} = "Troyes";
$areanames{en}->{3332572} = "Troyes";
$areanames{en}->{3332573} = "Troyes";
$areanames{en}->{3332574} = "Troyes";
$areanames{en}->{3332575} = "Troyes";
$areanames{en}->{3332576} = "Troyes";
$areanames{en}->{3332578} = "Troyes";
$areanames{en}->{3332579} = "Sainte\-Savine";
$areanames{en}->{3332580} = "Troyes";
$areanames{en}->{3332581} = "Troyes";
$areanames{en}->{3332582} = "Troyes";
$areanames{en}->{3332583} = "Troyes";
$areanames{en}->{3332587} = "Langres";
$areanames{en}->{3332590} = "Bourbonne\-les\-Bains";
$areanames{en}->{3332594} = "Joinville";
$areanames{en}->{3332600} = "Nord\ Est";
$areanames{en}->{3332601} = "Nord\ Est";
$areanames{en}->{3332602} = "Reims";
$areanames{en}->{3332603} = "Reims";
$areanames{en}->{3332604} = "Reims";
$areanames{en}->{3332605} = "Reims";
$areanames{en}->{3332606} = "Reims";
$areanames{en}->{3332607} = "Reims";
$areanames{en}->{3332608} = "Reims";
$areanames{en}->{3332609} = "Reims";
$areanames{en}->{333261} = "Nord\ Est";
$areanames{en}->{3332610} = "Reims";
$areanames{en}->{3332611} = "Reims";
$areanames{en}->{3332621} = "Châlons\-en\-Champagne";
$areanames{en}->{3332622} = "Châlons\-en\-Champagne";
$areanames{en}->{3332624} = "Reims";
$areanames{en}->{3332626} = "Châlons\-en\-Champagne";
$areanames{en}->{3332632} = "Épernay";
$areanames{en}->{3332635} = "Reims";
$areanames{en}->{3332636} = "Reims";
$areanames{en}->{3332640} = "Reims";
$areanames{en}->{3332641} = "Vitry\-le\-François";
$areanames{en}->{3332646} = "Reims";
$areanames{en}->{3332647} = "Reims";
$areanames{en}->{3332648} = "Fismes";
$areanames{en}->{3332650} = "Reims";
$areanames{en}->{3332651} = "Épernay";
$areanames{en}->{3332652} = "Vertus";
$areanames{en}->{3332654} = "Épernay";
$areanames{en}->{3332655} = "Épernay";
$areanames{en}->{3332656} = "Épernay";
$areanames{en}->{3332660} = "Sainte\-Menehould";
$areanames{en}->{3332662} = "Vitry\-le\-François";
$areanames{en}->{3332664} = "Châlons\-en\-Champagne";
$areanames{en}->{3332665} = "Châlons\-en\-Champagne";
$areanames{en}->{3332668} = "Châlons\-en\-Champagne";
$areanames{en}->{3332669} = "Châlons\-en\-Champagne";
$areanames{en}->{3332670} = "Châlons\-en\-Champagne";
$areanames{en}->{3332674} = "Vitry\-le\-François";
$areanames{en}->{3332677} = "Reims";
$areanames{en}->{3332679} = "Reims";
$areanames{en}->{3332680} = "Sézanne";
$areanames{en}->{3332682} = "Reims";
$areanames{en}->{3332683} = "Reims";
$areanames{en}->{3332684} = "Reims";
$areanames{en}->{3332685} = "Reims";
$areanames{en}->{3332686} = "Reims";
$areanames{en}->{3332687} = "Reims";
$areanames{en}->{3332688} = "Reims";
$areanames{en}->{3332689} = "Reims";
$areanames{en}->{3332691} = "Reims";
$areanames{en}->{3332708} = "Douai";
$areanames{en}->{3332709} = "Valenciennes";
$areanames{en}->{3332714} = "Valenciennes";
$areanames{en}->{3332719} = "Valenciennes";
$areanames{en}->{333272} = "Valenciennes";
$areanames{en}->{3332730} = "Valenciennes";
$areanames{en}->{3332731} = "Denain";
$areanames{en}->{3332732} = "Valenciennes";
$areanames{en}->{3332733} = "Valenciennes";
$areanames{en}->{3332739} = "Jeumont";
$areanames{en}->{3332740} = "Vieux\-Condé";
$areanames{en}->{3332741} = "Valenciennes";
$areanames{en}->{3332742} = "Valenciennes";
$areanames{en}->{3332743} = "Denain";
$areanames{en}->{3332744} = "Denain";
$areanames{en}->{3332745} = "Valenciennes";
$areanames{en}->{3332746} = "Valenciennes";
$areanames{en}->{3332747} = "Valenciennes";
$areanames{en}->{3332748} = "Saint\-Amand\-les\-Eaux";
$areanames{en}->{3332751} = "Valenciennes";
$areanames{en}->{3332753} = "Maubeuge";
$areanames{en}->{3332756} = "Avesnes\-sur\-Helpe";
$areanames{en}->{3332758} = "Maubeuge";
$areanames{en}->{3332760} = "Fourmies";
$areanames{en}->{3332761} = "Avesnes\-sur\-Helpe";
$areanames{en}->{3332762} = "Maubeuge";
$areanames{en}->{3332763} = "Hautmont";
$areanames{en}->{3332764} = "Maubeuge";
$areanames{en}->{3332765} = "Maubeuge";
$areanames{en}->{3332770} = "Cambrai";
$areanames{en}->{3332771} = "Douai";
$areanames{en}->{3332772} = "Cambrai";
$areanames{en}->{3332773} = "Cambrai";
$areanames{en}->{3332774} = "Cambrai";
$areanames{en}->{3332775} = "Caudry";
$areanames{en}->{3332776} = "Caudry";
$areanames{en}->{3332778} = "Cambrai";
$areanames{en}->{3332781} = "Cambrai";
$areanames{en}->{3332782} = "Cambrai";
$areanames{en}->{3332783} = "Cambrai";
$areanames{en}->{3332784} = "Le\ Cateau\ Cambresis";
$areanames{en}->{3332785} = "Caudry";
$areanames{en}->{3332786} = "Somain";
$areanames{en}->{3332787} = "Douai";
$areanames{en}->{3332788} = "Douai";
$areanames{en}->{3332792} = "Aniche";
$areanames{en}->{3332793} = "Douai";
$areanames{en}->{3332794} = "Douai";
$areanames{en}->{3332795} = "Douai";
$areanames{en}->{3332796} = "Douai";
$areanames{en}->{3332797} = "Douai";
$areanames{en}->{3332798} = "Douai";
$areanames{en}->{3332799} = "Douai";
$areanames{en}->{3332804} = "Lille";
$areanames{en}->{3332807} = "Lille";
$areanames{en}->{3332814} = "Lille";
$areanames{en}->{3332816} = "Seclin";
$areanames{en}->{3332820} = "Dunkirk";
$areanames{en}->{3332821} = "Grande\-Synthe";
$areanames{en}->{3332822} = "Bourbourg";
$areanames{en}->{3332823} = "Gravelines";
$areanames{en}->{3332824} = "Dunkirk";
$areanames{en}->{3332825} = "Dunkirk";
$areanames{en}->{3332826} = "Téteghem";
$areanames{en}->{3332828} = "Dunkirk";
$areanames{en}->{3332829} = "Dunkirk";
$areanames{en}->{3332833} = "Roubaix";
$areanames{en}->{3332836} = "Lille";
$areanames{en}->{3332838} = "Lille";
$areanames{en}->{3332841} = "Hazebrouck";
$areanames{en}->{3332844} = "Hazebrouck";
$areanames{en}->{3332849} = "Bailleul";
$areanames{en}->{3332850} = "Bailleul";
$areanames{en}->{3332851} = "Dunkirk";
$areanames{en}->{3332852} = "Lille";
$areanames{en}->{3332853} = "Lille";
$areanames{en}->{3332855} = "Lille";
$areanames{en}->{3332858} = "Dunkirk";
$areanames{en}->{3332859} = "Dunkirk";
$areanames{en}->{3332860} = "Dunkirk";
$areanames{en}->{3332861} = "Dunkirk";
$areanames{en}->{3332863} = "Dunkirk";
$areanames{en}->{3332864} = "Coudekerque\-Branche";
$areanames{en}->{3332865} = "Wormhout";
$areanames{en}->{3332866} = "Dunkirk";
$areanames{en}->{3332868} = "Bergues";
$areanames{en}->{3332869} = "Dunkirk";
$areanames{en}->{333287} = "Nord\ Est";
$areanames{en}->{3332876} = "Lille";
$areanames{en}->{3332877} = "Lille";
$areanames{en}->{333288} = "Nord\ Est";
$areanames{en}->{3332880} = "Lille";
$areanames{en}->{3332881} = "Lille";
$areanames{en}->{3332882} = "Lille";
$areanames{en}->{333289} = "Nord\ Est";
$areanames{en}->{3332890} = "Lille";
$areanames{en}->{3332908} = "Vittel";
$areanames{en}->{333291} = "Nord\ Est";
$areanames{en}->{3332922} = "Remiremont";
$areanames{en}->{3332923} = "Remiremont";
$areanames{en}->{3332925} = "La\ Bresse";
$areanames{en}->{3332929} = "Épinal";
$areanames{en}->{3332930} = "Le\ Val\-d\'Ajol";
$areanames{en}->{3332931} = "Épinal";
$areanames{en}->{3332932} = "Éloyes";
$areanames{en}->{3332933} = "Épinal";
$areanames{en}->{3332934} = "Épinal";
$areanames{en}->{3332935} = "Épinal";
$areanames{en}->{3332937} = "Mirecourt";
$areanames{en}->{3332938} = "Charmes";
$areanames{en}->{3332939} = "Thaon\-les\-Vosges";
$areanames{en}->{3332941} = "Raon\-l\'Étape";
$areanames{en}->{3332942} = "Saint\-Dié\-des\-Vosges";
$areanames{en}->{3332945} = "Bar\-le\-Duc";
$areanames{en}->{3332952} = "Saint\-Dié\-des\-Vosges";
$areanames{en}->{3332955} = "Saint\-Dié\-des\-Vosges";
$areanames{en}->{3332956} = "Saint\-Dié\-des\-Vosges";
$areanames{en}->{3332957} = "Senones";
$areanames{en}->{3332960} = "Gérardmer";
$areanames{en}->{3332962} = "Remiremont";
$areanames{en}->{3332963} = "Gérardmer";
$areanames{en}->{3332964} = "Épinal";
$areanames{en}->{3332965} = "Rambervillers";
$areanames{en}->{3332966} = "Plombières\-les\-Bains";
$areanames{en}->{3332968} = "Épinal";
$areanames{en}->{3332976} = "Bar\-le\-Duc";
$areanames{en}->{3332977} = "Bar\-le\-Duc";
$areanames{en}->{3332978} = "Ligny\-en\-Barrois";
$areanames{en}->{3332979} = "Bar\-le\-Duc";
$areanames{en}->{3332981} = "Épinal";
$areanames{en}->{3332982} = "Épinal";
$areanames{en}->{3332983} = "Verdun";
$areanames{en}->{3332984} = "Verdun";
$areanames{en}->{3332986} = "Verdun";
$areanames{en}->{3332991} = "Commercy";
$areanames{en}->{3332992} = "Commercy";
$areanames{en}->{3332994} = "Neufchâteau";
$areanames{en}->{3333900} = "Lure";
$areanames{en}->{3333901} = "Vesoul";
$areanames{en}->{3333902} = "Belfort";
$areanames{en}->{3333903} = "Belfort";
$areanames{en}->{3333904} = "Dole";
$areanames{en}->{3333905} = "Belfort";
$areanames{en}->{3333906} = "Morteau";
$areanames{en}->{3333907} = "Besançon";
$areanames{en}->{3333908} = "Montbéliard";
$areanames{en}->{3333909} = "Morteau";
$areanames{en}->{3333910} = "Gray";
$areanames{en}->{3333911} = "Morteau";
$areanames{en}->{3333912} = "Pontarlier";
$areanames{en}->{3333913} = "Arbois";
$areanames{en}->{3333914} = "Dole";
$areanames{en}->{3333915} = "Lons\-le\-Saunier";
$areanames{en}->{3333916} = "Saint\-Claude";
$areanames{en}->{3333917} = "Gray";
$areanames{en}->{3333918} = "Lure";
$areanames{en}->{3333919} = "Luxeuil\-les\-Bains";
$areanames{en}->{3333920} = "Vesoul";
$areanames{en}->{3333921} = "Besançon";
$areanames{en}->{3333922} = "Belfort";
$areanames{en}->{3333923} = "Lons\-le\-Saunier";
$areanames{en}->{3333924} = "Vesoul";
$areanames{en}->{3333925} = "Besançon";
$areanames{en}->{3333926} = "Besançon";
$areanames{en}->{3333927} = "Besançon";
$areanames{en}->{3333928} = "Vesoul";
$areanames{en}->{3333929} = "Lons\-le\-Saunier";
$areanames{en}->{3333930} = "Montbéliard";
$areanames{en}->{3333931} = "Dole";
$areanames{en}->{3333932} = "Morteau";
$areanames{en}->{3333933} = "Pontarlier";
$areanames{en}->{3333934} = "Arbois";
$areanames{en}->{3333935} = "Saint\-Claude";
$areanames{en}->{3333936} = "Gray";
$areanames{en}->{3333937} = "Lure";
$areanames{en}->{3333938} = "Luxeuil\-les\-Bains";
$areanames{en}->{3333939} = "Lons\-le\-Saunier";
$areanames{en}->{3333940} = "Besançon";
$areanames{en}->{3333941} = "Besançon";
$areanames{en}->{3333942} = "Dole";
$areanames{en}->{3333943} = "Lons\-le\-Saunier";
$areanames{en}->{3333944} = "Saint\-Claude";
$areanames{en}->{3333945} = "Gray";
$areanames{en}->{3333946} = "Lure";
$areanames{en}->{3333947} = "Luxeuil\-les\-Bains";
$areanames{en}->{3333948} = "Vesoul";
$areanames{en}->{3333949} = "Lons\-le\-Saunier";
$areanames{en}->{3333950} = "Lons\-le\-Saunier";
$areanames{en}->{3333951} = "Vesoul";
$areanames{en}->{3333952} = "Dole";
$areanames{en}->{3333953} = "Belfort";
$areanames{en}->{3333954} = "Lons\-le\-Saunier";
$areanames{en}->{3333970} = "Vesoul";
$areanames{en}->{3333971} = "Lons\-le\-Saunier";
$areanames{en}->{3333972} = "Belfort";
$areanames{en}->{3333973} = "Besançon";
$areanames{en}->{3333974} = "Gray";
$areanames{en}->{3333975} = "Lure";
$areanames{en}->{3333976} = "Luxeuil\-les\-Bains";
$areanames{en}->{3333977} = "Vesoul";
$areanames{en}->{3333978} = "Lons\-le\-Saunier";
$areanames{en}->{3333979} = "Besançon";
$areanames{en}->{3333980} = "Belfort";
$areanames{en}->{3333981} = "Dole";
$areanames{en}->{3333982} = "Vesoul";
$areanames{en}->{3333983} = "Belfort";
$areanames{en}->{3333984} = "Montbéliard";
$areanames{en}->{3333985} = "Morteau";
$areanames{en}->{3333986} = "Pontarlier";
$areanames{en}->{3333987} = "Arbois";
$areanames{en}->{3333988} = "Besançon";
$areanames{en}->{3333989} = "Besançon";
$areanames{en}->{3333990} = "Belfort";
$areanames{en}->{3333991} = "Besançon";
$areanames{en}->{3333992} = "Montbéliard";
$areanames{en}->{3333993} = "Morteau";
$areanames{en}->{3333994} = "Pontarlier";
$areanames{en}->{3333995} = "Arbois";
$areanames{en}->{3333996} = "Dole";
$areanames{en}->{3333997} = "Lons\-le\-Saunier";
$areanames{en}->{3333998} = "Saint\-Claude";
$areanames{en}->{3333999} = "Belfort";
$areanames{en}->{3334402} = "Beauvais";
$areanames{en}->{3334403} = "Noailles";
$areanames{en}->{3334405} = "Beauvais";
$areanames{en}->{3334406} = "Beauvais";
$areanames{en}->{3334407} = "Bresles";
$areanames{en}->{3334409} = "Noyon";
$areanames{en}->{3334410} = "Beauvais";
$areanames{en}->{3334411} = "Beauvais";
$areanames{en}->{3334412} = "Beauvais";
$areanames{en}->{3334414} = "Beauvais";
$areanames{en}->{3334415} = "Beauvais";
$areanames{en}->{3334420} = "Compiègne";
$areanames{en}->{3334421} = "Lamorlaye";
$areanames{en}->{3334422} = "Méru";
$areanames{en}->{3334423} = "Compiègne";
$areanames{en}->{3334424} = "Creil";
$areanames{en}->{3334425} = "Creil";
$areanames{en}->{3334426} = "Neuilly\-en\-Thelle";
$areanames{en}->{3334427} = "Précy\-sur\-Oise";
$areanames{en}->{3334428} = "Creil";
$areanames{en}->{3334429} = "Saint\-Martin\-Longueau";
$areanames{en}->{3334430} = "Compiègne";
$areanames{en}->{3334431} = "Pont\-Sainte\-Maxence";
$areanames{en}->{3334432} = "Senlis";
$areanames{en}->{3334436} = "Compiègne";
$areanames{en}->{3334437} = "Jaux";
$areanames{en}->{3334438} = "Compiègne";
$areanames{en}->{3334439} = "Crépy\-en\-Valois";
$areanames{en}->{3334440} = "Compiègne";
$areanames{en}->{3334444} = "Noyon";
$areanames{en}->{3334445} = "Beauvais";
$areanames{en}->{3334447} = "Auneuil";
$areanames{en}->{3334448} = "Beauvais";
$areanames{en}->{3334449} = "Chaumont\-en\-Vexin";
$areanames{en}->{3334450} = "Clermont";
$areanames{en}->{3334452} = "Méru";
$areanames{en}->{3334453} = "Senlis";
$areanames{en}->{3334455} = "Creil";
$areanames{en}->{3334456} = "Saint\-Leu\-d\'Esserent";
$areanames{en}->{3334457} = "Chantilly";
$areanames{en}->{3334458} = "Chantilly";
$areanames{en}->{3334459} = "Crépy\-en\-Valois";
$areanames{en}->{3334460} = "Senlis";
$areanames{en}->{3334462} = "Chantilly";
$areanames{en}->{3334463} = "Senlis";
$areanames{en}->{3334464} = "Creil";
$areanames{en}->{3334466} = "Nogent\-sur\-Oise";
$areanames{en}->{3334470} = "Pont\-Sainte\-Maxence";
$areanames{en}->{3334471} = "Nogent\-sur\-Oise";
$areanames{en}->{3334472} = "Pont\-Sainte\-Maxence";
$areanames{en}->{3334473} = "Liancourt";
$areanames{en}->{3334474} = "Nogent\-sur\-Oise";
$areanames{en}->{3334476} = "Thourotte";
$areanames{en}->{3334478} = "Saint\-Just\-en\-Chaussée";
$areanames{en}->{3334479} = "Troissereux";
$areanames{en}->{3334483} = "Margny\-lès\-Compiègne";
$areanames{en}->{3334486} = "Compiègne";
$areanames{en}->{3334487} = "Crépy\-en\-Valois";
$areanames{en}->{3334488} = "Nanteuil\-le\-Haudouin";
$areanames{en}->{3334490} = "Compiègne";
$areanames{en}->{3334491} = "La\ Croix\-Saint\-Ouen";
$areanames{en}->{3334493} = "Noyon";
$areanames{en}->{3334494} = "Crépy\-en\-Valois";
$areanames{en}->{3334496} = "Thourotte";
$areanames{en}->{3334497} = "Compiègne";
$areanames{en}->{3334500} = "Autun";
$areanames{en}->{3334501} = "Chalon\-sur\-Saône";
$areanames{en}->{3334502} = "Auxerre";
$areanames{en}->{3334503} = "Louhans";
$areanames{en}->{3334504} = "Beaune";
$areanames{en}->{3334505} = "Mâcon";
$areanames{en}->{3334506} = "Montceau\-les\-Mines";
$areanames{en}->{3334507} = "Paray\-le\-Monial";
$areanames{en}->{3334508} = "Dijon";
$areanames{en}->{3334509} = "Dijon";
$areanames{en}->{3334510} = "Auxerre";
$areanames{en}->{3334511} = "Is\-sur\-Tille";
$areanames{en}->{3334512} = "Joigny";
$areanames{en}->{3334513} = "Sens";
$areanames{en}->{3334514} = "Tonnerre";
$areanames{en}->{3334515} = "Toucy";
$areanames{en}->{3334516} = "Dijon";
$areanames{en}->{3334517} = "Châtillon\-sur\-Seine";
$areanames{en}->{3334518} = "Dijon";
$areanames{en}->{3334519} = "Is\-sur\-Tille";
$areanames{en}->{3334520} = "Montbard";
$areanames{en}->{3334521} = "Dijon";
$areanames{en}->{3334522} = "Châtillon\-sur\-Seine";
$areanames{en}->{3334523} = "Château\-Chinon\(Ville\)";
$areanames{en}->{3334524} = "Cosne\-Cours\-sur\-Loire";
$areanames{en}->{3334525} = "Decize";
$areanames{en}->{3334526} = "Nevers";
$areanames{en}->{3334527} = "Autun";
$areanames{en}->{3334528} = "Chalon\-sur\-Saône";
$areanames{en}->{3334529} = "Dijon";
$areanames{en}->{3334530} = "Mâcon";
$areanames{en}->{3334531} = "Montceau\-les\-Mines";
$areanames{en}->{3334532} = "Paray\-le\-Monial";
$areanames{en}->{3334533} = "Montbard";
$areanames{en}->{3334534} = "Dijon";
$areanames{en}->{3334535} = "Auxerre";
$areanames{en}->{3334536} = "Joigny";
$areanames{en}->{3334537} = "Sens";
$areanames{en}->{3334538} = "Tonnerre";
$areanames{en}->{3334539} = "Toucy";
$areanames{en}->{3334540} = "Saulieu";
$areanames{en}->{3334541} = "Beaune";
$areanames{en}->{3334542} = "Dijon";
$areanames{en}->{3334543} = "Dijon";
$areanames{en}->{3334544} = "Saulieu";
$areanames{en}->{3334545} = "Auxerre";
$areanames{en}->{3334546} = "Beaune";
$areanames{en}->{3334547} = "Mâcon";
$areanames{en}->{3334548} = "Montceau\-les\-Mines";
$areanames{en}->{3334549} = "Dijon";
$areanames{en}->{3334550} = "Cosne\-Cours\-sur\-Loire";
$areanames{en}->{3334551} = "Chalon\-sur\-Saône";
$areanames{en}->{3334552} = "Nevers";
$areanames{en}->{3334553} = "Paray\-le\-Monial";
$areanames{en}->{3334554} = "Sens";
$areanames{en}->{3334555} = "Autun";
$areanames{en}->{3334556} = "Beaune";
$areanames{en}->{3334557} = "Dijon";
$areanames{en}->{3334558} = "Dijon";
$areanames{en}->{3334559} = "Beaune";
$areanames{en}->{3334560} = "Dijon";
$areanames{en}->{3334561} = "Dijon";
$areanames{en}->{3334562} = "Dijon";
$areanames{en}->{3334563} = "Beaune";
$areanames{en}->{3334564} = "Nevers";
$areanames{en}->{3334565} = "Châtillon\-sur\-Seine";
$areanames{en}->{3334566} = "Chalon\-sur\-Saône";
$areanames{en}->{3334567} = "Is\-sur\-Tille";
$areanames{en}->{3334568} = "Mâcon";
$areanames{en}->{3334569} = "Montceau\-les\-Mines";
$areanames{en}->{3334570} = "Paray\-le\-Monial";
$areanames{en}->{3334571} = "Auxerre";
$areanames{en}->{3334572} = "Joigny";
$areanames{en}->{3334573} = "Sens";
$areanames{en}->{3334574} = "Autun";
$areanames{en}->{3334575} = "Auxerre";
$areanames{en}->{3334576} = "Beaune";
$areanames{en}->{3334577} = "Chalon\-sur\-Saône";
$areanames{en}->{3334578} = "Château\-Chinon\(Ville\)";
$areanames{en}->{3334579} = "Châtillon\-sur\-Seine";
$areanames{en}->{3334580} = "Cosne\-Cours\-sur\-Loire";
$areanames{en}->{3334581} = "Dijon";
$areanames{en}->{3334582} = "Decize";
$areanames{en}->{3334583} = "Dijon";
$areanames{en}->{3334584} = "Is\-sur\-Tille";
$areanames{en}->{3334585} = "Joigny";
$areanames{en}->{3334586} = "Louhans";
$areanames{en}->{3334587} = "Mâcon";
$areanames{en}->{3334588} = "Joigny";
$areanames{en}->{3334589} = "Auxerre";
$areanames{en}->{3334590} = "Beaune";
$areanames{en}->{3334591} = "Châtillon\-sur\-Seine";
$areanames{en}->{3334592} = "Is\-sur\-Tille";
$areanames{en}->{3334593} = "Montbard";
$areanames{en}->{3334594} = "Saulieu";
$areanames{en}->{3334595} = "Dijon";
$areanames{en}->{3334596} = "Château\-Chinon\(Ville\)";
$areanames{en}->{3334597} = "Cosne\-Cours\-sur\-Loire";
$areanames{en}->{3334598} = "Decize";
$areanames{en}->{3334599} = "Nevers";
$areanames{en}->{3335100} = "Reims";
$areanames{en}->{3335101} = "Reims";
$areanames{en}->{3335102} = "Epernay";
$areanames{en}->{3335103} = "Sainte\-Menehould";
$areanames{en}->{3335104} = "Sézanne";
$areanames{en}->{3335105} = "Vitry\-le\-François";
$areanames{en}->{3335106} = "Chaumont";
$areanames{en}->{3335107} = "Saint\-Dizier";
$areanames{en}->{3335108} = "Reims";
$areanames{en}->{3335109} = "Charleville\-Mézières";
$areanames{en}->{3335110} = "Rethel";
$areanames{en}->{3335111} = "Vouziers";
$areanames{en}->{3335112} = "Reims";
$areanames{en}->{3335113} = "Charleville\-Mézières";
$areanames{en}->{3335114} = "Troyes";
$areanames{en}->{3335115} = "Châlons\-en\-Champagne";
$areanames{en}->{3335116} = "Charleville\-Mézières";
$areanames{en}->{3335117} = "Arcis\-sur\-Aube";
$areanames{en}->{3335118} = "Bar\-sur\-Aube";
$areanames{en}->{3335119} = "Romilly\-sur\-Seine";
$areanames{en}->{3335120} = "Romilly\-sur\-Seine";
$areanames{en}->{3335121} = "Troyes";
$areanames{en}->{3335122} = "Châlons\-en\-Champagne";
$areanames{en}->{3335123} = "Epernay";
$areanames{en}->{3335124} = "Reims";
$areanames{en}->{3335125} = "Reims";
$areanames{en}->{3335126} = "Sézanne";
$areanames{en}->{3335127} = "Vitry\-le\-François";
$areanames{en}->{3335128} = "Chaumont";
$areanames{en}->{3335129} = "Saint\-Dizier";
$areanames{en}->{3335130} = "Reims";
$areanames{en}->{3335131} = "Reims";
$areanames{en}->{3335132} = "Arcis\-sur\-Aube";
$areanames{en}->{3335133} = "Troyes";
$areanames{en}->{3335134} = "Bar\-sur\-Aube";
$areanames{en}->{3335135} = "Troyes";
$areanames{en}->{3335136} = "Bar\-sur\-Seine";
$areanames{en}->{3335137} = "Châlons\-en\-Champagne";
$areanames{en}->{3335138} = "Charleville\-Mézières";
$areanames{en}->{3335139} = "Chaumont";
$areanames{en}->{3335140} = "Epernay";
$areanames{en}->{3335141} = "Châlons\-en\-Champagne";
$areanames{en}->{3335142} = "Reims";
$areanames{en}->{3335143} = "Rethel";
$areanames{en}->{3335144} = "Romilly\-sur\-Seine";
$areanames{en}->{3335145} = "Saint\-Dizier";
$areanames{en}->{3335146} = "Sainte\-Menehould";
$areanames{en}->{3335147} = "Sézanne";
$areanames{en}->{3335148} = "Troyes";
$areanames{en}->{3335149} = "Vitry\-le\-François";
$areanames{en}->{3335150} = "Vouziers";
$areanames{en}->{3335151} = "Charleville\-Mézières";
$areanames{en}->{3335152} = "Rethel";
$areanames{en}->{3335153} = "Troyes";
$areanames{en}->{3335154} = "Vitry\-le\-François";
$areanames{en}->{3335155} = "Chaumont";
$areanames{en}->{3335156} = "Reims";
$areanames{en}->{3335157} = "Reims";
$areanames{en}->{3335158} = "Saint\-Dizier";
$areanames{en}->{3335159} = "Troyes";
$areanames{en}->{3335160} = "Vouziers";
$areanames{en}->{3335161} = "Epernay";
$areanames{en}->{3335162} = "Arcis\-sur\-Aube";
$areanames{en}->{3335163} = "Bar\-sur\-Seine";
$areanames{en}->{3335164} = "Romilly\-sur\-Seine";
$areanames{en}->{3335165} = "Troyes";
$areanames{en}->{3335166} = "Arcis\-sur\-Aube";
$areanames{en}->{3335167} = "Epernay";
$areanames{en}->{3335168} = "Reims";
$areanames{en}->{3335169} = "Sainte\-Menehould";
$areanames{en}->{3335170} = "Sézanne";
$areanames{en}->{3335171} = "Vitry\-le\-François";
$areanames{en}->{3335172} = "Bar\-sur\-Aube";
$areanames{en}->{3335173} = "Saint\-Dizier";
$areanames{en}->{3335174} = "Charleville\-Mézières";
$areanames{en}->{3335175} = "Bar\-sur\-Seine";
$areanames{en}->{3335176} = "Vouziers";
$areanames{en}->{3335177} = "Châlons\-en\-Champagne";
$areanames{en}->{3335178} = "Châlons\-en\-Champagne";
$areanames{en}->{3335179} = "Charleville\-Mézières";
$areanames{en}->{3335180} = "Charleville\-Mézières";
$areanames{en}->{3335181} = "Bar\-sur\-Aube";
$areanames{en}->{3335182} = "Chaumont";
$areanames{en}->{3335183} = "Chaumont";
$areanames{en}->{3335184} = "Troyes";
$areanames{en}->{3335185} = "Reims";
$areanames{en}->{3335186} = "Rethel";
$areanames{en}->{3335187} = "Romilly\-sur\-Seine";
$areanames{en}->{3335188} = "Charleville\-Mézières";
$areanames{en}->{3335189} = "Saint\-Dizier";
$areanames{en}->{3335190} = "Charleville\-Mézières";
$areanames{en}->{3335191} = "Rethel";
$areanames{en}->{3335192} = "Vouziers";
$areanames{en}->{3335193} = "Arcis\-sur\-Aube";
$areanames{en}->{3335194} = "Bar\-sur\-Aube";
$areanames{en}->{3335195} = "Reims";
$areanames{en}->{3335196} = "Bar\-sur\-Seine";
$areanames{en}->{3335197} = "Romilly\-sur\-Seine";
$areanames{en}->{3335198} = "Troyes";
$areanames{en}->{3335199} = "Châlons\-en\-Champagne";
$areanames{en}->{3335200} = "Châlons\-en\-Champagne";
$areanames{en}->{3335201} = "Vitry\-le\-François";
$areanames{en}->{3335202} = "Reims";
$areanames{en}->{3335203} = "Reims";
$areanames{en}->{3335204} = "Charleville\-Mézières";
$areanames{en}->{3335205} = "Romilly\-sur\-Seine";
$areanames{en}->{3335206} = "Bar\-sur\-Seine";
$areanames{en}->{3335207} = "Saint\-Dizier";
$areanames{en}->{3335208} = "Rethel";
$areanames{en}->{3335209} = "Chaumont";
$areanames{en}->{3335210} = "Rethel";
$areanames{en}->{3335211} = "Arcis\-sur\-Aube";
$areanames{en}->{3335212} = "Bar\-sur\-Aube";
$areanames{en}->{3335213} = "Bar\-sur\-Seine";
$areanames{en}->{3335214} = "Romilly\-sur\-Seine";
$areanames{en}->{3335215} = "Reims";
$areanames{en}->{3335216} = "Sainte\-Menehould";
$areanames{en}->{3335217} = "Sézanne";
$areanames{en}->{3335218} = "Chaumont";
$areanames{en}->{3335219} = "Bar\-sur\-Aube";
$areanames{en}->{3335220} = "Châlons\-en\-Champagne";
$areanames{en}->{3335221} = "Arcis\-sur\-Aube";
$areanames{en}->{3335222} = "Sainte\-Menehould";
$areanames{en}->{3335223} = "Vitry\-le\-François";
$areanames{en}->{3335224} = "Vouziers";
$areanames{en}->{3335225} = "Sézanne";
$areanames{en}->{3335226} = "Troyes";
$areanames{en}->{3335227} = "Epernay";
$areanames{en}->{3335228} = "Charleville\-Mézières";
$areanames{en}->{3335229} = "Rethel";
$areanames{en}->{3335230} = "Vouziers";
$areanames{en}->{3335231} = "Arcis\-sur\-Aube";
$areanames{en}->{3335232} = "Bar\-sur\-Aube";
$areanames{en}->{3335233} = "Bar\-sur\-Seine";
$areanames{en}->{3335234} = "Romilly\-sur\-Seine";
$areanames{en}->{3335235} = "Troyes";
$areanames{en}->{3335236} = "Châlons\-en\-Champagne";
$areanames{en}->{3335237} = "Epernay";
$areanames{en}->{3335238} = "Reims";
$areanames{en}->{3335239} = "Sainte\-Menehould";
$areanames{en}->{3335240} = "Sézanne";
$areanames{en}->{3335241} = "Vitry\-le\-François";
$areanames{en}->{3335242} = "Chaumont";
$areanames{en}->{3335243} = "Saint\-Dizier";
$areanames{en}->{3335244} = "Reims";
$areanames{en}->{3335245} = "Reims";
$areanames{en}->{3335246} = "Arcis\-sur\-Aube";
$areanames{en}->{3335247} = "Bar\-sur\-Aube";
$areanames{en}->{3335248} = "Bar\-sur\-Seine";
$areanames{en}->{3335249} = "Romilly\-sur\-Seine";
$areanames{en}->{3335250} = "Sézanne";
$areanames{en}->{3335251} = "Saint\-Dizier";
$areanames{en}->{3335252} = "Troyes";
$areanames{en}->{3335253} = "Romilly\-sur\-Seine";
$areanames{en}->{3335254} = "Troyes";
$areanames{en}->{3335255} = "Châlons\-en\-Champagne";
$areanames{en}->{3335256} = "Chaumont";
$areanames{en}->{3335257} = "Rethel";
$areanames{en}->{3335258} = "Vouziers";
$areanames{en}->{3335259} = "Troyes";
$areanames{en}->{3335260} = "Charleville\-Mézières";
$areanames{en}->{3335261} = "Rethel";
$areanames{en}->{3335262} = "Reims";
$areanames{en}->{3335263} = "Châlons\-en\-Champagne";
$areanames{en}->{3335264} = "Epernay";
$areanames{en}->{3335265} = "Reims";
$areanames{en}->{3335266} = "Sainte\-Menehould";
$areanames{en}->{3335267} = "Sézanne";
$areanames{en}->{3335268} = "Vitry\-le\-François";
$areanames{en}->{3335269} = "Chaumont";
$areanames{en}->{3335270} = "Saint\-Dizier";
$areanames{en}->{3335271} = "Chaumont";
$areanames{en}->{3335272} = "Charleville\-Mézières";
$areanames{en}->{3335273} = "Troyes";
$areanames{en}->{3335274} = "Reims";
$areanames{en}->{3335275} = "Troyes";
$areanames{en}->{3335276} = "Charleville\-Mézières";
$areanames{en}->{3335277} = "Châlons\-en\-Champagne";
$areanames{en}->{3335278} = "Châlons\-en\-Champagne";
$areanames{en}->{3335279} = "Reims";
$areanames{en}->{3335280} = "Troyes";
$areanames{en}->{3335281} = "Troyes";
$areanames{en}->{3335282} = "Reims";
$areanames{en}->{3335283} = "Châlons\-en\-Champagne";
$areanames{en}->{3335284} = "Reims";
$areanames{en}->{3335285} = "Epernay";
$areanames{en}->{3335286} = "Saint\-Dizier";
$areanames{en}->{3335287} = "Rethel";
$areanames{en}->{3335288} = "Charleville\-Mézières";
$areanames{en}->{3335289} = "Rethel";
$areanames{en}->{3335290} = "Charleville\-Mézières";
$areanames{en}->{3335291} = "Reims";
$areanames{en}->{3335292} = "Saint\-Dizier";
$areanames{en}->{3335293} = "Vouziers";
$areanames{en}->{3335294} = "Arcis\-sur\-Aube";
$areanames{en}->{3335295} = "Bar\-sur\-Aube";
$areanames{en}->{3335296} = "Bar\-sur\-Seine";
$areanames{en}->{3335297} = "Sainte\-Menehould";
$areanames{en}->{3335298} = "Sézanne";
$areanames{en}->{3335299} = "Vitry\-le\-François";
$areanames{en}->{3335300} = "Troyes";
$areanames{en}->{3335302} = "Vouziers";
$areanames{en}->{3335303} = "Arcis\-sur\-Aube";
$areanames{en}->{3335304} = "Bar\-sur\-Aube";
$areanames{en}->{3335305} = "Bar\-sur\-Seine";
$areanames{en}->{3335306} = "Romilly\-sur\-Seine";
$areanames{en}->{3335307} = "Epernay";
$areanames{en}->{3335308} = "Sainte\-Menehould";
$areanames{en}->{3335309} = "Sézanne";
$areanames{en}->{3335310} = "Vitry\-le\-François";
$areanames{en}->{3335311} = "Chaumont";
$areanames{en}->{3335312} = "Saint\-Dizier";
$areanames{en}->{3335313} = "Reims";
$areanames{en}->{3335314} = "Châlons\-en\-Champagne";
$areanames{en}->{3335315} = "Troyes";
$areanames{en}->{3335316} = "Charleville\-Mézières";
$areanames{en}->{3335317} = "Vouziers";
$areanames{en}->{3335318} = "Arcis\-sur\-Aube";
$areanames{en}->{3335319} = "Châlons\-en\-Champagne";
$areanames{en}->{3335320} = "Epernay";
$areanames{en}->{3335321} = "Sézanne";
$areanames{en}->{3335322} = "Saint\-Dizier";
$areanames{en}->{3335323} = "Chaumont";
$areanames{en}->{3335324} = "Reims";
$areanames{en}->{3335325} = "Bar\-sur\-Aube";
$areanames{en}->{3335326} = "Bar\-sur\-Seine";
$areanames{en}->{3335327} = "Vitry\-le\-François";
$areanames{en}->{3335328} = "Reims";
$areanames{en}->{3335329} = "Romilly\-sur\-Seine";
$areanames{en}->{3335330} = "Sainte\-Menehould";
$areanames{en}->{3335331} = "Troyes";
$areanames{en}->{3335332} = "Reims";
$areanames{en}->{3335333} = "Charleville\-Mézières";
$areanames{en}->{3335334} = "Rethel";
$areanames{en}->{3335335} = "Vouziers";
$areanames{en}->{3335336} = "Arcis\-sur\-Aube";
$areanames{en}->{3335337} = "Bar\-sur\-Aube";
$areanames{en}->{3335338} = "Bar\-sur\-Seine";
$areanames{en}->{3335339} = "Romilly\-sur\-Seine";
$areanames{en}->{3335340} = "Châlons\-en\-Champagne";
$areanames{en}->{3335341} = "Epernay";
$areanames{en}->{3335342} = "Reims";
$areanames{en}->{3335343} = "Sainte\-Menehould";
$areanames{en}->{3335344} = "Sézanne";
$areanames{en}->{3335345} = "Vitry\-le\-François";
$areanames{en}->{3335346} = "Chaumont";
$areanames{en}->{3335347} = "Saint\-Dizier";
$areanames{en}->{3335348} = "Reims";
$areanames{en}->{3335349} = "Reims";
$areanames{en}->{3335350} = "Troyes";
$areanames{en}->{3335400} = "Nancy";
$areanames{en}->{3335401} = "Saint\-Avold";
$areanames{en}->{3335402} = "Bar\-le\-Duc";
$areanames{en}->{3335403} = "Toul";
$areanames{en}->{3335404} = "Épinal";
$areanames{en}->{3335405} = "Sarrebourg";
$areanames{en}->{3335406} = "Sarreguemines";
$areanames{en}->{3335407} = "Thionville";
$areanames{en}->{3335408} = "Épinal";
$areanames{en}->{3335409} = "Neufchâteau";
$areanames{en}->{3335412} = "Nancy";
$areanames{en}->{3335420} = "Verdun";
$areanames{en}->{3335421} = "Metz";
$areanames{en}->{3335422} = "Metz";
$areanames{en}->{3335423} = "Morhange";
$areanames{en}->{3335424} = "Lunéville";
$areanames{en}->{3335425} = "Sarrebourg";
$areanames{en}->{3335426} = "Saint\-Dié\-des\-Vosges";
$areanames{en}->{3335427} = "Saint\-Avold";
$areanames{en}->{3335428} = "Sarrebourg";
$areanames{en}->{3335429} = "Sarreguemines";
$areanames{en}->{3335430} = "Thionville";
$areanames{en}->{3335431} = "Épinal";
$areanames{en}->{3335432} = "Pont\-à\-Mousson";
$areanames{en}->{3335433} = "Neufchâteau";
$areanames{en}->{3335434} = "Vittel";
$areanames{en}->{3335435} = "Remiremont";
$areanames{en}->{3335436} = "Saint\-Dié\-des\-Vosges";
$areanames{en}->{3335437} = "Vittel";
$areanames{en}->{3335438} = "Bar\-le\-Duc";
$areanames{en}->{3335439} = "Saint\-Dié\-des\-Vosges";
$areanames{en}->{3335440} = "Nancy";
$areanames{en}->{3335441} = "Thionville";
$areanames{en}->{3335442} = "Briey";
$areanames{en}->{3335443} = "Épinal";
$areanames{en}->{3335444} = "Metz";
$areanames{en}->{3335445} = "Lunéville";
$areanames{en}->{3335446} = "Sarrebourg";
$areanames{en}->{3335447} = "Lunéville";
$areanames{en}->{3335448} = "Metz";
$areanames{en}->{3335449} = "Morhange";
$areanames{en}->{3335450} = "Nancy";
$areanames{en}->{3335451} = "Nancy";
$areanames{en}->{3335452} = "Neufchâteau";
$areanames{en}->{3335453} = "Morhange";
$areanames{en}->{3335454} = "Thionville";
$areanames{en}->{3335455} = "Épinal";
$areanames{en}->{3335456} = "Briey";
$areanames{en}->{3335457} = "Lunéville";
$areanames{en}->{3335458} = "Nancy";
$areanames{en}->{3335459} = "Nancy";
$areanames{en}->{3335462} = "Metz";
$areanames{en}->{3335470} = "Remiremont";
$areanames{en}->{3335471} = "Thionville";
$areanames{en}->{3335472} = "Épinal";
$areanames{en}->{3335473} = "Metz";
$areanames{en}->{3335474} = "Remiremont";
$areanames{en}->{3335475} = "Saint\-Dié\-des\-Vosges";
$areanames{en}->{3335476} = "Nancy";
$areanames{en}->{3335477} = "Morhange";
$areanames{en}->{3335478} = "Saint\-Avold";
$areanames{en}->{3335479} = "Pont\-à\-Mousson";
$areanames{en}->{3335480} = "Remiremont";
$areanames{en}->{3335481} = "Saint\-Avold";
$areanames{en}->{3335482} = "Saint\-Dié\-des\-Vosges";
$areanames{en}->{3335483} = "Sarrebourg";
$areanames{en}->{3335484} = "Metz";
$areanames{en}->{3335485} = "Sarreguemines";
$areanames{en}->{3335486} = "Thionville";
$areanames{en}->{3335487} = "Toul";
$areanames{en}->{3335488} = "Sarreguemines";
$areanames{en}->{3335489} = "Nancy";
$areanames{en}->{3335490} = "Briey";
$areanames{en}->{3335491} = "Lunéville";
$areanames{en}->{3335492} = "Nancy";
$areanames{en}->{3335493} = "Pont\-à\-Mousson";
$areanames{en}->{3335494} = "Toul";
$areanames{en}->{3335495} = "Nancy";
$areanames{en}->{3335496} = "Bar\-le\-Duc";
$areanames{en}->{3335497} = "Verdun";
$areanames{en}->{3335498} = "Metz";
$areanames{en}->{3335499} = "Morhange";
$areanames{en}->{3335500} = "Metz";
$areanames{en}->{3335501} = "Neufchâteau";
$areanames{en}->{3335502} = "Nancy";
$areanames{en}->{3335503} = "Sarreguemines";
$areanames{en}->{3335504} = "Pont\-à\-Mousson";
$areanames{en}->{3335505} = "Briey";
$areanames{en}->{3335506} = "Lunéville";
$areanames{en}->{3335507} = "Pont\-à\-Mousson";
$areanames{en}->{3335508} = "Toul";
$areanames{en}->{3335509} = "Verdun";
$areanames{en}->{3335510} = "Nancy";
$areanames{en}->{3335511} = "Metz";
$areanames{en}->{3335512} = "Bar\-le\-Duc";
$areanames{en}->{3335513} = "Verdun";
$areanames{en}->{3335514} = "Morhange";
$areanames{en}->{3335515} = "Saint\-Avold";
$areanames{en}->{3335516} = "Sarrebourg";
$areanames{en}->{3335517} = "Sarreguemines";
$areanames{en}->{3335518} = "Thionville";
$areanames{en}->{3335519} = "Épinal";
$areanames{en}->{3335520} = "Nancy";
$areanames{en}->{3335521} = "Neufchâteau";
$areanames{en}->{3335522} = "Remiremont";
$areanames{en}->{3335523} = "Saint\-Dié\-des\-Vosges";
$areanames{en}->{3335524} = "Vittel";
$areanames{en}->{3335525} = "Bar\-le\-Duc";
$areanames{en}->{3335526} = "Briey";
$areanames{en}->{3335527} = "Épinal";
$areanames{en}->{3335528} = "Morhange";
$areanames{en}->{3335529} = "Pont\-à\-Mousson";
$areanames{en}->{3335530} = "Nancy";
$areanames{en}->{3335531} = "Remiremont";
$areanames{en}->{3335532} = "Toul";
$areanames{en}->{3335533} = "Nancy";
$areanames{en}->{3335534} = "Saint\-Avold";
$areanames{en}->{3335535} = "Metz";
$areanames{en}->{3335536} = "Sarreguemines";
$areanames{en}->{3335537} = "Sarrebourg";
$areanames{en}->{3335538} = "Metz";
$areanames{en}->{3335539} = "Morhange";
$areanames{en}->{3335540} = "Nancy";
$areanames{en}->{3335541} = "Neufchâteau";
$areanames{en}->{3335542} = "Pont\-à\-Mousson";
$areanames{en}->{3335543} = "Remiremont";
$areanames{en}->{3335544} = "Saint\-Avold";
$areanames{en}->{3335545} = "Sarreguemines";
$areanames{en}->{3335546} = "Thionville";
$areanames{en}->{3335547} = "Toul";
$areanames{en}->{3335548} = "Verdun";
$areanames{en}->{3335549} = "Vittel";
$areanames{en}->{3335550} = "Bar\-le\-Duc";
$areanames{en}->{3335551} = "Briey";
$areanames{en}->{3335552} = "Épinal";
$areanames{en}->{3335553} = "Vittel";
$areanames{en}->{3335554} = "Nancy";
$areanames{en}->{3335555} = "Metz";
$areanames{en}->{3335556} = "Remiremont";
$areanames{en}->{3335557} = "Bar\-le\-Duc";
$areanames{en}->{3335558} = "Metz";
$areanames{en}->{3335559} = "Nancy";
$areanames{en}->{3335560} = "Thionville";
$areanames{en}->{3335561} = "Saint\-Avold";
$areanames{en}->{3335562} = "Metz";
$areanames{en}->{3335563} = "Sarreguemines";
$areanames{en}->{3335564} = "Thionville";
$areanames{en}->{3335565} = "Toul";
$areanames{en}->{3335566} = "Nancy";
$areanames{en}->{3335567} = "Bar\-le\-Duc";
$areanames{en}->{3335568} = "Nancy";
$areanames{en}->{3335569} = "Nancy";
$areanames{en}->{3335570} = "Briey";
$areanames{en}->{3335571} = "Sarreguemines";
$areanames{en}->{3335572} = "Saint\-Avold";
$areanames{en}->{3335573} = "Metz";
$areanames{en}->{3335574} = "Metz";
$areanames{en}->{3335575} = "Morhange";
$areanames{en}->{3335576} = "Pont\-à\-Mousson";
$areanames{en}->{3335577} = "Thionville";
$areanames{en}->{3335578} = "Sarreguemines";
$areanames{en}->{3335579} = "Saint\-Avold";
$areanames{en}->{3335580} = "Metz";
$areanames{en}->{3335590} = "Bar\-le\-Duc";
$areanames{en}->{3335591} = "Briey";
$areanames{en}->{3335592} = "Épinal";
$areanames{en}->{3335593} = "Lunéville";
$areanames{en}->{3335594} = "Metz";
$areanames{en}->{3335595} = "Morhange";
$areanames{en}->{3335596} = "Nancy";
$areanames{en}->{3335597} = "Neufchâteau";
$areanames{en}->{3335598} = "Pont\-à\-Mousson";
$areanames{en}->{3335599} = "Saint\-Avold";
$areanames{en}->{3335600} = "Bar\-le\-Duc";
$areanames{en}->{3335601} = "Verdun";
$areanames{en}->{3335602} = "Morhange";
$areanames{en}->{3335603} = "Saint\-Avold";
$areanames{en}->{3335604} = "Sarrebourg";
$areanames{en}->{3335605} = "Sarreguemines";
$areanames{en}->{3335606} = "Épinal";
$areanames{en}->{3335607} = "Neufchâteau";
$areanames{en}->{3335608} = "Remiremont";
$areanames{en}->{3335609} = "Saint\-Dié\-des\-Vosges";
$areanames{en}->{3335610} = "Vittel";
$areanames{en}->{3335611} = "Épinal";
$areanames{en}->{3335612} = "Metz";
$areanames{en}->{3335613} = "Vittel";
$areanames{en}->{3335614} = "Saint\-Avold";
$areanames{en}->{3335615} = "Lunéville";
$areanames{en}->{3335616} = "Lunéville";
$areanames{en}->{3335617} = "Pont\-à\-Mousson";
$areanames{en}->{3335618} = "Briey";
$areanames{en}->{3335619} = "Bar\-le\-Duc";
$areanames{en}->{3335620} = "Thionville";
$areanames{en}->{3335621} = "Sarreguemines";
$areanames{en}->{3335622} = "Metz";
$areanames{en}->{3335623} = "Saint\-Avold";
$areanames{en}->{3335624} = "Lunéville";
$areanames{en}->{3335625} = "Sarrebourg";
$areanames{en}->{3335626} = "Nancy";
$areanames{en}->{3335627} = "Morhange";
$areanames{en}->{3335628} = "Neufchâteau";
$areanames{en}->{3335629} = "Sarrebourg";
$areanames{en}->{3335630} = "Toul";
$areanames{en}->{3335631} = "Vittel";
$areanames{en}->{3335632} = "Épinal";
$areanames{en}->{3335633} = "Nancy";
$areanames{en}->{3335634} = "Remiremont";
$areanames{en}->{3335635} = "Briey";
$areanames{en}->{3335636} = "Lunéville";
$areanames{en}->{3335637} = "Nancy";
$areanames{en}->{3335638} = "Pont\-à\-Mousson";
$areanames{en}->{3335639} = "Toul";
$areanames{en}->{3335640} = "Bar\-le\-Duc";
$areanames{en}->{3335641} = "Verdun";
$areanames{en}->{3335642} = "Metz";
$areanames{en}->{3335643} = "Morhange";
$areanames{en}->{3335644} = "Saint\-Avold";
$areanames{en}->{3335645} = "Sarrebourg";
$areanames{en}->{3335646} = "Sarreguemines";
$areanames{en}->{3335647} = "Thionville";
$areanames{en}->{3335648} = "Épinal";
$areanames{en}->{3335649} = "Neufchâteau";
$areanames{en}->{3335650} = "Remiremont";
$areanames{en}->{3335651} = "Saint\-Dié\-des\-Vosges";
$areanames{en}->{3335652} = "Vittel";
$areanames{en}->{3335653} = "Briey";
$areanames{en}->{3335654} = "Metz";
$areanames{en}->{3335655} = "Saint\-Dié\-des\-Vosges";
$areanames{en}->{3335656} = "Épinal";
$areanames{en}->{3335657} = "Nancy";
$areanames{en}->{3335658} = "Nancy";
$areanames{en}->{3335660} = "Nancy";
$areanames{en}->{3335700} = "Remiremont";
$areanames{en}->{3335701} = "Saint\-Avold";
$areanames{en}->{3335702} = "Saint\-Dié\-des\-Vosges";
$areanames{en}->{3335703} = "Sarrebourg";
$areanames{en}->{3335704} = "Sarreguemines";
$areanames{en}->{3335705} = "Toul";
$areanames{en}->{3335706} = "Verdun";
$areanames{en}->{3335707} = "Vittel";
$areanames{en}->{3335708} = "Thionville";
$areanames{en}->{3335709} = "Nancy";
$areanames{en}->{3335710} = "Briey";
$areanames{en}->{3335711} = "Verdun";
$areanames{en}->{3335712} = "Épinal";
$areanames{en}->{3335713} = "Briey";
$areanames{en}->{3335714} = "Lunéville";
$areanames{en}->{3335715} = "Nancy";
$areanames{en}->{3335716} = "Pont\-à\-Mousson";
$areanames{en}->{3335717} = "Toul";
$areanames{en}->{3335718} = "Verdun";
$areanames{en}->{3335719} = "Morhange";
$areanames{en}->{3335728} = "Metz";
$areanames{en}->{3335730} = "Morhange";
$areanames{en}->{3335731} = "Saint\-Avold";
$areanames{en}->{3335732} = "Thionville";
$areanames{en}->{3335733} = "Lunéville";
$areanames{en}->{3335734} = "Lunéville";
$areanames{en}->{3335735} = "Nancy";
$areanames{en}->{3335736} = "Toul";
$areanames{en}->{3335737} = "Bar\-le\-Duc";
$areanames{en}->{3335738} = "Épinal";
$areanames{en}->{3335739} = "Épinal";
$areanames{en}->{3335740} = "Metz";
$areanames{en}->{3335741} = "Morhange";
$areanames{en}->{3335742} = "Saint\-Avold";
$areanames{en}->{3335743} = "Sarrebourg";
$areanames{en}->{3335744} = "Sarrebourg";
$areanames{en}->{3335745} = "Sarreguemines";
$areanames{en}->{3335746} = "Sarreguemines";
$areanames{en}->{3335747} = "Thionville";
$areanames{en}->{3335748} = "Nancy";
$areanames{en}->{3335749} = "Lunéville";
$areanames{en}->{3335750} = "Morhange";
$areanames{en}->{3335751} = "Metz";
$areanames{en}->{3335752} = "Sarrebourg";
$areanames{en}->{3335753} = "Saint\-Avold";
$areanames{en}->{3335754} = "Nancy";
$areanames{en}->{3335755} = "Metz";
$areanames{en}->{3335756} = "Metz";
$areanames{en}->{3335757} = "Metz";
$areanames{en}->{3335758} = "Verdun";
$areanames{en}->{3335759} = "Briey";
$areanames{en}->{3335760} = "Pont\-à\-Mousson";
$areanames{en}->{3335761} = "Bar\-le\-Duc";
$areanames{en}->{3335762} = "Verdun";
$areanames{en}->{3335763} = "Nancy";
$areanames{en}->{3335764} = "Toul";
$areanames{en}->{3335765} = "Neufchâteau";
$areanames{en}->{3335766} = "Épinal";
$areanames{en}->{3335767} = "Sarreguemines";
$areanames{en}->{3335768} = "Remiremont";
$areanames{en}->{3335769} = "Nancy";
$areanames{en}->{3335770} = "Briey";
$areanames{en}->{3335771} = "Bar\-le\-Duc";
$areanames{en}->{3335772} = "Vittel";
$areanames{en}->{3335773} = "Thionville";
$areanames{en}->{3335774} = "Saint\-Dié\-des\-Vosges";
$areanames{en}->{3335775} = "Nancy";
$areanames{en}->{3335776} = "Épinal";
$areanames{en}->{3335777} = "Nancy";
$areanames{en}->{3335778} = "Thionville";
$areanames{en}->{3335779} = "Briey";
$areanames{en}->{3335780} = "Nancy";
$areanames{en}->{3335781} = "Pont\-à\-Mousson";
$areanames{en}->{3335782} = "Toul";
$areanames{en}->{3335783} = "Verdun";
$areanames{en}->{3335784} = "Metz";
$areanames{en}->{3335785} = "Saint\-Avold";
$areanames{en}->{3335786} = "Sarrebourg";
$areanames{en}->{3335787} = "Sarreguemines";
$areanames{en}->{3335788} = "Thionville";
$areanames{en}->{3335789} = "Neufchâteau";
$areanames{en}->{3335790} = "Saint\-Dié\-des\-Vosges";
$areanames{en}->{3335791} = "Vittel";
$areanames{en}->{3335792} = "Lunéville";
$areanames{en}->{3335793} = "Nancy";
$areanames{en}->{3335794} = "Vittel";
$areanames{en}->{3335795} = "Pont\-à\-Mousson";
$areanames{en}->{3335796} = "Toul";
$areanames{en}->{3335797} = "Bar\-le\-Duc";
$areanames{en}->{3335798} = "Verdun";
$areanames{en}->{3335799} = "Épinal";
$areanames{en}->{3335800} = "Château\-Chinon\(Ville\)";
$areanames{en}->{3335801} = "Decize";
$areanames{en}->{3335802} = "Montbard";
$areanames{en}->{3335803} = "Saulieu";
$areanames{en}->{3335804} = "Château\-Chinon\(Ville\)";
$areanames{en}->{3335805} = "Cosne\-Cours\-sur\-Loire";
$areanames{en}->{3335806} = "Decize";
$areanames{en}->{3335807} = "Nevers";
$areanames{en}->{3335808} = "Autun";
$areanames{en}->{3335809} = "Chalon\-sur\-Saône";
$areanames{en}->{3335810} = "Montbard";
$areanames{en}->{3335811} = "Montceau\-les\-Mines";
$areanames{en}->{3335812} = "Nevers";
$areanames{en}->{3335813} = "Paray\-le\-Monial";
$areanames{en}->{3335814} = "Saulieu";
$areanames{en}->{3335815} = "Sens";
$areanames{en}->{3335816} = "Tonnerre";
$areanames{en}->{3335817} = "Toucy";
$areanames{en}->{3335818} = "Louhans";
$areanames{en}->{3335819} = "Mâcon";
$areanames{en}->{3335820} = "Autun";
$areanames{en}->{3335821} = "Auxerre";
$areanames{en}->{3335822} = "Beaune";
$areanames{en}->{3335823} = "Chalon\-sur\-Saône";
$areanames{en}->{3335824} = "Château\-Chinon\(Ville\)";
$areanames{en}->{3335825} = "Châtillon\-sur\-Seine";
$areanames{en}->{3335826} = "Cosne\-Cours\-sur\-Loire";
$areanames{en}->{3335827} = "Decize";
$areanames{en}->{3335828} = "Dijon";
$areanames{en}->{3335829} = "Is\-sur\-Tille";
$areanames{en}->{3335830} = "Joigny";
$areanames{en}->{3335831} = "Louhans";
$areanames{en}->{3335832} = "Mâcon";
$areanames{en}->{3335833} = "Montbard";
$areanames{en}->{3335834} = "Montceau\-les\-Mines";
$areanames{en}->{3335835} = "Nevers";
$areanames{en}->{3335836} = "Paray\-le\-Monial";
$areanames{en}->{3335837} = "Saulieu";
$areanames{en}->{3335838} = "Sens";
$areanames{en}->{3335839} = "Tonnerre";
$areanames{en}->{3335840} = "Toucy";
$areanames{en}->{3335841} = "Montceau\-les\-Mines";
$areanames{en}->{3335842} = "Paray\-le\-Monial";
$areanames{en}->{3335843} = "Auxerre";
$areanames{en}->{3335844} = "Joigny";
$areanames{en}->{3335845} = "Sens";
$areanames{en}->{3335846} = "Tonnerre";
$areanames{en}->{3335847} = "Toucy";
$areanames{en}->{3335848} = "Auxerre";
$areanames{en}->{3335849} = "Beaune";
$areanames{en}->{3335850} = "Chalon\-sur\-Saône";
$areanames{en}->{3335851} = "Châtillon\-sur\-Seine";
$areanames{en}->{3335852} = "Cosne\-Cours\-sur\-Loire";
$areanames{en}->{3335853} = "Is\-sur\-Tille";
$areanames{en}->{3335854} = "Joigny";
$areanames{en}->{3335855} = "Montbard";
$areanames{en}->{3335856} = "Montceau\-les\-Mines";
$areanames{en}->{3335857} = "Nevers";
$areanames{en}->{3335858} = "Nevers";
$areanames{en}->{3335859} = "Paray\-le\-Monial";
$areanames{en}->{3335860} = "Saulieu";
$areanames{en}->{3335861} = "Sens";
$areanames{en}->{3335862} = "Louhans";
$areanames{en}->{3335863} = "Tonnerre";
$areanames{en}->{3335864} = "Toucy";
$areanames{en}->{3335865} = "Auxerre";
$areanames{en}->{3335866} = "Chalon\-sur\-Saône";
$areanames{en}->{3335867} = "Cosne\-Cours\-sur\-Loire";
$areanames{en}->{3335868} = "Dijon";
$areanames{en}->{3335869} = "Chalon\-sur\-Saône";
$areanames{en}->{3335870} = "Dijon";
$areanames{en}->{3335871} = "Mâcon";
$areanames{en}->{3335872} = "Dijon";
$areanames{en}->{3335873} = "Louhans";
$areanames{en}->{3335874} = "Mâcon";
$areanames{en}->{3335875} = "Montceau\-les\-Mines";
$areanames{en}->{3335876} = "Nevers";
$areanames{en}->{3335877} = "Chalon\-sur\-Saône";
$areanames{en}->{3335878} = "Is\-sur\-Tille";
$areanames{en}->{3335879} = "Mâcon";
$areanames{en}->{3335880} = "Nevers";
$areanames{en}->{3335881} = "Saulieu";
$areanames{en}->{3335882} = "Nevers";
$areanames{en}->{3335883} = "Montceau\-les\-Mines";
$areanames{en}->{3335884} = "Chalon\-sur\-Saône";
$areanames{en}->{3335885} = "Châtillon\-sur\-Seine";
$areanames{en}->{3335886} = "Cosne\-Cours\-sur\-Loire";
$areanames{en}->{3335887} = "Montbard";
$areanames{en}->{3335888} = "Dijon";
$areanames{en}->{3335889} = "Montceau\-les\-Mines";
$areanames{en}->{3335890} = "Mâcon";
$areanames{en}->{3335891} = "Paray\-le\-Monial";
$areanames{en}->{3335892} = "Sens";
$areanames{en}->{3335893} = "Chalon\-sur\-Saône";
$areanames{en}->{3335894} = "Château\-Chinon\(Ville\)";
$areanames{en}->{3335895} = "Châtillon\-sur\-Seine";
$areanames{en}->{3335896} = "Cosne\-Cours\-sur\-Loire";
$areanames{en}->{3335897} = "Decize";
$areanames{en}->{3335898} = "Dijon";
$areanames{en}->{3335899} = "Louhans";
$areanames{en}->{333590} = "Lille";
$areanames{en}->{3335902} = "Béthune";
$areanames{en}->{3335904} = "Cambrai";
$areanames{en}->{3335906} = "Le\ Cateau\-Cambresis";
$areanames{en}->{3335907} = "Douai";
$areanames{en}->{3335910} = "Hazebrouck";
$areanames{en}->{3335911} = "Hazebrouck";
$areanames{en}->{3335912} = "Lille";
$areanames{en}->{3335913} = "Maubeuge";
$areanames{en}->{3335914} = "Valenciennes";
$areanames{en}->{3335915} = "Arras";
$areanames{en}->{3335916} = "Béthune";
$areanames{en}->{3335917} = "Lens";
$areanames{en}->{3335918} = "Béthune";
$areanames{en}->{3335919} = "Calais";
$areanames{en}->{3335920} = "Lille";
$areanames{en}->{3335921} = "Maubeuge";
$areanames{en}->{3335922} = "Lille";
$areanames{en}->{3335923} = "Valenciennes";
$areanames{en}->{3335924} = "Dunkerque";
$areanames{en}->{3335925} = "Arras";
$areanames{en}->{3335926} = "Cambrai";
$areanames{en}->{3335927} = "Dunkerque";
$areanames{en}->{3335928} = "Lille";
$areanames{en}->{3335929} = "Lens";
$areanames{en}->{3335930} = "Lille";
$areanames{en}->{3335931} = "Lille";
$areanames{en}->{3335932} = "Montreuil";
$areanames{en}->{3335933} = "Saint\-Omer";
$areanames{en}->{3335934} = "Saint\-Pol\-sur\-Ternoise";
$areanames{en}->{3335935} = "Lille";
$areanames{en}->{3335936} = "Lille";
$areanames{en}->{3335937} = "Béthune";
$areanames{en}->{3335938} = "Valenciennes";
$areanames{en}->{3335939} = "Lille";
$areanames{en}->{3335940} = "Lille";
$areanames{en}->{3335941} = "Béthune";
$areanames{en}->{3335942} = "Lens";
$areanames{en}->{3335943} = "Douai";
$areanames{en}->{3335944} = "Calais";
$areanames{en}->{3335945} = "Cambrai";
$areanames{en}->{3335946} = "Cambrai";
$areanames{en}->{3335947} = "Dunkerque";
$areanames{en}->{3335948} = "Dunkerque";
$areanames{en}->{3335949} = "Dunkerque";
$areanames{en}->{333595} = "Lille";
$areanames{en}->{3335960} = "Maubeuge";
$areanames{en}->{3335961} = "Lille";
$areanames{en}->{3335962} = "Calais";
$areanames{en}->{3335963} = "Lille";
$areanames{en}->{3335964} = "Douai";
$areanames{en}->{3335965} = "Cambrai";
$areanames{en}->{3335966} = "Douai";
$areanames{en}->{3335967} = "Dunkerque";
$areanames{en}->{3335968} = "Hazebrouck";
$areanames{en}->{3335969} = "Lille";
$areanames{en}->{3335970} = "Calais";
$areanames{en}->{3335971} = "Lille";
$areanames{en}->{3335972} = "Calais";
$areanames{en}->{3335973} = "Lille";
$areanames{en}->{3335974} = "Maubeuge";
$areanames{en}->{3335975} = "Lille";
$areanames{en}->{3335976} = "Valenciennes";
$areanames{en}->{3335977} = "Cambrai";
$areanames{en}->{3335978} = "Arras";
$areanames{en}->{3335979} = "Saint\-Omer";
$areanames{en}->{3335980} = "Arras";
$areanames{en}->{3335981} = "Lille";
$areanames{en}->{3335982} = "Lille";
$areanames{en}->{3335983} = "Valenciennes";
$areanames{en}->{3335984} = "Valenciennes";
$areanames{en}->{3335985} = "Arras";
$areanames{en}->{3335986} = "Arras";
$areanames{en}->{3335987} = "Béthune";
$areanames{en}->{3335988} = "Béthune";
$areanames{en}->{3335989} = "Lille";
$areanames{en}->{3335990} = "Le\ Cateau\-Cambresis";
$areanames{en}->{3335991} = "Calais";
$areanames{en}->{3335992} = "Calais";
$areanames{en}->{3335993} = "Lens";
$areanames{en}->{3335994} = "Lens";
$areanames{en}->{3335995} = "Valenciennes";
$areanames{en}->{3335996} = "Lille";
$areanames{en}->{3335997} = "Lille";
$areanames{en}->{3335998} = "Cambrai";
$areanames{en}->{3335999} = "Arras";
$areanames{en}->{3336000} = "Crépy\-en\-Valois";
$areanames{en}->{3336001} = "Amiens";
$areanames{en}->{3336002} = "Creil";
$areanames{en}->{3336003} = "Amiens";
$areanames{en}->{3336004} = "Abbeville";
$areanames{en}->{3336005} = "Beauvais";
$areanames{en}->{3336006} = "Château\-Thierry";
$areanames{en}->{3336007} = "Chauny";
$areanames{en}->{3336008} = "Hirson";
$areanames{en}->{3336009} = "Laon";
$areanames{en}->{3336010} = "Amiens";
$areanames{en}->{3336011} = "Amiens";
$areanames{en}->{3336012} = "Amiens";
$areanames{en}->{3336013} = "Amiens";
$areanames{en}->{3336014} = "Amiens";
$areanames{en}->{3336015} = "Saint\-Quentin";
$areanames{en}->{3336016} = "Soissons";
$areanames{en}->{3336017} = "Beauvais";
$areanames{en}->{3336018} = "Clermont";
$areanames{en}->{3336019} = "Compiègne";
$areanames{en}->{3336020} = "Amiens";
$areanames{en}->{3336021} = "Crépy\-en\-Valois";
$areanames{en}->{3336022} = "Abbeville";
$areanames{en}->{3336023} = "Albert";
$areanames{en}->{3336024} = "Amiens";
$areanames{en}->{3336025} = "Péronne";
$areanames{en}->{3336026} = "Abbeville";
$areanames{en}->{3336027} = "Albert";
$areanames{en}->{3336028} = "Amiens";
$areanames{en}->{3336029} = "Beauvais";
$areanames{en}->{3336030} = "Beauvais";
$areanames{en}->{3336031} = "Amiens";
$areanames{en}->{3336032} = "Abbeville";
$areanames{en}->{3336033} = "Albert";
$areanames{en}->{3336034} = "Péronne";
$areanames{en}->{3336035} = "Creil";
$areanames{en}->{3336036} = "Beauvais";
$areanames{en}->{3336037} = "Clermont";
$areanames{en}->{3336038} = "Château\-Thierry";
$areanames{en}->{3336039} = "Crépy\-en\-Valois";
$areanames{en}->{3336040} = "Compiègne";
$areanames{en}->{3336041} = "Château\-Thierry";
$areanames{en}->{3336042} = "Chauny";
$areanames{en}->{3336043} = "Clermont";
$areanames{en}->{3336044} = "Compiègne";
$areanames{en}->{3336045} = "Compiègne";
$areanames{en}->{3336046} = "Creil";
$areanames{en}->{3336047} = "Crépy\-en\-Valois";
$areanames{en}->{3336048} = "Hirson";
$areanames{en}->{3336049} = "Laon";
$areanames{en}->{3336050} = "Péronne";
$areanames{en}->{3336051} = "Péronne";
$areanames{en}->{3336052} = "Saint\-Quentin";
$areanames{en}->{3336053} = "Soissons";
$areanames{en}->{3336054} = "Laon";
$areanames{en}->{3336055} = "Beauvais";
$areanames{en}->{3336056} = "Beauvais";
$areanames{en}->{3336057} = "Saint\-Quentin";
$areanames{en}->{3336058} = "Creil";
$areanames{en}->{3336059} = "Crépy\-en\-Valois";
$areanames{en}->{3336060} = "Amiens";
$areanames{en}->{3336061} = "Abbeville";
$areanames{en}->{3336062} = "Amiens";
$areanames{en}->{3336063} = "Péronne";
$areanames{en}->{3336064} = "Albert";
$areanames{en}->{3336065} = "Amiens";
$areanames{en}->{3336066} = "Hirson";
$areanames{en}->{3336067} = "Creil";
$areanames{en}->{3336068} = "Saint\-Quentin";
$areanames{en}->{3336069} = "Soissons";
$areanames{en}->{3336070} = "Péronne";
$areanames{en}->{3336071} = "Soissons";
$areanames{en}->{3336072} = "Chauny";
$areanames{en}->{3336073} = "Hirson";
$areanames{en}->{3336074} = "Creil";
$areanames{en}->{3336075} = "Beauvais";
$areanames{en}->{3336076} = "Abbeville";
$areanames{en}->{3336077} = "Amiens";
$areanames{en}->{3336078} = "Creil";
$areanames{en}->{3336079} = "Compiègne";
$areanames{en}->{3336080} = "Creil";
$areanames{en}->{3336081} = "Laon";
$areanames{en}->{3336082} = "Beauvais";
$areanames{en}->{3336083} = "Creil";
$areanames{en}->{3336084} = "Beauvais";
$areanames{en}->{3336085} = "Amiens";
$areanames{en}->{3336086} = "Saint\-Quentin";
$areanames{en}->{3336087} = "Compiègne";
$areanames{en}->{3336088} = "Beauvais";
$areanames{en}->{3336089} = "Creil";
$areanames{en}->{3336090} = "Château\-Thierry";
$areanames{en}->{3336091} = "Chauny";
$areanames{en}->{3336092} = "Hirson";
$areanames{en}->{3336093} = "Laon";
$areanames{en}->{3336094} = "Saint\-Quentin";
$areanames{en}->{3336095} = "Soissons";
$areanames{en}->{3336096} = "Beauvais";
$areanames{en}->{3336097} = "Clermont";
$areanames{en}->{3336098} = "Compiègne";
$areanames{en}->{3336099} = "Creil";
$areanames{en}->{3336100} = "Lens";
$areanames{en}->{3336101} = "Montreuil";
$areanames{en}->{3336102} = "Saint\-Omer";
$areanames{en}->{3336103} = "Saint\-Pol\-sur\-Ternoise";
$areanames{en}->{3336104} = "Cambrai";
$areanames{en}->{3336105} = "Lille";
$areanames{en}->{3336106} = "Le\ Cateau\-Cambresis";
$areanames{en}->{3336107} = "Lille";
$areanames{en}->{3336108} = "Lille";
$areanames{en}->{3336109} = "Béthune";
$areanames{en}->{3336110} = "Valenciennes";
$areanames{en}->{3336111} = "Arras";
$areanames{en}->{3336112} = "Béthune";
$areanames{en}->{3336113} = "Calais";
$areanames{en}->{3336114} = "Cambrai";
$areanames{en}->{3336115} = "Le\ Cateau\-Cambresis";
$areanames{en}->{3336116} = "Douai";
$areanames{en}->{3336117} = "Dunkerque";
$areanames{en}->{3336118} = "Hazebrouck";
$areanames{en}->{3336119} = "Lens";
$areanames{en}->{3336120} = "Douai";
$areanames{en}->{3336121} = "Maubeuge";
$areanames{en}->{3336122} = "Montreuil";
$areanames{en}->{3336123} = "Saint\-Omer";
$areanames{en}->{3336124} = "Saint\-Pol\-sur\-Ternoise";
$areanames{en}->{3336125} = "Valenciennes";
$areanames{en}->{3336126} = "Lille";
$areanames{en}->{3336127} = "Valenciennes";
$areanames{en}->{3336128} = "Calais";
$areanames{en}->{3336129} = "Douai";
$areanames{en}->{3336138} = "Dunkirk";
$areanames{en}->{3336140} = "Béthune";
$areanames{en}->{3336141} = "Cambrai";
$areanames{en}->{3336142} = "Le\ Cateau\-Cambresis";
$areanames{en}->{3336143} = "Douai";
$areanames{en}->{3336144} = "Dunkerque";
$areanames{en}->{3336145} = "Hazebrouck";
$areanames{en}->{3336146} = "Maubeuge";
$areanames{en}->{3336147} = "Arras";
$areanames{en}->{3336148} = "Lens";
$areanames{en}->{3336149} = "Montreuil";
$areanames{en}->{3336150} = "Lille";
$areanames{en}->{3336151} = "Saint\-Omer";
$areanames{en}->{3336152} = "Saint\-Pol\-sur\-Ternoise";
$areanames{en}->{3336153} = "Arras";
$areanames{en}->{3336154} = "Cambrai";
$areanames{en}->{3336155} = "Hazebrouck";
$areanames{en}->{3336156} = "Le\ Cateau\-Cambresis";
$areanames{en}->{3336157} = "Lens";
$areanames{en}->{3336158} = "Lille";
$areanames{en}->{3336159} = "Maubeuge";
$areanames{en}->{3336160} = "Dunkerque";
$areanames{en}->{3336161} = "Lille";
$areanames{en}->{3336162} = "Lille";
$areanames{en}->{3336163} = "Dunkerque";
$areanames{en}->{3336164} = "Saint\-Omer";
$areanames{en}->{3336165} = "Saint\-Pol\-sur\-Ternoise";
$areanames{en}->{3336166} = "Arras";
$areanames{en}->{3336167} = "Valenciennes";
$areanames{en}->{3336168} = "Lens";
$areanames{en}->{3336169} = "Calais";
$areanames{en}->{3336170} = "Béthune";
$areanames{en}->{3336171} = "Calais";
$areanames{en}->{3336172} = "Béthune";
$areanames{en}->{3336173} = "Calais";
$areanames{en}->{3336174} = "Douai";
$areanames{en}->{3336175} = "Dunkerque";
$areanames{en}->{3336176} = "Lille";
$areanames{en}->{3336177} = "Lens";
$areanames{en}->{3336178} = "Lille";
$areanames{en}->{3336179} = "Saint\-Omer";
$areanames{en}->{3336180} = "Calais";
$areanames{en}->{3336181} = "Douai";
$areanames{en}->{3336182} = "Valenciennes";
$areanames{en}->{3336183} = "Hazebrouck";
$areanames{en}->{3336184} = "Le\ Cateau\-Cambresis";
$areanames{en}->{3336185} = "Montreuil";
$areanames{en}->{3336186} = "Saint\-Omer";
$areanames{en}->{3336187} = "Calais";
$areanames{en}->{3336188} = "Béthune";
$areanames{en}->{3336189} = "Cambrai";
$areanames{en}->{3336190} = "Lille";
$areanames{en}->{3336191} = "Béthune";
$areanames{en}->{3336192} = "Lille";
$areanames{en}->{3336193} = "Lens";
$areanames{en}->{3336194} = "Le\ Cateau\-Cambresis";
$areanames{en}->{3336195} = "Maubeuge";
$areanames{en}->{3336196} = "Montreuil";
$areanames{en}->{3336197} = "Lille";
$areanames{en}->{3336198} = "Saint\-Omer";
$areanames{en}->{3336199} = "Maubeuge";
$areanames{en}->{3336200} = "Dunkerque";
$areanames{en}->{3336201} = "Saint\-Pol\-sur\-Ternoise";
$areanames{en}->{3336202} = "Lille";
$areanames{en}->{3336203} = "Arras";
$areanames{en}->{3336204} = "Béthune";
$areanames{en}->{3336205} = "Calais";
$areanames{en}->{3336206} = "Cambrai";
$areanames{en}->{3336207} = "Douai";
$areanames{en}->{3336208} = "Dunkerque";
$areanames{en}->{3336209} = "Hazebrouck";
$areanames{en}->{3336210} = "Lille";
$areanames{en}->{3336211} = "Le\ Cateau\-Cambresis";
$areanames{en}->{3336212} = "Lens";
$areanames{en}->{3336213} = "Lille";
$areanames{en}->{3336214} = "Lille";
$areanames{en}->{3336215} = "Maubeuge";
$areanames{en}->{3336216} = "Montreuil";
$areanames{en}->{3336217} = "Saint\-Omer";
$areanames{en}->{3336218} = "Saint\-Pol\-sur\-Ternoise";
$areanames{en}->{3336219} = "Valenciennes";
$areanames{en}->{333622} = "Lille";
$areanames{en}->{3336220} = "Calais";
$areanames{en}->{3336222} = "Béthune";
$areanames{en}->{3336224} = "Dunkerque";
$areanames{en}->{3336230} = "Lille";
$areanames{en}->{3336231} = "Lille";
$areanames{en}->{3336232} = "Lille";
$areanames{en}->{3336233} = "Lille";
$areanames{en}->{3336234} = "Lille";
$areanames{en}->{3336235} = "Le\ Cateau\-Cambresis";
$areanames{en}->{3336236} = "Douai";
$areanames{en}->{3336237} = "Dunkerque";
$areanames{en}->{3336238} = "Hazebrouck";
$areanames{en}->{3336239} = "Valenciennes";
$areanames{en}->{3336240} = "Le\ Cateau\-Cambresis";
$areanames{en}->{3336241} = "Douai";
$areanames{en}->{3336242} = "Hazebrouck";
$areanames{en}->{3336243} = "Maubeuge";
$areanames{en}->{3336244} = "Montreuil";
$areanames{en}->{3336245} = "Saint\-Omer";
$areanames{en}->{3336246} = "Saint\-Pol\-sur\-Ternoise";
$areanames{en}->{3336247} = "Béthune";
$areanames{en}->{3336248} = "Lens";
$areanames{en}->{3336249} = "Montreuil";
$areanames{en}->{3336250} = "Arras";
$areanames{en}->{3336251} = "Saint\-Omer";
$areanames{en}->{3336252} = "Lille";
$areanames{en}->{3336253} = "Lille";
$areanames{en}->{3336254} = "Saint\-Pol\-sur\-Ternoise";
$areanames{en}->{3336255} = "Douai";
$areanames{en}->{3336256} = "Cambrai";
$areanames{en}->{3336257} = "Lille";
$areanames{en}->{3336258} = "Cambrai";
$areanames{en}->{3336259} = "Lille";
$areanames{en}->{3336265} = "Lille";
$areanames{en}->{3336270} = "Dunkerque";
$areanames{en}->{3336271} = "Hazebrouck";
$areanames{en}->{3336272} = "Lille";
$areanames{en}->{3336273} = "Dunkerque";
$areanames{en}->{3336274} = "Cambrai";
$areanames{en}->{3336275} = "Valenciennes";
$areanames{en}->{3336276} = "Douai";
$areanames{en}->{3336277} = "Saint\-Pol\-sur\-Ternoise";
$areanames{en}->{3336278} = "Calais";
$areanames{en}->{3336279} = "Béthune";
$areanames{en}->{3336280} = "Valenciennes";
$areanames{en}->{3336281} = "Lille";
$areanames{en}->{3336282} = "Lille";
$areanames{en}->{3336283} = "Arras";
$areanames{en}->{3336284} = "Lille";
$areanames{en}->{3336285} = "Maubeuge";
$areanames{en}->{3336286} = "Valenciennes";
$areanames{en}->{3336287} = "Lille";
$areanames{en}->{3336288} = "Montreuil";
$areanames{en}->{3336289} = "Béthune";
$areanames{en}->{3336290} = "Lens";
$areanames{en}->{3336291} = "Saint\-Pol\-sur\-Ternoise";
$areanames{en}->{3336292} = "Lille";
$areanames{en}->{3336293} = "Lens";
$areanames{en}->{3336294} = "Lille";
$areanames{en}->{3336295} = "Arras";
$areanames{en}->{3336296} = "Béthune";
$areanames{en}->{3336297} = "Calais";
$areanames{en}->{3336298} = "Calais";
$areanames{en}->{3336299} = "Saint\-Omer";
$areanames{en}->{3336300} = "Luxeuil\-les\-Bains";
$areanames{en}->{3336301} = "Besançon";
$areanames{en}->{3336302} = "Montbéliard";
$areanames{en}->{3336303} = "Morteau";
$areanames{en}->{3336304} = "Pontarlier";
$areanames{en}->{3336305} = "Arbois";
$areanames{en}->{3336306} = "Dole";
$areanames{en}->{3336307} = "Lons\-le\-Saunier";
$areanames{en}->{3336308} = "Besançon";
$areanames{en}->{3336309} = "Saint\-Claude";
$areanames{en}->{3336310} = "Gray";
$areanames{en}->{3336311} = "Montbéliard";
$areanames{en}->{3336312} = "Luxeuil\-les\-Bains";
$areanames{en}->{3336313} = "Vesoul";
$areanames{en}->{3336314} = "Belfort";
$areanames{en}->{3336315} = "Montbéliard";
$areanames{en}->{3336316} = "Besançon";
$areanames{en}->{3336317} = "Morteau";
$areanames{en}->{3336318} = "Besançon";
$areanames{en}->{3336319} = "Belfort";
$areanames{en}->{3336320} = "Besançon";
$areanames{en}->{3336321} = "Besançon";
$areanames{en}->{3336322} = "Montbéliard";
$areanames{en}->{3336323} = "Morteau";
$areanames{en}->{3336324} = "Pontarlier";
$areanames{en}->{3336325} = "Arbois";
$areanames{en}->{3336326} = "Dole";
$areanames{en}->{3336327} = "Lons\-le\-Saunier";
$areanames{en}->{3336328} = "Saint\-Claude";
$areanames{en}->{3336329} = "Gray";
$areanames{en}->{3336330} = "Lure";
$areanames{en}->{3336331} = "Belfort";
$areanames{en}->{3336332} = "Montbéliard";
$areanames{en}->{3336333} = "Lons\-le\-Saunier";
$areanames{en}->{3336334} = "Saint\-Claude";
$areanames{en}->{3336335} = "Besançon";
$areanames{en}->{3336336} = "Dole";
$areanames{en}->{3336337} = "Vesoul";
$areanames{en}->{3336338} = "Montbéliard";
$areanames{en}->{3336339} = "Morteau";
$areanames{en}->{3336340} = "Arbois";
$areanames{en}->{3336341} = "Belfort";
$areanames{en}->{3336342} = "Besançon";
$areanames{en}->{3336343} = "Dole";
$areanames{en}->{3336344} = "Gray";
$areanames{en}->{3336345} = "Lons\-le\-Saunier";
$areanames{en}->{3336346} = "Lure";
$areanames{en}->{3336347} = "Luxeuil\-les\-Bains";
$areanames{en}->{3336348} = "Montbéliard";
$areanames{en}->{3336349} = "Morteau";
$areanames{en}->{3336350} = "Pontarlier";
$areanames{en}->{3336351} = "Saint\-Claude";
$areanames{en}->{3336352} = "Vesoul";
$areanames{en}->{3336353} = "Belfort";
$areanames{en}->{3336354} = "Vesoul";
$areanames{en}->{3336355} = "Lons\-le\-Saunier";
$areanames{en}->{3336356} = "Pontarlier";
$areanames{en}->{3336357} = "Arbois";
$areanames{en}->{3336358} = "Besançon";
$areanames{en}->{3336359} = "Montbéliard";
$areanames{en}->{3336360} = "Pontarlier";
$areanames{en}->{3336361} = "Arbois";
$areanames{en}->{3336362} = "Vesoul";
$areanames{en}->{3336363} = "Belfort";
$areanames{en}->{3336364} = "Besançon";
$areanames{en}->{3336365} = "Gray";
$areanames{en}->{3336366} = "Dole";
$areanames{en}->{3336367} = "Lons\-le\-Saunier";
$areanames{en}->{3336368} = "Saint\-Claude";
$areanames{en}->{3336369} = "Belfort";
$areanames{en}->{3336370} = "Montbéliard";
$areanames{en}->{3336371} = "Belfort";
$areanames{en}->{3336372} = "Luxeuil\-les\-Bains";
$areanames{en}->{3336373} = "Vesoul";
$areanames{en}->{3336374} = "Gray";
$areanames{en}->{3336375} = "Lure";
$areanames{en}->{3336376} = "Luxeuil\-les\-Bains";
$areanames{en}->{3336377} = "Vesoul";
$areanames{en}->{3336378} = "Belfort";
$areanames{en}->{3336379} = "Belfort";
$areanames{en}->{3336380} = "Pontarlier";
$areanames{en}->{3336381} = "Montbéliard";
$areanames{en}->{3336382} = "Belfort";
$areanames{en}->{3336383} = "Dole";
$areanames{en}->{3336384} = "Lons\-le\-Saunier";
$areanames{en}->{3336385} = "Luxeuil\-les\-Bains";
$areanames{en}->{3336386} = "Arbois";
$areanames{en}->{3336387} = "Gray";
$areanames{en}->{3336388} = "Lure";
$areanames{en}->{3336389} = "Luxeuil\-les\-Bains";
$areanames{en}->{3336390} = "Besançon";
$areanames{en}->{3336391} = "Montbéliard";
$areanames{en}->{3336392} = "Morteau";
$areanames{en}->{3336393} = "Pontarlier";
$areanames{en}->{3336394} = "Arbois";
$areanames{en}->{3336395} = "Dole";
$areanames{en}->{3336396} = "Lons\-le\-Saunier";
$areanames{en}->{3336397} = "Saint\-Claude";
$areanames{en}->{3336398} = "Gray";
$areanames{en}->{3336399} = "Lure";
$areanames{en}->{3336400} = "Abbeville";
$areanames{en}->{3336401} = "Amiens";
$areanames{en}->{3336402} = "Albert";
$areanames{en}->{3336403} = "Château\-Thierry";
$areanames{en}->{3336404} = "Chauny";
$areanames{en}->{3336405} = "Clermont";
$areanames{en}->{3336406} = "Crépy\-en\-Valois";
$areanames{en}->{3336407} = "Hirson";
$areanames{en}->{3336408} = "Laon";
$areanames{en}->{3336409} = "Péronne";
$areanames{en}->{3336410} = "Saint\-Quentin";
$areanames{en}->{3336411} = "Soissons";
$areanames{en}->{3336412} = "Compiègne";
$areanames{en}->{3336413} = "Château\-Thierry";
$areanames{en}->{3336414} = "Chauny";
$areanames{en}->{3336415} = "Hirson";
$areanames{en}->{3336416} = "Laon";
$areanames{en}->{3336417} = "Saint\-Quentin";
$areanames{en}->{3336418} = "Soissons";
$areanames{en}->{3336419} = "Beauvais";
$areanames{en}->{3336420} = "Clermont";
$areanames{en}->{3336421} = "Compiègne";
$areanames{en}->{3336422} = "Creil";
$areanames{en}->{3336423} = "Crépy\-en\-Valois";
$areanames{en}->{3336424} = "Abbeville";
$areanames{en}->{3336425} = "Albert";
$areanames{en}->{3336426} = "Amiens";
$areanames{en}->{3336427} = "Péronne";
$areanames{en}->{3336428} = "Abbeville";
$areanames{en}->{3336429} = "Beauvais";
$areanames{en}->{3336430} = "Château\-Thierry";
$areanames{en}->{3336431} = "Clermont";
$areanames{en}->{3336432} = "Compiègne";
$areanames{en}->{3336433} = "Crépy\-en\-Valois";
$areanames{en}->{3336434} = "Hirson";
$areanames{en}->{3336435} = "Péronne";
$areanames{en}->{3336436} = "Saint\-Quentin";
$areanames{en}->{3336437} = "Abbeville";
$areanames{en}->{3336438} = "Amiens";
$areanames{en}->{3336439} = "Beauvais";
$areanames{en}->{3336440} = "Amiens";
$areanames{en}->{3336441} = "Beauvais";
$areanames{en}->{3336442} = "Château\-Thierry";
$areanames{en}->{3336443} = "Compiègne";
$areanames{en}->{3336444} = "Creil";
$areanames{en}->{3336445} = "Péronne";
$areanames{en}->{3336446} = "Amiens";
$areanames{en}->{3336447} = "Compiègne";
$areanames{en}->{3336448} = "Château\-Thierry";
$areanames{en}->{3336449} = "Crépy\-en\-Valois";
$areanames{en}->{3336450} = "Abbeville";
$areanames{en}->{3336451} = "Amiens";
$areanames{en}->{3336452} = "Château\-Thierry";
$areanames{en}->{3336453} = "Clermont";
$areanames{en}->{3336454} = "Laon";
$areanames{en}->{3336455} = "Abbeville";
$areanames{en}->{3336456} = "Albert";
$areanames{en}->{3336457} = "Amiens";
$areanames{en}->{3336458} = "Beauvais";
$areanames{en}->{3336459} = "Château\-Thierry";
$areanames{en}->{3336460} = "Compiègne";
$areanames{en}->{3336461} = "Clermont";
$areanames{en}->{3336462} = "Creil";
$areanames{en}->{3336463} = "Péronne";
$areanames{en}->{3336464} = "Abbeville";
$areanames{en}->{3336465} = "Amiens";
$areanames{en}->{3336466} = "Creil";
$areanames{en}->{3336467} = "Beauvais";
$areanames{en}->{3336468} = "Chauny";
$areanames{en}->{3336469} = "Clermont";
$areanames{en}->{3336470} = "Château\-Thierry";
$areanames{en}->{3336471} = "Compiègne";
$areanames{en}->{3336472} = "Creil";
$areanames{en}->{3336473} = "Crépy\-en\-Valois";
$areanames{en}->{3336474} = "Hirson";
$areanames{en}->{3336475} = "Laon";
$areanames{en}->{3336476} = "Péronne";
$areanames{en}->{3336477} = "Saint\-Quentin";
$areanames{en}->{3336478} = "Soissons";
$areanames{en}->{3336479} = "Chauny";
$areanames{en}->{3336480} = "Péronne";
$areanames{en}->{3336481} = "Chauny";
$areanames{en}->{3336482} = "Saint\-Quentin";
$areanames{en}->{3336483} = "Laon";
$areanames{en}->{3336484} = "Soissons";
$areanames{en}->{3336485} = "Amiens";
$areanames{en}->{3336486} = "Saint\-Quentin";
$areanames{en}->{3336487} = "Albert";
$areanames{en}->{3336488} = "Compiègne";
$areanames{en}->{3336489} = "Beauvais";
$areanames{en}->{3336490} = "Saint\-Quentin";
$areanames{en}->{3336491} = "Soissons";
$areanames{en}->{3336492} = "Soissons";
$areanames{en}->{3336493} = "Chauny";
$areanames{en}->{3336494} = "Amiens";
$areanames{en}->{3336495} = "Hirson";
$areanames{en}->{3336496} = "Laon";
$areanames{en}->{3336497} = "Saint\-Quentin";
$areanames{en}->{3336498} = "Soissons";
$areanames{en}->{3336499} = "Beauvais";
$areanames{en}->{3336500} = "Clermont";
$areanames{en}->{3336501} = "Compiègne";
$areanames{en}->{3336502} = "Creil";
$areanames{en}->{3336503} = "Crépy\-en\-Valois";
$areanames{en}->{3336504} = "Abbeville";
$areanames{en}->{3336505} = "Albert";
$areanames{en}->{3336506} = "Amiens";
$areanames{en}->{3336507} = "Péronne";
$areanames{en}->{3336508} = "Château\-Thierry";
$areanames{en}->{3336509} = "Creil";
$areanames{en}->{3336510} = "Beauvais";
$areanames{en}->{3336511} = "Compiègne";
$areanames{en}->{3336512} = "Creil";
$areanames{en}->{3336513} = "Abbeville";
$areanames{en}->{3336514} = "Amiens";
$areanames{en}->{3336515} = "Péronne";
$areanames{en}->{3336516} = "Laon";
$areanames{en}->{3336517} = "Abbeville";
$areanames{en}->{3336518} = "Abbeville";
$areanames{en}->{3336519} = "Albert";
$areanames{en}->{3336520} = "Abbeville";
$areanames{en}->{3336521} = "Saint\-Quentin";
$areanames{en}->{3336522} = "Crépy\-en\-Valois";
$areanames{en}->{3336523} = "Clermont";
$areanames{en}->{3336524} = "Beauvais";
$areanames{en}->{3336525} = "Château\-Thierry";
$areanames{en}->{3336526} = "Albert";
$areanames{en}->{3336527} = "Chauny";
$areanames{en}->{3336528} = "Compiègne";
$areanames{en}->{3336529} = "Soissons";
$areanames{en}->{3336530} = "Château\-Thierry";
$areanames{en}->{3336531} = "Chauny";
$areanames{en}->{3336532} = "Laon";
$areanames{en}->{3336533} = "Beauvais";
$areanames{en}->{3336534} = "Clermont";
$areanames{en}->{3336535} = "Compiègne";
$areanames{en}->{3336536} = "Creil";
$areanames{en}->{3336537} = "Crépy\-en\-Valois";
$areanames{en}->{3336538} = "Laon";
$areanames{en}->{3336539} = "Amiens";
$areanames{en}->{3336540} = "Péronne";
$areanames{en}->{3336541} = "Hirson";
$areanames{en}->{3336542} = "Creil";
$areanames{en}->{3336543} = "Beauvais";
$areanames{en}->{3336544} = "Château\-Thierry";
$areanames{en}->{3336545} = "Chauny";
$areanames{en}->{3336546} = "Hirson";
$areanames{en}->{3336547} = "Laon";
$areanames{en}->{3336548} = "Saint\-Quentin";
$areanames{en}->{3336549} = "Soissons";
$areanames{en}->{3336550} = "Beauvais";
$areanames{en}->{3336551} = "Clermont";
$areanames{en}->{3336552} = "Compiègne";
$areanames{en}->{3336553} = "Creil";
$areanames{en}->{3336554} = "Crépy\-en\-Valois";
$areanames{en}->{3336555} = "Abbeville";
$areanames{en}->{3336556} = "Albert";
$areanames{en}->{3336557} = "Amiens";
$areanames{en}->{3336558} = "Péronne";
$areanames{en}->{3336559} = "Amiens";
$areanames{en}->{3336560} = "Laon";
$areanames{en}->{3336561} = "Amiens";
$areanames{en}->{3336562} = "Chauny";
$areanames{en}->{3336563} = "Soissons";
$areanames{en}->{3336564} = "Albert";
$areanames{en}->{3336565} = "Creil";
$areanames{en}->{3336566} = "Amiens";
$areanames{en}->{3336567} = "Laon";
$areanames{en}->{3336568} = "Beauvais";
$areanames{en}->{3336569} = "Creil";
$areanames{en}->{3336570} = "Abbeville";
$areanames{en}->{3336571} = "Amiens";
$areanames{en}->{3336572} = "Laon";
$areanames{en}->{3336573} = "Saint\-Quentin";
$areanames{en}->{3336574} = "Beauvais";
$areanames{en}->{3336575} = "Compiègne";
$areanames{en}->{3336576} = "Creil";
$areanames{en}->{3336577} = "Crépy\-en\-Valois";
$areanames{en}->{3336578} = "Clermont";
$areanames{en}->{3336579} = "Amiens";
$areanames{en}->{3336580} = "Amiens";
$areanames{en}->{3336581} = "Château\-Thierry";
$areanames{en}->{3336582} = "Chauny";
$areanames{en}->{3336583} = "Hirson";
$areanames{en}->{3336584} = "Laon";
$areanames{en}->{3336585} = "Péronne";
$areanames{en}->{3336586} = "Saint\-Quentin";
$areanames{en}->{3336587} = "Soissons";
$areanames{en}->{3336588} = "Amiens";
$areanames{en}->{3336589} = "Amiens";
$areanames{en}->{3336590} = "Laon";
$areanames{en}->{3336591} = "Amiens";
$areanames{en}->{3336592} = "Saint\-Quentin";
$areanames{en}->{3336593} = "Compiègne";
$areanames{en}->{3336594} = "Beauvais";
$areanames{en}->{3336595} = "Laon";
$areanames{en}->{3336596} = "Creil";
$areanames{en}->{3336597} = "Beauvais";
$areanames{en}->{3336598} = "Compiègne";
$areanames{en}->{3336599} = "Saint\-Quentin";
$areanames{en}->{3336600} = "Douai";
$areanames{en}->{3336601} = "Dunkerque";
$areanames{en}->{3336602} = "Hazebrouck";
$areanames{en}->{3336603} = "Valenciennes";
$areanames{en}->{3336604} = "Lens";
$areanames{en}->{3336605} = "Saint\-Omer";
$areanames{en}->{3336606} = "Lille";
$areanames{en}->{3336607} = "Lens";
$areanames{en}->{3336608} = "Lille";
$areanames{en}->{3336609} = "Béthune";
$areanames{en}->{3336610} = "Saint\-Omer";
$areanames{en}->{3336611} = "Saint\-Pol\-sur\-Ternoise";
$areanames{en}->{3336612} = "Arras";
$areanames{en}->{3336613} = "Béthune";
$areanames{en}->{3336614} = "Lens";
$areanames{en}->{3336615} = "Montreuil";
$areanames{en}->{3336616} = "Le\ Cateau\-Cambresis";
$areanames{en}->{3336617} = "Dunkerque";
$areanames{en}->{3336618} = "Hazebrouck";
$areanames{en}->{3336619} = "Lille";
$areanames{en}->{3336620} = "Valenciennes";
$areanames{en}->{3336621} = "Lille";
$areanames{en}->{3336622} = "Valenciennes";
$areanames{en}->{3336623} = "Lens";
$areanames{en}->{3336624} = "Maubeuge";
$areanames{en}->{3336625} = "Calais";
$areanames{en}->{3336626} = "Maubeuge";
$areanames{en}->{3336627} = "Le\ Cateau\-Cambresis";
$areanames{en}->{3336628} = "Cambrai";
$areanames{en}->{3336629} = "Saint\-Pol\-sur\-Ternoise";
$areanames{en}->{3336630} = "Lens";
$areanames{en}->{3336631} = "Arras";
$areanames{en}->{3336632} = "Lille";
$areanames{en}->{3336633} = "Lille";
$areanames{en}->{3336634} = "Béthune";
$areanames{en}->{3336635} = "Hazebrouck";
$areanames{en}->{3336636} = "Douai";
$areanames{en}->{3336637} = "Montreuil";
$areanames{en}->{3336638} = "Saint\-Omer";
$areanames{en}->{3336639} = "Lille";
$areanames{en}->{3336640} = "Valenciennes";
$areanames{en}->{3336641} = "Dunkerque";
$areanames{en}->{3336642} = "Valenciennes";
$areanames{en}->{3336643} = "Cambrai";
$areanames{en}->{3336644} = "Le\ Cateau\-Cambresis";
$areanames{en}->{3336645} = "Douai";
$areanames{en}->{3336646} = "Dunkerque";
$areanames{en}->{3336647} = "Hazebrouck";
$areanames{en}->{3336648} = "Lille";
$areanames{en}->{3336649} = "Maubeuge";
$areanames{en}->{3336650} = "Valenciennes";
$areanames{en}->{3336651} = "Arras";
$areanames{en}->{3336652} = "Béthune";
$areanames{en}->{3336653} = "Calais";
$areanames{en}->{3336654} = "Lens";
$areanames{en}->{3336655} = "Montreuil";
$areanames{en}->{3336656} = "Saint\-Omer";
$areanames{en}->{3336657} = "Saint\-Pol\-sur\-Ternoise";
$areanames{en}->{3336658} = "Arras";
$areanames{en}->{3336659} = "Valenciennes";
$areanames{en}->{3336664} = "Lille";
$areanames{en}->{3336672} = "Lille";
$areanames{en}->{3336673} = "Lille";
$areanames{en}->{3336680} = "Lille";
$areanames{en}->{3336681} = "Calais";
$areanames{en}->{3336682} = "Lens";
$areanames{en}->{3336683} = "Montreuil";
$areanames{en}->{3336684} = "Saint\-Omer";
$areanames{en}->{3336685} = "Saint\-Pol\-sur\-Ternoise";
$areanames{en}->{3336686} = "Arras";
$areanames{en}->{3336687} = "Douai";
$areanames{en}->{3336688} = "Lille";
$areanames{en}->{3336689} = "Dunkerque";
$areanames{en}->{3336690} = "Cambrai";
$areanames{en}->{3336691} = "Douai";
$areanames{en}->{3336692} = "Dunkerque";
$areanames{en}->{3336693} = "Hazebrouck";
$areanames{en}->{3336694} = "Maubeuge";
$areanames{en}->{3336695} = "Valenciennes";
$areanames{en}->{3336696} = "Lille";
$areanames{en}->{3336697} = "Lille";
$areanames{en}->{3336698} = "Lens";
$areanames{en}->{3336699} = "Arras";
$areanames{en}->{3336707} = "Strasbourg";
$areanames{en}->{3336708} = "Strasbourg";
$areanames{en}->{3336710} = "Strasbourg";
$areanames{en}->{3336711} = "Mulhouse";
$areanames{en}->{3336720} = "Sélestat";
$areanames{en}->{3336721} = "Strasbourg";
$areanames{en}->{3336722} = "Strasbourg";
$areanames{en}->{3336723} = "Mulhouse";
$areanames{en}->{3336724} = "Caen";
$areanames{en}->{3336725} = "Strasbourg";
$areanames{en}->{3336726} = "Mulhouse";
$areanames{en}->{3336727} = "Mulhouse";
$areanames{en}->{3336728} = "Colmar";
$areanames{en}->{3336729} = "Strasbourg";
$areanames{en}->{3336730} = "Colmar";
$areanames{en}->{3336731} = "Haguenau";
$areanames{en}->{3336732} = "Strasbourg";
$areanames{en}->{3336733} = "Strasbourg";
$areanames{en}->{3336734} = "Strasbourg";
$areanames{en}->{3336735} = "Mulhouse";
$areanames{en}->{3336736} = "Altkirch";
$areanames{en}->{3336737} = "Sélestat";
$areanames{en}->{3336738} = "Saverne";
$areanames{en}->{3336739} = "Strasbourg";
$areanames{en}->{3336740} = "Haguenau";
$areanames{en}->{3336741} = "Saverne";
$areanames{en}->{3336742} = "Sélestat";
$areanames{en}->{3336743} = "Strasbourg";
$areanames{en}->{3336744} = "Altkirch";
$areanames{en}->{3336745} = "Colmar";
$areanames{en}->{3336746} = "Mulhouse";
$areanames{en}->{3336747} = "Strasbourg";
$areanames{en}->{3336748} = "Strasbourg";
$areanames{en}->{3336749} = "Strasbourg";
$areanames{en}->{3336750} = "Sélestat";
$areanames{en}->{3336751} = "Altkirch";
$areanames{en}->{3336752} = "Altkirch";
$areanames{en}->{3336760} = "Strasbourg";
$areanames{en}->{3336761} = "Mulhouse";
$areanames{en}->{3336762} = "Haguenau";
$areanames{en}->{3336763} = "Saverne";
$areanames{en}->{3336764} = "Sélestat";
$areanames{en}->{3336765} = "Strasbourg";
$areanames{en}->{3336766} = "Saverne";
$areanames{en}->{3336767} = "Strasbourg";
$areanames{en}->{3336768} = "Strasbourg";
$areanames{en}->{3336769} = "Haguenau";
$areanames{en}->{333677} = "Strasbourg";
$areanames{en}->{3336776} = "Mulhouse";
$areanames{en}->{3336777} = "Mulhouse";
$areanames{en}->{3336778} = "Mulhouse";
$areanames{en}->{3336780} = "Strasbourg";
$areanames{en}->{3336781} = "Saverne";
$areanames{en}->{3336782} = "Colmar";
$areanames{en}->{3336783} = "Haguenau";
$areanames{en}->{3336784} = "Colmar";
$areanames{en}->{3336785} = "Strasbourg";
$areanames{en}->{3336786} = "Strasbourg";
$areanames{en}->{3336787} = "Strasbourg";
$areanames{en}->{3336788} = "Mulhouse";
$areanames{en}->{3336789} = "Strasbourg";
$areanames{en}->{3336790} = "Colmar";
$areanames{en}->{3336791} = "Mulhouse";
$areanames{en}->{3336792} = "Sélestat";
$areanames{en}->{3336793} = "Altkirch";
$areanames{en}->{3336794} = "Mulhouse";
$areanames{en}->{3336795} = "Strasbourg";
$areanames{en}->{3336796} = "Colmar";
$areanames{en}->{3336797} = "Strasbourg";
$areanames{en}->{3336798} = "Strasbourg";
$areanames{en}->{3336799} = "Strasbourg";
$areanames{en}->{3336807} = "Colmar";
$areanames{en}->{3336810} = "Mulhouse";
$areanames{en}->{3336811} = "Colmar";
$areanames{en}->{3336812} = "Altkirch";
$areanames{en}->{3336813} = "Sélestat";
$areanames{en}->{3336814} = "Haguenau";
$areanames{en}->{3336815} = "Saverne";
$areanames{en}->{3336816} = "Haguenau";
$areanames{en}->{3336817} = "Saverne";
$areanames{en}->{3336818} = "Sélestat";
$areanames{en}->{3336819} = "Strasbourg";
$areanames{en}->{3336820} = "Strasbourg";
$areanames{en}->{3336821} = "Haguenau";
$areanames{en}->{3336822} = "Altkirch";
$areanames{en}->{3336823} = "Colmar";
$areanames{en}->{3336824} = "Haguenau";
$areanames{en}->{3336825} = "Mulhouse";
$areanames{en}->{3336826} = "Saverne";
$areanames{en}->{3336827} = "Sélestat";
$areanames{en}->{3336828} = "Strasbourg";
$areanames{en}->{3336829} = "Haguenau";
$areanames{en}->{3336830} = "Altkirch";
$areanames{en}->{3336831} = "Colmar";
$areanames{en}->{3336832} = "Mulhouse";
$areanames{en}->{3336833} = "Strasbourg";
$areanames{en}->{3336834} = "Colmar";
$areanames{en}->{3336835} = "Mulhouse";
$areanames{en}->{3336836} = "Mulhouse";
$areanames{en}->{3336837} = "Saverne";
$areanames{en}->{3336838} = "Strasbourg";
$areanames{en}->{3336839} = "Sélestat";
$areanames{en}->{3336847} = "Mulhouse";
$areanames{en}->{3336850} = "Haguenau";
$areanames{en}->{3336851} = "Altkirch";
$areanames{en}->{3336852} = "Colmar";
$areanames{en}->{3336853} = "Mulhouse";
$areanames{en}->{3336854} = "Haguenau";
$areanames{en}->{3336855} = "Haguenau";
$areanames{en}->{3336856} = "Saverne";
$areanames{en}->{3336857} = "Sélestat";
$areanames{en}->{3336858} = "Strasbourg";
$areanames{en}->{3336859} = "Strasbourg";
$areanames{en}->{3336860} = "Colmar";
$areanames{en}->{3336861} = "Colmar";
$areanames{en}->{3336862} = "Strasbourg";
$areanames{en}->{3336863} = "Colmar";
$areanames{en}->{3336864} = "Altkirch";
$areanames{en}->{3336865} = "Mulhouse";
$areanames{en}->{3336866} = "Haguenau";
$areanames{en}->{3336867} = "Strasbourg";
$areanames{en}->{3336868} = "Strasbourg";
$areanames{en}->{3336869} = "Strasbourg";
$areanames{en}->{3336870} = "Mulhouse";
$areanames{en}->{3336871} = "Strasbourg";
$areanames{en}->{3336872} = "Haguenau";
$areanames{en}->{3336873} = "Saverne";
$areanames{en}->{3336874} = "Sélestat";
$areanames{en}->{3336875} = "Mulhouse";
$areanames{en}->{3336876} = "Strasbourg";
$areanames{en}->{3336877} = "Saverne";
$areanames{en}->{3336878} = "Strasbourg";
$areanames{en}->{3336879} = "Sélestat";
$areanames{en}->{3336880} = "Altkirch";
$areanames{en}->{3336881} = "Haguenau";
$areanames{en}->{3336882} = "Saverne";
$areanames{en}->{3336883} = "Sélestat";
$areanames{en}->{3336884} = "Strasbourg";
$areanames{en}->{3336885} = "Altkirch";
$areanames{en}->{3336886} = "Colmar";
$areanames{en}->{3336887} = "Mulhouse";
$areanames{en}->{3336888} = "Saverne";
$areanames{en}->{3336889} = "Strasbourg";
$areanames{en}->{3336890} = "Sélestat";
$areanames{en}->{3336891} = "Strasbourg";
$areanames{en}->{3336892} = "Haguenau";
$areanames{en}->{3336893} = "Strasbourg";
$areanames{en}->{3336894} = "Altkirch";
$areanames{en}->{3336895} = "Haguenau";
$areanames{en}->{3336896} = "Saverne";
$areanames{en}->{3336897} = "Sélestat";
$areanames{en}->{3336898} = "Strasbourg";
$areanames{en}->{3336899} = "Colmar";
$areanames{en}->{3336907} = "Mulhouse";
$areanames{en}->{3336914} = "Strasbourg";
$areanames{en}->{3336919} = "Mulhouse";
$areanames{en}->{333692} = "Strasbourg";
$areanames{en}->{3336921} = "Mulhouse";
$areanames{en}->{3336927} = "Sélestat";
$areanames{en}->{3336928} = "Colmar";
$areanames{en}->{3336929} = "Mulhouse";
$areanames{en}->{3336930} = "Sélestat";
$areanames{en}->{3336931} = "Strasbourg";
$areanames{en}->{3336932} = "Strasbourg";
$areanames{en}->{3336933} = "Sélestat";
$areanames{en}->{3336934} = "Colmar";
$areanames{en}->{3336935} = "Saverne";
$areanames{en}->{3336936} = "Strasbourg";
$areanames{en}->{3336937} = "Saverne";
$areanames{en}->{3336938} = "Mulhouse";
$areanames{en}->{3336939} = "Strasbourg";
$areanames{en}->{3336940} = "Haguenau";
$areanames{en}->{3336941} = "Strasbourg";
$areanames{en}->{3336942} = "Saverne";
$areanames{en}->{3336943} = "Strasbourg";
$areanames{en}->{3336944} = "Altkirch";
$areanames{en}->{3336945} = "Colmar";
$areanames{en}->{3336946} = "Strasbourg";
$areanames{en}->{3336947} = "Sélestat";
$areanames{en}->{3336948} = "Strasbourg";
$areanames{en}->{3336949} = "Colmar";
$areanames{en}->{3336958} = "Mulhouse";
$areanames{en}->{3336960} = "Mulhouse";
$areanames{en}->{3336961} = "Strasbourg";
$areanames{en}->{3336962} = "Saverne";
$areanames{en}->{3336963} = "Altkirch";
$areanames{en}->{3336964} = "Sélestat";
$areanames{en}->{3336965} = "Mulhouse";
$areanames{en}->{3336966} = "Altkirch";
$areanames{en}->{3336967} = "Strasbourg";
$areanames{en}->{3336968} = "Strasbourg";
$areanames{en}->{3336969} = "Strasbourg";
$areanames{en}->{3336977} = "Mulhouse";
$areanames{en}->{3336978} = "Strasbourg";
$areanames{en}->{3336981} = "Strasbourg";
$areanames{en}->{3336990} = "Strasbourg";
$areanames{en}->{3336991} = "Haguenau";
$areanames{en}->{3336992} = "Saverne";
$areanames{en}->{3336993} = "Strasbourg";
$areanames{en}->{3336994} = "Strasbourg";
$areanames{en}->{3336995} = "Strasbourg";
$areanames{en}->{3336996} = "Strasbourg";
$areanames{en}->{3336997} = "Sélestat";
$areanames{en}->{3336998} = "Altkirch";
$areanames{en}->{3336999} = "Colmar";
$areanames{en}->{3337000} = "Besançon";
$areanames{en}->{3337001} = "Belfort";
$areanames{en}->{3337002} = "Besançon";
$areanames{en}->{3337003} = "Montbéliard";
$areanames{en}->{3337004} = "Belfort";
$areanames{en}->{3337005} = "Dole";
$areanames{en}->{3337006} = "Lons\-le\-Saunier";
$areanames{en}->{3337007} = "Montbéliard";
$areanames{en}->{3337008} = "Vesoul";
$areanames{en}->{3337009} = "Arbois";
$areanames{en}->{3337010} = "Belfort";
$areanames{en}->{3337011} = "Besançon";
$areanames{en}->{3337012} = "Dole";
$areanames{en}->{3337013} = "Gray";
$areanames{en}->{3337014} = "Lons\-le\-Saunier";
$areanames{en}->{3337015} = "Lure";
$areanames{en}->{3337016} = "Luxeuil\-les\-Bains";
$areanames{en}->{3337017} = "Montbéliard";
$areanames{en}->{3337018} = "Morteau";
$areanames{en}->{3337019} = "Pontarlier";
$areanames{en}->{3337020} = "Besançon";
$areanames{en}->{3337021} = "Besançon";
$areanames{en}->{3337022} = "Saint\-Claude";
$areanames{en}->{3337023} = "Vesoul";
$areanames{en}->{3337024} = "Morteau";
$areanames{en}->{3337025} = "Lure";
$areanames{en}->{3337026} = "Luxeuil\-les\-Bains";
$areanames{en}->{3337027} = "Besançon";
$areanames{en}->{3337028} = "Pontarlier";
$areanames{en}->{3337029} = "Besançon";
$areanames{en}->{3337030} = "Montbéliard";
$areanames{en}->{3337031} = "Morteau";
$areanames{en}->{3337032} = "Pontarlier";
$areanames{en}->{3337033} = "Arbois";
$areanames{en}->{3337034} = "Dole";
$areanames{en}->{3337035} = "Lons\-le\-Saunier";
$areanames{en}->{3337036} = "Saint\-Claude";
$areanames{en}->{3337037} = "Gray";
$areanames{en}->{3337038} = "Lure";
$areanames{en}->{3337039} = "Luxeuil\-les\-Bains";
$areanames{en}->{3337040} = "Vesoul";
$areanames{en}->{3337041} = "Belfort";
$areanames{en}->{3337042} = "Belfort";
$areanames{en}->{3337043} = "Lons\-le\-Saunier";
$areanames{en}->{3337044} = "Morteau";
$areanames{en}->{3337045} = "Gray";
$areanames{en}->{3337046} = "Montbéliard";
$areanames{en}->{3337047} = "Lure";
$areanames{en}->{3337048} = "Arbois";
$areanames{en}->{3337049} = "Pontarlier";
$areanames{en}->{3337050} = "Besançon";
$areanames{en}->{3337051} = "Morteau";
$areanames{en}->{3337052} = "Dole";
$areanames{en}->{3337053} = "Lons\-le\-Saunier";
$areanames{en}->{3337054} = "Saint\-Claude";
$areanames{en}->{3337055} = "Lure";
$areanames{en}->{3337056} = "Luxeuil\-les\-Bains";
$areanames{en}->{3337057} = "Vesoul";
$areanames{en}->{3337058} = "Dole";
$areanames{en}->{3337059} = "Vesoul";
$areanames{en}->{3337060} = "Saint\-Claude";
$areanames{en}->{3337061} = "Belfort";
$areanames{en}->{3337062} = "Luxeuil\-les\-Bains";
$areanames{en}->{3337063} = "Besançon";
$areanames{en}->{3337064} = "Besançon";
$areanames{en}->{3337065} = "Montbéliard";
$areanames{en}->{3337066} = "Morteau";
$areanames{en}->{3337067} = "Pontarlier";
$areanames{en}->{3337068} = "Gray";
$areanames{en}->{3337069} = "Lure";
$areanames{en}->{3337070} = "Besançon";
$areanames{en}->{3337071} = "Montbéliard";
$areanames{en}->{3337072} = "Besançon";
$areanames{en}->{3337073} = "Lons\-le\-Saunier";
$areanames{en}->{3337074} = "Lons\-le\-Saunier";
$areanames{en}->{3337075} = "Belfort";
$areanames{en}->{3337076} = "Vesoul";
$areanames{en}->{3337077} = "Besançon";
$areanames{en}->{3337078} = "Montbéliard";
$areanames{en}->{3337079} = "Arbois";
$areanames{en}->{3337080} = "Belfort";
$areanames{en}->{3337081} = "Dole";
$areanames{en}->{3337082} = "Lons\-le\-Saunier";
$areanames{en}->{3337083} = "Saint\-Claude";
$areanames{en}->{3337084} = "Luxeuil\-les\-Bains";
$areanames{en}->{3337085} = "Vesoul";
$areanames{en}->{3337086} = "Belfort";
$areanames{en}->{3337087} = "Besançon";
$areanames{en}->{3337088} = "Besançon";
$areanames{en}->{3337089} = "Montbéliard";
$areanames{en}->{3337090} = "Belfort";
$areanames{en}->{3337091} = "Morteau";
$areanames{en}->{3337092} = "Belfort";
$areanames{en}->{3337093} = "Besançon";
$areanames{en}->{3337094} = "Montbéliard";
$areanames{en}->{3337095} = "Pontarlier";
$areanames{en}->{3337096} = "Arbois";
$areanames{en}->{3337097} = "Saint\-Claude";
$areanames{en}->{3337098} = "Gray";
$areanames{en}->{3337099} = "Belfort";
$areanames{en}->{3337100} = "Is\-sur\-Tille";
$areanames{en}->{3337101} = "Joigny";
$areanames{en}->{3337102} = "Louhans";
$areanames{en}->{3337103} = "Mâcon";
$areanames{en}->{3337104} = "Montbard";
$areanames{en}->{3337105} = "Montceau\-les\-Mines";
$areanames{en}->{3337106} = "Nevers";
$areanames{en}->{3337107} = "Paray\-le\-Monial";
$areanames{en}->{3337108} = "Saulieu";
$areanames{en}->{3337109} = "Sens";
$areanames{en}->{3337110} = "Tonnerre";
$areanames{en}->{3337111} = "Toucy";
$areanames{en}->{3337112} = "Autun";
$areanames{en}->{3337113} = "Auxerre";
$areanames{en}->{3337114} = "Beaune";
$areanames{en}->{3337115} = "Dijon";
$areanames{en}->{3337116} = "Autun";
$areanames{en}->{3337117} = "Joigny";
$areanames{en}->{3337118} = "Tonnerre";
$areanames{en}->{3337119} = "Dijon";
$areanames{en}->{3337120} = "Châtillon\-sur\-Seine";
$areanames{en}->{3337121} = "Is\-sur\-Tille";
$areanames{en}->{3337122} = "Montbard";
$areanames{en}->{3337123} = "Saulieu";
$areanames{en}->{3337124} = "Château\-Chinon\(Ville\)";
$areanames{en}->{3337125} = "Cosne\-Cours\-sur\-Loire";
$areanames{en}->{3337126} = "Decize";
$areanames{en}->{3337127} = "Nevers";
$areanames{en}->{3337128} = "Autun";
$areanames{en}->{3337129} = "Chalon\-sur\-Saône";
$areanames{en}->{3337130} = "Louhans";
$areanames{en}->{3337131} = "Mâcon";
$areanames{en}->{3337132} = "Montceau\-les\-Mines";
$areanames{en}->{3337133} = "Paray\-le\-Monial";
$areanames{en}->{3337134} = "Auxerre";
$areanames{en}->{3337135} = "Joigny";
$areanames{en}->{3337136} = "Sens";
$areanames{en}->{3337137} = "Tonnerre";
$areanames{en}->{3337138} = "Toucy";
$areanames{en}->{3337139} = "Beaune";
$areanames{en}->{3337140} = "Chalon\-sur\-Saône";
$areanames{en}->{3337141} = "Mâcon";
$areanames{en}->{3337142} = "Nevers";
$areanames{en}->{3337143} = "Auxerre";
$areanames{en}->{3337144} = "Sens";
$areanames{en}->{3337145} = "Nevers";
$areanames{en}->{3337146} = "Decize";
$areanames{en}->{3337147} = "Autun";
$areanames{en}->{3337148} = "Louhans";
$areanames{en}->{3337149} = "Mâcon";
$areanames{en}->{3337150} = "Tonnerre";
$areanames{en}->{3337151} = "Toucy";
$areanames{en}->{3337152} = "Montbard";
$areanames{en}->{3337153} = "Saulieu";
$areanames{en}->{3337154} = "Château\-Chinon\(Ville\)";
$areanames{en}->{3337155} = "Cosne\-Cours\-sur\-Loire";
$areanames{en}->{3337156} = "Decize";
$areanames{en}->{3337157} = "Is\-sur\-Tille";
$areanames{en}->{3337158} = "Beaune";
$areanames{en}->{3337159} = "Château\-Chinon\(Ville\)";
$areanames{en}->{3337160} = "Châtillon\-sur\-Seine";
$areanames{en}->{3337161} = "Is\-sur\-Tille";
$areanames{en}->{3337162} = "Toucy";
$areanames{en}->{3337163} = "Mâcon";
$areanames{en}->{3337164} = "Nevers";
$areanames{en}->{3337165} = "Louhans";
$areanames{en}->{3337166} = "Autun";
$areanames{en}->{3337167} = "Auxerre";
$areanames{en}->{3337168} = "Montbard";
$areanames{en}->{3337169} = "Tonnerre";
$areanames{en}->{3337170} = "Dijon";
$areanames{en}->{3337171} = "Nevers";
$areanames{en}->{3337172} = "Paray\-le\-Monial";
$areanames{en}->{3337173} = "Châtillon\-sur\-Seine";
$areanames{en}->{3337174} = "Joigny";
$areanames{en}->{3337175} = "Sens";
$areanames{en}->{3337176} = "Chalon\-sur\-Saône";
$areanames{en}->{3337177} = "Mâcon";
$areanames{en}->{3337178} = "Auxerre";
$areanames{en}->{3337179} = "Montceau\-les\-Mines";
$areanames{en}->{3337180} = "Montceau\-les\-Mines";
$areanames{en}->{3337181} = "Dijon";
$areanames{en}->{3337182} = "Autun";
$areanames{en}->{3337183} = "Chalon\-sur\-Saône";
$areanames{en}->{3337184} = "Mâcon";
$areanames{en}->{3337185} = "Montceau\-les\-Mines";
$areanames{en}->{3337186} = "Dijon";
$areanames{en}->{3337187} = "Chalon\-sur\-Saône";
$areanames{en}->{3337188} = "Cosne\-Cours\-sur\-Loire";
$areanames{en}->{3337189} = "Saulieu";
$areanames{en}->{3337190} = "Dijon";
$areanames{en}->{3337191} = "Beaune";
$areanames{en}->{3337192} = "Châtillon\-sur\-Seine";
$areanames{en}->{3337193} = "Dijon";
$areanames{en}->{3337194} = "Is\-sur\-Tille";
$areanames{en}->{3337195} = "Montbard";
$areanames{en}->{3337196} = "Saulieu";
$areanames{en}->{3337197} = "Château\-Chinon\(Ville\)";
$areanames{en}->{3337198} = "Cosne\-Cours\-sur\-Loire";
$areanames{en}->{3337199} = "Decize";
$areanames{en}->{3337200} = "Metz";
$areanames{en}->{3337201} = "Morhange";
$areanames{en}->{3337202} = "Saint\-Avold";
$areanames{en}->{3337203} = "Sarrebourg";
$areanames{en}->{3337204} = "Sarreguemines";
$areanames{en}->{3337205} = "Thionville";
$areanames{en}->{3337206} = "Épinal";
$areanames{en}->{3337207} = "Neufchâteau";
$areanames{en}->{3337208} = "Remiremont";
$areanames{en}->{3337209} = "Saint\-Dié\-des\-Vosges";
$areanames{en}->{3337210} = "Vittel";
$areanames{en}->{3337211} = "Saint\-Dié\-des\-Vosges";
$areanames{en}->{3337212} = "Toul";
$areanames{en}->{3337213} = "Metz";
$areanames{en}->{3337214} = "Nancy";
$areanames{en}->{3337215} = "Pont\-à\-Mousson";
$areanames{en}->{3337216} = "Lunéville";
$areanames{en}->{3337217} = "Verdun";
$areanames{en}->{3337218} = "Saint\-Avold";
$areanames{en}->{3337219} = "Sarrebourg";
$areanames{en}->{3337220} = "Sarreguemines";
$areanames{en}->{3337221} = "Neufchâteau";
$areanames{en}->{3337222} = "Épinal";
$areanames{en}->{3337223} = "Nancy";
$areanames{en}->{3337224} = "Bar\-le\-Duc";
$areanames{en}->{3337225} = "Bar\-le\-Duc";
$areanames{en}->{3337226} = "Briey";
$areanames{en}->{3337227} = "Metz";
$areanames{en}->{3337228} = "Sarrebourg";
$areanames{en}->{3337229} = "Sarreguemines";
$areanames{en}->{3337230} = "Lunéville";
$areanames{en}->{3337231} = "Nancy";
$areanames{en}->{3337232} = "Pont\-à\-Mousson";
$areanames{en}->{3337233} = "Toul";
$areanames{en}->{3337234} = "Épinal";
$areanames{en}->{3337235} = "Morhange";
$areanames{en}->{3337236} = "Saint\-Avold";
$areanames{en}->{3337237} = "Thionville";
$areanames{en}->{3337238} = "Bar\-le\-Duc";
$areanames{en}->{3337239} = "Metz";
$areanames{en}->{3337240} = "Metz";
$areanames{en}->{3337241} = "Neufchâteau";
$areanames{en}->{3337242} = "Nancy";
$areanames{en}->{3337243} = "Metz";
$areanames{en}->{3337244} = "Épinal";
$areanames{en}->{3337245} = "Nancy";
$areanames{en}->{3337246} = "Verdun";
$areanames{en}->{3337247} = "Nancy";
$areanames{en}->{3337248} = "Metz";
$areanames{en}->{3337249} = "Thionville";
$areanames{en}->{3337250} = "Épinal";
$areanames{en}->{3337251} = "Metz";
$areanames{en}->{3337252} = "Thionville";
$areanames{en}->{3337253} = "Saint\-Avold";
$areanames{en}->{3337254} = "Épinal";
$areanames{en}->{3337255} = "Bar\-le\-Duc";
$areanames{en}->{3337256} = "Briey";
$areanames{en}->{3337257} = "Metz";
$areanames{en}->{3337258} = "Saint\-Dié\-des\-Vosges";
$areanames{en}->{3337259} = "Lunéville";
$areanames{en}->{3337260} = "Metz";
$areanames{en}->{3337261} = "Nancy";
$areanames{en}->{3337262} = "Bar\-le\-Duc";
$areanames{en}->{3337263} = "Nancy";
$areanames{en}->{3337264} = "Sarreguemines";
$areanames{en}->{3337265} = "Verdun";
$areanames{en}->{3337266} = "Sarrebourg";
$areanames{en}->{3337267} = "Remiremont";
$areanames{en}->{3337268} = "Briey";
$areanames{en}->{3337269} = "Morhange";
$areanames{en}->{3337270} = "Metz";
$areanames{en}->{3337271} = "Nancy";
$areanames{en}->{3337272} = "Metz";
$areanames{en}->{3337273} = "Épinal";
$areanames{en}->{3337274} = "Nancy";
$areanames{en}->{3337275} = "Pont\-à\-Mousson";
$areanames{en}->{3337276} = "Toul";
$areanames{en}->{3337277} = "Morhange";
$areanames{en}->{3337278} = "Neufchâteau";
$areanames{en}->{3337279} = "Vittel";
$areanames{en}->{3337280} = "Thionville";
$areanames{en}->{3337281} = "Nancy";
$areanames{en}->{3337282} = "Saint\-Avold";
$areanames{en}->{3337283} = "Metz";
$areanames{en}->{3337284} = "Nancy";
$areanames{en}->{3337285} = "Verdun";
$areanames{en}->{3337286} = "Épinal";
$areanames{en}->{3337287} = "Metz";
$areanames{en}->{3337288} = "Metz";
$areanames{en}->{3337289} = "Remiremont";
$areanames{en}->{3337290} = "Metz";
$areanames{en}->{3337291} = "Nancy";
$areanames{en}->{3337292} = "Verdun";
$areanames{en}->{3337293} = "Briey";
$areanames{en}->{3337294} = "Sarreguemines";
$areanames{en}->{3337295} = "Briey";
$areanames{en}->{3337296} = "Lunéville";
$areanames{en}->{3337297} = "Pont\-à\-Mousson";
$areanames{en}->{3337298} = "Toul";
$areanames{en}->{3337299} = "Neufchâteau";
$areanames{en}->{3337300} = "Nevers";
$areanames{en}->{3337301} = "Autun";
$areanames{en}->{3337302} = "Chalon\-sur\-Saône";
$areanames{en}->{3337303} = "Louhans";
$areanames{en}->{3337304} = "Mâcon";
$areanames{en}->{3337305} = "Montceau\-les\-Mines";
$areanames{en}->{3337306} = "Paray\-le\-Monial";
$areanames{en}->{3337307} = "Auxerre";
$areanames{en}->{3337308} = "Joigny";
$areanames{en}->{3337309} = "Sens";
$areanames{en}->{3337310} = "Tonnerre";
$areanames{en}->{3337311} = "Toucy";
$areanames{en}->{3337312} = "Chalon\-sur\-Saône";
$areanames{en}->{3337313} = "Dijon";
$areanames{en}->{3337314} = "Château\-Chinon\(Ville\)";
$areanames{en}->{3337315} = "Decize";
$areanames{en}->{3337316} = "Autun";
$areanames{en}->{3337317} = "Louhans";
$areanames{en}->{3337318} = "Mâcon";
$areanames{en}->{3337319} = "Tonnerre";
$areanames{en}->{3337320} = "Toucy";
$areanames{en}->{3337321} = "Château\-Chinon\(Ville\)";
$areanames{en}->{3337322} = "Cosne\-Cours\-sur\-Loire";
$areanames{en}->{3337323} = "Decize";
$areanames{en}->{3337324} = "Nevers";
$areanames{en}->{3337325} = "Dijon";
$areanames{en}->{3337326} = "Dijon";
$areanames{en}->{3337327} = "Dijon";
$areanames{en}->{3337328} = "Beaune";
$areanames{en}->{3337329} = "Châtillon\-sur\-Seine";
$areanames{en}->{3337330} = "Dijon";
$areanames{en}->{3337331} = "Is\-sur\-Tille";
$areanames{en}->{3337332} = "Montbard";
$areanames{en}->{3337333} = "Saulieu";
$areanames{en}->{3337334} = "Autun";
$areanames{en}->{3337335} = "Chalon\-sur\-Saône";
$areanames{en}->{3337336} = "Louhans";
$areanames{en}->{3337337} = "Mâcon";
$areanames{en}->{3337338} = "Montceau\-les\-Mines";
$areanames{en}->{3337339} = "Paray\-le\-Monial";
$areanames{en}->{3337340} = "Auxerre";
$areanames{en}->{3337341} = "Joigny";
$areanames{en}->{3337342} = "Sens";
$areanames{en}->{3337343} = "Tonnerre";
$areanames{en}->{3337344} = "Toucy";
$areanames{en}->{3337345} = "Dijon";
$areanames{en}->{3337346} = "Dijon";
$areanames{en}->{3337347} = "Auxerre";
$areanames{en}->{3337348} = "Chalon\-sur\-Saône";
$areanames{en}->{3337349} = "Nevers";
$areanames{en}->{3337350} = "Mâcon";
$areanames{en}->{3337351} = "Sens";
$areanames{en}->{3337352} = "Chalon\-sur\-Saône";
$areanames{en}->{3337353} = "Auxerre";
$areanames{en}->{3337354} = "Auxerre";
$areanames{en}->{3337355} = "Dijon";
$areanames{en}->{3337356} = "Sens";
$areanames{en}->{3337357} = "Montceau\-les\-Mines";
$areanames{en}->{3337358} = "Cosne\-Cours\-sur\-Loire";
$areanames{en}->{3337359} = "Joigny";
$areanames{en}->{3337360} = "Paray\-le\-Monial";
$areanames{en}->{3337361} = "Sens";
$areanames{en}->{3337362} = "Dijon";
$areanames{en}->{3337363} = "Dijon";
$areanames{en}->{3337364} = "Beaune";
$areanames{en}->{3337365} = "Châtillon\-sur\-Seine";
$areanames{en}->{3337366} = "Is\-sur\-Tille";
$areanames{en}->{3337367} = "Montbard";
$areanames{en}->{3337368} = "Saulieu";
$areanames{en}->{3337369} = "Château\-Chinon\(Ville\)";
$areanames{en}->{3337370} = "Decize";
$areanames{en}->{3337371} = "Autun";
$areanames{en}->{3337372} = "Chalon\-sur\-Saône";
$areanames{en}->{3337373} = "Dijon";
$areanames{en}->{3337374} = "Auxerre";
$areanames{en}->{3337375} = "Dijon";
$areanames{en}->{3337376} = "Beaune";
$areanames{en}->{3337377} = "Mâcon";
$areanames{en}->{3337378} = "Châtillon\-sur\-Seine";
$areanames{en}->{3337379} = "Is\-sur\-Tille";
$areanames{en}->{3337380} = "Chalon\-sur\-Saône";
$areanames{en}->{3337381} = "Chalon\-sur\-Saône";
$areanames{en}->{3337382} = "Paray\-le\-Monial";
$areanames{en}->{3337383} = "Mâcon";
$areanames{en}->{3337384} = "Dijon";
$areanames{en}->{3337385} = "Dijon";
$areanames{en}->{3337386} = "Montbard";
$areanames{en}->{3337387} = "Saulieu";
$areanames{en}->{3337388} = "Dijon";
$areanames{en}->{3337389} = "Sens";
$areanames{en}->{3337390} = "Louhans";
$areanames{en}->{3337391} = "Tonnerre";
$areanames{en}->{3337392} = "Toucy";
$areanames{en}->{3337393} = "Nevers";
$areanames{en}->{3337394} = "Château\-Chinon\(Ville\)";
$areanames{en}->{3337395} = "Cosne\-Cours\-sur\-Loire";
$areanames{en}->{3337396} = "Decize";
$areanames{en}->{3337397} = "Nevers";
$areanames{en}->{3337398} = "Chalon\-sur\-Saône";
$areanames{en}->{3337399} = "Chalon\-sur\-Saône";
$areanames{en}->{3337400} = "Lille";
$areanames{en}->{3337401} = "Valenciennes";
$areanames{en}->{3337402} = "Lille";
$areanames{en}->{3337403} = "Béthune";
$areanames{en}->{3337404} = "Arras";
$areanames{en}->{3337405} = "Béthune";
$areanames{en}->{3337406} = "Dunkerque";
$areanames{en}->{3337407} = "Lille";
$areanames{en}->{3337408} = "Lille";
$areanames{en}->{3337409} = "Lille";
$areanames{en}->{3337410} = "Calais";
$areanames{en}->{3337411} = "Lille";
$areanames{en}->{3337412} = "Calais";
$areanames{en}->{3337413} = "Dunkerque";
$areanames{en}->{3337414} = "Lens";
$areanames{en}->{3337415} = "Valenciennes";
$areanames{en}->{3337416} = "Douai";
$areanames{en}->{3337417} = "Arras";
$areanames{en}->{3337418} = "Saint\-Omer";
$areanames{en}->{3337419} = "Hazebrouck";
$areanames{en}->{3337420} = "Montreuil";
$areanames{en}->{3337421} = "Saint\-Pol\-sur\-Ternoise";
$areanames{en}->{3337422} = "Douai";
$areanames{en}->{3337423} = "Lille";
$areanames{en}->{3337424} = "Lens";
$areanames{en}->{3337425} = "Calais";
$areanames{en}->{3337426} = "Lille";
$areanames{en}->{3337427} = "Lille";
$areanames{en}->{3337428} = "Lille";
$areanames{en}->{3337429} = "Lille";
$areanames{en}->{3337430} = "Dunkerque";
$areanames{en}->{3337431} = "Dunkerque";
$areanames{en}->{3337432} = "Lille";
$areanames{en}->{3337433} = "Hazebrouck";
$areanames{en}->{3337434} = "Maubeuge";
$areanames{en}->{3337435} = "Béthune";
$areanames{en}->{3337436} = "Montreuil";
$areanames{en}->{3337437} = "Saint\-Omer";
$areanames{en}->{3337438} = "Saint\-Pol\-sur\-Ternoise";
$areanames{en}->{3337439} = "Arras";
$areanames{en}->{333744} = "Lille";
$areanames{en}->{3337440} = "Valenciennes";
$areanames{en}->{3337441} = "Arras";
$areanames{en}->{3337442} = "Maubeuge";
$areanames{en}->{3337443} = "Arras";
$areanames{en}->{3337450} = "Lille";
$areanames{en}->{3337451} = "Cambrai";
$areanames{en}->{3337452} = "Douai";
$areanames{en}->{3337453} = "Dunkerque";
$areanames{en}->{3337454} = "Hazebrouck";
$areanames{en}->{3337455} = "Le\ Cateau\-Cambresis";
$areanames{en}->{3337456} = "Lille";
$areanames{en}->{3337457} = "Maubeuge";
$areanames{en}->{3337458} = "Valenciennes";
$areanames{en}->{3337459} = "Arras";
$areanames{en}->{3337460} = "Béthune";
$areanames{en}->{3337461} = "Calais";
$areanames{en}->{3337462} = "Lens";
$areanames{en}->{3337463} = "Montreuil";
$areanames{en}->{3337464} = "Saint\-Omer";
$areanames{en}->{3337465} = "Saint\-Pol\-sur\-Ternoise";
$areanames{en}->{3337466} = "Lille";
$areanames{en}->{3337467} = "Lille";
$areanames{en}->{3337468} = "Lille";
$areanames{en}->{3337469} = "Lille";
$areanames{en}->{3337470} = "Douai";
$areanames{en}->{3337471} = "Lens";
$areanames{en}->{3337472} = "Lille";
$areanames{en}->{3337473} = "Calais";
$areanames{en}->{3337474} = "Lille";
$areanames{en}->{3337475} = "Valenciennes";
$areanames{en}->{3337476} = "Lille";
$areanames{en}->{3337477} = "Le\ Cateau\-Cambresis";
$areanames{en}->{3337478} = "Cambrai";
$areanames{en}->{3337479} = "Calais";
$areanames{en}->{3337480} = "Dunkerque";
$areanames{en}->{3337481} = "Hazebrouck";
$areanames{en}->{3337482} = "Lille";
$areanames{en}->{3337483} = "Lens";
$areanames{en}->{3337484} = "Lille";
$areanames{en}->{3337485} = "Lille";
$areanames{en}->{3337486} = "Cambrai";
$areanames{en}->{3337487} = "Le\ Cateau\-Cambresis";
$areanames{en}->{3337488} = "Douai";
$areanames{en}->{3337489} = "Dunkerque";
$areanames{en}->{3337490} = "Hazebrouck";
$areanames{en}->{3337491} = "Lille";
$areanames{en}->{3337492} = "Maubeuge";
$areanames{en}->{3337493} = "Valenciennes";
$areanames{en}->{3337494} = "Saint\-Pol\-sur\-Ternoise";
$areanames{en}->{3337495} = "Lille";
$areanames{en}->{3337496} = "Calais";
$areanames{en}->{3337497} = "Cambrai";
$areanames{en}->{3337498} = "Le\ Cateau\-Cambresis";
$areanames{en}->{3337499} = "Lille";
$areanames{en}->{3337500} = "Amiens";
$areanames{en}->{3337501} = "Soissons";
$areanames{en}->{3337502} = "Laon";
$areanames{en}->{3337503} = "Péronne";
$areanames{en}->{3337504} = "Chauny";
$areanames{en}->{3337505} = "Château\-Thierry";
$areanames{en}->{3337506} = "Abbeville";
$areanames{en}->{3337507} = "Albert";
$areanames{en}->{3337508} = "Amiens";
$areanames{en}->{3337509} = "Péronne";
$areanames{en}->{3337510} = "Hirson";
$areanames{en}->{3337511} = "Clermont";
$areanames{en}->{3337512} = "Crépy\-en\-Valois";
$areanames{en}->{3337513} = "Albert";
$areanames{en}->{3337514} = "Amiens";
$areanames{en}->{3337515} = "Beauvais";
$areanames{en}->{3337516} = "Abbeville";
$areanames{en}->{3337517} = "Beauvais";
$areanames{en}->{3337518} = "Soissons";
$areanames{en}->{3337519} = "Creil";
$areanames{en}->{3337520} = "Albert";
$areanames{en}->{3337521} = "Saint\-Quentin";
$areanames{en}->{3337522} = "Château\-Thierry";
$areanames{en}->{3337523} = "Amiens";
$areanames{en}->{3337524} = "Compiègne";
$areanames{en}->{3337525} = "Beauvais";
$areanames{en}->{3337526} = "Saint\-Quentin";
$areanames{en}->{3337527} = "Crépy\-en\-Valois";
$areanames{en}->{3337528} = "Creil";
$areanames{en}->{3337529} = "Creil";
$areanames{en}->{3337530} = "Chauny";
$areanames{en}->{3337531} = "Hirson";
$areanames{en}->{3337532} = "Laon";
$areanames{en}->{3337533} = "Soissons";
$areanames{en}->{3337534} = "Clermont";
$areanames{en}->{3337535} = "Creil";
$areanames{en}->{3337536} = "Crépy\-en\-Valois";
$areanames{en}->{3337537} = "Abbeville";
$areanames{en}->{3337538} = "Albert";
$areanames{en}->{3337539} = "Péronne";
$areanames{en}->{3337540} = "Amiens";
$areanames{en}->{3337541} = "Beauvais";
$areanames{en}->{3337542} = "Laon";
$areanames{en}->{3337543} = "Saint\-Quentin";
$areanames{en}->{3337544} = "Amiens";
$areanames{en}->{3337545} = "Compiègne";
$areanames{en}->{3337546} = "Compiègne";
$areanames{en}->{3337547} = "Amiens";
$areanames{en}->{3337548} = "Péronne";
$areanames{en}->{3337549} = "Château\-Thierry";
$areanames{en}->{3337550} = "Amiens";
$areanames{en}->{3337551} = "Château\-Thierry";
$areanames{en}->{3337552} = "Chauny";
$areanames{en}->{3337553} = "Hirson";
$areanames{en}->{3337554} = "Laon";
$areanames{en}->{3337555} = "Saint\-Quentin";
$areanames{en}->{3337556} = "Soissons";
$areanames{en}->{3337557} = "Beauvais";
$areanames{en}->{3337558} = "Clermont";
$areanames{en}->{3337559} = "Compiègne";
$areanames{en}->{3337560} = "Creil";
$areanames{en}->{3337561} = "Crépy\-en\-Valois";
$areanames{en}->{3337562} = "Abbeville";
$areanames{en}->{3337563} = "Albert";
$areanames{en}->{3337564} = "Amiens";
$areanames{en}->{3337565} = "Péronne";
$areanames{en}->{3337566} = "Saint\-Quentin";
$areanames{en}->{3337567} = "Beauvais";
$areanames{en}->{3337568} = "Abbeville";
$areanames{en}->{3337569} = "Amiens";
$areanames{en}->{3337570} = "Château\-Thierry";
$areanames{en}->{3337571} = "Saint\-Quentin";
$areanames{en}->{3337600} = "Lille";
$areanames{en}->{3337601} = "Lille";
$areanames{en}->{3337602} = "Lens";
$areanames{en}->{3337603} = "Saint\-Omer";
$areanames{en}->{3337604} = "Lille";
$areanames{en}->{3337605} = "Lille";
$areanames{en}->{3337606} = "Lens";
$areanames{en}->{3337900} = "Autun";
$areanames{en}->{3337901} = "Louhans";
$areanames{en}->{3337902} = "Montceau\-les\-Mines";
$areanames{en}->{3337903} = "Paray\-le\-Monial";
$areanames{en}->{3337904} = "Auxerre";
$areanames{en}->{3337905} = "Joigny";
$areanames{en}->{3337906} = "Tonnerre";
$areanames{en}->{3337907} = "Toucy";
$areanames{en}->{3337908} = "Auxerre";
$areanames{en}->{3337909} = "Nevers";
$areanames{en}->{3337910} = "Dijon";
$areanames{en}->{3337911} = "Beaune";
$areanames{en}->{3337912} = "Châtillon\-sur\-Seine";
$areanames{en}->{3337913} = "Dijon";
$areanames{en}->{3337914} = "Is\-sur\-Tille";
$areanames{en}->{3337915} = "Montbard";
$areanames{en}->{3337916} = "Saulieu";
$areanames{en}->{3337917} = "Château\-Chinon\(Ville\)";
$areanames{en}->{3337918} = "Cosne\-Cours\-sur\-Loire";
$areanames{en}->{3337919} = "Decize";
$areanames{en}->{3337920} = "Nevers";
$areanames{en}->{3337921} = "Autun";
$areanames{en}->{3337922} = "Chalon\-sur\-Saône";
$areanames{en}->{3337923} = "Louhans";
$areanames{en}->{3337924} = "Mâcon";
$areanames{en}->{3337925} = "Montceau\-les\-Mines";
$areanames{en}->{3337926} = "Paray\-le\-Monial";
$areanames{en}->{3337927} = "Auxerre";
$areanames{en}->{3337928} = "Joigny";
$areanames{en}->{3337929} = "Sens";
$areanames{en}->{3337930} = "Tonnerre";
$areanames{en}->{3337931} = "Toucy";
$areanames{en}->{3337932} = "Nevers";
$areanames{en}->{3337933} = "Dijon";
$areanames{en}->{3337934} = "Chalon\-sur\-Saône";
$areanames{en}->{3337935} = "Mâcon";
$areanames{en}->{3337936} = "Dijon";
$areanames{en}->{3337937} = "Mâcon";
$areanames{en}->{3337938} = "Chalon\-sur\-Saône";
$areanames{en}->{3337939} = "Autun";
$areanames{en}->{3337940} = "Louhans";
$areanames{en}->{3337941} = "Mâcon";
$areanames{en}->{3337942} = "Mâcon";
$areanames{en}->{3337943} = "Montceau\-les\-Mines";
$areanames{en}->{3337944} = "Dijon";
$areanames{en}->{333800} = "Nord\ Est";
$areanames{en}->{3338009} = "Dijon";
$areanames{en}->{3338010} = "Dijon";
$areanames{en}->{3338022} = "Beaune";
$areanames{en}->{3338024} = "Beaune";
$areanames{en}->{3338025} = "Beaune";
$areanames{en}->{3338027} = "Auxonne";
$areanames{en}->{3338028} = "Dijon";
$areanames{en}->{3338029} = "Brazey\-en\-Plaine";
$areanames{en}->{3338030} = "Dijon";
$areanames{en}->{3338031} = "Auxonne";
$areanames{en}->{3338032} = "Brazey\-en\-Plaine";
$areanames{en}->{3338034} = "Gevrey\-Chambertin";
$areanames{en}->{3338037} = "Auxonne";
$areanames{en}->{3338038} = "Dijon";
$areanames{en}->{3338041} = "Dijon";
$areanames{en}->{3338042} = "Dijon";
$areanames{en}->{3338043} = "Dijon";
$areanames{en}->{3338044} = "Dijon";
$areanames{en}->{3338045} = "Dijon";
$areanames{en}->{3338046} = "Quetigny";
$areanames{en}->{3338048} = "Quetigny";
$areanames{en}->{3338049} = "Dijon";
$areanames{en}->{333805} = "Dijon";
$areanames{en}->{3338051} = "Chenôve";
$areanames{en}->{3338052} = "Chenôve";
$areanames{en}->{3338056} = "Fontaine\-lès\-Dijon";
$areanames{en}->{3338057} = "Talant";
$areanames{en}->{3338060} = "Dijon";
$areanames{en}->{3338061} = "Nuits\-Saint\-Georges";
$areanames{en}->{3338062} = "Nuits\-Saint\-Georges";
$areanames{en}->{3338063} = "Dijon";
$areanames{en}->{3338064} = "Saulieu";
$areanames{en}->{3338065} = "Dijon";
$areanames{en}->{3338066} = "Dijon";
$areanames{en}->{3338067} = "Dijon";
$areanames{en}->{3338068} = "Dijon";
$areanames{en}->{333807} = "Dijon";
$areanames{en}->{3338075} = "Is\-sur\-Tille";
$areanames{en}->{3338089} = "Montbard";
$areanames{en}->{3338090} = "Pouilly\-en\-Auxois";
$areanames{en}->{3338091} = "Châtillon\-sur\-Seine";
$areanames{en}->{3338092} = "Montbard";
$areanames{en}->{3338095} = "Is\-sur\-Tille";
$areanames{en}->{3338097} = "Semur\-en\-Auxois";
$areanames{en}->{333810} = "Nord\ Est";
$areanames{en}->{3338102} = "Montbéliard";
$areanames{en}->{333811} = "Nord\ Est";
$areanames{en}->{3338121} = "Besançon";
$areanames{en}->{3338125} = "Besançon";
$areanames{en}->{3338130} = "Audincourt";
$areanames{en}->{3338131} = "Montbéliard";
$areanames{en}->{3338132} = "Montbéliard";
$areanames{en}->{3338134} = "Audincourt";
$areanames{en}->{3338135} = "Audincourt";
$areanames{en}->{3338136} = "Audincourt";
$areanames{en}->{3338137} = "Valentigney";
$areanames{en}->{3338138} = "Pontarlier";
$areanames{en}->{3338139} = "Pontarlier";
$areanames{en}->{3338140} = "Besançon";
$areanames{en}->{3338141} = "Besançon";
$areanames{en}->{3338146} = "Pontarlier";
$areanames{en}->{3338147} = "Besançon";
$areanames{en}->{3338148} = "Besançon";
$areanames{en}->{3338150} = "Besançon";
$areanames{en}->{3338151} = "Besançon";
$areanames{en}->{3338152} = "Besançon";
$areanames{en}->{3338153} = "Besançon";
$areanames{en}->{3338156} = "Valdahon";
$areanames{en}->{3338161} = "Besançon";
$areanames{en}->{3338162} = "Ornans";
$areanames{en}->{3338164} = "Maîche";
$areanames{en}->{3338165} = "Besançon";
$areanames{en}->{3338167} = "Morteau";
$areanames{en}->{3338168} = "Villers\-le\-Lac";
$areanames{en}->{333817} = "Nord\ Est";
$areanames{en}->{3338170} = "Morteau";
$areanames{en}->{3338171} = "Montbéliard";
$areanames{en}->{3338172} = "Montbéliard";
$areanames{en}->{3338180} = "Besançon";
$areanames{en}->{3338181} = "Besançon";
$areanames{en}->{3338182} = "Besançon";
$areanames{en}->{3338183} = "Besançon";
$areanames{en}->{3338184} = "Baume\-les\-Dames";
$areanames{en}->{3338185} = "Besançon";
$areanames{en}->{3338187} = "Saint\-Vit";
$areanames{en}->{3338188} = "Besançon";
$areanames{en}->{3338190} = "Montbéliard";
$areanames{en}->{3338191} = "Montbéliard";
$areanames{en}->{3338192} = "Pont\-de\-Roide";
$areanames{en}->{3338194} = "Montbéliard";
$areanames{en}->{3338195} = "Montbéliard";
$areanames{en}->{3338197} = "Montbéliard";
$areanames{en}->{3338198} = "Montbéliard";
$areanames{en}->{3338199} = "Montbéliard";
$areanames{en}->{333820} = "Nord\ Est";
$areanames{en}->{333821} = "Nord\ Est";
$areanames{en}->{3338210} = "Thionville";
$areanames{en}->{3338211} = "Thionville";
$areanames{en}->{3338212} = "Thionville";
$areanames{en}->{3338222} = "Jœuf";
$areanames{en}->{3338223} = "Longwy";
$areanames{en}->{3338224} = "Longwy";
$areanames{en}->{3338225} = "Longwy";
$areanames{en}->{3338226} = "Longuyon";
$areanames{en}->{3338233} = "Jarny";
$areanames{en}->{3338234} = "Thionville";
$areanames{en}->{3338239} = "Longuyon";
$areanames{en}->{3338246} = "Briey";
$areanames{en}->{3338251} = "Thionville";
$areanames{en}->{3338252} = "Audun\-le\-Tiche";
$areanames{en}->{3338253} = "Thionville";
$areanames{en}->{3338254} = "Thionville";
$areanames{en}->{3338255} = "Cattenom";
$areanames{en}->{3338256} = "Yutz";
$areanames{en}->{3338257} = "Florange";
$areanames{en}->{3338258} = "Florange";
$areanames{en}->{3338259} = "Thionville";
$areanames{en}->{333826} = "Nord\ Est";
$areanames{en}->{333827} = "Nord\ Est";
$areanames{en}->{3338282} = "Thionville";
$areanames{en}->{3338284} = "Hayange";
$areanames{en}->{3338285} = "Hayange";
$areanames{en}->{3338286} = "Uckange";
$areanames{en}->{3338288} = "Thionville";
$areanames{en}->{3338289} = "Villerupt";
$areanames{en}->{3338291} = "Aumetz";
$areanames{en}->{333830} = "Nord\ Est";
$areanames{en}->{3338304} = "Nancy";
$areanames{en}->{3338307} = "Nancy";
$areanames{en}->{3338315} = "Ludres";
$areanames{en}->{3338317} = "Nancy";
$areanames{en}->{3338318} = "Nancy";
$areanames{en}->{3338319} = "Nancy";
$areanames{en}->{3338322} = "Bouxières\-aux\-Dames";
$areanames{en}->{3338323} = "Velaine\-en\-Haye";
$areanames{en}->{3338324} = "Liverdun";
$areanames{en}->{3338325} = "Ludres";
$areanames{en}->{3338327} = "Nancy";
$areanames{en}->{3338328} = "Nancy";
$areanames{en}->{3338330} = "Nancy";
$areanames{en}->{3338332} = "Nancy";
$areanames{en}->{3338333} = "Nancy";
$areanames{en}->{3338335} = "Nancy";
$areanames{en}->{3338336} = "Nancy";
$areanames{en}->{3338337} = "Nancy";
$areanames{en}->{3338338} = "Champigneulles";
$areanames{en}->{3338339} = "Nancy";
$areanames{en}->{3338340} = "Nancy";
$areanames{en}->{3338341} = "Nancy";
$areanames{en}->{3338343} = "Toul";
$areanames{en}->{3338344} = "Vandœuvre\-lès\-Nancy";
$areanames{en}->{3338345} = "Dombasle\-sur\-Meurthe";
$areanames{en}->{3338347} = "Neuves\-Maisons";
$areanames{en}->{3338348} = "Dombasle\-sur\-Meurthe";
$areanames{en}->{3338349} = "Pompey";
$areanames{en}->{333835} = "Vandœuvre\-lès\-Nancy";
$areanames{en}->{3338363} = "Toul";
$areanames{en}->{3338364} = "Toul";
$areanames{en}->{3338367} = "Nancy";
$areanames{en}->{3338373} = "Lunéville";
$areanames{en}->{3338374} = "Lunéville";
$areanames{en}->{3338375} = "Baccarat";
$areanames{en}->{3338376} = "Lunéville";
$areanames{en}->{3338380} = "Pont\-à\-Mousson";
$areanames{en}->{3338381} = "Pont\-à\-Mousson";
$areanames{en}->{3338382} = "Pont\-à\-Mousson";
$areanames{en}->{3338383} = "Pont\-à\-Mousson";
$areanames{en}->{3338384} = "Pont\-à\-Mousson";
$areanames{en}->{3338385} = "Nancy";
$areanames{en}->{3338389} = "Lunéville";
$areanames{en}->{333839} = "Nancy";
$areanames{en}->{3338399} = "Nord\ Est";
$areanames{en}->{333840} = "Nord\ Est";
$areanames{en}->{333841} = "Nord\ Est";
$areanames{en}->{3338419} = "Belfort";
$areanames{en}->{3338421} = "Belfort";
$areanames{en}->{3338422} = "Belfort";
$areanames{en}->{3338424} = "Lons\-le\-Saunier";
$areanames{en}->{3338426} = "Belfort";
$areanames{en}->{3338428} = "Belfort";
$areanames{en}->{3338430} = "Lure";
$areanames{en}->{3338433} = "Morez";
$areanames{en}->{3338436} = "Delle";
$areanames{en}->{3338437} = "Poligny";
$areanames{en}->{3338440} = "Luxeuil\-les\-Bains";
$areanames{en}->{3338442} = "Moirans\-en\-Montagne";
$areanames{en}->{3338443} = "Lons\-le\-Saunier";
$areanames{en}->{3338445} = "Saint\-Claude";
$areanames{en}->{3338446} = "Héricourt";
$areanames{en}->{3338447} = "Lons\-le\-Saunier";
$areanames{en}->{3338449} = "Fougerolles";
$areanames{en}->{3338452} = "Champagnole";
$areanames{en}->{3338454} = "Belfort";
$areanames{en}->{3338456} = "Beaucourt";
$areanames{en}->{3338457} = "Belfort";
$areanames{en}->{3338458} = "Belfort";
$areanames{en}->{3338460} = "Les\ Rousses";
$areanames{en}->{3338462} = "Lure";
$areanames{en}->{3338464} = "Gray";
$areanames{en}->{3338465} = "Gray";
$areanames{en}->{3338466} = "Arbois";
$areanames{en}->{3338469} = "Dole";
$areanames{en}->{3338472} = "Dole";
$areanames{en}->{3338473} = "Salins\-les\-Bains";
$areanames{en}->{3338474} = "Mollans";
$areanames{en}->{3338475} = "Vesoul";
$areanames{en}->{3338476} = "Vesoul";
$areanames{en}->{3338479} = "Dole";
$areanames{en}->{3338482} = "Dole";
$areanames{en}->{3338486} = "Lons\-le\-Saunier";
$areanames{en}->{3338487} = "Lons\-le\-Saunier";
$areanames{en}->{3338490} = "Belfort";
$areanames{en}->{3338493} = "Luxeuil\-les\-Bains";
$areanames{en}->{3338495} = "Saulx";
$areanames{en}->{3338496} = "Vesoul";
$areanames{en}->{3338497} = "Vesoul";
$areanames{en}->{333850} = "Nord\ Est";
$areanames{en}->{333851} = "Nord\ Est";
$areanames{en}->{3338520} = "Mâcon";
$areanames{en}->{3338521} = "Mâcon";
$areanames{en}->{3338522} = "Mâcon";
$areanames{en}->{3338525} = "Marcigny";
$areanames{en}->{3338526} = "Chauffailles";
$areanames{en}->{3338528} = "La\ Clayette";
$areanames{en}->{3338529} = "Mâcon";
$areanames{en}->{3338531} = "Replonges";
$areanames{en}->{3338532} = "Tournus";
$areanames{en}->{3338534} = "Mâcon";
$areanames{en}->{3338538} = "Mâcon";
$areanames{en}->{3338539} = "Mâcon";
$areanames{en}->{333854} = "Chalon\-sur\-Saône";
$areanames{en}->{3338540} = "Mâcon";
$areanames{en}->{3338551} = "Tournus";
$areanames{en}->{3338552} = "Autun";
$areanames{en}->{3338553} = "Digoin";
$areanames{en}->{3338555} = "Le\ Creusot";
$areanames{en}->{3338556} = "Le\ Creusot";
$areanames{en}->{3338557} = "Montceau\-les\-Mines";
$areanames{en}->{3338558} = "Montceau\-les\-Mines";
$areanames{en}->{3338559} = "Cluny";
$areanames{en}->{3338567} = "Montceau\-les\-Mines";
$areanames{en}->{3338568} = "Blanzy";
$areanames{en}->{3338569} = "Montceau\-les\-Mines";
$areanames{en}->{3338573} = "Le\ Creusot";
$areanames{en}->{3338575} = "Louhans";
$areanames{en}->{3338577} = "Le\ Creusot";
$areanames{en}->{3338578} = "Montchanin";
$areanames{en}->{3338580} = "Le\ Creusot";
$areanames{en}->{3338581} = "Paray\-le\-Monial";
$areanames{en}->{3338585} = "Gueugnon";
$areanames{en}->{3338586} = "Autun";
$areanames{en}->{3338587} = "Chagny";
$areanames{en}->{3338588} = "Digoin";
$areanames{en}->{3338589} = "Bourbon\-Lancy";
$areanames{en}->{3338590} = "Chalon\-sur\-Saône";
$areanames{en}->{3338592} = "Buxy";
$areanames{en}->{3338593} = "Chalon\-sur\-Saône";
$areanames{en}->{3338594} = "Chalon\-sur\-Saône";
$areanames{en}->{3338597} = "Chalon\-sur\-Saône";
$areanames{en}->{3338598} = "Châtenoy\-le\-Royal";
$areanames{en}->{333860} = "Nord\ Est";
$areanames{en}->{3338618} = "Auxerre";
$areanames{en}->{3338620} = "Corbigny";
$areanames{en}->{3338621} = "Nevers";
$areanames{en}->{3338622} = "Lormes";
$areanames{en}->{3338623} = "Nevers";
$areanames{en}->{3338624} = "Clamecy";
$areanames{en}->{3338625} = "Decize";
$areanames{en}->{3338626} = "Cosne\-Cours\-sur\-Loire";
$areanames{en}->{3338627} = "Clamecy";
$areanames{en}->{3338628} = "Cosne\-Cours\-sur\-Loire";
$areanames{en}->{3338630} = "Luzy";
$areanames{en}->{3338631} = "Avallon";
$areanames{en}->{3338634} = "Avallon";
$areanames{en}->{3338635} = "Saint\-Florentin";
$areanames{en}->{3338636} = "Nevers";
$areanames{en}->{3338639} = "Pouilly\-sur\-Loire";
$areanames{en}->{3338640} = "Monéteau";
$areanames{en}->{3338642} = "Chablis";
$areanames{en}->{3338643} = "Saint\-Florentin";
$areanames{en}->{3338644} = "Toucy";
$areanames{en}->{3338646} = "Auxerre";
$areanames{en}->{3338648} = "Auxerre";
$areanames{en}->{3338649} = "Auxerre";
$areanames{en}->{3338651} = "Auxerre";
$areanames{en}->{3338652} = "Auxerre";
$areanames{en}->{3338653} = "Appoigny";
$areanames{en}->{3338654} = "Tonnerre";
$areanames{en}->{3338655} = "Tonnerre";
$areanames{en}->{3338656} = "Brienon\-sur\-Armançon";
$areanames{en}->{3338657} = "Nevers";
$areanames{en}->{3338659} = "Nevers";
$areanames{en}->{3338661} = "Nevers";
$areanames{en}->{3338662} = "Joigny";
$areanames{en}->{3338664} = "Sens";
$areanames{en}->{3338665} = "Sens";
$areanames{en}->{3338666} = "Villeneuve\-la\-Guyard";
$areanames{en}->{3338667} = "Pont\-sur\-Yonne";
$areanames{en}->{3338668} = "Prémery";
$areanames{en}->{3338670} = "La\ Charité\ sur\ Loire";
$areanames{en}->{3338671} = "Nevers";
$areanames{en}->{3338672} = "Auxerre";
$areanames{en}->{3338676} = "Moux\-en\-Morvan";
$areanames{en}->{3338677} = "Decize";
$areanames{en}->{3338680} = "Migennes";
$areanames{en}->{3338681} = "Vermenton";
$areanames{en}->{3338682} = "Noyers\ sur\ Serein";
$areanames{en}->{3338683} = "Sens";
$areanames{en}->{3338685} = "Château\-Chinon\(Ville\)";
$areanames{en}->{3338687} = "Villeneuve\-sur\-Yonne";
$areanames{en}->{3338692} = "Migennes";
$areanames{en}->{3338693} = "Nevers";
$areanames{en}->{3338694} = "Auxerre";
$areanames{en}->{3338695} = "Sens";
$areanames{en}->{3338703} = "Sarrebourg";
$areanames{en}->{3338704} = "Freyming\-Merlebach";
$areanames{en}->{3338705} = "Château\-Salins";
$areanames{en}->{3338706} = "Bitche";
$areanames{en}->{3338713} = "Forbach";
$areanames{en}->{3338715} = "Metz";
$areanames{en}->{3338716} = "Metz";
$areanames{en}->{3338717} = "Metz";
$areanames{en}->{3338718} = "Metz";
$areanames{en}->{3338720} = "Metz";
$areanames{en}->{3338721} = "Metz";
$areanames{en}->{3338723} = "Sarrebourg";
$areanames{en}->{3338724} = "Phalsbourg";
$areanames{en}->{3338727} = "Sarreguemines";
$areanames{en}->{3338728} = "Sarreguemines";
$areanames{en}->{3338729} = "Saint\-Avold";
$areanames{en}->{333873} = "Metz";
$areanames{en}->{3338738} = "Augny";
$areanames{en}->{333874} = "Nord\ Est";
$areanames{en}->{3338740} = "Metz";
$areanames{en}->{3338741} = "Morhange";
$areanames{en}->{3338743} = "Saint\-Avold";
$areanames{en}->{3338749} = "Metz";
$areanames{en}->{3338750} = "Metz";
$areanames{en}->{3338751} = "Maizières\-lès\-Metz";
$areanames{en}->{3338753} = "Amanvillers";
$areanames{en}->{3338755} = "Metz";
$areanames{en}->{3338756} = "Metz";
$areanames{en}->{3338758} = "Moyeuvre\-Grande";
$areanames{en}->{3338760} = "Ars\-sur\-Moselle";
$areanames{en}->{3338761} = "Sainte\-Marie\-aux\-Chênes";
$areanames{en}->{3338762} = "Metz";
$areanames{en}->{3338763} = "Metz";
$areanames{en}->{3338765} = "Metz";
$areanames{en}->{3338766} = "Metz";
$areanames{en}->{3338767} = "Rombas";
$areanames{en}->{3338768} = "Metz";
$areanames{en}->{3338769} = "Metz";
$areanames{en}->{3338770} = "Hagondange";
$areanames{en}->{3338771} = "Hagondange";
$areanames{en}->{3338772} = "Hagondange";
$areanames{en}->{3338773} = "Ennery";
$areanames{en}->{3338774} = "Metz";
$areanames{en}->{3338775} = "Metz";
$areanames{en}->{3338776} = "Metz";
$areanames{en}->{3338777} = "Vigy";
$areanames{en}->{3338778} = "Bouzonville";
$areanames{en}->{3338779} = "Boulay\-Moselle";
$areanames{en}->{3338780} = "Maizières\-lès\-Metz";
$areanames{en}->{3338781} = "Freyming\-Merlebach";
$areanames{en}->{3338782} = "Creutzwald";
$areanames{en}->{3338784} = "Forbach";
$areanames{en}->{3338785} = "Forbach";
$areanames{en}->{3338787} = "Forbach";
$areanames{en}->{3338788} = "Forbach";
$areanames{en}->{3338789} = "Farébersviller";
$areanames{en}->{3338791} = "Saint\-Avold";
$areanames{en}->{3338792} = "Saint\-Avold";
$areanames{en}->{3338793} = "Creutzwald";
$areanames{en}->{3338794} = "Faulquemont";
$areanames{en}->{3338795} = "Sarreguemines";
$areanames{en}->{3338796} = "Bitche";
$areanames{en}->{3338797} = "Sarralbe";
$areanames{en}->{3338798} = "Sarreguemines";
$areanames{en}->{3338802} = "Saverne";
$areanames{en}->{3338803} = "Saverne";
$areanames{en}->{3338805} = "Haguenau";
$areanames{en}->{3338806} = "Haguenau";
$areanames{en}->{3338808} = "Barr";
$areanames{en}->{3338809} = "Niederbronn\-les\-Bains";
$areanames{en}->{3338810} = "Strasbourg";
$areanames{en}->{3338812} = "Strasbourg";
$areanames{en}->{3338813} = "Strasbourg";
$areanames{en}->{3338814} = "Strasbourg";
$areanames{en}->{3338815} = "Strasbourg";
$areanames{en}->{3338816} = "Strasbourg";
$areanames{en}->{3338818} = "Schiltigheim";
$areanames{en}->{3338819} = "Schiltigheim";
$areanames{en}->{333882} = "Strasbourg";
$areanames{en}->{3338820} = "Souffelweyersheim";
$areanames{en}->{333883} = "Strasbourg";
$areanames{en}->{3338833} = "Schiltigheim";
$areanames{en}->{3338838} = "Molsheim";
$areanames{en}->{333884} = "Strasbourg";
$areanames{en}->{3338846} = "Nord\ Est";
$areanames{en}->{3338851} = "Brumath";
$areanames{en}->{3338852} = "Strasbourg";
$areanames{en}->{3338853} = "Drusenheim";
$areanames{en}->{3338854} = "Betschdorf";
$areanames{en}->{3338855} = "Geispolsheim";
$areanames{en}->{3338856} = "Oberhausbergen";
$areanames{en}->{3338858} = "Sélestat";
$areanames{en}->{3338860} = "Strasbourg";
$areanames{en}->{3338861} = "Strasbourg";
$areanames{en}->{3338862} = "Schiltigheim";
$areanames{en}->{3338863} = "Bischwiller";
$areanames{en}->{3338864} = "Fegersheim";
$areanames{en}->{3338865} = "Strasbourg";
$areanames{en}->{3338866} = "Illkirch\-Graffenstaden";
$areanames{en}->{3338867} = "Illkirch\-Graffenstaden";
$areanames{en}->{3338871} = "Saverne";
$areanames{en}->{3338872} = "Schweighouse\-sur\-Moder";
$areanames{en}->{3338873} = "Haguenau";
$areanames{en}->{3338874} = "Benfeld";
$areanames{en}->{3338875} = "Strasbourg";
$areanames{en}->{3338876} = "Lingolsheim";
$areanames{en}->{3338877} = "Lingolsheim";
$areanames{en}->{3338878} = "Lingolsheim";
$areanames{en}->{3338879} = "Strasbourg";
$areanames{en}->{3338881} = "Schiltigheim";
$areanames{en}->{3338882} = "Sélestat";
$areanames{en}->{3338883} = "Schiltigheim";
$areanames{en}->{3338884} = "Strasbourg";
$areanames{en}->{3338887} = "Wasselonne";
$areanames{en}->{3338889} = "Ingwiller";
$areanames{en}->{3338891} = "Saverne";
$areanames{en}->{3338892} = "Sélestat";
$areanames{en}->{3338893} = "Haguenau";
$areanames{en}->{3338894} = "Wissembourg";
$areanames{en}->{3338895} = "Obernai";
$areanames{en}->{3338898} = "Erstein";
$areanames{en}->{3338906} = "Brunstatt";
$areanames{en}->{3338908} = "Altkirch";
$areanames{en}->{333891} = "Nord\ Est";
$areanames{en}->{3338912} = "Colmar";
$areanames{en}->{3338920} = "Colmar";
$areanames{en}->{3338921} = "Colmar";
$areanames{en}->{3338922} = "Sainte\-Croix\-en\-Plaine";
$areanames{en}->{3338923} = "Colmar";
$areanames{en}->{3338924} = "Colmar";
$areanames{en}->{3338927} = "Wintzenheim";
$areanames{en}->{3338929} = "Colmar";
$areanames{en}->{3338930} = "Colmar";
$areanames{en}->{3338931} = "Sausheim";
$areanames{en}->{3338932} = "Mulhouse";
$areanames{en}->{3338933} = "Mulhouse";
$areanames{en}->{3338935} = "Mulhouse";
$areanames{en}->{3338936} = "Mulhouse";
$areanames{en}->{3338937} = "Thann";
$areanames{en}->{3338939} = "Cernay";
$areanames{en}->{3338940} = "Altkirch";
$areanames{en}->{3338941} = "Colmar";
$areanames{en}->{3338942} = "Mulhouse";
$areanames{en}->{3338943} = "Mulhouse";
$areanames{en}->{3338944} = "Mulhouse";
$areanames{en}->{3338945} = "Mulhouse";
$areanames{en}->{3338946} = "Mulhouse";
$areanames{en}->{3338951} = "Wittenheim";
$areanames{en}->{3338952} = "Wittenheim";
$areanames{en}->{3338953} = "Wittenheim";
$areanames{en}->{3338954} = "Mulhouse";
$areanames{en}->{3338955} = "Wittelsheim";
$areanames{en}->{3338956} = "Mulhouse";
$areanames{en}->{3338958} = "Sainte\-Marie\-aux\-Mines";
$areanames{en}->{3338959} = "Mulhouse";
$areanames{en}->{3338960} = "Mulhouse";
$areanames{en}->{3338961} = "Illzach";
$areanames{en}->{3338964} = "Mulhouse";
$areanames{en}->{3338965} = "Rixheim";
$areanames{en}->{3338966} = "Mulhouse";
$areanames{en}->{3338967} = "Saint\-Louis";
$areanames{en}->{3338969} = "Saint\-Louis";
$areanames{en}->{3338970} = "Saint\-Louis";
$areanames{en}->{3338971} = "Orbey";
$areanames{en}->{3338973} = "Ribeauville";
$areanames{en}->{3338974} = "Guebwiller";
$areanames{en}->{3338975} = "Cernay";
$areanames{en}->{3338976} = "Guebwiller";
$areanames{en}->{3338977} = "Munster";
$areanames{en}->{3338978} = "Kaysersberg";
$areanames{en}->{3338979} = "Colmar";
$areanames{en}->{3338980} = "Colmar";
$areanames{en}->{3338989} = "Saint\-Louis";
$areanames{en}->{333899} = "Nord\ Est";
$areanames{en}->{3338990} = "Altkirch";
$areanames{en}->{3338991} = "Altkirch";
$areanames{en}->{3338996} = "Strasbourg";
$areanames{en}->{333900} = "Nord\ Est";
$areanames{en}->{3339000} = "Strasbourg";
$areanames{en}->{3339006} = "Strasbourg";
$areanames{en}->{3339007} = "Strasbourg";
$areanames{en}->{333901} = "Nord\ Est";
$areanames{en}->{3339014} = "Strasbourg";
$areanames{en}->{3339020} = "Strasbourg";
$areanames{en}->{3339022} = "Strasbourg";
$areanames{en}->{3339023} = "Strasbourg";
$areanames{en}->{333903} = "Nord\ Est";
$areanames{en}->{3339031} = "Strasbourg";
$areanames{en}->{3339040} = "Strasbourg";
$areanames{en}->{3339041} = "Strasbourg";
$areanames{en}->{3339057} = "Sélestat";
$areanames{en}->{333906} = "Nord\ Est";
$areanames{en}->{3339060} = "Sélestat";
$areanames{en}->{3339064} = "Strasbourg";
$areanames{en}->{3339067} = "Strasbourg";
$areanames{en}->{333907} = "Nord\ Est";
$areanames{en}->{333908} = "Nord\ Est";
$areanames{en}->{333909} = "Nord\ Est";
$areanames{en}->{333910} = "Nord\ Est";
$areanames{en}->{333911} = "Nord\ Est";
$areanames{en}->{3339116} = "Montreuil";
$areanames{en}->{3339117} = "Montreuil";
$areanames{en}->{3339118} = "Calais";
$areanames{en}->{3339119} = "Arras";
$areanames{en}->{333912} = "Nord\ Est";
$areanames{en}->{3339120} = "Arras";
$areanames{en}->{3339121} = "Calais";
$areanames{en}->{3339122} = "Calais";
$areanames{en}->{333913} = "Nord\ Est";
$areanames{en}->{333914} = "Nord\ Est";
$areanames{en}->{333915} = "Nord\ Est";
$areanames{en}->{333916} = "Nord\ Est";
$areanames{en}->{333917} = "Nord\ Est";
$areanames{en}->{3339178} = "Calais";
$areanames{en}->{3339179} = "Béthune";
$areanames{en}->{3339180} = "Bruay\-la\-Buissière";
$areanames{en}->{3339183} = "Carvin";
$areanames{en}->{3339190} = "Boulogne\-sur\-Mer";
$areanames{en}->{3341100} = "Limoux";
$areanames{en}->{3341101} = "Narbonne";
$areanames{en}->{3341102} = "Ales";
$areanames{en}->{3341103} = "Bagnols\-sur\-Ceze";
$areanames{en}->{3341104} = "Nîmes";
$areanames{en}->{3341105} = "Bedarieux";
$areanames{en}->{3341106} = "Beziers";
$areanames{en}->{3341107} = "Langogne";
$areanames{en}->{3341108} = "Mende";
$areanames{en}->{3341109} = "Perpignan";
$areanames{en}->{3341110} = "Prades";
$areanames{en}->{3341111} = "Montpellier";
$areanames{en}->{3341112} = "Nîmes";
$areanames{en}->{3341113} = "Perpignan";
$areanames{en}->{3341114} = "Carcassonne";
$areanames{en}->{3341115} = "Narbonne";
$areanames{en}->{3341116} = "Beziers";
$areanames{en}->{3341117} = "Bagnols\-sur\-Ceze";
$areanames{en}->{3341118} = "Nîmes";
$areanames{en}->{3341119} = "Montpellier";
$areanames{en}->{3341120} = "Carcassonne";
$areanames{en}->{3341121} = "Castelnaudary";
$areanames{en}->{3341122} = "Limoux";
$areanames{en}->{3341123} = "Narbonne";
$areanames{en}->{3341124} = "Ales";
$areanames{en}->{3341125} = "Nîmes";
$areanames{en}->{3341126} = "Bedarieux";
$areanames{en}->{3341127} = "Beziers";
$areanames{en}->{3341128} = "Montpellier";
$areanames{en}->{3341129} = "Mende";
$areanames{en}->{3341130} = "Perpignan";
$areanames{en}->{3341131} = "Prades";
$areanames{en}->{3341132} = "Montpellier";
$areanames{en}->{3341133} = "Langogne";
$areanames{en}->{3341134} = "Bedarieux";
$areanames{en}->{3341135} = "Perpignan";
$areanames{en}->{3341136} = "Ales";
$areanames{en}->{3341137} = "Bedarieux";
$areanames{en}->{3341138} = "Montpellier";
$areanames{en}->{3341139} = "Beziers";
$areanames{en}->{3341140} = "Nîmes";
$areanames{en}->{3341141} = "Narbonne";
$areanames{en}->{3341142} = "Castelnaudary";
$areanames{en}->{3341143} = "Mende";
$areanames{en}->{3341144} = "Bagnols\-sur\-Ceze";
$areanames{en}->{3341145} = "Prades";
$areanames{en}->{3341146} = "Limoux";
$areanames{en}->{3341147} = "Carcassonne";
$areanames{en}->{3341148} = "Carcassonne";
$areanames{en}->{3341149} = "Castelnaudary";
$areanames{en}->{3341150} = "Limoux";
$areanames{en}->{3341151} = "Narbonne";
$areanames{en}->{3341152} = "Ales";
$areanames{en}->{3341153} = "Bagnols\-sur\-Ceze";
$areanames{en}->{3341154} = "Nîmes";
$areanames{en}->{3341155} = "Bedarieux";
$areanames{en}->{3341156} = "Beziers";
$areanames{en}->{3341157} = "Montpellier";
$areanames{en}->{3341158} = "Langogne";
$areanames{en}->{3341159} = "Mende";
$areanames{en}->{3341164} = "Perpignan";
$areanames{en}->{3341175} = "Montpellier";
$areanames{en}->{3341180} = "Montpellier";
$areanames{en}->{3341181} = "Perpignan";
$areanames{en}->{3341182} = "Narbonne";
$areanames{en}->{3341183} = "Nîmes";
$areanames{en}->{3341184} = "Ales";
$areanames{en}->{3341185} = "Nîmes";
$areanames{en}->{3341186} = "Mende";
$areanames{en}->{3341187} = "Nîmes";
$areanames{en}->{3341188} = "Nîmes";
$areanames{en}->{3341189} = "Montpellier";
$areanames{en}->{3341190} = "Beziers";
$areanames{en}->{3341191} = "Beziers";
$areanames{en}->{3341192} = "Montpellier";
$areanames{en}->{3341193} = "Montpellier";
$areanames{en}->{3341194} = "Nîmes";
$areanames{en}->{3341195} = "Montpellier";
$areanames{en}->{3341196} = "Perpignan";
$areanames{en}->{3341197} = "Beziers";
$areanames{en}->{3341198} = "Perpignan";
$areanames{en}->{3341199} = "Perpignan";
$areanames{en}->{3341307} = "Carpentras";
$areanames{en}->{3341310} = "Aix\-en\-Provence";
$areanames{en}->{3341311} = "Arles";
$areanames{en}->{3341312} = "Aubagne";
$areanames{en}->{3341313} = "Marseille";
$areanames{en}->{3341314} = "Aix\-en\-Provence";
$areanames{en}->{3341315} = "Avignon";
$areanames{en}->{3341316} = "Avignon";
$areanames{en}->{3341317} = "Cavaillon";
$areanames{en}->{3341318} = "Digne\-les\-Bains";
$areanames{en}->{3341319} = "Gap";
$areanames{en}->{3341320} = "Marseille";
$areanames{en}->{3341339} = "Avignon";
$areanames{en}->{3341340} = "Marignane";
$areanames{en}->{3341341} = "Aix\-en\-Provence";
$areanames{en}->{3341342} = "Marseille";
$areanames{en}->{3341343} = "Marignane";
$areanames{en}->{3341344} = "Aix\-en\-Provence";
$areanames{en}->{3341345} = "Arles";
$areanames{en}->{3341346} = "Cavaillon";
$areanames{en}->{3341347} = "Orange";
$areanames{en}->{3341348} = "Pertuis";
$areanames{en}->{3341349} = "Manosque";
$areanames{en}->{3341359} = "Marseille";
$areanames{en}->{3341363} = "Marseille";
$areanames{en}->{3341370} = "Arles";
$areanames{en}->{3341371} = "Cavaillon";
$areanames{en}->{3341372} = "Manosque";
$areanames{en}->{3341373} = "Marseille";
$areanames{en}->{3341374} = "Pertuis";
$areanames{en}->{3341375} = "Aix\-en\-Provence";
$areanames{en}->{3341376} = "Orange";
$areanames{en}->{3341377} = "Avignon";
$areanames{en}->{3341378} = "Saint\-André\-les\-Alpes";
$areanames{en}->{3341379} = "Digne\-les\-Bains";
$areanames{en}->{3341380} = "Digne\-les\-Bains";
$areanames{en}->{3341381} = "Manosque";
$areanames{en}->{3341382} = "Aix\-en\-Provence";
$areanames{en}->{3341383} = "Arles";
$areanames{en}->{3341384} = "Aubagne";
$areanames{en}->{3341385} = "Marignane";
$areanames{en}->{3341386} = "Marseille";
$areanames{en}->{3341387} = "Avignon";
$areanames{en}->{3341388} = "Cavaillon";
$areanames{en}->{3341389} = "Aubagne";
$areanames{en}->{3341390} = "Saint\-André\-les\-Alpes";
$areanames{en}->{3341391} = "Aix\-en\-Provence";
$areanames{en}->{3341392} = "Aubagne";
$areanames{en}->{3341393} = "Marignane";
$areanames{en}->{3341394} = "Marseille";
$areanames{en}->{3341395} = "Avignon";
$areanames{en}->{3341396} = "Marseille";
$areanames{en}->{3341397} = "Orange";
$areanames{en}->{3341398} = "Pertuis";
$areanames{en}->{3341399} = "Cavaillon";
$areanames{en}->{3341500} = "Issoire";
$areanames{en}->{3341501} = "Riom";
$areanames{en}->{3341502} = "La\ Bourboule";
$areanames{en}->{3341503} = "Montlucon";
$areanames{en}->{3341504} = "Le\ Puy\-en\-Velay";
$areanames{en}->{3341505} = "Aurillac";
$areanames{en}->{3341506} = "Saint\-Flour";
$areanames{en}->{3341507} = "Mauriac";
$areanames{en}->{3341508} = "Vichy";
$areanames{en}->{3341509} = "Ambert";
$areanames{en}->{3341510} = "Bourbon\-lArchambault";
$areanames{en}->{3341511} = "Clermont\-Ferrand";
$areanames{en}->{3341512} = "Yssingeaux";
$areanames{en}->{3341513} = "Thiers";
$areanames{en}->{3341514} = "Moulins";
$areanames{en}->{3341515} = "Brioude";
$areanames{en}->{3341516} = "Bourbon\-lArchambault";
$areanames{en}->{3341517} = "Montlucon";
$areanames{en}->{3341518} = "Moulins";
$areanames{en}->{3341519} = "Vichy";
$areanames{en}->{3341520} = "Aurillac";
$areanames{en}->{3341521} = "Mauriac";
$areanames{en}->{3341522} = "Saint\-Flour";
$areanames{en}->{3341523} = "Brioude";
$areanames{en}->{3341524} = "Le\ Puy\-en\-Velay";
$areanames{en}->{3341525} = "Yssingeaux";
$areanames{en}->{3341526} = "Ambert";
$areanames{en}->{3341527} = "La\ Bourboule";
$areanames{en}->{3341528} = "Clermont\-Ferrand";
$areanames{en}->{3341529} = "Issoire";
$areanames{en}->{3341530} = "Riom";
$areanames{en}->{3341531} = "Thiers";
$areanames{en}->{3341532} = "Clermont\-Ferrand";
$areanames{en}->{3341533} = "Bourbon\-lArchambault";
$areanames{en}->{3341534} = "Montlucon";
$areanames{en}->{3341535} = "Moulins";
$areanames{en}->{3341536} = "Saint\-Flour";
$areanames{en}->{3341537} = "Brioude";
$areanames{en}->{3341538} = "Yssingeaux";
$areanames{en}->{3341539} = "Clermont\-Ferrand";
$areanames{en}->{3341540} = "Clermont\-Ferrand";
$areanames{en}->{3341541} = "Moulins";
$areanames{en}->{3341542} = "Aurillac";
$areanames{en}->{3341543} = "Moulins";
$areanames{en}->{3341544} = "Clermont\-Ferrand";
$areanames{en}->{3341545} = "Moulins";
$areanames{en}->{3341546} = "Le\ Puy\-en\-Velay";
$areanames{en}->{3341547} = "Riom";
$areanames{en}->{3341548} = "Aurillac";
$areanames{en}->{3341549} = "Yssingeaux";
$areanames{en}->{3341550} = "Le\ Puy\-en\-Velay";
$areanames{en}->{3341551} = "Clermont\-Ferrand";
$areanames{en}->{3341552} = "Le\ Puy\-en\-Velay";
$areanames{en}->{3341553} = "Moulins";
$areanames{en}->{3341554} = "Clermont\-Ferrand";
$areanames{en}->{3341555} = "Aurillac";
$areanames{en}->{3341556} = "Bourbon\-lArchambault";
$areanames{en}->{3341557} = "Mauriac";
$areanames{en}->{3341558} = "Saint\-Flour";
$areanames{en}->{3341559} = "Brioude";
$areanames{en}->{3341560} = "Ambert";
$areanames{en}->{3341561} = "La\ Bourboule";
$areanames{en}->{3341562} = "Issoire";
$areanames{en}->{3341563} = "Thiers";
$areanames{en}->{3341564} = "Bourbon\-lArchambault";
$areanames{en}->{3341565} = "Montlucon";
$areanames{en}->{3341566} = "Clermont\-Ferrand";
$areanames{en}->{3341567} = "Montlucon";
$areanames{en}->{3341568} = "Moulins";
$areanames{en}->{3341569} = "Vichy";
$areanames{en}->{3341570} = "Aurillac";
$areanames{en}->{3341571} = "Mauriac";
$areanames{en}->{3341572} = "Saint\-Flour";
$areanames{en}->{3341573} = "Brioude";
$areanames{en}->{3341574} = "Le\ Puy\-en\-Velay";
$areanames{en}->{3341575} = "Yssingeaux";
$areanames{en}->{3341576} = "Ambert";
$areanames{en}->{3341577} = "La\ Bourboule";
$areanames{en}->{3341578} = "Issoire";
$areanames{en}->{3341579} = "Riom";
$areanames{en}->{3341580} = "Thiers";
$areanames{en}->{3341581} = "Clermont\-Ferrand";
$areanames{en}->{3341582} = "Vichy";
$areanames{en}->{3341583} = "Issoire";
$areanames{en}->{3341584} = "Aurillac";
$areanames{en}->{3341585} = "Clermont\-Ferrand";
$areanames{en}->{3341586} = "Aurillac";
$areanames{en}->{3341587} = "Mauriac";
$areanames{en}->{3341588} = "Saint\-Flour";
$areanames{en}->{3341589} = "Saint\-Flour";
$areanames{en}->{3341590} = "Vichy";
$areanames{en}->{3341591} = "Vichy";
$areanames{en}->{3341592} = "Riom";
$areanames{en}->{3341593} = "Le\ Puy\-en\-Velay";
$areanames{en}->{3341594} = "Brioude";
$areanames{en}->{3342004} = "Ajaccio";
$areanames{en}->{334201} = "Corse";
$areanames{en}->{3342020} = "Corse";
$areanames{en}->{3342030} = "Corse";
$areanames{en}->{3342040} = "Corse";
$areanames{en}->{3342055} = "Corse";
$areanames{en}->{3342057} = "Corse";
$areanames{en}->{3342058} = "Corse";
$areanames{en}->{3342059} = "Corse";
$areanames{en}->{3342060} = "Corse";
$areanames{en}->{3342061} = "Corse";
$areanames{en}->{3342088} = "Corse";
$areanames{en}->{3342094} = "Corse";
$areanames{en}->{3342095} = "Corse";
$areanames{en}->{3342200} = "Cannes";
$areanames{en}->{3342201} = "Grasse";
$areanames{en}->{3342202} = "Nice";
$areanames{en}->{3342203} = "Puget\-Theniers";
$areanames{en}->{3342204} = "Brignoles";
$areanames{en}->{3342205} = "Draguignan";
$areanames{en}->{3342206} = "Saint\-Raphael";
$areanames{en}->{3342207} = "Toulon";
$areanames{en}->{3342208} = "Cannes";
$areanames{en}->{3342209} = "Nice";
$areanames{en}->{3342220} = "Nice";
$areanames{en}->{3342221} = "Cannes";
$areanames{en}->{3342222} = "Nice";
$areanames{en}->{3342223} = "Grasse";
$areanames{en}->{3342224} = "Cannes";
$areanames{en}->{3342225} = "Grasse";
$areanames{en}->{3342226} = "Nice";
$areanames{en}->{3342227} = "Puget\-Theniers";
$areanames{en}->{3342228} = "Brignoles";
$areanames{en}->{3342229} = "Draguignan";
$areanames{en}->{3342230} = "Saint\-Raphael";
$areanames{en}->{3342231} = "Toulon";
$areanames{en}->{3342232} = "Cannes";
$areanames{en}->{3342233} = "Brignoles";
$areanames{en}->{3342234} = "Cannes";
$areanames{en}->{3342235} = "Draguignan";
$areanames{en}->{3342236} = "Cannes";
$areanames{en}->{3342237} = "Toulon";
$areanames{en}->{3342238} = "Toulon";
$areanames{en}->{3342239} = "Cannes";
$areanames{en}->{3342250} = "Brignoles";
$areanames{en}->{3342251} = "Saint\-Raphael";
$areanames{en}->{3342252} = "Cannes";
$areanames{en}->{3342253} = "Nice";
$areanames{en}->{3342254} = "Toulon";
$areanames{en}->{3342255} = "Saint\-Raphael";
$areanames{en}->{3342256} = "Draguignan";
$areanames{en}->{3342257} = "Brignoles";
$areanames{en}->{3342258} = "Cannes";
$areanames{en}->{3342259} = "Toulon";
$areanames{en}->{3342260} = "Brignoles";
$areanames{en}->{3342261} = "Nice";
$areanames{en}->{3342262} = "Toulon";
$areanames{en}->{3342263} = "Draguignan";
$areanames{en}->{3342264} = "Puget\-Theniers";
$areanames{en}->{3342265} = "Toulon";
$areanames{en}->{3342266} = "Draguignan";
$areanames{en}->{3342267} = "Nice";
$areanames{en}->{3342268} = "Nice";
$areanames{en}->{3342269} = "Nice";
$areanames{en}->{3342270} = "Nice";
$areanames{en}->{3342271} = "Cannes";
$areanames{en}->{3342272} = "Cannes";
$areanames{en}->{3342273} = "Saint\-Raphael";
$areanames{en}->{3342274} = "Nice";
$areanames{en}->{3342275} = "Nice";
$areanames{en}->{3342276} = "Brignoles";
$areanames{en}->{3342277} = "Draguignan";
$areanames{en}->{3342278} = "Cannes";
$areanames{en}->{3342279} = "Toulon";
$areanames{en}->{3342280} = "Toulon";
$areanames{en}->{3342281} = "Saint\-Raphael";
$areanames{en}->{3342282} = "Saint\-Raphael";
$areanames{en}->{3342283} = "Toulon";
$areanames{en}->{3342284} = "Cannes";
$areanames{en}->{3342285} = "Nice";
$areanames{en}->{3342286} = "Toulon";
$areanames{en}->{3342287} = "Toulon";
$areanames{en}->{3342288} = "Grasse";
$areanames{en}->{3342289} = "Saint\-Raphael";
$areanames{en}->{3342290} = "Cannes";
$areanames{en}->{3342291} = "Grasse";
$areanames{en}->{3342292} = "Puget\-Theniers";
$areanames{en}->{3342293} = "Cannes";
$areanames{en}->{3342294} = "Nice";
$areanames{en}->{3342295} = "Toulon";
$areanames{en}->{3342296} = "Nice";
$areanames{en}->{3342297} = "Brignoles";
$areanames{en}->{3342298} = "Draguignan";
$areanames{en}->{3342299} = "Saint\-Raphael";
$areanames{en}->{3342300} = "Nice";
$areanames{en}->{3342301} = "Cannes";
$areanames{en}->{3342302} = "Grasse";
$areanames{en}->{3342303} = "Nice";
$areanames{en}->{3342304} = "Puget\-Theniers";
$areanames{en}->{3342305} = "Brignoles";
$areanames{en}->{3342306} = "Draguignan";
$areanames{en}->{3342307} = "Saint\-Raphael";
$areanames{en}->{3342308} = "Toulon";
$areanames{en}->{3342309} = "Nice";
$areanames{en}->{3342310} = "Toulon";
$areanames{en}->{3342311} = "Nice";
$areanames{en}->{3342312} = "Toulon";
$areanames{en}->{3342313} = "Nice";
$areanames{en}->{3342314} = "Toulon";
$areanames{en}->{3342315} = "Toulon";
$areanames{en}->{3342316} = "Nice";
$areanames{en}->{3342317} = "Nice";
$areanames{en}->{3342318} = "Saint\-Raphael";
$areanames{en}->{3342319} = "Cannes";
$areanames{en}->{3342320} = "Nice";
$areanames{en}->{3342323} = "Nice";
$areanames{en}->{3342610} = "Lyon";
$areanames{en}->{3342611} = "Bourg\-en\-Bresse";
$areanames{en}->{3342612} = "Nantua";
$areanames{en}->{3342613} = "Annonay";
$areanames{en}->{3342614} = "Aubenas";
$areanames{en}->{3342615} = "Privas";
$areanames{en}->{3342616} = "Bourg\-en\-Bresse";
$areanames{en}->{3342617} = "Lyon";
$areanames{en}->{3342618} = "Lyon";
$areanames{en}->{3342619} = "Lyon";
$areanames{en}->{334262} = "Lyon";
$areanames{en}->{3342624} = "Roanne";
$areanames{en}->{3342625} = "Privas";
$areanames{en}->{3342630} = "Annonay";
$areanames{en}->{3342631} = "Lyon";
$areanames{en}->{3342632} = "Tournon\-sur\-Rhone";
$areanames{en}->{3342633} = "Die";
$areanames{en}->{3342634} = "Montelimar";
$areanames{en}->{3342635} = "Nyons";
$areanames{en}->{3342636} = "Saint\-Etienne";
$areanames{en}->{3342637} = "Bourg\-en\-Bresse";
$areanames{en}->{3342638} = "Bourgoin\-Jallieu";
$areanames{en}->{3342639} = "Feurs";
$areanames{en}->{3342640} = "Saint\-Vallier";
$areanames{en}->{3342641} = "Amberieu\-en\-Bugey";
$areanames{en}->{3342642} = "Valence";
$areanames{en}->{3342643} = "Romans\-sur\-Isere";
$areanames{en}->{3342644} = "Valence";
$areanames{en}->{3342645} = "Tarare";
$areanames{en}->{3342646} = "Lyon";
$areanames{en}->{3342647} = "Villefranche\-sur\-Saone";
$areanames{en}->{3342648} = "Saint\-Etienne";
$areanames{en}->{3342649} = "Lyon";
$areanames{en}->{3342650} = "Valence";
$areanames{en}->{3342651} = "Montelimar";
$areanames{en}->{3342652} = "Valence";
$areanames{en}->{3342653} = "Privas";
$areanames{en}->{3342654} = "Roanne";
$areanames{en}->{3342655} = "Lyon";
$areanames{en}->{3342656} = "Saint\-Etienne";
$areanames{en}->{3342657} = "Vienne";
$areanames{en}->{3342658} = "Die";
$areanames{en}->{3342659} = "Lyon";
$areanames{en}->{334267} = "Lyon";
$areanames{en}->{3342674} = "Villefranche\-sur\-Saone";
$areanames{en}->{3342675} = "Vienne";
$areanames{en}->{3342677} = "Villefranche\-sur\-Saone";
$areanames{en}->{3342679} = "Montelimar";
$areanames{en}->{3342680} = "Amberieu\-en\-Bugey";
$areanames{en}->{3342681} = "Tarare";
$areanames{en}->{3342682} = "Bourg\-en\-Bresse";
$areanames{en}->{3342683} = "Lyon";
$areanames{en}->{3342684} = "Lyon";
$areanames{en}->{3342685} = "Privas";
$areanames{en}->{3342686} = "Nantua";
$areanames{en}->{3342687} = "Privas";
$areanames{en}->{3342688} = "Bourg\-en\-Bresse";
$areanames{en}->{3342689} = "Bourg\-en\-Bresse";
$areanames{en}->{3342690} = "Lyon";
$areanames{en}->{3342691} = "Bourg\-en\-Bresse";
$areanames{en}->{3342692} = "Montelimar";
$areanames{en}->{3342693} = "Montelimar";
$areanames{en}->{3342694} = "Romans\-sur\-Isere";
$areanames{en}->{3342695} = "Romans\-sur\-Isere";
$areanames{en}->{3342696} = "Tarare";
$areanames{en}->{3342697} = "Saint\-Etienne";
$areanames{en}->{3342698} = "Saint\-Etienne";
$areanames{en}->{3342699} = "Lyon";
$areanames{en}->{3342700} = "Romans\-sur\-Isere";
$areanames{en}->{3342701} = "Lyon";
$areanames{en}->{3342702} = "Lyon";
$areanames{en}->{3342703} = "Saint\-Vallier";
$areanames{en}->{3342704} = "Lyon";
$areanames{en}->{3342705} = "Amberieu\-en\-Bugey";
$areanames{en}->{3342706} = "Amberieu\-en\-Bugey";
$areanames{en}->{3342707} = "Bourgoin\-Jallieu";
$areanames{en}->{3342708} = "Bourgoin\-Jallieu";
$areanames{en}->{3342709} = "Vienne";
$areanames{en}->{334271} = "Lyon";
$areanames{en}->{3342710} = "Saint\-Etienne";
$areanames{en}->{3342715} = "Privas";
$areanames{en}->{3342716} = "Valence";
$areanames{en}->{3342717} = "Valence";
$areanames{en}->{3342720} = "Feurs";
$areanames{en}->{3342721} = "Lyon";
$areanames{en}->{3342722} = "Lyon";
$areanames{en}->{3342723} = "Roanne";
$areanames{en}->{3342724} = "Valence";
$areanames{en}->{3342725} = "Saint\-Etienne";
$areanames{en}->{3342726} = "Roanne";
$areanames{en}->{3342727} = "Saint\-Etienne";
$areanames{en}->{3342728} = "Lyon";
$areanames{en}->{3342729} = "Tarare";
$areanames{en}->{3342730} = "Villefranche\-sur\-Saone";
$areanames{en}->{3342731} = "Amberieu\-en\-Bugey";
$areanames{en}->{3342732} = "Bourg\-en\-Bresse";
$areanames{en}->{3342733} = "Nantua";
$areanames{en}->{3342734} = "Annonay";
$areanames{en}->{3342735} = "Feurs";
$areanames{en}->{3342736} = "Bourg\-en\-Bresse";
$areanames{en}->{3342737} = "Tarare";
$areanames{en}->{3342738} = "Valence";
$areanames{en}->{3342739} = "Vienne";
$areanames{en}->{3342740} = "Saint\-Etienne";
$areanames{en}->{3342741} = "Amberieu\-en\-Bugey";
$areanames{en}->{3342742} = "Tournon\-sur\-Rhone";
$areanames{en}->{3342743} = "Romans\-sur\-Isere";
$areanames{en}->{3342744} = "Lyon";
$areanames{en}->{3342745} = "Saint\-Vallier";
$areanames{en}->{3342746} = "Lyon";
$areanames{en}->{3342747} = "Villefranche\-sur\-Saone";
$areanames{en}->{3342748} = "Tarare";
$areanames{en}->{3342749} = "Villefranche\-sur\-Saone";
$areanames{en}->{3342750} = "Amberieu\-en\-Bugey";
$areanames{en}->{3342751} = "Annonay";
$areanames{en}->{3342752} = "Aubenas";
$areanames{en}->{3342753} = "Bourg\-en\-Bresse";
$areanames{en}->{3342754} = "Bourgoin\-Jallieu";
$areanames{en}->{3342755} = "Die";
$areanames{en}->{3342756} = "Feurs";
$areanames{en}->{3342757} = "Bourgoin\-Jallieu";
$areanames{en}->{3342758} = "Montelimar";
$areanames{en}->{3342759} = "Nantua";
$areanames{en}->{3342790} = "Amberieu\-en\-Bugey";
$areanames{en}->{3342791} = "Bourg\-en\-Bresse";
$areanames{en}->{3342792} = "Nantua";
$areanames{en}->{3342793} = "Annonay";
$areanames{en}->{3342794} = "Aubenas";
$areanames{en}->{3342795} = "Privas";
$areanames{en}->{3342796} = "Tournon\-sur\-Rhone";
$areanames{en}->{3342797} = "Die";
$areanames{en}->{3342798} = "Montelimar";
$areanames{en}->{3342799} = "Nyons";
$areanames{en}->{3342800} = "Lyon";
$areanames{en}->{3342801} = "Lyon";
$areanames{en}->{3342802} = "Bourg\-en\-Bresse";
$areanames{en}->{3342803} = "Nantua";
$areanames{en}->{3342804} = "Saint\-Etienne";
$areanames{en}->{3342805} = "Feurs";
$areanames{en}->{3342806} = "Roanne";
$areanames{en}->{3342807} = "Saint\-Etienne";
$areanames{en}->{3342808} = "Valence";
$areanames{en}->{3342809} = "Saint\-Etienne";
$areanames{en}->{3342810} = "Lyon";
$areanames{en}->{3342811} = "Valence";
$areanames{en}->{3342812} = "Nantua";
$areanames{en}->{3342813} = "Saint\-Vallier";
$areanames{en}->{3342814} = "Tournon\-sur\-Rhone";
$areanames{en}->{3342815} = "Valence";
$areanames{en}->{3342816} = "Die";
$areanames{en}->{3342817} = "Nyons";
$areanames{en}->{3342818} = "Romans\-sur\-Isere";
$areanames{en}->{3342819} = "Bourgoin\-Jallieu";
$areanames{en}->{3342820} = "Vienne";
$areanames{en}->{3342821} = "Feurs";
$areanames{en}->{3342822} = "Roanne";
$areanames{en}->{3342823} = "Saint\-Etienne";
$areanames{en}->{3342824} = "Bourg\-en\-Bresse";
$areanames{en}->{3342825} = "Bourgoin\-Jallieu";
$areanames{en}->{3342826} = "Roanne";
$areanames{en}->{3342827} = "Lyon";
$areanames{en}->{3342828} = "Lyon";
$areanames{en}->{3342829} = "Lyon";
$areanames{en}->{3342830} = "Nantua";
$areanames{en}->{3342831} = "Lyon";
$areanames{en}->{3342832} = "Saint\-Etienne";
$areanames{en}->{3342833} = "Villefranche\-sur\-Saone";
$areanames{en}->{3342834} = "Bourgoin\-Jallieu";
$areanames{en}->{3342835} = "Bourgoin\-Jallieu";
$areanames{en}->{3342836} = "Bourg\-en\-Bresse";
$areanames{en}->{3342837} = "Montelimar";
$areanames{en}->{3342838} = "Lyon";
$areanames{en}->{3342839} = "Villefranche\-sur\-Saone";
$areanames{en}->{3342840} = "Aubenas";
$areanames{en}->{3342841} = "Amberieu\-en\-Bugey";
$areanames{en}->{3342842} = "Romans\-sur\-Isere";
$areanames{en}->{3342843} = "Tournon\-sur\-Rhone";
$areanames{en}->{3342844} = "Bourg\-en\-Bresse";
$areanames{en}->{3342845} = "Bourg\-en\-Bresse";
$areanames{en}->{3342846} = "Lyon";
$areanames{en}->{3342847} = "Saint\-Etienne";
$areanames{en}->{3342848} = "Annonay";
$areanames{en}->{3342849} = "Privas";
$areanames{en}->{3342850} = "Tournon\-sur\-Rhone";
$areanames{en}->{3342851} = "Die";
$areanames{en}->{3342852} = "Nyons";
$areanames{en}->{3342853} = "Feurs";
$areanames{en}->{3342854} = "Tarare";
$areanames{en}->{3342855} = "Saint\-Vallier";
$areanames{en}->{3342856} = "Bourgoin\-Jallieu";
$areanames{en}->{3342857} = "Vienne";
$areanames{en}->{3342858} = "Tarare";
$areanames{en}->{3342859} = "Villefranche\-sur\-Saone";
$areanames{en}->{334286} = "Lyon";
$areanames{en}->{3342861} = "Valence";
$areanames{en}->{3342864} = "Amberieu\-en\-Bugey";
$areanames{en}->{3342868} = "Romans\-sur\-Isere";
$areanames{en}->{3342870} = "Lyon";
$areanames{en}->{3342871} = "Bourgoin\-Jallieu";
$areanames{en}->{3342872} = "Roanne";
$areanames{en}->{3342873} = "Vienne";
$areanames{en}->{3342874} = "Valence";
$areanames{en}->{3342875} = "Bourgoin\-Jallieu";
$areanames{en}->{3342876} = "Saint\-Vallier";
$areanames{en}->{3342877} = "Lyon";
$areanames{en}->{3342878} = "Saint\-Etienne";
$areanames{en}->{3342879} = "Saint\-Vallier";
$areanames{en}->{3342880} = "Lyon";
$areanames{en}->{3342881} = "Lyon";
$areanames{en}->{3342882} = "Privas";
$areanames{en}->{3342883} = "Amberieu\-en\-Bugey";
$areanames{en}->{3342884} = "Nantua";
$areanames{en}->{3342885} = "Bourgoin\-Jallieu";
$areanames{en}->{3342886} = "Vienne";
$areanames{en}->{3342887} = "Lyon";
$areanames{en}->{3342888} = "Bourg\-en\-Bresse";
$areanames{en}->{3342889} = "Lyon";
$areanames{en}->{3342890} = "Annonay";
$areanames{en}->{3342891} = "Aubenas";
$areanames{en}->{3342892} = "Privas";
$areanames{en}->{3342893} = "Tournon\-sur\-Rhone";
$areanames{en}->{3342894} = "Die";
$areanames{en}->{3342895} = "Montelimar";
$areanames{en}->{3342896} = "Nyons";
$areanames{en}->{3342897} = "Romans\-sur\-Isere";
$areanames{en}->{3342898} = "Saint\-Vallier";
$areanames{en}->{3342899} = "Valence";
$areanames{en}->{3343000} = "Montpellier";
$areanames{en}->{3343001} = "Nîmes";
$areanames{en}->{3343002} = "Montpellier";
$areanames{en}->{3343003} = "Nîmes";
$areanames{en}->{3343004} = "Perpignan";
$areanames{en}->{3343005} = "Montpellier";
$areanames{en}->{3343006} = "Nîmes";
$areanames{en}->{3343007} = "Limoux";
$areanames{en}->{3343008} = "Nîmes";
$areanames{en}->{3343009} = "Langogne";
$areanames{en}->{3343020} = "Ales";
$areanames{en}->{3343021} = "Bagnols\-sur\-Ceze";
$areanames{en}->{3343022} = "Bedarieux";
$areanames{en}->{3343023} = "Beziers";
$areanames{en}->{3343024} = "Carcassonne";
$areanames{en}->{3343025} = "Castelnaudary";
$areanames{en}->{3343026} = "Langogne";
$areanames{en}->{3343027} = "Limoux";
$areanames{en}->{3343028} = "Mende";
$areanames{en}->{3343029} = "Montpellier";
$areanames{en}->{3343050} = "Nîmes";
$areanames{en}->{3343051} = "Carcassonne";
$areanames{en}->{3343052} = "Narbonne";
$areanames{en}->{3343053} = "Perpignan";
$areanames{en}->{3343054} = "Beziers";
$areanames{en}->{3343055} = "Beziers";
$areanames{en}->{3343056} = "Carcassonne";
$areanames{en}->{3343057} = "Montpellier";
$areanames{en}->{3343058} = "Narbonne";
$areanames{en}->{3343059} = "Nîmes";
$areanames{en}->{3343070} = "Montpellier";
$areanames{en}->{3343071} = "Bedarieux";
$areanames{en}->{3343072} = "Beziers";
$areanames{en}->{3343073} = "Carcassonne";
$areanames{en}->{3343074} = "Castelnaudary";
$areanames{en}->{3343075} = "Langogne";
$areanames{en}->{3343076} = "Limoux";
$areanames{en}->{3343077} = "Mende";
$areanames{en}->{3343078} = "Montpellier";
$areanames{en}->{3343079} = "Narbonne";
$areanames{en}->{3343080} = "Beziers";
$areanames{en}->{3343081} = "Nîmes";
$areanames{en}->{3343082} = "Perpignan";
$areanames{en}->{3343083} = "Prades";
$areanames{en}->{3343084} = "Beziers";
$areanames{en}->{3343085} = "Castelnaudary";
$areanames{en}->{3343086} = "Limoux";
$areanames{en}->{3343087} = "Mende";
$areanames{en}->{3343088} = "Carcassonne";
$areanames{en}->{3343089} = "Prades";
$areanames{en}->{3343090} = "Nîmes";
$areanames{en}->{3343091} = "Carcassonne";
$areanames{en}->{3343092} = "Nîmes";
$areanames{en}->{3343093} = "Ales";
$areanames{en}->{3343094} = "Mende";
$areanames{en}->{3343095} = "Perpignan";
$areanames{en}->{3343096} = "Montpellier";
$areanames{en}->{3343097} = "Carcassonne";
$areanames{en}->{3343098} = "Castelnaudary";
$areanames{en}->{3343099} = "Narbonne";
$areanames{en}->{334320} = "Sud\ Est";
$areanames{en}->{334321} = "Sud\ Est";
$areanames{en}->{334322} = "Sud\ Est";
$areanames{en}->{334323} = "Sud\ Est";
$areanames{en}->{334324} = "Sud\ Est";
$areanames{en}->{3343240} = "Avignon";
$areanames{en}->{3343244} = "Avignon";
$areanames{en}->{334329} = "Sud\ Est";
$areanames{en}->{3343450} = "Montpellier";
$areanames{en}->{3343451} = "Prades";
$areanames{en}->{3343452} = "Prades";
$areanames{en}->{3343453} = "Beziers";
$areanames{en}->{3343454} = "Perpignan";
$areanames{en}->{3343455} = "Perpignan";
$areanames{en}->{3343456} = "Prades";
$areanames{en}->{3343457} = "Carcassonne";
$areanames{en}->{3343458} = "Carcassonne";
$areanames{en}->{3343459} = "Perpignan";
$areanames{en}->{3343460} = "Narbonne";
$areanames{en}->{3343461} = "Ales";
$areanames{en}->{3343462} = "Bagnols\-sur\-Ceze";
$areanames{en}->{3343463} = "Nîmes";
$areanames{en}->{3343464} = "Prades";
$areanames{en}->{3343465} = "Beziers";
$areanames{en}->{3343466} = "Montpellier";
$areanames{en}->{3343467} = "Montpellier";
$areanames{en}->{3343468} = "Perpignan";
$areanames{en}->{3343469} = "Nîmes";
$areanames{en}->{3343470} = "Langogne";
$areanames{en}->{3343471} = "Ales";
$areanames{en}->{3343472} = "Bagnols\-sur\-Ceze";
$areanames{en}->{3343473} = "Castelnaudary";
$areanames{en}->{3343474} = "Beziers";
$areanames{en}->{3343475} = "Limoux";
$areanames{en}->{3343476} = "Montpellier";
$areanames{en}->{3343477} = "Bagnols\-sur\-Ceze";
$areanames{en}->{3343478} = "Bagnols\-sur\-Ceze";
$areanames{en}->{3343479} = "Bedarieux";
$areanames{en}->{3343480} = "Beziers";
$areanames{en}->{3343481} = "Montpellier";
$areanames{en}->{3343482} = "Mende";
$areanames{en}->{3343483} = "Prades";
$areanames{en}->{3343484} = "Narbonne";
$areanames{en}->{3343485} = "Beziers";
$areanames{en}->{3343486} = "Bedarieux";
$areanames{en}->{3343487} = "Carcassonne";
$areanames{en}->{3343488} = "Montpellier";
$areanames{en}->{3343489} = "Carcassonne";
$areanames{en}->{3343490} = "Montpellier";
$areanames{en}->{3343491} = "Carcassonne";
$areanames{en}->{3343492} = "Castelnaudary";
$areanames{en}->{3343493} = "Limoux";
$areanames{en}->{3343494} = "Narbonne";
$areanames{en}->{3343495} = "Ales";
$areanames{en}->{3343496} = "Bagnols\-sur\-Ceze";
$areanames{en}->{3343497} = "Nîmes";
$areanames{en}->{3343498} = "Bedarieux";
$areanames{en}->{3343499} = "Beziers";
$areanames{en}->{334371} = "Sud\ Est";
$areanames{en}->{334382} = "Sud\ Est";
$areanames{en}->{3343821} = "Grenoble";
$areanames{en}->{3343824} = "Grenoble";
$areanames{en}->{3343826} = "Grenoble";
$areanames{en}->{334385} = "Sud\ Est";
$areanames{en}->{3343850} = "Grenoble";
$areanames{en}->{334386} = "Sud\ Est";
$areanames{en}->{3343860} = "Grenoble";
$areanames{en}->{334388} = "Sud\ Est";
$areanames{en}->{3343880} = "Annecy";
$areanames{en}->{3343886} = "Grenoble";
$areanames{en}->{3343888} = "Grenoble";
$areanames{en}->{3344300} = "Bourbon\-lArchambault";
$areanames{en}->{3344301} = "Montlucon";
$areanames{en}->{3344302} = "Moulins";
$areanames{en}->{3344303} = "Vichy";
$areanames{en}->{3344304} = "Aurillac";
$areanames{en}->{3344305} = "Mauriac";
$areanames{en}->{3344306} = "Brioude";
$areanames{en}->{3344307} = "Le\ Puy\-en\-Velay";
$areanames{en}->{3344308} = "Yssingeaux";
$areanames{en}->{3344309} = "Ambert";
$areanames{en}->{3344310} = "La\ Bourboule";
$areanames{en}->{3344311} = "Clermont\-Ferrand";
$areanames{en}->{3344312} = "Issoire";
$areanames{en}->{3344313} = "Riom";
$areanames{en}->{3344314} = "Thiers";
$areanames{en}->{3344315} = "Ambert";
$areanames{en}->{3344316} = "Issoire";
$areanames{en}->{3344317} = "La\ Bourboule";
$areanames{en}->{3344318} = "Le\ Puy\-en\-Velay";
$areanames{en}->{3344319} = "Riom";
$areanames{en}->{3344320} = "Thiers";
$areanames{en}->{3344321} = "Vichy";
$areanames{en}->{3344322} = "Clermont\-Ferrand";
$areanames{en}->{3344323} = "Vichy";
$areanames{en}->{3344324} = "Le\ Puy\-en\-Velay";
$areanames{en}->{3344325} = "Ambert";
$areanames{en}->{3344326} = "La\ Bourboule";
$areanames{en}->{3344327} = "Issoire";
$areanames{en}->{3344328} = "Riom";
$areanames{en}->{3344329} = "Thiers";
$areanames{en}->{3344330} = "Clermont\-Ferrand";
$areanames{en}->{3344331} = "Montlucon";
$areanames{en}->{3344332} = "Ambert";
$areanames{en}->{3344333} = "Aurillac";
$areanames{en}->{3344334} = "Bourbon\-lArchambault";
$areanames{en}->{3344335} = "Brioude";
$areanames{en}->{3344336} = "Clermont\-Ferrand";
$areanames{en}->{3344337} = "Issoire";
$areanames{en}->{3344338} = "La\ Bourboule";
$areanames{en}->{3344339} = "Le\ Puy\-en\-Velay";
$areanames{en}->{3344340} = "Mauriac";
$areanames{en}->{3344341} = "Montlucon";
$areanames{en}->{3344342} = "Moulins";
$areanames{en}->{3344343} = "Clermont\-Ferrand";
$areanames{en}->{3344344} = "Riom";
$areanames{en}->{3344345} = "Saint\-Flour";
$areanames{en}->{3344346} = "Thiers";
$areanames{en}->{3344347} = "Vichy";
$areanames{en}->{3344348} = "Yssingeaux";
$areanames{en}->{3344349} = "Moulins";
$areanames{en}->{3344350} = "Vichy";
$areanames{en}->{3344351} = "Moulins";
$areanames{en}->{3344352} = "Aurillac";
$areanames{en}->{3344353} = "Mauriac";
$areanames{en}->{3344354} = "Saint\-Flour";
$areanames{en}->{3344355} = "Clermont\-Ferrand";
$areanames{en}->{3344356} = "Montlucon";
$areanames{en}->{3344357} = "Clermont\-Ferrand";
$areanames{en}->{3344358} = "Clermont\-Ferrand";
$areanames{en}->{3344359} = "Montlucon";
$areanames{en}->{3344360} = "Moulins";
$areanames{en}->{3344361} = "Vichy";
$areanames{en}->{3344362} = "Aurillac";
$areanames{en}->{3344363} = "Mauriac";
$areanames{en}->{3344364} = "Saint\-Flour";
$areanames{en}->{3344365} = "Brioude";
$areanames{en}->{3344366} = "Le\ Puy\-en\-Velay";
$areanames{en}->{3344367} = "Yssingeaux";
$areanames{en}->{3344368} = "Ambert";
$areanames{en}->{3344369} = "La\ Bourboule";
$areanames{en}->{3344370} = "Vichy";
$areanames{en}->{3344371} = "Issoire";
$areanames{en}->{3344372} = "Riom";
$areanames{en}->{3344373} = "Moulins";
$areanames{en}->{3344374} = "Thiers";
$areanames{en}->{3344375} = "Bourbon\-lArchambault";
$areanames{en}->{3344376} = "Clermont\-Ferrand";
$areanames{en}->{3344377} = "Montlucon";
$areanames{en}->{3344378} = "Moulins";
$areanames{en}->{3344379} = "Aurillac";
$areanames{en}->{3344380} = "Clermont\-Ferrand";
$areanames{en}->{3344381} = "Riom";
$areanames{en}->{3344382} = "Le\ Puy\-en\-Velay";
$areanames{en}->{3344383} = "Clermont\-Ferrand";
$areanames{en}->{3344384} = "Clermont\-Ferrand";
$areanames{en}->{3344385} = "Aurillac";
$areanames{en}->{3344386} = "Clermont\-Ferrand";
$areanames{en}->{3344387} = "Mauriac";
$areanames{en}->{3344388} = "Bourbon\-lArchambault";
$areanames{en}->{3344389} = "Montlucon";
$areanames{en}->{3344390} = "Vichy";
$areanames{en}->{3344391} = "Aurillac";
$areanames{en}->{3344392} = "Mauriac";
$areanames{en}->{3344393} = "Saint\-Flour";
$areanames{en}->{3344394} = "Le\ Puy\-en\-Velay";
$areanames{en}->{3344395} = "Ambert";
$areanames{en}->{3344396} = "La\ Bourboule";
$areanames{en}->{3344397} = "Clermont\-Ferrand";
$areanames{en}->{3344398} = "Riom";
$areanames{en}->{3344399} = "Thiers";
$areanames{en}->{3344400} = "Brioude";
$areanames{en}->{3344401} = "Le\ Puy\-en\-Velay";
$areanames{en}->{3344402} = "Yssingeaux";
$areanames{en}->{3344403} = "Aurillac";
$areanames{en}->{3344404} = "Le\ Puy\-en\-Velay";
$areanames{en}->{3344405} = "Clermont\-Ferrand";
$areanames{en}->{3344406} = "Clermont\-Ferrand";
$areanames{en}->{3344437} = "Ambert";
$areanames{en}->{3344438} = "Clermont\-Ferrand";
$areanames{en}->{3344439} = "Issoire";
$areanames{en}->{3344440} = "La\ Bourboule";
$areanames{en}->{3344441} = "Riom";
$areanames{en}->{3344442} = "Thiers";
$areanames{en}->{3344443} = "Le\ Puy\-en\-Velay";
$areanames{en}->{3344444} = "Clermont\-Ferrand";
$areanames{en}->{3344445} = "Yssingeaux";
$areanames{en}->{3344446} = "Brioude";
$areanames{en}->{3344447} = "Thiers";
$areanames{en}->{3344448} = "Bourbon\-lArchambault";
$areanames{en}->{3344449} = "Montlucon";
$areanames{en}->{3344450} = "Moulins";
$areanames{en}->{3344451} = "Vichy";
$areanames{en}->{3344452} = "Brioude";
$areanames{en}->{3344453} = "Le\ Puy\-en\-Velay";
$areanames{en}->{3344454} = "Clermont\-Ferrand";
$areanames{en}->{3344455} = "Yssingeaux";
$areanames{en}->{3344488} = "Clermont\-Ferrand";
$areanames{en}->{3344489} = "Clermont\-Ferrand";
$areanames{en}->{3344800} = "Nîmes";
$areanames{en}->{3344801} = "Langogne";
$areanames{en}->{3344802} = "Carcassonne";
$areanames{en}->{3344803} = "Mende";
$areanames{en}->{3344804} = "Perpignan";
$areanames{en}->{3344805} = "Perpignan";
$areanames{en}->{3344806} = "Nîmes";
$areanames{en}->{3344807} = "Perpignan";
$areanames{en}->{3344808} = "Beziers";
$areanames{en}->{3344809} = "Carcassonne";
$areanames{en}->{3344810} = "Perpignan";
$areanames{en}->{3344811} = "Beziers";
$areanames{en}->{3344812} = "Bagnols\-sur\-Ceze";
$areanames{en}->{3344813} = "Narbonne";
$areanames{en}->{3344814} = "Beziers";
$areanames{en}->{3344815} = "Ales";
$areanames{en}->{3344816} = "Narbonne";
$areanames{en}->{3344817} = "Beziers";
$areanames{en}->{3344818} = "Montpellier";
$areanames{en}->{3344819} = "Montpellier";
$areanames{en}->{3344820} = "Montpellier";
$areanames{en}->{3344821} = "Nîmes";
$areanames{en}->{3344822} = "Perpignan";
$areanames{en}->{3344823} = "Carcassonne";
$areanames{en}->{3344824} = "Bagnols\-sur\-Ceze";
$areanames{en}->{3344825} = "Mende";
$areanames{en}->{3344826} = "Bedarieux";
$areanames{en}->{3344827} = "Nîmes";
$areanames{en}->{3344828} = "Ales";
$areanames{en}->{3344829} = "Montpellier";
$areanames{en}->{3344830} = "Castelnaudary";
$areanames{en}->{3344831} = "Limoux";
$areanames{en}->{3344832} = "Langogne";
$areanames{en}->{3344833} = "Prades";
$areanames{en}->{3344834} = "Montpellier";
$areanames{en}->{3344835} = "Nîmes";
$areanames{en}->{3344836} = "Carcassonne";
$areanames{en}->{3344837} = "Castelnaudary";
$areanames{en}->{3344838} = "Limoux";
$areanames{en}->{3344839} = "Narbonne";
$areanames{en}->{3344840} = "Ales";
$areanames{en}->{3344841} = "Bagnols\-sur\-Ceze";
$areanames{en}->{3344842} = "Nîmes";
$areanames{en}->{3344843} = "Bedarieux";
$areanames{en}->{3344844} = "Beziers";
$areanames{en}->{3344845} = "Montpellier";
$areanames{en}->{3344846} = "Perpignan";
$areanames{en}->{3344847} = "Prades";
$areanames{en}->{3344848} = "Montpellier";
$areanames{en}->{3344849} = "Carcassonne";
$areanames{en}->{3344850} = "Perpignan";
$areanames{en}->{3344851} = "Narbonne";
$areanames{en}->{3344852} = "Beziers";
$areanames{en}->{3344853} = "Ales";
$areanames{en}->{3344854} = "Bedarieux";
$areanames{en}->{3344855} = "Prades";
$areanames{en}->{3344856} = "Beziers";
$areanames{en}->{3344857} = "Perpignan";
$areanames{en}->{3344858} = "Nîmes";
$areanames{en}->{3344859} = "Castelnaudary";
$areanames{en}->{3344860} = "Limoux";
$areanames{en}->{3344861} = "Ales";
$areanames{en}->{3344862} = "Bedarieux";
$areanames{en}->{3344863} = "Langogne";
$areanames{en}->{3344864} = "Mende";
$areanames{en}->{3344865} = "Prades";
$areanames{en}->{3344866} = "Carcassonne";
$areanames{en}->{3344867} = "Montpellier";
$areanames{en}->{3344868} = "Nîmes";
$areanames{en}->{3344869} = "Ales";
$areanames{en}->{3344870} = "Bagnols\-sur\-Ceze";
$areanames{en}->{3344871} = "Nîmes";
$areanames{en}->{3344872} = "Bedarieux";
$areanames{en}->{3344873} = "Beziers";
$areanames{en}->{3344874} = "Montpellier";
$areanames{en}->{3344875} = "Montpellier";
$areanames{en}->{3344876} = "Nîmes";
$areanames{en}->{3344877} = "Montpellier";
$areanames{en}->{3344878} = "Montpellier";
$areanames{en}->{3344879} = "Montpellier";
$areanames{en}->{3344880} = "Montpellier";
$areanames{en}->{3344881} = "Carcassonne";
$areanames{en}->{3344882} = "Castelnaudary";
$areanames{en}->{3344883} = "Limoux";
$areanames{en}->{3344884} = "Narbonne";
$areanames{en}->{3344885} = "Ales";
$areanames{en}->{3344886} = "Bagnols\-sur\-Ceze";
$areanames{en}->{3344887} = "Nîmes";
$areanames{en}->{3344888} = "Mende";
$areanames{en}->{3344889} = "Perpignan";
$areanames{en}->{3344890} = "Beziers";
$areanames{en}->{3344891} = "Nîmes";
$areanames{en}->{3344892} = "Nîmes";
$areanames{en}->{3344893} = "Bedarieux";
$areanames{en}->{3344894} = "Beziers";
$areanames{en}->{3344895} = "Montpellier";
$areanames{en}->{3344896} = "Langogne";
$areanames{en}->{3344897} = "Mende";
$areanames{en}->{3344898} = "Perpignan";
$areanames{en}->{3344899} = "Prades";
$areanames{en}->{3344900} = "Ales";
$areanames{en}->{3344901} = "Perpignan";
$areanames{en}->{3344902} = "Montpellier";
$areanames{en}->{3344903} = "Carcassonne";
$areanames{en}->{3344904} = "Perpignan";
$areanames{en}->{3344905} = "Nîmes";
$areanames{en}->{3344906} = "Beziers";
$areanames{en}->{3344907} = "Montpellier";
$areanames{en}->{3344908} = "Perpignan";
$areanames{en}->{3344909} = "Bagnols\-sur\-Ceze";
$areanames{en}->{3345600} = "Grenoble";
$areanames{en}->{3345601} = "Le\ Bourg\-dOisans";
$areanames{en}->{3345602} = "Bellegarde\-sur\-Valserine";
$areanames{en}->{3345603} = "Le\ Bourg\-dOisans";
$areanames{en}->{3345604} = "Monestier\-de\-Clermont";
$areanames{en}->{3345605} = "Grenoble";
$areanames{en}->{3345606} = "Aix\-les\-Bains";
$areanames{en}->{3345607} = "Albertville";
$areanames{en}->{3345608} = "Chambery";
$areanames{en}->{3345609} = "Grenoble";
$areanames{en}->{3345620} = "Annecy";
$areanames{en}->{3345621} = "Saint\-Marcellin";
$areanames{en}->{3345622} = "Voiron";
$areanames{en}->{3345623} = "Belley";
$areanames{en}->{3345624} = "Grenoble";
$areanames{en}->{3345625} = "Voiron";
$areanames{en}->{3345626} = "Voiron";
$areanames{en}->{3345627} = "Aix\-les\-Bains";
$areanames{en}->{3345628} = "Albertville";
$areanames{en}->{3345629} = "Chambery";
$areanames{en}->{3345630} = "Annemasse";
$areanames{en}->{3345631} = "Moutiers";
$areanames{en}->{3345632} = "Saint\-Jean\-de\-Maurienne";
$areanames{en}->{3345633} = "Saint\-Marcellin";
$areanames{en}->{3345634} = "Annecy";
$areanames{en}->{3345635} = "Annemasse";
$areanames{en}->{3345636} = "Annemasse";
$areanames{en}->{3345637} = "Sallanches";
$areanames{en}->{3345638} = "Grenoble";
$areanames{en}->{3345639} = "Aix\-les\-Bains";
$areanames{en}->{3345640} = "Grenoble";
$areanames{en}->{3345641} = "Annecy";
$areanames{en}->{3345642} = "Chambery";
$areanames{en}->{3345643} = "Albertville";
$areanames{en}->{3345644} = "Annemasse";
$areanames{en}->{3345645} = "Grenoble";
$areanames{en}->{3345646} = "Sallanches";
$areanames{en}->{3345647} = "Voiron";
$areanames{en}->{3345648} = "Aix\-les\-Bains";
$areanames{en}->{3345649} = "Annecy";
$areanames{en}->{3345650} = "Chambery";
$areanames{en}->{3345651} = "Moutiers";
$areanames{en}->{3345652} = "Grenoble";
$areanames{en}->{3345653} = "Saint\-Jean\-de\-Maurienne";
$areanames{en}->{3345654} = "Belley";
$areanames{en}->{3345655} = "Monestier\-de\-Clermont";
$areanames{en}->{3345656} = "La\ Mure";
$areanames{en}->{3345657} = "Aix\-les\-Bains";
$areanames{en}->{3345658} = "Grenoble";
$areanames{en}->{3345659} = "Grenoble";
$areanames{en}->{3345660} = "Grenoble";
$areanames{en}->{3345661} = "Grenoble";
$areanames{en}->{3345662} = "Voiron";
$areanames{en}->{3345663} = "Voiron";
$areanames{en}->{3345664} = "Chambery";
$areanames{en}->{3345665} = "Chambery";
$areanames{en}->{3345666} = "Annemasse";
$areanames{en}->{3345667} = "Annecy";
$areanames{en}->{3345668} = "Annecy";
$areanames{en}->{3345669} = "Sallanches";
$areanames{en}->{3345670} = "Annecy";
$areanames{en}->{3345671} = "Annecy";
$areanames{en}->{3345672} = "Annecy";
$areanames{en}->{3345673} = "Annecy";
$areanames{en}->{3345674} = "Annecy";
$areanames{en}->{3345675} = "Chambery";
$areanames{en}->{3345676} = "Chambery";
$areanames{en}->{3345677} = "Chambery";
$areanames{en}->{3345678} = "Chambery";
$areanames{en}->{3345679} = "Chambery";
$areanames{en}->{3345690} = "Grenoble";
$areanames{en}->{3345691} = "Bellegarde\-sur\-Valserine";
$areanames{en}->{3345692} = "Bellegarde\-sur\-Valserine";
$areanames{en}->{3345693} = "Belley";
$areanames{en}->{3345694} = "Le\ Bourg\-dOisans";
$areanames{en}->{3345695} = "Monestier\-de\-Clermont";
$areanames{en}->{3345696} = "Saint\-Jean\-de\-Maurienne";
$areanames{en}->{3345697} = "La\ Mure";
$areanames{en}->{3345698} = "Saint\-Marcellin";
$areanames{en}->{3345699} = "Voiron";
$areanames{en}->{3345700} = "Grenoble";
$areanames{en}->{3345701} = "Voiron";
$areanames{en}->{3345702} = "Grenoble";
$areanames{en}->{3345703} = "Belley";
$areanames{en}->{3345704} = "Grenoble";
$areanames{en}->{3345705} = "Bellegarde\-sur\-Valserine";
$areanames{en}->{3345706} = "Annecy";
$areanames{en}->{3345707} = "Grenoble";
$areanames{en}->{3345708} = "Chambery";
$areanames{en}->{3345709} = "Annecy";
$areanames{en}->{3345720} = "Voiron";
$areanames{en}->{3345721} = "Grenoble";
$areanames{en}->{3345722} = "Annemasse";
$areanames{en}->{3345723} = "Voiron";
$areanames{en}->{3345724} = "Aix\-les\-Bains";
$areanames{en}->{3345725} = "Albertville";
$areanames{en}->{3345726} = "Annemasse";
$areanames{en}->{3345727} = "Sallanches";
$areanames{en}->{3345728} = "Bellegarde\-sur\-Valserine";
$areanames{en}->{3345729} = "Belley";
$areanames{en}->{3345750} = "Monestier\-de\-Clermont";
$areanames{en}->{3345751} = "Moutiers";
$areanames{en}->{3345752} = "Saint\-Jean\-de\-Maurienne";
$areanames{en}->{3345753} = "Saint\-Marcellin";
$areanames{en}->{3345754} = "Sallanches";
$areanames{en}->{3345755} = "Moutiers";
$areanames{en}->{3345756} = "Voiron";
$areanames{en}->{3345757} = "Annecy";
$areanames{en}->{3345758} = "Grenoble";
$areanames{en}->{3345759} = "La\ Mure";
$areanames{en}->{3345760} = "Aix\-les\-Bains";
$areanames{en}->{3345761} = "Albertville";
$areanames{en}->{3345762} = "Annemasse";
$areanames{en}->{3345763} = "Moutiers";
$areanames{en}->{3345764} = "Saint\-Jean\-de\-Maurienne";
$areanames{en}->{3345765} = "Sallanches";
$areanames{en}->{3345766} = "Le\ Bourg\-dOisans";
$areanames{en}->{3345767} = "Bellegarde\-sur\-Valserine";
$areanames{en}->{3345768} = "Monestier\-de\-Clermont";
$areanames{en}->{3345769} = "La\ Mure";
$areanames{en}->{3345770} = "Saint\-Marcellin";
$areanames{en}->{3345771} = "Belley";
$areanames{en}->{3345772} = "Aix\-les\-Bains";
$areanames{en}->{3345773} = "Chambery";
$areanames{en}->{3345774} = "Annecy";
$areanames{en}->{3345775} = "Annemasse";
$areanames{en}->{3345776} = "Annecy";
$areanames{en}->{3345777} = "Annemasse";
$areanames{en}->{3345778} = "Chambery";
$areanames{en}->{3345779} = "Grenoble";
$areanames{en}->{3345780} = "Sallanches";
$areanames{en}->{3345781} = "Voiron";
$areanames{en}->{3345782} = "Saint\-Marcellin";
$areanames{en}->{3345783} = "Saint\-Jean\-de\-Maurienne";
$areanames{en}->{3345784} = "Annemasse";
$areanames{en}->{3345785} = "Chambery";
$areanames{en}->{3345786} = "Sallanches";
$areanames{en}->{3345787} = "Voiron";
$areanames{en}->{3345788} = "Annemasse";
$areanames{en}->{3345789} = "Annecy";
$areanames{en}->{3345790} = "Grenoble";
$areanames{en}->{3345791} = "Sallanches";
$areanames{en}->{3345792} = "Voiron";
$areanames{en}->{3345793} = "Grenoble";
$areanames{en}->{3345794} = "Bellegarde\-sur\-Valserine";
$areanames{en}->{3345795} = "Aix\-les\-Bains";
$areanames{en}->{3345796} = "Albertville";
$areanames{en}->{3345797} = "Aix\-les\-Bains";
$areanames{en}->{3345798} = "Annecy";
$areanames{en}->{3345799} = "Chambery";
$areanames{en}->{3345800} = "Grenoble";
$areanames{en}->{3345801} = "Chambery";
$areanames{en}->{3345802} = "Annecy";
$areanames{en}->{3345803} = "Le\ Bourg\-dOisans";
$areanames{en}->{3345804} = "Chambery";
$areanames{en}->{3345805} = "Grenoble";
$areanames{en}->{3345806} = "Monestier\-de\-Clermont";
$areanames{en}->{3345807} = "La\ Mure";
$areanames{en}->{3345808} = "Saint\-Marcellin";
$areanames{en}->{3345809} = "Voiron";
$areanames{en}->{3345810} = "Annecy";
$areanames{en}->{3345811} = "Belley";
$areanames{en}->{3345812} = "Chambery";
$areanames{en}->{3345813} = "Annecy";
$areanames{en}->{3345814} = "Chambery";
$areanames{en}->{3345815} = "Voiron";
$areanames{en}->{3345816} = "Aix\-les\-Bains";
$areanames{en}->{3345817} = "Grenoble";
$areanames{en}->{3345818} = "Grenoble";
$areanames{en}->{3345819} = "Le\ Bourg\-dOisans";
$areanames{en}->{3345820} = "Monestier\-de\-Clermont";
$areanames{en}->{3345821} = "La\ Mure";
$areanames{en}->{3345822} = "Saint\-Marcellin";
$areanames{en}->{3345823} = "Albertville";
$areanames{en}->{3345824} = "Moutiers";
$areanames{en}->{3345825} = "Saint\-Jean\-de\-Maurienne";
$areanames{en}->{3345826} = "Le\ Bourg\-dOisans";
$areanames{en}->{3345827} = "Grenoble";
$areanames{en}->{3345828} = "Monestier\-de\-Clermont";
$areanames{en}->{3345829} = "La\ Mure";
$areanames{en}->{3345830} = "Saint\-Marcellin";
$areanames{en}->{3345831} = "Voiron";
$areanames{en}->{3345832} = "Aix\-les\-Bains";
$areanames{en}->{3345833} = "Albertville";
$areanames{en}->{3345834} = "Chambery";
$areanames{en}->{3345835} = "Moutiers";
$areanames{en}->{3345836} = "Saint\-Jean\-de\-Maurienne";
$areanames{en}->{3345837} = "Annemasse";
$areanames{en}->{3345838} = "Sallanches";
$areanames{en}->{3345839} = "Aix\-les\-Bains";
$areanames{en}->{3345840} = "Albertville";
$areanames{en}->{3345841} = "Bellegarde\-sur\-Valserine";
$areanames{en}->{3345842} = "La\ Mure";
$areanames{en}->{3345843} = "Grenoble";
$areanames{en}->{3345844} = "Chambery";
$areanames{en}->{3345845} = "Belley";
$areanames{en}->{3345846} = "Grenoble";
$areanames{en}->{3345847} = "Grenoble";
$areanames{en}->{3345848} = "Chambery";
$areanames{en}->{3345849} = "Belley";
$areanames{en}->{3345850} = "Annemasse";
$areanames{en}->{3345851} = "Voiron";
$areanames{en}->{3345852} = "Annecy";
$areanames{en}->{3345853} = "Aix\-les\-Bains";
$areanames{en}->{3345854} = "Annecy";
$areanames{en}->{3345855} = "Grenoble";
$areanames{en}->{3345856} = "Sallanches";
$areanames{en}->{3345857} = "Annemasse";
$areanames{en}->{3345858} = "Annecy";
$areanames{en}->{3345859} = "Le\ Bourg\-dOisans";
$areanames{en}->{3345860} = "Grenoble";
$areanames{en}->{3345861} = "Chambery";
$areanames{en}->{3345862} = "Aix\-les\-Bains";
$areanames{en}->{3345863} = "Annecy";
$areanames{en}->{3345864} = "Annemasse";
$areanames{en}->{3345865} = "Sallanches";
$areanames{en}->{3345866} = "Annemasse";
$areanames{en}->{3345867} = "Grenoble";
$areanames{en}->{3345868} = "Monestier\-de\-Clermont";
$areanames{en}->{3345869} = "La\ Mure";
$areanames{en}->{3345870} = "Saint\-Marcellin";
$areanames{en}->{3345871} = "Voiron";
$areanames{en}->{3345872} = "Aix\-les\-Bains";
$areanames{en}->{3345873} = "Albertville";
$areanames{en}->{3345874} = "Moutiers";
$areanames{en}->{3345875} = "Saint\-Jean\-de\-Maurienne";
$areanames{en}->{3345876} = "Annemasse";
$areanames{en}->{3345877} = "Sallanches";
$areanames{en}->{3345878} = "Annemasse";
$areanames{en}->{3345879} = "Sallanches";
$areanames{en}->{3345880} = "Grenoble";
$areanames{en}->{3345881} = "Saint\-Jean\-de\-Maurienne";
$areanames{en}->{3345882} = "Chambery";
$areanames{en}->{3345883} = "Moutiers";
$areanames{en}->{3345884} = "Grenoble";
$areanames{en}->{3345885} = "Albertville";
$areanames{en}->{3345886} = "Le\ Bourg\-dOisans";
$areanames{en}->{3345887} = "Voiron";
$areanames{en}->{3345888} = "Saint\-Marcellin";
$areanames{en}->{3345889} = "Voiron";
$areanames{en}->{3345890} = "Chambery";
$areanames{en}->{3345891} = "Albertville";
$areanames{en}->{3345892} = "Annemasse";
$areanames{en}->{3345893} = "Bellegarde\-sur\-Valserine";
$areanames{en}->{3345894} = "Belley";
$areanames{en}->{3345895} = "Moutiers";
$areanames{en}->{3345896} = "Saint\-Jean\-de\-Maurienne";
$areanames{en}->{3345897} = "Sallanches";
$areanames{en}->{3345898} = "Annecy";
$areanames{en}->{3345899} = "Annemasse";
$areanames{en}->{3346300} = "Ambert";
$areanames{en}->{3346301} = "Clermont\-Ferrand";
$areanames{en}->{3346302} = "Montlucon";
$areanames{en}->{3346303} = "Saint\-Flour";
$areanames{en}->{3346304} = "Clermont\-Ferrand";
$areanames{en}->{3346305} = "Clermont\-Ferrand";
$areanames{en}->{3346306} = "Bourbon\-lArchambault";
$areanames{en}->{3346307} = "Moulins";
$areanames{en}->{3346308} = "Clermont\-Ferrand";
$areanames{en}->{3346309} = "Bourbon\-lArchambault";
$areanames{en}->{3346310} = "Montlucon";
$areanames{en}->{3346311} = "Moulins";
$areanames{en}->{3346312} = "Vichy";
$areanames{en}->{3346313} = "Aurillac";
$areanames{en}->{3346314} = "Mauriac";
$areanames{en}->{3346315} = "Saint\-Flour";
$areanames{en}->{3346316} = "Brioude";
$areanames{en}->{3346317} = "Le\ Puy\-en\-Velay";
$areanames{en}->{3346318} = "Yssingeaux";
$areanames{en}->{3346319} = "Ambert";
$areanames{en}->{3346330} = "Clermont\-Ferrand";
$areanames{en}->{3346331} = "Brioude";
$areanames{en}->{3346332} = "Clermont\-Ferrand";
$areanames{en}->{3346333} = "Ambert";
$areanames{en}->{3346334} = "Ambert";
$areanames{en}->{3346335} = "Vichy";
$areanames{en}->{3346336} = "Aurillac";
$areanames{en}->{3346337} = "Le\ Puy\-en\-Velay";
$areanames{en}->{3346338} = "Aurillac";
$areanames{en}->{3346339} = "Bourbon\-lArchambault";
$areanames{en}->{3346340} = "Ambert";
$areanames{en}->{3346341} = "Aurillac";
$areanames{en}->{3346342} = "La\ Bourboule";
$areanames{en}->{3346343} = "Clermont\-Ferrand";
$areanames{en}->{3346344} = "Issoire";
$areanames{en}->{3346345} = "Brioude";
$areanames{en}->{3346346} = "Clermont\-Ferrand";
$areanames{en}->{3346347} = "Issoire";
$areanames{en}->{3346348} = "Mauriac";
$areanames{en}->{3346349} = "Montlucon";
$areanames{en}->{3346350} = "Moulins";
$areanames{en}->{3346351} = "Roanne";
$areanames{en}->{3346352} = "Le\ Puy\-en\-Velay";
$areanames{en}->{3346353} = "Issoire";
$areanames{en}->{3346354} = "Riom";
$areanames{en}->{3346355} = "La\ Bourboule";
$areanames{en}->{3346356} = "Saint\-Flour";
$areanames{en}->{3346357} = "Thiers";
$areanames{en}->{3346358} = "Vichy";
$areanames{en}->{3346359} = "Brioude";
$areanames{en}->{3346360} = "Clermont\-Ferrand";
$areanames{en}->{3346361} = "Riom";
$areanames{en}->{3346362} = "Thiers";
$areanames{en}->{3346363} = "Riom";
$areanames{en}->{3346364} = "Vichy";
$areanames{en}->{3346365} = "Roanne";
$areanames{en}->{3346366} = "Clermont\-Ferrand";
$areanames{en}->{3346367} = "Clermont\-Ferrand";
$areanames{en}->{3346368} = "Issoire";
$areanames{en}->{3346369} = "Riom";
$areanames{en}->{3346370} = "Thiers";
$areanames{en}->{3346371} = "Yssingeaux";
$areanames{en}->{3346372} = "Montlucon";
$areanames{en}->{3346373} = "Moulins";
$areanames{en}->{3346374} = "Yssingeaux";
$areanames{en}->{3346375} = "Yssingeaux";
$areanames{en}->{3346376} = "Bourbon\-lArchambault";
$areanames{en}->{3346377} = "La\ Bourboule";
$areanames{en}->{3346378} = "Brioude";
$areanames{en}->{3346379} = "Clermont\-Ferrand";
$areanames{en}->{3346380} = "Issoire";
$areanames{en}->{3346381} = "Mauriac";
$areanames{en}->{3346382} = "Montlucon";
$areanames{en}->{3346383} = "Moulins";
$areanames{en}->{3346384} = "Le\ Puy\-en\-Velay";
$areanames{en}->{3346385} = "Riom";
$areanames{en}->{3346386} = "Saint\-Flour";
$areanames{en}->{3346387} = "Thiers";
$areanames{en}->{3346388} = "Vichy";
$areanames{en}->{3346389} = "Yssingeaux";
$areanames{en}->{3346390} = "Bourbon\-lArchambault";
$areanames{en}->{3346391} = "Montlucon";
$areanames{en}->{3346392} = "Moulins";
$areanames{en}->{3346393} = "Vichy";
$areanames{en}->{3346394} = "Aurillac";
$areanames{en}->{3346395} = "Mauriac";
$areanames{en}->{3346396} = "Saint\-Flour";
$areanames{en}->{3346397} = "Brioude";
$areanames{en}->{3346398} = "Le\ Puy\-en\-Velay";
$areanames{en}->{3346399} = "Yssingeaux";
$areanames{en}->{3346500} = "Avignon";
$areanames{en}->{3346501} = "Marignane";
$areanames{en}->{3346502} = "Orange";
$areanames{en}->{3346503} = "Gap";
$areanames{en}->{3346504} = "Aix\-en\-Provence";
$areanames{en}->{3346505} = "Marignane";
$areanames{en}->{3346506} = "Marseille";
$areanames{en}->{3346507} = "Aix\-en\-Provence";
$areanames{en}->{3346508} = "Arles";
$areanames{en}->{3346509} = "Cavaillon";
$areanames{en}->{3346510} = "Manosque";
$areanames{en}->{3346511} = "Marseille";
$areanames{en}->{3346512} = "Marseille";
$areanames{en}->{3346513} = "Digne\-les\-Bains";
$areanames{en}->{3346514} = "Gap";
$areanames{en}->{3346515} = "Aix\-en\-Provence";
$areanames{en}->{3346516} = "Arles";
$areanames{en}->{3346517} = "Aubagne";
$areanames{en}->{3346518} = "Marignane";
$areanames{en}->{3346519} = "Aix\-en\-Provence";
$areanames{en}->{3346520} = "Avignon";
$areanames{en}->{3346521} = "Marseille";
$areanames{en}->{3346522} = "Saint\-André\-les\-Alpes";
$areanames{en}->{3346523} = "Pertuis";
$areanames{en}->{3346524} = "Avignon";
$areanames{en}->{3346525} = "Orange";
$areanames{en}->{3346526} = "Aix\-en\-Provence";
$areanames{en}->{3346527} = "Marseille";
$areanames{en}->{3346528} = "Aubagne";
$areanames{en}->{3346529} = "Marignane";
$areanames{en}->{3346530} = "Cavaillon";
$areanames{en}->{3346531} = "Marseille";
$areanames{en}->{3346532} = "Digne\-les\-Bains";
$areanames{en}->{3346533} = "Marseille";
$areanames{en}->{3346534} = "Manosque";
$areanames{en}->{3346535} = "Digne\-les\-Bains";
$areanames{en}->{3346536} = "Aix\-en\-Provence";
$areanames{en}->{3346537} = "Marseille";
$areanames{en}->{3346538} = "Marseille";
$areanames{en}->{3346539} = "Marseille";
$areanames{en}->{3346540} = "Marseille";
$areanames{en}->{3346541} = "Marseille";
$areanames{en}->{3346542} = "Marseille";
$areanames{en}->{3346543} = "Marseille";
$areanames{en}->{3346544} = "Digne\-les\-Bains";
$areanames{en}->{3346545} = "Manosque";
$areanames{en}->{3346546} = "Saint\-André\-les\-Alpes";
$areanames{en}->{3346547} = "Gap";
$areanames{en}->{3346548} = "Aix\-en\-Provence";
$areanames{en}->{3346549} = "Arles";
$areanames{en}->{3346550} = "Aubagne";
$areanames{en}->{3346551} = "Marignane";
$areanames{en}->{3346552} = "Marseille";
$areanames{en}->{3346553} = "Avignon";
$areanames{en}->{3346554} = "Cavaillon";
$areanames{en}->{3346555} = "Orange";
$areanames{en}->{3346556} = "Pertuis";
$areanames{en}->{3346557} = "Marseille";
$areanames{en}->{3346558} = "Marseille";
$areanames{en}->{3346559} = "Marseille";
$areanames{en}->{3346560} = "Gap";
$areanames{en}->{3346561} = "Digne\-les\-Bains";
$areanames{en}->{3346562} = "Avignon";
$areanames{en}->{3346563} = "Marseille";
$areanames{en}->{3346564} = "Aubagne";
$areanames{en}->{3346565} = "Marseille";
$areanames{en}->{3346566} = "Marseille";
$areanames{en}->{3346567} = "Avignon";
$areanames{en}->{3346568} = "Avignon";
$areanames{en}->{3346569} = "Manosque";
$areanames{en}->{3346570} = "Arles";
$areanames{en}->{3346572} = "Marseille";
$areanames{en}->{3346573} = "Manosque";
$areanames{en}->{3346574} = "Saint\-André\-les\-Alpes";
$areanames{en}->{3346575} = "Cavaillon";
$areanames{en}->{3346576} = "Orange";
$areanames{en}->{3346577} = "Pertuis";
$areanames{en}->{3346578} = "Arles";
$areanames{en}->{3346579} = "Orange";
$areanames{en}->{3346580} = "Pertuis";
$areanames{en}->{3346581} = "Avignon";
$areanames{en}->{3346582} = "Marseille";
$areanames{en}->{3346583} = "Orange";
$areanames{en}->{3346584} = "Marseille";
$areanames{en}->{3346585} = "Marseille";
$areanames{en}->{3346586} = "Aix\-en\-Provence";
$areanames{en}->{3346587} = "Avignon";
$areanames{en}->{3346588} = "Arles";
$areanames{en}->{3346589} = "Orange";
$areanames{en}->{3346590} = "Gap";
$areanames{en}->{3346591} = "Marseille";
$areanames{en}->{3346592} = "Aix\-en\-Provence";
$areanames{en}->{3346593} = "Marseille";
$areanames{en}->{3346594} = "Marignane";
$areanames{en}->{3346595} = "Marseille";
$areanames{en}->{3346596} = "Marseille";
$areanames{en}->{3346597} = "Marseille";
$areanames{en}->{3346598} = "Marseille";
$areanames{en}->{334661} = "Sud\ Est";
$areanames{en}->{3346617} = "Mende";
$areanames{en}->{3346618} = "Nîmes";
$areanames{en}->{3346619} = "Nîmes";
$areanames{en}->{3346690} = "Bagnols\-sur\-Ceze";
$areanames{en}->{3346691} = "Ales";
$areanames{en}->{3346692} = "Ales";
$areanames{en}->{3346693} = "Nîmes";
$areanames{en}->{3346694} = "Mende";
$areanames{en}->{3346695} = "Nîmes";
$areanames{en}->{3346696} = "Bagnols\-sur\-Ceze";
$areanames{en}->{3346697} = "Sud\ Est";
$areanames{en}->{3346698} = "Bagnols\-sur\-Ceze";
$areanames{en}->{3346699} = "Sud\ Est";
$areanames{en}->{3346900} = "Bourgoin\-Jallieu";
$areanames{en}->{3346901} = "Vienne";
$areanames{en}->{3346902} = "Annonay";
$areanames{en}->{3346903} = "Aubenas";
$areanames{en}->{3346904} = "Die";
$areanames{en}->{3346905} = "Feurs";
$areanames{en}->{3346906} = "Nyons";
$areanames{en}->{3346907} = "Roanne";
$areanames{en}->{3346908} = "Saint\-Vallier";
$areanames{en}->{3346909} = "Tarare";
$areanames{en}->{3346910} = "Tournon\-sur\-Rhone";
$areanames{en}->{3346911} = "Valence";
$areanames{en}->{3346912} = "Villefranche\-sur\-Saone";
$areanames{en}->{3346913} = "Amberieu\-en\-Bugey";
$areanames{en}->{3346914} = "Montelimar";
$areanames{en}->{3346915} = "Bourgoin\-Jallieu";
$areanames{en}->{3346916} = "Lyon";
$areanames{en}->{3346917} = "Villefranche\-sur\-Saone";
$areanames{en}->{3346918} = "Amberieu\-en\-Bugey";
$areanames{en}->{3346919} = "Bourg\-en\-Bresse";
$areanames{en}->{3346920} = "Nantua";
$areanames{en}->{3346921} = "Annonay";
$areanames{en}->{3346922} = "Aubenas";
$areanames{en}->{3346923} = "Privas";
$areanames{en}->{3346924} = "Tournon\-sur\-Rhone";
$areanames{en}->{3346925} = "Die";
$areanames{en}->{3346926} = "Montelimar";
$areanames{en}->{3346927} = "Nyons";
$areanames{en}->{3346928} = "Romans\-sur\-Isere";
$areanames{en}->{3346929} = "Saint\-Vallier";
$areanames{en}->{3346940} = "Annonay";
$areanames{en}->{3346941} = "Bourg\-en\-Bresse";
$areanames{en}->{3346942} = "Bourgoin\-Jallieu";
$areanames{en}->{3346943} = "Montelimar";
$areanames{en}->{3346944} = "Nantua";
$areanames{en}->{3346945} = "Roanne";
$areanames{en}->{3346946} = "Vienne";
$areanames{en}->{3346947} = "Villefranche\-sur\-Saone";
$areanames{en}->{3346948} = "Nantua";
$areanames{en}->{3346949} = "Bourg\-en\-Bresse";
$areanames{en}->{3346950} = "Bourgoin\-Jallieu";
$areanames{en}->{3346951} = "Saint\-Etienne";
$areanames{en}->{3346952} = "Valence";
$areanames{en}->{3346953} = "Vienne";
$areanames{en}->{3346954} = "Bourg\-en\-Bresse";
$areanames{en}->{3346955} = "Lyon";
$areanames{en}->{3346956} = "Montelimar";
$areanames{en}->{3346957} = "Romans\-sur\-Isere";
$areanames{en}->{3346958} = "Saint\-Etienne";
$areanames{en}->{3346959} = "Tarare";
$areanames{en}->{3346980} = "Romans\-sur\-Isere";
$areanames{en}->{3346981} = "Bourg\-en\-Bresse";
$areanames{en}->{3346982} = "Bourgoin\-Jallieu";
$areanames{en}->{3346983} = "Feurs";
$areanames{en}->{3346984} = "Lyon";
$areanames{en}->{3346985} = "Lyon";
$areanames{en}->{3346986} = "Montelimar";
$areanames{en}->{3346987} = "Nantua";
$areanames{en}->{3346988} = "Bourg\-en\-Bresse";
$areanames{en}->{3346989} = "Villefranche\-sur\-Saone";
$areanames{en}->{3346990} = "Montelimar";
$areanames{en}->{3346991} = "Nyons";
$areanames{en}->{3346992} = "Privas";
$areanames{en}->{3346993} = "Roanne";
$areanames{en}->{3346994} = "Romans\-sur\-Isere";
$areanames{en}->{3346995} = "Saint\-Etienne";
$areanames{en}->{3346996} = "Lyon";
$areanames{en}->{3346997} = "Annemasse";
$areanames{en}->{3346998} = "Lyon";
$areanames{en}->{3346999} = "Tarare";
$areanames{en}->{334700} = "Montlucon";
$areanames{en}->{3347000} = "Sud\ Est";
$areanames{en}->{3347001} = "Sud\ Est";
$areanames{en}->{334701} = "Sud\ Est";
$areanames{en}->{3347050} = "Vichy";
$areanames{en}->{3347051} = "Montlucon";
$areanames{en}->{3347052} = "Moulins";
$areanames{en}->{3347053} = "Sud\ Est";
$areanames{en}->{3347054} = "Sud\ Est";
$areanames{en}->{3347055} = "Vichy";
$areanames{en}->{3347056} = "Vichy";
$areanames{en}->{3347057} = "Moulins";
$areanames{en}->{3347058} = "Vichy";
$areanames{en}->{3347059} = "Vichy";
$areanames{en}->{334707} = "Sud\ Est";
$areanames{en}->{334708} = "Sud\ Est";
$areanames{en}->{334711} = "Sud\ Est";
$areanames{en}->{334713} = "Sud\ Est";
$areanames{en}->{334718} = "Sud\ Est";
$areanames{en}->{334719} = "Sud\ Est";
$areanames{en}->{334730} = "Sud\ Est";
$areanames{en}->{334731} = "Clermont\-Ferrand";
$areanames{en}->{3347311} = "Sud\ Est";
$areanames{en}->{3347312} = "Sud\ Est";
$areanames{en}->{3347313} = "Moulins";
$areanames{en}->{3347318} = "Sud\ Est";
$areanames{en}->{334732} = "Clermont\-Ferrand";
$areanames{en}->{3347321} = "La\ Bourboule";
$areanames{en}->{3347322} = "La\ Bourboule";
$areanames{en}->{334751} = "Sud\ Est";
$areanames{en}->{3348000} = "Annemasse";
$areanames{en}->{3348001} = "Bellegarde\-sur\-Valserine";
$areanames{en}->{3348002} = "Belley";
$areanames{en}->{3348003} = "Chambery";
$areanames{en}->{3348004} = "Grenoble";
$areanames{en}->{3348005} = "La\ Mure";
$areanames{en}->{3348006} = "Le\ Bourg\-dOisans";
$areanames{en}->{3348007} = "Monestier\-de\-Clermont";
$areanames{en}->{3348008} = "Moutiers";
$areanames{en}->{3348009} = "Saint\-Jean\-de\-Maurienne";
$areanames{en}->{3348010} = "Saint\-Marcellin";
$areanames{en}->{3348011} = "Sallanches";
$areanames{en}->{3348012} = "Voiron";
$areanames{en}->{3348013} = "Annemasse";
$areanames{en}->{3348014} = "Chambery";
$areanames{en}->{3348015} = "Grenoble";
$areanames{en}->{3348016} = "Annemasse";
$areanames{en}->{3348017} = "Bellegarde\-sur\-Valserine";
$areanames{en}->{3348018} = "Le\ Bourg\-dOisans";
$areanames{en}->{3348019} = "Monestier\-de\-Clermont";
$areanames{en}->{3348020} = "La\ Mure";
$areanames{en}->{3348021} = "Saint\-Marcellin";
$areanames{en}->{3348022} = "Voiron";
$areanames{en}->{3348023} = "Aix\-les\-Bains";
$areanames{en}->{3348024} = "Albertville";
$areanames{en}->{3348025} = "Chambery";
$areanames{en}->{3348026} = "Moutiers";
$areanames{en}->{3348027} = "Saint\-Jean\-de\-Maurienne";
$areanames{en}->{3348028} = "Annecy";
$areanames{en}->{3348029} = "Annemasse";
$areanames{en}->{3348040} = "Belley";
$areanames{en}->{3348041} = "Le\ Bourg\-dOisans";
$areanames{en}->{3348042} = "Grenoble";
$areanames{en}->{3348043} = "Monestier\-de\-Clermont";
$areanames{en}->{3348044} = "La\ Mure";
$areanames{en}->{3348045} = "Saint\-Marcellin";
$areanames{en}->{3348046} = "Albertville";
$areanames{en}->{3348047} = "Chambery";
$areanames{en}->{3348048} = "Annecy";
$areanames{en}->{3348049} = "Annecy";
$areanames{en}->{3348050} = "Saint\-Jean\-de\-Maurienne";
$areanames{en}->{3348051} = "Albertville";
$areanames{en}->{3348052} = "Chambery";
$areanames{en}->{3348053} = "Grenoble";
$areanames{en}->{3348054} = "Saint\-Marcellin";
$areanames{en}->{3348055} = "Aix\-les\-Bains";
$areanames{en}->{3348056} = "Voiron";
$areanames{en}->{3348057} = "Annemasse";
$areanames{en}->{3348058} = "Sallanches";
$areanames{en}->{3348059} = "Belley";
$areanames{en}->{3348060} = "Le\ Bourg\-dOisans";
$areanames{en}->{3348061} = "Grenoble";
$areanames{en}->{3348062} = "Monestier\-de\-Clermont";
$areanames{en}->{3348063} = "La\ Mure";
$areanames{en}->{3348064} = "Saint\-Marcellin";
$areanames{en}->{3348065} = "Voiron";
$areanames{en}->{3348066} = "Aix\-les\-Bains";
$areanames{en}->{3348067} = "Albertville";
$areanames{en}->{3348068} = "Chambery";
$areanames{en}->{3348069} = "Moutiers";
$areanames{en}->{3348070} = "Grenoble";
$areanames{en}->{3348071} = "Voiron";
$areanames{en}->{3348072} = "Saint\-Jean\-de\-Maurienne";
$areanames{en}->{3348073} = "Annecy";
$areanames{en}->{3348074} = "Annemasse";
$areanames{en}->{3348075} = "Sallanches";
$areanames{en}->{3348076} = "Chambery";
$areanames{en}->{3348077} = "Annemasse";
$areanames{en}->{3348078} = "Annecy";
$areanames{en}->{3348079} = "Voiron";
$areanames{en}->{3348080} = "Grenoble";
$areanames{en}->{3348081} = "Chambery";
$areanames{en}->{3348082} = "Grenoble";
$areanames{en}->{3348083} = "Grenoble";
$areanames{en}->{3348084} = "Albertville";
$areanames{en}->{3348085} = "Aix\-les\-Bains";
$areanames{en}->{3348086} = "Albertville";
$areanames{en}->{3348087} = "Chambery";
$areanames{en}->{3348088} = "Annecy";
$areanames{en}->{3348089} = "Annemasse";
$areanames{en}->{3348090} = "Sallanches";
$areanames{en}->{3348091} = "Bellegarde\-sur\-Valserine";
$areanames{en}->{3348092} = "Annecy";
$areanames{en}->{3348093} = "Grenoble";
$areanames{en}->{3348094} = "Annecy";
$areanames{en}->{3348095} = "Annemasse";
$areanames{en}->{3348096} = "Sallanches";
$areanames{en}->{3348097} = "Annecy";
$areanames{en}->{3348098} = "Moutiers";
$areanames{en}->{3348099} = "Annemasse";
$areanames{en}->{3348100} = "Tarare";
$areanames{en}->{3348101} = "Tournon\-sur\-Rhone";
$areanames{en}->{3348102} = "Valence";
$areanames{en}->{3348103} = "Vienne";
$areanames{en}->{3348104} = "Villefranche\-sur\-Saone";
$areanames{en}->{3348105} = "Die";
$areanames{en}->{3348106} = "Lyon";
$areanames{en}->{3348107} = "Lyon";
$areanames{en}->{3348108} = "Saint\-Etienne";
$areanames{en}->{3348109} = "Lyon";
$areanames{en}->{3348110} = "Lyon";
$areanames{en}->{3348111} = "Lyon";
$areanames{en}->{3348112} = "Saint\-Etienne";
$areanames{en}->{3348113} = "Lyon";
$areanames{en}->{3348114} = "Tarare";
$areanames{en}->{3348115} = "Villefranche\-sur\-Saone";
$areanames{en}->{3348116} = "Valence";
$areanames{en}->{3348117} = "Roanne";
$areanames{en}->{3348118} = "Lyon";
$areanames{en}->{3348119} = "Amberieu\-en\-Bugey";
$areanames{en}->{3348120} = "Bourg\-en\-Bresse";
$areanames{en}->{3348121} = "Nantua";
$areanames{en}->{3348122} = "Annonay";
$areanames{en}->{3348123} = "Aubenas";
$areanames{en}->{3348124} = "Tournon\-sur\-Rhone";
$areanames{en}->{3348125} = "Die";
$areanames{en}->{3348126} = "Montelimar";
$areanames{en}->{3348127} = "Nyons";
$areanames{en}->{3348128} = "Romans\-sur\-Isere";
$areanames{en}->{3348129} = "Saint\-Vallier";
$areanames{en}->{3348130} = "Bourg\-en\-Bresse";
$areanames{en}->{3348131} = "Aubenas";
$areanames{en}->{3348132} = "Valence";
$areanames{en}->{3348133} = "Saint\-Etienne";
$areanames{en}->{3348134} = "Vienne";
$areanames{en}->{3348135} = "Vienne";
$areanames{en}->{3348136} = "Roanne";
$areanames{en}->{3348137} = "Feurs";
$areanames{en}->{3348138} = "Roanne";
$areanames{en}->{3348139} = "Valence";
$areanames{en}->{3348140} = "Saint\-Etienne";
$areanames{en}->{3348141} = "Tarare";
$areanames{en}->{3348142} = "Villefranche\-sur\-Saone";
$areanames{en}->{3348143} = "Vienne";
$areanames{en}->{3348144} = "Lyon";
$areanames{en}->{3348145} = "Tarare";
$areanames{en}->{3348146} = "Villefranche\-sur\-Saone";
$areanames{en}->{3348147} = "Lyon";
$areanames{en}->{3348148} = "Villefranche\-sur\-Saone";
$areanames{en}->{3348149} = "Lyon";
$areanames{en}->{3348150} = "Amberieu\-en\-Bugey";
$areanames{en}->{3348151} = "Bourg\-en\-Bresse";
$areanames{en}->{3348152} = "Annonay";
$areanames{en}->{3348153} = "Aubenas";
$areanames{en}->{3348154} = "Privas";
$areanames{en}->{3348155} = "Bourgoin\-Jallieu";
$areanames{en}->{3348156} = "Tournon\-sur\-Rhone";
$areanames{en}->{3348157} = "Die";
$areanames{en}->{3348158} = "Nyons";
$areanames{en}->{3348159} = "Romans\-sur\-Isere";
$areanames{en}->{3348160} = "Saint\-Vallier";
$areanames{en}->{3348161} = "Bourgoin\-Jallieu";
$areanames{en}->{3348162} = "Vienne";
$areanames{en}->{3348163} = "Feurs";
$areanames{en}->{3348164} = "Saint\-Etienne";
$areanames{en}->{3348165} = "Lyon";
$areanames{en}->{3348166} = "Valence";
$areanames{en}->{3348167} = "Nantua";
$areanames{en}->{3348168} = "Lyon";
$areanames{en}->{3348169} = "Lyon";
$areanames{en}->{3348170} = "Villefranche\-sur\-Saone";
$areanames{en}->{3348171} = "Lyon";
$areanames{en}->{3348172} = "Tarare";
$areanames{en}->{3348173} = "Romans\-sur\-Isere";
$areanames{en}->{3348174} = "Valence";
$areanames{en}->{3348175} = "Die";
$areanames{en}->{3348176} = "Lyon";
$areanames{en}->{3348177} = "Feurs";
$areanames{en}->{3348178} = "Roanne";
$areanames{en}->{3348179} = "Villefranche\-sur\-Saone";
$areanames{en}->{3348180} = "Tarare";
$areanames{en}->{3348181} = "Villefranche\-sur\-Saone";
$areanames{en}->{3348182} = "Montelimar";
$areanames{en}->{3348183} = "Romans\-sur\-Isere";
$areanames{en}->{3348184} = "Valence";
$areanames{en}->{3348185} = "Saint\-Etienne";
$areanames{en}->{3348186} = "Privas";
$areanames{en}->{3348187} = "Romans\-sur\-Isere";
$areanames{en}->{3348188} = "Lyon";
$areanames{en}->{3348189} = "Annonay";
$areanames{en}->{3348190} = "Romans\-sur\-Isere";
$areanames{en}->{3348191} = "Lyon";
$areanames{en}->{3348192} = "Lyon";
$areanames{en}->{3348193} = "Lyon";
$areanames{en}->{3348194} = "Bourg\-en\-Bresse";
$areanames{en}->{3348195} = "Roanne";
$areanames{en}->{3348196} = "Saint\-Etienne";
$areanames{en}->{3348197} = "Bourgoin\-Jallieu";
$areanames{en}->{3348198} = "Vienne";
$areanames{en}->{3348199} = "Valence";
$areanames{en}->{3348200} = "Bourg\-en\-Bresse";
$areanames{en}->{3348201} = "Tournon\-sur\-Rhone";
$areanames{en}->{3348202} = "Nantua";
$areanames{en}->{3348203} = "Aubenas";
$areanames{en}->{3348204} = "Saint\-Vallier";
$areanames{en}->{3348205} = "Bourgoin\-Jallieu";
$areanames{en}->{3348206} = "Vienne";
$areanames{en}->{3348207} = "Amberieu\-en\-Bugey";
$areanames{en}->{3348208} = "Nantua";
$areanames{en}->{3348209} = "Bourg\-en\-Bresse";
$areanames{en}->{3348210} = "Annonay";
$areanames{en}->{3348211} = "Aubenas";
$areanames{en}->{3348212} = "Privas";
$areanames{en}->{3348213} = "Tournon\-sur\-Rhone";
$areanames{en}->{3348214} = "Die";
$areanames{en}->{3348215} = "Montelimar";
$areanames{en}->{3348216} = "Nyons";
$areanames{en}->{3348217} = "Romans\-sur\-Isere";
$areanames{en}->{3348218} = "Saint\-Vallier";
$areanames{en}->{3348219} = "Valence";
$areanames{en}->{3348220} = "Bourgoin\-Jallieu";
$areanames{en}->{3348221} = "Vienne";
$areanames{en}->{3348222} = "Feurs";
$areanames{en}->{3348223} = "Roanne";
$areanames{en}->{3348224} = "Saint\-Etienne";
$areanames{en}->{3348225} = "Lyon";
$areanames{en}->{3348226} = "Tarare";
$areanames{en}->{3348227} = "Villefranche\-sur\-Saone";
$areanames{en}->{3348228} = "Saint\-Etienne";
$areanames{en}->{3348229} = "Lyon";
$areanames{en}->{3348230} = "Romans\-sur\-Isere";
$areanames{en}->{3348231} = "Lyon";
$areanames{en}->{3348232} = "Valence";
$areanames{en}->{3348233} = "Lyon";
$areanames{en}->{3348234} = "Montelimar";
$areanames{en}->{3348235} = "Roanne";
$areanames{en}->{3348236} = "Romans\-sur\-Isere";
$areanames{en}->{3348237} = "Saint\-Etienne";
$areanames{en}->{3348238} = "Tarare";
$areanames{en}->{3348239} = "Valence";
$areanames{en}->{3348240} = "Vienne";
$areanames{en}->{3348241} = "Villefranche\-sur\-Saone";
$areanames{en}->{3348242} = "Amberieu\-en\-Bugey";
$areanames{en}->{3348243} = "Aubenas";
$areanames{en}->{3348244} = "Privas";
$areanames{en}->{3348245} = "Tournon\-sur\-Rhone";
$areanames{en}->{3348246} = "Die";
$areanames{en}->{3348247} = "Nyons";
$areanames{en}->{3348248} = "Romans\-sur\-Isere";
$areanames{en}->{3348249} = "Saint\-Vallier";
$areanames{en}->{3348250} = "Feurs";
$areanames{en}->{3348251} = "Tarare";
$areanames{en}->{3348252} = "Lyon";
$areanames{en}->{3348253} = "Lyon";
$areanames{en}->{3348254} = "Lyon";
$areanames{en}->{3348255} = "Annonay";
$areanames{en}->{3348256} = "Aubenas";
$areanames{en}->{3348257} = "Privas";
$areanames{en}->{3348258} = "Tournon\-sur\-Rhone";
$areanames{en}->{3348259} = "Die";
$areanames{en}->{3348260} = "Montelimar";
$areanames{en}->{3348261} = "Nyons";
$areanames{en}->{3348262} = "Vienne";
$areanames{en}->{3348263} = "Romans\-sur\-Isere";
$areanames{en}->{3348264} = "Saint\-Vallier";
$areanames{en}->{3348265} = "Valence";
$areanames{en}->{3348266} = "Bourgoin\-Jallieu";
$areanames{en}->{3348267} = "Vienne";
$areanames{en}->{3348268} = "Feurs";
$areanames{en}->{3348269} = "Roanne";
$areanames{en}->{3348270} = "Saint\-Etienne";
$areanames{en}->{3348271} = "Lyon";
$areanames{en}->{3348272} = "Tarare";
$areanames{en}->{3348273} = "Villefranche\-sur\-Saone";
$areanames{en}->{3348274} = "Lyon";
$areanames{en}->{3348275} = "Lyon";
$areanames{en}->{3348276} = "Tournon\-sur\-Rhone";
$areanames{en}->{3348277} = "Saint\-Etienne";
$areanames{en}->{3348278} = "Lyon";
$areanames{en}->{3348279} = "Lyon";
$areanames{en}->{3348280} = "Lyon";
$areanames{en}->{3348281} = "Saint\-Etienne";
$areanames{en}->{3348282} = "Saint\-Etienne";
$areanames{en}->{3348283} = "Villefranche\-sur\-Saone";
$areanames{en}->{3348284} = "Bourg\-en\-Bresse";
$areanames{en}->{3348285} = "Valence";
$areanames{en}->{3348286} = "Vienne";
$areanames{en}->{3348287} = "Roanne";
$areanames{en}->{3348288} = "Nyons";
$areanames{en}->{3348289} = "Saint\-Etienne";
$areanames{en}->{3348290} = "Lyon";
$areanames{en}->{3348291} = "Lyon";
$areanames{en}->{3348292} = "Bourgoin\-Jallieu";
$areanames{en}->{3348293} = "Amberieu\-en\-Bugey";
$areanames{en}->{3348294} = "Annonay";
$areanames{en}->{3348295} = "Aubenas";
$areanames{en}->{3348296} = "Montelimar";
$areanames{en}->{3348297} = "Privas";
$areanames{en}->{3348298} = "Lyon";
$areanames{en}->{3348299} = "Amberieu\-en\-Bugey";
$areanames{en}->{3348300} = "Brignoles";
$areanames{en}->{3348301} = "Nice";
$areanames{en}->{3348302} = "Toulon";
$areanames{en}->{3348303} = "Cannes";
$areanames{en}->{3348304} = "Nice";
$areanames{en}->{3348305} = "Grasse";
$areanames{en}->{3348306} = "Nice";
$areanames{en}->{3348307} = "Brignoles";
$areanames{en}->{3348308} = "Draguignan";
$areanames{en}->{3348309} = "Saint\-Raphael";
$areanames{en}->{3348320} = "Saint\-Raphael";
$areanames{en}->{3348321} = "Toulon";
$areanames{en}->{3348322} = "Puget\-Theniers";
$areanames{en}->{3348323} = "Toulon";
$areanames{en}->{3348324} = "Toulon";
$areanames{en}->{3348325} = "Toulon";
$areanames{en}->{3348326} = "Grasse";
$areanames{en}->{3348327} = "Brignoles";
$areanames{en}->{3348328} = "Cannes";
$areanames{en}->{3348329} = "Draguignan";
$areanames{en}->{3348330} = "Cannes";
$areanames{en}->{3348331} = "Grasse";
$areanames{en}->{3348332} = "Nice";
$areanames{en}->{3348333} = "Nice";
$areanames{en}->{3348334} = "Puget\-Theniers";
$areanames{en}->{3348335} = "Saint\-Raphael";
$areanames{en}->{3348336} = "Toulon";
$areanames{en}->{3348337} = "Grasse";
$areanames{en}->{3348338} = "Toulon";
$areanames{en}->{3348339} = "Nice";
$areanames{en}->{3348360} = "Puget\-Theniers";
$areanames{en}->{3348361} = "Cannes";
$areanames{en}->{3348362} = "Saint\-Raphael";
$areanames{en}->{3348363} = "Nice";
$areanames{en}->{3348364} = "Toulon";
$areanames{en}->{3348365} = "Cannes";
$areanames{en}->{3348366} = "Nice";
$areanames{en}->{3348367} = "Brignoles";
$areanames{en}->{3348368} = "Saint\-Raphael";
$areanames{en}->{3348369} = "Toulon";
$areanames{en}->{3348370} = "Nice";
$areanames{en}->{3348371} = "Draguignan";
$areanames{en}->{3348372} = "Brignoles";
$areanames{en}->{3348373} = "Toulon";
$areanames{en}->{3348374} = "Puget\-Theniers";
$areanames{en}->{3348375} = "Toulon";
$areanames{en}->{3348376} = "Nice";
$areanames{en}->{3348377} = "Toulon";
$areanames{en}->{3348378} = "Draguignan";
$areanames{en}->{3348379} = "Puget\-Theniers";
$areanames{en}->{3348380} = "Nice";
$areanames{en}->{3348381} = "Nice";
$areanames{en}->{3348382} = "Brignoles";
$areanames{en}->{3348383} = "Cannes";
$areanames{en}->{3348384} = "Nice";
$areanames{en}->{3348385} = "Nice";
$areanames{en}->{3348386} = "Cannes";
$areanames{en}->{3348387} = "Toulon";
$areanames{en}->{3348388} = "Cannes";
$areanames{en}->{3348389} = "Toulon";
$areanames{en}->{3348390} = "Grasse";
$areanames{en}->{3348391} = "Cannes";
$areanames{en}->{3348392} = "Grasse";
$areanames{en}->{3348393} = "Nice";
$areanames{en}->{3348394} = "Nice";
$areanames{en}->{3348395} = "Toulon";
$areanames{en}->{3348396} = "Nice";
$areanames{en}->{3348397} = "Toulon";
$areanames{en}->{3348398} = "Nice";
$areanames{en}->{3348399} = "Toulon";
$areanames{en}->{3348400} = "Digne\-les\-Bains";
$areanames{en}->{3348401} = "Manosque";
$areanames{en}->{3348402} = "Saint\-André\-les\-Alpes";
$areanames{en}->{3348403} = "Gap";
$areanames{en}->{3348404} = "Aix\-en\-Provence";
$areanames{en}->{3348405} = "Arles";
$areanames{en}->{3348406} = "Aubagne";
$areanames{en}->{3348407} = "Marignane";
$areanames{en}->{3348408} = "Marseille";
$areanames{en}->{3348409} = "Avignon";
$areanames{en}->{3348430} = "Aix\-en\-Provence";
$areanames{en}->{3348431} = "Marseille";
$areanames{en}->{3348432} = "Marseille";
$areanames{en}->{3348433} = "Marseille";
$areanames{en}->{3348434} = "Aix\-en\-Provence";
$areanames{en}->{3348435} = "Marseille";
$areanames{en}->{3348436} = "Avignon";
$areanames{en}->{3348437} = "Digne\-les\-Bains";
$areanames{en}->{3348438} = "Gap";
$areanames{en}->{3348439} = "Aix\-en\-Provence";
$areanames{en}->{3348440} = "Marseille";
$areanames{en}->{3348441} = "Arles";
$areanames{en}->{3348442} = "Aubagne";
$areanames{en}->{3348443} = "Avignon";
$areanames{en}->{3348444} = "Marignane";
$areanames{en}->{3348445} = "Marseille";
$areanames{en}->{3348446} = "Aix\-en\-Provence";
$areanames{en}->{3348447} = "Aix\-en\-Provence";
$areanames{en}->{3348448} = "Aubagne";
$areanames{en}->{3348449} = "Aix\-en\-Provence";
$areanames{en}->{3348450} = "Marseille";
$areanames{en}->{3348451} = "Avignon";
$areanames{en}->{3348452} = "Marseille";
$areanames{en}->{3348453} = "Digne\-les\-Bains";
$areanames{en}->{3348454} = "Digne\-les\-Bains";
$areanames{en}->{3348455} = "Manosque";
$areanames{en}->{3348456} = "Saint\-André\-les\-Alpes";
$areanames{en}->{3348457} = "Gap";
$areanames{en}->{3348458} = "Aix\-en\-Provence";
$areanames{en}->{3348459} = "Arles";
$areanames{en}->{3348460} = "Aix\-en\-Provence";
$areanames{en}->{3348461} = "Arles";
$areanames{en}->{3348462} = "Aubagne";
$areanames{en}->{3348463} = "Avignon";
$areanames{en}->{3348464} = "Cavaillon";
$areanames{en}->{3348465} = "Gap";
$areanames{en}->{3348466} = "Marignane";
$areanames{en}->{3348467} = "Marseille";
$areanames{en}->{3348468} = "Orange";
$areanames{en}->{3348469} = "Pertuis";
$areanames{en}->{3348470} = "Aubagne";
$areanames{en}->{3348471} = "Marignane";
$areanames{en}->{3348472} = "Marseille";
$areanames{en}->{3348473} = "Avignon";
$areanames{en}->{3348474} = "Gap";
$areanames{en}->{3348475} = "Cavaillon";
$areanames{en}->{3348476} = "Arles";
$areanames{en}->{3348477} = "Orange";
$areanames{en}->{3348478} = "Pertuis";
$areanames{en}->{3348479} = "Marseille";
$areanames{en}->{3348480} = "Aix\-en\-Provence";
$areanames{en}->{3348481} = "Marseille";
$areanames{en}->{3348482} = "Marseille";
$areanames{en}->{3348483} = "Aubagne";
$areanames{en}->{3348484} = "Arles";
$areanames{en}->{3348485} = "Orange";
$areanames{en}->{3348486} = "Marseille";
$areanames{en}->{3348487} = "Digne\-les\-Bains";
$areanames{en}->{3348488} = "Marseille";
$areanames{en}->{3348489} = "Marseille";
$areanames{en}->{3348490} = "Marseille";
$areanames{en}->{3348491} = "Marseille";
$areanames{en}->{3348492} = "Marignane";
$areanames{en}->{3348493} = "Aix\-en\-Provence";
$areanames{en}->{3348494} = "Avignon";
$areanames{en}->{3348495} = "Aubagne";
$areanames{en}->{3348496} = "Gap";
$areanames{en}->{3348497} = "Arles";
$areanames{en}->{3348498} = "Arles";
$areanames{en}->{3348499} = "Marseille";
$areanames{en}->{3348500} = "Annecy";
$areanames{en}->{3348501} = "Chambery";
$areanames{en}->{3348502} = "Grenoble";
$areanames{en}->{3348503} = "Bellegarde\-sur\-Valserine";
$areanames{en}->{3348504} = "Belley";
$areanames{en}->{3348505} = "Aix\-les\-Bains";
$areanames{en}->{3348506} = "Monestier\-de\-Clermont";
$areanames{en}->{3348507} = "Saint\-Marcellin";
$areanames{en}->{3348508} = "Voiron";
$areanames{en}->{3348509} = "Le\ Bourg\-dOisans";
$areanames{en}->{3348510} = "La\ Mure";
$areanames{en}->{3348511} = "Aix\-les\-Bains";
$areanames{en}->{3348512} = "Albertville";
$areanames{en}->{3348513} = "Chambery";
$areanames{en}->{3348514} = "Moutiers";
$areanames{en}->{3348515} = "Saint\-Jean\-de\-Maurienne";
$areanames{en}->{3348516} = "Annecy";
$areanames{en}->{3348517} = "Annemasse";
$areanames{en}->{3348518} = "Sallanches";
$areanames{en}->{3348519} = "Grenoble";
$areanames{en}->{3348520} = "Bellegarde\-sur\-Valserine";
$areanames{en}->{3348521} = "Annecy";
$areanames{en}->{3348522} = "Annemasse";
$areanames{en}->{3348523} = "Sallanches";
$areanames{en}->{3348524} = "Belley";
$areanames{en}->{3348525} = "Aix\-les\-Bains";
$areanames{en}->{3348526} = "Albertville";
$areanames{en}->{3348527} = "Moutiers";
$areanames{en}->{3348528} = "Saint\-Jean\-de\-Maurienne";
$areanames{en}->{3348529} = "Bellegarde\-sur\-Valserine";
$areanames{en}->{3348530} = "Sallanches";
$areanames{en}->{3348531} = "Grenoble";
$areanames{en}->{3348532} = "La\ Mure";
$areanames{en}->{3348533} = "Le\ Bourg\-dOisans";
$areanames{en}->{3348534} = "Monestier\-de\-Clermont";
$areanames{en}->{3348535} = "Saint\-Marcellin";
$areanames{en}->{3348536} = "Voiron";
$areanames{en}->{3348537} = "Belley";
$areanames{en}->{3348538} = "Grenoble";
$areanames{en}->{3348539} = "Bellegarde\-sur\-Valserine";
$areanames{en}->{3348540} = "Voiron";
$areanames{en}->{3348541} = "Grenoble";
$areanames{en}->{3348542} = "Sallanches";
$areanames{en}->{3348543} = "Grenoble";
$areanames{en}->{3348544} = "Chambery";
$areanames{en}->{3348545} = "Aix\-les\-Bains";
$areanames{en}->{3348546} = "Annecy";
$areanames{en}->{3348547} = "Annemasse";
$areanames{en}->{3348571} = "Saint\-Jean\-de\-Maurienne";
$areanames{en}->{3348572} = "Annecy";
$areanames{en}->{3348573} = "Annemasse";
$areanames{en}->{3348574} = "Sallanches";
$areanames{en}->{3348575} = "Bellegarde\-sur\-Valserine";
$areanames{en}->{3348576} = "Aix\-les\-Bains";
$areanames{en}->{3348577} = "Albertville";
$areanames{en}->{3348578} = "Chambery";
$areanames{en}->{3348579} = "Moutiers";
$areanames{en}->{3348580} = "Annecy";
$areanames{en}->{3348581} = "La\ Mure";
$areanames{en}->{3348582} = "Monestier\-de\-Clermont";
$areanames{en}->{3348583} = "Saint\-Marcellin";
$areanames{en}->{3348584} = "Voiron";
$areanames{en}->{3348585} = "Grenoble";
$areanames{en}->{3348586} = "Chambery";
$areanames{en}->{3348587} = "Grenoble";
$areanames{en}->{3348588} = "Grenoble";
$areanames{en}->{3348589} = "Saint\-Jean\-de\-Maurienne";
$areanames{en}->{3348590} = "Annecy";
$areanames{en}->{3348591} = "Grenoble";
$areanames{en}->{3348592} = "Chambery";
$areanames{en}->{3348593} = "Bellegarde\-sur\-Valserine";
$areanames{en}->{3348594} = "Aix\-les\-Bains";
$areanames{en}->{3348595} = "Albertville";
$areanames{en}->{3348596} = "Chambery";
$areanames{en}->{3348597} = "Moutiers";
$areanames{en}->{3348598} = "Saint\-Jean\-de\-Maurienne";
$areanames{en}->{3348600} = "Digne\-les\-Bains";
$areanames{en}->{3348601} = "Marseille";
$areanames{en}->{3348602} = "Manosque";
$areanames{en}->{3348603} = "Cavaillon";
$areanames{en}->{3348604} = "Orange";
$areanames{en}->{3348605} = "Pertuis";
$areanames{en}->{3348606} = "Marseille";
$areanames{en}->{3348607} = "Marseille";
$areanames{en}->{3348608} = "Marignane";
$areanames{en}->{3348609} = "Marseille";
$areanames{en}->{3348620} = "Aubagne";
$areanames{en}->{3348621} = "Marignane";
$areanames{en}->{3348622} = "Aix\-en\-Provence";
$areanames{en}->{3348623} = "Aix\-en\-Provence";
$areanames{en}->{3348624} = "Avignon";
$areanames{en}->{3348625} = "Aubagne";
$areanames{en}->{3348626} = "Marseille";
$areanames{en}->{3348627} = "Manosque";
$areanames{en}->{3348628} = "Pertuis";
$areanames{en}->{3348629} = "Saint\-André\-les\-Alpes";
$areanames{en}->{3348640} = "Avignon";
$areanames{en}->{3348641} = "Marseille";
$areanames{en}->{3348642} = "Aix\-en\-Provence";
$areanames{en}->{3348643} = "Marignane";
$areanames{en}->{3348644} = "Aubagne";
$areanames{en}->{3348645} = "Cavaillon";
$areanames{en}->{3348646} = "Marseille";
$areanames{en}->{3348647} = "Orange";
$areanames{en}->{3348648} = "Marignane";
$areanames{en}->{3348649} = "Digne\-les\-Bains";
$areanames{en}->{3348650} = "Cavaillon";
$areanames{en}->{3348651} = "Marignane";
$areanames{en}->{3348652} = "Arles";
$areanames{en}->{3348653} = "Orange";
$areanames{en}->{3348654} = "Pertuis";
$areanames{en}->{3348655} = "Cavaillon";
$areanames{en}->{3348656} = "Manosque";
$areanames{en}->{3348657} = "Marseille";
$areanames{en}->{3348658} = "Manosque";
$areanames{en}->{3348659} = "Saint\-André\-les\-Alpes";
$areanames{en}->{3348700} = "Saint\-Etienne";
$areanames{en}->{3348701} = "Villefranche\-sur\-Saone";
$areanames{en}->{3348702} = "Saint\-Etienne";
$areanames{en}->{3348703} = "Feurs";
$areanames{en}->{3348704} = "Roanne";
$areanames{en}->{3348705} = "Nantua";
$areanames{en}->{3348706} = "Annonay";
$areanames{en}->{3348707} = "Aubenas";
$areanames{en}->{3348708} = "Privas";
$areanames{en}->{3348709} = "Tournon\-sur\-Rhone";
$areanames{en}->{3348710} = "Die";
$areanames{en}->{3348711} = "Montelimar";
$areanames{en}->{3348712} = "Nyons";
$areanames{en}->{3348713} = "Romans\-sur\-Isere";
$areanames{en}->{3348714} = "Saint\-Vallier";
$areanames{en}->{3348715} = "Valence";
$areanames{en}->{3348716} = "Vienne";
$areanames{en}->{3348717} = "Feurs";
$areanames{en}->{3348718} = "Roanne";
$areanames{en}->{3348719} = "Tarare";
$areanames{en}->{3348720} = "Romans\-sur\-Isere";
$areanames{en}->{3348721} = "Nantua";
$areanames{en}->{3348722} = "Aubenas";
$areanames{en}->{3348723} = "Roanne";
$areanames{en}->{3348724} = "Lyon";
$areanames{en}->{3348725} = "Lyon";
$areanames{en}->{3348726} = "Montelimar";
$areanames{en}->{3348727} = "Saint\-Etienne";
$areanames{en}->{3348728} = "Feurs";
$areanames{en}->{3348729} = "Lyon";
$areanames{en}->{3348730} = "Villefranche\-sur\-Saone";
$areanames{en}->{3348731} = "Romans\-sur\-Isere";
$areanames{en}->{3348732} = "Montelimar";
$areanames{en}->{3348733} = "Lyon";
$areanames{en}->{3348734} = "Lyon";
$areanames{en}->{3348735} = "Lyon";
$areanames{en}->{3348736} = "Amberieu\-en\-Bugey";
$areanames{en}->{3348737} = "Lyon";
$areanames{en}->{3348738} = "Lyon";
$areanames{en}->{3348739} = "Amberieu\-en\-Bugey";
$areanames{en}->{3348740} = "Bourg\-en\-Bresse";
$areanames{en}->{3348741} = "Nantua";
$areanames{en}->{3348742} = "Annonay";
$areanames{en}->{3348743} = "Aubenas";
$areanames{en}->{3348744} = "Privas";
$areanames{en}->{3348745} = "Tournon\-sur\-Rhone";
$areanames{en}->{3348746} = "Die";
$areanames{en}->{3348747} = "Montelimar";
$areanames{en}->{3348748} = "Nyons";
$areanames{en}->{3348749} = "Romans\-sur\-Isere";
$areanames{en}->{3348750} = "Saint\-Vallier";
$areanames{en}->{3348751} = "Valence";
$areanames{en}->{3348752} = "Feurs";
$areanames{en}->{3348753} = "Roanne";
$areanames{en}->{3348754} = "Saint\-Etienne";
$areanames{en}->{3348755} = "Lyon";
$areanames{en}->{3348756} = "Tarare";
$areanames{en}->{3348757} = "Villefranche\-sur\-Saone";
$areanames{en}->{3348758} = "Bourgoin\-Jallieu";
$areanames{en}->{3348759} = "Vienne";
$areanames{en}->{3348760} = "Aubenas";
$areanames{en}->{3348761} = "Lyon";
$areanames{en}->{3348762} = "Lyon";
$areanames{en}->{3348763} = "Lyon";
$areanames{en}->{3348764} = "Lyon";
$areanames{en}->{3348765} = "Lyon";
$areanames{en}->{3348766} = "Saint\-Etienne";
$areanames{en}->{3348767} = "Bourg\-en\-Bresse";
$areanames{en}->{3348768} = "Amberieu\-en\-Bugey";
$areanames{en}->{3348769} = "Feurs";
$areanames{en}->{3348770} = "Tarare";
$areanames{en}->{3348771} = "Lyon";
$areanames{en}->{3348772} = "Annonay";
$areanames{en}->{3348773} = "Montelimar";
$areanames{en}->{3348775} = "Valence";
$areanames{en}->{3348776} = "Lyon";
$areanames{en}->{3348777} = "Lyon";
$areanames{en}->{3348778} = "Lyon";
$areanames{en}->{3348779} = "Amberieu\-en\-Bugey";
$areanames{en}->{3348780} = "Lyon";
$areanames{en}->{3348788} = "Amberieu\-en\-Bugey";
$areanames{en}->{3348789} = "Lyon";
$areanames{en}->{3348790} = "Valence";
$areanames{en}->{3348791} = "Lyon";
$areanames{en}->{3348792} = "Tarare";
$areanames{en}->{3348793} = "Lyon";
$areanames{en}->{3348794} = "Lyon";
$areanames{en}->{3348795} = "Lyon";
$areanames{en}->{3348796} = "Valence";
$areanames{en}->{3348797} = "Amberieu\-en\-Bugey";
$areanames{en}->{3348798} = "Bourg\-en\-Bresse";
$areanames{en}->{3348799} = "Lyon";
$areanames{en}->{3348810} = "Marseille";
$areanames{en}->{3348811} = "Gap";
$areanames{en}->{3348812} = "Aix\-en\-Provence";
$areanames{en}->{3348813} = "Marseille";
$areanames{en}->{3348814} = "Aix\-en\-Provence";
$areanames{en}->{3348815} = "Marseille";
$areanames{en}->{3348816} = "Digne\-les\-Bains";
$areanames{en}->{3348817} = "Avignon";
$areanames{en}->{3348818} = "Arles";
$areanames{en}->{3348819} = "Aix\-en\-Provence";
$areanames{en}->{3348820} = "Aubagne";
$areanames{en}->{3348821} = "Marignane";
$areanames{en}->{3348822} = "Marseille";
$areanames{en}->{3348823} = "Cavaillon";
$areanames{en}->{3348824} = "Digne\-les\-Bains";
$areanames{en}->{3348825} = "Manosque";
$areanames{en}->{3348826} = "Gap";
$areanames{en}->{3348827} = "Gap";
$areanames{en}->{3348828} = "Avignon";
$areanames{en}->{3348829} = "Aix\-en\-Provence";
$areanames{en}->{3348830} = "Marseille";
$areanames{en}->{3348831} = "Marseille";
$areanames{en}->{3348832} = "Marseille";
$areanames{en}->{3348833} = "Marseille";
$areanames{en}->{3348834} = "Aix\-en\-Provence";
$areanames{en}->{3348835} = "Aix\-en\-Provence";
$areanames{en}->{3348836} = "Marseille";
$areanames{en}->{3348837} = "Arles";
$areanames{en}->{3348838} = "Cavaillon";
$areanames{en}->{3348839} = "Aubagne";
$areanames{en}->{3348840} = "Marignane";
$areanames{en}->{3348841} = "Aix\-en\-Provence";
$areanames{en}->{3348842} = "Aubagne";
$areanames{en}->{3348843} = "Marignane";
$areanames{en}->{3348844} = "Marseille";
$areanames{en}->{3348845} = "Arles";
$areanames{en}->{3348846} = "Aubagne";
$areanames{en}->{3348847} = "Marignane";
$areanames{en}->{3348848} = "Orange";
$areanames{en}->{3348849} = "Marseille";
$areanames{en}->{3348850} = "Orange";
$areanames{en}->{3348851} = "Avignon";
$areanames{en}->{3348852} = "Cavaillon";
$areanames{en}->{3348853} = "Orange";
$areanames{en}->{3348854} = "Avignon";
$areanames{en}->{3348855} = "Pertuis";
$areanames{en}->{3348856} = "Marseille";
$areanames{en}->{3348857} = "Marseille";
$areanames{en}->{3348858} = "Pertuis";
$areanames{en}->{3348859} = "Aix\-en\-Provence";
$areanames{en}->{334886} = "Marseille";
$areanames{en}->{3348861} = "Avignon";
$areanames{en}->{3348863} = "Marignane";
$areanames{en}->{3348865} = "Arles";
$areanames{en}->{3348868} = "Aubagne";
$areanames{en}->{3348870} = "Avignon";
$areanames{en}->{3348871} = "Aix\-en\-Provence";
$areanames{en}->{3348872} = "Aubagne";
$areanames{en}->{3348873} = "Marseille";
$areanames{en}->{3348874} = "Digne\-les\-Bains";
$areanames{en}->{3348875} = "Digne\-les\-Bains";
$areanames{en}->{3348876} = "Gap";
$areanames{en}->{3348877} = "Marseille";
$areanames{en}->{3348878} = "Aix\-en\-Provence";
$areanames{en}->{3348879} = "Gap";
$areanames{en}->{3348880} = "Aix\-en\-Provence";
$areanames{en}->{3348881} = "Aix\-en\-Provence";
$areanames{en}->{3348882} = "Arles";
$areanames{en}->{3348883} = "Arles";
$areanames{en}->{3348884} = "Orange";
$areanames{en}->{3348885} = "Cavaillon";
$areanames{en}->{3348886} = "Marseille";
$areanames{en}->{3348887} = "Digne\-les\-Bains";
$areanames{en}->{3348888} = "Marignane";
$areanames{en}->{3348889} = "Aubagne";
$areanames{en}->{3348890} = "Marseille";
$areanames{en}->{3348891} = "Marseille";
$areanames{en}->{3348892} = "Marseille";
$areanames{en}->{3348893} = "Marignane";
$areanames{en}->{3348894} = "Marignane";
$areanames{en}->{3348895} = "Avignon";
$areanames{en}->{3348896} = "Avignon";
$areanames{en}->{3348897} = "Orange";
$areanames{en}->{3348898} = "Orange";
$areanames{en}->{3348899} = "Avignon";
$areanames{en}->{3348930} = "Toulon";
$areanames{en}->{3348931} = "Puget\-Theniers";
$areanames{en}->{3348932} = "Nice";
$areanames{en}->{3348933} = "Toulon";
$areanames{en}->{3348934} = "Puget\-Theniers";
$areanames{en}->{3348935} = "Grasse";
$areanames{en}->{3348936} = "Brignoles";
$areanames{en}->{3348937} = "Cannes";
$areanames{en}->{3348938} = "Cannes";
$areanames{en}->{3348939} = "Grasse";
$areanames{en}->{3348940} = "Grasse";
$areanames{en}->{3348941} = "Nice";
$areanames{en}->{3348942} = "Nice";
$areanames{en}->{3348943} = "Puget\-Theniers";
$areanames{en}->{3348944} = "Puget\-Theniers";
$areanames{en}->{3348945} = "Brignoles";
$areanames{en}->{3348946} = "Brignoles";
$areanames{en}->{3348947} = "Draguignan";
$areanames{en}->{3348948} = "Draguignan";
$areanames{en}->{3348949} = "Saint\-Raphael";
$areanames{en}->{3348950} = "Saint\-Raphael";
$areanames{en}->{3348951} = "Toulon";
$areanames{en}->{3348952} = "Toulon";
$areanames{en}->{3348953} = "Draguignan";
$areanames{en}->{3348954} = "Toulon";
$areanames{en}->{3348955} = "Saint\-Raphael";
$areanames{en}->{3348956} = "Nice";
$areanames{en}->{3348957} = "Nice";
$areanames{en}->{3348958} = "Nice";
$areanames{en}->{3348959} = "Puget\-Theniers";
$areanames{en}->{334911} = "Marseille";
$areanames{en}->{334912} = "Marseille";
$areanames{en}->{334913} = "Marseille";
$areanames{en}->{334914} = "Marseille";
$areanames{en}->{334915} = "Marseille";
$areanames{en}->{334917} = "Marseille";
$areanames{en}->{334918} = "Marseille";
$areanames{en}->{334919} = "Marseille";
$areanames{en}->{334938} = "Nice";
$areanames{en}->{334958} = "Sud\ Est";
$areanames{en}->{334959} = "Sud\ Est";
$areanames{en}->{3349597} = "Corse";
$areanames{en}->{334960} = "Sud\ Est";
$areanames{en}->{334961} = "Marseille";
$areanames{en}->{334963} = "Sud\ Est";
$areanames{en}->{3349630} = "Aubagne";
$areanames{en}->{334964} = "Sud\ Est";
$areanames{en}->{3349641} = "Marseille";
$areanames{en}->{334965} = "Sud\ Est";
$areanames{en}->{334966} = "Sud\ Est";
$areanames{en}->{334967} = "Sud\ Est";
$areanames{en}->{334968} = "Sud\ Est";
$areanames{en}->{334969} = "Sud\ Est";
$areanames{en}->{334971} = "Nice";
$areanames{en}->{3349715} = "Cannes";
$areanames{en}->{3349716} = "Cannes";
$areanames{en}->{334973} = "Sud\ Est";
$areanames{en}->{3349733} = "Nice";
$areanames{en}->{334974} = "Sud\ Est";
$areanames{en}->{3349746} = "Nice";
$areanames{en}->{334975} = "Sud\ Est";
$areanames{en}->{334976} = "Sud\ Est";
$areanames{en}->{334977} = "Sud\ Est";
$areanames{en}->{334978} = "Sud\ Est";
$areanames{en}->{3349780} = "Nice";
$areanames{en}->{334979} = "Sud\ Est";
$areanames{en}->{3349797} = "Cannes";
$areanames{en}->{334982} = "Sud\ Est";
$areanames{en}->{334983} = "Sud\ Est";
$areanames{en}->{334984} = "Sud\ Est";
$areanames{en}->{334985} = "Sud\ Est";
$areanames{en}->{3349851} = "Toulon";
$areanames{en}->{334986} = "Sud\ Est";
$areanames{en}->{334987} = "Sud\ Est";
$areanames{en}->{334988} = "Sud\ Est";
$areanames{en}->{334989} = "Sud\ Est";
$areanames{en}->{334993} = "Sud\ Est";
$areanames{en}->{334998} = "Sud\ Est";
$areanames{en}->{3351610} = "Saintes";
$areanames{en}->{3351611} = "Montmorillon";
$areanames{en}->{3351612} = "Melle";
$areanames{en}->{3351613} = "Niort";
$areanames{en}->{3351614} = "Parthenay";
$areanames{en}->{3351615} = "Thouars";
$areanames{en}->{3351616} = "Angoulême";
$areanames{en}->{3351617} = "Chatellerault";
$areanames{en}->{3351618} = "Niort";
$areanames{en}->{3351619} = "La\ Rochelle";
$areanames{en}->{3351620} = "Saintes";
$areanames{en}->{3351621} = "Saint\-Jean\-dAngely";
$areanames{en}->{3351622} = "Saintes";
$areanames{en}->{3351623} = "Bressuire";
$areanames{en}->{3351624} = "Melle";
$areanames{en}->{3351625} = "Niort";
$areanames{en}->{3351626} = "Parthenay";
$areanames{en}->{3351627} = "Thouars";
$areanames{en}->{3351628} = "Chatellerault";
$areanames{en}->{3351629} = "Angoulême";
$areanames{en}->{3351630} = "Chatellerault";
$areanames{en}->{3351631} = "Loudun";
$areanames{en}->{3351632} = "Montmorillon";
$areanames{en}->{3351633} = "Civray";
$areanames{en}->{3351634} = "Poitiers";
$areanames{en}->{3351635} = "Rochefort";
$areanames{en}->{3351636} = "Niort";
$areanames{en}->{3351637} = "Poitiers";
$areanames{en}->{3351638} = "Barbezieux\-Saint\-Hilaire";
$areanames{en}->{3351639} = "Poitiers";
$areanames{en}->{3351650} = "Angoulême";
$areanames{en}->{3351651} = "Saint\-Jean\-dAngely";
$areanames{en}->{3351652} = "Poitiers";
$areanames{en}->{3351653} = "Angoulême";
$areanames{en}->{3351654} = "Barbezieux\-Saint\-Hilaire";
$areanames{en}->{3351655} = "Loudun";
$areanames{en}->{3351656} = "Confolens";
$areanames{en}->{3351657} = "Cognac";
$areanames{en}->{3351658} = "Rochefort";
$areanames{en}->{3351659} = "La\ Rochelle";
$areanames{en}->{3351660} = "Poitiers";
$areanames{en}->{3351661} = "Saintes";
$areanames{en}->{3351662} = "La\ Rochelle";
$areanames{en}->{3351663} = "Confolens";
$areanames{en}->{3351664} = "Niort";
$areanames{en}->{3351665} = "Rochefort";
$areanames{en}->{3351666} = "Montmorillon";
$areanames{en}->{3351667} = "Chatellerault";
$areanames{en}->{3351668} = "Poitiers";
$areanames{en}->{3351669} = "Poitiers";
$areanames{en}->{3351670} = "Angoulême";
$areanames{en}->{3351671} = "Barbezieux\-Saint\-Hilaire";
$areanames{en}->{3351672} = "Bressuire";
$areanames{en}->{3351673} = "Chatellerault";
$areanames{en}->{3351674} = "Civray";
$areanames{en}->{3351675} = "Cognac";
$areanames{en}->{3351676} = "Confolens";
$areanames{en}->{3351677} = "Jonzac";
$areanames{en}->{3351678} = "Loudun";
$areanames{en}->{3351679} = "Melle";
$areanames{en}->{3351690} = "Angoulême";
$areanames{en}->{3351691} = "Barbezieux\-Saint\-Hilaire";
$areanames{en}->{3351692} = "Cognac";
$areanames{en}->{3351693} = "Confolens";
$areanames{en}->{3351694} = "Jonzac";
$areanames{en}->{3351695} = "Poitiers";
$areanames{en}->{3351696} = "Rochefort";
$areanames{en}->{3351697} = "La\ Rochelle";
$areanames{en}->{3351698} = "Saintes";
$areanames{en}->{3351699} = "Saint\-Jean\-dAngely";
$areanames{en}->{3351700} = "Angoulême";
$areanames{en}->{3351701} = "Barbezieux\-Saint\-Hilaire";
$areanames{en}->{3351702} = "Bressuire";
$areanames{en}->{3351703} = "Chatellerault";
$areanames{en}->{3351704} = "Civray";
$areanames{en}->{3351705} = "Jonzac";
$areanames{en}->{3351706} = "La\ Rochelle";
$areanames{en}->{3351707} = "Loudun";
$areanames{en}->{3351708} = "Melle";
$areanames{en}->{3351709} = "Montmorillon";
$areanames{en}->{3351710} = "Niort";
$areanames{en}->{3351711} = "Parthenay";
$areanames{en}->{3351712} = "Poitiers";
$areanames{en}->{3351713} = "Rochefort";
$areanames{en}->{3351714} = "Saint\-Jean\-dAngely";
$areanames{en}->{3351715} = "Saintes";
$areanames{en}->{3351716} = "Thouars";
$areanames{en}->{3351717} = "Angoulême";
$areanames{en}->{3351718} = "Niort";
$areanames{en}->{3351719} = "Chatellerault";
$areanames{en}->{3351720} = "Angoulême";
$areanames{en}->{3351721} = "Barbezieux\-Saint\-Hilaire";
$areanames{en}->{3351722} = "Cognac";
$areanames{en}->{3351723} = "Confolens";
$areanames{en}->{3351724} = "Jonzac";
$areanames{en}->{3351725} = "Rochefort";
$areanames{en}->{3351726} = "La\ Rochelle";
$areanames{en}->{3351727} = "Saint\-Jean\-dAngely";
$areanames{en}->{3351728} = "Saintes";
$areanames{en}->{3351729} = "Bressuire";
$areanames{en}->{3351730} = "Melle";
$areanames{en}->{3351731} = "Parthenay";
$areanames{en}->{3351732} = "Thouars";
$areanames{en}->{3351733} = "Chatellerault";
$areanames{en}->{3351734} = "Civray";
$areanames{en}->{3351735} = "Loudun";
$areanames{en}->{3351736} = "Montmorillon";
$areanames{en}->{3351737} = "Chatellerault";
$areanames{en}->{3351738} = "Niort";
$areanames{en}->{3351739} = "Saintes";
$areanames{en}->{3351740} = "Niort";
$areanames{en}->{3351741} = "Bressuire";
$areanames{en}->{3351742} = "Melle";
$areanames{en}->{3351743} = "Parthenay";
$areanames{en}->{3351744} = "Thouars";
$areanames{en}->{3351745} = "Civray";
$areanames{en}->{3351746} = "Loudun";
$areanames{en}->{3351747} = "Montmorillon";
$areanames{en}->{3351748} = "Angoulême";
$areanames{en}->{3351749} = "Angoulême";
$areanames{en}->{3351750} = "Angoulême";
$areanames{en}->{3351751} = "Chatellerault";
$areanames{en}->{3351752} = "La\ Rochelle";
$areanames{en}->{3351753} = "Niort";
$areanames{en}->{3351754} = "Poitiers";
$areanames{en}->{3351755} = "Rochefort";
$areanames{en}->{3351756} = "Angoulême";
$areanames{en}->{3351757} = "Angoulême";
$areanames{en}->{3351758} = "Barbezieux\-Saint\-Hilaire";
$areanames{en}->{3351759} = "Bressuire";
$areanames{en}->{3351760} = "Chatellerault";
$areanames{en}->{3351761} = "Chatellerault";
$areanames{en}->{3351762} = "Civray";
$areanames{en}->{3351763} = "Cognac";
$areanames{en}->{3351764} = "Confolens";
$areanames{en}->{3351765} = "Jonzac";
$areanames{en}->{3351766} = "Niort";
$areanames{en}->{3351767} = "La\ Rochelle";
$areanames{en}->{3351768} = "Loudun";
$areanames{en}->{3351769} = "Melle";
$areanames{en}->{3351770} = "Poitiers";
$areanames{en}->{3351771} = "Montmorillon";
$areanames{en}->{3351772} = "Niort";
$areanames{en}->{3351773} = "Parthenay";
$areanames{en}->{3351774} = "Poitiers";
$areanames{en}->{3351775} = "Rochefort";
$areanames{en}->{3351776} = "Saintes";
$areanames{en}->{3351777} = "Saint\-Jean\-dAngely";
$areanames{en}->{3351778} = "Thouars";
$areanames{en}->{3351779} = "Angoulême";
$areanames{en}->{3351780} = "La\ Rochelle";
$areanames{en}->{3351781} = "La\ Rochelle";
$areanames{en}->{3351782} = "Rochefort";
$areanames{en}->{3351783} = "La\ Rochelle";
$areanames{en}->{3351784} = "Poitiers";
$areanames{en}->{3351785} = "Angoulême";
$areanames{en}->{3351786} = "Poitiers";
$areanames{en}->{3351787} = "Niort";
$areanames{en}->{3351788} = "Barbezieux\-Saint\-Hilaire";
$areanames{en}->{3351789} = "Cognac";
$areanames{en}->{3351790} = "Angoulême";
$areanames{en}->{3351791} = "La\ Rochelle";
$areanames{en}->{3351792} = "Rochefort";
$areanames{en}->{3351793} = "Poitiers";
$areanames{en}->{3351794} = "Jonzac";
$areanames{en}->{3351795} = "Rochefort";
$areanames{en}->{3351796} = "La\ Rochelle";
$areanames{en}->{3351797} = "Saint\-Jean\-dAngely";
$areanames{en}->{3351798} = "Saintes";
$areanames{en}->{3351799} = "Bressuire";
$areanames{en}->{3351800} = "Bourganeuf";
$areanames{en}->{3351801} = "Boussac";
$areanames{en}->{3351802} = "Gueret";
$areanames{en}->{3351803} = "La\ Souterraine";
$areanames{en}->{3351804} = "Bellac";
$areanames{en}->{3351805} = "Limoges";
$areanames{en}->{3351806} = "Limoges";
$areanames{en}->{3351807} = "Limoges";
$areanames{en}->{3351900} = "Boussac";
$areanames{en}->{3351901} = "Gueret";
$areanames{en}->{3351902} = "La\ Souterraine";
$areanames{en}->{3351903} = "Limoges";
$areanames{en}->{3351904} = "Tulle";
$areanames{en}->{3351905} = "Ussel";
$areanames{en}->{3351906} = "Uzerche";
$areanames{en}->{3351907} = "Tulle";
$areanames{en}->{3351908} = "Limoges";
$areanames{en}->{3351909} = "Limoges";
$areanames{en}->{3351910} = "Argentat";
$areanames{en}->{3351911} = "Tulle";
$areanames{en}->{3351912} = "Ussel";
$areanames{en}->{3351913} = "Uzerche";
$areanames{en}->{3351914} = "Aubusson";
$areanames{en}->{3351915} = "Bourganeuf";
$areanames{en}->{3351916} = "Boussac";
$areanames{en}->{3351917} = "Gueret";
$areanames{en}->{3351918} = "La\ Souterraine";
$areanames{en}->{3351919} = "Gueret";
$areanames{en}->{3351920} = "Bellac";
$areanames{en}->{3351921} = "Limoges";
$areanames{en}->{3351922} = "Limoges";
$areanames{en}->{3351923} = "Bellac";
$areanames{en}->{3351924} = "Bourganeuf";
$areanames{en}->{3351925} = "La\ Souterraine";
$areanames{en}->{3351926} = "Ussel";
$areanames{en}->{3351927} = "Aubusson";
$areanames{en}->{3351928} = "Gueret";
$areanames{en}->{3351929} = "Limoges";
$areanames{en}->{3351930} = "Argentat";
$areanames{en}->{3351931} = "Tulle";
$areanames{en}->{3351932} = "Ussel";
$areanames{en}->{3351933} = "Uzerche";
$areanames{en}->{3351934} = "Aubusson";
$areanames{en}->{3351935} = "Bourganeuf";
$areanames{en}->{3351936} = "Boussac";
$areanames{en}->{3351937} = "Gueret";
$areanames{en}->{3351938} = "Bellac";
$areanames{en}->{3351939} = "Limoges";
$areanames{en}->{3351940} = "Argentat";
$areanames{en}->{3351941} = "Limoges";
$areanames{en}->{3351942} = "Boussac";
$areanames{en}->{3351943} = "Tulle";
$areanames{en}->{3351944} = "Uzerche";
$areanames{en}->{3351945} = "Argentat";
$areanames{en}->{3351946} = "Tulle";
$areanames{en}->{3351947} = "Ussel";
$areanames{en}->{3351948} = "Uzerche";
$areanames{en}->{3351949} = "Aubusson";
$areanames{en}->{3351950} = "Bourganeuf";
$areanames{en}->{3351951} = "Boussac";
$areanames{en}->{3351952} = "Gueret";
$areanames{en}->{3351953} = "La\ Souterraine";
$areanames{en}->{3351954} = "Bellac";
$areanames{en}->{3351955} = "Limoges";
$areanames{en}->{3351956} = "Limoges";
$areanames{en}->{3351957} = "Limoges";
$areanames{en}->{3351958} = "Argentat";
$areanames{en}->{3351959} = "Tulle";
$areanames{en}->{3351960} = "Ussel";
$areanames{en}->{3351961} = "Aubusson";
$areanames{en}->{3351962} = "Boussac";
$areanames{en}->{3351963} = "Tulle";
$areanames{en}->{3351964} = "Argentat";
$areanames{en}->{3351965} = "Tulle";
$areanames{en}->{3351966} = "Ussel";
$areanames{en}->{3351967} = "Uzerche";
$areanames{en}->{3351968} = "Aubusson";
$areanames{en}->{3351969} = "Bourganeuf";
$areanames{en}->{3351970} = "Boussac";
$areanames{en}->{3351971} = "Gueret";
$areanames{en}->{3351972} = "La\ Souterraine";
$areanames{en}->{3351973} = "Bellac";
$areanames{en}->{3351974} = "Limoges";
$areanames{en}->{3351975} = "Tulle";
$areanames{en}->{3351976} = "Limoges";
$areanames{en}->{3351977} = "Gueret";
$areanames{en}->{3351978} = "Limoges";
$areanames{en}->{3351979} = "Tulle";
$areanames{en}->{3351980} = "Tulle";
$areanames{en}->{3351981} = "Tulle";
$areanames{en}->{3351982} = "Argentat";
$areanames{en}->{3351983} = "Ussel";
$areanames{en}->{3351984} = "Uzerche";
$areanames{en}->{3351985} = "Aubusson";
$areanames{en}->{3351986} = "Limoges";
$areanames{en}->{3351987} = "Limoges";
$areanames{en}->{3351988} = "Limoges";
$areanames{en}->{3351989} = "Gueret";
$areanames{en}->{3351990} = "Argentat";
$areanames{en}->{3351991} = "Ussel";
$areanames{en}->{3351992} = "Uzerche";
$areanames{en}->{3351993} = "Aubusson";
$areanames{en}->{3351994} = "Bourganeuf";
$areanames{en}->{3351995} = "Boussac";
$areanames{en}->{3351996} = "La\ Souterraine";
$areanames{en}->{3351997} = "Bellac";
$areanames{en}->{3351998} = "Tulle";
$areanames{en}->{3351999} = "Limoges";
$areanames{en}->{3352410} = "Bergerac";
$areanames{en}->{3352411} = "Mussidan";
$areanames{en}->{3352412} = "Nontron";
$areanames{en}->{3352413} = "Perigueux";
$areanames{en}->{3352414} = "Riberac";
$areanames{en}->{3352415} = "Sarlat\-la\-Caneda";
$areanames{en}->{3352416} = "Terrasson\-Lavilledieu";
$areanames{en}->{3352417} = "Thiviers";
$areanames{en}->{3352418} = "Andernos\-les\-Bains";
$areanames{en}->{3352419} = "Arcachon";
$areanames{en}->{3352420} = "Bazas";
$areanames{en}->{3352421} = "Blaye";
$areanames{en}->{3352422} = "Langon";
$areanames{en}->{3352423} = "Lesparre\-Medoc";
$areanames{en}->{3352424} = "Libourne";
$areanames{en}->{3352425} = "La\ Reole";
$areanames{en}->{3352426} = "Dax";
$areanames{en}->{3352427} = "Labouheyre";
$areanames{en}->{3352428} = "Mont\-de\-Marsan";
$areanames{en}->{3352429} = "Agen";
$areanames{en}->{3352440} = "Arcachon";
$areanames{en}->{3352441} = "Bazas";
$areanames{en}->{3352442} = "Blaye";
$areanames{en}->{3352443} = "Agen";
$areanames{en}->{3352444} = "Bordeaux";
$areanames{en}->{3352445} = "Dax";
$areanames{en}->{3352446} = "La\ Reole";
$areanames{en}->{3352447} = "Labouheyre";
$areanames{en}->{3352448} = "Langon";
$areanames{en}->{3352449} = "Lesparre\-Medoc";
$areanames{en}->{3352450} = "Libourne";
$areanames{en}->{3352451} = "Marmande";
$areanames{en}->{3352452} = "Perigueux";
$areanames{en}->{3352453} = "Bayonne";
$areanames{en}->{3352454} = "Bordeaux";
$areanames{en}->{3352455} = "Libourne";
$areanames{en}->{3352456} = "Pau";
$areanames{en}->{3352457} = "Bordeaux";
$areanames{en}->{3352458} = "Bordeaux";
$areanames{en}->{3352459} = "Andernos\-les\-Bains";
$areanames{en}->{3352470} = "Bordeaux";
$areanames{en}->{3352471} = "Blaye";
$areanames{en}->{3352472} = "Bordeaux";
$areanames{en}->{3352473} = "Bordeaux";
$areanames{en}->{3352474} = "Dax";
$areanames{en}->{3352475} = "La\ Reole";
$areanames{en}->{3352476} = "Labouheyre";
$areanames{en}->{3352477} = "Langon";
$areanames{en}->{3352478} = "Lesparre\-Medoc";
$areanames{en}->{3352479} = "Libourne";
$areanames{en}->{3352480} = "Bayonne";
$areanames{en}->{3352481} = "Marmande";
$areanames{en}->{3352482} = "Mauleon\-Licharre";
$areanames{en}->{3352483} = "Mont\-de\-Marsan";
$areanames{en}->{3352484} = "Bordeaux";
$areanames{en}->{3352485} = "Mussidan";
$areanames{en}->{3352486} = "Nerac";
$areanames{en}->{3352487} = "Nontron";
$areanames{en}->{3352488} = "Oloron\-Sainte\-Marie";
$areanames{en}->{3352489} = "Pau";
$areanames{en}->{3353100} = "Auch";
$areanames{en}->{3353101} = "Castres";
$areanames{en}->{3353102} = "Cazeres";
$areanames{en}->{3353103} = "Foix";
$areanames{en}->{3353104} = "Lannemezan";
$areanames{en}->{3353105} = "Montauban";
$areanames{en}->{3353106} = "Pamiers";
$areanames{en}->{3353107} = "Saint\-Gaudens";
$areanames{en}->{3353108} = "Toulouse";
$areanames{en}->{3353109} = "Toulouse";
$areanames{en}->{3353110} = "Condom";
$areanames{en}->{3353111} = "Toulouse";
$areanames{en}->{3353112} = "Albi";
$areanames{en}->{3353113} = "Castres";
$areanames{en}->{3353114} = "Montauban";
$areanames{en}->{3353115} = "Toulouse";
$areanames{en}->{3353116} = "Auch";
$areanames{en}->{3353117} = "Tarbes";
$areanames{en}->{3353118} = "Albi";
$areanames{en}->{3353119} = "Montauban";
$areanames{en}->{3353120} = "Toulouse";
$areanames{en}->{3353121} = "Toulouse";
$areanames{en}->{3353122} = "Toulouse";
$areanames{en}->{3353123} = "Albi";
$areanames{en}->{3353124} = "Auch";
$areanames{en}->{3353125} = "Cahors";
$areanames{en}->{3353126} = "Castres";
$areanames{en}->{3353127} = "Cazeres";
$areanames{en}->{3353128} = "Condom";
$areanames{en}->{3353129} = "Decazeville";
$areanames{en}->{3353130} = "Montauban";
$areanames{en}->{3353131} = "Toulouse";
$areanames{en}->{3353132} = "Albi";
$areanames{en}->{3353133} = "Castres";
$areanames{en}->{3353134} = "Espalion";
$areanames{en}->{3353135} = "Figeac";
$areanames{en}->{3353136} = "Foix";
$areanames{en}->{3353137} = "Lannemezan";
$areanames{en}->{3353138} = "Moissac";
$areanames{en}->{3353139} = "Montauban";
$areanames{en}->{3353140} = "Nogaro";
$areanames{en}->{3353141} = "Pamiers";
$areanames{en}->{3353142} = "Rodez";
$areanames{en}->{3353143} = "Saint\-Affrique";
$areanames{en}->{3353144} = "Saint\-Gaudens";
$areanames{en}->{3353145} = "Souillac";
$areanames{en}->{3353146} = "Tarbes";
$areanames{en}->{3353147} = "Toulouse";
$areanames{en}->{3353148} = "Toulouse";
$areanames{en}->{3353149} = "Villefranche\-de\-Rouergue";
$areanames{en}->{3353160} = "Toulouse";
$areanames{en}->{3353161} = "Toulouse";
$areanames{en}->{3353162} = "Decazeville";
$areanames{en}->{3353163} = "Espalion";
$areanames{en}->{3353164} = "Rodez";
$areanames{en}->{3353165} = "Saint\-Affrique";
$areanames{en}->{3353166} = "Villefranche\-de\-Rouergue";
$areanames{en}->{3353167} = "Cazeres";
$areanames{en}->{3353168} = "Saint\-Gaudens";
$areanames{en}->{3353169} = "Auch";
$areanames{en}->{3353170} = "Foix";
$areanames{en}->{3353171} = "Rodez";
$areanames{en}->{3353172} = "Auch";
$areanames{en}->{3353173} = "Cahors";
$areanames{en}->{3353174} = "Tarbes";
$areanames{en}->{3353175} = "Condom";
$areanames{en}->{3353176} = "Albi";
$areanames{en}->{3353177} = "Castres";
$areanames{en}->{3353178} = "Montauban";
$areanames{en}->{3353179} = "Nogaro";
$areanames{en}->{3353180} = "Castres";
$areanames{en}->{3353181} = "Albi";
$areanames{en}->{3353182} = "Montauban";
$areanames{en}->{3353183} = "Auch";
$areanames{en}->{3353184} = "Toulouse";
$areanames{en}->{3353185} = "Moissac";
$areanames{en}->{3353186} = "Cahors";
$areanames{en}->{3353187} = "Moissac";
$areanames{en}->{3353188} = "Montauban";
$areanames{en}->{3353189} = "Cahors";
$areanames{en}->{3353200} = "Cahors";
$areanames{en}->{3353201} = "Cazeres";
$areanames{en}->{3353202} = "Toulouse";
$areanames{en}->{3353203} = "Auch";
$areanames{en}->{3353204} = "Condom";
$areanames{en}->{3353205} = "Albi";
$areanames{en}->{3353206} = "Souillac";
$areanames{en}->{3353207} = "Moissac";
$areanames{en}->{3353208} = "Montauban";
$areanames{en}->{3353209} = "Toulouse";
$areanames{en}->{3353210} = "Toulouse";
$areanames{en}->{3353211} = "Toulouse";
$areanames{en}->{3353212} = "Decazeville";
$areanames{en}->{3353213} = "Espalion";
$areanames{en}->{3353214} = "Rodez";
$areanames{en}->{3353215} = "Saint\-Affrique";
$areanames{en}->{3353216} = "Villefranche\-de\-Rouergue";
$areanames{en}->{3353217} = "Saint\-Gaudens";
$areanames{en}->{3353218} = "Toulouse";
$areanames{en}->{3353219} = "Tarbes";
$areanames{en}->{3353220} = "Lannemezan";
$areanames{en}->{3353221} = "Auch";
$areanames{en}->{3353222} = "Cahors";
$areanames{en}->{3353223} = "Foix";
$areanames{en}->{3353224} = "Rodez";
$areanames{en}->{3353225} = "Tarbes";
$areanames{en}->{3353226} = "Toulouse";
$areanames{en}->{3353227} = "Nogaro";
$areanames{en}->{3353228} = "Toulouse";
$areanames{en}->{3353229} = "Toulouse";
$areanames{en}->{3353230} = "Toulouse";
$areanames{en}->{3353231} = "Toulouse";
$areanames{en}->{3353232} = "Toulouse";
$areanames{en}->{3353233} = "Albi";
$areanames{en}->{3353234} = "Figeac";
$areanames{en}->{3353235} = "Souillac";
$areanames{en}->{3353236} = "Lannemezan";
$areanames{en}->{3353237} = "Castres";
$areanames{en}->{3353238} = "Moissac";
$areanames{en}->{3353239} = "Pamiers";
$areanames{en}->{3353240} = "Souillac";
$areanames{en}->{3353241} = "Rodez";
$areanames{en}->{3353242} = "Foix";
$areanames{en}->{3353243} = "Villefranche\-de\-Rouergue";
$areanames{en}->{3353244} = "Cazeres";
$areanames{en}->{3353245} = "Saint\-Gaudens";
$areanames{en}->{3353246} = "Auch";
$areanames{en}->{3353247} = "Condom";
$areanames{en}->{3353248} = "Nogaro";
$areanames{en}->{3353249} = "Cahors";
$areanames{en}->{3353250} = "Toulouse";
$areanames{en}->{3353251} = "Toulouse";
$areanames{en}->{3353252} = "Rodez";
$areanames{en}->{3353253} = "Toulouse";
$areanames{en}->{3353254} = "Rodez";
$areanames{en}->{3353255} = "Montauban";
$areanames{en}->{3353256} = "Castres";
$areanames{en}->{3353257} = "Foix";
$areanames{en}->{3353258} = "Toulouse";
$areanames{en}->{3353259} = "Toulouse";
$areanames{en}->{3353260} = "Toulouse";
$areanames{en}->{3353261} = "Foix";
$areanames{en}->{3353262} = "Albi";
$areanames{en}->{3353263} = "Toulouse";
$areanames{en}->{3353264} = "Montauban";
$areanames{en}->{3353280} = "Moissac";
$areanames{en}->{3353281} = "Toulouse";
$areanames{en}->{3353282} = "Foix";
$areanames{en}->{3353283} = "Pamiers";
$areanames{en}->{3353284} = "Decazeville";
$areanames{en}->{3353285} = "Espalion";
$areanames{en}->{3353286} = "Rodez";
$areanames{en}->{3353287} = "Saint\-Affrique";
$areanames{en}->{3353288} = "Montauban";
$areanames{en}->{3353289} = "Albi";
$areanames{en}->{3353290} = "Auch";
$areanames{en}->{3353291} = "Foix";
$areanames{en}->{3353292} = "Toulouse";
$areanames{en}->{3353293} = "Toulouse";
$areanames{en}->{3353294} = "Toulouse";
$areanames{en}->{3353295} = "Tarbes";
$areanames{en}->{3353296} = "Albi";
$areanames{en}->{3353297} = "Toulouse";
$areanames{en}->{3353298} = "Toulouse";
$areanames{en}->{3353299} = "Foix";
$areanames{en}->{3353310} = "Bordeaux";
$areanames{en}->{3353311} = "Pau";
$areanames{en}->{3353312} = "Perigueux";
$areanames{en}->{3353313} = "Mont\-de\-Marsan";
$areanames{en}->{3353314} = "Marmande";
$areanames{en}->{3353315} = "Pau";
$areanames{en}->{3353316} = "Mussidan";
$areanames{en}->{3353317} = "Nontron";
$areanames{en}->{3353318} = "Perigueux";
$areanames{en}->{3353319} = "Riberac";
$areanames{en}->{3353320} = "Bordeaux";
$areanames{en}->{3353321} = "Sarlat\-la\-Caneda";
$areanames{en}->{3353322} = "Terrasson\-Lavilledieu";
$areanames{en}->{3353323} = "Thiviers";
$areanames{en}->{3353324} = "Perigueux";
$areanames{en}->{3353325} = "Arcachon";
$areanames{en}->{3353326} = "Bazas";
$areanames{en}->{3353327} = "Blaye";
$areanames{en}->{3353328} = "Langon";
$areanames{en}->{3353329} = "Lesparre\-Medoc";
$areanames{en}->{3353330} = "Bayonne";
$areanames{en}->{3353331} = "La\ Reole";
$areanames{en}->{3353332} = "Dax";
$areanames{en}->{3353333} = "Dax";
$areanames{en}->{3353334} = "Labouheyre";
$areanames{en}->{3353335} = "Mont\-de\-Marsan";
$areanames{en}->{3353336} = "Agen";
$areanames{en}->{3353337} = "Marmande";
$areanames{en}->{3353338} = "Nerac";
$areanames{en}->{3353339} = "Villeneuve\-sur\-Lot";
$areanames{en}->{3353360} = "Salies\-de\-Bearn";
$areanames{en}->{3353361} = "Libourne";
$areanames{en}->{3353362} = "Oloron\-Sainte\-Marie";
$areanames{en}->{3353363} = "Bordeaux";
$areanames{en}->{3353364} = "Pau";
$areanames{en}->{3353365} = "Bordeaux";
$areanames{en}->{3353366} = "Pau";
$areanames{en}->{3353367} = "Mauleon\-Licharre";
$areanames{en}->{3353368} = "Agen";
$areanames{en}->{3353369} = "Riberac";
$areanames{en}->{3353370} = "Bordeaux";
$areanames{en}->{3353371} = "Bayonne";
$areanames{en}->{3353372} = "Bayonne";
$areanames{en}->{3353373} = "Pau";
$areanames{en}->{3353374} = "Pau";
$areanames{en}->{3353375} = "Salies\-de\-Bearn";
$areanames{en}->{3353376} = "Bergerac";
$areanames{en}->{3353377} = "Libourne";
$areanames{en}->{3353378} = "Bayonne";
$areanames{en}->{3353379} = "Bordeaux";
$areanames{en}->{3353380} = "Mussidan";
$areanames{en}->{3353381} = "Nontron";
$areanames{en}->{3353382} = "Perigueux";
$areanames{en}->{3353383} = "Riberac";
$areanames{en}->{3353384} = "Sarlat\-la\-Caneda";
$areanames{en}->{3353385} = "Terrasson\-Lavilledieu";
$areanames{en}->{3353386} = "Thiviers";
$areanames{en}->{3353387} = "Bazas";
$areanames{en}->{3353388} = "Blaye";
$areanames{en}->{3353389} = "Bordeaux";
$areanames{en}->{3353390} = "Langon";
$areanames{en}->{3353391} = "Lesparre\-Medoc";
$areanames{en}->{3353392} = "La\ Reole";
$areanames{en}->{3353393} = "Labouheyre";
$areanames{en}->{3353394} = "Mont\-de\-Marsan";
$areanames{en}->{3353395} = "Agen";
$areanames{en}->{3353396} = "Nerac";
$areanames{en}->{3353397} = "Villeneuve\-sur\-Lot";
$areanames{en}->{3353398} = "Mauleon\-Licharre";
$areanames{en}->{3353399} = "Oloron\-Sainte\-Marie";
$areanames{en}->{335345} = "Toulouse";
$areanames{en}->{335346} = "Toulouse";
$areanames{en}->{3353468} = "Sud\ Ouest";
$areanames{en}->{3353469} = "Sud\ Ouest";
$areanames{en}->{335347} = "Sud\ Ouest";
$areanames{en}->{335349} = "Sud\ Ouest";
$areanames{en}->{3353500} = "Bordeaux";
$areanames{en}->{3353501} = "La\ Reole";
$areanames{en}->{3353502} = "Bergerac";
$areanames{en}->{3353503} = "Mussidan";
$areanames{en}->{3353504} = "Nontron";
$areanames{en}->{3353505} = "Perigueux";
$areanames{en}->{3353506} = "Riberac";
$areanames{en}->{3353507} = "Andernos\-les\-Bains";
$areanames{en}->{3353508} = "Arcachon";
$areanames{en}->{3353509} = "Sarlat\-la\-Caneda";
$areanames{en}->{3353510} = "Terrasson\-Lavilledieu";
$areanames{en}->{3353511} = "Thiviers";
$areanames{en}->{3353512} = "Bazas";
$areanames{en}->{3353513} = "Blaye";
$areanames{en}->{3353514} = "Bordeaux";
$areanames{en}->{3353515} = "Langon";
$areanames{en}->{3353516} = "Lesparre\-Medoc";
$areanames{en}->{3353517} = "Libourne";
$areanames{en}->{3353518} = "La\ Reole";
$areanames{en}->{3353519} = "Dax";
$areanames{en}->{3353520} = "Labouheyre";
$areanames{en}->{3353521} = "Mont\-de\-Marsan";
$areanames{en}->{3353522} = "Agen";
$areanames{en}->{3353523} = "Marmande";
$areanames{en}->{3353524} = "Nerac";
$areanames{en}->{3353525} = "Villeneuve\-sur\-Lot";
$areanames{en}->{3353526} = "Bayonne";
$areanames{en}->{3353527} = "Mauleon\-Licharre";
$areanames{en}->{3353528} = "Oloron\-Sainte\-Marie";
$areanames{en}->{3353529} = "Pau";
$areanames{en}->{3353550} = "Mauleon\-Licharre";
$areanames{en}->{3353551} = "Oloron\-Sainte\-Marie";
$areanames{en}->{3353552} = "Salies\-de\-Bearn";
$areanames{en}->{3353553} = "Pau";
$areanames{en}->{3353554} = "Bordeaux";
$areanames{en}->{3353555} = "Agen";
$areanames{en}->{3353556} = "Bordeaux";
$areanames{en}->{3353557} = "Bergerac";
$areanames{en}->{3353558} = "Mussidan";
$areanames{en}->{3353559} = "Nontron";
$areanames{en}->{3353560} = "Perigueux";
$areanames{en}->{3353561} = "Riberac";
$areanames{en}->{3353562} = "Sarlat\-la\-Caneda";
$areanames{en}->{3353563} = "Terrasson\-Lavilledieu";
$areanames{en}->{3353564} = "Thiviers";
$areanames{en}->{3353565} = "Dax";
$areanames{en}->{3353566} = "Andernos\-les\-Bains";
$areanames{en}->{3353567} = "Arcachon";
$areanames{en}->{3353568} = "Bazas";
$areanames{en}->{3353569} = "Blaye";
$areanames{en}->{3353570} = "Bordeaux";
$areanames{en}->{3353571} = "Salies\-de\-Bearn";
$areanames{en}->{3353572} = "Langon";
$areanames{en}->{3353573} = "Lesparre\-Medoc";
$areanames{en}->{3353574} = "Libourne";
$areanames{en}->{3353575} = "Lesparre\-Medoc";
$areanames{en}->{3353576} = "Villeneuve\-sur\-Lot";
$areanames{en}->{3353577} = "Nerac";
$areanames{en}->{3353578} = "Marmande";
$areanames{en}->{3353579} = "La\ Reole";
$areanames{en}->{3353580} = "Mont\-de\-Marsan";
$areanames{en}->{3353581} = "Labouheyre";
$areanames{en}->{3353582} = "Dax";
$areanames{en}->{3353583} = "Dax";
$areanames{en}->{3353584} = "Labouheyre";
$areanames{en}->{3353585} = "Lesparre\-Medoc";
$areanames{en}->{3353586} = "Langon";
$areanames{en}->{3353587} = "Mont\-de\-Marsan";
$areanames{en}->{3353588} = "Blaye";
$areanames{en}->{3353589} = "Bazas";
$areanames{en}->{3353590} = "Arcachon";
$areanames{en}->{3353591} = "Andernos\-les\-Bains";
$areanames{en}->{3353592} = "Thiviers";
$areanames{en}->{3353593} = "Terrasson\-Lavilledieu";
$areanames{en}->{3353594} = "Sarlat\-la\-Caneda";
$areanames{en}->{3353595} = "Pau";
$areanames{en}->{3353596} = "Agen";
$areanames{en}->{3353597} = "Nontron";
$areanames{en}->{3353598} = "Mussidan";
$areanames{en}->{3353599} = "Bergerac";
$areanames{en}->{3353600} = "Montauban";
$areanames{en}->{3353601} = "Albi";
$areanames{en}->{3353602} = "Tarbes";
$areanames{en}->{3353603} = "Auch";
$areanames{en}->{3353604} = "Cahors";
$areanames{en}->{3353605} = "Foix";
$areanames{en}->{3353606} = "Moissac";
$areanames{en}->{3353607} = "Saint\-Gaudens";
$areanames{en}->{3353608} = "Figeac";
$areanames{en}->{3353609} = "Toulouse";
$areanames{en}->{3353611} = "Toulouse";
$areanames{en}->{3353612} = "Pamiers";
$areanames{en}->{3353613} = "Decazeville";
$areanames{en}->{3353614} = "Espalion";
$areanames{en}->{3353615} = "Saint\-Affrique";
$areanames{en}->{3353616} = "Villefranche\-de\-Rouergue";
$areanames{en}->{3353617} = "Cazeres";
$areanames{en}->{3353618} = "Condom";
$areanames{en}->{3353619} = "Nogaro";
$areanames{en}->{3353620} = "Souillac";
$areanames{en}->{3353621} = "Lannemezan";
$areanames{en}->{3353622} = "Cazeres";
$areanames{en}->{3353623} = "Saint\-Gaudens";
$areanames{en}->{3353624} = "Toulouse";
$areanames{en}->{3353625} = "Toulouse";
$areanames{en}->{3353627} = "Toulouse";
$areanames{en}->{3353628} = "Toulouse";
$areanames{en}->{3353629} = "Castres";
$areanames{en}->{3353630} = "Tarbes";
$areanames{en}->{3353631} = "Toulouse";
$areanames{en}->{3353632} = "Tarbes";
$areanames{en}->{3353633} = "Foix";
$areanames{en}->{3353634} = "Saint\-Gaudens";
$areanames{en}->{3353635} = "Albi";
$areanames{en}->{3353636} = "Toulouse";
$areanames{en}->{3353637} = "Toulouse";
$areanames{en}->{3353638} = "Condom";
$areanames{en}->{3353640} = "Toulouse";
$areanames{en}->{3353641} = "Montauban";
$areanames{en}->{3353642} = "Toulouse";
$areanames{en}->{3353643} = "Toulouse";
$areanames{en}->{3353644} = "Toulouse";
$areanames{en}->{3353645} = "Cazeres";
$areanames{en}->{3353646} = "Albi";
$areanames{en}->{3353647} = "Toulouse";
$areanames{en}->{3353648} = "Montauban";
$areanames{en}->{3353653} = "Toulouse";
$areanames{en}->{3354010} = "Blaye";
$areanames{en}->{3354011} = "Langon";
$areanames{en}->{3354012} = "Bordeaux";
$areanames{en}->{3354013} = "Bordeaux";
$areanames{en}->{3354014} = "Libourne";
$areanames{en}->{3354015} = "La\ Reole";
$areanames{en}->{3354016} = "Bordeaux";
$areanames{en}->{3354017} = "Pau";
$areanames{en}->{3354018} = "Bordeaux";
$areanames{en}->{3354019} = "Lesparre\-Medoc";
$areanames{en}->{3354020} = "Libourne";
$areanames{en}->{3354021} = "Bordeaux";
$areanames{en}->{3354022} = "Andernos\-les\-Bains";
$areanames{en}->{3354023} = "Arcachon";
$areanames{en}->{3354024} = "Bordeaux";
$areanames{en}->{3354025} = "Bordeaux";
$areanames{en}->{3354026} = "Andernos\-les\-Bains";
$areanames{en}->{3354027} = "Arcachon";
$areanames{en}->{3354028} = "Bazas";
$areanames{en}->{3354029} = "Blaye";
$areanames{en}->{3354040} = "Agen";
$areanames{en}->{3354041} = "Langon";
$areanames{en}->{3354042} = "Dax";
$areanames{en}->{3354043} = "Andernos\-les\-Bains";
$areanames{en}->{3354044} = "Labouheyre";
$areanames{en}->{3354045} = "Bordeaux";
$areanames{en}->{3354046} = "Perigueux";
$areanames{en}->{3354047} = "Mont\-de\-Marsan";
$areanames{en}->{3354048} = "Bayonne";
$areanames{en}->{3354049} = "Agen";
$areanames{en}->{3354050} = "Bazas";
$areanames{en}->{3354051} = "Arcachon";
$areanames{en}->{3354052} = "Marmande";
$areanames{en}->{3354053} = "Blaye";
$areanames{en}->{3354054} = "Bordeaux";
$areanames{en}->{3354055} = "Nerac";
$areanames{en}->{3354056} = "Langon";
$areanames{en}->{3354057} = "Villeneuve\-sur\-Lot";
$areanames{en}->{3354058} = "Libourne";
$areanames{en}->{3354059} = "Bayonne";
$areanames{en}->{3354060} = "Labouheyre";
$areanames{en}->{3354061} = "Dax";
$areanames{en}->{3354062} = "Mauleon\-Licharre";
$areanames{en}->{3354063} = "Mont\-de\-Marsan";
$areanames{en}->{3354064} = "Oloron\-Sainte\-Marie";
$areanames{en}->{3354065} = "Marmande";
$areanames{en}->{3354066} = "Pau";
$areanames{en}->{3354067} = "Salies\-de\-Bearn";
$areanames{en}->{3354068} = "Blaye";
$areanames{en}->{3354069} = "Bayonne";
$areanames{en}->{3354080} = "Andernos\-les\-Bains";
$areanames{en}->{3354081} = "Bordeaux";
$areanames{en}->{3354082} = "Bordeaux";
$areanames{en}->{3354083} = "Bordeaux";
$areanames{en}->{3354084} = "Bordeaux";
$areanames{en}->{3354085} = "Pau";
$areanames{en}->{3354086} = "Mont\-de\-Marsan";
$areanames{en}->{3354087} = "Agen";
$areanames{en}->{3354088} = "Marmande";
$areanames{en}->{3354089} = "Marmande";
$areanames{en}->{3354090} = "Lesparre\-Medoc";
$areanames{en}->{3354091} = "Bordeaux";
$areanames{en}->{3354092} = "Bergerac";
$areanames{en}->{3354093} = "Mussidan";
$areanames{en}->{3354094} = "Nontron";
$areanames{en}->{3354095} = "Perigueux";
$areanames{en}->{3354096} = "Riberac";
$areanames{en}->{3354097} = "Sarlat\-la\-Caneda";
$areanames{en}->{3354098} = "Terrasson\-Lavilledieu";
$areanames{en}->{3354099} = "Thiviers";
$areanames{en}->{33542} = "Sud\ Ouest";
$areanames{en}->{3354254} = "Auch";
$areanames{en}->{33544} = "Sud\ Ouest";
$areanames{en}->{3354400} = "Limoges";
$areanames{en}->{3354419} = "Limoges";
$areanames{en}->{335442} = "Limoges";
$areanames{en}->{3354425} = "Bellac";
$areanames{en}->{3354430} = "Gueret";
$areanames{en}->{3354431} = "Tulle";
$areanames{en}->{3354440} = "Tulle";
$areanames{en}->{3354441} = "Tulle";
$areanames{en}->{3354460} = "Tulle";
$areanames{en}->{335450} = "Sud\ Ouest";
$areanames{en}->{335451} = "Sud\ Ouest";
$areanames{en}->{335454} = "Sud\ Ouest";
$areanames{en}->{335455} = "Sud\ Ouest";
$areanames{en}->{335461} = "Sud\ Ouest";
$areanames{en}->{3354700} = "Nerac";
$areanames{en}->{3354701} = "Villeneuve\-sur\-Lot";
$areanames{en}->{3354702} = "Bayonne";
$areanames{en}->{3354703} = "Mauleon\-Licharre";
$areanames{en}->{3354704} = "Oloron\-Sainte\-Marie";
$areanames{en}->{3354705} = "Pau";
$areanames{en}->{3354706} = "Salies\-de\-Bearn";
$areanames{en}->{3354707} = "Bazas";
$areanames{en}->{3354708} = "Riberac";
$areanames{en}->{3354709} = "Langon";
$areanames{en}->{3354710} = "Lesparre\-Medoc";
$areanames{en}->{3354711} = "Libourne";
$areanames{en}->{3354712} = "Bergerac";
$areanames{en}->{3354713} = "Nontron";
$areanames{en}->{3354714} = "Perigueux";
$areanames{en}->{3354715} = "Bayonne";
$areanames{en}->{3354716} = "Bordeaux";
$areanames{en}->{3354717} = "Bordeaux";
$areanames{en}->{3354718} = "Pau";
$areanames{en}->{3354719} = "Mussidan";
$areanames{en}->{3354750} = "Bordeaux";
$areanames{en}->{3354751} = "Bayonne";
$areanames{en}->{3354752} = "Bergerac";
$areanames{en}->{3354753} = "Dax";
$areanames{en}->{3354754} = "Bordeaux";
$areanames{en}->{3354755} = "Dax";
$areanames{en}->{3354756} = "Bergerac";
$areanames{en}->{3354757} = "Marmande";
$areanames{en}->{3354758} = "Mauleon\-Licharre";
$areanames{en}->{3354759} = "Mont\-de\-Marsan";
$areanames{en}->{3354780} = "Dax";
$areanames{en}->{3354781} = "Labouheyre";
$areanames{en}->{3354782} = "Langon";
$areanames{en}->{3354783} = "Lesparre\-Medoc";
$areanames{en}->{3354784} = "Libourne";
$areanames{en}->{3354785} = "Marmande";
$areanames{en}->{3354786} = "Mauleon\-Licharre";
$areanames{en}->{3354787} = "Mont\-de\-Marsan";
$areanames{en}->{3354788} = "Mussidan";
$areanames{en}->{3354789} = "Nerac";
$areanames{en}->{335495} = "Poitiers";
$areanames{en}->{3355400} = "Dax";
$areanames{en}->{3355401} = "Marmande";
$areanames{en}->{3355402} = "Bordeaux";
$areanames{en}->{3355403} = "Bayonne";
$areanames{en}->{3355404} = "Langon";
$areanames{en}->{3355405} = "La\ Reole";
$areanames{en}->{3355406} = "Bordeaux";
$areanames{en}->{3355407} = "Bordeaux";
$areanames{en}->{3355408} = "Labouheyre";
$areanames{en}->{3355409} = "Pau";
$areanames{en}->{3355410} = "Bordeaux";
$areanames{en}->{3355411} = "Bordeaux";
$areanames{en}->{3355412} = "Pau";
$areanames{en}->{3355413} = "Bordeaux";
$areanames{en}->{3355414} = "Bordeaux";
$areanames{en}->{3355415} = "Libourne";
$areanames{en}->{3355416} = "Bordeaux";
$areanames{en}->{3355417} = "Pau";
$areanames{en}->{3355418} = "Arcachon";
$areanames{en}->{3355419} = "Libourne";
$areanames{en}->{3355420} = "Bordeaux";
$areanames{en}->{3355421} = "Bordeaux";
$areanames{en}->{3355422} = "Bergerac";
$areanames{en}->{3355423} = "Mussidan";
$areanames{en}->{3355424} = "Nontron";
$areanames{en}->{3355425} = "Perigueux";
$areanames{en}->{3355426} = "Riberac";
$areanames{en}->{3355427} = "Sarlat\-la\-Caneda";
$areanames{en}->{3355428} = "Terrasson\-Lavilledieu";
$areanames{en}->{3355429} = "Thiviers";
$areanames{en}->{3355430} = "Andernos\-les\-Bains";
$areanames{en}->{3355431} = "Arcachon";
$areanames{en}->{3355432} = "Bazas";
$areanames{en}->{3355433} = "Blaye";
$areanames{en}->{3355434} = "Langon";
$areanames{en}->{3355435} = "Lesparre\-Medoc";
$areanames{en}->{3355436} = "Libourne";
$areanames{en}->{3355437} = "La\ Reole";
$areanames{en}->{3355438} = "Dax";
$areanames{en}->{3355439} = "Labouheyre";
$areanames{en}->{3355440} = "Mont\-de\-Marsan";
$areanames{en}->{3355441} = "Agen";
$areanames{en}->{3355442} = "Marmande";
$areanames{en}->{3355443} = "Nerac";
$areanames{en}->{3355444} = "Villeneuve\-sur\-Lot";
$areanames{en}->{3355445} = "Mauleon\-Licharre";
$areanames{en}->{3355446} = "Oloron\-Sainte\-Marie";
$areanames{en}->{3355447} = "Salies\-de\-Bearn";
$areanames{en}->{3355448} = "Bordeaux";
$areanames{en}->{3355449} = "Bordeaux";
$areanames{en}->{335545} = "Bordeaux";
$areanames{en}->{3355450} = "Perigueux";
$areanames{en}->{3355456} = "Lesparre\-Medoc";
$areanames{en}->{3355459} = "Langon";
$areanames{en}->{3355460} = "Oloron\-Sainte\-Marie";
$areanames{en}->{3355461} = "Bayonne";
$areanames{en}->{3355462} = "Bergerac";
$areanames{en}->{3355463} = "Andernos\-les\-Bains";
$areanames{en}->{3355464} = "Bayonne";
$areanames{en}->{3355465} = "Bordeaux";
$areanames{en}->{3355466} = "Bayonne";
$areanames{en}->{3355467} = "Bordeaux";
$areanames{en}->{3355468} = "Bordeaux";
$areanames{en}->{3355469} = "Bordeaux";
$areanames{en}->{3355470} = "Agen";
$areanames{en}->{3355471} = "Bordeaux";
$areanames{en}->{3355472} = "Bordeaux";
$areanames{en}->{3355473} = "Mont\-de\-Marsan";
$areanames{en}->{3355474} = "Labouheyre";
$areanames{en}->{3355475} = "Labouheyre";
$areanames{en}->{3355476} = "Andernos\-les\-Bains";
$areanames{en}->{3355477} = "Libourne";
$areanames{en}->{3355478} = "Bordeaux";
$areanames{en}->{3355479} = "Bordeaux";
$areanames{en}->{3355480} = "Sarlat\-la\-Caneda";
$areanames{en}->{3355481} = "Bayonne";
$areanames{en}->{3355482} = "Sarlat\-la\-Caneda";
$areanames{en}->{3355483} = "Bordeaux";
$areanames{en}->{3355484} = "Dax";
$areanames{en}->{3355760} = "Bordeaux";
$areanames{en}->{3355761} = "Bordeaux";
$areanames{en}->{3355762} = "Bordeaux";
$areanames{en}->{3355763} = "Arcachon";
$areanames{en}->{3355764} = "Blaye";
$areanames{en}->{3355765} = "Bordeaux";
$areanames{en}->{3355766} = "Sud\ Ouest";
$areanames{en}->{3355767} = "Bordeaux";
$areanames{en}->{3355768} = "Blaye";
$areanames{en}->{3355769} = "Libourne";
$areanames{en}->{335581} = "Sud\ Ouest";
$areanames{en}->{335582} = "Sud\ Ouest";
$areanames{en}->{335586} = "Sud\ Ouest";
$areanames{en}->{335614} = "Toulouse";
$areanames{en}->{335631} = "Sud\ Ouest";
$areanames{en}->{3356400} = "Nerac";
$areanames{en}->{3356401} = "Villeneuve\-sur\-Lot";
$areanames{en}->{3356402} = "Bayonne";
$areanames{en}->{3356403} = "Mauleon\-Licharre";
$areanames{en}->{3356404} = "Oloron\-Sainte\-Marie";
$areanames{en}->{3356405} = "Pau";
$areanames{en}->{3356406} = "Salies\-de\-Bearn";
$areanames{en}->{3356407} = "Bayonne";
$areanames{en}->{3356408} = "Bordeaux";
$areanames{en}->{3356409} = "Bordeaux";
$areanames{en}->{3356410} = "Bordeaux";
$areanames{en}->{3356411} = "Bayonne";
$areanames{en}->{3356412} = "Bordeaux";
$areanames{en}->{3356413} = "Bordeaux";
$areanames{en}->{3356414} = "Bayonne";
$areanames{en}->{3356415} = "Mauleon\-Licharre";
$areanames{en}->{3356416} = "Oloron\-Sainte\-Marie";
$areanames{en}->{3356417} = "Pau";
$areanames{en}->{3356418} = "Salies\-de\-Bearn";
$areanames{en}->{3356419} = "Pau";
$areanames{en}->{3356420} = "Perigueux";
$areanames{en}->{3356421} = "Bordeaux";
$areanames{en}->{3356422} = "Mont\-de\-Marsan";
$areanames{en}->{3356423} = "Agen";
$areanames{en}->{3356424} = "Perigueux";
$areanames{en}->{3356425} = "Agen";
$areanames{en}->{3356426} = "Bordeaux";
$areanames{en}->{3356427} = "Pau";
$areanames{en}->{3356428} = "Bordeaux";
$areanames{en}->{3356429} = "Pau";
$areanames{en}->{3356430} = "Bayonne";
$areanames{en}->{3356431} = "Bordeaux";
$areanames{en}->{3356432} = "Thiviers";
$areanames{en}->{3356433} = "Bordeaux";
$areanames{en}->{3356434} = "Bergerac";
$areanames{en}->{3356435} = "Villeneuve\-sur\-Lot";
$areanames{en}->{3356436} = "Blaye";
$areanames{en}->{3356437} = "Bordeaux";
$areanames{en}->{3356438} = "Bordeaux";
$areanames{en}->{3356439} = "Pau";
$areanames{en}->{3356440} = "Labouheyre";
$areanames{en}->{3356441} = "Dax";
$areanames{en}->{3356442} = "Thiviers";
$areanames{en}->{3356443} = "Villeneuve\-sur\-Lot";
$areanames{en}->{3356444} = "Langon";
$areanames{en}->{3356445} = "Mussidan";
$areanames{en}->{3356446} = "Nontron";
$areanames{en}->{3356447} = "Riberac";
$areanames{en}->{3356448} = "Sarlat\-la\-Caneda";
$areanames{en}->{3356449} = "Terrasson\-Lavilledieu";
$areanames{en}->{3356450} = "Thiviers";
$areanames{en}->{3356451} = "Andernos\-les\-Bains";
$areanames{en}->{3356452} = "Arcachon";
$areanames{en}->{3356453} = "Bazas";
$areanames{en}->{3356454} = "Langon";
$areanames{en}->{3356455} = "Lesparre\-Medoc";
$areanames{en}->{3356456} = "La\ Reole";
$areanames{en}->{3356457} = "Labouheyre";
$areanames{en}->{3356458} = "Nerac";
$areanames{en}->{3356459} = "Mauleon\-Licharre";
$areanames{en}->{3356460} = "Bordeaux";
$areanames{en}->{3356461} = "Oloron\-Sainte\-Marie";
$areanames{en}->{3356462} = "Salies\-de\-Bearn";
$areanames{en}->{3356463} = "Marmande";
$areanames{en}->{3356464} = "Pau";
$areanames{en}->{3356465} = "Andernos\-les\-Bains";
$areanames{en}->{3356466} = "Arcachon";
$areanames{en}->{3356467} = "Bazas";
$areanames{en}->{3356468} = "Blaye";
$areanames{en}->{3356469} = "Bordeaux";
$areanames{en}->{3356470} = "Langon";
$areanames{en}->{3356471} = "Lesparre\-Medoc";
$areanames{en}->{3356472} = "Libourne";
$areanames{en}->{3356473} = "La\ Reole";
$areanames{en}->{3356474} = "Perigueux";
$areanames{en}->{3356475} = "Blaye";
$areanames{en}->{3356476} = "Labouheyre";
$areanames{en}->{3356477} = "Mauleon\-Licharre";
$areanames{en}->{3356478} = "Mussidan";
$areanames{en}->{3356479} = "Nerac";
$areanames{en}->{3356480} = "Nontron";
$areanames{en}->{3356481} = "Oloron\-Sainte\-Marie";
$areanames{en}->{3356482} = "Pau";
$areanames{en}->{3356483} = "Perigueux";
$areanames{en}->{3356484} = "Riberac";
$areanames{en}->{3356485} = "Salies\-de\-Bearn";
$areanames{en}->{3356486} = "Sarlat\-la\-Caneda";
$areanames{en}->{3356487} = "Terrasson\-Lavilledieu";
$areanames{en}->{3356488} = "Pau";
$areanames{en}->{3356489} = "Agen";
$areanames{en}->{3356490} = "Andernos\-les\-Bains";
$areanames{en}->{3356491} = "Arcachon";
$areanames{en}->{3356492} = "Bayonne";
$areanames{en}->{3356493} = "Bazas";
$areanames{en}->{3356494} = "Blaye";
$areanames{en}->{3356495} = "Dax";
$areanames{en}->{3356496} = "La\ Reole";
$areanames{en}->{3356497} = "Labouheyre";
$areanames{en}->{3356498} = "Lesparre\-Medoc";
$areanames{en}->{3356499} = "Marmande";
$areanames{en}->{335650} = "Sud\ Ouest";
$areanames{en}->{3356740} = "Lannemezan";
$areanames{en}->{3356741} = "Tarbes";
$areanames{en}->{3356742} = "Albi";
$areanames{en}->{3356743} = "Castres";
$areanames{en}->{3356744} = "Pamiers";
$areanames{en}->{3356745} = "Tarbes";
$areanames{en}->{3356746} = "Castres";
$areanames{en}->{3356747} = "Lannemezan";
$areanames{en}->{3356748} = "Saint\-Gaudens";
$areanames{en}->{3356749} = "Villefranche\-de\-Rouergue";
$areanames{en}->{3356750} = "Cazeres";
$areanames{en}->{3356751} = "Saint\-Gaudens";
$areanames{en}->{3356752} = "Toulouse";
$areanames{en}->{3356753} = "Castres";
$areanames{en}->{3356754} = "Auch";
$areanames{en}->{3356755} = "Cazeres";
$areanames{en}->{3356756} = "Condom";
$areanames{en}->{3356757} = "Castres";
$areanames{en}->{3356758} = "Nogaro";
$areanames{en}->{3356759} = "Cahors";
$areanames{en}->{3356770} = "Toulouse";
$areanames{en}->{3356771} = "Tarbes";
$areanames{en}->{3356772} = "Albi";
$areanames{en}->{3356773} = "Toulouse";
$areanames{en}->{3356774} = "Toulouse";
$areanames{en}->{3356775} = "Montauban";
$areanames{en}->{3356776} = "Toulouse";
$areanames{en}->{3356777} = "Toulouse";
$areanames{en}->{3356778} = "Rodez";
$areanames{en}->{3356779} = "Rodez";
$areanames{en}->{3356780} = "Toulouse";
$areanames{en}->{3356781} = "Toulouse";
$areanames{en}->{3356782} = "Auch";
$areanames{en}->{3356783} = "Auch";
$areanames{en}->{3356784} = "Cahors";
$areanames{en}->{3356785} = "Cahors";
$areanames{en}->{3356786} = "Tarbes";
$areanames{en}->{3356787} = "Albi";
$areanames{en}->{3356788} = "Tarbes";
$areanames{en}->{3356789} = "Albi";
$areanames{en}->{3356790} = "Albi";
$areanames{en}->{3356791} = "Albi";
$areanames{en}->{3356792} = "Toulouse";
$areanames{en}->{3356793} = "Pamiers";
$areanames{en}->{3356794} = "Decazeville";
$areanames{en}->{3356795} = "Toulouse";
$areanames{en}->{3356796} = "Moissac";
$areanames{en}->{3356797} = "Moissac";
$areanames{en}->{3356798} = "Montauban";
$areanames{en}->{3356799} = "Montauban";
$areanames{en}->{3357900} = "Melle";
$areanames{en}->{3357901} = "Niort";
$areanames{en}->{3357902} = "Parthenay";
$areanames{en}->{3357903} = "Thouars";
$areanames{en}->{3357904} = "Chatellerault";
$areanames{en}->{3357905} = "Civray";
$areanames{en}->{3357906} = "Loudun";
$areanames{en}->{3357907} = "Montmorillon";
$areanames{en}->{3357908} = "Niort";
$areanames{en}->{3357909} = "Angoulême";
$areanames{en}->{3357910} = "Chatellerault";
$areanames{en}->{3357911} = "Confolens";
$areanames{en}->{3357912} = "Poitiers";
$areanames{en}->{3357913} = "La\ Rochelle";
$areanames{en}->{3357914} = "Saintes";
$areanames{en}->{3357915} = "Montmorillon";
$areanames{en}->{3357916} = "Poitiers";
$areanames{en}->{3357917} = "Jonzac";
$areanames{en}->{3357918} = "Niort";
$areanames{en}->{3357919} = "Chatellerault";
$areanames{en}->{3357920} = "Cognac";
$areanames{en}->{3357921} = "Jonzac";
$areanames{en}->{3357922} = "Rochefort";
$areanames{en}->{3357923} = "Saint\-Jean\-dAngely";
$areanames{en}->{3357924} = "Bressuire";
$areanames{en}->{3357925} = "Melle";
$areanames{en}->{3357926} = "Parthenay";
$areanames{en}->{3357927} = "Thouars";
$areanames{en}->{3357928} = "Chatellerault";
$areanames{en}->{3357929} = "Civray";
$areanames{en}->{3357930} = "Loudun";
$areanames{en}->{3357931} = "Montmorillon";
$areanames{en}->{3357932} = "Chatellerault";
$areanames{en}->{3357933} = "Bressuire";
$areanames{en}->{3357934} = "Saint\-Jean\-dAngely";
$areanames{en}->{3357935} = "Angoulême";
$areanames{en}->{3357936} = "Thouars";
$areanames{en}->{3357937} = "Saintes";
$areanames{en}->{3357938} = "Cognac";
$areanames{en}->{3357939} = "Confolens";
$areanames{en}->{3357940} = "Parthenay";
$areanames{en}->{3357941} = "Civray";
$areanames{en}->{3357942} = "Barbezieux\-Saint\-Hilaire";
$areanames{en}->{3357943} = "Loudun";
$areanames{en}->{3357944} = "La\ Rochelle";
$areanames{en}->{3357945} = "Rochefort";
$areanames{en}->{3357946} = "Melle";
$areanames{en}->{3357947} = "Angoulême";
$areanames{en}->{3357948} = "Barbezieux\-Saint\-Hilaire";
$areanames{en}->{3357949} = "Cognac";
$areanames{en}->{3357950} = "Confolens";
$areanames{en}->{3357951} = "Jonzac";
$areanames{en}->{3357952} = "Rochefort";
$areanames{en}->{3357953} = "La\ Rochelle";
$areanames{en}->{3357954} = "Saint\-Jean\-dAngely";
$areanames{en}->{3357955} = "Saintes";
$areanames{en}->{3357956} = "Bressuire";
$areanames{en}->{3357957} = "Melle";
$areanames{en}->{3357958} = "Niort";
$areanames{en}->{3357959} = "Parthenay";
$areanames{en}->{3357960} = "Thouars";
$areanames{en}->{3357961} = "Chatellerault";
$areanames{en}->{3357962} = "Civray";
$areanames{en}->{3357963} = "Loudun";
$areanames{en}->{3357964} = "Montmorillon";
$areanames{en}->{3357965} = "Poitiers";
$areanames{en}->{3357966} = "La\ Rochelle";
$areanames{en}->{3357967} = "Rochefort";
$areanames{en}->{3357968} = "Niort";
$areanames{en}->{3357969} = "Angoulême";
$areanames{en}->{3357970} = "Niort";
$areanames{en}->{3357971} = "Barbezieux\-Saint\-Hilaire";
$areanames{en}->{3357972} = "Cognac";
$areanames{en}->{3357973} = "Confolens";
$areanames{en}->{3357974} = "Jonzac";
$areanames{en}->{3357975} = "Saint\-Jean\-dAngely";
$areanames{en}->{3357976} = "Bressuire";
$areanames{en}->{3357977} = "Melle";
$areanames{en}->{3357978} = "Parthenay";
$areanames{en}->{3357979} = "Poitiers";
$areanames{en}->{3357980} = "Saintes";
$areanames{en}->{3357981} = "Thouars";
$areanames{en}->{3357982} = "Civray";
$areanames{en}->{3357983} = "Loudun";
$areanames{en}->{3357984} = "Montmorillon";
$areanames{en}->{3357985} = "Jonzac";
$areanames{en}->{3357986} = "Rochefort";
$areanames{en}->{3357987} = "La\ Rochelle";
$areanames{en}->{3357988} = "Saintes";
$areanames{en}->{3357989} = "Angoulême";
$areanames{en}->{3357990} = "Saint\-Jean\-dAngely";
$areanames{en}->{3357991} = "Parthenay";
$areanames{en}->{3357992} = "Civray";
$areanames{en}->{3357993} = "Loudun";
$areanames{en}->{3357994} = "Montmorillon";
$areanames{en}->{3357995} = "La\ Rochelle";
$areanames{en}->{3357996} = "Poitiers";
$areanames{en}->{3357997} = "Rochefort";
$areanames{en}->{3357998} = "Poitiers";
$areanames{en}->{3357999} = "Niort";
$areanames{en}->{3358100} = "Lannemezan";
$areanames{en}->{3358101} = "Tarbes";
$areanames{en}->{3358102} = "Albi";
$areanames{en}->{3358103} = "Moissac";
$areanames{en}->{3358104} = "Montauban";
$areanames{en}->{3358105} = "Foix";
$areanames{en}->{3358106} = "Pamiers";
$areanames{en}->{3358107} = "Decazeville";
$areanames{en}->{3358108} = "Toulouse";
$areanames{en}->{3358109} = "Foix";
$areanames{en}->{3358110} = "Toulouse";
$areanames{en}->{3358111} = "Moissac";
$areanames{en}->{3358112} = "Rodez";
$areanames{en}->{3358113} = "Toulouse";
$areanames{en}->{3358114} = "Toulouse";
$areanames{en}->{3358115} = "Foix";
$areanames{en}->{3358116} = "Decazeville";
$areanames{en}->{3358117} = "Espalion";
$areanames{en}->{3358118} = "Toulouse";
$areanames{en}->{3358119} = "Rodez";
$areanames{en}->{3358120} = "Saint\-Affrique";
$areanames{en}->{3358121} = "Villefranche\-de\-Rouergue";
$areanames{en}->{3358122} = "Cahors";
$areanames{en}->{3358123} = "Nogaro";
$areanames{en}->{3358124} = "Figeac";
$areanames{en}->{3358125} = "Souillac";
$areanames{en}->{3358126} = "Toulouse";
$areanames{en}->{3358127} = "Albi";
$areanames{en}->{3358128} = "Montauban";
$areanames{en}->{3358129} = "Foix";
$areanames{en}->{3358140} = "Albi";
$areanames{en}->{3358141} = "Auch";
$areanames{en}->{3358142} = "Cahors";
$areanames{en}->{3358143} = "Castres";
$areanames{en}->{3358144} = "Cazeres";
$areanames{en}->{3358145} = "Condom";
$areanames{en}->{3358146} = "Decazeville";
$areanames{en}->{3358147} = "Espalion";
$areanames{en}->{3358148} = "Figeac";
$areanames{en}->{3358149} = "Foix";
$areanames{en}->{3358150} = "Lannemezan";
$areanames{en}->{3358151} = "Moissac";
$areanames{en}->{3358152} = "Montauban";
$areanames{en}->{3358153} = "Nogaro";
$areanames{en}->{3358154} = "Pamiers";
$areanames{en}->{3358155} = "Rodez";
$areanames{en}->{3358156} = "Saint\-Affrique";
$areanames{en}->{3358157} = "Saint\-Gaudens";
$areanames{en}->{3358158} = "Souillac";
$areanames{en}->{3358159} = "Tarbes";
$areanames{en}->{3358170} = "Cahors";
$areanames{en}->{3358171} = "Figeac";
$areanames{en}->{3358172} = "Tarbes";
$areanames{en}->{3358173} = "Souillac";
$areanames{en}->{3358174} = "Lannemezan";
$areanames{en}->{3358175} = "Tarbes";
$areanames{en}->{3358176} = "Toulouse";
$areanames{en}->{3358177} = "Toulouse";
$areanames{en}->{3358178} = "Moissac";
$areanames{en}->{3358179} = "Castres";
$areanames{en}->{3358180} = "Toulouse";
$areanames{en}->{3358181} = "Toulouse";
$areanames{en}->{3358182} = "Montauban";
$areanames{en}->{3358183} = "Toulouse";
$areanames{en}->{3358184} = "Cazeres";
$areanames{en}->{3358185} = "Condom";
$areanames{en}->{3358186} = "Decazeville";
$areanames{en}->{3358187} = "Espalion";
$areanames{en}->{3358188} = "Figeac";
$areanames{en}->{3358189} = "Lannemezan";
$areanames{en}->{3358200} = "Saint\-Gaudens";
$areanames{en}->{3358201} = "Toulouse";
$areanames{en}->{3358202} = "Castres";
$areanames{en}->{3358203} = "Montauban";
$areanames{en}->{3358204} = "Tarbes";
$areanames{en}->{3358205} = "Toulouse";
$areanames{en}->{3358206} = "Toulouse";
$areanames{en}->{3358207} = "Saint\-Gaudens";
$areanames{en}->{3358208} = "Toulouse";
$areanames{en}->{3358209} = "Condom";
$areanames{en}->{3358210} = "Albi";
$areanames{en}->{3358211} = "Cahors";
$areanames{en}->{3358212} = "Figeac";
$areanames{en}->{3358213} = "Souillac";
$areanames{en}->{3358214} = "Lannemezan";
$areanames{en}->{3358215} = "Tarbes";
$areanames{en}->{3358216} = "Moissac";
$areanames{en}->{3358217} = "Montauban";
$areanames{en}->{3358218} = "Rodez";
$areanames{en}->{3358219} = "Nogaro";
$areanames{en}->{3358220} = "Foix";
$areanames{en}->{3358221} = "Pamiers";
$areanames{en}->{3358222} = "Decazeville";
$areanames{en}->{3358223} = "Espalion";
$areanames{en}->{3358224} = "Rodez";
$areanames{en}->{3358225} = "Saint\-Affrique";
$areanames{en}->{3358226} = "Villefranche\-de\-Rouergue";
$areanames{en}->{3358227} = "Nogaro";
$areanames{en}->{3358228} = "Toulouse";
$areanames{en}->{3358229} = "Condom";
$areanames{en}->{3358230} = "Foix";
$areanames{en}->{3358231} = "Pamiers";
$areanames{en}->{3358232} = "Nogaro";
$areanames{en}->{3358233} = "Souillac";
$areanames{en}->{3358234} = "Pamiers";
$areanames{en}->{3358235} = "Albi";
$areanames{en}->{3358236} = "Auch";
$areanames{en}->{3358237} = "Moissac";
$areanames{en}->{3358238} = "Saint\-Affrique";
$areanames{en}->{3358239} = "Figeac";
$areanames{en}->{3358240} = "Figeac";
$areanames{en}->{3358241} = "Saint\-Gaudens";
$areanames{en}->{3358242} = "Tarbes";
$areanames{en}->{3358243} = "Cazeres";
$areanames{en}->{3358244} = "Montauban";
$areanames{en}->{3358245} = "Castres";
$areanames{en}->{3358246} = "Foix";
$areanames{en}->{3358247} = "Cahors";
$areanames{en}->{3358248} = "Decazeville";
$areanames{en}->{3358249} = "Espalion";
$areanames{en}->{3358250} = "Villefranche\-de\-Rouergue";
$areanames{en}->{3358251} = "Lannemezan";
$areanames{en}->{3358252} = "Toulouse";
$areanames{en}->{3358253} = "Decazeville";
$areanames{en}->{3358254} = "Espalion";
$areanames{en}->{3358255} = "Rodez";
$areanames{en}->{3358256} = "Saint\-Affrique";
$areanames{en}->{3358257} = "Villefranche\-de\-Rouergue";
$areanames{en}->{3358258} = "Cazeres";
$areanames{en}->{3358259} = "Saint\-Gaudens";
$areanames{en}->{3358260} = "Toulouse";
$areanames{en}->{3358261} = "Auch";
$areanames{en}->{3358262} = "Condom";
$areanames{en}->{3358263} = "Nogaro";
$areanames{en}->{3358264} = "Cahors";
$areanames{en}->{3358265} = "Figeac";
$areanames{en}->{3358266} = "Souillac";
$areanames{en}->{3358267} = "Lannemezan";
$areanames{en}->{3358268} = "Tarbes";
$areanames{en}->{3358269} = "Albi";
$areanames{en}->{3358280} = "Tarbes";
$areanames{en}->{3358281} = "Montauban";
$areanames{en}->{3358283} = "Auch";
$areanames{en}->{3358284} = "Toulouse";
$areanames{en}->{3358285} = "Villefranche\-de\-Rouergue";
$areanames{en}->{3358286} = "Condom";
$areanames{en}->{3358287} = "Nogaro";
$areanames{en}->{3358288} = "Toulouse";
$areanames{en}->{3358289} = "Cahors";
$areanames{en}->{3358600} = "Angoulême";
$areanames{en}->{3358601} = "Bressuire";
$areanames{en}->{3358602} = "Melle";
$areanames{en}->{3358603} = "Niort";
$areanames{en}->{3358604} = "Parthenay";
$areanames{en}->{3358605} = "Thouars";
$areanames{en}->{3358606} = "Civray";
$areanames{en}->{3358607} = "Angoulême";
$areanames{en}->{3358608} = "La\ Rochelle";
$areanames{en}->{3358609} = "Poitiers";
$areanames{en}->{3358610} = "La\ Rochelle";
$areanames{en}->{3358611} = "La\ Rochelle";
$areanames{en}->{3358612} = "Angoulême";
$areanames{en}->{3358613} = "Barbezieux\-Saint\-Hilaire";
$areanames{en}->{3358614} = "Cognac";
$areanames{en}->{3358615} = "Confolens";
$areanames{en}->{3358616} = "Poitiers";
$areanames{en}->{3358617} = "Poitiers";
$areanames{en}->{3358618} = "La\ Rochelle";
$areanames{en}->{3358619} = "Cognac";
$areanames{en}->{3358620} = "Niort";
$areanames{en}->{3358621} = "Saint\-Jean\-dAngely";
$areanames{en}->{3358622} = "Rochefort";
$areanames{en}->{3358623} = "Saintes";
$areanames{en}->{3358624} = "Chatellerault";
$areanames{en}->{3358625} = "Bressuire";
$areanames{en}->{3358626} = "Parthenay";
$areanames{en}->{3358627} = "Cognac";
$areanames{en}->{3358628} = "Poitiers";
$areanames{en}->{3358629} = "Cognac";
$areanames{en}->{3358630} = "Poitiers";
$areanames{en}->{3358631} = "Poitiers";
$areanames{en}->{3358632} = "Barbezieux\-Saint\-Hilaire";
$areanames{en}->{3358633} = "Confolens";
$areanames{en}->{3358634} = "Jonzac";
$areanames{en}->{3358635} = "Rochefort";
$areanames{en}->{3358636} = "Saintes";
$areanames{en}->{3358637} = "Bressuire";
$areanames{en}->{3358638} = "Melle";
$areanames{en}->{3358639} = "Parthenay";
$areanames{en}->{3358640} = "Thouars";
$areanames{en}->{3358641} = "Chatellerault";
$areanames{en}->{3358642} = "Civray";
$areanames{en}->{3358643} = "Loudun";
$areanames{en}->{3358644} = "Montmorillon";
$areanames{en}->{3358645} = "Chatellerault";
$areanames{en}->{3358646} = "Poitiers";
$areanames{en}->{3358647} = "Saintes";
$areanames{en}->{3358648} = "Poitiers";
$areanames{en}->{3358649} = "Bressuire";
$areanames{en}->{3358650} = "Angoulême";
$areanames{en}->{3358651} = "Parthenay";
$areanames{en}->{3358652} = "La\ Rochelle";
$areanames{en}->{3358653} = "Rochefort";
$areanames{en}->{3358654} = "Poitiers";
$areanames{en}->{3358655} = "Angoulême";
$areanames{en}->{3358656} = "La\ Rochelle";
$areanames{en}->{3358657} = "Rochefort";
$areanames{en}->{3358658} = "La\ Rochelle";
$areanames{en}->{3358665} = "Cognac";
$areanames{en}->{3358666} = "Angoulême";
$areanames{en}->{3358667} = "Barbezieux\-Saint\-Hilaire";
$areanames{en}->{3358668} = "Confolens";
$areanames{en}->{3358669} = "Jonzac";
$areanames{en}->{3358670} = "Loudun";
$areanames{en}->{3358671} = "Montmorillon";
$areanames{en}->{3358672} = "Melle";
$areanames{en}->{3358673} = "Saint\-Jean\-dAngely";
$areanames{en}->{3358674} = "Poitiers";
$areanames{en}->{3358675} = "Angoulême";
$areanames{en}->{3358676} = "Rochefort";
$areanames{en}->{3358677} = "La\ Rochelle";
$areanames{en}->{3358678} = "Niort";
$areanames{en}->{3358679} = "Niort";
$areanames{en}->{3358680} = "Rochefort";
$areanames{en}->{3358681} = "Confolens";
$areanames{en}->{3358682} = "Melle";
$areanames{en}->{3358683} = "Thouars";
$areanames{en}->{3358684} = "Angoulême";
$areanames{en}->{3358685} = "La\ Rochelle";
$areanames{en}->{3358686} = "Angoulême";
$areanames{en}->{3358687} = "Rochefort";
$areanames{en}->{3358688} = "La\ Rochelle";
$areanames{en}->{3358689} = "Barbezieux\-Saint\-Hilaire";
$areanames{en}->{3358690} = "Confolens";
$areanames{en}->{3358691} = "Jonzac";
$areanames{en}->{3358692} = "Saint\-Jean\-dAngely";
$areanames{en}->{3358693} = "Melle";
$areanames{en}->{3358694} = "Thouars";
$areanames{en}->{3358695} = "Civray";
$areanames{en}->{3358696} = "Loudun";
$areanames{en}->{3358697} = "Montmorillon";
$areanames{en}->{3358698} = "Poitiers";
$areanames{en}->{3358699} = "Niort";
$areanames{en}->{3358700} = "Limoges";
$areanames{en}->{3358701} = "Tulle";
$areanames{en}->{3358702} = "Limoges";
$areanames{en}->{3358703} = "Limoges";
$areanames{en}->{3358704} = "Aubusson";
$areanames{en}->{3358705} = "Uzerche";
$areanames{en}->{3358706} = "Argentat";
$areanames{en}->{3358707} = "Limoges";
$areanames{en}->{3358708} = "Limoges";
$areanames{en}->{3358709} = "Tulle";
$areanames{en}->{3358710} = "Tulle";
$areanames{en}->{3358711} = "Ussel";
$areanames{en}->{3358712} = "Uzerche";
$areanames{en}->{3358713} = "Aubusson";
$areanames{en}->{3358714} = "Limoges";
$areanames{en}->{3358715} = "Gueret";
$areanames{en}->{3358716} = "Gueret";
$areanames{en}->{3358717} = "La\ Souterraine";
$areanames{en}->{3358718} = "Bellac";
$areanames{en}->{3358719} = "Limoges";
$areanames{en}->{3358720} = "Limoges";
$areanames{en}->{3358721} = "Limoges";
$areanames{en}->{3358722} = "Tulle";
$areanames{en}->{3358723} = "Gueret";
$areanames{en}->{3358724} = "Boussac";
$areanames{en}->{3358725} = "Argentat";
$areanames{en}->{3358726} = "Aubusson";
$areanames{en}->{3358727} = "Bellac";
$areanames{en}->{3358728} = "Bourganeuf";
$areanames{en}->{3358729} = "Boussac";
$areanames{en}->{3358730} = "Gueret";
$areanames{en}->{3358731} = "Limoges";
$areanames{en}->{3358732} = "La\ Souterraine";
$areanames{en}->{3358733} = "Limoges";
$areanames{en}->{3358734} = "Argentat";
$areanames{en}->{3358735} = "Argentat";
$areanames{en}->{3358736} = "Aubusson";
$areanames{en}->{3358737} = "Bellac";
$areanames{en}->{3358738} = "Bourganeuf";
$areanames{en}->{3358739} = "Boussac";
$areanames{en}->{3358740} = "Gueret";
$areanames{en}->{3358741} = "Limoges";
$areanames{en}->{3358742} = "La\ Souterraine";
$areanames{en}->{3358743} = "Tulle";
$areanames{en}->{3358744} = "Ussel";
$areanames{en}->{3358745} = "Uzerche";
$areanames{en}->{3358746} = "Tulle";
$areanames{en}->{3358747} = "Ussel";
$areanames{en}->{3358748} = "Uzerche";
$areanames{en}->{3358749} = "Tulle";
$areanames{en}->{3358750} = "Limoges";
$areanames{en}->{3358751} = "Ussel";
$areanames{en}->{3358752} = "Uzerche";
$areanames{en}->{3358753} = "Aubusson";
$areanames{en}->{3358754} = "Bourganeuf";
$areanames{en}->{3358755} = "Boussac";
$areanames{en}->{3358756} = "Gueret";
$areanames{en}->{3358757} = "La\ Souterraine";
$areanames{en}->{3358758} = "Tulle";
$areanames{en}->{3358759} = "Bellac";
$areanames{en}->{3358760} = "Bellac";
$areanames{en}->{3358761} = "Bourganeuf";
$areanames{en}->{3358762} = "La\ Souterraine";
$areanames{en}->{3358763} = "Gueret";
$areanames{en}->{3358764} = "Limoges";
$areanames{en}->{3358765} = "La\ Souterraine";
$areanames{en}->{3358766} = "La\ Souterraine";
$areanames{en}->{3358767} = "Uzerche";
$areanames{en}->{3358768} = "Limoges";
$areanames{en}->{3358769} = "Limoges";
$areanames{en}->{3358770} = "Limoges";
$areanames{en}->{3358771} = "Gueret";
$areanames{en}->{3358772} = "Bourganeuf";
$areanames{en}->{3358773} = "Limoges";
$areanames{en}->{3358774} = "La\ Souterraine";
$areanames{en}->{3358775} = "Limoges";
$areanames{en}->{3358776} = "Limoges";
$areanames{en}->{3358777} = "Bellac";
$areanames{en}->{3358778} = "Ussel";
$areanames{en}->{3358779} = "Limoges";
$areanames{en}->{3358780} = "Gueret";
$areanames{en}->{3358781} = "Argentat";
$areanames{en}->{3358782} = "Aubusson";
$areanames{en}->{3358783} = "Limoges";
$areanames{en}->{3358784} = "Limoges";
$areanames{en}->{3358785} = "Limoges";
$areanames{en}->{3358786} = "Gueret";
$areanames{en}->{3358787} = "Bellac";
$areanames{en}->{3358788} = "Bourganeuf";
$areanames{en}->{3358789} = "Bourganeuf";
$areanames{en}->{3358790} = "Argentat";
$areanames{en}->{3358791} = "Tulle";
$areanames{en}->{3358792} = "Ussel";
$areanames{en}->{3358793} = "Uzerche";
$areanames{en}->{3358794} = "Aubusson";
$areanames{en}->{3358795} = "Bourganeuf";
$areanames{en}->{3358796} = "Boussac";
$areanames{en}->{3358797} = "Gueret";
$areanames{en}->{3358798} = "La\ Souterraine";
$areanames{en}->{3358799} = "Bellac";
$areanames{en}->{3359020} = "Les\ Abymes";
$areanames{en}->{3359021} = "Pointe\-à\-Pitre";
$areanames{en}->{3359022} = "Petit\-Canal";
$areanames{en}->{3359023} = "Le\ Moule";
$areanames{en}->{3359024} = "Morne\-À\-l\'Eau";
$areanames{en}->{3359025} = "Baie\ Mahault";
$areanames{en}->{3359026} = "Baie\ Mahault";
$areanames{en}->{3359027} = "Saint\ Barthélémy";
$areanames{en}->{3359028} = "Sainte\ Rose";
$areanames{en}->{3359029} = "Saint\ Barthélémy";
$areanames{en}->{3359032} = "Baie\ Mahault";
$areanames{en}->{3359038} = "Baie\ Mahault";
$areanames{en}->{3359041} = "Baie\ Mahault";
$areanames{en}->{3359048} = "Les\ Abymes";
$areanames{en}->{3359052} = "Saint\ Barthélémy";
$areanames{en}->{3359060} = "Baie\ Mahault";
$areanames{en}->{3359068} = "Les\ Abymes";
$areanames{en}->{3359080} = "Saint\-Claude";
$areanames{en}->{3359081} = "Basse\ Terre";
$areanames{en}->{3359082} = "Pointe\-à\-Pitre";
$areanames{en}->{3359083} = "Pointe\-à\-Pitre";
$areanames{en}->{3359084} = "Le\ Gosier";
$areanames{en}->{3359085} = "Sainte\-Anne";
$areanames{en}->{3359086} = "Capesterre\ Belle\ Eau";
$areanames{en}->{3359087} = "Saint\ Barthélémy";
$areanames{en}->{3359088} = "Sainte\-Anne";
$areanames{en}->{3359089} = "Les\ Abymes";
$areanames{en}->{3359090} = "Pointe\-à\-Pitre";
$areanames{en}->{3359091} = "Les\ Abymes";
$areanames{en}->{3359092} = "Trois\ Rivieres";
$areanames{en}->{3359093} = "Pointe\-à\-Pitre";
$areanames{en}->{3359094} = "Petit\ Bourg";
$areanames{en}->{3359095} = "Petit\ Bourg";
$areanames{en}->{3359097} = "Grand\-Bourg";
$areanames{en}->{3359098} = "Vieux\ Habitants";
$areanames{en}->{3359099} = "Basse\ Terre";
$areanames{en}->{3359422} = "Kourou";
$areanames{en}->{3359425} = "Cayenne";
$areanames{en}->{3359427} = "Saint\-Laurent\-du\-Maroni";
$areanames{en}->{3359428} = "Cayenne";
$areanames{en}->{3359429} = "Cayenne";
$areanames{en}->{3359430} = "Cayenne";
$areanames{en}->{3359431} = "Cayenne";
$areanames{en}->{3359432} = "Kourou";
$areanames{en}->{3359434} = "Saint\-Laurent\-du\-Maroni";
$areanames{en}->{3359435} = "Matoury";
$areanames{en}->{3359437} = "Cayenne";
$areanames{en}->{3359438} = "Cayenne";
$areanames{en}->{3359439} = "Cayenne";
$areanames{en}->{3359638} = "Le\ Robert";
$areanames{en}->{3359639} = "Fort\ de\ France";
$areanames{en}->{3359642} = "Fort\ de\ France";
$areanames{en}->{3359648} = "Rivière\-Salée";
$areanames{en}->{3359650} = "Fort\ de\ France";
$areanames{en}->{3359651} = "Fort\ de\ France";
$areanames{en}->{3359652} = "Le\ Morne\ Rouge";
$areanames{en}->{3359653} = "Le\ Lorrain";
$areanames{en}->{3359654} = "Le\ François";
$areanames{en}->{3359655} = "Le\ Morne\ Vert";
$areanames{en}->{3359656} = "Ducos";
$areanames{en}->{3359657} = "Saint\ Joseph";
$areanames{en}->{3359658} = "Fort\ de\ France";
$areanames{en}->{3359660} = "Fort\ de\ France";
$areanames{en}->{3359661} = "Schoelcher";
$areanames{en}->{3359662} = "Rivière\-Pilote";
$areanames{en}->{3359663} = "Fort\ de\ France";
$areanames{en}->{3359664} = "Fort\ de\ France";
$areanames{en}->{3359665} = "Le\ Robert";
$areanames{en}->{3359667} = "Gros\-Morne";
$areanames{en}->{3359668} = "Rivière\-Salée";
$areanames{en}->{3359669} = "Sainte\ Marie";
$areanames{en}->{335967} = "Fort\ de\ France";
$areanames{en}->{3359674} = "Le\ Vauclin";
$areanames{en}->{3359676} = "Sainte\-Anne";
$areanames{en}->{3359677} = "Ducos";
$areanames{en}->{3359678} = "Basse\-Pointe";
$areanames{fr}->{33105} = "Ile\ de\ France";
$areanames{fr}->{331241} = "Ile\ de\ France";
$areanames{fr}->{331242} = "Ile\ de\ France";
$areanames{fr}->{3313005} = "Coignières";
$areanames{fr}->{3313006} = "Poissy";
$areanames{fr}->{3313007} = "Plaisir";
$areanames{fr}->{3313008} = "Marly\-le\-Roi";
$areanames{fr}->{3313009} = "Chatou";
$areanames{fr}->{3313010} = "Cormeilles\-en\-Parisis";
$areanames{fr}->{3313011} = "Gonesse";
$areanames{fr}->{3313013} = "Trappes";
$areanames{fr}->{3313015} = "Montesson";
$areanames{fr}->{3313016} = "Trappes";
$areanames{fr}->{3313017} = "Cergy";
$areanames{fr}->{3313018} = "Goussainville";
$areanames{fr}->{3313021} = "Versailles";
$areanames{fr}->{3313022} = "Les\ Mureaux";
$areanames{fr}->{3313023} = "Bois\-d\'Arcy";
$areanames{fr}->{3313024} = "Viroflay";
$areanames{fr}->{3313025} = "Argenteuil";
$areanames{fr}->{3313026} = "Herblay";
$areanames{fr}->{3313028} = "Chambly";
$areanames{fr}->{3313029} = "Luzarches";
$areanames{fr}->{3313030} = "Cergy";
$areanames{fr}->{3313031} = "Cergy";
$areanames{fr}->{3313032} = "Cergy";
$areanames{fr}->{3313033} = "Mantes\-la\-Jolie";
$areanames{fr}->{3313034} = "Chambly";
$areanames{fr}->{3313035} = "Viarmes";
$areanames{fr}->{3313036} = "Auvers\-sur\-Oise";
$areanames{fr}->{3313037} = "Saint\-Ouen\-l\'Aumône";
$areanames{fr}->{3313038} = "Cergy";
$areanames{fr}->{3313039} = "Marines";
$areanames{fr}->{3313040} = "Taverny";
$areanames{fr}->{3313041} = "Rambouillet";
$areanames{fr}->{3313042} = "Rosny\-sur\-Seine";
$areanames{fr}->{3313043} = "Montigny\-le\-Bretonneux";
$areanames{fr}->{3313044} = "Montigny\-le\-Bretonneux";
$areanames{fr}->{3313045} = "Saint\-Cyr\-l\'École";
$areanames{fr}->{3313046} = "Houdan";
$areanames{fr}->{3313047} = "Saint\-Rémy\-lès\-Chevreuse";
$areanames{fr}->{3313048} = "Montigny\-le\-Bretonneux";
$areanames{fr}->{3313049} = "Coignières";
$areanames{fr}->{3313050} = "Maurepas";
$areanames{fr}->{3313051} = "Trappes";
$areanames{fr}->{3313052} = "Chevreuse";
$areanames{fr}->{3313053} = "Chatou";
$areanames{fr}->{3313054} = "Plaisir";
$areanames{fr}->{3313055} = "Plaisir";
$areanames{fr}->{3313056} = "Villepreux";
$areanames{fr}->{3313057} = "Montigny\-le\-Bretonneux";
$areanames{fr}->{3313058} = "Saint\-Cyr\-l\'École";
$areanames{fr}->{3313059} = "Houdan";
$areanames{fr}->{3313060} = "Montigny\-le\-Bretonneux";
$areanames{fr}->{3313061} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3313062} = "Trappes";
$areanames{fr}->{3313063} = "Mantes\-la\-Jolie";
$areanames{fr}->{3313064} = "Montigny\-le\-Bretonneux";
$areanames{fr}->{3313065} = "Poissy";
$areanames{fr}->{3313066} = "Trappes";
$areanames{fr}->{3313068} = "Élancourt";
$areanames{fr}->{3313069} = "Trappes";
$areanames{fr}->{3313070} = "Vélizy\-Villacoublay";
$areanames{fr}->{3313071} = "Chatou";
$areanames{fr}->{3313072} = "Franconville";
$areanames{fr}->{3313073} = "Cergy";
$areanames{fr}->{3313074} = "Poissy";
$areanames{fr}->{3313075} = "Cergy";
$areanames{fr}->{3313076} = "Argenteuil";
$areanames{fr}->{3313079} = "Plaisir";
$areanames{fr}->{3313080} = "Saint\-Nom\-la\-Bretèche";
$areanames{fr}->{3313081} = "Plaisir";
$areanames{fr}->{3313082} = "La\ Celle\ Saint\ Cloud";
$areanames{fr}->{3313083} = "Versailles";
$areanames{fr}->{3313086} = "Sartrouville";
$areanames{fr}->{3313087} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3313088} = "Rambouillet";
$areanames{fr}->{3313090} = "Maule";
$areanames{fr}->{3313092} = "Mantes\-la\-Ville";
$areanames{fr}->{3313094} = "Mantes\-la\-Jolie";
$areanames{fr}->{3313095} = "Aubergenville";
$areanames{fr}->{3313096} = "Montigny\-le\-Bretonneux";
$areanames{fr}->{3313098} = "Mantes\-la\-Jolie";
$areanames{fr}->{3313099} = "Les\ Mureaux";
$areanames{fr}->{3313402} = "Saint\-Ouen\-l\'Aumône";
$areanames{fr}->{3313404} = "Sarcelles";
$areanames{fr}->{3313405} = "Deuil\-la\-Barre";
$areanames{fr}->{3313407} = "Gonesse";
$areanames{fr}->{3313408} = "L\'Isle\ Adam";
$areanames{fr}->{3313409} = "Viarmes";
$areanames{fr}->{3313410} = "Argenteuil";
$areanames{fr}->{3313411} = "Argenteuil";
$areanames{fr}->{3313412} = "Enghien\-les\-Bains";
$areanames{fr}->{3313413} = "Franconville";
$areanames{fr}->{3313414} = "Franconville";
$areanames{fr}->{3313415} = "Ermont";
$areanames{fr}->{3313416} = "Eaubonne";
$areanames{fr}->{3313417} = "Saint\-Gratien";
$areanames{fr}->{3313418} = "Taverny";
$areanames{fr}->{3313419} = "Sarcelles";
$areanames{fr}->{3313420} = "Cergy";
$areanames{fr}->{3313421} = "Saint\-Ouen\-l\'Aumône";
$areanames{fr}->{3313422} = "Cergy";
$areanames{fr}->{3313424} = "Cergy";
$areanames{fr}->{3313425} = "Cergy";
$areanames{fr}->{3313427} = "Eaubonne";
$areanames{fr}->{3313428} = "Deuil\-la\-Barre";
$areanames{fr}->{3313429} = "Roissy\-en\-France";
$areanames{fr}->{3313430} = "Saint\-Ouen\-l\'Aumône";
$areanames{fr}->{3313431} = "Fosses";
$areanames{fr}->{3313432} = "Cergy";
$areanames{fr}->{3313434} = "Argenteuil";
$areanames{fr}->{3313435} = "Cergy";
$areanames{fr}->{3313437} = "Ermont";
$areanames{fr}->{3313438} = "Sarcelles";
$areanames{fr}->{3313440} = "Saint\-Ouen\-l\'Aumône";
$areanames{fr}->{3313441} = "Cergy";
$areanames{fr}->{3313442} = "Boissy\-l\'Aillerie";
$areanames{fr}->{3313443} = "Jouy\-le\-Moutier";
$areanames{fr}->{3313444} = "Franconville";
$areanames{fr}->{3313445} = "Garges\-lès\-Gonesse";
$areanames{fr}->{3313446} = "Cergy";
$areanames{fr}->{3313448} = "Auvers\-sur\-Oise";
$areanames{fr}->{3313450} = "Herblay";
$areanames{fr}->{3313451} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3313452} = "Montigny\-le\-Bretonneux";
$areanames{fr}->{3313453} = "Gonesse";
$areanames{fr}->{3313457} = "Rambouillet";
$areanames{fr}->{3313459} = "Plaisir";
$areanames{fr}->{3313460} = "Fontenay\-le\-Fleury";
$areanames{fr}->{3313461} = "Coignières";
$areanames{fr}->{3313462} = "Noisy\-le\-Roi";
$areanames{fr}->{3313464} = "Saint\-Ouen\-l\'Aumône";
$areanames{fr}->{3313465} = "Vélizy\-Villacoublay";
$areanames{fr}->{3313467} = "Magny\-en\-Vexin";
$areanames{fr}->{3313468} = "Louvres";
$areanames{fr}->{3313469} = "L\'Isle\ Adam";
$areanames{fr}->{3313470} = "Beaumont\-sur\-Oise";
$areanames{fr}->{3313471} = "Luzarches";
$areanames{fr}->{3313472} = "Fosses";
$areanames{fr}->{3313473} = "Parmain";
$areanames{fr}->{3313474} = "Les\ Mureaux";
$areanames{fr}->{3313475} = "Ecquevilly";
$areanames{fr}->{3313477} = "Mantes\-la\-Jolie";
$areanames{fr}->{3313479} = "Porcheville";
$areanames{fr}->{3313480} = "Chatou";
$areanames{fr}->{3313481} = "Plaisir";
$areanames{fr}->{3313482} = "Trappes";
$areanames{fr}->{3313483} = "Rambouillet";
$areanames{fr}->{3313484} = "Le\ Perray\ en\ Yvelines";
$areanames{fr}->{3313485} = "Rambouillet";
$areanames{fr}->{3313486} = "Montfort\-l\'Amaury";
$areanames{fr}->{3313489} = "Beynes";
$areanames{fr}->{3313490} = "Conflans\-Sainte\-Honorine";
$areanames{fr}->{3313492} = "Les\ Mureaux";
$areanames{fr}->{3313493} = "Maisons\-Laffitte";
$areanames{fr}->{3313902} = "Versailles";
$areanames{fr}->{3313904} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3313907} = "Versailles";
$areanames{fr}->{3313908} = "Orgeval";
$areanames{fr}->{3313909} = "Saint\-Ouen\-l\'Aumône";
$areanames{fr}->{3313911} = "Achères";
$areanames{fr}->{3313912} = "Maisons\-Laffitte";
$areanames{fr}->{3313913} = "Sartrouville";
$areanames{fr}->{3313914} = "Sartrouville";
$areanames{fr}->{3313915} = "Sartrouville";
$areanames{fr}->{3313916} = "Marly\-le\-Roi";
$areanames{fr}->{3313917} = "Marly\-le\-Roi";
$areanames{fr}->{3313918} = "La\ Celle\ Saint\ Cloud";
$areanames{fr}->{3313919} = "Conflans\-Sainte\-Honorine";
$areanames{fr}->{3313920} = "Versailles";
$areanames{fr}->{3313921} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3313922} = "Achères";
$areanames{fr}->{3313923} = "Le\ Chesnay";
$areanames{fr}->{3313924} = "Versailles";
$areanames{fr}->{3313925} = "Versailles";
$areanames{fr}->{3313927} = "Triel\-sur\-Seine";
$areanames{fr}->{3313928} = "Verneuil\-sur\-Seine";
$areanames{fr}->{3313930} = "Montigny\-le\-Bretonneux";
$areanames{fr}->{3313931} = "Herblay";
$areanames{fr}->{3313932} = "Taverny";
$areanames{fr}->{3313933} = "Sarcelles";
$areanames{fr}->{3313934} = "Enghien\-les\-Bains";
$areanames{fr}->{3313935} = "Domont";
$areanames{fr}->{3313937} = "Chambly";
$areanames{fr}->{3313943} = "Le\ Chesnay";
$areanames{fr}->{3313944} = "Montigny\-le\-Bretonneux";
$areanames{fr}->{3313946} = "Vélizy\-Villacoublay";
$areanames{fr}->{3313947} = "Argenteuil";
$areanames{fr}->{3313949} = "Versailles";
$areanames{fr}->{3313950} = "Versailles";
$areanames{fr}->{3313951} = "Versailles";
$areanames{fr}->{3313952} = "Chatou";
$areanames{fr}->{3313953} = "Versailles";
$areanames{fr}->{3313954} = "Le\ Chesnay";
$areanames{fr}->{3313955} = "Le\ Chesnay";
$areanames{fr}->{3313956} = "Buc";
$areanames{fr}->{3313957} = "Sartrouville";
$areanames{fr}->{3313958} = "Marly\-le\-Roi";
$areanames{fr}->{3313959} = "Eaubonne";
$areanames{fr}->{3313960} = "Taverny";
$areanames{fr}->{3313961} = "Argenteuil";
$areanames{fr}->{3313962} = "Maisons\-Laffitte";
$areanames{fr}->{3313963} = "Le\ Chesnay";
$areanames{fr}->{3313964} = "Montmorency";
$areanames{fr}->{3313965} = "Poissy";
$areanames{fr}->{3313966} = "Le\ Chesnay";
$areanames{fr}->{3313967} = "Versailles";
$areanames{fr}->{3313968} = "Houilles";
$areanames{fr}->{3313969} = "La\ Celle\ Saint\ Cloud";
$areanames{fr}->{3313970} = "Triel\-sur\-Seine";
$areanames{fr}->{3313971} = "Verneuil\-sur\-Seine";
$areanames{fr}->{3313972} = "Conflans\-Sainte\-Honorine";
$areanames{fr}->{3313973} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3313974} = "Andrésy";
$areanames{fr}->{3313975} = "Orgeval";
$areanames{fr}->{3313976} = "Le\ Vésinet";
$areanames{fr}->{3313978} = "Cormeilles\-en\-Parisis";
$areanames{fr}->{3313979} = "Poissy";
$areanames{fr}->{3313980} = "Argenteuil";
$areanames{fr}->{3313981} = "Argenteuil";
$areanames{fr}->{3313982} = "Argenteuil";
$areanames{fr}->{3313983} = "Deuil\-la\-Barre";
$areanames{fr}->{3313984} = "Deuil\-la\-Barre";
$areanames{fr}->{3313985} = "Gonesse";
$areanames{fr}->{3313986} = "Garges\-lès\-Gonesse";
$areanames{fr}->{3313987} = "Gonesse";
$areanames{fr}->{3313988} = "Goussainville";
$areanames{fr}->{3313989} = "Saint\-Gratien";
$areanames{fr}->{3313990} = "Sarcelles";
$areanames{fr}->{3313991} = "Domont";
$areanames{fr}->{3313992} = "Sarcelles";
$areanames{fr}->{3313993} = "Garges\-lès\-Gonesse";
$areanames{fr}->{3313994} = "Sarcelles";
$areanames{fr}->{3313995} = "Taverny";
$areanames{fr}->{3313996} = "Argenteuil";
$areanames{fr}->{3313997} = "Herblay";
$areanames{fr}->{3313998} = "Argenteuil";
$areanames{fr}->{331400} = "Paris";
$areanames{fr}->{3314010} = "Saint\-Ouen";
$areanames{fr}->{3314011} = "Saint\-Ouen";
$areanames{fr}->{3314012} = "Saint\-Ouen";
$areanames{fr}->{3314013} = "Paris";
$areanames{fr}->{3314015} = "Paris";
$areanames{fr}->{3314016} = "Paris";
$areanames{fr}->{3314017} = "Paris";
$areanames{fr}->{3314018} = "Paris";
$areanames{fr}->{3314019} = "Paris";
$areanames{fr}->{331402} = "Paris";
$areanames{fr}->{331403} = "Paris";
$areanames{fr}->{331404} = "Paris";
$areanames{fr}->{331405} = "Paris";
$areanames{fr}->{331406} = "Paris";
$areanames{fr}->{331407} = "Paris";
$areanames{fr}->{3314080} = "Asnières\-sur\-Seine";
$areanames{fr}->{3314082} = "Paris";
$areanames{fr}->{3314083} = "Clamart";
$areanames{fr}->{3314084} = "Montrouge";
$areanames{fr}->{3314085} = "Gennevilliers";
$areanames{fr}->{3314086} = "Asnières\-sur\-Seine";
$areanames{fr}->{3314087} = "Clichy";
$areanames{fr}->{3314088} = "Neuilly\-sur\-Seine";
$areanames{fr}->{3314089} = "Levallois\-Perret";
$areanames{fr}->{3314090} = "Puteaux";
$areanames{fr}->{3314091} = "Sceaux";
$areanames{fr}->{3314092} = "Montrouge";
$areanames{fr}->{3314093} = "Issy\-les\-Moulineaux";
$areanames{fr}->{3314094} = "Clamart";
$areanames{fr}->{3314095} = "Issy\-les\-Moulineaux";
$areanames{fr}->{3314096} = "Antony";
$areanames{fr}->{3314099} = "Suresnes";
$areanames{fr}->{3314105} = "Levallois\-Perret";
$areanames{fr}->{3314106} = "Clichy";
$areanames{fr}->{3314108} = "Issy\-les\-Moulineaux";
$areanames{fr}->{3314109} = "Issy\-les\-Moulineaux";
$areanames{fr}->{3314110} = "Boulogne\-Billancourt";
$areanames{fr}->{3314111} = "Asnières\-sur\-Seine";
$areanames{fr}->{3314112} = "Saint\-Cloud";
$areanames{fr}->{3314113} = "Sceaux";
$areanames{fr}->{3314114} = "Meudon";
$areanames{fr}->{3314115} = "Chaville";
$areanames{fr}->{3314116} = "Courbevoie";
$areanames{fr}->{3314117} = "Montrouge";
$areanames{fr}->{3314118} = "Suresnes";
$areanames{fr}->{3314119} = "Colombes";
$areanames{fr}->{3314120} = "Nanterre";
$areanames{fr}->{3314121} = "Gennevilliers";
$areanames{fr}->{3314122} = "Boulogne\-Billancourt";
$areanames{fr}->{3314124} = "Arcueil";
$areanames{fr}->{3314127} = "Clichy";
$areanames{fr}->{3314129} = "Rueil\-Malmaison";
$areanames{fr}->{3314131} = "Boulogne\-Billancourt";
$areanames{fr}->{3314132} = "Asnières\-sur\-Seine";
$areanames{fr}->{3314134} = "Levallois\-Perret";
$areanames{fr}->{3314137} = "Nanterre";
$areanames{fr}->{3314138} = "Suresnes";
$areanames{fr}->{3314139} = "Rueil\-Malmaison";
$areanames{fr}->{3314140} = "Clichy";
$areanames{fr}->{3314141} = "Boulogne\-Billancourt";
$areanames{fr}->{3314142} = "Rueil\-Malmaison";
$areanames{fr}->{3314143} = "Neuilly\-sur\-Seine";
$areanames{fr}->{3314144} = "Suresnes";
$areanames{fr}->{3314146} = "Issy\-les\-Moulineaux";
$areanames{fr}->{3314147} = "Gennevilliers";
$areanames{fr}->{3314150} = "Drancy";
$areanames{fr}->{3314152} = "Sevran";
$areanames{fr}->{3314153} = "Gagny";
$areanames{fr}->{3314155} = "Bondy";
$areanames{fr}->{3314157} = "Aubervilliers";
$areanames{fr}->{3314158} = "Montreuil";
$areanames{fr}->{3314160} = "Drancy";
$areanames{fr}->{3314161} = "Aubervilliers";
$areanames{fr}->{3314170} = "Montfermeil";
$areanames{fr}->{3314171} = "Pantin";
$areanames{fr}->{3314173} = "Rungis\ Complexe";
$areanames{fr}->{3314174} = "Vincennes";
$areanames{fr}->{3314177} = "Champigny\-sur\-Marne";
$areanames{fr}->{3314178} = "Créteil";
$areanames{fr}->{3314179} = "Maisons\-Alfort";
$areanames{fr}->{3314180} = "Rungis\ Complexe";
$areanames{fr}->{3314181} = "Saint\-Maur\-des\-Fossés";
$areanames{fr}->{3314183} = "Pantin";
$areanames{fr}->{3314187} = "Bourg\-la\-Reine";
$areanames{fr}->{3314190} = "Issy\-les\-Moulineaux";
$areanames{fr}->{3314192} = "Neuilly\-sur\-Seine";
$areanames{fr}->{3314193} = "Vincennes";
$areanames{fr}->{3314194} = "Créteil";
$areanames{fr}->{3314195} = "Fontenay\-sous\-Bois";
$areanames{fr}->{331420} = "Paris";
$areanames{fr}->{3314204} = "Suresnes";
$areanames{fr}->{3314207} = "Créteil";
$areanames{fr}->{3314211} = "Villejuif";
$areanames{fr}->{3314212} = "Paris";
$areanames{fr}->{3314215} = "Paris";
$areanames{fr}->{3314216} = "Paris";
$areanames{fr}->{3314217} = "Paris";
$areanames{fr}->{3314218} = "Paris";
$areanames{fr}->{3314219} = "Paris";
$areanames{fr}->{331422} = "Paris";
$areanames{fr}->{3314230} = "Paris";
$areanames{fr}->{3314233} = "Paris";
$areanames{fr}->{3314235} = "Saint\-Denis";
$areanames{fr}->{3314236} = "Paris";
$areanames{fr}->{3314237} = "Antony";
$areanames{fr}->{3314238} = "Paris";
$areanames{fr}->{3314239} = "Paris";
$areanames{fr}->{3314240} = "Paris";
$areanames{fr}->{3314241} = "Paris";
$areanames{fr}->{3314242} = "Colombes";
$areanames{fr}->{3314243} = "Saint\-Denis";
$areanames{fr}->{3314245} = "Paris";
$areanames{fr}->{3314246} = "Paris";
$areanames{fr}->{3314247} = "Paris";
$areanames{fr}->{3314249} = "Paris";
$areanames{fr}->{331425} = "Paris";
$areanames{fr}->{3314253} = "Montrouge";
$areanames{fr}->{331426} = "Paris";
$areanames{fr}->{3314270} = "Clichy";
$areanames{fr}->{3314271} = "Paris";
$areanames{fr}->{3314272} = "Paris";
$areanames{fr}->{3314273} = "Paris";
$areanames{fr}->{3314274} = "Paris";
$areanames{fr}->{3314276} = "Paris";
$areanames{fr}->{3314277} = "Paris";
$areanames{fr}->{3314278} = "Paris";
$areanames{fr}->{3314279} = "Paris";
$areanames{fr}->{331428} = "Paris";
$areanames{fr}->{3314283} = "Saint\-Maur\-des\-Fossés";
$areanames{fr}->{3314287} = "Montreuil";
$areanames{fr}->{331429} = "Paris";
$areanames{fr}->{3314291} = "Nanterre";
$areanames{fr}->{3314295} = "Boulogne\-Billancourt";
$areanames{fr}->{3314300} = "Neuilly\-Plaisance";
$areanames{fr}->{3314301} = "Gagny";
$areanames{fr}->{3314302} = "Gagny";
$areanames{fr}->{3314303} = "Noisy\-le\-Grand";
$areanames{fr}->{3314304} = "Noisy\-le\-Grand";
$areanames{fr}->{3314305} = "Noisy\-le\-Grand";
$areanames{fr}->{3314306} = "Paris";
$areanames{fr}->{3314307} = "Paris";
$areanames{fr}->{3314308} = "Neuilly\-sur\-Marne";
$areanames{fr}->{3314309} = "Neuilly\-sur\-Marne";
$areanames{fr}->{3314310} = "Sevran";
$areanames{fr}->{3314311} = "La\ Courneuve";
$areanames{fr}->{3314312} = "Paris";
$areanames{fr}->{3314314} = "Paris";
$areanames{fr}->{3314315} = "Paris";
$areanames{fr}->{3314318} = "Paris";
$areanames{fr}->{3314320} = "Paris";
$areanames{fr}->{3314321} = "Paris";
$areanames{fr}->{3314322} = "Paris";
$areanames{fr}->{3314324} = "Le\ Perreux\ sur\ Marne";
$areanames{fr}->{3314325} = "Paris";
$areanames{fr}->{3314326} = "Paris";
$areanames{fr}->{3314327} = "Paris";
$areanames{fr}->{3314328} = "Vincennes";
$areanames{fr}->{3314329} = "Paris";
$areanames{fr}->{3314330} = "Livry\-Gargan";
$areanames{fr}->{3314331} = "Paris";
$areanames{fr}->{3314332} = "Montfermeil";
$areanames{fr}->{3314333} = "Courbevoie";
$areanames{fr}->{3314334} = "Courbevoie";
$areanames{fr}->{3314335} = "Paris";
$areanames{fr}->{3314336} = "Paris";
$areanames{fr}->{3314337} = "Paris";
$areanames{fr}->{3314338} = "Paris";
$areanames{fr}->{3314339} = "Créteil";
$areanames{fr}->{331434} = "Paris";
$areanames{fr}->{331435} = "Paris";
$areanames{fr}->{3314350} = "Sceaux";
$areanames{fr}->{3314351} = "Montfermeil";
$areanames{fr}->{3314352} = "Aubervilliers";
$areanames{fr}->{3314353} = "Alfortville";
$areanames{fr}->{3314360} = "Bagnolet";
$areanames{fr}->{3314361} = "Paris";
$areanames{fr}->{3314362} = "Bagnolet";
$areanames{fr}->{3314363} = "Bagnolet";
$areanames{fr}->{3314364} = "Paris";
$areanames{fr}->{3314365} = "Vincennes";
$areanames{fr}->{3314366} = "Paris";
$areanames{fr}->{3314367} = "Paris";
$areanames{fr}->{3314368} = "Charenton\-le\-Pont";
$areanames{fr}->{3314370} = "Paris";
$areanames{fr}->{3314371} = "Paris";
$areanames{fr}->{3314372} = "Paris";
$areanames{fr}->{3314373} = "Paris";
$areanames{fr}->{3314374} = "Vincennes";
$areanames{fr}->{3314375} = "Alfortville";
$areanames{fr}->{3314376} = "Maisons\-Alfort";
$areanames{fr}->{3314377} = "Créteil";
$areanames{fr}->{3314378} = "Maisons\-Alfort";
$areanames{fr}->{3314379} = "Paris";
$areanames{fr}->{3314380} = "Paris";
$areanames{fr}->{3314381} = "Gagny";
$areanames{fr}->{3314382} = "Villeneuve\-Saint\-Georges";
$areanames{fr}->{3314383} = "Sevran";
$areanames{fr}->{3314384} = "Sevran";
$areanames{fr}->{3314385} = "Sevran";
$areanames{fr}->{3314386} = "Villeneuve\-Saint\-Georges";
$areanames{fr}->{3314387} = "Paris";
$areanames{fr}->{3314388} = "Montfermeil";
$areanames{fr}->{3314389} = "Villeneuve\-Saint\-Georges";
$areanames{fr}->{3314390} = "Ivry\-sur\-Seine";
$areanames{fr}->{3314391} = "Vitry\-sur\-Seine";
$areanames{fr}->{3314394} = "Fontenay\-sous\-Bois";
$areanames{fr}->{3314396} = "Maisons\-Alfort";
$areanames{fr}->{3314397} = "Saint\-Maur\-des\-Fossés";
$areanames{fr}->{3314398} = "Vincennes";
$areanames{fr}->{3314399} = "Créteil";
$areanames{fr}->{33144} = "Paris";
$areanames{fr}->{3314400} = "Ile\ de\ France";
$areanames{fr}->{3314402} = "Bobigny";
$areanames{fr}->{3314403} = "Ile\ de\ France";
$areanames{fr}->{3314404} = "Bobigny";
$areanames{fr}->{3314422} = "Nanterre";
$areanames{fr}->{3314433} = "Créteil";
$areanames{fr}->{3314445} = "Nanterre";
$areanames{fr}->{3314447} = "Bobigny";
$areanames{fr}->{3314448} = "Boulogne\-Billancourt";
$areanames{fr}->{3314460} = "Ile\ de\ France";
$areanames{fr}->{3314466} = "Ile\ de\ France";
$areanames{fr}->{3314498} = "Créteil";
$areanames{fr}->{3314499} = "Ile\ de\ France";
$areanames{fr}->{331450} = "Paris";
$areanames{fr}->{3314506} = "Suresnes";
$areanames{fr}->{3314507} = "Meudon";
$areanames{fr}->{3314509} = "Montfermeil";
$areanames{fr}->{3314510} = "Boissy\-Saint\-Léger";
$areanames{fr}->{3314511} = "Saint\-Maur\-des\-Fossés";
$areanames{fr}->{3314512} = "Rungis\ Complexe";
$areanames{fr}->{3314513} = "Bonneuil\-sur\-Marne";
$areanames{fr}->{3314515} = "Ivry\-sur\-Seine";
$areanames{fr}->{3314516} = "Champigny\-sur\-Marne";
$areanames{fr}->{3314517} = "Créteil";
$areanames{fr}->{3314518} = "Maisons\-Alfort";
$areanames{fr}->{331452} = "Paris";
$areanames{fr}->{3314521} = "Ivry\-sur\-Seine";
$areanames{fr}->{3314528} = "Rosny\-Sous\-Bois";
$areanames{fr}->{3314529} = "Issy\-les\-Moulineaux";
$areanames{fr}->{331453} = "Paris";
$areanames{fr}->{3314534} = "Meudon";
$areanames{fr}->{3314536} = "Bagneux";
$areanames{fr}->{3314537} = "Clamart";
$areanames{fr}->{331454} = "Paris";
$areanames{fr}->{3314546} = "Cachan";
$areanames{fr}->{3314547} = "Cachan";
$areanames{fr}->{331455} = "Paris";
$areanames{fr}->{3314559} = "Créteil";
$areanames{fr}->{3314560} = "Rungis\ Complexe";
$areanames{fr}->{3314561} = "Paris";
$areanames{fr}->{3314562} = "Paris";
$areanames{fr}->{3314563} = "Paris";
$areanames{fr}->{3314565} = "Paris";
$areanames{fr}->{3314566} = "Paris";
$areanames{fr}->{3314567} = "Paris";
$areanames{fr}->{3314569} = "Boissy\-Saint\-Léger";
$areanames{fr}->{331457} = "Paris";
$areanames{fr}->{3314573} = "Vitry\-sur\-Seine";
$areanames{fr}->{3314576} = "Chennevières\-sur\-Marne";
$areanames{fr}->{331458} = "Paris";
$areanames{fr}->{3314590} = "Sucy\-en\-Brie";
$areanames{fr}->{3314591} = "Le\ Blanc\ Mesnil";
$areanames{fr}->{3314592} = "Noisy\-le\-Grand";
$areanames{fr}->{3314593} = "Chennevières\-sur\-Marne";
$areanames{fr}->{3314594} = "Chennevières\-sur\-Marne";
$areanames{fr}->{3314595} = "Limeil\-Brévannes";
$areanames{fr}->{3314597} = "Villeneuve\-le\-Roi";
$areanames{fr}->{3314598} = "Mandres\-les\-Roses";
$areanames{fr}->{3314599} = "Villecresnes";
$areanames{fr}->{3314601} = "Le\ Plessis\-Robinson";
$areanames{fr}->{3314602} = "Saint\-Cloud";
$areanames{fr}->{3314603} = "Boulogne\-Billancourt";
$areanames{fr}->{3314604} = "Boulogne\-Billancourt";
$areanames{fr}->{3314605} = "Boulogne\-Billancourt";
$areanames{fr}->{3314606} = "Paris";
$areanames{fr}->{3314607} = "Paris";
$areanames{fr}->{3314608} = "Boulogne\-Billancourt";
$areanames{fr}->{3314609} = "Boulogne\-Billancourt";
$areanames{fr}->{3314610} = "Boulogne\-Billancourt";
$areanames{fr}->{3314612} = "Montrouge";
$areanames{fr}->{3314615} = "Fresnes";
$areanames{fr}->{3314620} = "Boulogne\-Billancourt";
$areanames{fr}->{3314621} = "Boulogne\-Billancourt";
$areanames{fr}->{3314622} = "Paris";
$areanames{fr}->{3314623} = "Meudon";
$areanames{fr}->{3314624} = "Neuilly\-sur\-Seine";
$areanames{fr}->{3314625} = "Suresnes";
$areanames{fr}->{3314626} = "Meudon";
$areanames{fr}->{3314627} = "Paris";
$areanames{fr}->{3314628} = "Paris";
$areanames{fr}->{3314630} = "Clamart";
$areanames{fr}->{3314631} = "Clamart";
$areanames{fr}->{3314632} = "Clamart";
$areanames{fr}->{3314633} = "Paris";
$areanames{fr}->{3314634} = "Paris";
$areanames{fr}->{3314636} = "Paris";
$areanames{fr}->{3314637} = "Neuilly\-sur\-Seine";
$areanames{fr}->{3314638} = "Issy\-les\-Moulineaux";
$areanames{fr}->{3314640} = "Neuilly\-sur\-Seine";
$areanames{fr}->{3314642} = "Issy\-les\-Moulineaux";
$areanames{fr}->{3314644} = "Issy\-les\-Moulineaux";
$areanames{fr}->{3314645} = "Issy\-les\-Moulineaux";
$areanames{fr}->{3314647} = "Paris";
$areanames{fr}->{3314648} = "Issy\-les\-Moulineaux";
$areanames{fr}->{3314649} = "Colombes";
$areanames{fr}->{3314651} = "Paris";
$areanames{fr}->{3314652} = "Colombes";
$areanames{fr}->{3314654} = "Montrouge";
$areanames{fr}->{3314655} = "Montrouge";
$areanames{fr}->{3314656} = "Montrouge";
$areanames{fr}->{3314657} = "Montrouge";
$areanames{fr}->{3314658} = "Ivry\-sur\-Seine";
$areanames{fr}->{3314659} = "Paris";
$areanames{fr}->{3314660} = "Sceaux";
$areanames{fr}->{3314661} = "Sceaux";
$areanames{fr}->{3314662} = "Issy\-les\-Moulineaux";
$areanames{fr}->{3314663} = "Cachan";
$areanames{fr}->{3314664} = "Bagneux";
$areanames{fr}->{3314665} = "Bagneux";
$areanames{fr}->{3314666} = "Antony";
$areanames{fr}->{3314667} = "Courbevoie";
$areanames{fr}->{3314668} = "Antony";
$areanames{fr}->{3314670} = "Ivry\-sur\-Seine";
$areanames{fr}->{3314671} = "Ivry\-sur\-Seine";
$areanames{fr}->{3314672} = "Ivry\-sur\-Seine";
$areanames{fr}->{3314674} = "Antony";
$areanames{fr}->{3314675} = "Rungis\ Complexe";
$areanames{fr}->{3314677} = "Villejuif";
$areanames{fr}->{3314678} = "Villejuif";
$areanames{fr}->{3314680} = "Vitry\-sur\-Seine";
$areanames{fr}->{3314681} = "Vitry\-sur\-Seine";
$areanames{fr}->{3314682} = "Vitry\-sur\-Seine";
$areanames{fr}->{3314683} = "Sceaux";
$areanames{fr}->{3314684} = "Boulogne\-Billancourt";
$areanames{fr}->{3314686} = "Rungis\ Complexe";
$areanames{fr}->{3314687} = "Rungis\ Complexe";
$areanames{fr}->{3314688} = "Asnières\-sur\-Seine";
$areanames{fr}->{3314689} = "Antony";
$areanames{fr}->{3314691} = "Courbevoie";
$areanames{fr}->{3314694} = "Boulogne\-Billancourt";
$areanames{fr}->{3314695} = "Nanterre";
$areanames{fr}->{3314697} = "Suresnes";
$areanames{fr}->{3314698} = "Puteaux";
$areanames{fr}->{3314699} = "Boulogne\-Billancourt";
$areanames{fr}->{3314700} = "Paris";
$areanames{fr}->{3314701} = "Garches";
$areanames{fr}->{3314702} = "Sceaux";
$areanames{fr}->{3314703} = "Paris";
$areanames{fr}->{3314704} = "Paris";
$areanames{fr}->{3314705} = "Paris";
$areanames{fr}->{3314706} = "Champigny\-sur\-Marne";
$areanames{fr}->{3314707} = "Paris";
$areanames{fr}->{3314708} = "Rueil\-Malmaison";
$areanames{fr}->{3314709} = "Chaville";
$areanames{fr}->{3314712} = "Boulogne\-Billancourt";
$areanames{fr}->{3314714} = "Rueil\-Malmaison";
$areanames{fr}->{3314715} = "Levallois\-Perret";
$areanames{fr}->{3314716} = "Rueil\-Malmaison";
$areanames{fr}->{3314717} = "Courbevoie";
$areanames{fr}->{3314718} = "Vitry\-sur\-Seine";
$areanames{fr}->{3314720} = "Paris";
$areanames{fr}->{3314721} = "Nanterre";
$areanames{fr}->{3314722} = "Neuilly\-sur\-Seine";
$areanames{fr}->{3314723} = "Paris";
$areanames{fr}->{3314724} = "Nanterre";
$areanames{fr}->{3314725} = "Nanterre";
$areanames{fr}->{3314726} = "Villejuif";
$areanames{fr}->{3314727} = "Paris";
$areanames{fr}->{3314728} = "Suresnes";
$areanames{fr}->{3314729} = "Nanterre";
$areanames{fr}->{3314730} = "Clichy";
$areanames{fr}->{3314731} = "Clichy";
$areanames{fr}->{3314732} = "Rueil\-Malmaison";
$areanames{fr}->{3314733} = "Asnières\-sur\-Seine";
$areanames{fr}->{3314734} = "Paris";
$areanames{fr}->{3314735} = "Montrouge";
$areanames{fr}->{3314736} = "Issy\-les\-Moulineaux";
$areanames{fr}->{3314737} = "Clichy";
$areanames{fr}->{3314738} = "Neuilly\-sur\-Seine";
$areanames{fr}->{3314739} = "Clichy";
$areanames{fr}->{3314740} = "Cachan";
$areanames{fr}->{3314741} = "Garches";
$areanames{fr}->{3314742} = "Paris";
$areanames{fr}->{3314743} = "Paris";
$areanames{fr}->{3314745} = "Neuilly\-sur\-Seine";
$areanames{fr}->{3314746} = "Montrouge";
$areanames{fr}->{3314747} = "Neuilly\-sur\-Seine";
$areanames{fr}->{3314748} = "Levallois\-Perret";
$areanames{fr}->{3314749} = "Rueil\-Malmaison";
$areanames{fr}->{3314750} = "Chaville";
$areanames{fr}->{3314751} = "Rueil\-Malmaison";
$areanames{fr}->{3314752} = "Rueil\-Malmaison";
$areanames{fr}->{3314753} = "Paris";
$areanames{fr}->{3314754} = "Paris";
$areanames{fr}->{3314755} = "Paris";
$areanames{fr}->{3314756} = "Clichy";
$areanames{fr}->{3314757} = "Levallois\-Perret";
$areanames{fr}->{3314758} = "Levallois\-Perret";
$areanames{fr}->{3314759} = "Levallois\-Perret";
$areanames{fr}->{3314760} = "Colombes";
$areanames{fr}->{3314761} = "Boulogne\-Billancourt";
$areanames{fr}->{3314763} = "Paris";
$areanames{fr}->{3314764} = "Paris";
$areanames{fr}->{3314765} = "Issy\-les\-Moulineaux";
$areanames{fr}->{3314766} = "Paris";
$areanames{fr}->{3314768} = "Courbevoie";
$areanames{fr}->{3314769} = "Colombes";
$areanames{fr}->{3314770} = "Paris";
$areanames{fr}->{3314771} = "Saint\-Cloud";
$areanames{fr}->{3314772} = "Suresnes";
$areanames{fr}->{3314773} = "Puteaux";
$areanames{fr}->{3314774} = "Puteaux";
$areanames{fr}->{3314775} = "Puteaux";
$areanames{fr}->{3314776} = "Puteaux";
$areanames{fr}->{3314778} = "Puteaux";
$areanames{fr}->{3314780} = "Colombes";
$areanames{fr}->{3314781} = "Colombes";
$areanames{fr}->{3314782} = "Colombes";
$areanames{fr}->{3314783} = "Paris";
$areanames{fr}->{3314784} = "Colombes";
$areanames{fr}->{3314785} = "Colombes";
$areanames{fr}->{3314786} = "Colombes";
$areanames{fr}->{3314788} = "Courbevoie";
$areanames{fr}->{3314789} = "Courbevoie";
$areanames{fr}->{3314790} = "Asnières\-sur\-Seine";
$areanames{fr}->{3314791} = "Asnières\-sur\-Seine";
$areanames{fr}->{3314792} = "Gennevilliers";
$areanames{fr}->{3314793} = "Asnières\-sur\-Seine";
$areanames{fr}->{3314794} = "Gennevilliers";
$areanames{fr}->{3314795} = "Garches";
$areanames{fr}->{3314797} = "Paris";
$areanames{fr}->{3314798} = "Gennevilliers";
$areanames{fr}->{3314799} = "Gennevilliers";
$areanames{fr}->{331480} = "Paris";
$areanames{fr}->{3314802} = "Bondy";
$areanames{fr}->{3314808} = "Vincennes";
$areanames{fr}->{3314809} = "Saint\-Denis";
$areanames{fr}->{3314811} = "Aubervilliers";
$areanames{fr}->{3314812} = "Rosny\-Sous\-Bois";
$areanames{fr}->{3314813} = "Saint\-Denis";
$areanames{fr}->{3314815} = "Noisy\-le\-Grand";
$areanames{fr}->{3314817} = "Villepinte";
$areanames{fr}->{3314818} = "Montreuil";
$areanames{fr}->{3314819} = "Aulnay\-sous\-Bois";
$areanames{fr}->{3314820} = "Saint\-Denis";
$areanames{fr}->{3314821} = "Stains";
$areanames{fr}->{3314822} = "Saint\-Denis";
$areanames{fr}->{3314823} = "Saint\-Denis";
$areanames{fr}->{3314824} = "Paris";
$areanames{fr}->{3314825} = "Boulogne\-Billancourt";
$areanames{fr}->{3314826} = "Stains";
$areanames{fr}->{3314827} = "Saint\-Denis";
$areanames{fr}->{3314828} = "Paris";
$areanames{fr}->{3314829} = "Stains";
$areanames{fr}->{3314830} = "Drancy";
$areanames{fr}->{3314831} = "Drancy";
$areanames{fr}->{3314832} = "Drancy";
$areanames{fr}->{3314833} = "Aubervilliers";
$areanames{fr}->{3314834} = "Aubervilliers";
$areanames{fr}->{3314835} = "La\ Courneuve";
$areanames{fr}->{3314836} = "La\ Courneuve";
$areanames{fr}->{3314837} = "Le\ Bourget";
$areanames{fr}->{3314838} = "La\ Courneuve";
$areanames{fr}->{3314839} = "Aubervilliers";
$areanames{fr}->{3314840} = "Pantin";
$areanames{fr}->{3314841} = "Épinay\-sur\-Seine";
$areanames{fr}->{3314842} = "Paris";
$areanames{fr}->{3314843} = "Pantin";
$areanames{fr}->{3314844} = "Pantin";
$areanames{fr}->{3314845} = "Pantin";
$areanames{fr}->{3314846} = "Pantin";
$areanames{fr}->{3314847} = "Bondy";
$areanames{fr}->{3314848} = "Bondy";
$areanames{fr}->{3314849} = "Bondy";
$areanames{fr}->{3314850} = "Bondy";
$areanames{fr}->{3314851} = "Montreuil";
$areanames{fr}->{3314852} = "Choisy\-le\-Roi";
$areanames{fr}->{3314853} = "Choisy\-le\-Roi";
$areanames{fr}->{3314854} = "Rosny\-Sous\-Bois";
$areanames{fr}->{3314855} = "Villemomble";
$areanames{fr}->{3314856} = "Paris";
$areanames{fr}->{3314857} = "Montreuil";
$areanames{fr}->{3314858} = "Montreuil";
$areanames{fr}->{3314859} = "Montreuil";
$areanames{fr}->{3314860} = "Tremblay\-en\-France";
$areanames{fr}->{3314861} = "Tremblay\-en\-France";
$areanames{fr}->{3314863} = "Villepinte";
$areanames{fr}->{3314865} = "Le\ Blanc\ Mesnil";
$areanames{fr}->{3314866} = "Aulnay\-sous\-Bois";
$areanames{fr}->{3314867} = "Le\ Blanc\ Mesnil";
$areanames{fr}->{3314868} = "Aulnay\-sous\-Bois";
$areanames{fr}->{3314869} = "Aulnay\-sous\-Bois";
$areanames{fr}->{3314870} = "Montreuil";
$areanames{fr}->{3314871} = "Le\ Perreux\ sur\ Marne";
$areanames{fr}->{3314872} = "Le\ Perreux\ sur\ Marne";
$areanames{fr}->{3314873} = "Nogent\-sur\-Marne";
$areanames{fr}->{3314874} = "Paris";
$areanames{fr}->{3314875} = "Fontenay\-sous\-Bois";
$areanames{fr}->{3314876} = "Fontenay\-sous\-Bois";
$areanames{fr}->{3314877} = "Fontenay\-sous\-Bois";
$areanames{fr}->{3314878} = "Paris";
$areanames{fr}->{3314879} = "Aulnay\-sous\-Bois";
$areanames{fr}->{3314880} = "Champigny\-sur\-Marne";
$areanames{fr}->{3314881} = "Champigny\-sur\-Marne";
$areanames{fr}->{3314882} = "Champigny\-sur\-Marne";
$areanames{fr}->{3314883} = "Saint\-Maur\-des\-Fossés";
$areanames{fr}->{3314884} = "Choisy\-le\-Roi";
$areanames{fr}->{3314885} = "Saint\-Maur\-des\-Fossés";
$areanames{fr}->{3314886} = "Saint\-Maur\-des\-Fossés";
$areanames{fr}->{3314887} = "Paris";
$areanames{fr}->{3314888} = "Paris";
$areanames{fr}->{3314889} = "Saint\-Maur\-des\-Fossés";
$areanames{fr}->{3314890} = "Choisy\-le\-Roi";
$areanames{fr}->{3314891} = "Pantin";
$areanames{fr}->{3314892} = "Choisy\-le\-Roi";
$areanames{fr}->{3314893} = "Charenton\-le\-Pont";
$areanames{fr}->{3314894} = "Rosny\-Sous\-Bois";
$areanames{fr}->{3314895} = "Drancy";
$areanames{fr}->{3314896} = "Drancy";
$areanames{fr}->{3314897} = "Bagnolet";
$areanames{fr}->{3314898} = "Créteil";
$areanames{fr}->{3314899} = "Créteil";
$areanames{fr}->{3314900} = "Puteaux";
$areanames{fr}->{3314901} = "Puteaux";
$areanames{fr}->{3314908} = "Gentilly";
$areanames{fr}->{3314909} = "Boulogne\-Billancourt";
$areanames{fr}->{3314910} = "Boulogne\-Billancourt";
$areanames{fr}->{3314911} = "Saint\-Cloud";
$areanames{fr}->{3314912} = "Arcueil";
$areanames{fr}->{3314917} = "Saint\-Denis";
$areanames{fr}->{331492} = "Paris";
$areanames{fr}->{3314920} = "Bobigny";
$areanames{fr}->{3314921} = "Bobigny";
$areanames{fr}->{3314922} = "Bobigny";
$areanames{fr}->{3314930} = "Villiers\-sur\-Marne";
$areanames{fr}->{3314932} = "Noisy\-le\-Grand";
$areanames{fr}->{3314933} = "Saint\-Denis";
$areanames{fr}->{3314934} = "La\ Courneuve";
$areanames{fr}->{3314935} = "Rosny\-Sous\-Bois";
$areanames{fr}->{3314936} = "Sevran";
$areanames{fr}->{3314937} = "Aubervilliers";
$areanames{fr}->{3314938} = "Villepinte";
$areanames{fr}->{3314941} = "Villiers\-sur\-Marne";
$areanames{fr}->{3314942} = "Noisy\-le\-Sec";
$areanames{fr}->{3314944} = "Neuilly\-sur\-Marne";
$areanames{fr}->{3314945} = "Saint\-Ouen";
$areanames{fr}->{3314946} = "Saint\-Denis";
$areanames{fr}->{3314947} = "Roissy\-en\-France";
$areanames{fr}->{3314948} = "Saint\-Ouen";
$areanames{fr}->{3314951} = "Saint\-Denis";
$areanames{fr}->{3314952} = "Paris";
$areanames{fr}->{3314953} = "Paris";
$areanames{fr}->{3314956} = "Créteil";
$areanames{fr}->{3314957} = "Vincennes";
$areanames{fr}->{3314958} = "Villejuif";
$areanames{fr}->{3314959} = "Ivry\-sur\-Seine";
$areanames{fr}->{3314960} = "Ivry\-sur\-Seine";
$areanames{fr}->{3314961} = "Villeneuve\-le\-Roi";
$areanames{fr}->{3314962} = "Chennevières\-sur\-Marne";
$areanames{fr}->{3314963} = "Tremblay\-en\-France";
$areanames{fr}->{3314965} = "Montrouge";
$areanames{fr}->{3314966} = "Sèvres";
$areanames{fr}->{3314968} = "Levallois\-Perret";
$areanames{fr}->{3314969} = "Cachan";
$areanames{fr}->{3314970} = "Paris";
$areanames{fr}->{3314971} = "Saint\-Denis";
$areanames{fr}->{3314972} = "Bagnolet";
$areanames{fr}->{3314974} = "Fontenay\-sous\-Bois";
$areanames{fr}->{3314976} = "Saint\-Maur\-des\-Fossés";
$areanames{fr}->{3314977} = "Maisons\-Alfort";
$areanames{fr}->{3314978} = "Rungis\ Complexe";
$areanames{fr}->{3314979} = "Rungis\ Complexe";
$areanames{fr}->{3314980} = "Créteil";
$areanames{fr}->{3314981} = "Créteil";
$areanames{fr}->{3314982} = "Sucy\-en\-Brie";
$areanames{fr}->{3314983} = "Champigny\-sur\-Marne";
$areanames{fr}->{3314984} = "Fresnes";
$areanames{fr}->{3314985} = "Arcueil";
$areanames{fr}->{3314986} = "Gentilly";
$areanames{fr}->{3314988} = "Montreuil";
$areanames{fr}->{3314993} = "Bagnolet";
$areanames{fr}->{3314995} = "Paris";
$areanames{fr}->{3314996} = "Paris";
$areanames{fr}->{3314997} = "Courbevoie";
$areanames{fr}->{3314998} = "Saint\-Denis";
$areanames{fr}->{33150} = "Ile\ de\ France";
$areanames{fr}->{3315010} = "Le\ Raincy";
$areanames{fr}->{3315013} = "Paris";
$areanames{fr}->{3315015} = "Boulogne\-Billancourt";
$areanames{fr}->{3315016} = "Paris";
$areanames{fr}->{3315017} = "Nanterre";
$areanames{fr}->{3315018} = "Le\ Raincy";
$areanames{fr}->{3315038} = "Paris";
$areanames{fr}->{3315040} = "Paris";
$areanames{fr}->{3315041} = "Paris";
$areanames{fr}->{331530} = "Paris";
$areanames{fr}->{3315303} = "Ile\ de\ France";
$areanames{fr}->{3315310} = "Paris";
$areanames{fr}->{3315311} = "Paris";
$areanames{fr}->{3315314} = "Villejuif";
$areanames{fr}->{3315316} = "Paris";
$areanames{fr}->{3315317} = "Paris";
$areanames{fr}->{3315319} = "Paris";
$areanames{fr}->{331532} = "Paris";
$areanames{fr}->{3315322} = "Ile\ de\ France";
$areanames{fr}->{331533} = "Paris";
$areanames{fr}->{3315337} = "Ile\ de\ France";
$areanames{fr}->{331534} = "Paris";
$areanames{fr}->{3315347} = "Ile\ de\ France";
$areanames{fr}->{3315348} = "Créteil";
$areanames{fr}->{3315349} = "Ile\ de\ France";
$areanames{fr}->{3315353} = "Paris";
$areanames{fr}->{3315356} = "Aubervilliers";
$areanames{fr}->{3315357} = "Paris";
$areanames{fr}->{3315358} = "Paris";
$areanames{fr}->{3315359} = "Paris";
$areanames{fr}->{331536} = "Paris";
$areanames{fr}->{3315366} = "Vincennes";
$areanames{fr}->{331537} = "Paris";
$areanames{fr}->{331538} = "Paris";
$areanames{fr}->{3315387} = "Ile\ de\ France";
$areanames{fr}->{3315388} = "Créteil";
$areanames{fr}->{331539} = "Paris";
$areanames{fr}->{3315397} = "Ile\ de\ France";
$areanames{fr}->{3315399} = "Créteil";
$areanames{fr}->{3315502} = "Asnières\-sur\-Seine";
$areanames{fr}->{3315504} = "Paris";
$areanames{fr}->{3315506} = "Paris";
$areanames{fr}->{3315507} = "Paris";
$areanames{fr}->{3315512} = "Saint\-Maur\-des\-Fossés";
$areanames{fr}->{3315520} = "Boulogne\-Billancourt";
$areanames{fr}->{3315521} = "Nanterre";
$areanames{fr}->{3315522} = "Boulogne\-Billancourt";
$areanames{fr}->{3315523} = "Nanterre";
$areanames{fr}->{3315524} = "Nanterre";
$areanames{fr}->{3315525} = "Paris";
$areanames{fr}->{3315526} = "Paris";
$areanames{fr}->{3315527} = "Paris";
$areanames{fr}->{3315528} = "Paris";
$areanames{fr}->{3315529} = "Paris";
$areanames{fr}->{331553} = "Paris";
$areanames{fr}->{3315536} = "Ile\ de\ France";
$areanames{fr}->{3315538} = "Boulogne\-Billancourt";
$areanames{fr}->{3315539} = "Boulogne\-Billancourt";
$areanames{fr}->{3315542} = "Paris";
$areanames{fr}->{3315543} = "Paris";
$areanames{fr}->{3315546} = "Clichy";
$areanames{fr}->{3315552} = "Fontenay\-aux\-Roses";
$areanames{fr}->{3315559} = "Antony";
$areanames{fr}->{3315560} = "Boulogne\-Billancourt";
$areanames{fr}->{3315562} = "Neuilly\-sur\-Seine";
$areanames{fr}->{3315564} = "Sèvres";
$areanames{fr}->{331557} = "Paris";
$areanames{fr}->{3315570} = "Nanterre";
$areanames{fr}->{3315571} = "Boulogne\-Billancourt";
$areanames{fr}->{3315572} = "Nanterre";
$areanames{fr}->{3315580} = "Paris";
$areanames{fr}->{3315585} = "Noisy\-le\-Grand";
$areanames{fr}->{3315586} = "Montreuil";
$areanames{fr}->{3315587} = "Saint\-Denis";
$areanames{fr}->{3315590} = "Levallois\-Perret";
$areanames{fr}->{3315593} = "Saint\-Denis";
$areanames{fr}->{3315595} = "Issy\-les\-Moulineaux";
$areanames{fr}->{3315596} = "Saint\-Maur\-des\-Fossés";
$areanames{fr}->{3315597} = "Saint\-Maur\-des\-Fossés";
$areanames{fr}->{3315598} = "Champigny\-sur\-Marne";
$areanames{fr}->{3315605} = "Colombes";
$areanames{fr}->{3315608} = "Paris";
$areanames{fr}->{331561} = "Ile\ de\ France";
$areanames{fr}->{3315610} = "Paris";
$areanames{fr}->{3315620} = "Ivry\-sur\-Seine";
$areanames{fr}->{3315624} = "Paris";
$areanames{fr}->{3315626} = "Paris";
$areanames{fr}->{3315629} = "Alfortville";
$areanames{fr}->{3315630} = "Rungis\ Complexe";
$areanames{fr}->{3315631} = "Chennevières\-sur\-Marne";
$areanames{fr}->{3315633} = "Paris";
$areanames{fr}->{3315643} = "Paris";
$areanames{fr}->{3315645} = "Antony";
$areanames{fr}->{331565} = "Paris";
$areanames{fr}->{3315650} = "Le\ Raincy";
$areanames{fr}->{3315651} = "Ile\ de\ France";
$areanames{fr}->{3315657} = "Nanterre";
$areanames{fr}->{331566} = "Paris";
$areanames{fr}->{3315663} = "Bobigny";
$areanames{fr}->{3315665} = "Nanterre";
$areanames{fr}->{3315670} = "Rungis\ Complexe";
$areanames{fr}->{3315671} = "Créteil";
$areanames{fr}->{3315673} = "Sucy\-en\-Brie";
$areanames{fr}->{3315674} = "Sucy\-en\-Brie";
$areanames{fr}->{3315679} = "Paris";
$areanames{fr}->{3315681} = "Paris";
$areanames{fr}->{3315683} = "Colombes";
$areanames{fr}->{3315686} = "Chennevières\-sur\-Marne";
$areanames{fr}->{3315688} = "Paris";
$areanames{fr}->{331569} = "Paris";
$areanames{fr}->{3315693} = "Bobigny";
$areanames{fr}->{3315694} = "Ile\ de\ France";
$areanames{fr}->{3315696} = "Bobigny";
$areanames{fr}->{3315697} = "Boulogne\-Billancourt";
$areanames{fr}->{331570} = "Paris";
$areanames{fr}->{3315700} = "Nanterre";
$areanames{fr}->{3315702} = "Créteil";
$areanames{fr}->{3315706} = "Bobigny";
$areanames{fr}->{3315707} = "Boulogne\-Billancourt";
$areanames{fr}->{3315714} = "Pantin";
$areanames{fr}->{3315719} = "Antony";
$areanames{fr}->{3315721} = "Montrouge";
$areanames{fr}->{331573} = "Paris";
$areanames{fr}->{3315732} = "Nanterre";
$areanames{fr}->{3315733} = "Le\ Raincy";
$areanames{fr}->{3315736} = "Bobigny";
$areanames{fr}->{3315739} = "Boulogne\-Billancourt";
$areanames{fr}->{3315742} = "Pantin";
$areanames{fr}->{331575} = "Paris";
$areanames{fr}->{3315753} = "Bobigny";
$areanames{fr}->{3315758} = "Boulogne\-Billancourt";
$areanames{fr}->{3315759} = "Boulogne\-Billancourt";
$areanames{fr}->{3315763} = "Montrouge";
$areanames{fr}->{3315769} = "Rueil\-Malmaison";
$areanames{fr}->{3315770} = "Boulogne\-Billancourt";
$areanames{fr}->{3315771} = "Nanterre";
$areanames{fr}->{3315772} = "Boulogne\-Billancourt";
$areanames{fr}->{3315773} = "Paris";
$areanames{fr}->{3315774} = "Paris";
$areanames{fr}->{3315775} = "Boulogne\-Billancourt";
$areanames{fr}->{3315776} = "Paris";
$areanames{fr}->{3315777} = "Nanterre";
$areanames{fr}->{3315778} = "Paris";
$areanames{fr}->{3315779} = "Paris";
$areanames{fr}->{331578} = "Paris";
$areanames{fr}->{3315784} = "Nanterre";
$areanames{fr}->{3315787} = "Nanterre";
$areanames{fr}->{331579} = "Paris";
$areanames{fr}->{3315798} = "Nanterre";
$areanames{fr}->{3315799} = "Boulogne\-Billancourt";
$areanames{fr}->{3315805} = "Paris";
$areanames{fr}->{3315818} = "Paris";
$areanames{fr}->{331582} = "Paris";
$areanames{fr}->{3315826} = "Ile\ de\ France";
$areanames{fr}->{3315830} = "Paris";
$areanames{fr}->{3315834} = "Saint\-Denis";
$areanames{fr}->{3315836} = "Paris";
$areanames{fr}->{3315842} = "Choisy\-le\-Roi";
$areanames{fr}->{331585} = "Paris";
$areanames{fr}->{3315858} = "Nanterre";
$areanames{fr}->{3315860} = "Paris";
$areanames{fr}->{3315862} = "Paris";
$areanames{fr}->{3315864} = "Vincennes";
$areanames{fr}->{3315869} = "Saint\-Denis";
$areanames{fr}->{331587} = "Paris";
$areanames{fr}->{3315873} = "Créteil";
$areanames{fr}->{3315874} = "Nanterre";
$areanames{fr}->{3315875} = "Nanterre";
$areanames{fr}->{3315879} = "Bobigny";
$areanames{fr}->{3315888} = "Issy\-les\-Moulineaux";
$areanames{fr}->{3315890} = "Paris";
$areanames{fr}->{3315891} = "Créteil";
$areanames{fr}->{3315892} = "Bobigny";
$areanames{fr}->{3315893} = "Créteil";
$areanames{fr}->{3315894} = "Créteil";
$areanames{fr}->{3315895} = "Paris";
$areanames{fr}->{3315896} = "Le\ Raincy";
$areanames{fr}->{3315897} = "Paris";
$areanames{fr}->{3315898} = "Nanterre";
$areanames{fr}->{3315899} = "Paris";
$areanames{fr}->{3316002} = "Ozoir\-la\-Ferrière";
$areanames{fr}->{3316003} = "Dammartin\-en\-Goële";
$areanames{fr}->{3316005} = "Torcy";
$areanames{fr}->{3316006} = "Torcy";
$areanames{fr}->{3316007} = "Lagny\-sur\-Marne";
$areanames{fr}->{3316008} = "Chelles";
$areanames{fr}->{3316009} = "Meaux";
$areanames{fr}->{3316010} = "Palaiseau";
$areanames{fr}->{3316011} = "Massy";
$areanames{fr}->{3316012} = "Gif\-sur\-Yvette";
$areanames{fr}->{3316013} = "Massy";
$areanames{fr}->{3316014} = "Palaiseau";
$areanames{fr}->{3316015} = "Sainte\-Geneviève\-des\-Bois";
$areanames{fr}->{3316016} = "Sainte\-Geneviève\-des\-Bois";
$areanames{fr}->{3316017} = "Torcy";
$areanames{fr}->{3316018} = "Lieusaint";
$areanames{fr}->{3316019} = "Igny";
$areanames{fr}->{3316020} = "Chelles";
$areanames{fr}->{3316021} = "Mitry\-Mory";
$areanames{fr}->{3316022} = "La\ Ferté\ sous\ Jouarre";
$areanames{fr}->{3316023} = "Meaux";
$areanames{fr}->{3316024} = "Meaux";
$areanames{fr}->{3316025} = "Meaux";
$areanames{fr}->{3316026} = "Claye\-Souilly";
$areanames{fr}->{3316027} = "Claye\-Souilly";
$areanames{fr}->{3316028} = "Pontault\-Combault";
$areanames{fr}->{3316029} = "Pontault\-Combault";
$areanames{fr}->{3316031} = "Lagny\-sur\-Marne";
$areanames{fr}->{3316032} = "Meaux";
$areanames{fr}->{3316034} = "Pontault\-Combault";
$areanames{fr}->{3316035} = "Saint\-Thibault\-des\-Vignes";
$areanames{fr}->{3316036} = "Montévrain";
$areanames{fr}->{3316037} = "Torcy";
$areanames{fr}->{3316039} = "Fontainebleau";
$areanames{fr}->{3316042} = "Serris";
$areanames{fr}->{3316043} = "Serris";
$areanames{fr}->{3316044} = "Meaux";
$areanames{fr}->{3316046} = "Brunoy";
$areanames{fr}->{3316047} = "Brunoy";
$areanames{fr}->{3316048} = "Athis\-Mons";
$areanames{fr}->{3316054} = "Dammartin\-en\-Goële";
$areanames{fr}->{3316055} = "Nemours";
$areanames{fr}->{3316056} = "Melun";
$areanames{fr}->{3316057} = "Montereau\-Fault\-Yonne";
$areanames{fr}->{3316058} = "Provins";
$areanames{fr}->{3316059} = "Melun";
$areanames{fr}->{3316060} = "Combs\-la\-Ville";
$areanames{fr}->{3316062} = "Brie\-Comte\-Robert";
$areanames{fr}->{3316063} = "Savigny\-le\-Temple";
$areanames{fr}->{3316065} = "Saint\-Fargeau\-Ponthierry";
$areanames{fr}->{3316068} = "Melun";
$areanames{fr}->{3316069} = "Bois\-le\-Roi";
$areanames{fr}->{3316070} = "Moret\-sur\-Loing";
$areanames{fr}->{3316071} = "Fontainebleau";
$areanames{fr}->{3316072} = "Fontainebleau";
$areanames{fr}->{3316074} = "Fontainebleau";
$areanames{fr}->{3316075} = "Soisy\-sur\-Seine";
$areanames{fr}->{3316077} = "Évry";
$areanames{fr}->{3316078} = "Évry";
$areanames{fr}->{3316079} = "Évry";
$areanames{fr}->{3316080} = "Étréchy";
$areanames{fr}->{3316081} = "Dourdan";
$areanames{fr}->{3316082} = "Lardy";
$areanames{fr}->{3316083} = "Arpajon";
$areanames{fr}->{3316084} = "Brétigny\-sur\-Orge";
$areanames{fr}->{3316085} = "Brétigny\-sur\-Orge";
$areanames{fr}->{3316086} = "Bondoufle";
$areanames{fr}->{3316087} = "Évry";
$areanames{fr}->{3316088} = "Corbeil\-Essonnes";
$areanames{fr}->{3316089} = "Corbeil\-Essonnes";
$areanames{fr}->{3316091} = "Évry";
$areanames{fr}->{3316092} = "Villebon\-sur\-Yvette";
$areanames{fr}->{3316096} = "Montereau\-Fault\-Yonne";
$areanames{fr}->{3316104} = "Sartrouville";
$areanames{fr}->{331611} = "Ile\ de\ France";
$areanames{fr}->{3316110} = "Meaux";
$areanames{fr}->{3316111} = "Poissy";
$areanames{fr}->{3316112} = "Versailles";
$areanames{fr}->{331612} = "Ile\ de\ France";
$areanames{fr}->{3316130} = "Sartrouville";
$areanames{fr}->{3316137} = "Montigny\-le\-Bretonneux";
$areanames{fr}->{3316138} = "Montigny\-le\-Bretonneux";
$areanames{fr}->{331614} = "Ile\ de\ France";
$areanames{fr}->{3316140} = "Lagny\-sur\-Marne";
$areanames{fr}->{3316144} = "Lagny\-sur\-Marne";
$areanames{fr}->{3316145} = "Poissy";
$areanames{fr}->{331615} = "Ile\ de\ France";
$areanames{fr}->{331616} = "Ile\ de\ France";
$areanames{fr}->{3316161} = "Corbeil\-Essonnes";
$areanames{fr}->{3316162} = "Versailles";
$areanames{fr}->{3316169} = "Corbeil\-Essonnes";
$areanames{fr}->{331617} = "Ile\ de\ France";
$areanames{fr}->{3316178} = "Guyancourt";
$areanames{fr}->{331618} = "Ile\ de\ France";
$areanames{fr}->{331619} = "Ile\ de\ France";
$areanames{fr}->{3316400} = "Provins";
$areanames{fr}->{3316402} = "Lagny\-sur\-Marne";
$areanames{fr}->{3316403} = "Coulommiers";
$areanames{fr}->{3316405} = "Brie\-Comte\-Robert";
$areanames{fr}->{3316407} = "Tournan\-en\-Brie";
$areanames{fr}->{3316408} = "Nangis";
$areanames{fr}->{3316409} = "Melun";
$areanames{fr}->{3316410} = "Melun";
$areanames{fr}->{3316411} = "Torcy";
$areanames{fr}->{3316412} = "Lagny\-sur\-Marne";
$areanames{fr}->{3316413} = "Moissy\-Cramayel";
$areanames{fr}->{3316414} = "Melun";
$areanames{fr}->{3316417} = "Serris";
$areanames{fr}->{3316419} = "Savigny\-le\-Temple";
$areanames{fr}->{3316420} = "Coulommiers";
$areanames{fr}->{3316421} = "Chelles";
$areanames{fr}->{3316422} = "Fontainebleau";
$areanames{fr}->{3316425} = "Fontenay\-Trésigny";
$areanames{fr}->{3316426} = "Chelles";
$areanames{fr}->{3316427} = "Villeparisis";
$areanames{fr}->{3316428} = "Nemours";
$areanames{fr}->{3316430} = "Lagny\-sur\-Marne";
$areanames{fr}->{3316432} = "Montereau\-Fault\-Yonne";
$areanames{fr}->{3316433} = "Meaux";
$areanames{fr}->{3316434} = "Meaux";
$areanames{fr}->{3316435} = "Meaux";
$areanames{fr}->{3316437} = "Melun";
$areanames{fr}->{3316439} = "Melun";
$areanames{fr}->{3316440} = "Ozoir\-la\-Ferrière";
$areanames{fr}->{3316441} = "Savigny\-le\-Temple";
$areanames{fr}->{3316443} = "Pontault\-Combault";
$areanames{fr}->{3316445} = "Montigny\-sur\-Loing";
$areanames{fr}->{3316446} = "Orsay";
$areanames{fr}->{3316447} = "Massy";
$areanames{fr}->{3316448} = "Longjumeau";
$areanames{fr}->{3316449} = "Marcoussis";
$areanames{fr}->{3316452} = "Melun";
$areanames{fr}->{3316454} = "Longjumeau";
$areanames{fr}->{3316456} = "Saint\-Chéron";
$areanames{fr}->{3316457} = "Mennecy";
$areanames{fr}->{3316458} = "Breuillet";
$areanames{fr}->{3316459} = "Dourdan";
$areanames{fr}->{3316460} = "Provins";
$areanames{fr}->{3316461} = "Champs\-sur\-Marne";
$areanames{fr}->{3316462} = "Lognes";
$areanames{fr}->{3316463} = "Crécy\-la\-Chapelle";
$areanames{fr}->{3316464} = "Melun";
$areanames{fr}->{3316465} = "Coulommiers";
$areanames{fr}->{3316466} = "Bussy\-Saint\-Georges";
$areanames{fr}->{3316467} = "Villeparisis";
$areanames{fr}->{3316468} = "Champs\-sur\-Marne";
$areanames{fr}->{3316469} = "Fontainebleau";
$areanames{fr}->{3316470} = "Montereau\-Fault\-Yonne";
$areanames{fr}->{3316471} = "Melun";
$areanames{fr}->{3316472} = "Chelles";
$areanames{fr}->{3316475} = "Coulommiers";
$areanames{fr}->{3316476} = "Bussy\-Saint\-Georges";
$areanames{fr}->{3316477} = "Bussy\-Saint\-Georges";
$areanames{fr}->{3316478} = "Nemours";
$areanames{fr}->{3316479} = "Dammarie\-les\-Lys";
$areanames{fr}->{3316480} = "Lognes";
$areanames{fr}->{3316486} = "Les\ Ulis";
$areanames{fr}->{3316487} = "Melun";
$areanames{fr}->{3316488} = "Moissy\-Cramayel";
$areanames{fr}->{3316490} = "Arpajon";
$areanames{fr}->{3316491} = "Limours\ en\ Hurepoix";
$areanames{fr}->{3316492} = "Arpajon";
$areanames{fr}->{3316493} = "Ballancourt\-sur\-Essonne";
$areanames{fr}->{3316494} = "Étampes";
$areanames{fr}->{3316496} = "Corbeil\-Essonnes";
$areanames{fr}->{3316497} = "Évry";
$areanames{fr}->{3316498} = "Milly\-la\-Forêt";
$areanames{fr}->{3316499} = "Mennecy";
$areanames{fr}->{3316900} = "Quincy\-sous\-Sénart";
$areanames{fr}->{3316901} = "Montlhéry";
$areanames{fr}->{3316902} = "Ris\-Orangis";
$areanames{fr}->{3316903} = "Montgeron";
$areanames{fr}->{3316904} = "Morsang\-sur\-Orge";
$areanames{fr}->{3316905} = "Savigny\-sur\-Orge";
$areanames{fr}->{3316906} = "Ris\-Orangis";
$areanames{fr}->{3316907} = "Gif\-sur\-Yvette";
$areanames{fr}->{3316909} = "Chilly\-Mazarin";
$areanames{fr}->{3316910} = "Chilly\-Mazarin";
$areanames{fr}->{3316911} = "Lisses";
$areanames{fr}->{3316912} = "Viry\-Châtillon";
$areanames{fr}->{3316914} = "Marolles\-en\-Hurepoix";
$areanames{fr}->{3316918} = "Les\ Ulis";
$areanames{fr}->{3316920} = "Massy";
$areanames{fr}->{3316921} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3316923} = "Cerny";
$areanames{fr}->{3316924} = "Viry\-Châtillon";
$areanames{fr}->{3316925} = "Sainte\-Geneviève\-des\-Bois";
$areanames{fr}->{3316926} = "Arpajon";
$areanames{fr}->{3316927} = "Lardy";
$areanames{fr}->{3316928} = "Orsay";
$areanames{fr}->{3316929} = "Orsay";
$areanames{fr}->{3316930} = "Massy";
$areanames{fr}->{3316931} = "Palaiseau";
$areanames{fr}->{3316932} = "Massy";
$areanames{fr}->{3316934} = "Longjumeau";
$areanames{fr}->{3316935} = "Bièvres";
$areanames{fr}->{3316936} = "Évry";
$areanames{fr}->{3316938} = "Athis\-Mons";
$areanames{fr}->{3316939} = "Brunoy";
$areanames{fr}->{3316940} = "Draveil";
$areanames{fr}->{3316941} = "Igny";
$areanames{fr}->{3316942} = "Draveil";
$areanames{fr}->{3316943} = "Ris\-Orangis";
$areanames{fr}->{3316944} = "Savigny\-sur\-Orge";
$areanames{fr}->{3316945} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3316946} = "Sainte\-Geneviève\-des\-Bois";
$areanames{fr}->{3316947} = "Évry";
$areanames{fr}->{3316948} = "Yerres";
$areanames{fr}->{3316949} = "Yerres";
$areanames{fr}->{3316951} = "Sainte\-Geneviève\-des\-Bois";
$areanames{fr}->{3316952} = "Montgeron";
$areanames{fr}->{3316953} = "Massy";
$areanames{fr}->{3316956} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3316957} = "Athis\-Mons";
$areanames{fr}->{3316960} = "Ile\ de\ France";
$areanames{fr}->{3316961} = "Ile\ de\ France";
$areanames{fr}->{3316962} = "Massy";
$areanames{fr}->{3316963} = "Massy";
$areanames{fr}->{3316964} = "Corbeil\-Essonnes";
$areanames{fr}->{3316965} = "Massy";
$areanames{fr}->{3316966} = "Ile\ de\ France";
$areanames{fr}->{3316967} = "Lagny\-sur\-Marne";
$areanames{fr}->{3316968} = "Melun";
$areanames{fr}->{3316969} = "Ile\ de\ France";
$areanames{fr}->{3316975} = "Massy";
$areanames{fr}->{3316978} = "Étampes";
$areanames{fr}->{3316979} = "Chilly\-Mazarin";
$areanames{fr}->{3316980} = "Montlhéry";
$areanames{fr}->{3316981} = "Massy";
$areanames{fr}->{3316983} = "Yerres";
$areanames{fr}->{3316986} = "Gif\-sur\-Yvette";
$areanames{fr}->{3316988} = "Brétigny\-sur\-Orge";
$areanames{fr}->{3316989} = "Soisy\-sur\-Seine";
$areanames{fr}->{3316990} = "Mennecy";
$areanames{fr}->{3316991} = "Évry";
$areanames{fr}->{3316992} = "Étampes";
$areanames{fr}->{3316995} = "Angerville";
$areanames{fr}->{3316996} = "Savigny\-sur\-Orge";
$areanames{fr}->{3317000} = "Chelles";
$areanames{fr}->{3317010} = "Brie\-Comte\-Robert";
$areanames{fr}->{3317011} = "Cergy";
$areanames{fr}->{3317012} = "Paris";
$areanames{fr}->{3317013} = "Créteil";
$areanames{fr}->{3317014} = "Enghien\-les\-Bains";
$areanames{fr}->{3317015} = "Nanterre";
$areanames{fr}->{3317016} = "Nanterre";
$areanames{fr}->{3317017} = "Lagny\-sur\-Marne";
$areanames{fr}->{3317018} = "Boulogne\-Billancourt";
$areanames{fr}->{3317019} = "Boulogne\-Billancourt";
$areanames{fr}->{3317028} = "Boulogne\-Billancourt";
$areanames{fr}->{3317030} = "Sarcelles";
$areanames{fr}->{3317031} = "Les\ Mureaux";
$areanames{fr}->{3317032} = "Bobigny";
$areanames{fr}->{3317033} = "Brie\-Comte\-Robert";
$areanames{fr}->{3317034} = "Poissy";
$areanames{fr}->{3317035} = "Coulommiers";
$areanames{fr}->{3317036} = "Paris";
$areanames{fr}->{3317037} = "Paris";
$areanames{fr}->{3317038} = "Paris";
$areanames{fr}->{3317039} = "Paris";
$areanames{fr}->{3317040} = "Le\ Raincy";
$areanames{fr}->{3317041} = "Rambouillet";
$areanames{fr}->{3317042} = "Guyancourt";
$areanames{fr}->{3317043} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3317044} = "Versailles";
$areanames{fr}->{3317045} = "Fontainebleau";
$areanames{fr}->{3317046} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3317047} = "Meaux";
$areanames{fr}->{3317048} = "Nanterre";
$areanames{fr}->{3317049} = "Cergy";
$areanames{fr}->{3317050} = "Bobigny";
$areanames{fr}->{3317051} = "Les\ Mureaux";
$areanames{fr}->{3317052} = "Paris";
$areanames{fr}->{3317053} = "Rambouillet";
$areanames{fr}->{3317054} = "Brie\-Comte\-Robert";
$areanames{fr}->{3317055} = "Massy";
$areanames{fr}->{3317056} = "Massy";
$areanames{fr}->{3317057} = "Sarcelles";
$areanames{fr}->{3317058} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3317059} = "Bobigny";
$areanames{fr}->{331706} = "Paris";
$areanames{fr}->{3317062} = "Arpajon";
$areanames{fr}->{3317068} = "Boulogne\-Billancourt";
$areanames{fr}->{3317070} = "Paris";
$areanames{fr}->{3317071} = "Paris";
$areanames{fr}->{3317072} = "Nanterre";
$areanames{fr}->{3317073} = "Nanterre";
$areanames{fr}->{3317074} = "Boulogne\-Billancourt";
$areanames{fr}->{3317075} = "Paris";
$areanames{fr}->{3317076} = "Le\ Raincy";
$areanames{fr}->{3317077} = "Lagny\-sur\-Marne";
$areanames{fr}->{3317078} = "Nanterre";
$areanames{fr}->{3317079} = "Paris";
$areanames{fr}->{3317080} = "Paris";
$areanames{fr}->{3317081} = "Paris";
$areanames{fr}->{3317082} = "Nanterre";
$areanames{fr}->{3317083} = "Boulogne\-Billancourt";
$areanames{fr}->{3317084} = "Massy";
$areanames{fr}->{3317085} = "Lagny\-sur\-Marne";
$areanames{fr}->{3317086} = "Le\ Raincy";
$areanames{fr}->{3317087} = "Corbeil\-Essonnes";
$areanames{fr}->{3317088} = "Les\ Mureaux";
$areanames{fr}->{3317089} = "Tournan\-en\-Brie";
$areanames{fr}->{3317090} = "Paris";
$areanames{fr}->{3317091} = "Paris";
$areanames{fr}->{3317092} = "Nanterre";
$areanames{fr}->{3317093} = "Bobigny";
$areanames{fr}->{3317094} = "Nanterre";
$areanames{fr}->{3317095} = "Boulogne\-Billancourt";
$areanames{fr}->{3317096} = "Nanterre";
$areanames{fr}->{3317097} = "Créteil";
$areanames{fr}->{3317098} = "Paris";
$areanames{fr}->{3317099} = "Paris";
$areanames{fr}->{331710} = "Nanterre";
$areanames{fr}->{3317117} = "Boulogne\-Billancourt";
$areanames{fr}->{3317118} = "Paris";
$areanames{fr}->{3317119} = "Paris";
$areanames{fr}->{331712} = "Paris";
$areanames{fr}->{3317122} = "Boulogne\-Billancourt";
$areanames{fr}->{3317123} = "Nanterre";
$areanames{fr}->{3317129} = "Bobigny";
$areanames{fr}->{3317130} = "Tournan\-en\-Brie";
$areanames{fr}->{3317131} = "Tournan\-en\-Brie";
$areanames{fr}->{3317132} = "Paris";
$areanames{fr}->{3317133} = "Créteil";
$areanames{fr}->{3317134} = "Boissy\-Saint\-Léger";
$areanames{fr}->{3317135} = "Boulogne\-Billancourt";
$areanames{fr}->{3317136} = "Créteil";
$areanames{fr}->{3317137} = "Paris";
$areanames{fr}->{3317138} = "Paris";
$areanames{fr}->{3317139} = "Paris";
$areanames{fr}->{3317140} = "Lagny\-sur\-Marne";
$areanames{fr}->{3317141} = "Versailles";
$areanames{fr}->{3317142} = "Versailles";
$areanames{fr}->{3317143} = "Mantes\-la\-Jolie";
$areanames{fr}->{3317144} = "Versailles";
$areanames{fr}->{3317145} = "Versailles";
$areanames{fr}->{3317146} = "Mantes\-la\-Jolie";
$areanames{fr}->{3317147} = "Versailles";
$areanames{fr}->{3317148} = "Mantes\-la\-Jolie";
$areanames{fr}->{3317149} = "Guyancourt";
$areanames{fr}->{3317150} = "Paris";
$areanames{fr}->{3317151} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3317152} = "Poissy";
$areanames{fr}->{3317153} = "Nanterre";
$areanames{fr}->{3317154} = "Boulogne\-Billancourt";
$areanames{fr}->{3317155} = "Tournan\-en\-Brie";
$areanames{fr}->{3317156} = "Créteil";
$areanames{fr}->{3317157} = "Boissy\-Saint\-Léger";
$areanames{fr}->{3317158} = "Lagny\-sur\-Marne";
$areanames{fr}->{3317159} = "Versailles";
$areanames{fr}->{3317160} = "Paris";
$areanames{fr}->{3317161} = "Mantes\-la\-Jolie";
$areanames{fr}->{3317162} = "Corbeil\-Essonnes";
$areanames{fr}->{3317163} = "Corbeil\-Essonnes";
$areanames{fr}->{3317164} = "Guyancourt";
$areanames{fr}->{3317165} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3317166} = "Cergy";
$areanames{fr}->{3317167} = "Enghien\-les\-Bains";
$areanames{fr}->{3317168} = "Enghien\-les\-Bains";
$areanames{fr}->{3317169} = "Sarcelles";
$areanames{fr}->{331717} = "Paris";
$areanames{fr}->{3317174} = "Poissy";
$areanames{fr}->{3317177} = "Nanterre";
$areanames{fr}->{3317178} = "Corbeil\-Essonnes";
$areanames{fr}->{3317179} = "Cergy";
$areanames{fr}->{331718} = "Le\ Raincy";
$areanames{fr}->{3317186} = "Bobigny";
$areanames{fr}->{3317187} = "Sarcelles";
$areanames{fr}->{3317189} = "Bobigny";
$areanames{fr}->{331719} = "Paris";
$areanames{fr}->{3317190} = "Nanterre";
$areanames{fr}->{3317191} = "Nanterre";
$areanames{fr}->{3317192} = "Bobigny";
$areanames{fr}->{3317200} = "Cergy";
$areanames{fr}->{3317201} = "Enghien\-les\-Bains";
$areanames{fr}->{3317202} = "Sarcelles";
$areanames{fr}->{3317203} = "Bobigny";
$areanames{fr}->{3317204} = "Créteil";
$areanames{fr}->{3317205} = "Boissy\-Saint\-Léger";
$areanames{fr}->{3317206} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3317207} = "Corbeil\-Essonnes";
$areanames{fr}->{3317208} = "Brie\-Comte\-Robert";
$areanames{fr}->{3317209} = "Bobigny";
$areanames{fr}->{3317210} = "Versailles";
$areanames{fr}->{3317211} = "Guyancourt";
$areanames{fr}->{3317212} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3317213} = "Poissy";
$areanames{fr}->{3317214} = "Mantes\-la\-Jolie";
$areanames{fr}->{3317215} = "Rambouillet";
$areanames{fr}->{3317216} = "Arpajon";
$areanames{fr}->{3317217} = "Melun";
$areanames{fr}->{3317218} = "Tournan\-en\-Brie";
$areanames{fr}->{3317219} = "Meaux";
$areanames{fr}->{3317220} = "Coulommiers";
$areanames{fr}->{3317221} = "Provins";
$areanames{fr}->{3317222} = "Fontainebleau";
$areanames{fr}->{3317223} = "Beaumont\-sur\-Oise";
$areanames{fr}->{3317224} = "Versailles";
$areanames{fr}->{3317225} = "Nanterre";
$areanames{fr}->{3317226} = "Nanterre";
$areanames{fr}->{3317227} = "Nanterre";
$areanames{fr}->{3317228} = "Nanterre";
$areanames{fr}->{3317229} = "Boulogne\-Billancourt";
$areanames{fr}->{3317234} = "Paris";
$areanames{fr}->{3317240} = "Bobigny";
$areanames{fr}->{3317241} = "Nanterre";
$areanames{fr}->{3317242} = "Nanterre";
$areanames{fr}->{3317243} = "Créteil";
$areanames{fr}->{3317244} = "Boulogne\-Billancourt";
$areanames{fr}->{3317245} = "Créteil";
$areanames{fr}->{3317246} = "Créteil";
$areanames{fr}->{3317247} = "Boulogne\-Billancourt";
$areanames{fr}->{3317248} = "Massy";
$areanames{fr}->{3317249} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3317250} = "Boissy\-Saint\-Léger";
$areanames{fr}->{3317251} = "Le\ Raincy";
$areanames{fr}->{3317252} = "Sarcelles";
$areanames{fr}->{3317253} = "Enghien\-les\-Bains";
$areanames{fr}->{3317254} = "Poissy";
$areanames{fr}->{3317255} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3317256} = "Guyancourt";
$areanames{fr}->{3317257} = "Boulogne\-Billancourt";
$areanames{fr}->{3317258} = "Cergy";
$areanames{fr}->{3317259} = "Bobigny";
$areanames{fr}->{3317260} = "Paris";
$areanames{fr}->{3317261} = "Nanterre";
$areanames{fr}->{3317262} = "Brie\-Comte\-Robert";
$areanames{fr}->{3317263} = "Paris";
$areanames{fr}->{3317264} = "Bobigny";
$areanames{fr}->{3317265} = "Bobigny";
$areanames{fr}->{3317266} = "Fontainebleau";
$areanames{fr}->{3317267} = "Guyancourt";
$areanames{fr}->{3317268} = "Paris";
$areanames{fr}->{3317269} = "Paris";
$areanames{fr}->{331727} = "Paris";
$areanames{fr}->{3317270} = "Créteil";
$areanames{fr}->{3317277} = "Bobigny";
$areanames{fr}->{3317278} = "Versailles";
$areanames{fr}->{3317279} = "Fontainebleau";
$areanames{fr}->{3317280} = "Bobigny";
$areanames{fr}->{3317281} = "Versailles";
$areanames{fr}->{3317282} = "Guyancourt";
$areanames{fr}->{3317283} = "Melun";
$areanames{fr}->{3317284} = "Lagny\-sur\-Marne";
$areanames{fr}->{3317285} = "Cergy";
$areanames{fr}->{3317286} = "Massy";
$areanames{fr}->{3317287} = "Guyancourt";
$areanames{fr}->{3317288} = "Le\ Raincy";
$areanames{fr}->{3317289} = "Nanterre";
$areanames{fr}->{3317290} = "Boulogne\-Billancourt";
$areanames{fr}->{3317291} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3317292} = "Nanterre";
$areanames{fr}->{3317293} = "Bobigny";
$areanames{fr}->{3317294} = "Créteil";
$areanames{fr}->{3317295} = "Paris";
$areanames{fr}->{3317296} = "Lagny\-sur\-Marne";
$areanames{fr}->{3317297} = "Guyancourt";
$areanames{fr}->{3317298} = "Paris";
$areanames{fr}->{3317299} = "Lagny\-sur\-Marne";
$areanames{fr}->{3317300} = "Paris";
$areanames{fr}->{3317301} = "Paris";
$areanames{fr}->{3317302} = "Paris";
$areanames{fr}->{3317303} = "Paris";
$areanames{fr}->{3317304} = "Paris";
$areanames{fr}->{3317305} = "Brie\-Comte\-Robert";
$areanames{fr}->{3317306} = "Coulommiers";
$areanames{fr}->{3317307} = "Fontainebleau";
$areanames{fr}->{3317308} = "Lagny\-sur\-Marne";
$areanames{fr}->{3317309} = "Meaux";
$areanames{fr}->{3317310} = "Melun";
$areanames{fr}->{3317311} = "Provins";
$areanames{fr}->{3317312} = "Tournan\-en\-Brie";
$areanames{fr}->{3317313} = "Guyancourt";
$areanames{fr}->{3317314} = "Mantes\-la\-Jolie";
$areanames{fr}->{3317315} = "Les\ Mureaux";
$areanames{fr}->{3317316} = "Poissy";
$areanames{fr}->{3317317} = "Rambouillet";
$areanames{fr}->{3317318} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3317319} = "Versailles";
$areanames{fr}->{3317320} = "Arpajon";
$areanames{fr}->{3317321} = "Corbeil\-Essonnes";
$areanames{fr}->{3317322} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3317323} = "Massy";
$areanames{fr}->{3317324} = "Beaumont\-sur\-Oise";
$areanames{fr}->{3317325} = "Cergy";
$areanames{fr}->{3317326} = "Enghien\-les\-Bains";
$areanames{fr}->{3317327} = "Sarcelles";
$areanames{fr}->{3317328} = "Boulogne\-Billancourt";
$areanames{fr}->{3317329} = "Nanterre";
$areanames{fr}->{3317330} = "Bobigny";
$areanames{fr}->{3317331} = "Le\ Raincy";
$areanames{fr}->{3317332} = "Boissy\-Saint\-Léger";
$areanames{fr}->{3317333} = "Paris";
$areanames{fr}->{3317334} = "Nanterre";
$areanames{fr}->{3317335} = "Boulogne\-Billancourt";
$areanames{fr}->{3317336} = "Guyancourt";
$areanames{fr}->{3317337} = "Massy";
$areanames{fr}->{3317338} = "Lagny\-sur\-Marne";
$areanames{fr}->{3317339} = "Le\ Raincy";
$areanames{fr}->{3317348} = "Boulogne\-Billancourt";
$areanames{fr}->{3317350} = "Paris";
$areanames{fr}->{3317351} = "Melun";
$areanames{fr}->{3317352} = "Melun";
$areanames{fr}->{3317353} = "Le\ Raincy";
$areanames{fr}->{3317354} = "Paris";
$areanames{fr}->{3317355} = "Bobigny";
$areanames{fr}->{3317356} = "Bobigny";
$areanames{fr}->{3317357} = "Bobigny";
$areanames{fr}->{3317358} = "Lagny\-sur\-Marne";
$areanames{fr}->{3317359} = "Brie\-Comte\-Robert";
$areanames{fr}->{3317360} = "Nanterre";
$areanames{fr}->{3317361} = "Poissy";
$areanames{fr}->{3317362} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3317363} = "Nanterre";
$areanames{fr}->{3317364} = "Nanterre";
$areanames{fr}->{3317365} = "Enghien\-les\-Bains";
$areanames{fr}->{3317366} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3317367} = "Paris";
$areanames{fr}->{3317368} = "Paris";
$areanames{fr}->{3317369} = "Brie\-Comte\-Robert";
$areanames{fr}->{331737} = "Paris";
$areanames{fr}->{3317380} = "Coulommiers";
$areanames{fr}->{3317381} = "Fontainebleau";
$areanames{fr}->{3317382} = "Lagny\-sur\-Marne";
$areanames{fr}->{3317383} = "Meaux";
$areanames{fr}->{3317384} = "Melun";
$areanames{fr}->{3317385} = "Provins";
$areanames{fr}->{3317386} = "Tournan\-en\-Brie";
$areanames{fr}->{3317387} = "Guyancourt";
$areanames{fr}->{3317388} = "Mantes\-la\-Jolie";
$areanames{fr}->{3317389} = "Les\ Mureaux";
$areanames{fr}->{3317390} = "Poissy";
$areanames{fr}->{3317391} = "Rambouillet";
$areanames{fr}->{3317392} = "Nanterre";
$areanames{fr}->{3317393} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3317394} = "Versailles";
$areanames{fr}->{3317395} = "Versailles";
$areanames{fr}->{3317396} = "Arpajon";
$areanames{fr}->{3317397} = "Corbeil\-Essonnes";
$areanames{fr}->{3317398} = "Boulogne\-Billancourt";
$areanames{fr}->{3317399} = "Nanterre";
$areanames{fr}->{3317400} = "Enghien\-les\-Bains";
$areanames{fr}->{3317401} = "Boissy\-Saint\-Léger";
$areanames{fr}->{3317402} = "Créteil";
$areanames{fr}->{3317403} = "Enghien\-les\-Bains";
$areanames{fr}->{3317404} = "Sarcelles";
$areanames{fr}->{3317405} = "Corbeil\-Essonnes";
$areanames{fr}->{3317406} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3317407} = "Versailles";
$areanames{fr}->{3317408} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3317409} = "Guyancourt";
$areanames{fr}->{3317413} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3317420} = "Bobigny";
$areanames{fr}->{3317421} = "Bobigny";
$areanames{fr}->{3317422} = "Créteil";
$areanames{fr}->{3317423} = "Bobigny";
$areanames{fr}->{3317424} = "Le\ Raincy";
$areanames{fr}->{3317425} = "Le\ Raincy";
$areanames{fr}->{3317426} = "Le\ Raincy";
$areanames{fr}->{3317427} = "Boissy\-Saint\-Léger";
$areanames{fr}->{3317428} = "Boissy\-Saint\-Léger";
$areanames{fr}->{3317429} = "Le\ Raincy";
$areanames{fr}->{3317430} = "Paris";
$areanames{fr}->{3317440} = "Bobigny";
$areanames{fr}->{3317441} = "Le\ Raincy";
$areanames{fr}->{3317442} = "Boissy\-Saint\-Léger";
$areanames{fr}->{3317443} = "Créteil";
$areanames{fr}->{3317444} = "Créteil";
$areanames{fr}->{3317445} = "Beaumont\-sur\-Oise";
$areanames{fr}->{3317446} = "Cergy";
$areanames{fr}->{3317447} = "Enghien\-les\-Bains";
$areanames{fr}->{3317448} = "Sarcelles";
$areanames{fr}->{3317449} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3317450} = "Créteil";
$areanames{fr}->{3317451} = "Corbeil\-Essonnes";
$areanames{fr}->{3317452} = "Massy";
$areanames{fr}->{3317453} = "Nanterre";
$areanames{fr}->{3317454} = "Nanterre";
$areanames{fr}->{3317455} = "Nanterre";
$areanames{fr}->{3317456} = "Beaumont\-sur\-Oise";
$areanames{fr}->{3317457} = "Corbeil\-Essonnes";
$areanames{fr}->{3317458} = "Mantes\-la\-Jolie";
$areanames{fr}->{3317459} = "Brie\-Comte\-Robert";
$areanames{fr}->{3317462} = "Boulogne\-Billancourt";
$areanames{fr}->{3317463} = "Levallois\-Perret";
$areanames{fr}->{3317464} = "Paris";
$areanames{fr}->{3317470} = "Nanterre";
$areanames{fr}->{3317471} = "Boulogne\-Billancourt";
$areanames{fr}->{3317472} = "Le\ Raincy";
$areanames{fr}->{3317473} = "Bobigny";
$areanames{fr}->{3317474} = "Boulogne\-Billancourt";
$areanames{fr}->{3317475} = "Massy";
$areanames{fr}->{3317476} = "Meaux";
$areanames{fr}->{3317477} = "Melun";
$areanames{fr}->{3317478} = "Provins";
$areanames{fr}->{3317479} = "Tournan\-en\-Brie";
$areanames{fr}->{3317480} = "Fontainebleau";
$areanames{fr}->{3317481} = "Meaux";
$areanames{fr}->{3317482} = "Melun";
$areanames{fr}->{3317483} = "Guyancourt";
$areanames{fr}->{3317484} = "Mantes\-la\-Jolie";
$areanames{fr}->{3317485} = "Massy";
$areanames{fr}->{3317486} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3317487} = "Corbeil\-Essonnes";
$areanames{fr}->{3317488} = "Bobigny";
$areanames{fr}->{3317489} = "Versailles";
$areanames{fr}->{3317490} = "Paris";
$areanames{fr}->{3317491} = "Arpajon";
$areanames{fr}->{3317492} = "Lagny\-sur\-Marne";
$areanames{fr}->{3317493} = "Sarcelles";
$areanames{fr}->{3317494} = "Corbeil\-Essonnes";
$areanames{fr}->{3317495} = "Paris";
$areanames{fr}->{3317496} = "Bobigny";
$areanames{fr}->{3317497} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3317498} = "Massy";
$areanames{fr}->{3317499} = "Beaumont\-sur\-Oise";
$areanames{fr}->{3317500} = "Paris";
$areanames{fr}->{3317501} = "Beaumont\-sur\-Oise";
$areanames{fr}->{3317502} = "Arpajon";
$areanames{fr}->{3317503} = "Rambouillet";
$areanames{fr}->{3317504} = "Poissy";
$areanames{fr}->{3317505} = "Meaux";
$areanames{fr}->{3317506} = "Brie\-Comte\-Robert";
$areanames{fr}->{3317507} = "Les\ Mureaux";
$areanames{fr}->{3317508} = "Coulommiers";
$areanames{fr}->{3317509} = "Mantes\-la\-Jolie";
$areanames{fr}->{3317510} = "Fontainebleau";
$areanames{fr}->{3317511} = "Tournan\-en\-Brie";
$areanames{fr}->{3317512} = "Provins";
$areanames{fr}->{3317513} = "Brie\-Comte\-Robert";
$areanames{fr}->{3317514} = "Coulommiers";
$areanames{fr}->{3317515} = "Fontainebleau";
$areanames{fr}->{3317516} = "Lagny\-sur\-Marne";
$areanames{fr}->{3317517} = "Meaux";
$areanames{fr}->{3317518} = "Melun";
$areanames{fr}->{3317519} = "Provins";
$areanames{fr}->{3317520} = "Tournan\-en\-Brie";
$areanames{fr}->{3317521} = "Guyancourt";
$areanames{fr}->{3317522} = "Mantes\-la\-Jolie";
$areanames{fr}->{3317523} = "Les\ Mureaux";
$areanames{fr}->{3317524} = "Poissy";
$areanames{fr}->{3317525} = "Rambouillet";
$areanames{fr}->{3317526} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3317527} = "Versailles";
$areanames{fr}->{3317528} = "Arpajon";
$areanames{fr}->{3317529} = "Corbeil\-Essonnes";
$areanames{fr}->{3317530} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3317531} = "Massy";
$areanames{fr}->{3317532} = "Boulogne\-Billancourt";
$areanames{fr}->{3317533} = "Nanterre";
$areanames{fr}->{3317534} = "Bobigny";
$areanames{fr}->{3317535} = "Le\ Raincy";
$areanames{fr}->{3317536} = "Boissy\-Saint\-Léger";
$areanames{fr}->{3317537} = "Créteil";
$areanames{fr}->{3317538} = "Beaumont\-sur\-Oise";
$areanames{fr}->{3317539} = "Cergy";
$areanames{fr}->{3317540} = "Argenteuil";
$areanames{fr}->{3317542} = "Paris";
$areanames{fr}->{3317549} = "Boulogne\-Billancourt";
$areanames{fr}->{3317550} = "Paris";
$areanames{fr}->{3317551} = "Paris";
$areanames{fr}->{3317552} = "Bobigny";
$areanames{fr}->{3317553} = "Boulogne\-Billancourt";
$areanames{fr}->{3317554} = "Nanterre";
$areanames{fr}->{3317555} = "Paris";
$areanames{fr}->{3317556} = "Bobigny";
$areanames{fr}->{3317557} = "Paris";
$areanames{fr}->{3317558} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3317559} = "Arpajon";
$areanames{fr}->{3317560} = "Boulogne\-Billancourt";
$areanames{fr}->{3317561} = "Nanterre";
$areanames{fr}->{3317562} = "Bobigny";
$areanames{fr}->{3317563} = "Le\ Raincy";
$areanames{fr}->{3317564} = "Créteil";
$areanames{fr}->{3317565} = "Boissy\-Saint\-Léger";
$areanames{fr}->{3317566} = "Corbeil\-Essonnes";
$areanames{fr}->{3317567} = "Mantes\-la\-Jolie";
$areanames{fr}->{3317568} = "Enghien\-les\-Bains";
$areanames{fr}->{3317569} = "Sarcelles";
$areanames{fr}->{3317570} = "Beaumont\-sur\-Oise";
$areanames{fr}->{3317571} = "Les\ Mureaux";
$areanames{fr}->{3317572} = "Cergy";
$areanames{fr}->{3317573} = "Lagny\-sur\-Marne";
$areanames{fr}->{3317574} = "Mantes\-la\-Jolie";
$areanames{fr}->{3317575} = "Paris";
$areanames{fr}->{3317576} = "Paris";
$areanames{fr}->{3317577} = "Paris";
$areanames{fr}->{3317578} = "Meaux";
$areanames{fr}->{3317579} = "Melun";
$areanames{fr}->{3317581} = "Cergy";
$areanames{fr}->{3317590} = "Tournan\-en\-Brie";
$areanames{fr}->{3317591} = "Le\ Raincy";
$areanames{fr}->{3317592} = "Rambouillet";
$areanames{fr}->{3317593} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3317594} = "Sarcelles";
$areanames{fr}->{3317595} = "Boulogne\-Billancourt";
$areanames{fr}->{3317596} = "Nanterre";
$areanames{fr}->{3317597} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3317598} = "Tournan\-en\-Brie";
$areanames{fr}->{3317599} = "Coulommiers";
$areanames{fr}->{3317600} = "Paris";
$areanames{fr}->{3317601} = "Les\ Mureaux";
$areanames{fr}->{3317602} = "Poissy";
$areanames{fr}->{3317603} = "Rambouillet";
$areanames{fr}->{3317604} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3317605} = "Versailles";
$areanames{fr}->{3317606} = "Arpajon";
$areanames{fr}->{3317607} = "Corbeil\-Essonnes";
$areanames{fr}->{3317608} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3317609} = "Massy";
$areanames{fr}->{3317610} = "Boulogne\-Billancourt";
$areanames{fr}->{3317611} = "Nanterre";
$areanames{fr}->{3317612} = "Bobigny";
$areanames{fr}->{3317613} = "Le\ Raincy";
$areanames{fr}->{3317614} = "Boissy\-Saint\-Léger";
$areanames{fr}->{3317615} = "Créteil";
$areanames{fr}->{3317616} = "Beaumont\-sur\-Oise";
$areanames{fr}->{3317617} = "Cergy";
$areanames{fr}->{3317618} = "Enghien\-les\-Bains";
$areanames{fr}->{3317619} = "Sarcelles";
$areanames{fr}->{3317620} = "Boulogne\-Billancourt";
$areanames{fr}->{3317621} = "Paris";
$areanames{fr}->{3317622} = "Le\ Raincy";
$areanames{fr}->{3317623} = "Nanterre";
$areanames{fr}->{3317624} = "Paris";
$areanames{fr}->{3317625} = "Paris";
$areanames{fr}->{3317626} = "Paris";
$areanames{fr}->{3317627} = "Nanterre";
$areanames{fr}->{3317628} = "Créteil";
$areanames{fr}->{3317629} = "Enghien\-les\-Bains";
$areanames{fr}->{3317630} = "Boissy\-Saint\-Léger";
$areanames{fr}->{3317631} = "Corbeil\-Essonnes";
$areanames{fr}->{3317632} = "Paris";
$areanames{fr}->{3317633} = "Guyancourt";
$areanames{fr}->{3317634} = "Meaux";
$areanames{fr}->{3317635} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3317636} = "Bobigny";
$areanames{fr}->{3317637} = "Paris";
$areanames{fr}->{3317638} = "Versailles";
$areanames{fr}->{3317639} = "Cergy";
$areanames{fr}->{3317640} = "Nanterre";
$areanames{fr}->{3317641} = "Le\ Raincy";
$areanames{fr}->{3317642} = "Sarcelles";
$areanames{fr}->{3317643} = "Boulogne\-Billancourt";
$areanames{fr}->{3317644} = "Enghien\-les\-Bains";
$areanames{fr}->{3317645} = "Paris";
$areanames{fr}->{3317646} = "Créteil";
$areanames{fr}->{3317647} = "Nanterre";
$areanames{fr}->{3317648} = "Paris";
$areanames{fr}->{3317649} = "Paris";
$areanames{fr}->{3317650} = "Paris";
$areanames{fr}->{3317652} = "Guyancourt";
$areanames{fr}->{3317653} = "Paris";
$areanames{fr}->{3317654} = "Nanterre";
$areanames{fr}->{3317655} = "Meaux";
$areanames{fr}->{3317656} = "Paris";
$areanames{fr}->{3317657} = "Créteil";
$areanames{fr}->{3317658} = "Bobigny";
$areanames{fr}->{3317659} = "Brie\-Comte\-Robert";
$areanames{fr}->{331766} = "Paris";
$areanames{fr}->{3317661} = "Boulogne\-Billancourt";
$areanames{fr}->{3317666} = "Nanterre";
$areanames{fr}->{3317669} = "Nanterre";
$areanames{fr}->{331767} = "Paris";
$areanames{fr}->{3317678} = "Guyancourt";
$areanames{fr}->{3317679} = "Mantes\-la\-Jolie";
$areanames{fr}->{3317680} = "Boulogne\-Billancourt";
$areanames{fr}->{3317681} = "Cergy";
$areanames{fr}->{3317682} = "Les\ Mureaux";
$areanames{fr}->{3317683} = "Arpajon";
$areanames{fr}->{3317684} = "Boulogne\-Billancourt";
$areanames{fr}->{3317685} = "Nanterre";
$areanames{fr}->{3317686} = "Guyancourt";
$areanames{fr}->{3317687} = "Guyancourt";
$areanames{fr}->{3317688} = "Guyancourt";
$areanames{fr}->{3317689} = "Boulogne\-Billancourt";
$areanames{fr}->{3317690} = "Paris";
$areanames{fr}->{3317691} = "Massy";
$areanames{fr}->{3317692} = "Coulommiers";
$areanames{fr}->{3317693} = "Fontainebleau";
$areanames{fr}->{3317694} = "Lagny\-sur\-Marne";
$areanames{fr}->{3317695} = "Cergy";
$areanames{fr}->{3317696} = "Melun";
$areanames{fr}->{3317697} = "Provins";
$areanames{fr}->{3317698} = "Tournan\-en\-Brie";
$areanames{fr}->{3317699} = "Guyancourt";
$areanames{fr}->{3317702} = "Argenteuil";
$areanames{fr}->{331771} = "Paris";
$areanames{fr}->{3317720} = "Créteil";
$areanames{fr}->{3317721} = "Créteil";
$areanames{fr}->{3317722} = "Créteil";
$areanames{fr}->{3317723} = "Créteil";
$areanames{fr}->{3317724} = "Boulogne\-Billancourt";
$areanames{fr}->{3317725} = "Boulogne\-Billancourt";
$areanames{fr}->{3317726} = "Boulogne\-Billancourt";
$areanames{fr}->{3317727} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3317728} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3317729} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3317730} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3317731} = "Massy";
$areanames{fr}->{3317732} = "Paris";
$areanames{fr}->{3317733} = "Cergy";
$areanames{fr}->{3317734} = "Arpajon";
$areanames{fr}->{3317735} = "Meaux";
$areanames{fr}->{3317736} = "Versailles";
$areanames{fr}->{3317737} = "Corbeil\-Essonnes";
$areanames{fr}->{3317738} = "Boulogne\-Billancourt";
$areanames{fr}->{3317739} = "Bobigny";
$areanames{fr}->{331774} = "Paris";
$areanames{fr}->{3317741} = "Bobigny";
$areanames{fr}->{3317746} = "Boulogne\-Billancourt";
$areanames{fr}->{3317747} = "Créteil";
$areanames{fr}->{3317749} = "Nanterre";
$areanames{fr}->{3317750} = "Enghien\-les\-Bains";
$areanames{fr}->{3317751} = "Nanterre";
$areanames{fr}->{3317752} = "Mantes\-la\-Jolie";
$areanames{fr}->{3317753} = "Les\ Mureaux";
$areanames{fr}->{3317754} = "Poissy";
$areanames{fr}->{3317755} = "Rambouillet";
$areanames{fr}->{3317756} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3317757} = "Arpajon";
$areanames{fr}->{3317758} = "Corbeil\-Essonnes";
$areanames{fr}->{3317759} = "Fontainebleau";
$areanames{fr}->{3317760} = "Bobigny";
$areanames{fr}->{3317761} = "Boissy\-Saint\-Léger";
$areanames{fr}->{3317762} = "Beaumont\-sur\-Oise";
$areanames{fr}->{3317763} = "Cergy";
$areanames{fr}->{3317764} = "Paris";
$areanames{fr}->{3317765} = "Sarcelles";
$areanames{fr}->{3317766} = "Enghien\-les\-Bains";
$areanames{fr}->{3317767} = "Créteil";
$areanames{fr}->{3317768} = "Nanterre";
$areanames{fr}->{3317769} = "Nanterre";
$areanames{fr}->{3317770} = "Boulogne\-Billancourt";
$areanames{fr}->{3317771} = "Versailles";
$areanames{fr}->{3317772} = "Paris";
$areanames{fr}->{3317773} = "Nanterre";
$areanames{fr}->{3317774} = "Créteil";
$areanames{fr}->{3317775} = "Paris";
$areanames{fr}->{3317776} = "Le\ Raincy";
$areanames{fr}->{3317777} = "Melun";
$areanames{fr}->{3317778} = "Versailles";
$areanames{fr}->{3317779} = "Boissy\-Saint\-Léger";
$areanames{fr}->{3317780} = "Sarcelles";
$areanames{fr}->{3317781} = "Boissy\-Saint\-Léger";
$areanames{fr}->{3317782} = "Lagny\-sur\-Marne";
$areanames{fr}->{3317783} = "Melun";
$areanames{fr}->{3317784} = "Melun";
$areanames{fr}->{3317785} = "Créteil";
$areanames{fr}->{3317786} = "Boulogne\-Billancourt";
$areanames{fr}->{3317787} = "Boulogne\-Billancourt";
$areanames{fr}->{3317788} = "Nanterre";
$areanames{fr}->{3317789} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3317790} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3317791} = "Corbeil\-Essonnes";
$areanames{fr}->{3317792} = "Boulogne\-Billancourt";
$areanames{fr}->{3317793} = "Bobigny";
$areanames{fr}->{3317794} = "Créteil";
$areanames{fr}->{3317795} = "Cergy";
$areanames{fr}->{3317796} = "Massy";
$areanames{fr}->{3317797} = "Corbeil\-Essonnes";
$areanames{fr}->{3317798} = "Bobigny";
$areanames{fr}->{3317799} = "Créteil";
$areanames{fr}->{3317800} = "Meaux";
$areanames{fr}->{3317801} = "Paris";
$areanames{fr}->{3317802} = "Paris";
$areanames{fr}->{3317803} = "Paris";
$areanames{fr}->{3317804} = "Tournan\-en\-Brie";
$areanames{fr}->{3317805} = "Corbeil\-Essonnes";
$areanames{fr}->{3317806} = "Enghien\-les\-Bains";
$areanames{fr}->{3317807} = "Le\ Raincy";
$areanames{fr}->{3317808} = "Bobigny";
$areanames{fr}->{3317809} = "Paris";
$areanames{fr}->{3317810} = "Paris";
$areanames{fr}->{3317811} = "Paris";
$areanames{fr}->{3317812} = "Créteil";
$areanames{fr}->{3317813} = "Créteil";
$areanames{fr}->{3317814} = "Nanterre";
$areanames{fr}->{3317815} = "Nanterre";
$areanames{fr}->{3317816} = "Boulogne\-Billancourt";
$areanames{fr}->{3317817} = "Enghien\-les\-Bains";
$areanames{fr}->{3317818} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3317819} = "Massy";
$areanames{fr}->{3317820} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3317821} = "Guyancourt";
$areanames{fr}->{3317822} = "Versailles";
$areanames{fr}->{3317823} = "Poissy";
$areanames{fr}->{3317824} = "Mantes\-la\-Jolie";
$areanames{fr}->{3317825} = "Boulogne\-Billancourt";
$areanames{fr}->{3317826} = "Nanterre";
$areanames{fr}->{3317827} = "Bobigny";
$areanames{fr}->{3317828} = "Créteil";
$areanames{fr}->{3317829} = "Créteil";
$areanames{fr}->{3317830} = "Enghien\-les\-Bains";
$areanames{fr}->{3317831} = "Cergy";
$areanames{fr}->{3317832} = "Sarcelles";
$areanames{fr}->{3317833} = "Paris";
$areanames{fr}->{3317834} = "Paris";
$areanames{fr}->{3317835} = "Le\ Raincy";
$areanames{fr}->{3317836} = "Corbeil\-Essonnes";
$areanames{fr}->{3317837} = "Lagny\-sur\-Marne";
$areanames{fr}->{3317838} = "Guyancourt";
$areanames{fr}->{3317839} = "Versailles";
$areanames{fr}->{3317840} = "Paris";
$areanames{fr}->{3317841} = "Paris";
$areanames{fr}->{3317842} = "Paris";
$areanames{fr}->{3317843} = "Cergy";
$areanames{fr}->{3317844} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3317845} = "Bobigny";
$areanames{fr}->{3317846} = "Boulogne\-Billancourt";
$areanames{fr}->{3317847} = "Cergy";
$areanames{fr}->{3317848} = "Brie\-Comte\-Robert";
$areanames{fr}->{3317849} = "Melun";
$areanames{fr}->{3317852} = "Versailles";
$areanames{fr}->{3317853} = "Asnières\-sur\-Seine";
$areanames{fr}->{3317854} = "Créteil";
$areanames{fr}->{3317860} = "Arpajon";
$areanames{fr}->{3317861} = "Corbeil\-Essonnes";
$areanames{fr}->{3317862} = "Lagny\-sur\-Marne";
$areanames{fr}->{3317863} = "Poissy";
$areanames{fr}->{3317864} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3317865} = "Arpajon";
$areanames{fr}->{3317866} = "Nanterre";
$areanames{fr}->{3317867} = "Paris";
$areanames{fr}->{3317868} = "Créteil";
$areanames{fr}->{3317869} = "Beaumont\-sur\-Oise";
$areanames{fr}->{3317870} = "Enghien\-les\-Bains";
$areanames{fr}->{3317871} = "Meaux";
$areanames{fr}->{3317872} = "Mantes\-la\-Jolie";
$areanames{fr}->{3317873} = "Les\ Mureaux";
$areanames{fr}->{3317874} = "Versailles";
$areanames{fr}->{3317875} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3317876} = "Boulogne\-Billancourt";
$areanames{fr}->{3317877} = "Le\ Raincy";
$areanames{fr}->{3317878} = "Le\ Raincy";
$areanames{fr}->{3317879} = "Provins";
$areanames{fr}->{3317880} = "Les\ Mureaux";
$areanames{fr}->{3317881} = "Nanterre";
$areanames{fr}->{3317882} = "Rambouillet";
$areanames{fr}->{3317883} = "Arpajon";
$areanames{fr}->{3317884} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3317885} = "Massy";
$areanames{fr}->{3317886} = "Beaumont\-sur\-Oise";
$areanames{fr}->{3317887} = "Bobigny";
$areanames{fr}->{3317888} = "Boissy\-Saint\-Léger";
$areanames{fr}->{3317889} = "Boulogne\-Billancourt";
$areanames{fr}->{3317890} = "Paris";
$areanames{fr}->{3317891} = "Paris";
$areanames{fr}->{3317892} = "Boulogne\-Billancourt";
$areanames{fr}->{3317893} = "Enghien\-les\-Bains";
$areanames{fr}->{3317894} = "Paris";
$areanames{fr}->{3317895} = "Paris";
$areanames{fr}->{3317896} = "Paris";
$areanames{fr}->{3317897} = "Rambouillet";
$areanames{fr}->{3317898} = "Nanterre";
$areanames{fr}->{3317899} = "Nanterre";
$areanames{fr}->{3317900} = "Arpajon";
$areanames{fr}->{3317901} = "Brie\-Comte\-Robert";
$areanames{fr}->{3317902} = "Arpajon";
$areanames{fr}->{3317903} = "Beaumont\-sur\-Oise";
$areanames{fr}->{3317904} = "Bobigny";
$areanames{fr}->{3317905} = "Boissy\-Saint\-Léger";
$areanames{fr}->{3317906} = "Boulogne\-Billancourt";
$areanames{fr}->{3317907} = "Brie\-Comte\-Robert";
$areanames{fr}->{3317908} = "Cergy";
$areanames{fr}->{3317909} = "Provins";
$areanames{fr}->{3317910} = "Corbeil\-Essonnes";
$areanames{fr}->{3317911} = "Créteil";
$areanames{fr}->{3317912} = "Enghien\-les\-Bains";
$areanames{fr}->{3317913} = "Fontainebleau";
$areanames{fr}->{3317914} = "Guyancourt";
$areanames{fr}->{3317915} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3317916} = "Lagny\-sur\-Marne";
$areanames{fr}->{3317917} = "Le\ Raincy";
$areanames{fr}->{3317918} = "Les\ Mureaux";
$areanames{fr}->{3317919} = "Fontainebleau";
$areanames{fr}->{3317920} = "Mantes\-la\-Jolie";
$areanames{fr}->{3317921} = "Massy";
$areanames{fr}->{3317922} = "Meaux";
$areanames{fr}->{3317923} = "Melun";
$areanames{fr}->{3317924} = "Nanterre";
$areanames{fr}->{3317925} = "Paris";
$areanames{fr}->{3317926} = "Poissy";
$areanames{fr}->{3317927} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3317928} = "Sarcelles";
$areanames{fr}->{3317929} = "Versailles";
$areanames{fr}->{3317930} = "Rueil\-Malmaison";
$areanames{fr}->{3317940} = "Boissy\-Saint\-Léger";
$areanames{fr}->{3317941} = "Boulogne\-Billancourt";
$areanames{fr}->{3317942} = "Cergy";
$areanames{fr}->{3317943} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3317944} = "Beaumont\-sur\-Oise";
$areanames{fr}->{3317945} = "Meaux";
$areanames{fr}->{3317946} = "Boulogne\-Billancourt";
$areanames{fr}->{3317947} = "Corbeil\-Essonnes";
$areanames{fr}->{3317948} = "Coulommiers";
$areanames{fr}->{3317949} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3317951} = "Argenteuil";
$areanames{fr}->{3317956} = "Créteil";
$areanames{fr}->{3317960} = "Créteil";
$areanames{fr}->{3317961} = "Créteil";
$areanames{fr}->{3317962} = "Nanterre";
$areanames{fr}->{3317963} = "Bobigny";
$areanames{fr}->{3317964} = "Bobigny";
$areanames{fr}->{3317965} = "Sarcelles";
$areanames{fr}->{3317966} = "Cergy";
$areanames{fr}->{3317967} = "Les\ Mureaux";
$areanames{fr}->{3317968} = "Boissy\-Saint\-Léger";
$areanames{fr}->{3317969} = "Mantes\-la\-Jolie";
$areanames{fr}->{3317970} = "Nanterre";
$areanames{fr}->{3317971} = "Boulogne\-Billancourt";
$areanames{fr}->{3317972} = "Nanterre";
$areanames{fr}->{3317973} = "Boulogne\-Billancourt";
$areanames{fr}->{3317974} = "Brie\-Comte\-Robert";
$areanames{fr}->{3317975} = "Paris";
$areanames{fr}->{3317976} = "Melun";
$areanames{fr}->{3317977} = "Coulommiers";
$areanames{fr}->{3317978} = "Lagny\-sur\-Marne";
$areanames{fr}->{3317979} = "Meaux";
$areanames{fr}->{3317980} = "Tournan\-en\-Brie";
$areanames{fr}->{3317981} = "Cergy";
$areanames{fr}->{3317982} = "Corbeil\-Essonnes";
$areanames{fr}->{3317983} = "Coulommiers";
$areanames{fr}->{3317984} = "Créteil";
$areanames{fr}->{3317985} = "Paris";
$areanames{fr}->{3317986} = "Créteil";
$areanames{fr}->{3317987} = "Enghien\-les\-Bains";
$areanames{fr}->{3317988} = "Corbeil\-Essonnes";
$areanames{fr}->{3317989} = "Guyancourt";
$areanames{fr}->{3317990} = "Le\ Raincy";
$areanames{fr}->{3317991} = "Fontainebleau";
$areanames{fr}->{3317992} = "Guyancourt";
$areanames{fr}->{3317993} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3317994} = "Lagny\-sur\-Marne";
$areanames{fr}->{3317995} = "Le\ Raincy";
$areanames{fr}->{3317996} = "Les\ Mureaux";
$areanames{fr}->{3317997} = "Paris";
$areanames{fr}->{3317998} = "Mantes\-la\-Jolie";
$areanames{fr}->{3317999} = "Paris";
$areanames{fr}->{3318000} = "Massy";
$areanames{fr}->{3318001} = "Meaux";
$areanames{fr}->{3318002} = "Melun";
$areanames{fr}->{3318003} = "Nanterre";
$areanames{fr}->{3318004} = "Nanterre";
$areanames{fr}->{3318005} = "Paris";
$areanames{fr}->{3318006} = "Paris";
$areanames{fr}->{3318007} = "Poissy";
$areanames{fr}->{3318008} = "Provins";
$areanames{fr}->{3318009} = "Rambouillet";
$areanames{fr}->{3318010} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3318011} = "Sarcelles";
$areanames{fr}->{3318012} = "Tournan\-en\-Brie";
$areanames{fr}->{3318013} = "Versailles";
$areanames{fr}->{3318014} = "Paris";
$areanames{fr}->{3318015} = "Arpajon";
$areanames{fr}->{3318016} = "Créteil";
$areanames{fr}->{3318017} = "Le\ Raincy";
$areanames{fr}->{3318018} = "Paris";
$areanames{fr}->{3318019} = "Sarcelles";
$areanames{fr}->{3318020} = "Paris";
$areanames{fr}->{3318021} = "Nanterre";
$areanames{fr}->{3318022} = "Boulogne\-Billancourt";
$areanames{fr}->{3318023} = "Bobigny";
$areanames{fr}->{3318024} = "Le\ Raincy";
$areanames{fr}->{3318025} = "Créteil";
$areanames{fr}->{3318026} = "Boissy\-Saint\-Léger";
$areanames{fr}->{3318027} = "Paris";
$areanames{fr}->{3318028} = "Guyancourt";
$areanames{fr}->{3318029} = "Guyancourt";
$areanames{fr}->{3318030} = "Nanterre";
$areanames{fr}->{3318031} = "Massy";
$areanames{fr}->{3318032} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3318033} = "Corbeil\-Essonnes";
$areanames{fr}->{3318034} = "Cergy";
$areanames{fr}->{3318035} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3318036} = "Arpajon";
$areanames{fr}->{3318037} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3318038} = "Massy";
$areanames{fr}->{3318039} = "Melun";
$areanames{fr}->{3318040} = "Paris";
$areanames{fr}->{3318041} = "Boulogne\-Billancourt";
$areanames{fr}->{3318042} = "Nanterre";
$areanames{fr}->{3318043} = "Bobigny";
$areanames{fr}->{3318044} = "Le\ Raincy";
$areanames{fr}->{3318045} = "Créteil";
$areanames{fr}->{3318046} = "Nanterre";
$areanames{fr}->{3318047} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3318048} = "Paris";
$areanames{fr}->{3318049} = "Paris";
$areanames{fr}->{3318050} = "Paris";
$areanames{fr}->{3318051} = "Créteil";
$areanames{fr}->{3318052} = "Paris";
$areanames{fr}->{3318053} = "Paris";
$areanames{fr}->{3318054} = "Paris";
$areanames{fr}->{3318055} = "Guyancourt";
$areanames{fr}->{3318056} = "Massy";
$areanames{fr}->{3318057} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3318058} = "Corbeil\-Essonnes";
$areanames{fr}->{3318059} = "Cergy";
$areanames{fr}->{3318060} = "Bobigny";
$areanames{fr}->{3318061} = "Guyancourt";
$areanames{fr}->{3318062} = "Le\ Raincy";
$areanames{fr}->{3318063} = "Brie\-Comte\-Robert";
$areanames{fr}->{3318064} = "Coulommiers";
$areanames{fr}->{3318065} = "Fontainebleau";
$areanames{fr}->{3318066} = "Lagny\-sur\-Marne";
$areanames{fr}->{3318067} = "Meaux";
$areanames{fr}->{3318068} = "Melun";
$areanames{fr}->{3318069} = "Provins";
$areanames{fr}->{3318070} = "Tournan\-en\-Brie";
$areanames{fr}->{3318071} = "Guyancourt";
$areanames{fr}->{3318072} = "Mantes\-la\-Jolie";
$areanames{fr}->{3318073} = "Boulogne\-Billancourt";
$areanames{fr}->{3318074} = "Arpajon";
$areanames{fr}->{3318075} = "Massy";
$areanames{fr}->{3318076} = "Rambouillet";
$areanames{fr}->{3318077} = "Versailles";
$areanames{fr}->{3318078} = "Guyancourt";
$areanames{fr}->{3318079} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3318080} = "Boulogne\-Billancourt";
$areanames{fr}->{3318081} = "Lagny\-sur\-Marne";
$areanames{fr}->{3318082} = "Guyancourt";
$areanames{fr}->{3318083} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3318084} = "Versailles";
$areanames{fr}->{3318085} = "Corbeil\-Essonnes";
$areanames{fr}->{3318086} = "Massy";
$areanames{fr}->{3318087} = "Boulogne\-Billancourt";
$areanames{fr}->{3318088} = "Nanterre";
$areanames{fr}->{3318089} = "Bobigny";
$areanames{fr}->{3318090} = "Le\ Raincy";
$areanames{fr}->{3318091} = "Créteil";
$areanames{fr}->{3318092} = "Cergy";
$areanames{fr}->{3318093} = "Boulogne\-Billancourt";
$areanames{fr}->{3318094} = "Paris";
$areanames{fr}->{3318095} = "Paris";
$areanames{fr}->{3318096} = "Paris";
$areanames{fr}->{3318097} = "Paris";
$areanames{fr}->{3318098} = "Paris";
$areanames{fr}->{3318099} = "Les\ Mureaux";
$areanames{fr}->{3318100} = "Guyancourt";
$areanames{fr}->{3318101} = "Mantes\-la\-Jolie";
$areanames{fr}->{3318102} = "Les\ Mureaux";
$areanames{fr}->{3318103} = "Poissy";
$areanames{fr}->{3318104} = "Rambouillet";
$areanames{fr}->{3318105} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3318106} = "Arpajon";
$areanames{fr}->{3318107} = "Corbeil\-Essonnes";
$areanames{fr}->{3318108} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3318109} = "Le\ Raincy";
$areanames{fr}->{3318110} = "Boissy\-Saint\-Léger";
$areanames{fr}->{3318111} = "Beaumont\-sur\-Oise";
$areanames{fr}->{3318112} = "Enghien\-les\-Bains";
$areanames{fr}->{3318113} = "Sarcelles";
$areanames{fr}->{3318114} = "Brie\-Comte\-Robert";
$areanames{fr}->{3318115} = "Coulommiers";
$areanames{fr}->{3318116} = "Lagny\-sur\-Marne";
$areanames{fr}->{3318117} = "Meaux";
$areanames{fr}->{3318118} = "Melun";
$areanames{fr}->{3318119} = "Provins";
$areanames{fr}->{3318120} = "Tournan\-en\-Brie";
$areanames{fr}->{3318121} = "Le\ Raincy";
$areanames{fr}->{3318122} = "Massy";
$areanames{fr}->{3318123} = "Poissy";
$areanames{fr}->{3318124} = "Rambouillet";
$areanames{fr}->{3318125} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3318126} = "Versailles";
$areanames{fr}->{3318127} = "Arpajon";
$areanames{fr}->{3318128} = "Corbeil\-Essonnes";
$areanames{fr}->{3318129} = "Paris";
$areanames{fr}->{3318130} = "Massy";
$areanames{fr}->{3318131} = "Beaumont\-sur\-Oise";
$areanames{fr}->{3318132} = "Cergy";
$areanames{fr}->{3318133} = "Enghien\-les\-Bains";
$areanames{fr}->{3318134} = "Sarcelles";
$areanames{fr}->{3318135} = "Melun";
$areanames{fr}->{3318136} = "Provins";
$areanames{fr}->{3318137} = "Tournan\-en\-Brie";
$areanames{fr}->{3318138} = "Guyancourt";
$areanames{fr}->{3318139} = "Mantes\-la\-Jolie";
$areanames{fr}->{3318140} = "Les\ Mureaux";
$areanames{fr}->{3318141} = "Poissy";
$areanames{fr}->{3318142} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3318143} = "Versailles";
$areanames{fr}->{3318144} = "Arpajon";
$areanames{fr}->{3318145} = "Corbeil\-Essonnes";
$areanames{fr}->{3318146} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3318147} = "Massy";
$areanames{fr}->{3318148} = "Boulogne\-Billancourt";
$areanames{fr}->{3318149} = "Nanterre";
$areanames{fr}->{3318150} = "Paris";
$areanames{fr}->{3318151} = "Paris";
$areanames{fr}->{3318152} = "Boissy\-Saint\-Léger";
$areanames{fr}->{3318153} = "Créteil";
$areanames{fr}->{3318154} = "Beaumont\-sur\-Oise";
$areanames{fr}->{3318155} = "Cergy";
$areanames{fr}->{3318156} = "Enghien\-les\-Bains";
$areanames{fr}->{3318157} = "Sarcelles";
$areanames{fr}->{3318158} = "Brie\-Comte\-Robert";
$areanames{fr}->{3318159} = "Bobigny";
$areanames{fr}->{3318160} = "Le\ Raincy";
$areanames{fr}->{3318161} = "Paris";
$areanames{fr}->{3318162} = "Paris";
$areanames{fr}->{3318163} = "Paris";
$areanames{fr}->{3318164} = "Boulogne\-Billancourt";
$areanames{fr}->{3318165} = "Fontainebleau";
$areanames{fr}->{3318166} = "Lagny\-sur\-Marne";
$areanames{fr}->{3318167} = "Meaux";
$areanames{fr}->{3318168} = "Nanterre";
$areanames{fr}->{3318169} = "Paris";
$areanames{fr}->{3318170} = "Paris";
$areanames{fr}->{3318171} = "Nanterre";
$areanames{fr}->{3318172} = "Paris";
$areanames{fr}->{3318173} = "Meaux";
$areanames{fr}->{3318174} = "Melun";
$areanames{fr}->{3318175} = "Guyancourt";
$areanames{fr}->{3318176} = "Poissy";
$areanames{fr}->{3318177} = "Fontainebleau";
$areanames{fr}->{3318178} = "Versailles";
$areanames{fr}->{3318179} = "Corbeil\-Essonnes";
$areanames{fr}->{3318180} = "Paris";
$areanames{fr}->{3318181} = "Bobigny";
$areanames{fr}->{3318182} = "Rambouillet";
$areanames{fr}->{3318183} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3318184} = "Arpajon";
$areanames{fr}->{3318185} = "Corbeil\-Essonnes";
$areanames{fr}->{3318186} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3318187} = "Massy";
$areanames{fr}->{3318188} = "Guyancourt";
$areanames{fr}->{3318189} = "Boulogne\-Billancourt";
$areanames{fr}->{3318190} = "Paris";
$areanames{fr}->{3318191} = "Massy";
$areanames{fr}->{3318192} = "Nanterre";
$areanames{fr}->{3318193} = "Nanterre";
$areanames{fr}->{3318194} = "Créteil";
$areanames{fr}->{3318195} = "Cergy";
$areanames{fr}->{3318196} = "Nanterre";
$areanames{fr}->{3318197} = "Nanterre";
$areanames{fr}->{3318198} = "Boulogne\-Billancourt";
$areanames{fr}->{3318199} = "Boulogne\-Billancourt";
$areanames{fr}->{3318200} = "Boulogne\-Billancourt";
$areanames{fr}->{3318201} = "Créteil";
$areanames{fr}->{3318202} = "Bobigny";
$areanames{fr}->{3318203} = "Poissy";
$areanames{fr}->{3318204} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3318205} = "Corbeil\-Essonnes";
$areanames{fr}->{3318206} = "Enghien\-les\-Bains";
$areanames{fr}->{3318207} = "Paris";
$areanames{fr}->{3318208} = "Versailles";
$areanames{fr}->{3318209} = "Paris";
$areanames{fr}->{3318210} = "Paris";
$areanames{fr}->{3318211} = "Paris";
$areanames{fr}->{3318212} = "Paris";
$areanames{fr}->{3318213} = "Bobigny";
$areanames{fr}->{3318214} = "Nanterre";
$areanames{fr}->{3318215} = "Boulogne\-Billancourt";
$areanames{fr}->{3318216} = "Provins";
$areanames{fr}->{3318217} = "Mantes\-la\-Jolie";
$areanames{fr}->{3318218} = "Rambouillet";
$areanames{fr}->{3318219} = "Poissy";
$areanames{fr}->{3318220} = "Guyancourt";
$areanames{fr}->{3318221} = "Tournan\-en\-Brie";
$areanames{fr}->{3318222} = "Meaux";
$areanames{fr}->{3318223} = "Coulommiers";
$areanames{fr}->{3318224} = "Nanterre";
$areanames{fr}->{3318225} = "Melun";
$areanames{fr}->{3318226} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3318227} = "Enghien\-les\-Bains";
$areanames{fr}->{3318228} = "Paris";
$areanames{fr}->{3318229} = "Beaumont\-sur\-Oise";
$areanames{fr}->{3318230} = "Bobigny";
$areanames{fr}->{3318231} = "Cergy";
$areanames{fr}->{3318232} = "Sarcelles";
$areanames{fr}->{3318233} = "Brie\-Comte\-Robert";
$areanames{fr}->{3318234} = "Fontainebleau";
$areanames{fr}->{3318235} = "Lagny\-sur\-Marne";
$areanames{fr}->{3318236} = "Mantes\-la\-Jolie";
$areanames{fr}->{3318237} = "Le\ Raincy";
$areanames{fr}->{3318238} = "Boissy\-Saint\-Léger";
$areanames{fr}->{3318239} = "Créteil";
$areanames{fr}->{3318240} = "Beaumont\-sur\-Oise";
$areanames{fr}->{3318241} = "Enghien\-les\-Bains";
$areanames{fr}->{3318242} = "Poissy";
$areanames{fr}->{3318243} = "Corbeil\-Essonnes";
$areanames{fr}->{3318244} = "Cergy";
$areanames{fr}->{3318245} = "Sarcelles";
$areanames{fr}->{3318246} = "Bobigny";
$areanames{fr}->{3318247} = "Lagny\-sur\-Marne";
$areanames{fr}->{3318248} = "Boulogne\-Billancourt";
$areanames{fr}->{3318249} = "Versailles";
$areanames{fr}->{3318250} = "Paris";
$areanames{fr}->{3318251} = "Paris";
$areanames{fr}->{3318252} = "Paris";
$areanames{fr}->{3318253} = "Paris";
$areanames{fr}->{3318254} = "Boulogne\-Billancourt";
$areanames{fr}->{3318255} = "Boulogne\-Billancourt";
$areanames{fr}->{3318256} = "Nanterre";
$areanames{fr}->{3318257} = "Nanterre";
$areanames{fr}->{3318258} = "Nanterre";
$areanames{fr}->{3318259} = "Les\ Mureaux";
$areanames{fr}->{3318260} = "Arpajon";
$areanames{fr}->{3318261} = "Guyancourt";
$areanames{fr}->{3318262} = "Fontainebleau";
$areanames{fr}->{3318263} = "Paris";
$areanames{fr}->{3318264} = "Nanterre";
$areanames{fr}->{3318265} = "Créteil";
$areanames{fr}->{3318266} = "Boissy\-Saint\-Léger";
$areanames{fr}->{3318267} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3318268} = "Les\ Mureaux";
$areanames{fr}->{3318269} = "Créteil";
$areanames{fr}->{3318270} = "Brie\-Comte\-Robert";
$areanames{fr}->{3318271} = "Le\ Raincy";
$areanames{fr}->{3318272} = "Massy";
$areanames{fr}->{3318273} = "Paris";
$areanames{fr}->{3318274} = "Brie\-Comte\-Robert";
$areanames{fr}->{3318275} = "Coulommiers";
$areanames{fr}->{3318276} = "Fontainebleau";
$areanames{fr}->{3318277} = "Lagny\-sur\-Marne";
$areanames{fr}->{3318278} = "Meaux";
$areanames{fr}->{3318279} = "Melun";
$areanames{fr}->{3318280} = "Provins";
$areanames{fr}->{3318281} = "Tournan\-en\-Brie";
$areanames{fr}->{3318282} = "Paris";
$areanames{fr}->{3318283} = "Paris";
$areanames{fr}->{3318284} = "Guyancourt";
$areanames{fr}->{3318285} = "Mantes\-la\-Jolie";
$areanames{fr}->{3318286} = "Les\ Mureaux";
$areanames{fr}->{3318287} = "Poissy";
$areanames{fr}->{3318288} = "Paris";
$areanames{fr}->{3318289} = "Rambouillet";
$areanames{fr}->{3318290} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3318291} = "Versailles";
$areanames{fr}->{3318292} = "Arpajon";
$areanames{fr}->{3318293} = "Corbeil\-Essonnes";
$areanames{fr}->{3318294} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3318295} = "Massy";
$areanames{fr}->{3318296} = "Boulogne\-Billancourt";
$areanames{fr}->{3318297} = "Nanterre";
$areanames{fr}->{3318298} = "Bobigny";
$areanames{fr}->{3318299} = "Le\ Raincy";
$areanames{fr}->{3318300} = "Boissy\-Saint\-Léger";
$areanames{fr}->{3318301} = "Créteil";
$areanames{fr}->{3318302} = "Beaumont\-sur\-Oise";
$areanames{fr}->{3318303} = "Cergy";
$areanames{fr}->{3318304} = "Enghien\-les\-Bains";
$areanames{fr}->{3318305} = "Sarcelles";
$areanames{fr}->{3318306} = "Paris";
$areanames{fr}->{3318307} = "Arpajon";
$areanames{fr}->{3318308} = "Beaumont\-sur\-Oise";
$areanames{fr}->{3318309} = "Bobigny";
$areanames{fr}->{3318310} = "Boissy\-Saint\-Léger";
$areanames{fr}->{3318311} = "Boulogne\-Billancourt";
$areanames{fr}->{3318312} = "Brie\-Comte\-Robert";
$areanames{fr}->{3318313} = "Cergy";
$areanames{fr}->{3318314} = "Corbeil\-Essonnes";
$areanames{fr}->{3318315} = "Coulommiers";
$areanames{fr}->{3318316} = "Melun";
$areanames{fr}->{3318317} = "Nanterre";
$areanames{fr}->{3318318} = "Paris";
$areanames{fr}->{3318319} = "Poissy";
$areanames{fr}->{3318320} = "Provins";
$areanames{fr}->{3318321} = "Rambouillet";
$areanames{fr}->{3318322} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3318323} = "Sarcelles";
$areanames{fr}->{3318324} = "Tournan\-en\-Brie";
$areanames{fr}->{3318325} = "Versailles";
$areanames{fr}->{3318326} = "Meaux";
$areanames{fr}->{3318327} = "Enghien\-les\-Bains";
$areanames{fr}->{3318328} = "Fontainebleau";
$areanames{fr}->{3318329} = "Guyancourt";
$areanames{fr}->{3318330} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3318331} = "Lagny\-sur\-Marne";
$areanames{fr}->{3318332} = "Les\ Mureaux";
$areanames{fr}->{3318333} = "Mantes\-la\-Jolie";
$areanames{fr}->{3318334} = "Massy";
$areanames{fr}->{3318335} = "Paris";
$areanames{fr}->{3318336} = "Rambouillet";
$areanames{fr}->{3318337} = "Bobigny";
$areanames{fr}->{3318338} = "Meaux";
$areanames{fr}->{3318339} = "Boulogne\-Billancourt";
$areanames{fr}->{3318340} = "Brie\-Comte\-Robert";
$areanames{fr}->{3318341} = "Corbeil\-Essonnes";
$areanames{fr}->{3318342} = "Créteil";
$areanames{fr}->{3318343} = "Poissy";
$areanames{fr}->{3318344} = "Enghien\-les\-Bains";
$areanames{fr}->{3318345} = "Guyancourt";
$areanames{fr}->{3318346} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3318347} = "Lagny\-sur\-Marne";
$areanames{fr}->{3318348} = "Le\ Raincy";
$areanames{fr}->{3318349} = "Mantes\-la\-Jolie";
$areanames{fr}->{3318350} = "Massy";
$areanames{fr}->{3318351} = "Meaux";
$areanames{fr}->{3318352} = "Melun";
$areanames{fr}->{3318353} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3318354} = "Les\ Mureaux";
$areanames{fr}->{3318355} = "Nanterre";
$areanames{fr}->{3318356} = "Paris";
$areanames{fr}->{3318357} = "Poissy";
$areanames{fr}->{3318358} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3318359} = "Versailles";
$areanames{fr}->{3318360} = "Sarcelles";
$areanames{fr}->{3318361} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3318362} = "Paris";
$areanames{fr}->{3318363} = "Arpajon";
$areanames{fr}->{3318364} = "Paris";
$areanames{fr}->{3318365} = "Paris";
$areanames{fr}->{3318366} = "Bobigny";
$areanames{fr}->{3318367} = "Nanterre";
$areanames{fr}->{3318368} = "Créteil";
$areanames{fr}->{3318369} = "Meaux";
$areanames{fr}->{3318372} = "Saint\-Denis";
$areanames{fr}->{3318380} = "Paris";
$areanames{fr}->{3318381} = "Paris";
$areanames{fr}->{3318382} = "Versailles";
$areanames{fr}->{3318383} = "Sarcelles";
$areanames{fr}->{3318384} = "Enghien\-les\-Bains";
$areanames{fr}->{3318385} = "Brie\-Comte\-Robert";
$areanames{fr}->{3318386} = "Melun";
$areanames{fr}->{3318387} = "Paris";
$areanames{fr}->{3318388} = "Fontainebleau";
$areanames{fr}->{3318389} = "Paris";
$areanames{fr}->{331839} = "Paris";
$areanames{fr}->{3318393} = "Beaumont\-sur\-Oise";
$areanames{fr}->{3318399} = "Melun";
$areanames{fr}->{3318400} = "Massy";
$areanames{fr}->{3318401} = "Boulogne\-Billancourt";
$areanames{fr}->{3318402} = "Nanterre";
$areanames{fr}->{3318403} = "Bobigny";
$areanames{fr}->{3318404} = "Créteil";
$areanames{fr}->{3318405} = "Paris";
$areanames{fr}->{3318406} = "Paris";
$areanames{fr}->{3318407} = "Créteil";
$areanames{fr}->{3318408} = "Bobigny";
$areanames{fr}->{3318409} = "Le\ Raincy";
$areanames{fr}->{3318410} = "Paris";
$areanames{fr}->{3318411} = "Nanterre";
$areanames{fr}->{3318412} = "Mantes\-la\-Jolie";
$areanames{fr}->{3318413} = "Paris";
$areanames{fr}->{3318414} = "Paris";
$areanames{fr}->{3318415} = "Cergy";
$areanames{fr}->{3318416} = "Paris";
$areanames{fr}->{3318417} = "Paris";
$areanames{fr}->{3318418} = "Corbeil\-Essonnes";
$areanames{fr}->{3318419} = "Boulogne\-Billancourt";
$areanames{fr}->{3318420} = "Nanterre";
$areanames{fr}->{3318421} = "Bobigny";
$areanames{fr}->{3318422} = "Boulogne\-Billancourt";
$areanames{fr}->{3318423} = "Créteil";
$areanames{fr}->{3318424} = "Cergy";
$areanames{fr}->{3318425} = "Paris";
$areanames{fr}->{3318426} = "Melun";
$areanames{fr}->{3318427} = "Versailles";
$areanames{fr}->{3318428} = "Cergy";
$areanames{fr}->{3318429} = "Cergy";
$areanames{fr}->{3318430} = "Nanterre";
$areanames{fr}->{3318431} = "Brie\-Comte\-Robert";
$areanames{fr}->{3318432} = "Coulommiers";
$areanames{fr}->{3318433} = "Fontainebleau";
$areanames{fr}->{3318434} = "Meaux";
$areanames{fr}->{3318435} = "Melun";
$areanames{fr}->{3318436} = "Provins";
$areanames{fr}->{3318437} = "Tournan\-en\-Brie";
$areanames{fr}->{3318438} = "Paris";
$areanames{fr}->{3318439} = "Guyancourt";
$areanames{fr}->{3318440} = "Versailles";
$areanames{fr}->{3318441} = "Mantes\-la\-Jolie";
$areanames{fr}->{3318442} = "Les\ Mureaux";
$areanames{fr}->{3318443} = "Poissy";
$areanames{fr}->{3318444} = "Rambouillet";
$areanames{fr}->{3318445} = "Arpajon";
$areanames{fr}->{3318446} = "Corbeil\-Essonnes";
$areanames{fr}->{3318447} = "Boissy\-Saint\-Léger";
$areanames{fr}->{3318448} = "Beaumont\-sur\-Oise";
$areanames{fr}->{3318449} = "Brie\-Comte\-Robert";
$areanames{fr}->{3318450} = "Coulommiers";
$areanames{fr}->{3318451} = "Fontainebleau";
$areanames{fr}->{3318452} = "Meaux";
$areanames{fr}->{3318453} = "Melun";
$areanames{fr}->{3318454} = "Provins";
$areanames{fr}->{3318455} = "Mantes\-la\-Jolie";
$areanames{fr}->{3318456} = "Les\ Mureaux";
$areanames{fr}->{3318457} = "Poissy";
$areanames{fr}->{3318458} = "Rambouillet";
$areanames{fr}->{3318459} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3318460} = "Boulogne\-Billancourt";
$areanames{fr}->{3318461} = "Guyancourt";
$areanames{fr}->{3318462} = "Versailles";
$areanames{fr}->{3318463} = "Arpajon";
$areanames{fr}->{3318464} = "Corbeil\-Essonnes";
$areanames{fr}->{3318465} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3318466} = "Massy";
$areanames{fr}->{3318467} = "Bobigny";
$areanames{fr}->{3318468} = "Le\ Raincy";
$areanames{fr}->{3318469} = "Boissy\-Saint\-Léger";
$areanames{fr}->{3318470} = "Beaumont\-sur\-Oise";
$areanames{fr}->{3318471} = "Enghien\-les\-Bains";
$areanames{fr}->{3318472} = "Paris";
$areanames{fr}->{3318473} = "Versailles";
$areanames{fr}->{3318474} = "Bobigny";
$areanames{fr}->{3318475} = "Boissy\-Saint\-Léger";
$areanames{fr}->{3318476} = "Boulogne\-Billancourt";
$areanames{fr}->{3318477} = "Créteil";
$areanames{fr}->{3318478} = "Nanterre";
$areanames{fr}->{3318479} = "Paris";
$areanames{fr}->{331848} = "Paris";
$areanames{fr}->{3318480} = "Nanterre";
$areanames{fr}->{3318481} = "Le\ Raincy";
$areanames{fr}->{3318487} = "Bobigny";
$areanames{fr}->{3318489} = "Beaumont\-sur\-Oise";
$areanames{fr}->{3318490} = "Bobigny";
$areanames{fr}->{3318491} = "Cergy";
$areanames{fr}->{3318492} = "Enghien\-les\-Bains";
$areanames{fr}->{3318493} = "Le\ Raincy";
$areanames{fr}->{3318494} = "Nanterre";
$areanames{fr}->{3318495} = "Paris";
$areanames{fr}->{3318496} = "Poissy";
$areanames{fr}->{3318497} = "Sarcelles";
$areanames{fr}->{3318498} = "Boissy\-Saint\-Léger";
$areanames{fr}->{3318499} = "Boulogne\-Billancourt";
$areanames{fr}->{3318500} = "Créteil";
$areanames{fr}->{3318501} = "Nanterre";
$areanames{fr}->{3318502} = "Le\ Raincy";
$areanames{fr}->{3318503} = "Fontainebleau";
$areanames{fr}->{3318504} = "Bobigny";
$areanames{fr}->{3318505} = "Paris";
$areanames{fr}->{3318506} = "Bobigny";
$areanames{fr}->{3318507} = "Bobigny";
$areanames{fr}->{3318508} = "Paris";
$areanames{fr}->{3318509} = "Paris";
$areanames{fr}->{3318510} = "Le\ Raincy";
$areanames{fr}->{3318511} = "Enghien\-les\-Bains";
$areanames{fr}->{3318512} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3318513} = "Brie\-Comte\-Robert";
$areanames{fr}->{3318514} = "Paris";
$areanames{fr}->{3318515} = "Paris";
$areanames{fr}->{3318516} = "Créteil";
$areanames{fr}->{3318517} = "Bobigny";
$areanames{fr}->{3318518} = "Boulogne\-Billancourt";
$areanames{fr}->{3318519} = "Le\ Raincy";
$areanames{fr}->{3318520} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3318521} = "Enghien\-les\-Bains";
$areanames{fr}->{3318522} = "Sarcelles";
$areanames{fr}->{3318523} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3318524} = "Versailles";
$areanames{fr}->{3318525} = "Poissy";
$areanames{fr}->{3318526} = "Cergy";
$areanames{fr}->{3318527} = "Meaux";
$areanames{fr}->{3318528} = "Les\ Mureaux";
$areanames{fr}->{3318529} = "Corbeil\-Essonnes";
$areanames{fr}->{3318530} = "Nanterre";
$areanames{fr}->{3318531} = "Boulogne\-Billancourt";
$areanames{fr}->{3318532} = "Boulogne\-Billancourt";
$areanames{fr}->{3318533} = "Créteil";
$areanames{fr}->{3318534} = "Paris";
$areanames{fr}->{3318535} = "Brie\-Comte\-Robert";
$areanames{fr}->{3318536} = "Versailles";
$areanames{fr}->{3318537} = "Massy";
$areanames{fr}->{3318538} = "Cergy";
$areanames{fr}->{3318539} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3318540} = "Guyancourt";
$areanames{fr}->{3318541} = "Massy";
$areanames{fr}->{3318542} = "Lagny\-sur\-Marne";
$areanames{fr}->{3318543} = "Sarcelles";
$areanames{fr}->{3318544} = "Boissy\-Saint\-Léger";
$areanames{fr}->{3318545} = "Melun";
$areanames{fr}->{3318546} = "Arpajon";
$areanames{fr}->{3318547} = "Poissy";
$areanames{fr}->{3318548} = "Fontainebleau";
$areanames{fr}->{3318549} = "Meaux";
$areanames{fr}->{3318550} = "Mantes\-la\-Jolie";
$areanames{fr}->{3318551} = "Brie\-Comte\-Robert";
$areanames{fr}->{3318552} = "Beaumont\-sur\-Oise";
$areanames{fr}->{3318553} = "Paris";
$areanames{fr}->{3318554} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3318555} = "Paris";
$areanames{fr}->{3318556} = "Paris";
$areanames{fr}->{3318557} = "Bobigny";
$areanames{fr}->{3318558} = "Bobigny";
$areanames{fr}->{3318559} = "Guyancourt";
$areanames{fr}->{331856} = "Paris";
$areanames{fr}->{3318562} = "Boulogne\-Billancourt";
$areanames{fr}->{3318563} = "Nanterre";
$areanames{fr}->{3318566} = "Lagny\-sur\-Marne";
$areanames{fr}->{3318567} = "Nanterre";
$areanames{fr}->{3318570} = "Boissy\-Saint\-Léger";
$areanames{fr}->{3318571} = "Nanterre";
$areanames{fr}->{3318572} = "Créteil";
$areanames{fr}->{3318573} = "Paris";
$areanames{fr}->{3318574} = "Boulogne\-Billancourt";
$areanames{fr}->{3318575} = "Paris";
$areanames{fr}->{3318576} = "Enghien\-les\-Bains";
$areanames{fr}->{3318577} = "Rambouillet";
$areanames{fr}->{3318578} = "Nanterre";
$areanames{fr}->{3318579} = "Les\ Mureaux";
$areanames{fr}->{3318580} = "Provins";
$areanames{fr}->{3318581} = "Coulommiers";
$areanames{fr}->{3318582} = "Massy";
$areanames{fr}->{3318583} = "Guyancourt";
$areanames{fr}->{3318584} = "Meaux";
$areanames{fr}->{3318585} = "Paris";
$areanames{fr}->{3318586} = "Melun";
$areanames{fr}->{3318587} = "Arpajon";
$areanames{fr}->{3318588} = "Paris";
$areanames{fr}->{3318589} = "Paris";
$areanames{fr}->{3318590} = "Lagny\-sur\-Marne";
$areanames{fr}->{3318591} = "Beaumont\-sur\-Oise";
$areanames{fr}->{3318592} = "Sarcelles";
$areanames{fr}->{3318593} = "Paris";
$areanames{fr}->{3318594} = "Tournan\-en\-Brie";
$areanames{fr}->{3318595} = "Nanterre";
$areanames{fr}->{3318596} = "Boulogne\-Billancourt";
$areanames{fr}->{3318597} = "Cergy";
$areanames{fr}->{3318598} = "Paris";
$areanames{fr}->{3318599} = "Coulommiers";
$areanames{fr}->{3318600} = "Fontainebleau";
$areanames{fr}->{3318601} = "Lagny\-sur\-Marne";
$areanames{fr}->{3318602} = "Meaux";
$areanames{fr}->{3318603} = "Melun";
$areanames{fr}->{3318604} = "Provins";
$areanames{fr}->{3318605} = "Tournan\-en\-Brie";
$areanames{fr}->{3318606} = "Guyancourt";
$areanames{fr}->{3318607} = "Mantes\-la\-Jolie";
$areanames{fr}->{3318608} = "Les\ Mureaux";
$areanames{fr}->{3318609} = "Poissy";
$areanames{fr}->{3318610} = "Rambouillet";
$areanames{fr}->{3318611} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3318612} = "Versailles";
$areanames{fr}->{3318613} = "Arpajon";
$areanames{fr}->{3318614} = "Corbeil\-Essonnes";
$areanames{fr}->{3318615} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3318616} = "Massy";
$areanames{fr}->{3318617} = "Beaumont\-sur\-Oise";
$areanames{fr}->{3318618} = "Cergy";
$areanames{fr}->{3318619} = "Enghien\-les\-Bains";
$areanames{fr}->{3318620} = "Sarcelles";
$areanames{fr}->{3318621} = "Paris";
$areanames{fr}->{3318622} = "Paris";
$areanames{fr}->{3318623} = "Enghien\-les\-Bains";
$areanames{fr}->{3318624} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3318625} = "Nanterre";
$areanames{fr}->{3318626} = "Paris";
$areanames{fr}->{3318627} = "Paris";
$areanames{fr}->{3318628} = "Corbeil\-Essonnes";
$areanames{fr}->{3318629} = "Fontainebleau";
$areanames{fr}->{3318630} = "Sarcelles";
$areanames{fr}->{3318631} = "Paris";
$areanames{fr}->{3318632} = "Coulommiers";
$areanames{fr}->{3318633} = "Lagny\-sur\-Marne";
$areanames{fr}->{3318634} = "Provins";
$areanames{fr}->{3318635} = "Mantes\-la\-Jolie";
$areanames{fr}->{3318636} = "Les\ Mureaux";
$areanames{fr}->{3318637} = "Poissy";
$areanames{fr}->{3318638} = "Rambouillet";
$areanames{fr}->{3318639} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3318640} = "Paris";
$areanames{fr}->{3318641} = "Versailles";
$areanames{fr}->{3318642} = "Boulogne\-Billancourt";
$areanames{fr}->{3318643} = "Cergy";
$areanames{fr}->{3318644} = "Créteil";
$areanames{fr}->{3318645} = "Sarcelles";
$areanames{fr}->{3318646} = "Paris";
$areanames{fr}->{3318647} = "Paris";
$areanames{fr}->{3318648} = "Boulogne\-Billancourt";
$areanames{fr}->{3318649} = "Versailles";
$areanames{fr}->{3318650} = "Cergy";
$areanames{fr}->{3318651} = "Melun";
$areanames{fr}->{3318652} = "Nanterre";
$areanames{fr}->{3318653} = "Enghien\-les\-Bains";
$areanames{fr}->{3318654} = "Paris";
$areanames{fr}->{3318655} = "Paris";
$areanames{fr}->{3318656} = "Corbeil\-Essonnes";
$areanames{fr}->{3318657} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3318658} = "Corbeil\-Essonnes";
$areanames{fr}->{3318659} = "Versailles";
$areanames{fr}->{331866} = "Paris";
$areanames{fr}->{3318660} = "Créteil";
$areanames{fr}->{3318663} = "Boulogne\-Billancourt";
$areanames{fr}->{3318667} = "Boulogne\-Billancourt";
$areanames{fr}->{331867} = "Paris";
$areanames{fr}->{3318674} = "Lagny\-sur\-Marne";
$areanames{fr}->{3318675} = "Mantes\-la\-Jolie";
$areanames{fr}->{3318678} = "Bobigny";
$areanames{fr}->{3318679} = "Brie\-Comte\-Robert";
$areanames{fr}->{3318680} = "Corbeil\-Essonnes";
$areanames{fr}->{3318681} = "Créteil";
$areanames{fr}->{3318682} = "Coulommiers";
$areanames{fr}->{3318683} = "Fontainebleau";
$areanames{fr}->{3318684} = "Lagny\-sur\-Marne";
$areanames{fr}->{3318685} = "Paris";
$areanames{fr}->{3318686} = "Paris";
$areanames{fr}->{3318687} = "Paris";
$areanames{fr}->{3318688} = "Paris";
$areanames{fr}->{3318689} = "Paris";
$areanames{fr}->{331869} = "Paris";
$areanames{fr}->{3318693} = "Créteil";
$areanames{fr}->{3318694} = "Nanterre";
$areanames{fr}->{3318699} = "Nanterre";
$areanames{fr}->{3318700} = "Bobigny";
$areanames{fr}->{3318701} = "Bobigny";
$areanames{fr}->{3318702} = "Paris";
$areanames{fr}->{3318703} = "Paris";
$areanames{fr}->{3318704} = "Paris";
$areanames{fr}->{3318705} = "Paris";
$areanames{fr}->{3318706} = "Lagny\-sur\-Marne";
$areanames{fr}->{3318707} = "Lagny\-sur\-Marne";
$areanames{fr}->{3318708} = "Guyancourt";
$areanames{fr}->{3318709} = "Nanterre";
$areanames{fr}->{3318710} = "Nanterre";
$areanames{fr}->{3318711} = "Provins";
$areanames{fr}->{3318712} = "Boulogne\-Billancourt";
$areanames{fr}->{3318713} = "Cergy";
$areanames{fr}->{3318714} = "Créteil";
$areanames{fr}->{3318715} = "Nanterre";
$areanames{fr}->{3318716} = "Paris";
$areanames{fr}->{3318717} = "Paris";
$areanames{fr}->{3318718} = "Nanterre";
$areanames{fr}->{3318719} = "Boulogne\-Billancourt";
$areanames{fr}->{331872} = "Paris";
$areanames{fr}->{3318723} = "Beaumont\-sur\-Oise";
$areanames{fr}->{3318728} = "Melun";
$areanames{fr}->{3318729} = "Provins";
$areanames{fr}->{3318730} = "Tournan\-en\-Brie";
$areanames{fr}->{3318731} = "Mantes\-la\-Jolie";
$areanames{fr}->{3318732} = "Rambouillet";
$areanames{fr}->{3318733} = "Arpajon";
$areanames{fr}->{3318734} = "Boissy\-Saint\-Léger";
$areanames{fr}->{3318735} = "Beaumont\-sur\-Oise";
$areanames{fr}->{3318736} = "Créteil";
$areanames{fr}->{3318737} = "Nanterre";
$areanames{fr}->{3318738} = "Guyancourt";
$areanames{fr}->{3318739} = "Paris";
$areanames{fr}->{3318740} = "Paris";
$areanames{fr}->{3318741} = "Boulogne\-Billancourt";
$areanames{fr}->{3318742} = "Boulogne\-Billancourt";
$areanames{fr}->{3318743} = "Boulogne\-Billancourt";
$areanames{fr}->{3318744} = "Paris";
$areanames{fr}->{3318745} = "Fontainebleau";
$areanames{fr}->{3318746} = "Paris";
$areanames{fr}->{3318747} = "Lagny\-sur\-Marne";
$areanames{fr}->{3318748} = "Enghien\-les\-Bains";
$areanames{fr}->{3318749} = "Massy";
$areanames{fr}->{3318750} = "Guyancourt";
$areanames{fr}->{3318751} = "Créteil";
$areanames{fr}->{3318752} = "Paris";
$areanames{fr}->{3318753} = "Paris";
$areanames{fr}->{3318754} = "Massy";
$areanames{fr}->{3318755} = "Nanterre";
$areanames{fr}->{3318756} = "Boulogne\-Billancourt";
$areanames{fr}->{3318757} = "Lagny\-sur\-Marne";
$areanames{fr}->{3318758} = "Paris";
$areanames{fr}->{3318759} = "Massy";
$areanames{fr}->{3318760} = "Boulogne\-Billancourt";
$areanames{fr}->{3318761} = "Meaux";
$areanames{fr}->{3318762} = "Lagny\-sur\-Marne";
$areanames{fr}->{3318763} = "Enghien\-les\-Bains";
$areanames{fr}->{3318764} = "Paris";
$areanames{fr}->{3318765} = "Paris";
$areanames{fr}->{3318766} = "Paris";
$areanames{fr}->{3318767} = "Paris";
$areanames{fr}->{3318768} = "Paris";
$areanames{fr}->{3318769} = "Boulogne\-Billancourt";
$areanames{fr}->{3318770} = "Brie\-Comte\-Robert";
$areanames{fr}->{3318771} = "Melun";
$areanames{fr}->{3318772} = "Guyancourt";
$areanames{fr}->{3318773} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3318774} = "Bobigny";
$areanames{fr}->{3318775} = "Paris";
$areanames{fr}->{3318776} = "Nanterre";
$areanames{fr}->{3318777} = "Paris";
$areanames{fr}->{3318778} = "Paris";
$areanames{fr}->{3318779} = "Paris";
$areanames{fr}->{3318780} = "Versailles";
$areanames{fr}->{3318781} = "Paris";
$areanames{fr}->{3318782} = "Massy";
$areanames{fr}->{3318783} = "Boulogne\-Billancourt";
$areanames{fr}->{3318784} = "Créteil";
$areanames{fr}->{3318785} = "Bobigny";
$areanames{fr}->{3318786} = "Paris";
$areanames{fr}->{3318787} = "Paris";
$areanames{fr}->{3318788} = "Versailles";
$areanames{fr}->{3318789} = "Paris";
$areanames{fr}->{3318790} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3318791} = "Brie\-Comte\-Robert";
$areanames{fr}->{3318792} = "Coulommiers";
$areanames{fr}->{3318793} = "Fontainebleau";
$areanames{fr}->{3318794} = "Lagny\-sur\-Marne";
$areanames{fr}->{3318795} = "Meaux";
$areanames{fr}->{3318796} = "Melun";
$areanames{fr}->{3318797} = "Provins";
$areanames{fr}->{3318798} = "Provins";
$areanames{fr}->{3318799} = "Tournan\-en\-Brie";
$areanames{fr}->{3318800} = "Guyancourt";
$areanames{fr}->{3318801} = "Les\ Mureaux";
$areanames{fr}->{3318802} = "Mantes\-la\-Jolie";
$areanames{fr}->{3318803} = "Poissy";
$areanames{fr}->{3318804} = "Rambouillet";
$areanames{fr}->{3318805} = "Saint\-Germain\-en\-Laye";
$areanames{fr}->{3318806} = "Versailles";
$areanames{fr}->{3318807} = "Arpajon";
$areanames{fr}->{3318808} = "Corbeil\-Essonnes";
$areanames{fr}->{3318809} = "Juvisy\-sur\-Orge";
$areanames{fr}->{3318810} = "Massy";
$areanames{fr}->{3318811} = "Boulogne\-Billancourt";
$areanames{fr}->{3318812} = "Bobigny";
$areanames{fr}->{3318813} = "Le\ Raincy";
$areanames{fr}->{3318814} = "Boissy\-Saint\-Léger";
$areanames{fr}->{3318815} = "Créteil";
$areanames{fr}->{3318816} = "Beaumont\-sur\-Oise";
$areanames{fr}->{3318817} = "Cergy";
$areanames{fr}->{3318818} = "Enghien\-les\-Bains";
$areanames{fr}->{3318819} = "Sarcelles";
$areanames{fr}->{3318820} = "Enghien\-les\-Bains";
$areanames{fr}->{3318821} = "Paris";
$areanames{fr}->{3318822} = "Paris";
$areanames{fr}->{3318823} = "Paris";
$areanames{fr}->{3318824} = "Paris";
$areanames{fr}->{3318825} = "Paris";
$areanames{fr}->{3318826} = "Cergy";
$areanames{fr}->{3318827} = "Créteil";
$areanames{fr}->{3318828} = "Créteil";
$areanames{fr}->{3318829} = "Créteil";
$areanames{fr}->{331883} = "Paris";
$areanames{fr}->{3318837} = "Melun";
$areanames{fr}->{3318838} = "Versailles";
$areanames{fr}->{3318839} = "Guyancourt";
$areanames{fr}->{331884} = "Paris";
$areanames{fr}->{3318842} = "Nanterre";
$areanames{fr}->{3318849} = "Bobigny";
$areanames{fr}->{3318850} = "Bobigny";
$areanames{fr}->{3318851} = "Bobigny";
$areanames{fr}->{3318852} = "Paris";
$areanames{fr}->{3318854} = "Nanterre";
$areanames{fr}->{3318855} = "Paris";
$areanames{fr}->{3318856} = "Paris";
$areanames{fr}->{3318857} = "Paris";
$areanames{fr}->{3318858} = "Paris";
$areanames{fr}->{33190} = "Ile\ de\ France";
$areanames{fr}->{33191} = "Ile\ de\ France";
$areanames{fr}->{3321400} = "Alençon";
$areanames{fr}->{3321401} = "Argentan";
$areanames{fr}->{3321402} = "Falaise";
$areanames{fr}->{3321403} = "Flers";
$areanames{fr}->{3321404} = "Lisieux";
$areanames{fr}->{3321405} = "Mortagne\-au\-Perche";
$areanames{fr}->{3321406} = "Saint\-Lô";
$areanames{fr}->{3321407} = "Vire";
$areanames{fr}->{3321408} = "Bayeux";
$areanames{fr}->{3321409} = "Deauville";
$areanames{fr}->{3321410} = "Falaise";
$areanames{fr}->{3321411} = "Lisieux";
$areanames{fr}->{3321412} = "Vire";
$areanames{fr}->{3321413} = "Avranches";
$areanames{fr}->{3321414} = "Carentan\-les\-Marais";
$areanames{fr}->{3321415} = "Coutances";
$areanames{fr}->{3321416} = "Saint\-Lô";
$areanames{fr}->{3321417} = "Alençon";
$areanames{fr}->{3321418} = "Argentan";
$areanames{fr}->{3321419} = "Flers";
$areanames{fr}->{3321420} = "L\'Aigle";
$areanames{fr}->{3321421} = "Mortagne\-au\-Perche";
$areanames{fr}->{3321422} = "Alençon";
$areanames{fr}->{3321423} = "Argentan";
$areanames{fr}->{3321424} = "Avranches";
$areanames{fr}->{3321425} = "Carentan\-les\-Marais";
$areanames{fr}->{3321426} = "Deauville";
$areanames{fr}->{3321427} = "Flers";
$areanames{fr}->{3321428} = "Mortagne\-au\-Perche";
$areanames{fr}->{3321429} = "Saint\-Lô";
$areanames{fr}->{3321430} = "Vire";
$areanames{fr}->{3321431} = "Alençon";
$areanames{fr}->{3321432} = "Avranches";
$areanames{fr}->{3321433} = "Caen";
$areanames{fr}->{3321434} = "Carentan\-les\-Marais";
$areanames{fr}->{3321435} = "Coutances";
$areanames{fr}->{3321436} = "Saint\-Lô";
$areanames{fr}->{3321437} = "Caen";
$areanames{fr}->{3321438} = "Alençon";
$areanames{fr}->{3321439} = "Saint\-Lô";
$areanames{fr}->{3321440} = "Caen";
$areanames{fr}->{3321441} = "Caen";
$areanames{fr}->{3321442} = "Alençon";
$areanames{fr}->{3321443} = "Alençon";
$areanames{fr}->{3321444} = "Argentan";
$areanames{fr}->{3321445} = "Avranches";
$areanames{fr}->{3321446} = "Bayeux";
$areanames{fr}->{3321447} = "Caen";
$areanames{fr}->{3321448} = "Carentan\-les\-Marais";
$areanames{fr}->{3321449} = "Coutances";
$areanames{fr}->{3321450} = "Avranches";
$areanames{fr}->{3321451} = "Deauville";
$areanames{fr}->{3321452} = "Falaise";
$areanames{fr}->{3321453} = "Flers";
$areanames{fr}->{3321454} = "L\'Aigle";
$areanames{fr}->{3321455} = "Saint\-Lô";
$areanames{fr}->{3321456} = "Lisieux";
$areanames{fr}->{3321457} = "Mortagne\-au\-Perche";
$areanames{fr}->{3321458} = "Saint\-Lô";
$areanames{fr}->{3321459} = "Vire";
$areanames{fr}->{3321460} = "Caen";
$areanames{fr}->{3321461} = "Caen";
$areanames{fr}->{3321462} = "Lisieux";
$areanames{fr}->{3321463} = "Deauville";
$areanames{fr}->{3321464} = "Lisieux";
$areanames{fr}->{3321465} = "Bayeux";
$areanames{fr}->{3321466} = "Caen";
$areanames{fr}->{3321467} = "Deauville";
$areanames{fr}->{3321468} = "Falaise";
$areanames{fr}->{3321469} = "Lisieux";
$areanames{fr}->{3321470} = "Carentan\-les\-Marais";
$areanames{fr}->{3321471} = "Carentan\-les\-Marais";
$areanames{fr}->{3321472} = "Avranches";
$areanames{fr}->{3321473} = "Vire";
$areanames{fr}->{3321474} = "Caen";
$areanames{fr}->{3321475} = "Avranches";
$areanames{fr}->{3321476} = "Carentan\-les\-Marais";
$areanames{fr}->{3321477} = "Coutances";
$areanames{fr}->{3321478} = "Saint\-Lô";
$areanames{fr}->{3321479} = "Alençon";
$areanames{fr}->{3321480} = "Coutances";
$areanames{fr}->{3321481} = "Argentan";
$areanames{fr}->{3321482} = "Flers";
$areanames{fr}->{3321483} = "L\'Aigle";
$areanames{fr}->{3321484} = "Mortagne\-au\-Perche";
$areanames{fr}->{3321485} = "Caen";
$areanames{fr}->{3321486} = "Carentan\-les\-Marais";
$areanames{fr}->{3321487} = "Coutances";
$areanames{fr}->{3321488} = "Saint\-Lô";
$areanames{fr}->{3321489} = "Coutances";
$areanames{fr}->{3321490} = "Avranches";
$areanames{fr}->{3321491} = "Alençon";
$areanames{fr}->{3321492} = "Lisieux";
$areanames{fr}->{3321493} = "Coutances";
$areanames{fr}->{3321494} = "Caen";
$areanames{fr}->{3321495} = "Argentan";
$areanames{fr}->{3321496} = "Flers";
$areanames{fr}->{3321497} = "L\'Aigle";
$areanames{fr}->{3321498} = "Mortagne\-au\-Perche";
$areanames{fr}->{3321499} = "Caen";
$areanames{fr}->{3321800} = "Nogent\-le\-Rotrou";
$areanames{fr}->{3321801} = "Le\ Blanc";
$areanames{fr}->{3321802} = "Châteauroux";
$areanames{fr}->{3321803} = "La\ Châtre";
$areanames{fr}->{3321804} = "Issoudun";
$areanames{fr}->{3321805} = "Valençay";
$areanames{fr}->{3321806} = "Amboise";
$areanames{fr}->{3321807} = "Chinon";
$areanames{fr}->{3321808} = "Loches";
$areanames{fr}->{3321809} = "Saint\-Aignan";
$areanames{fr}->{3321810} = "Vendôme";
$areanames{fr}->{3321811} = "Gien";
$areanames{fr}->{3321812} = "Montargis";
$areanames{fr}->{3321813} = "Pithiviers";
$areanames{fr}->{3321814} = "Blois";
$areanames{fr}->{3321815} = "Bourges";
$areanames{fr}->{3321816} = "Chartres";
$areanames{fr}->{3321817} = "Châteaudun";
$areanames{fr}->{3321818} = "Gien";
$areanames{fr}->{3321819} = "La\ Guerche\-sur\-lAubois";
$areanames{fr}->{3321820} = "Montargis";
$areanames{fr}->{3321821} = "Orléans";
$areanames{fr}->{3321822} = "Pithiviers";
$areanames{fr}->{3321823} = "Romorantin\-Lanthenay";
$areanames{fr}->{3321824} = "Tours";
$areanames{fr}->{3321825} = "Vendôme";
$areanames{fr}->{3321826} = "Vierzon";
$areanames{fr}->{3321827} = "Le\ Blanc";
$areanames{fr}->{3321828} = "Issoudun";
$areanames{fr}->{3321829} = "Romorantin\-Lanthenay";
$areanames{fr}->{3321830} = "Tours";
$areanames{fr}->{3321831} = "Blois";
$areanames{fr}->{3321832} = "Bourges";
$areanames{fr}->{3321833} = "Chartres";
$areanames{fr}->{3321834} = "Montargis";
$areanames{fr}->{3321835} = "Orléans";
$areanames{fr}->{3321836} = "Tours";
$areanames{fr}->{3321837} = "Tours";
$areanames{fr}->{3321838} = "Pithiviers";
$areanames{fr}->{3321839} = "Orléans";
$areanames{fr}->{3321840} = "Chartres";
$areanames{fr}->{3321841} = "Tours";
$areanames{fr}->{3321842} = "Blois";
$areanames{fr}->{3321843} = "Bourges";
$areanames{fr}->{3321844} = "Chartres";
$areanames{fr}->{3321845} = "Orléans";
$areanames{fr}->{3321846} = "Châteaudun";
$areanames{fr}->{3321847} = "Châteauroux";
$areanames{fr}->{3321848} = "Dreux";
$areanames{fr}->{3321849} = "Gien";
$areanames{fr}->{3321850} = "Montargis";
$areanames{fr}->{3321851} = "Vendôme";
$areanames{fr}->{3321852} = "Amboise";
$areanames{fr}->{3321853} = "Aubigny\-sur\-Nère";
$areanames{fr}->{3321854} = "Blois";
$areanames{fr}->{3321855} = "Bourges";
$areanames{fr}->{3321856} = "Chartres";
$areanames{fr}->{3321857} = "Châteaudun";
$areanames{fr}->{3321858} = "Châteauroux";
$areanames{fr}->{3321859} = "Chinon";
$areanames{fr}->{3321860} = "Dreux";
$areanames{fr}->{3321861} = "Gien";
$areanames{fr}->{3321862} = "Issoudun";
$areanames{fr}->{3321863} = "La\ Châtre";
$areanames{fr}->{3321864} = "La\ Guerche\-sur\-lAubois";
$areanames{fr}->{3321865} = "Le\ Blanc";
$areanames{fr}->{3321866} = "Loches";
$areanames{fr}->{3321867} = "Montargis";
$areanames{fr}->{3321868} = "Nogent\-le\-Rotrou";
$areanames{fr}->{3321869} = "Orléans";
$areanames{fr}->{3321870} = "Pithiviers";
$areanames{fr}->{3321871} = "Romorantin\-Lanthenay";
$areanames{fr}->{3321872} = "Saint\-Aignan";
$areanames{fr}->{3321873} = "Saint\-Amand\-Montrond";
$areanames{fr}->{3321874} = "Sancerre";
$areanames{fr}->{3321875} = "Tours";
$areanames{fr}->{3321876} = "Valençay";
$areanames{fr}->{3321877} = "Vendôme";
$areanames{fr}->{3321878} = "Vierzon";
$areanames{fr}->{3321879} = "Blois";
$areanames{fr}->{3321880} = "La\ Guerche\-sur\-lAubois";
$areanames{fr}->{3321881} = "Bourges";
$areanames{fr}->{3321882} = "Nogent\-le\-Rotrou";
$areanames{fr}->{3321883} = "Blois";
$areanames{fr}->{3321884} = "Orléans";
$areanames{fr}->{3321885} = "Montargis";
$areanames{fr}->{3321886} = "Aubigny\-sur\-Nère";
$areanames{fr}->{3321887} = "Bourges";
$areanames{fr}->{3321888} = "Orléans";
$areanames{fr}->{3321889} = "Bourges";
$areanames{fr}->{3321890} = "Chartres";
$areanames{fr}->{3321891} = "La\ Guerche\-sur\-lAubois";
$areanames{fr}->{3321892} = "Saint\-Amand\-Montrond";
$areanames{fr}->{3321893} = "Châteauroux";
$areanames{fr}->{3321894} = "Sancerre";
$areanames{fr}->{3321895} = "Vierzon";
$areanames{fr}->{3321896} = "Tours";
$areanames{fr}->{3321897} = "Chartres";
$areanames{fr}->{3321898} = "Châteaudun";
$areanames{fr}->{3321899} = "Dreux";
$areanames{fr}->{3321900} = "Bourges";
$areanames{fr}->{3321901} = "Orléans";
$areanames{fr}->{3321902} = "Chartres";
$areanames{fr}->{3321903} = "Tours";
$areanames{fr}->{3321904} = "Blois";
$areanames{fr}->{3321905} = "Orléans";
$areanames{fr}->{3321906} = "Vierzon";
$areanames{fr}->{3321907} = "Issoudun";
$areanames{fr}->{3321908} = "Châteauroux";
$areanames{fr}->{3322100} = "Rennes";
$areanames{fr}->{3322101} = "Saint\-Malo";
$areanames{fr}->{3322102} = "Vannes";
$areanames{fr}->{3322103} = "Carhaix\-Plouguer";
$areanames{fr}->{3322104} = "Rennes";
$areanames{fr}->{3322105} = "Rennes";
$areanames{fr}->{3322106} = "Brest";
$areanames{fr}->{3322107} = "Rennes";
$areanames{fr}->{3322108} = "Saint\-Brieuc";
$areanames{fr}->{3322109} = "Brest";
$areanames{fr}->{3322110} = "Brest";
$areanames{fr}->{3322111} = "Rennes";
$areanames{fr}->{3322112} = "Guingamp";
$areanames{fr}->{3322113} = "Lamballe";
$areanames{fr}->{3322114} = "Loudéac";
$areanames{fr}->{3322115} = "Paimpol";
$areanames{fr}->{3322116} = "Rostrenen";
$areanames{fr}->{3322117} = "Morlaix";
$areanames{fr}->{3322118} = "Quimperlé";
$areanames{fr}->{3322119} = "Fougères";
$areanames{fr}->{3322120} = "Janzé";
$areanames{fr}->{3322121} = "Montfort\-sur\-Meu";
$areanames{fr}->{3322122} = "Redon";
$areanames{fr}->{3322123} = "Vitré";
$areanames{fr}->{3322124} = "Le\ Faouet";
$areanames{fr}->{3322125} = "Ploërmel";
$areanames{fr}->{3322126} = "Pontivy";
$areanames{fr}->{3322127} = "Saint\-Brieuc";
$areanames{fr}->{3322128} = "Morlaix";
$areanames{fr}->{3322129} = "Vitré";
$areanames{fr}->{3322130} = "Auray";
$areanames{fr}->{3322131} = "Rennes";
$areanames{fr}->{3322132} = "Auray";
$areanames{fr}->{3322133} = "Carhaix\-Plouguer";
$areanames{fr}->{3322134} = "Rennes";
$areanames{fr}->{3322135} = "Dinan";
$areanames{fr}->{3322136} = "Guingamp";
$areanames{fr}->{3322137} = "Lamballe";
$areanames{fr}->{3322138} = "Loudéac";
$areanames{fr}->{3322139} = "Paimpol";
$areanames{fr}->{3322140} = "Rostrenen";
$areanames{fr}->{3322141} = "Saint\-Brieuc";
$areanames{fr}->{3322142} = "Brest";
$areanames{fr}->{3322143} = "Carhaix\-Plouguer";
$areanames{fr}->{3322144} = "Morlaix";
$areanames{fr}->{3322145} = "Quimperlé";
$areanames{fr}->{3322146} = "Fougères";
$areanames{fr}->{3322147} = "Janzé";
$areanames{fr}->{3322148} = "Montfort\-sur\-Meu";
$areanames{fr}->{3322149} = "Redon";
$areanames{fr}->{3322150} = "Rennes";
$areanames{fr}->{3322151} = "Saint\-Malo";
$areanames{fr}->{3322152} = "Vitré";
$areanames{fr}->{3322153} = "Auray";
$areanames{fr}->{3322154} = "Le\ Faouet";
$areanames{fr}->{3322155} = "Ploërmel";
$areanames{fr}->{3322156} = "Pontivy";
$areanames{fr}->{3322157} = "Vannes";
$areanames{fr}->{3322158} = "Carhaix\-Plouguer";
$areanames{fr}->{3322159} = "Quimperlé";
$areanames{fr}->{3322160} = "Saint\-Brieuc";
$areanames{fr}->{3322161} = "Dinan";
$areanames{fr}->{3322162} = "Carhaix\-Plouguer";
$areanames{fr}->{3322163} = "Paimpol";
$areanames{fr}->{3322164} = "Brest";
$areanames{fr}->{3322165} = "Rennes";
$areanames{fr}->{3322166} = "Saint\-Brieuc";
$areanames{fr}->{3322167} = "Rennes";
$areanames{fr}->{3322168} = "Rennes";
$areanames{fr}->{3322169} = "Redon";
$areanames{fr}->{3322170} = "Rennes";
$areanames{fr}->{3322171} = "Guingamp";
$areanames{fr}->{3322200} = "Brest";
$areanames{fr}->{3322201} = "Carhaix\-Plouguer";
$areanames{fr}->{3322202} = "Janzé";
$areanames{fr}->{3322203} = "Rennes";
$areanames{fr}->{3322204} = "Saint\-Brieuc";
$areanames{fr}->{3322205} = "Vannes";
$areanames{fr}->{3322206} = "Rennes";
$areanames{fr}->{3322207} = "Vannes";
$areanames{fr}->{3322208} = "Brest";
$areanames{fr}->{3322209} = "Montfort\-sur\-Meu";
$areanames{fr}->{3322210} = "Saint\-Brieuc";
$areanames{fr}->{3322211} = "Auray";
$areanames{fr}->{3322212} = "Carhaix\-Plouguer";
$areanames{fr}->{3322213} = "Dinan";
$areanames{fr}->{3322214} = "Fougères";
$areanames{fr}->{3322215} = "Janzé";
$areanames{fr}->{3322216} = "Ploërmel";
$areanames{fr}->{3322217} = "Quimperlé";
$areanames{fr}->{3322218} = "Redon";
$areanames{fr}->{3322219} = "Vitré";
$areanames{fr}->{3322220} = "Janzé";
$areanames{fr}->{3322221} = "Auray";
$areanames{fr}->{3322222} = "Saint\-Brieuc";
$areanames{fr}->{3322223} = "Vannes";
$areanames{fr}->{3322224} = "Brest";
$areanames{fr}->{3322225} = "Carhaix\-Plouguer";
$areanames{fr}->{3322226} = "Dinan";
$areanames{fr}->{3322227} = "Fougères";
$areanames{fr}->{3322228} = "Guingamp";
$areanames{fr}->{3322229} = "Carhaix\-Plouguer";
$areanames{fr}->{3322230} = "Janzé";
$areanames{fr}->{3322231} = "Lamballe";
$areanames{fr}->{3322232} = "Le\ Faouet";
$areanames{fr}->{3322233} = "Brest";
$areanames{fr}->{3322234} = "Loudéac";
$areanames{fr}->{3322235} = "Rennes";
$areanames{fr}->{3322236} = "Montfort\-sur\-Meu";
$areanames{fr}->{3322237} = "Morlaix";
$areanames{fr}->{3322238} = "Paimpol";
$areanames{fr}->{3322239} = "Ploërmel";
$areanames{fr}->{3322240} = "Pontivy";
$areanames{fr}->{3322241} = "Quimperlé";
$areanames{fr}->{3322242} = "Redon";
$areanames{fr}->{3322243} = "Rennes";
$areanames{fr}->{3322244} = "Rennes";
$areanames{fr}->{3322245} = "Rostrenen";
$areanames{fr}->{3322246} = "Saint\-Brieuc";
$areanames{fr}->{3322247} = "Saint\-Malo";
$areanames{fr}->{3322248} = "Vannes";
$areanames{fr}->{3322249} = "Vitré";
$areanames{fr}->{3322250} = "Brest";
$areanames{fr}->{3322251} = "Rennes";
$areanames{fr}->{3322252} = "Brest";
$areanames{fr}->{3322253} = "Carhaix\-Plouguer";
$areanames{fr}->{3322254} = "Rennes";
$areanames{fr}->{3322255} = "Morlaix";
$areanames{fr}->{3322256} = "Pontivy";
$areanames{fr}->{3322257} = "Dinan";
$areanames{fr}->{3322258} = "Guingamp";
$areanames{fr}->{3322259} = "Lamballe";
$areanames{fr}->{3322260} = "Loudéac";
$areanames{fr}->{3322261} = "Paimpol";
$areanames{fr}->{3322262} = "Rostrenen";
$areanames{fr}->{3322263} = "Saint\-Brieuc";
$areanames{fr}->{3322264} = "Brest";
$areanames{fr}->{3322265} = "Carhaix\-Plouguer";
$areanames{fr}->{3322266} = "Rennes";
$areanames{fr}->{3322267} = "Morlaix";
$areanames{fr}->{3322268} = "Quimperlé";
$areanames{fr}->{3322269} = "Fougères";
$areanames{fr}->{3322270} = "Saint\-Brieuc";
$areanames{fr}->{3322271} = "Guingamp";
$areanames{fr}->{3322272} = "Carhaix\-Plouguer";
$areanames{fr}->{3322273} = "Brest";
$areanames{fr}->{3322274} = "Rennes";
$areanames{fr}->{3322275} = "Saint\-Malo";
$areanames{fr}->{3322276} = "Auray";
$areanames{fr}->{3322277} = "Vannes";
$areanames{fr}->{3322278} = "Janzé";
$areanames{fr}->{3322279} = "Montfort\-sur\-Meu";
$areanames{fr}->{3322280} = "Redon";
$areanames{fr}->{3322281} = "Saint\-Malo";
$areanames{fr}->{3322282} = "Vitré";
$areanames{fr}->{3322283} = "Auray";
$areanames{fr}->{3322284} = "Le\ Faouet";
$areanames{fr}->{3322285} = "Ploërmel";
$areanames{fr}->{3322286} = "Pontivy";
$areanames{fr}->{3322287} = "Vannes";
$areanames{fr}->{3322288} = "Brest";
$areanames{fr}->{3322289} = "Carhaix\-Plouguer";
$areanames{fr}->{3322290} = "Brest";
$areanames{fr}->{3322291} = "Rennes";
$areanames{fr}->{3322292} = "Rostrenen";
$areanames{fr}->{3322293} = "Rennes";
$areanames{fr}->{3322294} = "Carhaix\-Plouguer";
$areanames{fr}->{3322295} = "Saint\-Brieuc";
$areanames{fr}->{3322296} = "Brest";
$areanames{fr}->{3322297} = "Carhaix\-Plouguer";
$areanames{fr}->{3322298} = "Rennes";
$areanames{fr}->{3322299} = "Auray";
$areanames{fr}->{332230} = "Nord\ Ouest";
$areanames{fr}->{3322305} = "Rennes";
$areanames{fr}->{3322306} = "Rennes";
$areanames{fr}->{3322307} = "Rennes";
$areanames{fr}->{3322308} = "Janzé";
$areanames{fr}->{3322310} = "Pénestin";
$areanames{fr}->{3322315} = "Cancale";
$areanames{fr}->{3322316} = "Combourg";
$areanames{fr}->{3322318} = "Saint\-Malo";
$areanames{fr}->{3322320} = "Rennes";
$areanames{fr}->{3322321} = "Rennes";
$areanames{fr}->{3322322} = "Montreuil\-sur\-Ille";
$areanames{fr}->{3322325} = "Saint\-Grégoire";
$areanames{fr}->{3322330} = "Rennes";
$areanames{fr}->{3322331} = "Bain\-de\-Bretagne";
$areanames{fr}->{3322335} = "Rennes";
$areanames{fr}->{3322340} = "Rennes";
$areanames{fr}->{3322341} = "Bréal\-sous\-Montfort";
$areanames{fr}->{3322342} = "Rennes";
$areanames{fr}->{3322343} = "Montfort\-sur\-Meu";
$areanames{fr}->{3322344} = "Rennes";
$areanames{fr}->{3322345} = "Cesson\-Sévigné";
$areanames{fr}->{3322346} = "Rennes";
$areanames{fr}->{3322348} = "Rennes";
$areanames{fr}->{3322350} = "Bruz";
$areanames{fr}->{3322351} = "Fougères";
$areanames{fr}->{3322352} = "Saint\-Malo";
$areanames{fr}->{3322355} = "Vitré";
$areanames{fr}->{332236} = "Nord\ Ouest";
$areanames{fr}->{3322361} = "Rennes";
$areanames{fr}->{3322362} = "Rennes";
$areanames{fr}->{3322363} = "Redon";
$areanames{fr}->{3322364} = "Montfort\-sur\-Meu";
$areanames{fr}->{332237} = "Nord\ Ouest";
$areanames{fr}->{332238} = "Nord\ Ouest";
$areanames{fr}->{332239} = "Nord\ Ouest";
$areanames{fr}->{332270} = "Nord\ Ouest";
$areanames{fr}->{3322700} = "Rouen";
$areanames{fr}->{3322705} = "Rouen";
$areanames{fr}->{3322708} = "Rouen";
$areanames{fr}->{332271} = "Nord\ Ouest";
$areanames{fr}->{3322713} = "Fécamp";
$areanames{fr}->{3322719} = "Bernay";
$areanames{fr}->{3322728} = "Eu";
$areanames{fr}->{332273} = "Nord\ Ouest";
$areanames{fr}->{3322730} = "Fécamp";
$areanames{fr}->{3322734} = "Evreux";
$areanames{fr}->{3322736} = "Pont\-Audemer";
$areanames{fr}->{332274} = "Nord\ Ouest";
$areanames{fr}->{3322743} = "Fécamp";
$areanames{fr}->{332275} = "Nord\ Ouest";
$areanames{fr}->{332276} = "Nord\ Ouest";
$areanames{fr}->{332277} = "Nord\ Ouest";
$areanames{fr}->{3322776} = "Rouen";
$areanames{fr}->{332278} = "Nord\ Ouest";
$areanames{fr}->{332279} = "Nord\ Ouest";
$areanames{fr}->{3322802} = "Vigneux\-de\-Bretagne";
$areanames{fr}->{3322803} = "Saint\-Herblain";
$areanames{fr}->{3322808} = "Nantes";
$areanames{fr}->{3322811} = "Saint\-Jean\-de\-Monts";
$areanames{fr}->{3322812} = "Challans";
$areanames{fr}->{3322813} = "Fontenay\-le\-Comte";
$areanames{fr}->{332282} = "Nantes";
$areanames{fr}->{332283} = "Nord\ Ouest";
$areanames{fr}->{3322830} = "Nantes";
$areanames{fr}->{3322834} = "Nantes";
$areanames{fr}->{3322844} = "Nantes";
$areanames{fr}->{3322853} = "Saint\-Brevin\-les\-Pins";
$areanames{fr}->{3322854} = "Saint\-Nazaire";
$areanames{fr}->{332286} = "Nord\ Ouest";
$areanames{fr}->{332287} = "Nord\ Ouest";
$areanames{fr}->{332288} = "Nord\ Ouest";
$areanames{fr}->{3322885} = "La\ Roche\-sur\-Yon";
$areanames{fr}->{332289} = "Nord\ Ouest";
$areanames{fr}->{3322891} = "Nantes";
$areanames{fr}->{3322896} = "Nantes";
$areanames{fr}->{3322897} = "La\ Roche\-sur\-Yon";
$areanames{fr}->{332290} = "Nord\ Ouest";
$areanames{fr}->{3322900} = "Brest";
$areanames{fr}->{3322902} = "Brest";
$areanames{fr}->{3322905} = "Brest";
$areanames{fr}->{332291} = "Nord\ Ouest";
$areanames{fr}->{3322915} = "Carhaix\-Plouguer";
$areanames{fr}->{332292} = "Nord\ Ouest";
$areanames{fr}->{3322920} = "Carhaix\-Plouguer";
$areanames{fr}->{3322925} = "Carhaix\-Plouguer";
$areanames{fr}->{332293} = "Nord\ Ouest";
$areanames{fr}->{3322940} = "Briec";
$areanames{fr}->{332295} = "Nord\ Ouest";
$areanames{fr}->{3322962} = "Landerneau";
$areanames{fr}->{332297} = "Nord\ Ouest";
$areanames{fr}->{332298} = "Nord\ Ouest";
$areanames{fr}->{332299} = "Nord\ Ouest";
$areanames{fr}->{3323002} = "Rennes";
$areanames{fr}->{3323010} = "Dinan";
$areanames{fr}->{3323011} = "Lamballe";
$areanames{fr}->{3323012} = "Loudéac";
$areanames{fr}->{3323013} = "Brest";
$areanames{fr}->{3323014} = "Carhaix\-Plouguer";
$areanames{fr}->{3323015} = "Quimperlé";
$areanames{fr}->{3323016} = "Fougères";
$areanames{fr}->{3323017} = "Auray";
$areanames{fr}->{3323018} = "Le\ Faouet";
$areanames{fr}->{3323019} = "Ploërmel";
$areanames{fr}->{3323020} = "Pontivy";
$areanames{fr}->{3323021} = "Rennes";
$areanames{fr}->{3323022} = "Janzé";
$areanames{fr}->{3323023} = "Montfort\-sur\-Meu";
$areanames{fr}->{3323024} = "Redon";
$areanames{fr}->{3323025} = "Saint\-Malo";
$areanames{fr}->{3323026} = "Vitré";
$areanames{fr}->{3323027} = "Auray";
$areanames{fr}->{3323028} = "Le\ Faouet";
$areanames{fr}->{3323029} = "Ploërmel";
$areanames{fr}->{3323030} = "Pontivy";
$areanames{fr}->{3323031} = "Vannes";
$areanames{fr}->{3323032} = "Rennes";
$areanames{fr}->{3323033} = "Carhaix\-Plouguer";
$areanames{fr}->{3323034} = "Montfort\-sur\-Meu";
$areanames{fr}->{3323035} = "Morlaix";
$areanames{fr}->{3323036} = "Le\ Faouet";
$areanames{fr}->{3323037} = "Rennes";
$areanames{fr}->{3323038} = "Rostrenen";
$areanames{fr}->{3323039} = "Auray";
$areanames{fr}->{3323040} = "Janzé";
$areanames{fr}->{3323041} = "Vannes";
$areanames{fr}->{3323042} = "Saint\-Malo";
$areanames{fr}->{3323043} = "Fougères";
$areanames{fr}->{3323044} = "Loudéac";
$areanames{fr}->{3323045} = "Saint\-Brieuc";
$areanames{fr}->{3323046} = "Quimperlé";
$areanames{fr}->{3323047} = "Dinan";
$areanames{fr}->{3323048} = "Lamballe";
$areanames{fr}->{3323049} = "Vitré";
$areanames{fr}->{3323050} = "Brest";
$areanames{fr}->{3323051} = "Ploërmel";
$areanames{fr}->{3323052} = "Guingamp";
$areanames{fr}->{3323053} = "Paimpol";
$areanames{fr}->{3323054} = "Pontivy";
$areanames{fr}->{3323055} = "Redon";
$areanames{fr}->{3323056} = "Dinan";
$areanames{fr}->{3323057} = "Guingamp";
$areanames{fr}->{3323058} = "Lamballe";
$areanames{fr}->{3323059} = "Loudéac";
$areanames{fr}->{3323060} = "Paimpol";
$areanames{fr}->{3323061} = "Rostrenen";
$areanames{fr}->{3323062} = "Saint\-Brieuc";
$areanames{fr}->{3323063} = "Brest";
$areanames{fr}->{3323064} = "Carhaix\-Plouguer";
$areanames{fr}->{3323065} = "Morlaix";
$areanames{fr}->{3323066} = "Quimperlé";
$areanames{fr}->{3323067} = "Fougères";
$areanames{fr}->{3323068} = "Janzé";
$areanames{fr}->{3323069} = "Montfort\-sur\-Meu";
$areanames{fr}->{3323070} = "Redon";
$areanames{fr}->{3323071} = "Rennes";
$areanames{fr}->{3323072} = "Saint\-Malo";
$areanames{fr}->{3323073} = "Vitré";
$areanames{fr}->{3323074} = "Auray";
$areanames{fr}->{3323075} = "Le\ Faouet";
$areanames{fr}->{3323076} = "Ploërmel";
$areanames{fr}->{3323077} = "Pontivy";
$areanames{fr}->{3323078} = "Vannes";
$areanames{fr}->{3323079} = "Brest";
$areanames{fr}->{3323080} = "Morlaix";
$areanames{fr}->{3323081} = "Pontivy";
$areanames{fr}->{3323082} = "Brest";
$areanames{fr}->{3323083} = "Rennes";
$areanames{fr}->{3323084} = "Lamballe";
$areanames{fr}->{3323085} = "Vannes";
$areanames{fr}->{3323086} = "Brest";
$areanames{fr}->{3323087} = "Loudéac";
$areanames{fr}->{3323088} = "Rennes";
$areanames{fr}->{3323089} = "Paimpol";
$areanames{fr}->{3323096} = "Rennes";
$areanames{fr}->{3323106} = "Caen";
$areanames{fr}->{3323109} = "Vire";
$areanames{fr}->{3323110} = "Bayeux";
$areanames{fr}->{3323114} = "Deauville";
$areanames{fr}->{3323115} = "Caen";
$areanames{fr}->{3323120} = "Saint\-Pierre\-sur\-Dives";
$areanames{fr}->{3323127} = "Caen";
$areanames{fr}->{3323128} = "Houlgate";
$areanames{fr}->{3323129} = "Caen";
$areanames{fr}->{3323130} = "Caen";
$areanames{fr}->{3323131} = "Lisieux";
$areanames{fr}->{3323134} = "Caen";
$areanames{fr}->{3323135} = "Mondeville";
$areanames{fr}->{3323137} = "Courseulles\-sur\-Mer";
$areanames{fr}->{3323138} = "Caen";
$areanames{fr}->{3323140} = "Falaise";
$areanames{fr}->{3323143} = "Caen";
$areanames{fr}->{3323144} = "Caen";
$areanames{fr}->{3323146} = "Caen";
$areanames{fr}->{3323147} = "Caen";
$areanames{fr}->{3323148} = "Lisieux";
$areanames{fr}->{3323150} = "Caen";
$areanames{fr}->{3323151} = "Bayeux";
$areanames{fr}->{3323152} = "Caen";
$areanames{fr}->{3323153} = "Caen";
$areanames{fr}->{3323154} = "Hérouville\-Saint\-Clair";
$areanames{fr}->{3323161} = "Lisieux";
$areanames{fr}->{3323162} = "Lisieux";
$areanames{fr}->{3323164} = "Pont\-l\'Évêque";
$areanames{fr}->{3323165} = "Pont\-l\'Évêque";
$areanames{fr}->{3323166} = "Vire";
$areanames{fr}->{3323167} = "Vire";
$areanames{fr}->{3323168} = "Vire";
$areanames{fr}->{3323169} = "Condé\-sur\-Noireau";
$areanames{fr}->{3323170} = "Caen";
$areanames{fr}->{3323171} = "Carpiquet";
$areanames{fr}->{3323172} = "Colombelles";
$areanames{fr}->{3323173} = "Caen";
$areanames{fr}->{3323174} = "Caen";
$areanames{fr}->{3323175} = "Caen";
$areanames{fr}->{3323181} = "Deauville";
$areanames{fr}->{3323182} = "Caen";
$areanames{fr}->{3323183} = "Caen";
$areanames{fr}->{3323184} = "Caen";
$areanames{fr}->{3323185} = "Caen";
$areanames{fr}->{3323186} = "Caen";
$areanames{fr}->{3323187} = "Villers\-sur\-Mer";
$areanames{fr}->{3323188} = "Deauville";
$areanames{fr}->{3323189} = "Honfleur";
$areanames{fr}->{3323190} = "Falaise";
$areanames{fr}->{3323191} = "Cabourg";
$areanames{fr}->{3323192} = "Bayeux";
$areanames{fr}->{3323193} = "Caen";
$areanames{fr}->{3323194} = "Caen";
$areanames{fr}->{3323195} = "Hérouville\-Saint\-Clair";
$areanames{fr}->{3323196} = "Ouistreham";
$areanames{fr}->{3323197} = "Ouistreham";
$areanames{fr}->{3323198} = "Deauville";
$areanames{fr}->{3323208} = "Rouen";
$areanames{fr}->{3323209} = "Louviers";
$areanames{fr}->{3323210} = "Rouen";
$areanames{fr}->{3323211} = "Le\ Grand\ Quevilly";
$areanames{fr}->{3323212} = "Rouen";
$areanames{fr}->{3323214} = "Dieppe";
$areanames{fr}->{3323218} = "Rouen";
$areanames{fr}->{3323220} = "Pont\-Audemer";
$areanames{fr}->{3323221} = "Vernon";
$areanames{fr}->{3323223} = "Évreux";
$areanames{fr}->{3323225} = "Louviers";
$areanames{fr}->{3323227} = "Gisors";
$areanames{fr}->{3323228} = "Évreux";
$areanames{fr}->{3323229} = "Breteuil\ sur\ Iton";
$areanames{fr}->{3323230} = "Conches\-en\-Ouche";
$areanames{fr}->{3323231} = "Évreux";
$areanames{fr}->{3323232} = "Verneuil\-sur\-Avre";
$areanames{fr}->{3323233} = "Évreux";
$areanames{fr}->{3323238} = "Évreux";
$areanames{fr}->{3323239} = "Évreux";
$areanames{fr}->{3323240} = "Louviers";
$areanames{fr}->{3323241} = "Pont\-Audemer";
$areanames{fr}->{3323243} = "Bernay";
$areanames{fr}->{3323246} = "Bernay";
$areanames{fr}->{3323247} = "Bernay";
$areanames{fr}->{3323250} = "Louviers";
$areanames{fr}->{3323251} = "Vernon";
$areanames{fr}->{3323253} = "Gaillon";
$areanames{fr}->{3323254} = "Les\ Andelys";
$areanames{fr}->{3323255} = "Gisors";
$areanames{fr}->{3323258} = "Nonancourt";
$areanames{fr}->{3323259} = "Val\-de\-Reuil";
$areanames{fr}->{3323261} = "Val\-de\-Reuil";
$areanames{fr}->{3323262} = "Évreux";
$areanames{fr}->{3323264} = "Vernon";
$areanames{fr}->{3323269} = "Écouis";
$areanames{fr}->{3323270} = "Yvetot";
$areanames{fr}->{3323271} = "Vernon";
$areanames{fr}->{3323274} = "Le\ Havre";
$areanames{fr}->{3323276} = "Rouen";
$areanames{fr}->{3323277} = "Gaillon";
$areanames{fr}->{3323279} = "Montivilliers";
$areanames{fr}->{3323281} = "Rouen";
$areanames{fr}->{3323282} = "Maromme";
$areanames{fr}->{3323283} = "Rouen";
$areanames{fr}->{3323284} = "Notre\-Dame\-de\-Gravenchon";
$areanames{fr}->{3323289} = "Gournay\-en\-Bray";
$areanames{fr}->{3323290} = "Dieppe";
$areanames{fr}->{3323291} = "Saint\-Étienne\-du\-Rouvray";
$areanames{fr}->{3323294} = "Barentin";
$areanames{fr}->{3323296} = "Elbeuf";
$areanames{fr}->{3323297} = "Neufchâtel\-en\-Bray";
$areanames{fr}->{3323301} = "Cherbourg\-Octeville";
$areanames{fr}->{3323303} = "Équeurdreville\-Hainneville";
$areanames{fr}->{3323305} = "Saint\-Lô";
$areanames{fr}->{3323306} = "Saint\-Lô";
$areanames{fr}->{3323308} = "Équeurdreville\-Hainneville";
$areanames{fr}->{3323310} = "Cherbourg\-Octeville";
$areanames{fr}->{3323312} = "Argentan";
$areanames{fr}->{3323317} = "Coutances";
$areanames{fr}->{3323319} = "Coutances";
$areanames{fr}->{3323320} = "Cherbourg\-Octeville";
$areanames{fr}->{3323322} = "Tourlaville";
$areanames{fr}->{3323323} = "Cherbourg\-Octeville";
$areanames{fr}->{3323324} = "L\'Aigle";
$areanames{fr}->{3323326} = "Alençon";
$areanames{fr}->{3323328} = "Alençon";
$areanames{fr}->{3323329} = "Alençon";
$areanames{fr}->{3323331} = "Alençon";
$areanames{fr}->{3323332} = "Alençon";
$areanames{fr}->{3323336} = "Argentan";
$areanames{fr}->{3323340} = "Valognes";
$areanames{fr}->{3323342} = "Carentan";
$areanames{fr}->{3323343} = "Cherbourg\-Octeville";
$areanames{fr}->{3323344} = "Cherbourg\-Octeville";
$areanames{fr}->{3323345} = "Coutances";
$areanames{fr}->{3323350} = "Granville";
$areanames{fr}->{3323353} = "Cherbourg\-Octeville";
$areanames{fr}->{3323357} = "Saint\-Lô";
$areanames{fr}->{3323358} = "Avranches";
$areanames{fr}->{3323362} = "Flers";
$areanames{fr}->{3323364} = "Flers";
$areanames{fr}->{3323365} = "Flers";
$areanames{fr}->{3323367} = "Argentan";
$areanames{fr}->{3323368} = "Avranches";
$areanames{fr}->{3323371} = "Carentan";
$areanames{fr}->{3323372} = "Saint\-Lô";
$areanames{fr}->{3323376} = "Coutances";
$areanames{fr}->{3323377} = "Saint\-Lô";
$areanames{fr}->{3323378} = "Cherbourg\-Octeville";
$areanames{fr}->{3323379} = "Avranches";
$areanames{fr}->{3323380} = "Alençon";
$areanames{fr}->{3323381} = "Alençon";
$areanames{fr}->{3323382} = "Alençon";
$areanames{fr}->{3323384} = "L\'Aigle";
$areanames{fr}->{3323385} = "Mortagne\-au\-Perche";
$areanames{fr}->{3323387} = "Cherbourg\-Octeville";
$areanames{fr}->{3323388} = "Cherbourg\-Octeville";
$areanames{fr}->{3323389} = "Avranches";
$areanames{fr}->{3323390} = "Granville";
$areanames{fr}->{3323391} = "Granville";
$areanames{fr}->{3323393} = "Cherbourg\-Octeville";
$areanames{fr}->{3323394} = "Cherbourg\-Octeville";
$areanames{fr}->{3323395} = "Valognes";
$areanames{fr}->{3323400} = "Pithiviers";
$areanames{fr}->{3323401} = "Nogent\-le\-Rotrou";
$areanames{fr}->{3323402} = "Montargis";
$areanames{fr}->{3323403} = "Blois";
$areanames{fr}->{3323404} = "Gien";
$areanames{fr}->{3323405} = "Montargis";
$areanames{fr}->{3323406} = "Romorantin\-Lanthenay";
$areanames{fr}->{3323407} = "Vierzon";
$areanames{fr}->{3323408} = "Orléans";
$areanames{fr}->{3323409} = "Orléans";
$areanames{fr}->{3323410} = "Le\ Blanc";
$areanames{fr}->{3323411} = "Châteauroux";
$areanames{fr}->{3323412} = "La\ Châtre";
$areanames{fr}->{3323413} = "Issoudun";
$areanames{fr}->{3323414} = "Valençay";
$areanames{fr}->{3323415} = "Amboise";
$areanames{fr}->{3323416} = "Chinon";
$areanames{fr}->{3323417} = "Loches";
$areanames{fr}->{3323418} = "Tours";
$areanames{fr}->{3323419} = "Blois";
$areanames{fr}->{3323420} = "Romorantin\-Lanthenay";
$areanames{fr}->{3323421} = "Saint\-Aignan";
$areanames{fr}->{3323422} = "Vendôme";
$areanames{fr}->{3323423} = "Gien";
$areanames{fr}->{3323424} = "Châteaudun";
$areanames{fr}->{3323425} = "Orléans";
$areanames{fr}->{3323426} = "Montargis";
$areanames{fr}->{3323427} = "Pithiviers";
$areanames{fr}->{3323428} = "Orléans";
$areanames{fr}->{3323429} = "Bourges";
$areanames{fr}->{3323430} = "Tours";
$areanames{fr}->{3323431} = "Saint\-Amand\-Montrond";
$areanames{fr}->{3323432} = "Orléans";
$areanames{fr}->{3323433} = "Romorantin\-Lanthenay";
$areanames{fr}->{3323434} = "Bourges";
$areanames{fr}->{3323435} = "Blois";
$areanames{fr}->{3323436} = "Tours";
$areanames{fr}->{3323437} = "Tours";
$areanames{fr}->{3323438} = "Tours";
$areanames{fr}->{3323439} = "Vierzon";
$areanames{fr}->{3323440} = "Chartres";
$areanames{fr}->{3323441} = "Vierzon";
$areanames{fr}->{3323442} = "Chartres";
$areanames{fr}->{3323443} = "Chartres";
$areanames{fr}->{3323444} = "Vendôme";
$areanames{fr}->{3323445} = "Romorantin\-Lanthenay";
$areanames{fr}->{3323446} = "Blois";
$areanames{fr}->{3323447} = "Vendôme";
$areanames{fr}->{3323448} = "Gien";
$areanames{fr}->{3323449} = "Montargis";
$areanames{fr}->{3323453} = "Tours";
$areanames{fr}->{3323460} = "Tours";
$areanames{fr}->{3323461} = "Aubigny\-sur\-Nère";
$areanames{fr}->{3323462} = "Orléans";
$areanames{fr}->{3323463} = "Chartres";
$areanames{fr}->{3323464} = "Bourges";
$areanames{fr}->{3323465} = "Dreux";
$areanames{fr}->{3323466} = "Nogent\-le\-Rotrou";
$areanames{fr}->{3323467} = "Saint\-Amand\-Montrond";
$areanames{fr}->{3323468} = "Châteauroux";
$areanames{fr}->{3323469} = "Dreux";
$areanames{fr}->{3323470} = "Nogent\-le\-Rotrou";
$areanames{fr}->{3323471} = "Nogent\-le\-Rotrou";
$areanames{fr}->{3323472} = "Amboise";
$areanames{fr}->{3323473} = "Le\ Blanc";
$areanames{fr}->{3323474} = "Tours";
$areanames{fr}->{3323475} = "Tours";
$areanames{fr}->{3323476} = "Blois";
$areanames{fr}->{3323477} = "Châteauroux";
$areanames{fr}->{3323478} = "La\ Châtre";
$areanames{fr}->{3323479} = "Vendôme";
$areanames{fr}->{3323480} = "Issoudun";
$areanames{fr}->{3323481} = "Montargis";
$areanames{fr}->{3323482} = "Orléans";
$areanames{fr}->{3323483} = "Pithiviers";
$areanames{fr}->{3323484} = "Valençay";
$areanames{fr}->{3323485} = "Amboise";
$areanames{fr}->{3323486} = "Chinon";
$areanames{fr}->{3323487} = "Loches";
$areanames{fr}->{3323488} = "Tours";
$areanames{fr}->{3323489} = "Blois";
$areanames{fr}->{3323490} = "Orléans";
$areanames{fr}->{3323491} = "Aubigny\-sur\-Nère";
$areanames{fr}->{3323492} = "Bourges";
$areanames{fr}->{3323493} = "La\ Guerche\-sur\-lAubois";
$areanames{fr}->{3323494} = "Saint\-Amand\-Montrond";
$areanames{fr}->{3323495} = "Sancerre";
$areanames{fr}->{3323496} = "Vierzon";
$areanames{fr}->{3323497} = "Chartres";
$areanames{fr}->{3323498} = "Châteaudun";
$areanames{fr}->{3323499} = "Dreux";
$areanames{fr}->{3323503} = "Rouen";
$areanames{fr}->{3323506} = "Dieppe";
$areanames{fr}->{3323507} = "Rouen";
$areanames{fr}->{3323508} = "Darnétal";
$areanames{fr}->{3323509} = "Gournay\-en\-Bray";
$areanames{fr}->{3323510} = "Fécamp";
$areanames{fr}->{3323512} = "Mont\-Saint\-Aignan";
$areanames{fr}->{3323514} = "Rouen";
$areanames{fr}->{3323515} = "Rouen";
$areanames{fr}->{3323519} = "Le\ Havre";
$areanames{fr}->{3323521} = "Le\ Havre";
$areanames{fr}->{3323522} = "Le\ Havre";
$areanames{fr}->{3323524} = "Le\ Havre";
$areanames{fr}->{3323525} = "Le\ Havre";
$areanames{fr}->{3323526} = "Le\ Havre";
$areanames{fr}->{3323528} = "Fécamp";
$areanames{fr}->{3323529} = "Fécamp";
$areanames{fr}->{3323530} = "Montivilliers";
$areanames{fr}->{3323531} = "Bolbec";
$areanames{fr}->{3323536} = "Canteleu";
$areanames{fr}->{3323537} = "Duclair";
$areanames{fr}->{3323538} = "Lillebonne";
$areanames{fr}->{332354} = "Le\ Havre";
$areanames{fr}->{3323540} = "Dieppe";
$areanames{fr}->{3323550} = "Eu";
$areanames{fr}->{3323551} = "Le\ Havre";
$areanames{fr}->{3323552} = "Rouen";
$areanames{fr}->{3323553} = "Le\ Havre";
$areanames{fr}->{3323554} = "Le\ Havre";
$areanames{fr}->{3323556} = "Yvetot";
$areanames{fr}->{3323557} = "Saint\-Valery\-en\-Caux";
$areanames{fr}->{3323559} = "Bois\-Guillaume";
$areanames{fr}->{3323560} = "Bois\-Guillaume";
$areanames{fr}->{3323561} = "Bois\-Guillaume";
$areanames{fr}->{3323562} = "Rouen";
$areanames{fr}->{3323563} = "Rouen";
$areanames{fr}->{3323564} = "Oissel";
$areanames{fr}->{3323565} = "Saint\-Étienne\-du\-Rouvray";
$areanames{fr}->{3323566} = "Saint\-Étienne\-du\-Rouvray";
$areanames{fr}->{3323567} = "Grand\-Couronne";
$areanames{fr}->{3323568} = "Petit\-Couronne";
$areanames{fr}->{3323569} = "Le\ Grand\ Quevilly";
$areanames{fr}->{3323570} = "Rouen";
$areanames{fr}->{3323571} = "Rouen";
$areanames{fr}->{3323572} = "Rouen";
$areanames{fr}->{3323573} = "Rouen";
$areanames{fr}->{3323574} = "Déville\-lès\-Rouen";
$areanames{fr}->{3323577} = "Elbeuf";
$areanames{fr}->{3323578} = "Elbeuf";
$areanames{fr}->{3323581} = "Elbeuf";
$areanames{fr}->{3323582} = "Dieppe";
$areanames{fr}->{3323584} = "Dieppe";
$areanames{fr}->{3323586} = "Eu";
$areanames{fr}->{3323588} = "Rouen";
$areanames{fr}->{3323589} = "Rouen";
$areanames{fr}->{3323590} = "Gournay\-en\-Bray";
$areanames{fr}->{3323591} = "Barentin";
$areanames{fr}->{3323592} = "Barentin";
$areanames{fr}->{3323595} = "Yvetot";
$areanames{fr}->{3323597} = "Saint\-Valery\-en\-Caux";
$areanames{fr}->{3323598} = "Rouen";
$areanames{fr}->{3323600} = "Tours";
$areanames{fr}->{3323601} = "La\ Châtre";
$areanames{fr}->{3323602} = "Valençay";
$areanames{fr}->{3323603} = "Amboise";
$areanames{fr}->{3323604} = "Chinon";
$areanames{fr}->{3323605} = "Loches";
$areanames{fr}->{3323606} = "Saint\-Aignan";
$areanames{fr}->{3323607} = "Tours";
$areanames{fr}->{3323608} = "Bourges";
$areanames{fr}->{3323609} = "La\ Guerche\-sur\-lAubois";
$areanames{fr}->{3323610} = "Orléans";
$areanames{fr}->{3323611} = "Orléans";
$areanames{fr}->{3323612} = "Orléans";
$areanames{fr}->{3323613} = "Orléans";
$areanames{fr}->{3323614} = "Romorantin\-Lanthenay";
$areanames{fr}->{3323615} = "Chartres";
$areanames{fr}->{3323616} = "Tours";
$areanames{fr}->{3323617} = "Orléans";
$areanames{fr}->{3323618} = "Bourges";
$areanames{fr}->{3323619} = "Chinon";
$areanames{fr}->{3323620} = "Amboise";
$areanames{fr}->{3323621} = "Aubigny\-sur\-Nère";
$areanames{fr}->{3323622} = "Le\ Blanc";
$areanames{fr}->{3323623} = "Blois";
$areanames{fr}->{3323624} = "Bourges";
$areanames{fr}->{3323625} = "Chartres";
$areanames{fr}->{3323626} = "Châteaudun";
$areanames{fr}->{3323627} = "Châteauroux";
$areanames{fr}->{3323628} = "La\ Châtre";
$areanames{fr}->{3323629} = "Chinon";
$areanames{fr}->{3323630} = "Dreux";
$areanames{fr}->{3323631} = "La\ Guerche\-sur\-lAubois";
$areanames{fr}->{3323632} = "Issoudun";
$areanames{fr}->{3323633} = "Loches";
$areanames{fr}->{3323634} = "Montargis";
$areanames{fr}->{3323635} = "Nogent\-le\-Rotrou";
$areanames{fr}->{3323636} = "Dreux";
$areanames{fr}->{3323637} = "Pithiviers";
$areanames{fr}->{3323638} = "Romorantin\-Lanthenay";
$areanames{fr}->{3323639} = "Saint\-Aignan";
$areanames{fr}->{3323640} = "Saint\-Amand\-Montrond";
$areanames{fr}->{3323641} = "Blois";
$areanames{fr}->{3323642} = "Sancerre";
$areanames{fr}->{3323643} = "Tours";
$areanames{fr}->{3323644} = "Valençay";
$areanames{fr}->{3323645} = "Vendôme";
$areanames{fr}->{3323646} = "Vierzon";
$areanames{fr}->{3323647} = "Orléans";
$areanames{fr}->{3323648} = "Gien";
$areanames{fr}->{3323649} = "Tours";
$areanames{fr}->{3323650} = "Orléans";
$areanames{fr}->{3323651} = "Aubigny\-sur\-Nère";
$areanames{fr}->{3323652} = "La\ Guerche\-sur\-lAubois";
$areanames{fr}->{3323653} = "Saint\-Amand\-Montrond";
$areanames{fr}->{3323654} = "Sancerre";
$areanames{fr}->{3323655} = "Vierzon";
$areanames{fr}->{3323656} = "Orléans";
$areanames{fr}->{3323657} = "Châteauroux";
$areanames{fr}->{3323658} = "Chartres";
$areanames{fr}->{3323659} = "Amboise";
$areanames{fr}->{3323660} = "Tours";
$areanames{fr}->{3323661} = "Orléans";
$areanames{fr}->{3323662} = "Aubigny\-sur\-Nère";
$areanames{fr}->{3323663} = "Nogent\-le\-Rotrou";
$areanames{fr}->{3323664} = "Le\ Blanc";
$areanames{fr}->{3323665} = "Blois";
$areanames{fr}->{3323666} = "Sancerre";
$areanames{fr}->{3323667} = "Chartres";
$areanames{fr}->{3323668} = "Châteaudun";
$areanames{fr}->{3323669} = "Dreux";
$areanames{fr}->{3323670} = "Tours";
$areanames{fr}->{3323671} = "Bourges";
$areanames{fr}->{3323672} = "Chartres";
$areanames{fr}->{3323673} = "Châteaudun";
$areanames{fr}->{3323674} = "Châteauroux";
$areanames{fr}->{3323675} = "La\ Châtre";
$areanames{fr}->{3323676} = "Chinon";
$areanames{fr}->{3323677} = "Dreux";
$areanames{fr}->{3323678} = "Bourges";
$areanames{fr}->{3323679} = "Gien";
$areanames{fr}->{3323680} = "La\ Guerche\-sur\-lAubois";
$areanames{fr}->{3323681} = "Orléans";
$areanames{fr}->{3323682} = "Issoudun";
$areanames{fr}->{3323683} = "Loches";
$areanames{fr}->{3323684} = "Montargis";
$areanames{fr}->{3323685} = "Nogent\-le\-Rotrou";
$areanames{fr}->{3323686} = "Orléans";
$areanames{fr}->{3323687} = "Pithiviers";
$areanames{fr}->{3323688} = "Romorantin\-Lanthenay";
$areanames{fr}->{3323689} = "Saint\-Aignan";
$areanames{fr}->{3323690} = "Châteauroux";
$areanames{fr}->{3323691} = "Saint\-Amand\-Montrond";
$areanames{fr}->{3323692} = "Sancerre";
$areanames{fr}->{3323693} = "Tours";
$areanames{fr}->{3323694} = "Valençay";
$areanames{fr}->{3323695} = "Vendôme";
$areanames{fr}->{3323696} = "Vierzon";
$areanames{fr}->{3323697} = "Tours";
$areanames{fr}->{3323698} = "Dreux";
$areanames{fr}->{3323699} = "Orléans";
$areanames{fr}->{332370} = "Nord\ Ouest";
$areanames{fr}->{3323718} = "Chartres";
$areanames{fr}->{3323720} = "Chartres";
$areanames{fr}->{3323721} = "Chartres";
$areanames{fr}->{3323723} = "Courville\-sur\-Eure";
$areanames{fr}->{3323724} = "Illiers\-Combray";
$areanames{fr}->{3323727} = "Maintenon";
$areanames{fr}->{3323728} = "Chartres";
$areanames{fr}->{3323730} = "Chartres";
$areanames{fr}->{3323731} = "Auneau";
$areanames{fr}->{3323733} = "Chartres";
$areanames{fr}->{3323734} = "Chartres";
$areanames{fr}->{3323735} = "Chartres";
$areanames{fr}->{3323736} = "Chartres";
$areanames{fr}->{3323737} = "Senonches";
$areanames{fr}->{3323741} = "Anet";
$areanames{fr}->{3323742} = "Dreux";
$areanames{fr}->{3323744} = "Châteaudun";
$areanames{fr}->{3323745} = "Châteaudun";
$areanames{fr}->{3323746} = "Dreux";
$areanames{fr}->{3323747} = "Bonneval";
$areanames{fr}->{3323750} = "Dreux";
$areanames{fr}->{3323751} = "Nogent\-le\-Roi";
$areanames{fr}->{3323752} = "Nogent\-le\-Rotrou";
$areanames{fr}->{3323753} = "Nogent\-le\-Rotrou";
$areanames{fr}->{3323764} = "Ézy\-sur\-Eure";
$areanames{fr}->{3323765} = "Tremblay\-les\-Villages";
$areanames{fr}->{3323766} = "Châteaudun";
$areanames{fr}->{332377} = "Nord\ Ouest";
$areanames{fr}->{3323781} = "La\ Loupe";
$areanames{fr}->{3323783} = "Épernon";
$areanames{fr}->{3323784} = "Chartres";
$areanames{fr}->{3323788} = "Chartres";
$areanames{fr}->{3323791} = "Chartres";
$areanames{fr}->{3323797} = "Arrou";
$areanames{fr}->{3323798} = "Cloyes\-sur\-le\-Loir";
$areanames{fr}->{3323799} = "Voves";
$areanames{fr}->{3323807} = "Montargis";
$areanames{fr}->{332381} = "Nord\ Ouest";
$areanames{fr}->{3323814} = "Orléans";
$areanames{fr}->{3323815} = "Orléans";
$areanames{fr}->{3323816} = "Montargis";
$areanames{fr}->{3323821} = "Saint\-Jean\-de\-Braye";
$areanames{fr}->{3323822} = "Orléans";
$areanames{fr}->{3323824} = "Orléans";
$areanames{fr}->{3323825} = "Olivet";
$areanames{fr}->{3323828} = "Montargis";
$areanames{fr}->{3323830} = "Pithiviers";
$areanames{fr}->{3323831} = "Briare";
$areanames{fr}->{3323833} = "Puiseaux";
$areanames{fr}->{3323834} = "Malesherbes";
$areanames{fr}->{3323835} = "Saint\-Benoît\-sur\-Loire";
$areanames{fr}->{3323836} = "Sully\-sur\-Loire";
$areanames{fr}->{3323837} = "Briare";
$areanames{fr}->{3323838} = "Gien";
$areanames{fr}->{3323841} = "Sandillon";
$areanames{fr}->{3323842} = "Orléans";
$areanames{fr}->{3323843} = "Orléans";
$areanames{fr}->{3323844} = "Beaugency";
$areanames{fr}->{3323845} = "Cléry\-Saint\-André";
$areanames{fr}->{3323849} = "Olivet";
$areanames{fr}->{3323851} = "Orléans";
$areanames{fr}->{3323852} = "Orléans";
$areanames{fr}->{3323853} = "Orléans";
$areanames{fr}->{3323854} = "Orléans";
$areanames{fr}->{3323855} = "Saint\-Jean\-de\-Braye";
$areanames{fr}->{3323856} = "Orléans";
$areanames{fr}->{3323858} = "Châteauneuf\-sur\-Loire";
$areanames{fr}->{3323859} = "Jargeau";
$areanames{fr}->{3323861} = "Saint\-Jean\-de\-Braye";
$areanames{fr}->{3323862} = "Orléans";
$areanames{fr}->{3323863} = "Olivet";
$areanames{fr}->{3323864} = "Saint\-Denis\-en\-Val";
$areanames{fr}->{3323865} = "Loury";
$areanames{fr}->{3323866} = "Orléans";
$areanames{fr}->{3323867} = "Gien";
$areanames{fr}->{3323868} = "Orléans";
$areanames{fr}->{3323869} = "Olivet";
$areanames{fr}->{3323873} = "Saran";
$areanames{fr}->{3323874} = "Ingré";
$areanames{fr}->{3323877} = "Orléans";
$areanames{fr}->{3323879} = "Orléans";
$areanames{fr}->{3323881} = "Orléans";
$areanames{fr}->{3323883} = "Orléans";
$areanames{fr}->{3323884} = "Orléans";
$areanames{fr}->{3323885} = "Montargis";
$areanames{fr}->{3323886} = "Orléans";
$areanames{fr}->{3323888} = "Orléans";
$areanames{fr}->{3323889} = "Montargis";
$areanames{fr}->{3323890} = "Bellegarde";
$areanames{fr}->{3323891} = "Neuville\-aux\-Bois";
$areanames{fr}->{3323892} = "Dordives";
$areanames{fr}->{3323893} = "Montargis";
$areanames{fr}->{3323895} = "Château\-Renard";
$areanames{fr}->{3323896} = "Ferrières\-en\-Gâtinais";
$areanames{fr}->{3323897} = "Courtenay";
$areanames{fr}->{3323898} = "Montargis";
$areanames{fr}->{3324000} = "Saint\-Nazaire";
$areanames{fr}->{3324001} = "Saint\-Nazaire";
$areanames{fr}->{3324002} = "Sainte\-Pazanne";
$areanames{fr}->{3324007} = "Derval";
$areanames{fr}->{3324008} = "Nantes";
$areanames{fr}->{3324009} = "Liré";
$areanames{fr}->{3324011} = "La\ Baule\ Escoublac";
$areanames{fr}->{3324012} = "Nantes";
$areanames{fr}->{3324013} = "Rezé";
$areanames{fr}->{3324014} = "Nantes";
$areanames{fr}->{3324015} = "Guérande";
$areanames{fr}->{3324016} = "Nantes";
$areanames{fr}->{3324017} = "Saint\-Nazaire";
$areanames{fr}->{3324018} = "Nantes";
$areanames{fr}->{3324019} = "Saint\-Nazaire";
$areanames{fr}->{3324020} = "Nantes";
$areanames{fr}->{3324022} = "Saint\-Nazaire";
$areanames{fr}->{3324023} = "Batz\-sur\-Mer";
$areanames{fr}->{3324024} = "Guérande";
$areanames{fr}->{3324025} = "Sainte\-Luce\-sur\-Loire";
$areanames{fr}->{3324027} = "Saint\-Brevin\-les\-Pins";
$areanames{fr}->{3324028} = "Châteaubriant";
$areanames{fr}->{3324029} = "Nantes";
$areanames{fr}->{3324030} = "Nantes";
$areanames{fr}->{3324034} = "Vertou";
$areanames{fr}->{3324035} = "Nantes";
$areanames{fr}->{3324036} = "Vallet";
$areanames{fr}->{3324037} = "Nantes";
$areanames{fr}->{3324038} = "Couëron";
$areanames{fr}->{3324039} = "Saint\-Brevin\-les\-Pins";
$areanames{fr}->{3324040} = "Nantes";
$areanames{fr}->{3324041} = "Nantes";
$areanames{fr}->{3324042} = "Le\ Pouliguen";
$areanames{fr}->{3324043} = "Nantes";
$areanames{fr}->{3324045} = "Donges";
$areanames{fr}->{3324046} = "Nantes";
$areanames{fr}->{3324047} = "Nantes";
$areanames{fr}->{3324048} = "Nantes";
$areanames{fr}->{3324049} = "Nantes";
$areanames{fr}->{3324050} = "Nantes";
$areanames{fr}->{3324052} = "Nantes";
$areanames{fr}->{3324053} = "Saint\-Nazaire";
$areanames{fr}->{3324054} = "Clisson";
$areanames{fr}->{3324057} = "Héric";
$areanames{fr}->{3324058} = "Nantes";
$areanames{fr}->{3324059} = "Nantes";
$areanames{fr}->{3324060} = "La\ Baule\ Escoublac";
$areanames{fr}->{3324061} = "Pornichet";
$areanames{fr}->{3324062} = "Guérande";
$areanames{fr}->{3324063} = "Orvault";
$areanames{fr}->{3324065} = "Bouguenais";
$areanames{fr}->{3324066} = "Saint\-Nazaire";
$areanames{fr}->{3324068} = "Carquefou";
$areanames{fr}->{3324069} = "Nantes";
$areanames{fr}->{3324070} = "Saint\-Nazaire";
$areanames{fr}->{3324071} = "Nantes";
$areanames{fr}->{3324072} = "Nort\-sur\-Erdre";
$areanames{fr}->{3324073} = "Nantes";
$areanames{fr}->{3324074} = "Nantes";
$areanames{fr}->{3324075} = "Rezé";
$areanames{fr}->{3324076} = "Nantes";
$areanames{fr}->{3324077} = "Sucé\-sur\-Erdre";
$areanames{fr}->{3324078} = "Saint\-Philbert\-de\-Grand\-Lieu";
$areanames{fr}->{3324079} = "Blain";
$areanames{fr}->{3324080} = "Saint\-Sébastien\-sur\-Loire";
$areanames{fr}->{3324081} = "Châteaubriant";
$areanames{fr}->{3324082} = "Pornic";
$areanames{fr}->{3324083} = "Ancenis";
$areanames{fr}->{3324084} = "Nantes";
$areanames{fr}->{3324085} = "Saint\-Herblain";
$areanames{fr}->{3324086} = "Couëron";
$areanames{fr}->{3324089} = "Nantes";
$areanames{fr}->{3324090} = "Trignac";
$areanames{fr}->{3324091} = "Saint\-Nazaire";
$areanames{fr}->{3324092} = "Saint\-Herblain";
$areanames{fr}->{3324093} = "Nantes";
$areanames{fr}->{3324094} = "Treillières";
$areanames{fr}->{3324095} = "Nantes";
$areanames{fr}->{3324096} = "Ancenis";
$areanames{fr}->{3324105} = "Angers";
$areanames{fr}->{3324118} = "Angers";
$areanames{fr}->{3324119} = "Angers";
$areanames{fr}->{3324120} = "Angers";
$areanames{fr}->{3324122} = "Angers";
$areanames{fr}->{3324123} = "Angers";
$areanames{fr}->{3324124} = "Angers";
$areanames{fr}->{3324125} = "Angers";
$areanames{fr}->{3324127} = "Angers";
$areanames{fr}->{3324129} = "Cholet";
$areanames{fr}->{3324130} = "Chemillé";
$areanames{fr}->{3324131} = "Angers";
$areanames{fr}->{3324134} = "Angers";
$areanames{fr}->{3324135} = "Angers";
$areanames{fr}->{3324136} = "Angers";
$areanames{fr}->{3324137} = "Angers";
$areanames{fr}->{3324140} = "Saumur";
$areanames{fr}->{3324143} = "Angers";
$areanames{fr}->{3324144} = "Angers";
$areanames{fr}->{3324146} = "Cholet";
$areanames{fr}->{3324147} = "Angers";
$areanames{fr}->{3324148} = "Angers";
$areanames{fr}->{3324149} = "Cholet";
$areanames{fr}->{3324150} = "Saumur";
$areanames{fr}->{3324151} = "Saumur";
$areanames{fr}->{3324153} = "Saumur";
$areanames{fr}->{3324158} = "Cholet";
$areanames{fr}->{3324159} = "Doué\-la\-Fontaine";
$areanames{fr}->{3324160} = "Angers";
$areanames{fr}->{3324162} = "Cholet";
$areanames{fr}->{3324163} = "Beaupreau";
$areanames{fr}->{3324165} = "Cholet";
$areanames{fr}->{3324166} = "Angers";
$areanames{fr}->{3324167} = "Saumur";
$areanames{fr}->{3324168} = "Angers";
$areanames{fr}->{3324169} = "Avrillé";
$areanames{fr}->{3324171} = "Cholet";
$areanames{fr}->{3324172} = "Angers";
$areanames{fr}->{3324173} = "Angers";
$areanames{fr}->{3324178} = "Chalonnes\-sur\-Loire";
$areanames{fr}->{3324179} = "Angers";
$areanames{fr}->{3324180} = "Maze";
$areanames{fr}->{3324181} = "Angers";
$areanames{fr}->{3324183} = "Saumur";
$areanames{fr}->{3324186} = "Angers";
$areanames{fr}->{3324187} = "Angers";
$areanames{fr}->{3324188} = "Angers";
$areanames{fr}->{3324189} = "Baugé";
$areanames{fr}->{3324190} = "Cheviré\-le\-Rouge";
$areanames{fr}->{3324191} = "Brissac\-Quincé";
$areanames{fr}->{3324192} = "Segré";
$areanames{fr}->{3324193} = "Saint\-Barthélemy\-d\'Anjou";
$areanames{fr}->{3324200} = "Châteauroux";
$areanames{fr}->{3324201} = "Montargis";
$areanames{fr}->{3324202} = "Vendôme";
$areanames{fr}->{3324203} = "Romorantin\-Lanthenay";
$areanames{fr}->{3324204} = "Gien";
$areanames{fr}->{3324205} = "Châteauroux";
$areanames{fr}->{3324206} = "Tours";
$areanames{fr}->{3324207} = "Orléans";
$areanames{fr}->{3324208} = "Tours";
$areanames{fr}->{3324209} = "Aubigny\-sur\-Nère";
$areanames{fr}->{3324210} = "La\ Guerche\-sur\-lAubois";
$areanames{fr}->{3324211} = "Saint\-Amand\-Montrond";
$areanames{fr}->{3324212} = "Sancerre";
$areanames{fr}->{3324213} = "Vierzon";
$areanames{fr}->{3324214} = "Châteaudun";
$areanames{fr}->{3324215} = "Nogent\-le\-Rotrou";
$areanames{fr}->{3324216} = "Le\ Blanc";
$areanames{fr}->{3324217} = "La\ Châtre";
$areanames{fr}->{3324218} = "Issoudun";
$areanames{fr}->{3324219} = "Valençay";
$areanames{fr}->{3324220} = "Amboise";
$areanames{fr}->{3324221} = "Chinon";
$areanames{fr}->{3324222} = "Loches";
$areanames{fr}->{3324223} = "Saint\-Aignan";
$areanames{fr}->{3324224} = "Pithiviers";
$areanames{fr}->{3324225} = "Chartres";
$areanames{fr}->{3324226} = "Dreux";
$areanames{fr}->{3324227} = "Tours";
$areanames{fr}->{3324228} = "Châteaudun";
$areanames{fr}->{3324229} = "Orléans";
$areanames{fr}->{3324230} = "Bourges";
$areanames{fr}->{3324231} = "Tours";
$areanames{fr}->{3324232} = "Valençay";
$areanames{fr}->{3324233} = "Vendôme";
$areanames{fr}->{3324234} = "Chinon";
$areanames{fr}->{3324235} = "Sancerre";
$areanames{fr}->{3324236} = "Saint\-Amand\-Montrond";
$areanames{fr}->{3324237} = "Amboise";
$areanames{fr}->{3324238} = "Issoudun";
$areanames{fr}->{3324239} = "Nogent\-le\-Rotrou";
$areanames{fr}->{3324240} = "La\ Châtre";
$areanames{fr}->{3324241} = "Saint\-Aignan";
$areanames{fr}->{3324242} = "Pithiviers";
$areanames{fr}->{3324243} = "Montargis";
$areanames{fr}->{3324244} = "Blois";
$areanames{fr}->{3324245} = "Aubigny\-sur\-Nère";
$areanames{fr}->{3324246} = "La\ Guerche\-sur\-lAubois";
$areanames{fr}->{3324247} = "Saint\-Amand\-Montrond";
$areanames{fr}->{3324248} = "Sancerre";
$areanames{fr}->{3324249} = "Vierzon";
$areanames{fr}->{3324250} = "Chartres";
$areanames{fr}->{3324251} = "Châteaudun";
$areanames{fr}->{3324252} = "Nogent\-le\-Rotrou";
$areanames{fr}->{3324253} = "Le\ Blanc";
$areanames{fr}->{3324254} = "La\ Châtre";
$areanames{fr}->{3324255} = "Issoudun";
$areanames{fr}->{3324256} = "Valençay";
$areanames{fr}->{3324257} = "Amboise";
$areanames{fr}->{3324258} = "Chinon";
$areanames{fr}->{3324259} = "Loches";
$areanames{fr}->{3324260} = "Romorantin\-Lanthenay";
$areanames{fr}->{3324261} = "Saint\-Aignan";
$areanames{fr}->{3324262} = "Vendôme";
$areanames{fr}->{3324263} = "Gien";
$areanames{fr}->{3324264} = "Montargis";
$areanames{fr}->{3324265} = "Pithiviers";
$areanames{fr}->{3324266} = "Châteauroux";
$areanames{fr}->{3324267} = "Tours";
$areanames{fr}->{3324268} = "Blois";
$areanames{fr}->{3324269} = "Chartres";
$areanames{fr}->{3324270} = "Aubigny\-sur\-Nère";
$areanames{fr}->{3324271} = "Bourges";
$areanames{fr}->{3324272} = "La\ Guerche\-sur\-lAubois";
$areanames{fr}->{3324273} = "Sancerre";
$areanames{fr}->{3324274} = "Saint\-Amand\-Montrond";
$areanames{fr}->{3324275} = "Vierzon";
$areanames{fr}->{3324276} = "Chartres";
$areanames{fr}->{3324277} = "Châteaudun";
$areanames{fr}->{3324278} = "Dreux";
$areanames{fr}->{3324279} = "Nogent\-le\-Rotrou";
$areanames{fr}->{3324280} = "Châteauroux";
$areanames{fr}->{3324281} = "Issoudun";
$areanames{fr}->{3324282} = "La\ Châtre";
$areanames{fr}->{3324283} = "Le\ Blanc";
$areanames{fr}->{3324284} = "Valençay";
$areanames{fr}->{3324285} = "Amboise";
$areanames{fr}->{3324286} = "Chinon";
$areanames{fr}->{3324287} = "Loches";
$areanames{fr}->{3324288} = "Tours";
$areanames{fr}->{3324289} = "Blois";
$areanames{fr}->{3324290} = "Romorantin\-Lanthenay";
$areanames{fr}->{3324291} = "Saint\-Aignan";
$areanames{fr}->{3324292} = "Vendôme";
$areanames{fr}->{3324293} = "Gien";
$areanames{fr}->{3324294} = "Montargis";
$areanames{fr}->{3324295} = "Orléans";
$areanames{fr}->{3324296} = "Pithiviers";
$areanames{fr}->{3324297} = "Tours";
$areanames{fr}->{3324298} = "Saint\-Aignan";
$areanames{fr}->{3324299} = "Romorantin\-Lanthenay";
$areanames{fr}->{3324301} = "Évron";
$areanames{fr}->{3324304} = "Mayenne";
$areanames{fr}->{3324305} = "Ernée";
$areanames{fr}->{3324307} = "Château\-Gontier";
$areanames{fr}->{3324308} = "Gorron";
$areanames{fr}->{3324309} = "Château\-Gontier";
$areanames{fr}->{3324314} = "Le\ Mans";
$areanames{fr}->{3324316} = "Le\ Mans";
$areanames{fr}->{3324321} = "Arnage";
$areanames{fr}->{3324323} = "Le\ Mans";
$areanames{fr}->{3324324} = "Le\ Mans";
$areanames{fr}->{3324326} = "Laval";
$areanames{fr}->{3324328} = "Le\ Mans";
$areanames{fr}->{3324329} = "Bonnétable";
$areanames{fr}->{3324330} = "Mayenne";
$areanames{fr}->{3324332} = "Mayenne";
$areanames{fr}->{3324339} = "Le\ Mans";
$areanames{fr}->{3324340} = "Changé";
$areanames{fr}->{3324341} = "Le\ Mans";
$areanames{fr}->{3324342} = "Écommoy";
$areanames{fr}->{3324343} = "Le\ Mans";
$areanames{fr}->{3324344} = "Château\-du\-Loir";
$areanames{fr}->{3324348} = "La\ Flèche";
$areanames{fr}->{3324349} = "Laval";
$areanames{fr}->{3324350} = "Le\ Mans";
$areanames{fr}->{3324352} = "Le\ Mans";
$areanames{fr}->{3324353} = "Laval";
$areanames{fr}->{3324354} = "Le\ Mans";
$areanames{fr}->{3324356} = "Laval";
$areanames{fr}->{3324358} = "Laval";
$areanames{fr}->{3324359} = "Laval";
$areanames{fr}->{3324360} = "La\ Ferté\ Bernard";
$areanames{fr}->{3324362} = "Sablé\-sur\-Sarthe";
$areanames{fr}->{3324363} = "Saint\-Calais";
$areanames{fr}->{3324366} = "Laval";
$areanames{fr}->{3324367} = "Laval";
$areanames{fr}->{3324369} = "Laval";
$areanames{fr}->{3324371} = "La\ Ferté\ Bernard";
$areanames{fr}->{3324372} = "Le\ Mans";
$areanames{fr}->{3324374} = "Le\ Mans";
$areanames{fr}->{3324375} = "Le\ Mans";
$areanames{fr}->{3324377} = "Le\ Mans";
$areanames{fr}->{3324378} = "Le\ Mans";
$areanames{fr}->{3324380} = "Allonnes";
$areanames{fr}->{3324381} = "Le\ Mans";
$areanames{fr}->{3324382} = "Le\ Mans";
$areanames{fr}->{3324383} = "Le\ Mans";
$areanames{fr}->{3324384} = "Le\ Mans";
$areanames{fr}->{3324385} = "Le\ Mans";
$areanames{fr}->{3324386} = "Le\ Mans";
$areanames{fr}->{3324389} = "Connerré";
$areanames{fr}->{3324391} = "Laval";
$areanames{fr}->{3324392} = "Sablé\-sur\-Sarthe";
$areanames{fr}->{3324394} = "La\ Flèche";
$areanames{fr}->{3324395} = "Sablé\-sur\-Sarthe";
$areanames{fr}->{3324400} = "Le\ Mans";
$areanames{fr}->{3324401} = "Angers";
$areanames{fr}->{3324402} = "Le\ Mans";
$areanames{fr}->{3324403} = "Ancenis";
$areanames{fr}->{3324404} = "Blain";
$areanames{fr}->{3324405} = "Châteaubriant";
$areanames{fr}->{3324406} = "Pornic";
$areanames{fr}->{3324407} = "Saint\-Nazaire";
$areanames{fr}->{3324408} = "Baugé\-en\-Anjou";
$areanames{fr}->{3324409} = "Cholet";
$areanames{fr}->{3324410} = "Angers";
$areanames{fr}->{3324411} = "Baugé\-en\-Anjou";
$areanames{fr}->{3324412} = "Beaumont\-sur\-Sarthe";
$areanames{fr}->{3324413} = "Château\-du\-Loir";
$areanames{fr}->{3324414} = "Château\-Gontier";
$areanames{fr}->{3324415} = "La\ Ferte\-Bernard";
$areanames{fr}->{3324416} = "La\ Flèche";
$areanames{fr}->{3324417} = "Fontenay\-le\-Comte";
$areanames{fr}->{3324418} = "Les\ Herbiers";
$areanames{fr}->{3324419} = "Laval";
$areanames{fr}->{3324420} = "Luçon";
$areanames{fr}->{3324421} = "Le\ Mans";
$areanames{fr}->{3324422} = "Mayenne";
$areanames{fr}->{3324423} = "Les\ Sables\ d\'Olonne";
$areanames{fr}->{3324424} = "Sablé\-sur\-Sarthe";
$areanames{fr}->{3324425} = "Saint\-Calais";
$areanames{fr}->{3324426} = "Saumur";
$areanames{fr}->{3324427} = "Saumur";
$areanames{fr}->{3324428} = "Segre";
$areanames{fr}->{3324429} = "Mayenne";
$areanames{fr}->{3324430} = "Beaumont\-sur\-Sarthe";
$areanames{fr}->{3324431} = "Château\-du\-Loir";
$areanames{fr}->{3324432} = "La\ Ferte\-Bernard";
$areanames{fr}->{3324433} = "La\ Flèche";
$areanames{fr}->{3324434} = "Sablé\-sur\-Sarthe";
$areanames{fr}->{3324435} = "Saint\-Calais";
$areanames{fr}->{3324436} = "Challans";
$areanames{fr}->{3324437} = "Fontenay\-le\-Comte";
$areanames{fr}->{3324438} = "Les\ Herbiers";
$areanames{fr}->{3324439} = "Luçon";
$areanames{fr}->{3324440} = "La\ Roche\-sur\-Yon";
$areanames{fr}->{3324441} = "Les\ Sables\ d\'Olonne";
$areanames{fr}->{3324442} = "Ancenis";
$areanames{fr}->{3324443} = "Blain";
$areanames{fr}->{3324444} = "Châteaubriant";
$areanames{fr}->{3324445} = "Fontenay\-le\-Comte";
$areanames{fr}->{3324446} = "La\ Flèche";
$areanames{fr}->{3324447} = "Laval";
$areanames{fr}->{3324448} = "Pornic";
$areanames{fr}->{3324449} = "Sablé\-sur\-Sarthe";
$areanames{fr}->{3324450} = "Segre";
$areanames{fr}->{3324451} = "Nantes";
$areanames{fr}->{3324452} = "Château\-du\-Loir";
$areanames{fr}->{3324453} = "La\ Ferte\-Bernard";
$areanames{fr}->{3324454} = "La\ Flèche";
$areanames{fr}->{3324455} = "Sablé\-sur\-Sarthe";
$areanames{fr}->{3324456} = "Saint\-Calais";
$areanames{fr}->{3324457} = "Fontenay\-le\-Comte";
$areanames{fr}->{3324458} = "Les\ Herbiers";
$areanames{fr}->{3324459} = "Luçon";
$areanames{fr}->{3324460} = "Les\ Sables\ d\'Olonne";
$areanames{fr}->{3324461} = "Angers";
$areanames{fr}->{3324462} = "Saint\-Nazaire";
$areanames{fr}->{3324463} = "Angers";
$areanames{fr}->{3324464} = "Laval";
$areanames{fr}->{3324465} = "Le\ Mans";
$areanames{fr}->{3324466} = "Nantes";
$areanames{fr}->{3324467} = "Saint\-Nazaire";
$areanames{fr}->{3324468} = "Angers";
$areanames{fr}->{3324469} = "Cholet";
$areanames{fr}->{3324470} = "Nantes";
$areanames{fr}->{3324471} = "Le\ Mans";
$areanames{fr}->{3324472} = "Laval";
$areanames{fr}->{3324473} = "Saint\-Nazaire";
$areanames{fr}->{3324474} = "Ancenis";
$areanames{fr}->{3324475} = "Blain";
$areanames{fr}->{3324476} = "Nantes";
$areanames{fr}->{3324477} = "Nantes";
$areanames{fr}->{3324478} = "Challans";
$areanames{fr}->{3324479} = "Châteaubriant";
$areanames{fr}->{3324480} = "La\ Roche\-sur\-Yon";
$areanames{fr}->{3324481} = "Le\ Mans";
$areanames{fr}->{3324482} = "Pornic";
$areanames{fr}->{3324483} = "Segre";
$areanames{fr}->{3324484} = "Nantes";
$areanames{fr}->{3324485} = "Angers";
$areanames{fr}->{3324486} = "Ancenis";
$areanames{fr}->{3324487} = "Angers";
$areanames{fr}->{3324488} = "Angers";
$areanames{fr}->{3324489} = "Baugé\-en\-Anjou";
$areanames{fr}->{3324490} = "Saint\-Nazaire";
$areanames{fr}->{3324491} = "Beaumont\-sur\-Sarthe";
$areanames{fr}->{3324492} = "Blain";
$areanames{fr}->{3324493} = "Challans";
$areanames{fr}->{3324494} = "Châteaubriant";
$areanames{fr}->{3324495} = "Château\-du\-Loir";
$areanames{fr}->{3324496} = "Château\-Gontier";
$areanames{fr}->{3324497} = "Cholet";
$areanames{fr}->{3324498} = "Fontenay\-le\-Comte";
$areanames{fr}->{3324499} = "Le\ Mans";
$areanames{fr}->{3324500} = "Nogent\-le\-Rotrou";
$areanames{fr}->{3324501} = "Le\ Blanc";
$areanames{fr}->{3324502} = "Châteauroux";
$areanames{fr}->{3324503} = "La\ Châtre";
$areanames{fr}->{3324504} = "Issoudun";
$areanames{fr}->{3324505} = "Valençay";
$areanames{fr}->{3324506} = "Amboise";
$areanames{fr}->{3324507} = "Chinon";
$areanames{fr}->{3324508} = "Loches";
$areanames{fr}->{3324509} = "Tours";
$areanames{fr}->{3324510} = "Blois";
$areanames{fr}->{3324511} = "Romorantin\-Lanthenay";
$areanames{fr}->{3324512} = "Saint\-Aignan";
$areanames{fr}->{3324513} = "Vendôme";
$areanames{fr}->{3324514} = "Gien";
$areanames{fr}->{3324515} = "Montargis";
$areanames{fr}->{3324516} = "Pithiviers";
$areanames{fr}->{3324517} = "Blois";
$areanames{fr}->{3324518} = "Bourges";
$areanames{fr}->{3324519} = "La\ Guerche\-sur\-lAubois";
$areanames{fr}->{3324520} = "Châteauroux";
$areanames{fr}->{3324521} = "Blois";
$areanames{fr}->{3324522} = "Montargis";
$areanames{fr}->{3324523} = "Orléans";
$areanames{fr}->{3324524} = "Châteauroux";
$areanames{fr}->{3324525} = "Tours";
$areanames{fr}->{3324526} = "Chartres";
$areanames{fr}->{3324527} = "Châteaudun";
$areanames{fr}->{3324528} = "Le\ Blanc";
$areanames{fr}->{3324529} = "La\ Châtre";
$areanames{fr}->{3324530} = "Orléans";
$areanames{fr}->{3324531} = "Valençay";
$areanames{fr}->{3324532} = "Chinon";
$areanames{fr}->{3324533} = "Loches";
$areanames{fr}->{3324534} = "Tours";
$areanames{fr}->{3324535} = "Blois";
$areanames{fr}->{3324536} = "Romorantin\-Lanthenay";
$areanames{fr}->{3324537} = "Saint\-Aignan";
$areanames{fr}->{3324538} = "Gien";
$areanames{fr}->{3324539} = "Montargis";
$areanames{fr}->{3324540} = "Orléans";
$areanames{fr}->{3324541} = "Bourges";
$areanames{fr}->{3324542} = "La\ Guerche\-sur\-lAubois";
$areanames{fr}->{3324543} = "Saint\-Amand\-Montrond";
$areanames{fr}->{3324544} = "Sancerre";
$areanames{fr}->{3324545} = "Vierzon";
$areanames{fr}->{3324546} = "Issoudun";
$areanames{fr}->{3324547} = "Tours";
$areanames{fr}->{3324548} = "Orléans";
$areanames{fr}->{3324549} = "Chinon";
$areanames{fr}->{3324550} = "Blois";
$areanames{fr}->{3324551} = "Saint\-Aignan";
$areanames{fr}->{3324552} = "Châteauroux";
$areanames{fr}->{3324553} = "La\ Guerche\-sur\-lAubois";
$areanames{fr}->{3324554} = "Issoudun";
$areanames{fr}->{3324555} = "Tours";
$areanames{fr}->{3324556} = "Vendôme";
$areanames{fr}->{3324557} = "Nogent\-le\-Rotrou";
$areanames{fr}->{3324558} = "Saint\-Amand\-Montrond";
$areanames{fr}->{3324559} = "Chinon";
$areanames{fr}->{3324560} = "Aubigny\-sur\-Nère";
$areanames{fr}->{3324561} = "Loches";
$areanames{fr}->{3324562} = "Gien";
$areanames{fr}->{3324563} = "Romorantin\-Lanthenay";
$areanames{fr}->{3324564} = "Amboise";
$areanames{fr}->{3324565} = "Bourges";
$areanames{fr}->{3324566} = "Pithiviers";
$areanames{fr}->{3324567} = "Aubigny\-sur\-Nère";
$areanames{fr}->{3324568} = "Montargis";
$areanames{fr}->{3324569} = "Orléans";
$areanames{fr}->{3324570} = "Valençay";
$areanames{fr}->{3324571} = "Châteaudun";
$areanames{fr}->{3324572} = "Le\ Blanc";
$areanames{fr}->{3324573} = "Chartres";
$areanames{fr}->{3324574} = "Dreux";
$areanames{fr}->{3324575} = "Sancerre";
$areanames{fr}->{3324576} = "La\ Châtre";
$areanames{fr}->{3324577} = "Vierzon";
$areanames{fr}->{3324578} = "Aubigny\-sur\-Nère";
$areanames{fr}->{3324579} = "Bourges";
$areanames{fr}->{3324580} = "La\ Guerche\-sur\-lAubois";
$areanames{fr}->{3324581} = "Chartres";
$areanames{fr}->{3324582} = "Châteaudun";
$areanames{fr}->{3324583} = "Dreux";
$areanames{fr}->{3324584} = "Nogent\-le\-Rotrou";
$areanames{fr}->{3324585} = "Le\ Blanc";
$areanames{fr}->{3324586} = "Châteauroux";
$areanames{fr}->{3324587} = "La\ Châtre";
$areanames{fr}->{3324588} = "Issoudun";
$areanames{fr}->{3324589} = "Valençay";
$areanames{fr}->{3324590} = "Amboise";
$areanames{fr}->{3324591} = "Chinon";
$areanames{fr}->{3324592} = "Loches";
$areanames{fr}->{3324593} = "Tours";
$areanames{fr}->{3324594} = "Blois";
$areanames{fr}->{3324595} = "Romorantin\-Lanthenay";
$areanames{fr}->{3324596} = "Saint\-Aignan";
$areanames{fr}->{3324597} = "Vendôme";
$areanames{fr}->{3324598} = "Gien";
$areanames{fr}->{3324599} = "Montargis";
$areanames{fr}->{3324600} = "Orléans";
$areanames{fr}->{3324601} = "Pithiviers";
$areanames{fr}->{3324602} = "Orléans";
$areanames{fr}->{3324603} = "Loches";
$areanames{fr}->{3324604} = "Dreux";
$areanames{fr}->{3324605} = "Saint\-Amand\-Montrond";
$areanames{fr}->{3324606} = "Sancerre";
$areanames{fr}->{3324607} = "Vierzon";
$areanames{fr}->{3324608} = "Bourges";
$areanames{fr}->{3324609} = "Orléans";
$areanames{fr}->{3324610} = "Tours";
$areanames{fr}->{3324611} = "Aubigny\-sur\-Nère";
$areanames{fr}->{3324612} = "Saint\-Amand\-Montrond";
$areanames{fr}->{3324613} = "Sancerre";
$areanames{fr}->{3324614} = "Nogent\-le\-Rotrou";
$areanames{fr}->{3324615} = "Le\ Blanc";
$areanames{fr}->{3324616} = "Châteauroux";
$areanames{fr}->{3324617} = "La\ Châtre";
$areanames{fr}->{3324618} = "Issoudun";
$areanames{fr}->{3324619} = "Valençay";
$areanames{fr}->{3324620} = "Amboise";
$areanames{fr}->{3324621} = "Chinon";
$areanames{fr}->{3324622} = "Saint\-Aignan";
$areanames{fr}->{3324623} = "Tours";
$areanames{fr}->{3324624} = "Gien";
$areanames{fr}->{3324625} = "Montargis";
$areanames{fr}->{3324626} = "Orléans";
$areanames{fr}->{3324627} = "Pithiviers";
$areanames{fr}->{3324628} = "Aubigny\-sur\-Nère";
$areanames{fr}->{3324629} = "Bourges";
$areanames{fr}->{3324630} = "La\ Guerche\-sur\-lAubois";
$areanames{fr}->{3324631} = "Saint\-Amand\-Montrond";
$areanames{fr}->{3324632} = "Sancerre";
$areanames{fr}->{3324633} = "Vierzon";
$areanames{fr}->{3324634} = "Chartres";
$areanames{fr}->{3324635} = "Châteaudun";
$areanames{fr}->{3324636} = "Châteaudun";
$areanames{fr}->{3324637} = "Nogent\-le\-Rotrou";
$areanames{fr}->{3324638} = "Le\ Blanc";
$areanames{fr}->{3324639} = "Châteauroux";
$areanames{fr}->{3324640} = "La\ Châtre";
$areanames{fr}->{3324641} = "Issoudun";
$areanames{fr}->{3324642} = "Valençay";
$areanames{fr}->{3324643} = "Amboise";
$areanames{fr}->{3324644} = "Chinon";
$areanames{fr}->{3324645} = "Loches";
$areanames{fr}->{3324646} = "Tours";
$areanames{fr}->{3324647} = "Orléans";
$areanames{fr}->{3324648} = "Tours";
$areanames{fr}->{3324649} = "Blois";
$areanames{fr}->{3324650} = "Romorantin\-Lanthenay";
$areanames{fr}->{3324651} = "Saint\-Aignan";
$areanames{fr}->{3324652} = "Vendôme";
$areanames{fr}->{3324653} = "Gien";
$areanames{fr}->{3324654} = "Montargis";
$areanames{fr}->{3324655} = "Orléans";
$areanames{fr}->{3324656} = "Chartres";
$areanames{fr}->{3324657} = "Pithiviers";
$areanames{fr}->{3324658} = "Aubigny\-sur\-Nère";
$areanames{fr}->{3324659} = "Bourges";
$areanames{fr}->{3324660} = "La\ Guerche\-sur\-lAubois";
$areanames{fr}->{3324661} = "Saint\-Amand\-Montrond";
$areanames{fr}->{3324662} = "Sancerre";
$areanames{fr}->{3324663} = "Vierzon";
$areanames{fr}->{3324664} = "Chartres";
$areanames{fr}->{3324665} = "Tours";
$areanames{fr}->{3324666} = "Montargis";
$areanames{fr}->{3324667} = "Tours";
$areanames{fr}->{3324668} = "Blois";
$areanames{fr}->{3324669} = "Dreux";
$areanames{fr}->{3324670} = "Nogent\-le\-Rotrou";
$areanames{fr}->{3324671} = "Tours";
$areanames{fr}->{3324672} = "Orléans";
$areanames{fr}->{3324673} = "Châteaudun";
$areanames{fr}->{3324674} = "Amboise";
$areanames{fr}->{3324675} = "Le\ Blanc";
$areanames{fr}->{3324676} = "Châteaudun";
$areanames{fr}->{3324677} = "Chinon";
$areanames{fr}->{3324678} = "Loches";
$areanames{fr}->{3324679} = "Blois";
$areanames{fr}->{3324680} = "Bourges";
$areanames{fr}->{3324681} = "Chartres";
$areanames{fr}->{3324682} = "Dreux";
$areanames{fr}->{3324683} = "Dreux";
$areanames{fr}->{3324684} = "Orléans";
$areanames{fr}->{3324685} = "Orléans";
$areanames{fr}->{3324686} = "Châteauroux";
$areanames{fr}->{3324687} = "Blois";
$areanames{fr}->{3324688} = "Tours";
$areanames{fr}->{3324689} = "Dreux";
$areanames{fr}->{3324690} = "Orléans";
$areanames{fr}->{3324691} = "Orléans";
$areanames{fr}->{3324692} = "Blois";
$areanames{fr}->{3324693} = "Tours";
$areanames{fr}->{3324694} = "Bourges";
$areanames{fr}->{3324695} = "Châteauroux";
$areanames{fr}->{3324696} = "Bourges";
$areanames{fr}->{3324697} = "Dreux";
$areanames{fr}->{3324698} = "Blois";
$areanames{fr}->{3324699} = "Tours";
$areanames{fr}->{3324705} = "Tours";
$areanames{fr}->{332471} = "Nord\ Ouest";
$areanames{fr}->{3324719} = "Loches";
$areanames{fr}->{3324720} = "Tours";
$areanames{fr}->{3324721} = "Tours";
$areanames{fr}->{3324723} = "Amboise";
$areanames{fr}->{3324725} = "Chambray\-lès\-Tours";
$areanames{fr}->{3324727} = "Saint\-Avertin";
$areanames{fr}->{3324728} = "Chambray\-lès\-Tours";
$areanames{fr}->{3324730} = "Amboise";
$areanames{fr}->{3324731} = "Tours";
$areanames{fr}->{3324732} = "Saint\-Pierre\-des\-Corps";
$areanames{fr}->{3324736} = "Tours";
$areanames{fr}->{3324737} = "Tours";
$areanames{fr}->{3324738} = "Tours";
$areanames{fr}->{3324739} = "Tours";
$areanames{fr}->{3324741} = "Tours";
$areanames{fr}->{3324742} = "Fondettes";
$areanames{fr}->{3324743} = "Truyes";
$areanames{fr}->{3324744} = "Saint\-Pierre\-des\-Corps";
$areanames{fr}->{3324745} = "Azay\-le\-Rideau";
$areanames{fr}->{3324746} = "Tours";
$areanames{fr}->{3324747} = "Tours";
$areanames{fr}->{3324748} = "Chambray\-lès\-Tours";
$areanames{fr}->{3324749} = "Fondettes";
$areanames{fr}->{3324750} = "Montlouis\-sur\-Loire";
$areanames{fr}->{3324751} = "Tours";
$areanames{fr}->{3324752} = "Vouvray";
$areanames{fr}->{3324753} = "Joué\-lès\-Tours";
$areanames{fr}->{3324754} = "Tours";
$areanames{fr}->{3324755} = "Luynes";
$areanames{fr}->{3324757} = "Amboise";
$areanames{fr}->{3324759} = "Loches";
$areanames{fr}->{3324760} = "Tours";
$areanames{fr}->{3324761} = "Tours";
$areanames{fr}->{3324763} = "Saint\-Pierre\-des\-Corps";
$areanames{fr}->{3324764} = "Tours";
$areanames{fr}->{3324765} = "Sainte\-Maure\-de\-Touraine";
$areanames{fr}->{3324766} = "Tours";
$areanames{fr}->{3324767} = "Joué\-lès\-Tours";
$areanames{fr}->{3324768} = "Joué\-lès\-Tours";
$areanames{fr}->{3324770} = "Tours";
$areanames{fr}->{3324771} = "Chambray\-lès\-Tours";
$areanames{fr}->{3324773} = "Joué\-lès\-Tours";
$areanames{fr}->{3324774} = "Saint\-Avertin";
$areanames{fr}->{3324775} = "Tours";
$areanames{fr}->{3324776} = "Tours";
$areanames{fr}->{3324780} = "Joué\-lès\-Tours";
$areanames{fr}->{3324785} = "Tours";
$areanames{fr}->{3324786} = "Tours";
$areanames{fr}->{3324788} = "Tours";
$areanames{fr}->{3324791} = "Loches";
$areanames{fr}->{3324793} = "Chinon";
$areanames{fr}->{3324796} = "Langeais";
$areanames{fr}->{3324797} = "Bourgueil";
$areanames{fr}->{3324798} = "Chinon";
$areanames{fr}->{3324802} = "Bourges";
$areanames{fr}->{332481} = "Nord\ Ouest";
$areanames{fr}->{3324816} = "Bourges";
$areanames{fr}->{332482} = "Bourges";
$areanames{fr}->{3324828} = "Nord\ Ouest";
$areanames{fr}->{3324829} = "Nord\ Ouest";
$areanames{fr}->{3324830} = "Saint\-Germain\-du\-Puy";
$areanames{fr}->{332484} = "Nord\ Ouest";
$areanames{fr}->{3324848} = "Bourges";
$areanames{fr}->{3324850} = "Bourges";
$areanames{fr}->{3324852} = "Vierzon";
$areanames{fr}->{3324854} = "Sancerre";
$areanames{fr}->{3324855} = "Saint\-Florent\-sur\-Cher";
$areanames{fr}->{3324857} = "Mehun\-sur\-Yèvre";
$areanames{fr}->{3324858} = "Aubigny\-sur\-Nère";
$areanames{fr}->{3324859} = "Dun\-sur\-Auron";
$areanames{fr}->{3324861} = "Châteaumeillant";
$areanames{fr}->{3324865} = "Bourges";
$areanames{fr}->{3324866} = "Bourges";
$areanames{fr}->{3324867} = "Bourges";
$areanames{fr}->{3324868} = "Bourges";
$areanames{fr}->{3324869} = "Bourges";
$areanames{fr}->{3324870} = "Bourges";
$areanames{fr}->{3324871} = "Vierzon";
$areanames{fr}->{3324873} = "Argent\-sur\-Sauldre";
$areanames{fr}->{3324874} = "Sancoins";
$areanames{fr}->{3324875} = "Vierzon";
$areanames{fr}->{3324878} = "Sancerre";
$areanames{fr}->{3324880} = "Cuffy";
$areanames{fr}->{3324881} = "Aubigny\-sur\-Nère";
$areanames{fr}->{3324896} = "Saint\-Amand\-Montrond";
$areanames{fr}->{3324900} = "La\ Ferte\-Bernard";
$areanames{fr}->{3324901} = "La\ Flèche";
$areanames{fr}->{3324902} = "La\ Roche\-sur\-Yon";
$areanames{fr}->{3324903} = "Laval";
$areanames{fr}->{3324904} = "Le\ Mans";
$areanames{fr}->{3324905} = "Les\ Herbiers";
$areanames{fr}->{3324906} = "Les\ Sables\ d\'Olonne";
$areanames{fr}->{3324907} = "Luçon";
$areanames{fr}->{3324908} = "Mayenne";
$areanames{fr}->{3324909} = "Nantes";
$areanames{fr}->{3324910} = "Nantes";
$areanames{fr}->{3324911} = "Pornic";
$areanames{fr}->{3324912} = "Sablé\-sur\-Sarthe";
$areanames{fr}->{3324913} = "Saint\-Calais";
$areanames{fr}->{3324914} = "Saint\-Nazaire";
$areanames{fr}->{3324915} = "Saumur";
$areanames{fr}->{3324916} = "Segre";
$areanames{fr}->{3324917} = "Nantes";
$areanames{fr}->{3324918} = "Angers";
$areanames{fr}->{3324919} = "Saumur";
$areanames{fr}->{3324920} = "Mayenne";
$areanames{fr}->{3324921} = "La\ Flèche";
$areanames{fr}->{3324922} = "Les\ Herbiers";
$areanames{fr}->{3324923} = "Le\ Mans";
$areanames{fr}->{3324924} = "Ancenis";
$areanames{fr}->{3324925} = "Blain";
$areanames{fr}->{3324926} = "Châteaubriant";
$areanames{fr}->{3324927} = "Pornic";
$areanames{fr}->{3324928} = "Saint\-Nazaire";
$areanames{fr}->{3324929} = "Angers";
$areanames{fr}->{3324930} = "Baugé\-en\-Anjou";
$areanames{fr}->{3324931} = "Cholet";
$areanames{fr}->{3324932} = "Saumur";
$areanames{fr}->{3324933} = "Segre";
$areanames{fr}->{3324934} = "Château\-Gontier";
$areanames{fr}->{3324935} = "Laval";
$areanames{fr}->{3324936} = "Mayenne";
$areanames{fr}->{3324937} = "Beaumont\-sur\-Sarthe";
$areanames{fr}->{3324938} = "Château\-du\-Loir";
$areanames{fr}->{3324939} = "La\ Ferte\-Bernard";
$areanames{fr}->{3324944} = "Nantes";
$areanames{fr}->{3324950} = "La\ Roche\-sur\-Yon";
$areanames{fr}->{3324951} = "Les\ Sables\ d\'Olonne";
$areanames{fr}->{3324952} = "Saint\-Nazaire";
$areanames{fr}->{3324953} = "Nantes";
$areanames{fr}->{3324954} = "Le\ Mans";
$areanames{fr}->{3324955} = "Sablé\-sur\-Sarthe";
$areanames{fr}->{3324956} = "Saint\-Calais";
$areanames{fr}->{3324957} = "Fontenay\-le\-Comte";
$areanames{fr}->{3324958} = "Luçon";
$areanames{fr}->{3324959} = "Les\ Sables\ d\'Olonne";
$areanames{fr}->{3324960} = "Ancenis";
$areanames{fr}->{3324961} = "Nantes";
$areanames{fr}->{3324962} = "Nantes";
$areanames{fr}->{3324963} = "Saint\-Nazaire";
$areanames{fr}->{3324964} = "Baugé\-en\-Anjou";
$areanames{fr}->{3324965} = "Saumur";
$areanames{fr}->{3324966} = "Mayenne";
$areanames{fr}->{3324967} = "Beaumont\-sur\-Sarthe";
$areanames{fr}->{3324968} = "La\ Ferte\-Bernard";
$areanames{fr}->{3324969} = "La\ Flèche";
$areanames{fr}->{3324970} = "Saint\-Nazaire";
$areanames{fr}->{3324971} = "Angers";
$areanames{fr}->{3324972} = "Cholet";
$areanames{fr}->{3324973} = "Saumur";
$areanames{fr}->{3324974} = "Laval";
$areanames{fr}->{3324975} = "Angers";
$areanames{fr}->{3324976} = "Cholet";
$areanames{fr}->{3324977} = "Saint\-Nazaire";
$areanames{fr}->{3324978} = "Le\ Mans";
$areanames{fr}->{3324979} = "Nantes";
$areanames{fr}->{3324980} = "Château\-Gontier";
$areanames{fr}->{3324981} = "Saumur";
$areanames{fr}->{3324982} = "Le\ Mans";
$areanames{fr}->{3324983} = "Laval";
$areanames{fr}->{3324984} = "Nantes";
$areanames{fr}->{3324985} = "La\ Roche\-sur\-Yon";
$areanames{fr}->{3324986} = "Blain";
$areanames{fr}->{3324987} = "Angers";
$areanames{fr}->{3324988} = "Nantes";
$areanames{fr}->{3324989} = "Angers";
$areanames{fr}->{3324990} = "Baugé\-en\-Anjou";
$areanames{fr}->{3324991} = "Châteaubriant";
$areanames{fr}->{3324992} = "Saint\-Nazaire";
$areanames{fr}->{3324993} = "Segre";
$areanames{fr}->{3324994} = "La\ Roche\-sur\-Yon";
$areanames{fr}->{3324995} = "Saint\-Calais";
$areanames{fr}->{3324996} = "Laval";
$areanames{fr}->{3324997} = "La\ Flèche";
$areanames{fr}->{3324998} = "Les\ Sables\ d\'Olonne";
$areanames{fr}->{3324999} = "Mayenne";
$areanames{fr}->{3325000} = "L\'Aigle";
$areanames{fr}->{3325001} = "Caen";
$areanames{fr}->{3325002} = "Alençon";
$areanames{fr}->{3325003} = "Argentan";
$areanames{fr}->{3325004} = "Flers";
$areanames{fr}->{3325005} = "Mortagne\-au\-Perche";
$areanames{fr}->{3325006} = "Avranches";
$areanames{fr}->{3325007} = "L\'Aigle";
$areanames{fr}->{3325008} = "Caen";
$areanames{fr}->{3325009} = "Bayeux";
$areanames{fr}->{3325010} = "Caen";
$areanames{fr}->{3325011} = "Deauville";
$areanames{fr}->{3325012} = "Falaise";
$areanames{fr}->{3325013} = "Lisieux";
$areanames{fr}->{3325014} = "Vire";
$areanames{fr}->{3325015} = "Caen";
$areanames{fr}->{3325016} = "Carentan\-les\-Marais";
$areanames{fr}->{3325017} = "Coutances";
$areanames{fr}->{3325018} = "Saint\-Lô";
$areanames{fr}->{3325019} = "Alençon";
$areanames{fr}->{3325020} = "Argentan";
$areanames{fr}->{3325021} = "Flers";
$areanames{fr}->{3325022} = "Caen";
$areanames{fr}->{3325023} = "Mortagne\-au\-Perche";
$areanames{fr}->{3325024} = "Alençon";
$areanames{fr}->{3325025} = "Argentan";
$areanames{fr}->{3325026} = "Avranches";
$areanames{fr}->{3325027} = "Bayeux";
$areanames{fr}->{3325028} = "Caen";
$areanames{fr}->{3325029} = "Carentan\-les\-Marais";
$areanames{fr}->{3325030} = "Caen";
$areanames{fr}->{3325031} = "Deauville";
$areanames{fr}->{3325032} = "Caen";
$areanames{fr}->{3325033} = "Bayeux";
$areanames{fr}->{3325034} = "Falaise";
$areanames{fr}->{3325035} = "Bayeux";
$areanames{fr}->{3325036} = "Lisieux";
$areanames{fr}->{3325037} = "Vire";
$areanames{fr}->{3325038} = "L\'Aigle";
$areanames{fr}->{3325039} = "Alençon";
$areanames{fr}->{3325040} = "Argentan";
$areanames{fr}->{3325041} = "Flers";
$areanames{fr}->{3325042} = "Mortagne\-au\-Perche";
$areanames{fr}->{3325043} = "Deauville";
$areanames{fr}->{3325044} = "Falaise";
$areanames{fr}->{3325045} = "Flers";
$areanames{fr}->{3325046} = "Lisieux";
$areanames{fr}->{3325047} = "Mortagne\-au\-Perche";
$areanames{fr}->{3325048} = "Saint\-Lô";
$areanames{fr}->{3325049} = "Vire";
$areanames{fr}->{3325050} = "Caen";
$areanames{fr}->{3325051} = "Alençon";
$areanames{fr}->{3325052} = "Coutances";
$areanames{fr}->{3325053} = "Caen";
$areanames{fr}->{3325054} = "Caen";
$areanames{fr}->{3325055} = "Bayeux";
$areanames{fr}->{3325056} = "Caen";
$areanames{fr}->{3325057} = "Caen";
$areanames{fr}->{3325058} = "Falaise";
$areanames{fr}->{3325059} = "Bayeux";
$areanames{fr}->{3325065} = "Caen";
$areanames{fr}->{3325070} = "Carentan\-les\-Marais";
$areanames{fr}->{3325071} = "Saint\-Lô";
$areanames{fr}->{3325072} = "Alençon";
$areanames{fr}->{3325073} = "Vire";
$areanames{fr}->{3325074} = "Argentan";
$areanames{fr}->{3325075} = "Flers";
$areanames{fr}->{3325076} = "L\'Aigle";
$areanames{fr}->{3325077} = "Mortagne\-au\-Perche";
$areanames{fr}->{3325078} = "Caen";
$areanames{fr}->{3325079} = "Carentan\-les\-Marais";
$areanames{fr}->{3325080} = "Saint\-Lô";
$areanames{fr}->{3325081} = "Avranches";
$areanames{fr}->{3325082} = "L\'Aigle";
$areanames{fr}->{3325083} = "Avranches";
$areanames{fr}->{3325084} = "Bayeux";
$areanames{fr}->{3325085} = "Caen";
$areanames{fr}->{3325086} = "Carentan\-les\-Marais";
$areanames{fr}->{3325087} = "Coutances";
$areanames{fr}->{3325088} = "Bayeux";
$areanames{fr}->{3325089} = "Deauville";
$areanames{fr}->{3325090} = "Alençon";
$areanames{fr}->{3325091} = "Caen";
$areanames{fr}->{3325092} = "Deauville";
$areanames{fr}->{3325093} = "Falaise";
$areanames{fr}->{3325094} = "Lisieux";
$areanames{fr}->{3325095} = "Vire";
$areanames{fr}->{3325096} = "Avranches";
$areanames{fr}->{3325097} = "Carentan\-les\-Marais";
$areanames{fr}->{3325098} = "Coutances";
$areanames{fr}->{3325099} = "Saint\-Lô";
$areanames{fr}->{3325105} = "La\ Roche\ sur\ Yon";
$areanames{fr}->{3325108} = "La\ Roche\ sur\ Yon";
$areanames{fr}->{3325110} = "Saint\-Nazaire";
$areanames{fr}->{3325111} = "Rezé";
$areanames{fr}->{3325112} = "La\ Chapelle\ sur\ Erdre";
$areanames{fr}->{3325113} = "Nantes";
$areanames{fr}->{3325116} = "Saint\-Nazaire";
$areanames{fr}->{3325121} = "Les\ Sables\ d\'Olonne";
$areanames{fr}->{3325123} = "Les\ Sables\ d\'Olonne";
$areanames{fr}->{3325124} = "La\ Roche\ sur\ Yon";
$areanames{fr}->{3325126} = "Saint\-Gilles\-Croix\-de\-Vie";
$areanames{fr}->{3325129} = "Luçon";
$areanames{fr}->{3325130} = "La\ Tranche\ sur\ Mer";
$areanames{fr}->{3325132} = "Les\ Sables\ d\'Olonne";
$areanames{fr}->{3325133} = "Jard\-sur\-Mer";
$areanames{fr}->{3325135} = "Challans";
$areanames{fr}->{3325136} = "La\ Roche\ sur\ Yon";
$areanames{fr}->{3325137} = "La\ Roche\ sur\ Yon";
$areanames{fr}->{3325138} = "Mouilleron\-le\-Captif";
$areanames{fr}->{3325139} = "Noirmoutier\-en\-l\'Île";
$areanames{fr}->{3325144} = "La\ Roche\ sur\ Yon";
$areanames{fr}->{3325147} = "La\ Roche\ sur\ Yon";
$areanames{fr}->{3325149} = "Challans";
$areanames{fr}->{3325150} = "Fontenay\-le\-Comte";
$areanames{fr}->{3325153} = "Saint\-Martin\-de\-Fraigneau";
$areanames{fr}->{3325154} = "Saint\-Hilaire\-de\-Riez";
$areanames{fr}->{3325155} = "Saint\-Gilles\-Croix\-de\-Vie";
$areanames{fr}->{3325156} = "Luçon";
$areanames{fr}->{3325157} = "Pouzauges";
$areanames{fr}->{3325158} = "Saint\-Jean\-de\-Monts";
$areanames{fr}->{3325159} = "Saint\-Jean\-de\-Monts";
$areanames{fr}->{3325160} = "Saint\-Gilles\-Croix\-de\-Vie";
$areanames{fr}->{3325162} = "La\ Roche\ sur\ Yon";
$areanames{fr}->{3325163} = "Mortagne\-sur\-Sèvre";
$areanames{fr}->{3325164} = "Les\ Herbiers";
$areanames{fr}->{3325165} = "Mortagne\-sur\-Sèvre";
$areanames{fr}->{3325166} = "Les\ Herbiers";
$areanames{fr}->{3325167} = "Les\ Herbiers";
$areanames{fr}->{3325168} = "Challans";
$areanames{fr}->{3325169} = "Fontenay\-le\-Comte";
$areanames{fr}->{3325170} = "Rezé";
$areanames{fr}->{3325172} = "Nantes";
$areanames{fr}->{3325173} = "Guérande";
$areanames{fr}->{3325174} = "Pornic";
$areanames{fr}->{3325175} = "La\ Baule\ Escoublac";
$areanames{fr}->{3325176} = "Saint\-Nazaire";
$areanames{fr}->{3325177} = "Nantes";
$areanames{fr}->{3325178} = "Orvault";
$areanames{fr}->{3325179} = "Vertou";
$areanames{fr}->{3325180} = "Nantes";
$areanames{fr}->{3325181} = "Nantes";
$areanames{fr}->{3325182} = "Nantes";
$areanames{fr}->{3325183} = "Nantes";
$areanames{fr}->{3325184} = "Nantes";
$areanames{fr}->{3325185} = "Sainte\-Luce\-sur\-Loire";
$areanames{fr}->{3325186} = "Nantes";
$areanames{fr}->{3325189} = "Nantes";
$areanames{fr}->{3325190} = "Bretignolles\-sur\-Mer";
$areanames{fr}->{3325193} = "Challans";
$areanames{fr}->{3325194} = "Chantonnay";
$areanames{fr}->{3325195} = "Les\ Sables\ d\'Olonne";
$areanames{fr}->{3325200} = "Saint\-Calais";
$areanames{fr}->{3325201} = "Challans";
$areanames{fr}->{3325202} = "Fontenay\-le\-Comte";
$areanames{fr}->{3325203} = "Les\ Herbiers";
$areanames{fr}->{3325204} = "Luçon";
$areanames{fr}->{3325205} = "La\ Roche\-sur\-Yon";
$areanames{fr}->{3325206} = "Les\ Sables\ d\'Olonne";
$areanames{fr}->{3325207} = "Nantes";
$areanames{fr}->{3325208} = "La\ Roche\-sur\-Yon";
$areanames{fr}->{3325209} = "Angers";
$areanames{fr}->{3325210} = "Nantes";
$areanames{fr}->{3325211} = "Saint\-Calais";
$areanames{fr}->{3325212} = "Challans";
$areanames{fr}->{3325213} = "Fontenay\-le\-Comte";
$areanames{fr}->{3325214} = "Les\ Herbiers";
$areanames{fr}->{3325215} = "Luçon";
$areanames{fr}->{3325216} = "La\ Roche\-sur\-Yon";
$areanames{fr}->{3325217} = "Les\ Sables\ d\'Olonne";
$areanames{fr}->{3325218} = "Le\ Mans";
$areanames{fr}->{3325219} = "Le\ Mans";
$areanames{fr}->{3325220} = "Nantes";
$areanames{fr}->{3325221} = "Angers";
$areanames{fr}->{3325222} = "Le\ Mans";
$areanames{fr}->{3325223} = "Ancenis";
$areanames{fr}->{3325224} = "Blain";
$areanames{fr}->{3325225} = "Pornic";
$areanames{fr}->{3325226} = "Saumur";
$areanames{fr}->{3325227} = "Segre";
$areanames{fr}->{3325228} = "Fontenay\-le\-Comte";
$areanames{fr}->{3325229} = "Luçon";
$areanames{fr}->{3325230} = "Les\ Sables\ d\'Olonne";
$areanames{fr}->{3325231} = "Châteaubriant";
$areanames{fr}->{3325232} = "Nantes";
$areanames{fr}->{3325233} = "Nantes";
$areanames{fr}->{3325234} = "Laval";
$areanames{fr}->{3325235} = "Angers";
$areanames{fr}->{3325236} = "Le\ Mans";
$areanames{fr}->{3325237} = "Saumur";
$areanames{fr}->{3325238} = "Le\ Mans";
$areanames{fr}->{3325239} = "Cholet";
$areanames{fr}->{3325240} = "La\ Roche\-sur\-Yon";
$areanames{fr}->{3325241} = "Saint\-Nazaire";
$areanames{fr}->{3325242} = "Cholet";
$areanames{fr}->{3325243} = "La\ Roche\-sur\-Yon";
$areanames{fr}->{3325244} = "Nantes";
$areanames{fr}->{3325245} = "Cholet";
$areanames{fr}->{3325246} = "Laval";
$areanames{fr}->{3325247} = "Saumur";
$areanames{fr}->{3325248} = "Saint\-Nazaire";
$areanames{fr}->{3325249} = "La\ Flèche";
$areanames{fr}->{3325250} = "Château\-du\-Loir";
$areanames{fr}->{3325251} = "Sablé\-sur\-Sarthe";
$areanames{fr}->{3325252} = "Nantes";
$areanames{fr}->{3325253} = "La\ Ferte\-Bernard";
$areanames{fr}->{3325254} = "Saint\-Calais";
$areanames{fr}->{3325255} = "Baugé\-en\-Anjou";
$areanames{fr}->{3325256} = "Nantes";
$areanames{fr}->{3325257} = "Angers";
$areanames{fr}->{3325258} = "Nantes";
$areanames{fr}->{3325259} = "Nantes";
$areanames{fr}->{3325260} = "Angers";
$areanames{fr}->{3325261} = "Fontenay\-le\-Comte";
$areanames{fr}->{3325262} = "Nantes";
$areanames{fr}->{3325263} = "Challans";
$areanames{fr}->{3325264} = "Mayenne";
$areanames{fr}->{3325265} = "Les\ Herbiers";
$areanames{fr}->{3325266} = "Fontenay\-le\-Comte";
$areanames{fr}->{3325267} = "Les\ Sables\ d\'Olonne";
$areanames{fr}->{3325268} = "Nantes";
$areanames{fr}->{3325269} = "Segre";
$areanames{fr}->{3325270} = "Nantes";
$areanames{fr}->{3325271} = "Saint\-Nazaire";
$areanames{fr}->{3325272} = "Le\ Mans";
$areanames{fr}->{3325273} = "Pornic";
$areanames{fr}->{3325274} = "Luçon";
$areanames{fr}->{3325275} = "Angers";
$areanames{fr}->{3325276} = "Ancenis";
$areanames{fr}->{3325277} = "Ancenis";
$areanames{fr}->{3325278} = "Blain";
$areanames{fr}->{3325279} = "Châteaubriant";
$areanames{fr}->{3325280} = "Pornic";
$areanames{fr}->{3325281} = "Segre";
$areanames{fr}->{3325282} = "Château\-Gontier";
$areanames{fr}->{3325283} = "Beaumont\-sur\-Sarthe";
$areanames{fr}->{3325284} = "Le\ Mans";
$areanames{fr}->{3325285} = "Nantes";
$areanames{fr}->{3325286} = "Laval";
$areanames{fr}->{3325287} = "Nantes";
$areanames{fr}->{3325288} = "Angers";
$areanames{fr}->{3325289} = "Beaumont\-sur\-Sarthe";
$areanames{fr}->{3325290} = "Sablé\-sur\-Sarthe";
$areanames{fr}->{3325291} = "Mayenne";
$areanames{fr}->{3325292} = "Le\ Mans";
$areanames{fr}->{3325293} = "Laval";
$areanames{fr}->{3325294} = "La\ Ferte\-Bernard";
$areanames{fr}->{3325295} = "La\ Flèche";
$areanames{fr}->{3325296} = "Château\-Gontier";
$areanames{fr}->{3325297} = "Château\-du\-Loir";
$areanames{fr}->{3325298} = "Laval";
$areanames{fr}->{3325299} = "Le\ Mans";
$areanames{fr}->{3325300} = "Nantes";
$areanames{fr}->{3325301} = "Angers";
$areanames{fr}->{3325302} = "Cholet";
$areanames{fr}->{3325303} = "Fontenay\-le\-Comte";
$areanames{fr}->{3325304} = "Le\ Mans";
$areanames{fr}->{3325305} = "Les\ Herbiers";
$areanames{fr}->{3325306} = "Luçon";
$areanames{fr}->{3325307} = "La\ Roche\-sur\-Yon";
$areanames{fr}->{3325308} = "Les\ Sables\ d\'Olonne";
$areanames{fr}->{3325309} = "Mayenne";
$areanames{fr}->{3325310} = "Beaumont\-sur\-Sarthe";
$areanames{fr}->{3325311} = "Château\-du\-Loir";
$areanames{fr}->{3325312} = "La\ Ferte\-Bernard";
$areanames{fr}->{3325313} = "La\ Flèche";
$areanames{fr}->{3325314} = "Baugé\-en\-Anjou";
$areanames{fr}->{3325315} = "Le\ Mans";
$areanames{fr}->{3325316} = "Sablé\-sur\-Sarthe";
$areanames{fr}->{3325317} = "Saint\-Calais";
$areanames{fr}->{3325318} = "Challans";
$areanames{fr}->{3325319} = "Saint\-Nazaire";
$areanames{fr}->{3325320} = "Angers";
$areanames{fr}->{3325330} = "Saint\-Nazaire";
$areanames{fr}->{3325331} = "Luçon";
$areanames{fr}->{3325332} = "Les\ Sables\ d\'Olonne";
$areanames{fr}->{3325333} = "La\ Roche\-sur\-Yon";
$areanames{fr}->{3325334} = "Fontenay\-le\-Comte";
$areanames{fr}->{3325335} = "Nantes";
$areanames{fr}->{3325336} = "Challans";
$areanames{fr}->{3325337} = "Les\ Herbiers";
$areanames{fr}->{3325338} = "Saint\-Calais";
$areanames{fr}->{3325339} = "Nantes";
$areanames{fr}->{3325345} = "Nantes";
$areanames{fr}->{3325355} = "Nantes";
$areanames{fr}->{3325360} = "Challans";
$areanames{fr}->{3325361} = "Angers";
$areanames{fr}->{3325362} = "Baugé\-en\-Anjou";
$areanames{fr}->{3325363} = "Beaumont\-sur\-Sarthe";
$areanames{fr}->{3325364} = "Blain";
$areanames{fr}->{3325365} = "Challans";
$areanames{fr}->{3325366} = "Châteaubriant";
$areanames{fr}->{3325367} = "Château\-du\-Loir";
$areanames{fr}->{3325368} = "Château\-Gontier";
$areanames{fr}->{3325369} = "Cholet";
$areanames{fr}->{3325378} = "Nantes";
$areanames{fr}->{3325380} = "La\ Roche\-sur\-Yon";
$areanames{fr}->{3325381} = "Les\ Sables\ d\'Olonne";
$areanames{fr}->{3325382} = "Les\ Sables\ d\'Olonne";
$areanames{fr}->{3325383} = "Saint\-Calais";
$areanames{fr}->{3325384} = "Saint\-Nazaire";
$areanames{fr}->{3325385} = "Saumur";
$areanames{fr}->{3325386} = "Segre";
$areanames{fr}->{3325387} = "Ancenis";
$areanames{fr}->{3325388} = "La\ Roche\-sur\-Yon";
$areanames{fr}->{3325389} = "La\ Roche\-sur\-Yon";
$areanames{fr}->{3325397} = "Nantes";
$areanames{fr}->{3325400} = "Valençay";
$areanames{fr}->{3325401} = "Argenton\-sur\-Creuse";
$areanames{fr}->{3325402} = "Buzançais";
$areanames{fr}->{3325403} = "Issoudun";
$areanames{fr}->{3325406} = "Aigurande";
$areanames{fr}->{3325407} = "Châteauroux";
$areanames{fr}->{3325408} = "Châteauroux";
$areanames{fr}->{332541} = "Nord\ Ouest";
$areanames{fr}->{3325421} = "Issoudun";
$areanames{fr}->{3325422} = "Châteauroux";
$areanames{fr}->{3325424} = "Argenton\-sur\-Creuse";
$areanames{fr}->{3325426} = "Villedieu\-sur\-Indre";
$areanames{fr}->{3325427} = "Châteauroux";
$areanames{fr}->{3325428} = "Le\ Blanc";
$areanames{fr}->{3325429} = "Niherne";
$areanames{fr}->{3325431} = "Cluis";
$areanames{fr}->{3325432} = "Montrichard";
$areanames{fr}->{3325434} = "Châteauroux";
$areanames{fr}->{3325435} = "Levroux";
$areanames{fr}->{3325436} = "Ardentes";
$areanames{fr}->{3325437} = "Le\ Blanc";
$areanames{fr}->{3325438} = "Châtillon\-sur\-Indre";
$areanames{fr}->{3325441} = "Lye";
$areanames{fr}->{3325442} = "Blois";
$areanames{fr}->{3325443} = "Blois";
$areanames{fr}->{3325445} = "Blois";
$areanames{fr}->{3325448} = "La\ Châtre";
$areanames{fr}->{3325450} = "Vineuil";
$areanames{fr}->{3325451} = "Blois";
$areanames{fr}->{3325453} = "Châteauroux";
$areanames{fr}->{3325455} = "Blois";
$areanames{fr}->{3325456} = "Blois";
$areanames{fr}->{3325458} = "Blois";
$areanames{fr}->{3325460} = "Châteauroux";
$areanames{fr}->{3325461} = "Châteauroux";
$areanames{fr}->{3325467} = "Vendôme";
$areanames{fr}->{3325470} = "Mont\-prés\-Chambord";
$areanames{fr}->{3325473} = "Vendôme";
$areanames{fr}->{3325474} = "Blois";
$areanames{fr}->{3325475} = "Saint\-Aignan";
$areanames{fr}->{3325476} = "Romorantin\-Lanthenay";
$areanames{fr}->{3325477} = "Vendôme";
$areanames{fr}->{3325478} = "Blois";
$areanames{fr}->{3325479} = "Contres";
$areanames{fr}->{3325481} = "Mer";
$areanames{fr}->{3325484} = "Buzançais";
$areanames{fr}->{3325485} = "Montoire\-sur\-le\-Loir";
$areanames{fr}->{3325487} = "Saint\-Laurent\-Nouan";
$areanames{fr}->{3325488} = "Lamotte\-Beuvron";
$areanames{fr}->{3325489} = "Vendôme";
$areanames{fr}->{3325490} = "Blois";
$areanames{fr}->{3325495} = "Romorantin\-Lanthenay";
$areanames{fr}->{3325497} = "Salbris";
$areanames{fr}->{332550} = "Nantes";
$areanames{fr}->{3325500} = "Château\-Gontier";
$areanames{fr}->{3325508} = "Ancenis";
$areanames{fr}->{3325510} = "Nantes";
$areanames{fr}->{3325511} = "Nantes";
$areanames{fr}->{3325512} = "Nantes";
$areanames{fr}->{3325513} = "Ancenis";
$areanames{fr}->{3325514} = "Blain";
$areanames{fr}->{3325515} = "Châteaubriant";
$areanames{fr}->{3325516} = "Nantes";
$areanames{fr}->{3325517} = "Pornic";
$areanames{fr}->{3325518} = "Saint\-Nazaire";
$areanames{fr}->{3325519} = "Angers";
$areanames{fr}->{3325520} = "Baugé\-en\-Anjou";
$areanames{fr}->{3325521} = "Cholet";
$areanames{fr}->{3325522} = "Saumur";
$areanames{fr}->{3325523} = "Segre";
$areanames{fr}->{3325524} = "Château\-Gontier";
$areanames{fr}->{3325525} = "Laval";
$areanames{fr}->{3325526} = "Mayenne";
$areanames{fr}->{3325527} = "Beaumont\-sur\-Sarthe";
$areanames{fr}->{3325528} = "Château\-du\-Loir";
$areanames{fr}->{3325529} = "La\ Ferte\-Bernard";
$areanames{fr}->{3325530} = "La\ Flèche";
$areanames{fr}->{3325531} = "Le\ Mans";
$areanames{fr}->{3325532} = "Sablé\-sur\-Sarthe";
$areanames{fr}->{3325533} = "Saint\-Calais";
$areanames{fr}->{3325534} = "Challans";
$areanames{fr}->{3325535} = "Fontenay\-le\-Comte";
$areanames{fr}->{3325536} = "La\ Roche\-sur\-Yon";
$areanames{fr}->{3325537} = "Les\ Herbiers";
$areanames{fr}->{3325538} = "Les\ Sables\ d\'Olonne";
$areanames{fr}->{3325539} = "Luçon";
$areanames{fr}->{3325540} = "Saint\-Nazaire";
$areanames{fr}->{3325541} = "Angers";
$areanames{fr}->{3325542} = "Nantes";
$areanames{fr}->{3325543} = "Mayenne";
$areanames{fr}->{3325544} = "Nantes";
$areanames{fr}->{3325545} = "Nantes";
$areanames{fr}->{3325546} = "Le\ Mans";
$areanames{fr}->{3325547} = "Nantes";
$areanames{fr}->{3325548} = "Le\ Mans";
$areanames{fr}->{3325549} = "Les\ Sables\ d\'Olonne";
$areanames{fr}->{332555} = "Nantes";
$areanames{fr}->{3325552} = "Pornic";
$areanames{fr}->{3325553} = "Cholet";
$areanames{fr}->{3325555} = "Châteaubriant";
$areanames{fr}->{3325557} = "Ancenis";
$areanames{fr}->{3325560} = "Nantes";
$areanames{fr}->{3325561} = "Nantes";
$areanames{fr}->{3325562} = "Angers";
$areanames{fr}->{3325563} = "Cholet";
$areanames{fr}->{3325564} = "Saint\-Nazaire";
$areanames{fr}->{3325565} = "Challans";
$areanames{fr}->{3325566} = "Nantes";
$areanames{fr}->{3325567} = "Blain";
$areanames{fr}->{3325568} = "Châteaubriant";
$areanames{fr}->{3325569} = "Pornic";
$areanames{fr}->{3325570} = "Saint\-Nazaire";
$areanames{fr}->{3325571} = "Baugé\-en\-Anjou";
$areanames{fr}->{3325572} = "Saumur";
$areanames{fr}->{3325573} = "Segre";
$areanames{fr}->{3325574} = "Château\-Gontier";
$areanames{fr}->{3325575} = "Laval";
$areanames{fr}->{3325576} = "Mayenne";
$areanames{fr}->{3325577} = "Beaumont\-sur\-Sarthe";
$areanames{fr}->{3325578} = "Château\-du\-Loir";
$areanames{fr}->{3325579} = "La\ Ferte\-Bernard";
$areanames{fr}->{3325580} = "La\ Flèche";
$areanames{fr}->{3325581} = "Sablé\-sur\-Sarthe";
$areanames{fr}->{3325582} = "Saint\-Calais";
$areanames{fr}->{3325583} = "Challans";
$areanames{fr}->{3325584} = "Fontenay\-le\-Comte";
$areanames{fr}->{3325585} = "Les\ Herbiers";
$areanames{fr}->{3325586} = "Luçon";
$areanames{fr}->{3325587} = "Les\ Sables\ d\'Olonne";
$areanames{fr}->{3325588} = "Saumur";
$areanames{fr}->{3325589} = "Les\ Sables\ d\'Olonne";
$areanames{fr}->{3325590} = "La\ Roche\-sur\-Yon";
$areanames{fr}->{3325591} = "Châteaubriant";
$areanames{fr}->{3325592} = "Cholet";
$areanames{fr}->{3325593} = "Sablé\-sur\-Sarthe";
$areanames{fr}->{3325594} = "La\ Roche\-sur\-Yon";
$areanames{fr}->{3325595} = "Nantes";
$areanames{fr}->{3325596} = "Nantes";
$areanames{fr}->{3325597} = "Angers";
$areanames{fr}->{3325598} = "Angers";
$areanames{fr}->{3325599} = "Nantes";
$areanames{fr}->{3325600} = "Rennes";
$areanames{fr}->{3325601} = "Rennes";
$areanames{fr}->{3325602} = "Brest";
$areanames{fr}->{3325603} = "Rennes";
$areanames{fr}->{3325604} = "Carhaix\-Plouguer";
$areanames{fr}->{3325605} = "Quimperlé";
$areanames{fr}->{3325606} = "Carhaix\-Plouguer";
$areanames{fr}->{3325607} = "Loudéac";
$areanames{fr}->{3325608} = "Paimpol";
$areanames{fr}->{3325609} = "Rostrenen";
$areanames{fr}->{3325610} = "Carhaix\-Plouguer";
$areanames{fr}->{3325611} = "Dinan";
$areanames{fr}->{3325612} = "Le\ Faouet";
$areanames{fr}->{3325613} = "Fougères";
$areanames{fr}->{3325614} = "Guingamp";
$areanames{fr}->{3325615} = "Janzé";
$areanames{fr}->{3325616} = "Lamballe";
$areanames{fr}->{3325617} = "Loudéac";
$areanames{fr}->{3325618} = "Montfort\-sur\-Meu";
$areanames{fr}->{3325619} = "Morlaix";
$areanames{fr}->{3325629} = "Brest";
$areanames{fr}->{3325630} = "Auray";
$areanames{fr}->{3325631} = "Brest";
$areanames{fr}->{3325632} = "Rennes";
$areanames{fr}->{3325633} = "Le\ Faouet";
$areanames{fr}->{3325634} = "Pontivy";
$areanames{fr}->{3325635} = "Rennes";
$areanames{fr}->{3325636} = "Morlaix";
$areanames{fr}->{3325637} = "Auray";
$areanames{fr}->{3325638} = "Dinan";
$areanames{fr}->{3325639} = "Guingamp";
$areanames{fr}->{3325640} = "Lamballe";
$areanames{fr}->{3325641} = "Loudéac";
$areanames{fr}->{3325642} = "Paimpol";
$areanames{fr}->{3325643} = "Rostrenen";
$areanames{fr}->{3325644} = "Saint\-Brieuc";
$areanames{fr}->{3325645} = "Morlaix";
$areanames{fr}->{3325646} = "Quimperlé";
$areanames{fr}->{3325647} = "Fougères";
$areanames{fr}->{3325648} = "Janzé";
$areanames{fr}->{3325649} = "Montfort\-sur\-Meu";
$areanames{fr}->{3325651} = "Rennes";
$areanames{fr}->{3325654} = "Lorient";
$areanames{fr}->{3325660} = "Auray";
$areanames{fr}->{3325661} = "Ploërmel";
$areanames{fr}->{3325662} = "Pontivy";
$areanames{fr}->{3325663} = "Vannes";
$areanames{fr}->{3325664} = "Carhaix\-Plouguer";
$areanames{fr}->{3325665} = "Fougères";
$areanames{fr}->{3325666} = "Guingamp";
$areanames{fr}->{3325667} = "Janzé";
$areanames{fr}->{3325668} = "Auray";
$areanames{fr}->{3325669} = "Brest";
$areanames{fr}->{3325670} = "Carhaix\-Plouguer";
$areanames{fr}->{3325671} = "Dinan";
$areanames{fr}->{3325672} = "Le\ Faouet";
$areanames{fr}->{3325673} = "Fougères";
$areanames{fr}->{3325674} = "Guingamp";
$areanames{fr}->{3325675} = "Janzé";
$areanames{fr}->{3325676} = "Lamballe";
$areanames{fr}->{3325677} = "Loudéac";
$areanames{fr}->{3325678} = "Montfort\-sur\-Meu";
$areanames{fr}->{3325679} = "Morlaix";
$areanames{fr}->{3325680} = "Paimpol";
$areanames{fr}->{3325681} = "Ploërmel";
$areanames{fr}->{3325682} = "Pontivy";
$areanames{fr}->{3325683} = "Quimperlé";
$areanames{fr}->{3325684} = "Redon";
$areanames{fr}->{3325685} = "Rennes";
$areanames{fr}->{3325686} = "Rostrenen";
$areanames{fr}->{3325687} = "Saint\-Brieuc";
$areanames{fr}->{3325688} = "Saint\-Malo";
$areanames{fr}->{3325689} = "Vannes";
$areanames{fr}->{3325690} = "Vitré";
$areanames{fr}->{3325691} = "Montfort\-sur\-Meu";
$areanames{fr}->{3325692} = "Ploërmel";
$areanames{fr}->{3325693} = "Redon";
$areanames{fr}->{3325694} = "Carhaix\-Plouguer";
$areanames{fr}->{3325695} = "Vitré";
$areanames{fr}->{3325696} = "Vannes";
$areanames{fr}->{3325697} = "Rennes";
$areanames{fr}->{3325698} = "Auray";
$areanames{fr}->{3325699} = "Lamballe";
$areanames{fr}->{3325700} = "Guingamp";
$areanames{fr}->{3325701} = "Lamballe";
$areanames{fr}->{3325702} = "Loudéac";
$areanames{fr}->{3325703} = "Paimpol";
$areanames{fr}->{3325704} = "Rostrenen";
$areanames{fr}->{3325705} = "Saint\-Brieuc";
$areanames{fr}->{3325706} = "Fougères";
$areanames{fr}->{3325707} = "Janzé";
$areanames{fr}->{3325708} = "Montfort\-sur\-Meu";
$areanames{fr}->{3325709} = "Redon";
$areanames{fr}->{3325710} = "Rennes";
$areanames{fr}->{3325711} = "Saint\-Malo";
$areanames{fr}->{3325712} = "Vitré";
$areanames{fr}->{3325713} = "Auray";
$areanames{fr}->{3325714} = "Le\ Faouet";
$areanames{fr}->{3325715} = "Ploërmel";
$areanames{fr}->{3325716} = "Pontivy";
$areanames{fr}->{3325717} = "Vannes";
$areanames{fr}->{3325718} = "Saint\-Brieuc";
$areanames{fr}->{3325719} = "Guingamp";
$areanames{fr}->{3325720} = "Rennes";
$areanames{fr}->{3325721} = "Rennes";
$areanames{fr}->{3325722} = "Rennes";
$areanames{fr}->{3325723} = "Brest";
$areanames{fr}->{3325724} = "Rennes";
$areanames{fr}->{3325725} = "Saint\-Brieuc";
$areanames{fr}->{3325726} = "Rennes";
$areanames{fr}->{3325727} = "Dinan";
$areanames{fr}->{3325728} = "Vannes";
$areanames{fr}->{3325729} = "Brest";
$areanames{fr}->{3325730} = "Carhaix\-Plouguer";
$areanames{fr}->{3325731} = "Fougères";
$areanames{fr}->{3325732} = "Guingamp";
$areanames{fr}->{3325733} = "Janzé";
$areanames{fr}->{3325734} = "Lamballe";
$areanames{fr}->{3325735} = "Dinan";
$areanames{fr}->{3325736} = "Loudéac";
$areanames{fr}->{3325737} = "Montfort\-sur\-Meu";
$areanames{fr}->{3325738} = "Morlaix";
$areanames{fr}->{3325739} = "Paimpol";
$areanames{fr}->{3325740} = "Brest";
$areanames{fr}->{3325741} = "Redon";
$areanames{fr}->{3325742} = "Rennes";
$areanames{fr}->{3325743} = "Rostrenen";
$areanames{fr}->{3325744} = "Saint\-Brieuc";
$areanames{fr}->{3325745} = "Saint\-Malo";
$areanames{fr}->{3325746} = "Vitré";
$areanames{fr}->{3325747} = "Auray";
$areanames{fr}->{3325748} = "Saint\-Malo";
$areanames{fr}->{3325749} = "Brest";
$areanames{fr}->{3325750} = "Morlaix";
$areanames{fr}->{3325751} = "Quimperlé";
$areanames{fr}->{3325752} = "Brest";
$areanames{fr}->{3325753} = "Rennes";
$areanames{fr}->{3325754} = "Rennes";
$areanames{fr}->{3325755} = "Brest";
$areanames{fr}->{3325756} = "Carhaix\-Plouguer";
$areanames{fr}->{3325757} = "Saint\-Brieuc";
$areanames{fr}->{3325758} = "Auray";
$areanames{fr}->{3325759} = "Vannes";
$areanames{fr}->{3325760} = "Saint\-Malo";
$areanames{fr}->{3325761} = "Saint\-Brieuc";
$areanames{fr}->{3325762} = "Vannes";
$areanames{fr}->{3325763} = "Guingamp";
$areanames{fr}->{3325764} = "Saint\-Malo";
$areanames{fr}->{3325765} = "Morlaix";
$areanames{fr}->{3325766} = "Rennes";
$areanames{fr}->{3325767} = "Rennes";
$areanames{fr}->{3325768} = "Brest";
$areanames{fr}->{3325769} = "Dinan";
$areanames{fr}->{3325770} = "Fougères";
$areanames{fr}->{3325771} = "Redon";
$areanames{fr}->{3325772} = "Pontivy";
$areanames{fr}->{3325773} = "Ploërmel";
$areanames{fr}->{3325774} = "Vitré";
$areanames{fr}->{3325775} = "Rennes";
$areanames{fr}->{3325776} = "Guingamp";
$areanames{fr}->{3325777} = "Lamballe";
$areanames{fr}->{3325778} = "Loudéac";
$areanames{fr}->{3325779} = "Paimpol";
$areanames{fr}->{3325780} = "Rostrenen";
$areanames{fr}->{3325781} = "Quimperlé";
$areanames{fr}->{3325782} = "Janzé";
$areanames{fr}->{3325783} = "Montfort\-sur\-Meu";
$areanames{fr}->{3325784} = "Auray";
$areanames{fr}->{3325785} = "Rennes";
$areanames{fr}->{3325786} = "Le\ Faouet";
$areanames{fr}->{3325787} = "Rennes";
$areanames{fr}->{3325788} = "Carhaix\-Plouguer";
$areanames{fr}->{3325789} = "Quimperlé";
$areanames{fr}->{3325790} = "Auray";
$areanames{fr}->{3325791} = "Ploërmel";
$areanames{fr}->{3325792} = "Vannes";
$areanames{fr}->{3325794} = "Auray";
$areanames{fr}->{3325795} = "Saint\-Malo";
$areanames{fr}->{3325796} = "Vannes";
$areanames{fr}->{3325797} = "Pontivy";
$areanames{fr}->{3325798} = "Guingamp";
$areanames{fr}->{3325799} = "Vitré";
$areanames{fr}->{3325800} = "Saint\-Lô";
$areanames{fr}->{3325801} = "Alençon";
$areanames{fr}->{3325802} = "Argentan";
$areanames{fr}->{3325803} = "Flers";
$areanames{fr}->{3325804} = "L\'Aigle";
$areanames{fr}->{3325805} = "Mortagne\-au\-Perche";
$areanames{fr}->{3325806} = "Deauville";
$areanames{fr}->{3325807} = "Caen";
$areanames{fr}->{3325808} = "Bayeux";
$areanames{fr}->{3325809} = "Caen";
$areanames{fr}->{3325810} = "Deauville";
$areanames{fr}->{3325811} = "Falaise";
$areanames{fr}->{3325812} = "Lisieux";
$areanames{fr}->{3325813} = "Vire";
$areanames{fr}->{3325814} = "Avranches";
$areanames{fr}->{3325815} = "Carentan\-les\-Marais";
$areanames{fr}->{3325816} = "Coutances";
$areanames{fr}->{3325817} = "Saint\-Lô";
$areanames{fr}->{3325818} = "Alençon";
$areanames{fr}->{3325819} = "Argentan";
$areanames{fr}->{3325820} = "Flers";
$areanames{fr}->{3325821} = "L\'Aigle";
$areanames{fr}->{3325822} = "Mortagne\-au\-Perche";
$areanames{fr}->{3325823} = "Caen";
$areanames{fr}->{3325824} = "Carentan\-les\-Marais";
$areanames{fr}->{3325825} = "Vire";
$areanames{fr}->{3325826} = "Bayeux";
$areanames{fr}->{3325900} = "La\ Roche\-sur\-Yon";
$areanames{fr}->{3325901} = "Nantes";
$areanames{fr}->{3326100} = "Deauville";
$areanames{fr}->{3326101} = "Mortagne\-au\-Perche";
$areanames{fr}->{3326102} = "Flers";
$areanames{fr}->{3326103} = "Falaise";
$areanames{fr}->{3326104} = "Avranches";
$areanames{fr}->{3326105} = "Bayeux";
$areanames{fr}->{3326106} = "Argentan";
$areanames{fr}->{3326107} = "Lisieux";
$areanames{fr}->{3326108} = "Carentan\-les\-Marais";
$areanames{fr}->{3326109} = "Caen";
$areanames{fr}->{3326110} = "Caen";
$areanames{fr}->{3326111} = "Deauville";
$areanames{fr}->{3326112} = "Alençon";
$areanames{fr}->{3326113} = "L\'Aigle";
$areanames{fr}->{3326114} = "Vire";
$areanames{fr}->{3326115} = "Saint\-Lô";
$areanames{fr}->{3326116} = "Alençon";
$areanames{fr}->{3326117} = "Bayeux";
$areanames{fr}->{3326118} = "Caen";
$areanames{fr}->{3326119} = "Deauville";
$areanames{fr}->{3326120} = "Falaise";
$areanames{fr}->{3326121} = "Lisieux";
$areanames{fr}->{3326122} = "Vire";
$areanames{fr}->{3326123} = "Avranches";
$areanames{fr}->{3326124} = "Carentan\-les\-Marais";
$areanames{fr}->{3326125} = "Coutances";
$areanames{fr}->{3326126} = "Saint\-Lô";
$areanames{fr}->{3326127} = "Alençon";
$areanames{fr}->{3326128} = "Argentan";
$areanames{fr}->{3326129} = "Flers";
$areanames{fr}->{3326130} = "L\'Aigle";
$areanames{fr}->{3326131} = "Mortagne\-au\-Perche";
$areanames{fr}->{3326132} = "Caen";
$areanames{fr}->{3326133} = "Bayeux";
$areanames{fr}->{3326134} = "Falaise";
$areanames{fr}->{3326135} = "Lisieux";
$areanames{fr}->{3326136} = "Coutances";
$areanames{fr}->{3326137} = "L\'Aigle";
$areanames{fr}->{3326138} = "Caen";
$areanames{fr}->{3326139} = "Saint\-Lô";
$areanames{fr}->{3326140} = "Alençon";
$areanames{fr}->{3326141} = "Avranches";
$areanames{fr}->{3326142} = "Carentan\-les\-Marais";
$areanames{fr}->{3326143} = "Coutances";
$areanames{fr}->{3326144} = "Saint\-Lô";
$areanames{fr}->{3326145} = "Caen";
$areanames{fr}->{3326146} = "Deauville";
$areanames{fr}->{3326147} = "Falaise";
$areanames{fr}->{3326148} = "Lisieux";
$areanames{fr}->{3326149} = "Vire";
$areanames{fr}->{3326150} = "Alençon";
$areanames{fr}->{3326151} = "Carentan\-les\-Marais";
$areanames{fr}->{3326152} = "Caen";
$areanames{fr}->{3326153} = "Caen";
$areanames{fr}->{3326154} = "Alençon";
$areanames{fr}->{3326155} = "Argentan";
$areanames{fr}->{3326156} = "Avranches";
$areanames{fr}->{3326157} = "Flers";
$areanames{fr}->{3326158} = "Carentan\-les\-Marais";
$areanames{fr}->{3326159} = "Saint\-Lô";
$areanames{fr}->{3326160} = "Mortagne\-au\-Perche";
$areanames{fr}->{3326161} = "L\'Aigle";
$areanames{fr}->{3326162} = "Coutances";
$areanames{fr}->{3326163} = "L\'Aigle";
$areanames{fr}->{3326164} = "Argentan";
$areanames{fr}->{3326165} = "Flers";
$areanames{fr}->{3326166} = "Mortagne\-au\-Perche";
$areanames{fr}->{3326167} = "Caen";
$areanames{fr}->{3326168} = "Caen";
$areanames{fr}->{3326169} = "Avranches";
$areanames{fr}->{3326170} = "Flers";
$areanames{fr}->{3326171} = "Alençon";
$areanames{fr}->{3326172} = "Alençon";
$areanames{fr}->{3326173} = "Argentan";
$areanames{fr}->{3326174} = "Saint\-Lô";
$areanames{fr}->{3326175} = "Lisieux";
$areanames{fr}->{3326176} = "Coutances";
$areanames{fr}->{3326177} = "Bayeux";
$areanames{fr}->{3326178} = "Vire";
$areanames{fr}->{3326179} = "Caen";
$areanames{fr}->{3326180} = "Caen";
$areanames{fr}->{3326181} = "Saint\-Lô";
$areanames{fr}->{3326182} = "Deauville";
$areanames{fr}->{3326183} = "Falaise";
$areanames{fr}->{3326184} = "L\'Aigle";
$areanames{fr}->{3326185} = "Mortagne\-au\-Perche";
$areanames{fr}->{3326186} = "Bayeux";
$areanames{fr}->{3326187} = "Caen";
$areanames{fr}->{3326188} = "Caen";
$areanames{fr}->{3326189} = "Deauville";
$areanames{fr}->{3326190} = "Avranches";
$areanames{fr}->{3326192} = "Caen";
$areanames{fr}->{3326193} = "Deauville";
$areanames{fr}->{3326194} = "Falaise";
$areanames{fr}->{3326195} = "Lisieux";
$areanames{fr}->{3326196} = "Vire";
$areanames{fr}->{3326197} = "Avranches";
$areanames{fr}->{3326198} = "Carentan\-les\-Marais";
$areanames{fr}->{3326199} = "Coutances";
$areanames{fr}->{3326300} = "Saint\-Denis";
$areanames{fr}->{3327202} = "Nantes";
$areanames{fr}->{3327210} = "Cholet";
$areanames{fr}->{3327211} = "Challans";
$areanames{fr}->{3327212} = "Blain";
$areanames{fr}->{3327213} = "Cholet";
$areanames{fr}->{3327214} = "Château\-Gontier";
$areanames{fr}->{3327215} = "Saumur";
$areanames{fr}->{3327216} = "Le\ Mans";
$areanames{fr}->{3327217} = "Nantes";
$areanames{fr}->{3327218} = "Nantes";
$areanames{fr}->{3327219} = "La\ Roche\-sur\-Yon";
$areanames{fr}->{3327220} = "Nantes";
$areanames{fr}->{3327221} = "Segre";
$areanames{fr}->{3327222} = "Nantes";
$areanames{fr}->{3327223} = "Château\-Gontier";
$areanames{fr}->{3327224} = "Nantes";
$areanames{fr}->{3327225} = "Nantes";
$areanames{fr}->{3327226} = "Laval";
$areanames{fr}->{3327227} = "Saint\-Nazaire";
$areanames{fr}->{3327228} = "Mayenne";
$areanames{fr}->{3327229} = "Beaumont\-sur\-Sarthe";
$areanames{fr}->{3327230} = "Château\-du\-Loir";
$areanames{fr}->{3327231} = "La\ Ferte\-Bernard";
$areanames{fr}->{3327232} = "Châteaubriant";
$areanames{fr}->{3327233} = "La\ Flèche";
$areanames{fr}->{3327234} = "Nantes";
$areanames{fr}->{3327235} = "Le\ Mans";
$areanames{fr}->{3327236} = "Sablé\-sur\-Sarthe";
$areanames{fr}->{3327237} = "Saint\-Calais";
$areanames{fr}->{3327238} = "Challans";
$areanames{fr}->{3327239} = "Fontenay\-le\-Comte";
$areanames{fr}->{3327240} = "Les\ Herbiers";
$areanames{fr}->{3327241} = "Châteaubriant";
$areanames{fr}->{3327242} = "Segre";
$areanames{fr}->{3327243} = "Nantes";
$areanames{fr}->{3327244} = "Luçon";
$areanames{fr}->{3327245} = "Pornic";
$areanames{fr}->{3327246} = "Saint\-Nazaire";
$areanames{fr}->{3327247} = "Angers";
$areanames{fr}->{3327248} = "La\ Roche\-sur\-Yon";
$areanames{fr}->{3327249} = "Cholet";
$areanames{fr}->{3327250} = "Saumur";
$areanames{fr}->{3327251} = "Segre";
$areanames{fr}->{3327252} = "Ancenis";
$areanames{fr}->{3327253} = "Château\-Gontier";
$areanames{fr}->{3327254} = "Laval";
$areanames{fr}->{3327255} = "Les\ Sables\ d\'Olonne";
$areanames{fr}->{3327256} = "Nantes";
$areanames{fr}->{3327257} = "Beaumont\-sur\-Sarthe";
$areanames{fr}->{3327258} = "Château\-du\-Loir";
$areanames{fr}->{3327259} = "Ancenis";
$areanames{fr}->{3327260} = "Nantes";
$areanames{fr}->{3327261} = "Le\ Mans";
$areanames{fr}->{3327262} = "Cholet";
$areanames{fr}->{3327263} = "Châteaubriant";
$areanames{fr}->{3327264} = "Nantes";
$areanames{fr}->{3327265} = "Nantes";
$areanames{fr}->{3327266} = "Pornic";
$areanames{fr}->{3327267} = "Les\ Herbiers";
$areanames{fr}->{3327268} = "Nantes";
$areanames{fr}->{3327269} = "La\ Roche\-sur\-Yon";
$areanames{fr}->{3327270} = "Châteaubriant";
$areanames{fr}->{3327271} = "La\ Roche\-sur\-Yon";
$areanames{fr}->{3327272} = "Angers";
$areanames{fr}->{3327273} = "Angers";
$areanames{fr}->{3327274} = "Nantes";
$areanames{fr}->{3327275} = "Challans";
$areanames{fr}->{3327276} = "Le\ Mans";
$areanames{fr}->{3327277} = "Cholet";
$areanames{fr}->{3327278} = "La\ Roche\-sur\-Yon";
$areanames{fr}->{3327279} = "Angers";
$areanames{fr}->{3327280} = "Les\ Sables\ d\'Olonne";
$areanames{fr}->{3327281} = "Cholet";
$areanames{fr}->{3327282} = "Challans";
$areanames{fr}->{3327283} = "Nantes";
$areanames{fr}->{3327284} = "Nantes";
$areanames{fr}->{3327285} = "Nantes";
$areanames{fr}->{3327286} = "Saumur";
$areanames{fr}->{3327287} = "Segre";
$areanames{fr}->{3327288} = "Le\ Mans";
$areanames{fr}->{3327289} = "Laval";
$areanames{fr}->{3327290} = "Nantes";
$areanames{fr}->{3327291} = "Le\ Mans";
$areanames{fr}->{3327292} = "Pornic";
$areanames{fr}->{3327293} = "Ancenis";
$areanames{fr}->{3327294} = "Blain";
$areanames{fr}->{3327295} = "Laval";
$areanames{fr}->{3327296} = "Nantes";
$areanames{fr}->{3327297} = "Pornic";
$areanames{fr}->{3327298} = "Saint\-Nazaire";
$areanames{fr}->{3327299} = "Angers";
$areanames{fr}->{3327600} = "Rouen";
$areanames{fr}->{3327601} = "Rouen";
$areanames{fr}->{3327602} = "Yvetot";
$areanames{fr}->{3327603} = "Fécamp";
$areanames{fr}->{3327604} = "Gournay\-en\-Bray";
$areanames{fr}->{3327605} = "Le\ Havre";
$areanames{fr}->{3327606} = "Neufchâtel\-en\-Bray";
$areanames{fr}->{3327607} = "Yvetot";
$areanames{fr}->{3327608} = "Rouen";
$areanames{fr}->{3327609} = "Bernay";
$areanames{fr}->{3327610} = "Fleury\-sur\-Andelle";
$areanames{fr}->{3327611} = "Neufchâtel\-en\-Bray";
$areanames{fr}->{3327612} = "Evreux";
$areanames{fr}->{3327613} = "Fleury\-sur\-Andelle";
$areanames{fr}->{3327614} = "Gisors";
$areanames{fr}->{3327615} = "Louviers";
$areanames{fr}->{3327616} = "Bolbec";
$areanames{fr}->{3327617} = "Dieppe";
$areanames{fr}->{3327618} = "Pont\-Audemer";
$areanames{fr}->{3327619} = "Vernon";
$areanames{fr}->{3327620} = "Rouen";
$areanames{fr}->{3327621} = "Dieppe";
$areanames{fr}->{3327622} = "Gournay\-en\-Bray";
$areanames{fr}->{3327623} = "Fécamp";
$areanames{fr}->{3327624} = "Gournay\-en\-Bray";
$areanames{fr}->{3327625} = "Le\ Havre";
$areanames{fr}->{3327626} = "Neufchâtel\-en\-Bray";
$areanames{fr}->{3327627} = "Rouen";
$areanames{fr}->{3327628} = "Rouen";
$areanames{fr}->{3327629} = "Yvetot";
$areanames{fr}->{3327630} = "Rouen";
$areanames{fr}->{3327631} = "Bolbec";
$areanames{fr}->{3327632} = "Le\ Havre";
$areanames{fr}->{3327633} = "Fleury\-sur\-Andelle";
$areanames{fr}->{3327634} = "Rouen";
$areanames{fr}->{3327635} = "Bernay";
$areanames{fr}->{3327636} = "Bolbec";
$areanames{fr}->{3327637} = "Dieppe";
$areanames{fr}->{3327638} = "Evreux";
$areanames{fr}->{3327639} = "Fécamp";
$areanames{fr}->{3327640} = "Le\ Havre";
$areanames{fr}->{3327641} = "Bernay";
$areanames{fr}->{3327642} = "Evreux";
$areanames{fr}->{3327643} = "Fleury\-sur\-Andelle";
$areanames{fr}->{3327644} = "Louviers";
$areanames{fr}->{3327645} = "Gisors";
$areanames{fr}->{3327646} = "Louviers";
$areanames{fr}->{3327647} = "Pont\-Audemer";
$areanames{fr}->{3327648} = "Vernon";
$areanames{fr}->{3327649} = "Louviers";
$areanames{fr}->{3327650} = "Neufchâtel\-en\-Bray";
$areanames{fr}->{3327651} = "Rouen";
$areanames{fr}->{3327652} = "Rouen";
$areanames{fr}->{3327653} = "Yvetot";
$areanames{fr}->{3327654} = "Dieppe";
$areanames{fr}->{3327655} = "Evreux";
$areanames{fr}->{3327656} = "Bernay";
$areanames{fr}->{3327657} = "Evreux";
$areanames{fr}->{3327658} = "Gournay\-en\-Bray";
$areanames{fr}->{3327659} = "Gisors";
$areanames{fr}->{3327660} = "Louviers";
$areanames{fr}->{3327661} = "Rouen";
$areanames{fr}->{3327662} = "Vernon";
$areanames{fr}->{3327663} = "Bolbec";
$areanames{fr}->{3327664} = "Nantes";
$areanames{fr}->{3327665} = "Fécamp";
$areanames{fr}->{3327666} = "Pont\-Audemer";
$areanames{fr}->{3327667} = "Rouen";
$areanames{fr}->{3327668} = "Rouen";
$areanames{fr}->{3327669} = "Bolbec";
$areanames{fr}->{3327670} = "Rouen";
$areanames{fr}->{3327671} = "Yvetot";
$areanames{fr}->{3327672} = "Dieppe";
$areanames{fr}->{3327673} = "Gournay\-en\-Bray";
$areanames{fr}->{3327674} = "Le\ Havre";
$areanames{fr}->{3327675} = "Bolbec";
$areanames{fr}->{3327676} = "Vernon";
$areanames{fr}->{3327677} = "Dieppe";
$areanames{fr}->{3327678} = "Rouen";
$areanames{fr}->{3327679} = "Gisors";
$areanames{fr}->{3327680} = "Le\ Havre";
$areanames{fr}->{3327681} = "Le\ Havre";
$areanames{fr}->{3327682} = "Gournay\-en\-Bray";
$areanames{fr}->{3327683} = "Fécamp";
$areanames{fr}->{3327684} = "Le\ Havre";
$areanames{fr}->{3327685} = "Neufchâtel\-en\-Bray";
$areanames{fr}->{3327686} = "Rouen";
$areanames{fr}->{3327687} = "Rouen";
$areanames{fr}->{3327688} = "Rouen";
$areanames{fr}->{3327689} = "Le\ Havre";
$areanames{fr}->{3327690} = "Bernay";
$areanames{fr}->{3327691} = "Evreux";
$areanames{fr}->{3327692} = "Fleury\-sur\-Andelle";
$areanames{fr}->{3327693} = "Gisors";
$areanames{fr}->{3327694} = "Louviers";
$areanames{fr}->{3327695} = "Rouen";
$areanames{fr}->{3327696} = "Pont\-Audemer";
$areanames{fr}->{3327697} = "Vernon";
$areanames{fr}->{3327698} = "Bolbec";
$areanames{fr}->{3327699} = "Dieppe";
$areanames{fr}->{3327700} = "Le\ Havre";
$areanames{fr}->{3327701} = "Pont\-Audemer";
$areanames{fr}->{3327702} = "Vernon";
$areanames{fr}->{3327703} = "Yvetot";
$areanames{fr}->{3327704} = "Le\ Havre";
$areanames{fr}->{3327705} = "Bernay";
$areanames{fr}->{3327706} = "Rouen";
$areanames{fr}->{3327707} = "Rouen";
$areanames{fr}->{3327708} = "Louviers";
$areanames{fr}->{3327709} = "Bernay";
$areanames{fr}->{3327710} = "Le\ Havre";
$areanames{fr}->{3327711} = "Rouen";
$areanames{fr}->{3327712} = "Evreux";
$areanames{fr}->{3327713} = "Fleury\-sur\-Andelle";
$areanames{fr}->{3327714} = "Gisors";
$areanames{fr}->{3327715} = "Le\ Havre";
$areanames{fr}->{3327716} = "Louviers";
$areanames{fr}->{3327717} = "Bolbec";
$areanames{fr}->{3327718} = "Pont\-Audemer";
$areanames{fr}->{3327719} = "Vernon";
$areanames{fr}->{3327720} = "Rouen";
$areanames{fr}->{3327721} = "Le\ Havre";
$areanames{fr}->{3327722} = "Bolbec";
$areanames{fr}->{3327723} = "Dieppe";
$areanames{fr}->{3327724} = "Fécamp";
$areanames{fr}->{3327725} = "Gournay\-en\-Bray";
$areanames{fr}->{3327726} = "Neufchâtel\-en\-Bray";
$areanames{fr}->{3327727} = "Evreux";
$areanames{fr}->{3327728} = "Yvetot";
$areanames{fr}->{3327729} = "Dieppe";
$areanames{fr}->{3327730} = "Bernay";
$areanames{fr}->{3327731} = "Bolbec";
$areanames{fr}->{3327732} = "Dieppe";
$areanames{fr}->{3327733} = "Evreux";
$areanames{fr}->{3327734} = "Fécamp";
$areanames{fr}->{3327735} = "Fleury\-sur\-Andelle";
$areanames{fr}->{3327736} = "Gisors";
$areanames{fr}->{3327737} = "Gournay\-en\-Bray";
$areanames{fr}->{3327738} = "Le\ Havre";
$areanames{fr}->{3327739} = "Neufchâtel\-en\-Bray";
$areanames{fr}->{3327740} = "Pont\-Audemer";
$areanames{fr}->{3327741} = "Rouen";
$areanames{fr}->{3327742} = "Vernon";
$areanames{fr}->{3327743} = "Yvetot";
$areanames{fr}->{3327744} = "Evreux";
$areanames{fr}->{3327745} = "Fleury\-sur\-Andelle";
$areanames{fr}->{3327746} = "Gournay\-en\-Bray";
$areanames{fr}->{3327747} = "Louviers";
$areanames{fr}->{3327748} = "Neufchâtel\-en\-Bray";
$areanames{fr}->{3327749} = "Pont\-Audemer";
$areanames{fr}->{3327750} = "Rouen";
$areanames{fr}->{3327751} = "Yvetot";
$areanames{fr}->{3327752} = "Rouen";
$areanames{fr}->{3327753} = "Bernay";
$areanames{fr}->{3327754} = "Dieppe";
$areanames{fr}->{3327755} = "Evreux";
$areanames{fr}->{3327756} = "Le\ Havre";
$areanames{fr}->{3327757} = "Louviers";
$areanames{fr}->{3327758} = "Rouen";
$areanames{fr}->{3327759} = "Vernon";
$areanames{fr}->{3327760} = "Evreux";
$areanames{fr}->{3327761} = "Le\ Havre";
$areanames{fr}->{3327762} = "Rouen";
$areanames{fr}->{3327763} = "Evreux";
$areanames{fr}->{3327764} = "Fleury\-sur\-Andelle";
$areanames{fr}->{3327765} = "Gournay\-en\-Bray";
$areanames{fr}->{3327766} = "Le\ Havre";
$areanames{fr}->{3327767} = "Le\ Havre";
$areanames{fr}->{3327768} = "Louviers";
$areanames{fr}->{3327769} = "Vernon";
$areanames{fr}->{3327776} = "Rouen";
$areanames{fr}->{3327780} = "Bernay";
$areanames{fr}->{3327781} = "Le\ Havre";
$areanames{fr}->{3327782} = "Bernay";
$areanames{fr}->{3327783} = "Bolbec";
$areanames{fr}->{3327784} = "Dieppe";
$areanames{fr}->{3327785} = "Evreux";
$areanames{fr}->{3327786} = "Fécamp";
$areanames{fr}->{3327787} = "Dieppe";
$areanames{fr}->{3327788} = "Evreux";
$areanames{fr}->{3327789} = "Louviers";
$areanames{fr}->{3327790} = "Gisors";
$areanames{fr}->{3327791} = "Fleury\-sur\-Andelle";
$areanames{fr}->{3327792} = "Gisors";
$areanames{fr}->{3327793} = "Gournay\-en\-Bray";
$areanames{fr}->{3327794} = "Le\ Havre";
$areanames{fr}->{3327795} = "Louviers";
$areanames{fr}->{3327796} = "Neufchâtel\-en\-Bray";
$areanames{fr}->{3327797} = "Pont\-Audemer";
$areanames{fr}->{3327798} = "Rouen";
$areanames{fr}->{3327799} = "Fécamp";
$areanames{fr}->{3327800} = "Vernon";
$areanames{fr}->{3327801} = "Yvetot";
$areanames{fr}->{3327802} = "Gisors";
$areanames{fr}->{3327803} = "Bernay";
$areanames{fr}->{3327804} = "Evreux";
$areanames{fr}->{3327805} = "Fleury\-sur\-Andelle";
$areanames{fr}->{3327806} = "Gisors";
$areanames{fr}->{3327807} = "Louviers";
$areanames{fr}->{3327808} = "Rouen";
$areanames{fr}->{3327809} = "Pont\-Audemer";
$areanames{fr}->{3327810} = "Vernon";
$areanames{fr}->{3327811} = "Bolbec";
$areanames{fr}->{3327812} = "Dieppe";
$areanames{fr}->{3327813} = "Fécamp";
$areanames{fr}->{3327814} = "Gournay\-en\-Bray";
$areanames{fr}->{3327815} = "Le\ Havre";
$areanames{fr}->{3327816} = "Neufchâtel\-en\-Bray";
$areanames{fr}->{3327817} = "Yvetot";
$areanames{fr}->{3327818} = "Dieppe";
$areanames{fr}->{3327819} = "Le\ Havre";
$areanames{fr}->{3327820} = "Rouen";
$areanames{fr}->{3327821} = "Bernay";
$areanames{fr}->{3327822} = "Evreux";
$areanames{fr}->{3327823} = "Louviers";
$areanames{fr}->{3327824} = "Vernon";
$areanames{fr}->{3327825} = "Neufchâtel\-en\-Bray";
$areanames{fr}->{3327826} = "Rouen";
$areanames{fr}->{3327827} = "Le\ Havre";
$areanames{fr}->{3327828} = "Gisors";
$areanames{fr}->{3327829} = "Bernay";
$areanames{fr}->{3327830} = "Fleury\-sur\-Andelle";
$areanames{fr}->{3327831} = "Pont\-Audemer";
$areanames{fr}->{3327832} = "Vernon";
$areanames{fr}->{3327833} = "Fécamp";
$areanames{fr}->{3327834} = "Le\ Havre";
$areanames{fr}->{3327835} = "Fleury\-sur\-Andelle";
$areanames{fr}->{3327836} = "Gournay\-en\-Bray";
$areanames{fr}->{3327837} = "Dieppe";
$areanames{fr}->{3327838} = "Neufchâtel\-en\-Bray";
$areanames{fr}->{3327839} = "Yvetot";
$areanames{fr}->{3327840} = "Dieppe";
$areanames{fr}->{3327841} = "Vernon";
$areanames{fr}->{3327842} = "Fécamp";
$areanames{fr}->{3327843} = "Bolbec";
$areanames{fr}->{3327844} = "Evreux";
$areanames{fr}->{3327845} = "Le\ Havre";
$areanames{fr}->{3327846} = "Louviers";
$areanames{fr}->{3327847} = "Rouen";
$areanames{fr}->{3327848} = "Bolbec";
$areanames{fr}->{3327849} = "Dieppe";
$areanames{fr}->{3327850} = "Fécamp";
$areanames{fr}->{3327851} = "Pont\-Audemer";
$areanames{fr}->{3327852} = "Bernay";
$areanames{fr}->{3327853} = "Evreux";
$areanames{fr}->{3327854} = "Fleury\-sur\-Andelle";
$areanames{fr}->{3327855} = "Gisors";
$areanames{fr}->{3327856} = "Louviers";
$areanames{fr}->{3327857} = "Pont\-Audemer";
$areanames{fr}->{3327858} = "Vernon";
$areanames{fr}->{3327859} = "Fécamp";
$areanames{fr}->{3327860} = "Gournay\-en\-Bray";
$areanames{fr}->{3327861} = "Gournay\-en\-Bray";
$areanames{fr}->{3327862} = "Rouen";
$areanames{fr}->{3327863} = "Le\ Havre";
$areanames{fr}->{3327864} = "Neufchâtel\-en\-Bray";
$areanames{fr}->{3327865} = "Rouen";
$areanames{fr}->{3327866} = "Yvetot";
$areanames{fr}->{3327867} = "Rouen";
$areanames{fr}->{3327868} = "Gisors";
$areanames{fr}->{3327869} = "Le\ Havre";
$areanames{fr}->{3327870} = "Neufchâtel\-en\-Bray";
$areanames{fr}->{3327871} = "Rouen";
$areanames{fr}->{3327872} = "Bernay";
$areanames{fr}->{3327873} = "Vernon";
$areanames{fr}->{3327874} = "Fécamp";
$areanames{fr}->{3327875} = "Rouen";
$areanames{fr}->{3327876} = "Evreux";
$areanames{fr}->{3327877} = "Rouen";
$areanames{fr}->{3327878} = "Le\ Havre";
$areanames{fr}->{3327879} = "Evreux";
$areanames{fr}->{3327880} = "Yvetot";
$areanames{fr}->{3327881} = "Rouen";
$areanames{fr}->{3327882} = "Bernay";
$areanames{fr}->{3327883} = "Evreux";
$areanames{fr}->{3327884} = "Rouen";
$areanames{fr}->{3327885} = "Fleury\-sur\-Andelle";
$areanames{fr}->{3327886} = "Gisors";
$areanames{fr}->{3327887} = "Louviers";
$areanames{fr}->{3327888} = "Evreux";
$areanames{fr}->{3327889} = "Pont\-Audemer";
$areanames{fr}->{3327890} = "Bolbec";
$areanames{fr}->{3327891} = "Vernon";
$areanames{fr}->{3327892} = "Le\ Havre";
$areanames{fr}->{3327893} = "Le\ Havre";
$areanames{fr}->{3327894} = "Rouen";
$areanames{fr}->{3327895} = "Le\ Havre";
$areanames{fr}->{3327896} = "Rouen";
$areanames{fr}->{3327897} = "Evreux";
$areanames{fr}->{3327898} = "Evreux";
$areanames{fr}->{3327899} = "Evreux";
$areanames{fr}->{3327900} = "Dieppe";
$areanames{fr}->{3327901} = "Le\ Havre";
$areanames{fr}->{3327902} = "Rouen";
$areanames{fr}->{3327903} = "Fécamp";
$areanames{fr}->{3327904} = "Vernon";
$areanames{fr}->{3327905} = "Pont\-Audemer";
$areanames{fr}->{3327906} = "Bernay";
$areanames{fr}->{3327907} = "Yvetot";
$areanames{fr}->{3327908} = "Bolbec";
$areanames{fr}->{3327909} = "Louviers";
$areanames{fr}->{3327910} = "Evreux";
$areanames{fr}->{3327911} = "Fleury\-sur\-Andelle";
$areanames{fr}->{3327912} = "Gisors";
$areanames{fr}->{3327913} = "Gournay\-en\-Bray";
$areanames{fr}->{3327914} = "Neufchâtel\-en\-Bray";
$areanames{fr}->{3327915} = "Le\ Havre";
$areanames{fr}->{3327916} = "Rouen";
$areanames{fr}->{3327917} = "Le\ Havre";
$areanames{fr}->{3327918} = "Rouen";
$areanames{fr}->{3327919} = "Evreux";
$areanames{fr}->{3327920} = "Bernay";
$areanames{fr}->{3327921} = "Fleury\-sur\-Andelle";
$areanames{fr}->{3327922} = "Gisors";
$areanames{fr}->{3327923} = "Louviers";
$areanames{fr}->{3327924} = "Pont\-Audemer";
$areanames{fr}->{3327925} = "Vernon";
$areanames{fr}->{3327926} = "Bernay";
$areanames{fr}->{3327927} = "Fleury\-sur\-Andelle";
$areanames{fr}->{3327928} = "Gisors";
$areanames{fr}->{3327929} = "Louviers";
$areanames{fr}->{3327930} = "Pont\-Audemer";
$areanames{fr}->{3327931} = "Vernon";
$areanames{fr}->{3327932} = "Bolbec";
$areanames{fr}->{3327933} = "Dieppe";
$areanames{fr}->{3327934} = "Fécamp";
$areanames{fr}->{3327935} = "Gournay\-en\-Bray";
$areanames{fr}->{3327936} = "Neufchâtel\-en\-Bray";
$areanames{fr}->{3327937} = "Rouen";
$areanames{fr}->{3327938} = "Yvetot";
$areanames{fr}->{3327979} = "Le\ Havre";
$areanames{fr}->{3327980} = "Rouen";
$areanames{fr}->{3327981} = "Rouen";
$areanames{fr}->{3327982} = "Le\ Havre";
$areanames{fr}->{3327983} = "Le\ Havre";
$areanames{fr}->{3327984} = "Bolbec";
$areanames{fr}->{3327985} = "Dieppe";
$areanames{fr}->{3327986} = "Fécamp";
$areanames{fr}->{3327987} = "Gournay\-en\-Bray";
$areanames{fr}->{3327988} = "Neufchâtel\-en\-Bray";
$areanames{fr}->{3327989} = "Yvetot";
$areanames{fr}->{3327990} = "Rouen";
$areanames{fr}->{3327991} = "Rouen";
$areanames{fr}->{3327992} = "Le\ Havre";
$areanames{fr}->{3327993} = "Rouen";
$areanames{fr}->{3327994} = "Vernon";
$areanames{fr}->{3327995} = "Evreux";
$areanames{fr}->{3327996} = "Fleury\-sur\-Andelle";
$areanames{fr}->{3328500} = "Sablé\-sur\-Sarthe";
$areanames{fr}->{3328501} = "La\ Ferte\-Bernard";
$areanames{fr}->{3328502} = "Ancenis";
$areanames{fr}->{3328503} = "Blain";
$areanames{fr}->{3328504} = "Châteaubriant";
$areanames{fr}->{3328505} = "Nantes";
$areanames{fr}->{3328506} = "Pornic";
$areanames{fr}->{3328507} = "Saint\-Nazaire";
$areanames{fr}->{3328508} = "Angers";
$areanames{fr}->{3328509} = "Baugé\-en\-Anjou";
$areanames{fr}->{3328510} = "Cholet";
$areanames{fr}->{3328511} = "Saumur";
$areanames{fr}->{3328512} = "Segre";
$areanames{fr}->{3328513} = "Château\-Gontier";
$areanames{fr}->{3328514} = "Laval";
$areanames{fr}->{3328515} = "Mayenne";
$areanames{fr}->{3328516} = "Beaumont\-sur\-Sarthe";
$areanames{fr}->{3328517} = "Château\-du\-Loir";
$areanames{fr}->{3328518} = "La\ Ferte\-Bernard";
$areanames{fr}->{3328519} = "La\ Flèche";
$areanames{fr}->{3328520} = "Le\ Mans";
$areanames{fr}->{3328521} = "Sablé\-sur\-Sarthe";
$areanames{fr}->{3328522} = "Saint\-Calais";
$areanames{fr}->{3328523} = "Challans";
$areanames{fr}->{3328524} = "Fontenay\-le\-Comte";
$areanames{fr}->{3328525} = "Les\ Herbiers";
$areanames{fr}->{3328526} = "Luçon";
$areanames{fr}->{3328527} = "La\ Roche\-sur\-Yon";
$areanames{fr}->{3328528} = "Les\ Sables\ d\'Olonne";
$areanames{fr}->{3328529} = "Le\ Mans";
$areanames{fr}->{3328537} = "Nantes";
$areanames{fr}->{3328540} = "Château\-Gontier";
$areanames{fr}->{3328541} = "Mayenne";
$areanames{fr}->{3328542} = "Château\-du\-Loir";
$areanames{fr}->{3328543} = "La\ Ferte\-Bernard";
$areanames{fr}->{3328544} = "Saint\-Calais";
$areanames{fr}->{3328545} = "Cholet";
$areanames{fr}->{3328546} = "Les\ Herbiers";
$areanames{fr}->{3328547} = "Luçon";
$areanames{fr}->{3328548} = "Les\ Sables\ d\'Olonne";
$areanames{fr}->{3328549} = "Laval";
$areanames{fr}->{3328552} = "Nantes";
$areanames{fr}->{3328560} = "Château\-du\-Loir";
$areanames{fr}->{3328561} = "La\ Ferte\-Bernard";
$areanames{fr}->{3328562} = "La\ Flèche";
$areanames{fr}->{3328563} = "Le\ Mans";
$areanames{fr}->{3328564} = "Sablé\-sur\-Sarthe";
$areanames{fr}->{3328565} = "Laval";
$areanames{fr}->{3328566} = "Saint\-Calais";
$areanames{fr}->{3328567} = "Nantes";
$areanames{fr}->{3328568} = "Laval";
$areanames{fr}->{3328569} = "Ancenis";
$areanames{fr}->{3328570} = "Blain";
$areanames{fr}->{3328571} = "Châteaubriant";
$areanames{fr}->{3328572} = "Nantes";
$areanames{fr}->{3328573} = "Nantes";
$areanames{fr}->{3328574} = "Saint\-Nazaire";
$areanames{fr}->{3328575} = "La\ Roche\-sur\-Yon";
$areanames{fr}->{3328576} = "Les\ Herbiers";
$areanames{fr}->{3328577} = "Fontenay\-le\-Comte";
$areanames{fr}->{3328578} = "Challans";
$areanames{fr}->{3328579} = "Angers";
$areanames{fr}->{3328580} = "Baugé\-en\-Anjou";
$areanames{fr}->{3328581} = "Cholet";
$areanames{fr}->{3328582} = "Saumur";
$areanames{fr}->{3328583} = "Segre";
$areanames{fr}->{3328584} = "Château\-du\-Loir";
$areanames{fr}->{3328585} = "Le\ Mans";
$areanames{fr}->{3328586} = "Château\-Gontier";
$areanames{fr}->{3328587} = "Laval";
$areanames{fr}->{3328588} = "Château\-Gontier";
$areanames{fr}->{3328589} = "Mayenne";
$areanames{fr}->{3328590} = "Beaumont\-sur\-Sarthe";
$areanames{fr}->{3328591} = "Château\-du\-Loir";
$areanames{fr}->{3328592} = "La\ Ferte\-Bernard";
$areanames{fr}->{3328593} = "Pornic";
$areanames{fr}->{3328594} = "La\ Flèche";
$areanames{fr}->{3328595} = "Saint\-Nazaire";
$areanames{fr}->{3328596} = "Le\ Mans";
$areanames{fr}->{3328597} = "Sablé\-sur\-Sarthe";
$areanames{fr}->{3328598} = "Blain";
$areanames{fr}->{3328599} = "Ancenis";
$areanames{fr}->{3329000} = "Rostrenen";
$areanames{fr}->{3329001} = "Rennes";
$areanames{fr}->{3329002} = "Rennes";
$areanames{fr}->{3329003} = "Saint\-Brieuc";
$areanames{fr}->{3329004} = "Saint\-Malo";
$areanames{fr}->{3329005} = "Saint\-Brieuc";
$areanames{fr}->{3329006} = "Brest";
$areanames{fr}->{3329007} = "Carhaix\-Plouguer";
$areanames{fr}->{3329008} = "Rennes";
$areanames{fr}->{3329009} = "Rennes";
$areanames{fr}->{3329010} = "Saint\-Malo";
$areanames{fr}->{3329011} = "Morlaix";
$areanames{fr}->{3329012} = "Quimperlé";
$areanames{fr}->{3329013} = "Fougères";
$areanames{fr}->{3329014} = "Janzé";
$areanames{fr}->{3329015} = "Montfort\-sur\-Meu";
$areanames{fr}->{3329016} = "Redon";
$areanames{fr}->{3329017} = "Saint\-Malo";
$areanames{fr}->{3329018} = "Vitré";
$areanames{fr}->{3329019} = "Auray";
$areanames{fr}->{3329020} = "Dinan";
$areanames{fr}->{3329021} = "Le\ Faouet";
$areanames{fr}->{3329022} = "Rennes";
$areanames{fr}->{3329023} = "Ploërmel";
$areanames{fr}->{3329024} = "Pontivy";
$areanames{fr}->{3329025} = "Vannes";
$areanames{fr}->{3329026} = "Brest";
$areanames{fr}->{3329027} = "Guingamp";
$areanames{fr}->{3329028} = "Lamballe";
$areanames{fr}->{3329029} = "Loudéac";
$areanames{fr}->{3329030} = "Montfort\-sur\-Meu";
$areanames{fr}->{3329031} = "Paimpol";
$areanames{fr}->{3329032} = "Rennes";
$areanames{fr}->{3329033} = "Paimpol";
$areanames{fr}->{3329034} = "Loudéac";
$areanames{fr}->{3329035} = "Dinan";
$areanames{fr}->{3329036} = "Saint\-Brieuc";
$areanames{fr}->{3329037} = "Dinan";
$areanames{fr}->{3329038} = "Auray";
$areanames{fr}->{3329039} = "Brest";
$areanames{fr}->{3329040} = "Ploërmel";
$areanames{fr}->{3329041} = "Carhaix\-Plouguer";
$areanames{fr}->{3329042} = "Morlaix";
$areanames{fr}->{3329043} = "Quimperlé";
$areanames{fr}->{3329044} = "Fougères";
$areanames{fr}->{3329045} = "Janzé";
$areanames{fr}->{3329046} = "Guingamp";
$areanames{fr}->{3329047} = "Montfort\-sur\-Meu";
$areanames{fr}->{3329048} = "Redon";
$areanames{fr}->{3329049} = "Paimpol";
$areanames{fr}->{3329056} = "Rennes";
$areanames{fr}->{3329060} = "Janzé";
$areanames{fr}->{3329061} = "Auray";
$areanames{fr}->{3329062} = "Rennes";
$areanames{fr}->{3329063} = "Saint\-Malo";
$areanames{fr}->{3329064} = "Vitré";
$areanames{fr}->{3329065} = "Auray";
$areanames{fr}->{3329066} = "Le\ Faouet";
$areanames{fr}->{3329067} = "Le\ Faouet";
$areanames{fr}->{3329068} = "Ploërmel";
$areanames{fr}->{3329069} = "Vannes";
$areanames{fr}->{3329078} = "Rennes";
$areanames{fr}->{3329080} = "Fougères";
$areanames{fr}->{3329081} = "Saint\-Brieuc";
$areanames{fr}->{3329082} = "Brest";
$areanames{fr}->{3329083} = "Dinan";
$areanames{fr}->{3329084} = "Auray";
$areanames{fr}->{3329085} = "Brest";
$areanames{fr}->{3329086} = "Saint\-Malo";
$areanames{fr}->{3329087} = "Rennes";
$areanames{fr}->{3329088} = "Brest";
$areanames{fr}->{3329089} = "Rennes";
$areanames{fr}->{3329090} = "Saint\-Brieuc";
$areanames{fr}->{3329091} = "Brest";
$areanames{fr}->{3329092} = "Rennes";
$areanames{fr}->{3329093} = "Guingamp";
$areanames{fr}->{3329094} = "Carhaix\-Plouguer";
$areanames{fr}->{3329095} = "Rennes";
$areanames{fr}->{3329096} = "Guingamp";
$areanames{fr}->{3329097} = "Lamballe";
$areanames{fr}->{3329098} = "Auray";
$areanames{fr}->{3329099} = "Vannes";
$areanames{fr}->{3329601} = "Saint\-Brieuc";
$areanames{fr}->{3329611} = "Ploumagoar";
$areanames{fr}->{3329614} = "Lannion";
$areanames{fr}->{3329615} = "Trébeurden";
$areanames{fr}->{3329616} = "Plouézec";
$areanames{fr}->{3329620} = "Paimpol";
$areanames{fr}->{3329623} = "Perros\-Guirec";
$areanames{fr}->{3329628} = "Loudéac";
$areanames{fr}->{3329629} = "Rostrenen";
$areanames{fr}->{3329630} = "Lamballe";
$areanames{fr}->{3329631} = "Lamballe";
$areanames{fr}->{3329633} = "Saint\-Brieuc";
$areanames{fr}->{3329635} = "Plestin\-les\-Grèves";
$areanames{fr}->{3329636} = "Plouguernével";
$areanames{fr}->{3329637} = "Lannion";
$areanames{fr}->{3329638} = "Plouaret";
$areanames{fr}->{3329639} = "Dinan";
$areanames{fr}->{3329640} = "Guingamp";
$areanames{fr}->{3329641} = "Saint\-Cast\-le\-Guildo";
$areanames{fr}->{3329644} = "Guingamp";
$areanames{fr}->{3329645} = "Bégard";
$areanames{fr}->{3329646} = "Lannion";
$areanames{fr}->{3329647} = "Ploubezre";
$areanames{fr}->{3329648} = "Lannion";
$areanames{fr}->{3329649} = "Perros\-Guirec";
$areanames{fr}->{3329650} = "Lamballe";
$areanames{fr}->{3329652} = "Langueux";
$areanames{fr}->{3329654} = "Plestin\-les\-Grèves";
$areanames{fr}->{3329655} = "Paimpol";
$areanames{fr}->{3329656} = "Illifaut";
$areanames{fr}->{3329658} = "Plérin";
$areanames{fr}->{3329660} = "Saint\-Brieuc";
$areanames{fr}->{3329661} = "Saint\-Brieuc";
$areanames{fr}->{3329662} = "Saint\-Brieuc";
$areanames{fr}->{3329663} = "Pléneuf\-Val\-André";
$areanames{fr}->{3329664} = "Plédran";
$areanames{fr}->{3329665} = "Lanvollon";
$areanames{fr}->{3329666} = "Loudéac";
$areanames{fr}->{3329668} = "Saint\-Brieuc";
$areanames{fr}->{3329669} = "Binic";
$areanames{fr}->{3329670} = "Saint\-Quay\-Portrieux";
$areanames{fr}->{3329671} = "Trégueux";
$areanames{fr}->{3329672} = "Erquy";
$areanames{fr}->{3329673} = "Binic";
$areanames{fr}->{3329674} = "Plérin";
$areanames{fr}->{3329675} = "Saint\-Brieuc";
$areanames{fr}->{3329676} = "Ploufragan";
$areanames{fr}->{3329677} = "Saint\-Brieuc";
$areanames{fr}->{3329678} = "Saint\-Brieuc";
$areanames{fr}->{3329679} = "Pordic";
$areanames{fr}->{3329680} = "Broons";
$areanames{fr}->{3329684} = "Plancoët";
$areanames{fr}->{3329685} = "Dinan";
$areanames{fr}->{3329687} = "Dinan";
$areanames{fr}->{3329691} = "Perros\-Guirec";
$areanames{fr}->{3329692} = "Tréguier";
$areanames{fr}->{3329694} = "Saint\-Brieuc";
$areanames{fr}->{3329695} = "Pontrieux";
$areanames{fr}->{3329701} = "Vannes";
$areanames{fr}->{3329702} = "Guidel";
$areanames{fr}->{3329705} = "Quéven";
$areanames{fr}->{3329708} = "Baud";
$areanames{fr}->{3329711} = "Plouay";
$areanames{fr}->{3329721} = "Lorient";
$areanames{fr}->{3329722} = "Guer";
$areanames{fr}->{3329723} = "Gourin";
$areanames{fr}->{3329724} = "Auray";
$areanames{fr}->{3329725} = "Pontivy";
$areanames{fr}->{3329726} = "Questembert";
$areanames{fr}->{3329727} = "Pontivy";
$areanames{fr}->{3329728} = "Séglien";
$areanames{fr}->{3329729} = "Auray";
$areanames{fr}->{3329730} = "Quiberon";
$areanames{fr}->{3329731} = "Le\ Palais";
$areanames{fr}->{3329732} = "Pont\-Scorff";
$areanames{fr}->{3329733} = "Plouay";
$areanames{fr}->{3329734} = "Guiscriff";
$areanames{fr}->{3329735} = "Lorient";
$areanames{fr}->{3329736} = "Hennebont";
$areanames{fr}->{3329737} = "Lorient";
$areanames{fr}->{3329740} = "Vannes";
$areanames{fr}->{3329741} = "Sarzeau";
$areanames{fr}->{3329742} = "Vannes";
$areanames{fr}->{3329743} = "Theix";
$areanames{fr}->{3329744} = "Arradon";
$areanames{fr}->{3329746} = "Vannes";
$areanames{fr}->{3329747} = "Vannes";
$areanames{fr}->{3329748} = "Sarzeau";
$areanames{fr}->{3329749} = "Questembert";
$areanames{fr}->{3329750} = "Quiberon";
$areanames{fr}->{3329752} = "Carnac";
$areanames{fr}->{3329753} = "Elven";
$areanames{fr}->{3329754} = "Vannes";
$areanames{fr}->{3329755} = "Belz";
$areanames{fr}->{3329756} = "Auray";
$areanames{fr}->{3329757} = "Baden";
$areanames{fr}->{3329758} = "Baden";
$areanames{fr}->{3329762} = "Vannes";
$areanames{fr}->{3329763} = "Vannes";
$areanames{fr}->{3329764} = "Lorient";
$areanames{fr}->{3329765} = "Languidic";
$areanames{fr}->{3329766} = "Grand\-Champ";
$areanames{fr}->{3329768} = "Vannes";
$areanames{fr}->{3329769} = "Vannes";
$areanames{fr}->{3329770} = "Guer";
$areanames{fr}->{3329772} = "Ploërmel";
$areanames{fr}->{3329773} = "Ploërmel";
$areanames{fr}->{3329774} = "Ploërmel";
$areanames{fr}->{3329776} = "Lanester";
$areanames{fr}->{3329780} = "Quéven";
$areanames{fr}->{3329781} = "Lanester";
$areanames{fr}->{3329782} = "Ploërmel";
$areanames{fr}->{3329783} = "Lorient";
$areanames{fr}->{3329784} = "Lorient";
$areanames{fr}->{3329785} = "Hennebont";
$areanames{fr}->{3329786} = "Ploërmel";
$areanames{fr}->{3329787} = "Lorient";
$areanames{fr}->{3329788} = "Lorient";
$areanames{fr}->{3329789} = "Lanester";
$areanames{fr}->{332979} = "Nord\ Ouest";
$areanames{fr}->{3329800} = "Brest";
$areanames{fr}->{3329801} = "Brest";
$areanames{fr}->{3329802} = "Brest";
$areanames{fr}->{3329803} = "Brest";
$areanames{fr}->{3329804} = "Lannilis";
$areanames{fr}->{3329805} = "Brest";
$areanames{fr}->{3329806} = "Riec\-sur\-Bélon";
$areanames{fr}->{3329807} = "Guilers";
$areanames{fr}->{3329809} = "Pont\-Aven";
$areanames{fr}->{3329810} = "Quimper";
$areanames{fr}->{3329811} = "Douarnenez";
$areanames{fr}->{3329815} = "Morlaix";
$areanames{fr}->{3329816} = "Crozon";
$areanames{fr}->{3329817} = "Crozon";
$areanames{fr}->{3329819} = "Saint\-Pol\-de\-Léon";
$areanames{fr}->{3329821} = "Landerneau";
$areanames{fr}->{3329824} = "Landivisiau";
$areanames{fr}->{3329826} = "Pleyben";
$areanames{fr}->{3329827} = "Crozon";
$areanames{fr}->{3329828} = "Le\ Relecq\ Kerhuon";
$areanames{fr}->{3329829} = "Saint\-Pol\-de\-Léon";
$areanames{fr}->{3329830} = "Landerneau";
$areanames{fr}->{3329832} = "Saint\-Renan";
$areanames{fr}->{3329833} = "Brest";
$areanames{fr}->{3329834} = "Brest";
$areanames{fr}->{3329835} = "Quimperlé";
$areanames{fr}->{3329837} = "Plabennec";
$areanames{fr}->{3329838} = "Ploudalmézeau";
$areanames{fr}->{3329839} = "Bannalec";
$areanames{fr}->{332984} = "Brest";
$areanames{fr}->{3329840} = "Plougastel\-Daoulas";
$areanames{fr}->{3329848} = "Ploudalmézeau";
$areanames{fr}->{3329850} = "Concarneau";
$areanames{fr}->{3329851} = "Fouesnant";
$areanames{fr}->{3329852} = "Quimper";
$areanames{fr}->{3329853} = "Quimper";
$areanames{fr}->{3329854} = "Plogastel\-Saint\-Germain";
$areanames{fr}->{3329855} = "Quimper";
$areanames{fr}->{3329856} = "Fouesnant";
$areanames{fr}->{3329857} = "Briec";
$areanames{fr}->{3329858} = "Penmarch";
$areanames{fr}->{3329859} = "Rosporden";
$areanames{fr}->{3329860} = "Concarneau";
$areanames{fr}->{3329861} = "Plounévez\-Lochrist";
$areanames{fr}->{3329862} = "Morlaix";
$areanames{fr}->{3329863} = "Morlaix";
$areanames{fr}->{3329864} = "Quimper";
$areanames{fr}->{3329866} = "Pont\-l\'Abbé";
$areanames{fr}->{3329868} = "Landivisiau";
$areanames{fr}->{3329869} = "Saint\-Pol\-de\-Léon";
$areanames{fr}->{3329870} = "Audierne";
$areanames{fr}->{3329871} = "Clohars\-Carnoët";
$areanames{fr}->{3329872} = "Guerlesquin";
$areanames{fr}->{3329874} = "Douarnenez";
$areanames{fr}->{3329875} = "Douarnenez";
$areanames{fr}->{3329878} = "Pleyber\-Christ";
$areanames{fr}->{3329880} = "Brest";
$areanames{fr}->{3329881} = "Châteauneuf\-du\-Faou";
$areanames{fr}->{3329882} = "Pont\-l\'Abbé";
$areanames{fr}->{3329883} = "Lesneven";
$areanames{fr}->{3329884} = "Guipavas";
$areanames{fr}->{3329885} = "Landerneau";
$areanames{fr}->{3329886} = "Chateaulin";
$areanames{fr}->{3329887} = "Pont\-l\'Abbé";
$areanames{fr}->{3329888} = "Morlaix";
$areanames{fr}->{3329890} = "Quimper";
$areanames{fr}->{3329891} = "Plozévet";
$areanames{fr}->{3329892} = "Douarnenez";
$areanames{fr}->{3329893} = "Carhaix\-Plouguer";
$areanames{fr}->{3329895} = "Quimper";
$areanames{fr}->{3329896} = "Quimperlé";
$areanames{fr}->{3329897} = "Concarneau";
$areanames{fr}->{3329898} = "Quimper";
$areanames{fr}->{3329899} = "Carhaix\-Plouguer";
$areanames{fr}->{3329900} = "Châteaubourg";
$areanames{fr}->{3329905} = "Bruz";
$areanames{fr}->{3329906} = "Montauban\-de\-Bretagne";
$areanames{fr}->{3329909} = "Montfort\-sur\-Meu";
$areanames{fr}->{3329913} = "Melesse";
$areanames{fr}->{3329914} = "Rennes";
$areanames{fr}->{3329916} = "Dinard";
$areanames{fr}->{3329917} = "Fougères";
$areanames{fr}->{3329918} = "Saint\-Brice\-en\-Coglès";
$areanames{fr}->{3329919} = "Saint\-Malo";
$areanames{fr}->{3329920} = "Saint\-Malo";
$areanames{fr}->{3329921} = "Saint\-Malo";
$areanames{fr}->{3329922} = "Rennes";
$areanames{fr}->{3329923} = "Saint\-Grégoire";
$areanames{fr}->{3329926} = "Rennes";
$areanames{fr}->{3329927} = "Rennes";
$areanames{fr}->{3329929} = "Rennes";
$areanames{fr}->{3329930} = "Rennes";
$areanames{fr}->{3329931} = "Rennes";
$areanames{fr}->{3329932} = "Rennes";
$areanames{fr}->{3329933} = "Rennes";
$areanames{fr}->{3329935} = "Rennes";
$areanames{fr}->{3329936} = "Rennes";
$areanames{fr}->{3329937} = "Châteaugiron";
$areanames{fr}->{3329938} = "Rennes";
$areanames{fr}->{3329939} = "Saint\-Aubin\-du\-Cormier";
$areanames{fr}->{3329940} = "Saint\-Malo";
$areanames{fr}->{3329941} = "Chantepie";
$areanames{fr}->{3329942} = "Laillé";
$areanames{fr}->{3329943} = "Bain\-de\-Bretagne";
$areanames{fr}->{3329946} = "Dinard";
$areanames{fr}->{3329947} = "Janzé";
$areanames{fr}->{3329948} = "Dol\-de\-Bretagne";
$areanames{fr}->{3329949} = "Val\-d\'Izé";
$areanames{fr}->{3329950} = "Rennes";
$areanames{fr}->{3329951} = "Rennes";
$areanames{fr}->{3329952} = "Bruz";
$areanames{fr}->{3329953} = "Rennes";
$areanames{fr}->{3329954} = "Rennes";
$areanames{fr}->{3329955} = "Betton";
$areanames{fr}->{3329956} = "Saint\-Malo";
$areanames{fr}->{3329957} = "Guichen";
$areanames{fr}->{3329959} = "Rennes";
$areanames{fr}->{3329960} = "Pacé";
$areanames{fr}->{3329961} = "Plélan\-le\-Grand";
$areanames{fr}->{3329962} = "Vern\-sur\-Seiche";
$areanames{fr}->{3329963} = "Rennes";
$areanames{fr}->{3329964} = "Saint\-Gilles";
$areanames{fr}->{3329965} = "Rennes";
$areanames{fr}->{3329966} = "Melesse";
$areanames{fr}->{3329967} = "Rennes";
$areanames{fr}->{3329968} = "Liffré";
$areanames{fr}->{3329969} = "Gévezé";
$areanames{fr}->{3329970} = "Sixt\-sur\-Aff";
$areanames{fr}->{3329971} = "Redon";
$areanames{fr}->{3329972} = "Redon";
$areanames{fr}->{3329973} = "Combourg";
$areanames{fr}->{3329974} = "Vitré";
$areanames{fr}->{3329975} = "Vitré";
$areanames{fr}->{3329977} = "Chartres\-de\-Bretagne";
$areanames{fr}->{3329978} = "Rennes";
$areanames{fr}->{3329979} = "Rennes";
$areanames{fr}->{3329981} = "Saint\-Malo";
$areanames{fr}->{3329982} = "Saint\-Malo";
$areanames{fr}->{3329983} = "Cesson\-Sévigné";
$areanames{fr}->{3329984} = "Rennes";
$areanames{fr}->{3329985} = "Pacé";
$areanames{fr}->{3329986} = "Rennes";
$areanames{fr}->{3329987} = "Rennes";
$areanames{fr}->{3329988} = "Pleurtuit";
$areanames{fr}->{3329989} = "Cancale";
$areanames{fr}->{3329990} = "Nivillac";
$areanames{fr}->{3329992} = "Guignen";
$areanames{fr}->{3329993} = "Carentoir";
$areanames{fr}->{3329994} = "Fougères";
$areanames{fr}->{3329998} = "Louvigné\-du\-Désert";
$areanames{fr}->{3329999} = "Fougères";
$areanames{fr}->{3331000} = "Reims";
$areanames{fr}->{3331001} = "Epernay";
$areanames{fr}->{3331002} = "Sainte\-Menehould";
$areanames{fr}->{3331003} = "Sézanne";
$areanames{fr}->{3331004} = "Troyes";
$areanames{fr}->{3331005} = "Vitry\-le\-François";
$areanames{fr}->{3331006} = "Vouziers";
$areanames{fr}->{3331007} = "Charleville\-Mézières";
$areanames{fr}->{3331008} = "Rethel";
$areanames{fr}->{3331009} = "Vouziers";
$areanames{fr}->{3331010} = "Arcis\-sur\-Aube";
$areanames{fr}->{3331011} = "Bar\-sur\-Aube";
$areanames{fr}->{3331012} = "Bar\-sur\-Seine";
$areanames{fr}->{3331013} = "Romilly\-sur\-Seine";
$areanames{fr}->{3331014} = "Châlons\-en\-Champagne";
$areanames{fr}->{3331015} = "Epernay";
$areanames{fr}->{3331016} = "Reims";
$areanames{fr}->{3331017} = "Sainte\-Menehould";
$areanames{fr}->{3331018} = "Sézanne";
$areanames{fr}->{3331019} = "Vitry\-le\-François";
$areanames{fr}->{3331020} = "Chaumont";
$areanames{fr}->{3331021} = "Saint\-Dizier";
$areanames{fr}->{3331022} = "Châlons\-en\-Champagne";
$areanames{fr}->{3331023} = "Charleville\-Mézières";
$areanames{fr}->{3331024} = "Chaumont";
$areanames{fr}->{3331025} = "Epernay";
$areanames{fr}->{3331026} = "Rethel";
$areanames{fr}->{3331027} = "Sainte\-Menehould";
$areanames{fr}->{3331028} = "Vitry\-le\-François";
$areanames{fr}->{3331029} = "Vouziers";
$areanames{fr}->{3331030} = "Troyes";
$areanames{fr}->{3331031} = "Reims";
$areanames{fr}->{3331032} = "Châlons\-en\-Champagne";
$areanames{fr}->{3331033} = "Epernay";
$areanames{fr}->{3331034} = "Reims";
$areanames{fr}->{3331035} = "Vitry\-le\-François";
$areanames{fr}->{3331036} = "Reims";
$areanames{fr}->{3331037} = "Chaumont";
$areanames{fr}->{3331038} = "Rethel";
$areanames{fr}->{3331039} = "Vitry\-le\-François";
$areanames{fr}->{3331040} = "Charleville\-Mézières";
$areanames{fr}->{3331041} = "Epernay";
$areanames{fr}->{3331042} = "Châlons\-en\-Champagne";
$areanames{fr}->{3331043} = "Charleville\-Mézières";
$areanames{fr}->{3331044} = "Chaumont";
$areanames{fr}->{3331045} = "Reims";
$areanames{fr}->{3331046} = "Vitry\-le\-François";
$areanames{fr}->{3331047} = "Vouziers";
$areanames{fr}->{3331048} = "Arcis\-sur\-Aube";
$areanames{fr}->{3331049} = "Bar\-sur\-Aube";
$areanames{fr}->{3331050} = "Epernay";
$areanames{fr}->{3331051} = "Reims";
$areanames{fr}->{3331052} = "Bar\-sur\-Seine";
$areanames{fr}->{3331053} = "Châlons\-en\-Champagne";
$areanames{fr}->{3331054} = "Charleville\-Mézières";
$areanames{fr}->{3331055} = "Chaumont";
$areanames{fr}->{3331056} = "Epernay";
$areanames{fr}->{3331057} = "Reims";
$areanames{fr}->{3331058} = "Rethel";
$areanames{fr}->{3331059} = "Romilly\-sur\-Seine";
$areanames{fr}->{3331060} = "Vitry\-le\-François";
$areanames{fr}->{3331061} = "Saint\-Dizier";
$areanames{fr}->{3331062} = "Sainte\-Menehould";
$areanames{fr}->{3331063} = "Sézanne";
$areanames{fr}->{3331064} = "Troyes";
$areanames{fr}->{3331065} = "Vitry\-le\-François";
$areanames{fr}->{3331066} = "Vouziers";
$areanames{fr}->{3331067} = "Châlons\-en\-Champagne";
$areanames{fr}->{3331068} = "Sézanne";
$areanames{fr}->{3331069} = "Saint\-Dizier";
$areanames{fr}->{3331070} = "Châlons\-en\-Champagne";
$areanames{fr}->{3331071} = "Charleville\-Mézières";
$areanames{fr}->{3331072} = "Troyes";
$areanames{fr}->{3331073} = "Reims";
$areanames{fr}->{3331074} = "Chaumont";
$areanames{fr}->{3331075} = "Charleville\-Mézières";
$areanames{fr}->{3331076} = "Rethel";
$areanames{fr}->{3331077} = "Vouziers";
$areanames{fr}->{3331078} = "Arcis\-sur\-Aube";
$areanames{fr}->{3331079} = "Bar\-sur\-Aube";
$areanames{fr}->{3331080} = "Bar\-sur\-Seine";
$areanames{fr}->{3331081} = "Romilly\-sur\-Seine";
$areanames{fr}->{3331082} = "Troyes";
$areanames{fr}->{3331083} = "Châlons\-en\-Champagne";
$areanames{fr}->{3331084} = "Epernay";
$areanames{fr}->{3331085} = "Sainte\-Menehould";
$areanames{fr}->{3331086} = "Sézanne";
$areanames{fr}->{3331087} = "Vitry\-le\-François";
$areanames{fr}->{3331088} = "Chaumont";
$areanames{fr}->{3331089} = "Saint\-Dizier";
$areanames{fr}->{3331090} = "Charleville\-Mézières";
$areanames{fr}->{3331091} = "Châlons\-en\-Champagne";
$areanames{fr}->{3331092} = "Troyes";
$areanames{fr}->{3331093} = "Charleville\-Mézières";
$areanames{fr}->{3331094} = "Troyes";
$areanames{fr}->{3331095} = "Troyes";
$areanames{fr}->{3331096} = "Chaumont";
$areanames{fr}->{3331097} = "Troyes";
$areanames{fr}->{3331098} = "Epernay";
$areanames{fr}->{3331099} = "Reims";
$areanames{fr}->{3332001} = "Tourcoing";
$areanames{fr}->{3332002} = "Roubaix";
$areanames{fr}->{3332003} = "Tourcoing";
$areanames{fr}->{3332004} = "Mons\-en\-Barœul";
$areanames{fr}->{3332005} = "Villeneuve\-d\'Ascq";
$areanames{fr}->{3332006} = "Lille";
$areanames{fr}->{3332007} = "Loos";
$areanames{fr}->{3332008} = "Pérenchies";
$areanames{fr}->{3332009} = "Lomme";
$areanames{fr}->{3332011} = "Tourcoing";
$areanames{fr}->{3332012} = "Lille";
$areanames{fr}->{3332013} = "Lille";
$areanames{fr}->{3332014} = "Lille";
$areanames{fr}->{3332015} = "Lille";
$areanames{fr}->{3332017} = "Lille";
$areanames{fr}->{3332018} = "Lille";
$areanames{fr}->{3332019} = "Villeneuve\-d\'Ascq";
$areanames{fr}->{3332020} = "Roubaix";
$areanames{fr}->{3332021} = "Lille";
$areanames{fr}->{3332022} = "Lomme";
$areanames{fr}->{3332023} = "Bondues";
$areanames{fr}->{3332024} = "Tourcoing";
$areanames{fr}->{3332025} = "Tourcoing";
$areanames{fr}->{3332026} = "Tourcoing";
$areanames{fr}->{3332027} = "Tourcoing";
$areanames{fr}->{3332028} = "Tourcoing";
$areanames{fr}->{3332029} = "La\ Bassée";
$areanames{fr}->{3332030} = "Lille";
$areanames{fr}->{3332031} = "Lille";
$areanames{fr}->{3332032} = "Seclin";
$areanames{fr}->{3332033} = "Villeneuve\-d\'Ascq";
$areanames{fr}->{3332034} = "Villeneuve\-d\'Ascq";
$areanames{fr}->{3332035} = "Armentières";
$areanames{fr}->{3332036} = "Tourcoing";
$areanames{fr}->{3332039} = "Comines";
$areanames{fr}->{3332040} = "Lille";
$areanames{fr}->{3332041} = "Villeneuve\-d\'Ascq";
$areanames{fr}->{3332042} = "Lille";
$areanames{fr}->{3332043} = "Villeneuve\-d\'Ascq";
$areanames{fr}->{3332045} = "Roubaix";
$areanames{fr}->{3332047} = "Villeneuve\-d\'Ascq";
$areanames{fr}->{3332048} = "Nieppe";
$areanames{fr}->{3332049} = "Lille";
$areanames{fr}->{3332051} = "Lille";
$areanames{fr}->{3332052} = "Lille";
$areanames{fr}->{3332053} = "Lille";
$areanames{fr}->{3332054} = "Lille";
$areanames{fr}->{3332055} = "Lille";
$areanames{fr}->{3332056} = "Lille";
$areanames{fr}->{3332057} = "Lille";
$areanames{fr}->{3332058} = "Wavrin";
$areanames{fr}->{3332060} = "Wattignies";
$areanames{fr}->{3332062} = "Seclin";
$areanames{fr}->{3332063} = "Lille";
$areanames{fr}->{3332065} = "Marcq\-en\-Barœul";
$areanames{fr}->{3332066} = "Roubaix";
$areanames{fr}->{3332067} = "Villeneuve\-d\'Ascq";
$areanames{fr}->{3332068} = "Tourcoing";
$areanames{fr}->{3332069} = "Tourcoing";
$areanames{fr}->{3332070} = "Roubaix";
$areanames{fr}->{3332071} = "Orchies";
$areanames{fr}->{3332072} = "Marcq\-en\-Barœul";
$areanames{fr}->{3332073} = "Roubaix";
$areanames{fr}->{3332074} = "Lille";
$areanames{fr}->{3332075} = "Roubaix";
$areanames{fr}->{3332076} = "Tourcoing";
$areanames{fr}->{3332077} = "Armentières";
$areanames{fr}->{3332078} = "Lille";
$areanames{fr}->{3332080} = "Roubaix";
$areanames{fr}->{3332081} = "Roubaix";
$areanames{fr}->{3332082} = "Roubaix";
$areanames{fr}->{3332083} = "Roubaix";
$areanames{fr}->{3332085} = "Annœullin";
$areanames{fr}->{3332087} = "Lesquin";
$areanames{fr}->{3332088} = "Lille";
$areanames{fr}->{3332089} = "Marcq\-en\-Barœul";
$areanames{fr}->{3332090} = "Seclin";
$areanames{fr}->{3332091} = "Villeneuve\-d\'Ascq";
$areanames{fr}->{3332092} = "Lomme";
$areanames{fr}->{3332093} = "Lille";
$areanames{fr}->{3332094} = "Tourcoing";
$areanames{fr}->{3332095} = "Wattignies";
$areanames{fr}->{3332098} = "Marcq\-en\-Barœul";
$areanames{fr}->{3332099} = "Roubaix";
$areanames{fr}->{3332100} = "Calais";
$areanames{fr}->{3332101} = "Béthune";
$areanames{fr}->{3332103} = "Saint\-Pol\-sur\-Ternoise";
$areanames{fr}->{3332105} = "Le\ Touquet\ Paris\ Plage";
$areanames{fr}->{3332106} = "Montreuil";
$areanames{fr}->{3332109} = "Berck\ sur\ Mer";
$areanames{fr}->{3332110} = "Boulogne\-sur\-Mer";
$areanames{fr}->{3332113} = "Lens";
$areanames{fr}->{3332114} = "Lens";
$areanames{fr}->{3332115} = "Arras";
$areanames{fr}->{3332116} = "Arras";
$areanames{fr}->{3332117} = "Calais";
$areanames{fr}->{3332119} = "Calais";
$areanames{fr}->{3332120} = "Hénin\-Beaumont";
$areanames{fr}->{3332121} = "Arras";
$areanames{fr}->{3332123} = "Arras";
$areanames{fr}->{3332128} = "Lens";
$areanames{fr}->{3332129} = "Bully\-les\-Mines";
$areanames{fr}->{3332130} = "Boulogne\-sur\-Mer";
$areanames{fr}->{3332131} = "Boulogne\-sur\-Mer";
$areanames{fr}->{3332134} = "Calais";
$areanames{fr}->{3332136} = "Calais";
$areanames{fr}->{3332137} = "Carvin";
$areanames{fr}->{3332138} = "Saint\-Omer";
$areanames{fr}->{3332142} = "Lens";
$areanames{fr}->{3332143} = "Lens";
$areanames{fr}->{3332144} = "Liévin";
$areanames{fr}->{3332145} = "Liévin";
$areanames{fr}->{3332146} = "Calais";
$areanames{fr}->{3332149} = "Hénin\-Beaumont";
$areanames{fr}->{3332151} = "Arras";
$areanames{fr}->{3332153} = "Bruay\-la\-Buissière";
$areanames{fr}->{3332154} = "Lillers";
$areanames{fr}->{3332156} = "Béthune";
$areanames{fr}->{3332157} = "Béthune";
$areanames{fr}->{3332160} = "Arras";
$areanames{fr}->{3332162} = "Bruay\-la\-Buissière";
$areanames{fr}->{3332163} = "Béthune";
$areanames{fr}->{3332167} = "Lens";
$areanames{fr}->{3332168} = "Béthune";
$areanames{fr}->{3332169} = "Wingles";
$areanames{fr}->{3332170} = "Lens";
$areanames{fr}->{3332171} = "Arras";
$areanames{fr}->{3332172} = "Liévin";
$areanames{fr}->{3332174} = "Carvin";
$areanames{fr}->{3332175} = "Hénin\-Beaumont";
$areanames{fr}->{3332176} = "Hénin\-Beaumont";
$areanames{fr}->{3332177} = "Leforest";
$areanames{fr}->{3332178} = "Lens";
$areanames{fr}->{3332180} = "Boulogne\-sur\-Mer";
$areanames{fr}->{3332185} = "Calais";
$areanames{fr}->{3332187} = "Boulogne\-sur\-Mer";
$areanames{fr}->{3332188} = "Saint\-Omer";
$areanames{fr}->{3332194} = "Étaples";
$areanames{fr}->{3332196} = "Calais";
$areanames{fr}->{3332197} = "Calais";
$areanames{fr}->{3332198} = "Saint\-Omer";
$areanames{fr}->{3332199} = "Boulogne\-sur\-Mer";
$areanames{fr}->{3332209} = "Moreuil";
$areanames{fr}->{3332219} = "Abbeville";
$areanames{fr}->{3332220} = "Abbeville";
$areanames{fr}->{3332222} = "Amiens";
$areanames{fr}->{3332224} = "Abbeville";
$areanames{fr}->{3332225} = "Rue";
$areanames{fr}->{3332226} = "Cayeux\-sur\-Mer";
$areanames{fr}->{3332227} = "Le\ Crotoy";
$areanames{fr}->{3332231} = "Abbeville";
$areanames{fr}->{3332232} = "Doullens";
$areanames{fr}->{3332233} = "Amiens";
$areanames{fr}->{3332235} = "Moreuil";
$areanames{fr}->{3332241} = "Ailly\-sur\-Noye";
$areanames{fr}->{3332243} = "Amiens";
$areanames{fr}->{3332244} = "Amiens";
$areanames{fr}->{3332245} = "Amiens";
$areanames{fr}->{3332246} = "Amiens";
$areanames{fr}->{3332247} = "Amiens";
$areanames{fr}->{3332248} = "Corbie";
$areanames{fr}->{3332249} = "Camon";
$areanames{fr}->{333225} = "Amiens";
$areanames{fr}->{3332256} = "Nord\ Est";
$areanames{fr}->{3332257} = "Nord\ Est";
$areanames{fr}->{3332258} = "Nord\ Est";
$areanames{fr}->{3332259} = "Nord\ Est";
$areanames{fr}->{3332260} = "Saint\-Valery\-sur\-Somme";
$areanames{fr}->{3332261} = "Friville\-Escarbotin";
$areanames{fr}->{3332266} = "Amiens";
$areanames{fr}->{3332270} = "Rivery";
$areanames{fr}->{3332271} = "Amiens";
$areanames{fr}->{3332272} = "Amiens";
$areanames{fr}->{3332274} = "Albert";
$areanames{fr}->{3332275} = "Albert";
$areanames{fr}->{3332277} = "Doullens";
$areanames{fr}->{3332278} = "Montdidier";
$areanames{fr}->{3332280} = "Amiens";
$areanames{fr}->{3332283} = "Chaulnes";
$areanames{fr}->{3332284} = "Péronne";
$areanames{fr}->{3332286} = "Roisel";
$areanames{fr}->{3332287} = "Roye";
$areanames{fr}->{3332288} = "Rosières\-en\-Santerre";
$areanames{fr}->{3332289} = "Amiens";
$areanames{fr}->{3332291} = "Amiens";
$areanames{fr}->{3332292} = "Amiens";
$areanames{fr}->{3332294} = "Hangest\-en\-Santerre";
$areanames{fr}->{3332295} = "Amiens";
$areanames{fr}->{3332296} = "Corbie";
$areanames{fr}->{3332297} = "Amiens";
$areanames{fr}->{3332304} = "Saint\-Quentin";
$areanames{fr}->{3332305} = "Saint\-Quentin";
$areanames{fr}->{3332306} = "Saint\-Quentin";
$areanames{fr}->{3332307} = "Bohain\-en\-Vermandois";
$areanames{fr}->{3332308} = "Saint\-Quentin";
$areanames{fr}->{333231} = "Nord\ Est";
$areanames{fr}->{333232} = "Laon";
$areanames{fr}->{3332336} = "Ham";
$areanames{fr}->{3332338} = "Chauny";
$areanames{fr}->{3332339} = "Chauny";
$areanames{fr}->{3332340} = "Chauny";
$areanames{fr}->{3332352} = "Chauny";
$areanames{fr}->{3332353} = "Soissons";
$areanames{fr}->{3332354} = "Vailly\-sur\-Aisne";
$areanames{fr}->{3332356} = "La\ Fère";
$areanames{fr}->{3332357} = "Tergnier";
$areanames{fr}->{3332358} = "Hirson";
$areanames{fr}->{3332359} = "Soissons";
$areanames{fr}->{3332361} = "Guise";
$areanames{fr}->{3332362} = "Saint\-Quentin";
$areanames{fr}->{3332364} = "Saint\-Quentin";
$areanames{fr}->{3332365} = "Saint\-Quentin";
$areanames{fr}->{3332367} = "Saint\-Quentin";
$areanames{fr}->{3332368} = "Saint\-Quentin";
$areanames{fr}->{3332369} = "Château\-Thierry";
$areanames{fr}->{3332373} = "Soissons";
$areanames{fr}->{3332375} = "Soissons";
$areanames{fr}->{3332376} = "Soissons";
$areanames{fr}->{3332379} = "Laon";
$areanames{fr}->{3332381} = "Ham";
$areanames{fr}->{3332383} = "Château\-Thierry";
$areanames{fr}->{3332384} = "Château\-Thierry";
$areanames{fr}->{3332393} = "Soissons";
$areanames{fr}->{3332396} = "Villers\-Cotterêts";
$areanames{fr}->{333240} = "Nord\ Est";
$areanames{fr}->{333241} = "Nord\ Est";
$areanames{fr}->{3332427} = "Sedan";
$areanames{fr}->{3332429} = "Sedan";
$areanames{fr}->{3332433} = "Charleville\-Mézières";
$areanames{fr}->{3332436} = "Charleville\-Mézières";
$areanames{fr}->{3332437} = "Charleville\-Mézières";
$areanames{fr}->{3332438} = "Rethel";
$areanames{fr}->{3332439} = "Rethel";
$areanames{fr}->{3332440} = "Revin";
$areanames{fr}->{3332441} = "Fumay";
$areanames{fr}->{3332442} = "Givet";
$areanames{fr}->{3332453} = "Nouzonville";
$areanames{fr}->{3332455} = "Charleville\-Mézières";
$areanames{fr}->{3332456} = "Charleville\-Mézières";
$areanames{fr}->{3332457} = "Charleville\-Mézières";
$areanames{fr}->{3332458} = "Charleville\-Mézières";
$areanames{fr}->{3332459} = "Charleville\-Mézières";
$areanames{fr}->{333246} = "Nord\ Est";
$areanames{fr}->{3332471} = "Vouziers";
$areanames{fr}->{333248} = "Nord\ Est";
$areanames{fr}->{333249} = "Nord\ Est";
$areanames{fr}->{3332501} = "Chaumont";
$areanames{fr}->{3332502} = "Chaumont";
$areanames{fr}->{3332503} = "Chaumont";
$areanames{fr}->{3332505} = "Saint\-Dizier";
$areanames{fr}->{3332506} = "Saint\-Dizier";
$areanames{fr}->{3332507} = "Saint\-Dizier";
$areanames{fr}->{333251} = "Nord\ Est";
$areanames{fr}->{3332524} = "Romilly\-sur\-Seine";
$areanames{fr}->{3332525} = "Romilly\-sur\-Seine";
$areanames{fr}->{3332527} = "Bar\-sur\-Aube";
$areanames{fr}->{3332529} = "Bar\-sur\-Seine";
$areanames{fr}->{3332530} = "Chaumont";
$areanames{fr}->{3332532} = "Chaumont";
$areanames{fr}->{3332535} = "Chaumont";
$areanames{fr}->{3332539} = "Nogent\-sur\-Seine";
$areanames{fr}->{333254} = "Troyes";
$areanames{fr}->{3332544} = "Nord\ Est";
$areanames{fr}->{3332547} = "Arcis\-sur\-Aube";
$areanames{fr}->{3332548} = "Nord\ Est";
$areanames{fr}->{3332556} = "Saint\-Dizier";
$areanames{fr}->{333256} = "Nord\ Est";
$areanames{fr}->{3332571} = "Troyes";
$areanames{fr}->{3332572} = "Troyes";
$areanames{fr}->{3332573} = "Troyes";
$areanames{fr}->{3332574} = "Troyes";
$areanames{fr}->{3332575} = "Troyes";
$areanames{fr}->{3332576} = "Troyes";
$areanames{fr}->{3332578} = "Troyes";
$areanames{fr}->{3332579} = "Sainte\-Savine";
$areanames{fr}->{3332580} = "Troyes";
$areanames{fr}->{3332581} = "Troyes";
$areanames{fr}->{3332582} = "Troyes";
$areanames{fr}->{3332583} = "Troyes";
$areanames{fr}->{3332587} = "Langres";
$areanames{fr}->{3332590} = "Bourbonne\-les\-Bains";
$areanames{fr}->{3332594} = "Joinville";
$areanames{fr}->{3332600} = "Nord\ Est";
$areanames{fr}->{3332601} = "Nord\ Est";
$areanames{fr}->{3332602} = "Reims";
$areanames{fr}->{3332603} = "Reims";
$areanames{fr}->{3332604} = "Reims";
$areanames{fr}->{3332605} = "Reims";
$areanames{fr}->{3332606} = "Reims";
$areanames{fr}->{3332607} = "Reims";
$areanames{fr}->{3332608} = "Reims";
$areanames{fr}->{3332609} = "Reims";
$areanames{fr}->{333261} = "Nord\ Est";
$areanames{fr}->{3332610} = "Reims";
$areanames{fr}->{3332611} = "Reims";
$areanames{fr}->{3332621} = "Châlons\-en\-Champagne";
$areanames{fr}->{3332622} = "Châlons\-en\-Champagne";
$areanames{fr}->{3332624} = "Reims";
$areanames{fr}->{3332626} = "Châlons\-en\-Champagne";
$areanames{fr}->{3332632} = "Épernay";
$areanames{fr}->{3332635} = "Reims";
$areanames{fr}->{3332636} = "Reims";
$areanames{fr}->{3332640} = "Reims";
$areanames{fr}->{3332641} = "Vitry\-le\-François";
$areanames{fr}->{3332646} = "Reims";
$areanames{fr}->{3332647} = "Reims";
$areanames{fr}->{3332648} = "Fismes";
$areanames{fr}->{3332650} = "Reims";
$areanames{fr}->{3332651} = "Épernay";
$areanames{fr}->{3332652} = "Vertus";
$areanames{fr}->{3332654} = "Épernay";
$areanames{fr}->{3332655} = "Épernay";
$areanames{fr}->{3332656} = "Épernay";
$areanames{fr}->{3332660} = "Sainte\-Menehould";
$areanames{fr}->{3332662} = "Vitry\-le\-François";
$areanames{fr}->{3332664} = "Châlons\-en\-Champagne";
$areanames{fr}->{3332665} = "Châlons\-en\-Champagne";
$areanames{fr}->{3332668} = "Châlons\-en\-Champagne";
$areanames{fr}->{3332669} = "Châlons\-en\-Champagne";
$areanames{fr}->{3332670} = "Châlons\-en\-Champagne";
$areanames{fr}->{3332674} = "Vitry\-le\-François";
$areanames{fr}->{3332677} = "Reims";
$areanames{fr}->{3332679} = "Reims";
$areanames{fr}->{3332680} = "Sézanne";
$areanames{fr}->{3332682} = "Reims";
$areanames{fr}->{3332683} = "Reims";
$areanames{fr}->{3332684} = "Reims";
$areanames{fr}->{3332685} = "Reims";
$areanames{fr}->{3332686} = "Reims";
$areanames{fr}->{3332687} = "Reims";
$areanames{fr}->{3332688} = "Reims";
$areanames{fr}->{3332689} = "Reims";
$areanames{fr}->{3332691} = "Reims";
$areanames{fr}->{3332708} = "Douai";
$areanames{fr}->{3332709} = "Valenciennes";
$areanames{fr}->{3332714} = "Valenciennes";
$areanames{fr}->{3332719} = "Valenciennes";
$areanames{fr}->{333272} = "Valenciennes";
$areanames{fr}->{3332730} = "Valenciennes";
$areanames{fr}->{3332731} = "Denain";
$areanames{fr}->{3332732} = "Valenciennes";
$areanames{fr}->{3332733} = "Valenciennes";
$areanames{fr}->{3332739} = "Jeumont";
$areanames{fr}->{3332740} = "Vieux\-Condé";
$areanames{fr}->{3332741} = "Valenciennes";
$areanames{fr}->{3332742} = "Valenciennes";
$areanames{fr}->{3332743} = "Denain";
$areanames{fr}->{3332744} = "Denain";
$areanames{fr}->{3332745} = "Valenciennes";
$areanames{fr}->{3332746} = "Valenciennes";
$areanames{fr}->{3332747} = "Valenciennes";
$areanames{fr}->{3332748} = "Saint\-Amand\-les\-Eaux";
$areanames{fr}->{3332751} = "Valenciennes";
$areanames{fr}->{3332753} = "Maubeuge";
$areanames{fr}->{3332756} = "Avesnes\-sur\-Helpe";
$areanames{fr}->{3332758} = "Maubeuge";
$areanames{fr}->{3332760} = "Fourmies";
$areanames{fr}->{3332761} = "Avesnes\-sur\-Helpe";
$areanames{fr}->{3332762} = "Maubeuge";
$areanames{fr}->{3332763} = "Hautmont";
$areanames{fr}->{3332764} = "Maubeuge";
$areanames{fr}->{3332765} = "Maubeuge";
$areanames{fr}->{3332770} = "Cambrai";
$areanames{fr}->{3332771} = "Douai";
$areanames{fr}->{3332772} = "Cambrai";
$areanames{fr}->{3332773} = "Cambrai";
$areanames{fr}->{3332774} = "Cambrai";
$areanames{fr}->{3332775} = "Caudry";
$areanames{fr}->{3332776} = "Caudry";
$areanames{fr}->{3332778} = "Cambrai";
$areanames{fr}->{3332781} = "Cambrai";
$areanames{fr}->{3332782} = "Cambrai";
$areanames{fr}->{3332783} = "Cambrai";
$areanames{fr}->{3332784} = "Le\ Cateau\ Cambrésis";
$areanames{fr}->{3332785} = "Caudry";
$areanames{fr}->{3332786} = "Somain";
$areanames{fr}->{3332787} = "Douai";
$areanames{fr}->{3332788} = "Douai";
$areanames{fr}->{3332792} = "Aniche";
$areanames{fr}->{3332793} = "Douai";
$areanames{fr}->{3332794} = "Douai";
$areanames{fr}->{3332795} = "Douai";
$areanames{fr}->{3332796} = "Douai";
$areanames{fr}->{3332797} = "Douai";
$areanames{fr}->{3332798} = "Douai";
$areanames{fr}->{3332799} = "Douai";
$areanames{fr}->{3332804} = "Lille";
$areanames{fr}->{3332807} = "Lille";
$areanames{fr}->{3332814} = "Lille";
$areanames{fr}->{3332816} = "Seclin";
$areanames{fr}->{3332820} = "Dunkerque";
$areanames{fr}->{3332821} = "Grande\-Synthe";
$areanames{fr}->{3332822} = "Bourbourg";
$areanames{fr}->{3332823} = "Gravelines";
$areanames{fr}->{3332824} = "Dunkerque";
$areanames{fr}->{3332825} = "Dunkerque";
$areanames{fr}->{3332826} = "Téteghem";
$areanames{fr}->{3332828} = "Dunkerque";
$areanames{fr}->{3332829} = "Dunkerque";
$areanames{fr}->{3332833} = "Roubaix";
$areanames{fr}->{3332836} = "Lille";
$areanames{fr}->{3332838} = "Lille";
$areanames{fr}->{3332841} = "Hazebrouck";
$areanames{fr}->{3332844} = "Hazebrouck";
$areanames{fr}->{3332849} = "Bailleul";
$areanames{fr}->{3332850} = "Bailleul";
$areanames{fr}->{3332851} = "Dunkerque";
$areanames{fr}->{3332852} = "Lille";
$areanames{fr}->{3332853} = "Lille";
$areanames{fr}->{3332855} = "Lille";
$areanames{fr}->{3332858} = "Dunkerque";
$areanames{fr}->{3332859} = "Dunkerque";
$areanames{fr}->{3332860} = "Dunkerque";
$areanames{fr}->{3332861} = "Dunkerque";
$areanames{fr}->{3332863} = "Dunkerque";
$areanames{fr}->{3332864} = "Coudekerque\-Branche";
$areanames{fr}->{3332865} = "Wormhout";
$areanames{fr}->{3332866} = "Dunkerque";
$areanames{fr}->{3332868} = "Bergues";
$areanames{fr}->{3332869} = "Dunkerque";
$areanames{fr}->{333287} = "Nord\ Est";
$areanames{fr}->{3332876} = "Lille";
$areanames{fr}->{3332877} = "Lille";
$areanames{fr}->{333288} = "Nord\ Est";
$areanames{fr}->{3332880} = "Lille";
$areanames{fr}->{3332881} = "Lille";
$areanames{fr}->{3332882} = "Lille";
$areanames{fr}->{333289} = "Nord\ Est";
$areanames{fr}->{3332890} = "Lille";
$areanames{fr}->{3332908} = "Vittel";
$areanames{fr}->{333291} = "Nord\ Est";
$areanames{fr}->{3332922} = "Remiremont";
$areanames{fr}->{3332923} = "Remiremont";
$areanames{fr}->{3332925} = "La\ Bresse";
$areanames{fr}->{3332929} = "Épinal";
$areanames{fr}->{3332930} = "Le\ Val\-d\'Ajol";
$areanames{fr}->{3332931} = "Épinal";
$areanames{fr}->{3332932} = "Éloyes";
$areanames{fr}->{3332933} = "Épinal";
$areanames{fr}->{3332934} = "Épinal";
$areanames{fr}->{3332935} = "Épinal";
$areanames{fr}->{3332937} = "Mirecourt";
$areanames{fr}->{3332938} = "Charmes";
$areanames{fr}->{3332939} = "Thaon\-les\-Vosges";
$areanames{fr}->{3332941} = "Raon\-l\'Étape";
$areanames{fr}->{3332942} = "Saint\-Dié\-des\-Vosges";
$areanames{fr}->{3332945} = "Bar\-le\-Duc";
$areanames{fr}->{3332952} = "Saint\-Dié\-des\-Vosges";
$areanames{fr}->{3332955} = "Saint\-Dié\-des\-Vosges";
$areanames{fr}->{3332956} = "Saint\-Dié\-des\-Vosges";
$areanames{fr}->{3332957} = "Senones";
$areanames{fr}->{3332960} = "Gérardmer";
$areanames{fr}->{3332962} = "Remiremont";
$areanames{fr}->{3332963} = "Gérardmer";
$areanames{fr}->{3332964} = "Épinal";
$areanames{fr}->{3332965} = "Rambervillers";
$areanames{fr}->{3332966} = "Plombières\-les\-Bains";
$areanames{fr}->{3332968} = "Épinal";
$areanames{fr}->{3332976} = "Bar\-le\-Duc";
$areanames{fr}->{3332977} = "Bar\-le\-Duc";
$areanames{fr}->{3332978} = "Ligny\-en\-Barrois";
$areanames{fr}->{3332979} = "Bar\-le\-Duc";
$areanames{fr}->{3332981} = "Épinal";
$areanames{fr}->{3332982} = "Épinal";
$areanames{fr}->{3332983} = "Verdun";
$areanames{fr}->{3332984} = "Verdun";
$areanames{fr}->{3332986} = "Verdun";
$areanames{fr}->{3332991} = "Commercy";
$areanames{fr}->{3332992} = "Commercy";
$areanames{fr}->{3332994} = "Neufchâteau";
$areanames{fr}->{3333900} = "Lure";
$areanames{fr}->{3333901} = "Vesoul";
$areanames{fr}->{3333902} = "Belfort";
$areanames{fr}->{3333903} = "Belfort";
$areanames{fr}->{3333904} = "Dole";
$areanames{fr}->{3333905} = "Belfort";
$areanames{fr}->{3333906} = "Morteau";
$areanames{fr}->{3333907} = "Besançon";
$areanames{fr}->{3333908} = "Montbéliard";
$areanames{fr}->{3333909} = "Morteau";
$areanames{fr}->{3333910} = "Gray";
$areanames{fr}->{3333911} = "Morteau";
$areanames{fr}->{3333912} = "Pontarlier";
$areanames{fr}->{3333913} = "Arbois";
$areanames{fr}->{3333914} = "Dole";
$areanames{fr}->{3333915} = "Lons\-le\-Saunier";
$areanames{fr}->{3333916} = "Saint\-Claude";
$areanames{fr}->{3333917} = "Gray";
$areanames{fr}->{3333918} = "Lure";
$areanames{fr}->{3333919} = "Luxeuil\-les\-Bains";
$areanames{fr}->{3333920} = "Vesoul";
$areanames{fr}->{3333921} = "Besançon";
$areanames{fr}->{3333922} = "Belfort";
$areanames{fr}->{3333923} = "Lons\-le\-Saunier";
$areanames{fr}->{3333924} = "Vesoul";
$areanames{fr}->{3333925} = "Besançon";
$areanames{fr}->{3333926} = "Besançon";
$areanames{fr}->{3333927} = "Besançon";
$areanames{fr}->{3333928} = "Vesoul";
$areanames{fr}->{3333929} = "Lons\-le\-Saunier";
$areanames{fr}->{3333930} = "Montbéliard";
$areanames{fr}->{3333931} = "Dole";
$areanames{fr}->{3333932} = "Morteau";
$areanames{fr}->{3333933} = "Pontarlier";
$areanames{fr}->{3333934} = "Arbois";
$areanames{fr}->{3333935} = "Saint\-Claude";
$areanames{fr}->{3333936} = "Gray";
$areanames{fr}->{3333937} = "Lure";
$areanames{fr}->{3333938} = "Luxeuil\-les\-Bains";
$areanames{fr}->{3333939} = "Lons\-le\-Saunier";
$areanames{fr}->{3333940} = "Besançon";
$areanames{fr}->{3333941} = "Besançon";
$areanames{fr}->{3333942} = "Dole";
$areanames{fr}->{3333943} = "Lons\-le\-Saunier";
$areanames{fr}->{3333944} = "Saint\-Claude";
$areanames{fr}->{3333945} = "Gray";
$areanames{fr}->{3333946} = "Lure";
$areanames{fr}->{3333947} = "Luxeuil\-les\-Bains";
$areanames{fr}->{3333948} = "Vesoul";
$areanames{fr}->{3333949} = "Lons\-le\-Saunier";
$areanames{fr}->{3333950} = "Lons\-le\-Saunier";
$areanames{fr}->{3333951} = "Vesoul";
$areanames{fr}->{3333952} = "Dole";
$areanames{fr}->{3333953} = "Belfort";
$areanames{fr}->{3333954} = "Lons\-le\-Saunier";
$areanames{fr}->{3333970} = "Vesoul";
$areanames{fr}->{3333971} = "Lons\-le\-Saunier";
$areanames{fr}->{3333972} = "Belfort";
$areanames{fr}->{3333973} = "Besançon";
$areanames{fr}->{3333974} = "Gray";
$areanames{fr}->{3333975} = "Lure";
$areanames{fr}->{3333976} = "Luxeuil\-les\-Bains";
$areanames{fr}->{3333977} = "Vesoul";
$areanames{fr}->{3333978} = "Lons\-le\-Saunier";
$areanames{fr}->{3333979} = "Besançon";
$areanames{fr}->{3333980} = "Belfort";
$areanames{fr}->{3333981} = "Dole";
$areanames{fr}->{3333982} = "Vesoul";
$areanames{fr}->{3333983} = "Belfort";
$areanames{fr}->{3333984} = "Montbéliard";
$areanames{fr}->{3333985} = "Morteau";
$areanames{fr}->{3333986} = "Pontarlier";
$areanames{fr}->{3333987} = "Arbois";
$areanames{fr}->{3333988} = "Besançon";
$areanames{fr}->{3333989} = "Besançon";
$areanames{fr}->{3333990} = "Belfort";
$areanames{fr}->{3333991} = "Besançon";
$areanames{fr}->{3333992} = "Montbéliard";
$areanames{fr}->{3333993} = "Morteau";
$areanames{fr}->{3333994} = "Pontarlier";
$areanames{fr}->{3333995} = "Arbois";
$areanames{fr}->{3333996} = "Dole";
$areanames{fr}->{3333997} = "Lons\-le\-Saunier";
$areanames{fr}->{3333998} = "Saint\-Claude";
$areanames{fr}->{3333999} = "Belfort";
$areanames{fr}->{3334402} = "Beauvais";
$areanames{fr}->{3334403} = "Noailles";
$areanames{fr}->{3334405} = "Beauvais";
$areanames{fr}->{3334406} = "Beauvais";
$areanames{fr}->{3334407} = "Bresles";
$areanames{fr}->{3334409} = "Noyon";
$areanames{fr}->{3334410} = "Beauvais";
$areanames{fr}->{3334411} = "Beauvais";
$areanames{fr}->{3334412} = "Beauvais";
$areanames{fr}->{3334414} = "Beauvais";
$areanames{fr}->{3334415} = "Beauvais";
$areanames{fr}->{3334420} = "Compiègne";
$areanames{fr}->{3334421} = "Lamorlaye";
$areanames{fr}->{3334422} = "Méru";
$areanames{fr}->{3334423} = "Compiègne";
$areanames{fr}->{3334424} = "Creil";
$areanames{fr}->{3334425} = "Creil";
$areanames{fr}->{3334426} = "Neuilly\-en\-Thelle";
$areanames{fr}->{3334427} = "Précy\-sur\-Oise";
$areanames{fr}->{3334428} = "Creil";
$areanames{fr}->{3334429} = "Saint\-Martin\-Longueau";
$areanames{fr}->{3334430} = "Compiègne";
$areanames{fr}->{3334431} = "Pont\-Sainte\-Maxence";
$areanames{fr}->{3334432} = "Senlis";
$areanames{fr}->{3334436} = "Compiègne";
$areanames{fr}->{3334437} = "Jaux";
$areanames{fr}->{3334438} = "Compiègne";
$areanames{fr}->{3334439} = "Crépy\-en\-Valois";
$areanames{fr}->{3334440} = "Compiègne";
$areanames{fr}->{3334444} = "Noyon";
$areanames{fr}->{3334445} = "Beauvais";
$areanames{fr}->{3334447} = "Auneuil";
$areanames{fr}->{3334448} = "Beauvais";
$areanames{fr}->{3334449} = "Chaumont\-en\-Vexin";
$areanames{fr}->{3334450} = "Clermont";
$areanames{fr}->{3334452} = "Méru";
$areanames{fr}->{3334453} = "Senlis";
$areanames{fr}->{3334455} = "Creil";
$areanames{fr}->{3334456} = "Saint\-Leu\-d\'Esserent";
$areanames{fr}->{3334457} = "Chantilly";
$areanames{fr}->{3334458} = "Chantilly";
$areanames{fr}->{3334459} = "Crépy\-en\-Valois";
$areanames{fr}->{3334460} = "Senlis";
$areanames{fr}->{3334462} = "Chantilly";
$areanames{fr}->{3334463} = "Senlis";
$areanames{fr}->{3334464} = "Creil";
$areanames{fr}->{3334466} = "Nogent\-sur\-Oise";
$areanames{fr}->{3334470} = "Pont\-Sainte\-Maxence";
$areanames{fr}->{3334471} = "Nogent\-sur\-Oise";
$areanames{fr}->{3334472} = "Pont\-Sainte\-Maxence";
$areanames{fr}->{3334473} = "Liancourt";
$areanames{fr}->{3334474} = "Nogent\-sur\-Oise";
$areanames{fr}->{3334476} = "Thourotte";
$areanames{fr}->{3334478} = "Saint\-Just\-en\-Chaussée";
$areanames{fr}->{3334479} = "Troissereux";
$areanames{fr}->{3334483} = "Margny\-lès\-Compiègne";
$areanames{fr}->{3334486} = "Compiègne";
$areanames{fr}->{3334487} = "Crépy\-en\-Valois";
$areanames{fr}->{3334488} = "Nanteuil\-le\-Haudouin";
$areanames{fr}->{3334490} = "Compiègne";
$areanames{fr}->{3334491} = "La\ Croix\-Saint\-Ouen";
$areanames{fr}->{3334493} = "Noyon";
$areanames{fr}->{3334494} = "Crépy\-en\-Valois";
$areanames{fr}->{3334496} = "Thourotte";
$areanames{fr}->{3334497} = "Compiègne";
$areanames{fr}->{3334500} = "Autun";
$areanames{fr}->{3334501} = "Chalon\-sur\-Saône";
$areanames{fr}->{3334502} = "Auxerre";
$areanames{fr}->{3334503} = "Louhans";
$areanames{fr}->{3334504} = "Beaune";
$areanames{fr}->{3334505} = "Mâcon";
$areanames{fr}->{3334506} = "Montceau\-les\-Mines";
$areanames{fr}->{3334507} = "Paray\-le\-Monial";
$areanames{fr}->{3334508} = "Dijon";
$areanames{fr}->{3334509} = "Dijon";
$areanames{fr}->{3334510} = "Auxerre";
$areanames{fr}->{3334511} = "Is\-sur\-Tille";
$areanames{fr}->{3334512} = "Joigny";
$areanames{fr}->{3334513} = "Sens";
$areanames{fr}->{3334514} = "Tonnerre";
$areanames{fr}->{3334515} = "Toucy";
$areanames{fr}->{3334516} = "Dijon";
$areanames{fr}->{3334517} = "Châtillon\-sur\-Seine";
$areanames{fr}->{3334518} = "Dijon";
$areanames{fr}->{3334519} = "Is\-sur\-Tille";
$areanames{fr}->{3334520} = "Montbard";
$areanames{fr}->{3334521} = "Dijon";
$areanames{fr}->{3334522} = "Châtillon\-sur\-Seine";
$areanames{fr}->{3334523} = "Château\-Chinon\(Ville\)";
$areanames{fr}->{3334524} = "Cosne\-Cours\-sur\-Loire";
$areanames{fr}->{3334525} = "Decize";
$areanames{fr}->{3334526} = "Nevers";
$areanames{fr}->{3334527} = "Autun";
$areanames{fr}->{3334528} = "Chalon\-sur\-Saône";
$areanames{fr}->{3334529} = "Dijon";
$areanames{fr}->{3334530} = "Mâcon";
$areanames{fr}->{3334531} = "Montceau\-les\-Mines";
$areanames{fr}->{3334532} = "Paray\-le\-Monial";
$areanames{fr}->{3334533} = "Montbard";
$areanames{fr}->{3334534} = "Dijon";
$areanames{fr}->{3334535} = "Auxerre";
$areanames{fr}->{3334536} = "Joigny";
$areanames{fr}->{3334537} = "Sens";
$areanames{fr}->{3334538} = "Tonnerre";
$areanames{fr}->{3334539} = "Toucy";
$areanames{fr}->{3334540} = "Saulieu";
$areanames{fr}->{3334541} = "Beaune";
$areanames{fr}->{3334542} = "Dijon";
$areanames{fr}->{3334543} = "Dijon";
$areanames{fr}->{3334544} = "Saulieu";
$areanames{fr}->{3334545} = "Auxerre";
$areanames{fr}->{3334546} = "Beaune";
$areanames{fr}->{3334547} = "Mâcon";
$areanames{fr}->{3334548} = "Montceau\-les\-Mines";
$areanames{fr}->{3334549} = "Dijon";
$areanames{fr}->{3334550} = "Cosne\-Cours\-sur\-Loire";
$areanames{fr}->{3334551} = "Chalon\-sur\-Saône";
$areanames{fr}->{3334552} = "Nevers";
$areanames{fr}->{3334553} = "Paray\-le\-Monial";
$areanames{fr}->{3334554} = "Sens";
$areanames{fr}->{3334555} = "Autun";
$areanames{fr}->{3334556} = "Beaune";
$areanames{fr}->{3334557} = "Dijon";
$areanames{fr}->{3334558} = "Dijon";
$areanames{fr}->{3334559} = "Beaune";
$areanames{fr}->{3334560} = "Dijon";
$areanames{fr}->{3334561} = "Dijon";
$areanames{fr}->{3334562} = "Dijon";
$areanames{fr}->{3334563} = "Beaune";
$areanames{fr}->{3334564} = "Nevers";
$areanames{fr}->{3334565} = "Châtillon\-sur\-Seine";
$areanames{fr}->{3334566} = "Chalon\-sur\-Saône";
$areanames{fr}->{3334567} = "Is\-sur\-Tille";
$areanames{fr}->{3334568} = "Mâcon";
$areanames{fr}->{3334569} = "Montceau\-les\-Mines";
$areanames{fr}->{3334570} = "Paray\-le\-Monial";
$areanames{fr}->{3334571} = "Auxerre";
$areanames{fr}->{3334572} = "Joigny";
$areanames{fr}->{3334573} = "Sens";
$areanames{fr}->{3334574} = "Autun";
$areanames{fr}->{3334575} = "Auxerre";
$areanames{fr}->{3334576} = "Beaune";
$areanames{fr}->{3334577} = "Chalon\-sur\-Saône";
$areanames{fr}->{3334578} = "Château\-Chinon\(Ville\)";
$areanames{fr}->{3334579} = "Châtillon\-sur\-Seine";
$areanames{fr}->{3334580} = "Cosne\-Cours\-sur\-Loire";
$areanames{fr}->{3334581} = "Dijon";
$areanames{fr}->{3334582} = "Decize";
$areanames{fr}->{3334583} = "Dijon";
$areanames{fr}->{3334584} = "Is\-sur\-Tille";
$areanames{fr}->{3334585} = "Joigny";
$areanames{fr}->{3334586} = "Louhans";
$areanames{fr}->{3334587} = "Mâcon";
$areanames{fr}->{3334588} = "Joigny";
$areanames{fr}->{3334589} = "Auxerre";
$areanames{fr}->{3334590} = "Beaune";
$areanames{fr}->{3334591} = "Châtillon\-sur\-Seine";
$areanames{fr}->{3334592} = "Is\-sur\-Tille";
$areanames{fr}->{3334593} = "Montbard";
$areanames{fr}->{3334594} = "Saulieu";
$areanames{fr}->{3334595} = "Dijon";
$areanames{fr}->{3334596} = "Château\-Chinon\(Ville\)";
$areanames{fr}->{3334597} = "Cosne\-Cours\-sur\-Loire";
$areanames{fr}->{3334598} = "Decize";
$areanames{fr}->{3334599} = "Nevers";
$areanames{fr}->{3335100} = "Reims";
$areanames{fr}->{3335101} = "Reims";
$areanames{fr}->{3335102} = "Epernay";
$areanames{fr}->{3335103} = "Sainte\-Menehould";
$areanames{fr}->{3335104} = "Sézanne";
$areanames{fr}->{3335105} = "Vitry\-le\-François";
$areanames{fr}->{3335106} = "Chaumont";
$areanames{fr}->{3335107} = "Saint\-Dizier";
$areanames{fr}->{3335108} = "Reims";
$areanames{fr}->{3335109} = "Charleville\-Mézières";
$areanames{fr}->{3335110} = "Rethel";
$areanames{fr}->{3335111} = "Vouziers";
$areanames{fr}->{3335112} = "Reims";
$areanames{fr}->{3335113} = "Charleville\-Mézières";
$areanames{fr}->{3335114} = "Troyes";
$areanames{fr}->{3335115} = "Châlons\-en\-Champagne";
$areanames{fr}->{3335116} = "Charleville\-Mézières";
$areanames{fr}->{3335117} = "Arcis\-sur\-Aube";
$areanames{fr}->{3335118} = "Bar\-sur\-Aube";
$areanames{fr}->{3335119} = "Romilly\-sur\-Seine";
$areanames{fr}->{3335120} = "Romilly\-sur\-Seine";
$areanames{fr}->{3335121} = "Troyes";
$areanames{fr}->{3335122} = "Châlons\-en\-Champagne";
$areanames{fr}->{3335123} = "Epernay";
$areanames{fr}->{3335124} = "Reims";
$areanames{fr}->{3335125} = "Reims";
$areanames{fr}->{3335126} = "Sézanne";
$areanames{fr}->{3335127} = "Vitry\-le\-François";
$areanames{fr}->{3335128} = "Chaumont";
$areanames{fr}->{3335129} = "Saint\-Dizier";
$areanames{fr}->{3335130} = "Reims";
$areanames{fr}->{3335131} = "Reims";
$areanames{fr}->{3335132} = "Arcis\-sur\-Aube";
$areanames{fr}->{3335133} = "Troyes";
$areanames{fr}->{3335134} = "Bar\-sur\-Aube";
$areanames{fr}->{3335135} = "Troyes";
$areanames{fr}->{3335136} = "Bar\-sur\-Seine";
$areanames{fr}->{3335137} = "Châlons\-en\-Champagne";
$areanames{fr}->{3335138} = "Charleville\-Mézières";
$areanames{fr}->{3335139} = "Chaumont";
$areanames{fr}->{3335140} = "Epernay";
$areanames{fr}->{3335141} = "Châlons\-en\-Champagne";
$areanames{fr}->{3335142} = "Reims";
$areanames{fr}->{3335143} = "Rethel";
$areanames{fr}->{3335144} = "Romilly\-sur\-Seine";
$areanames{fr}->{3335145} = "Saint\-Dizier";
$areanames{fr}->{3335146} = "Sainte\-Menehould";
$areanames{fr}->{3335147} = "Sézanne";
$areanames{fr}->{3335148} = "Troyes";
$areanames{fr}->{3335149} = "Vitry\-le\-François";
$areanames{fr}->{3335150} = "Vouziers";
$areanames{fr}->{3335151} = "Charleville\-Mézières";
$areanames{fr}->{3335152} = "Rethel";
$areanames{fr}->{3335153} = "Troyes";
$areanames{fr}->{3335154} = "Vitry\-le\-François";
$areanames{fr}->{3335155} = "Chaumont";
$areanames{fr}->{3335156} = "Reims";
$areanames{fr}->{3335157} = "Reims";
$areanames{fr}->{3335158} = "Saint\-Dizier";
$areanames{fr}->{3335159} = "Troyes";
$areanames{fr}->{3335160} = "Vouziers";
$areanames{fr}->{3335161} = "Epernay";
$areanames{fr}->{3335162} = "Arcis\-sur\-Aube";
$areanames{fr}->{3335163} = "Bar\-sur\-Seine";
$areanames{fr}->{3335164} = "Romilly\-sur\-Seine";
$areanames{fr}->{3335165} = "Troyes";
$areanames{fr}->{3335166} = "Arcis\-sur\-Aube";
$areanames{fr}->{3335167} = "Epernay";
$areanames{fr}->{3335168} = "Reims";
$areanames{fr}->{3335169} = "Sainte\-Menehould";
$areanames{fr}->{3335170} = "Sézanne";
$areanames{fr}->{3335171} = "Vitry\-le\-François";
$areanames{fr}->{3335172} = "Bar\-sur\-Aube";
$areanames{fr}->{3335173} = "Saint\-Dizier";
$areanames{fr}->{3335174} = "Charleville\-Mézières";
$areanames{fr}->{3335175} = "Bar\-sur\-Seine";
$areanames{fr}->{3335176} = "Vouziers";
$areanames{fr}->{3335177} = "Châlons\-en\-Champagne";
$areanames{fr}->{3335178} = "Châlons\-en\-Champagne";
$areanames{fr}->{3335179} = "Charleville\-Mézières";
$areanames{fr}->{3335180} = "Charleville\-Mézières";
$areanames{fr}->{3335181} = "Bar\-sur\-Aube";
$areanames{fr}->{3335182} = "Chaumont";
$areanames{fr}->{3335183} = "Chaumont";
$areanames{fr}->{3335184} = "Troyes";
$areanames{fr}->{3335185} = "Reims";
$areanames{fr}->{3335186} = "Rethel";
$areanames{fr}->{3335187} = "Romilly\-sur\-Seine";
$areanames{fr}->{3335188} = "Charleville\-Mézières";
$areanames{fr}->{3335189} = "Saint\-Dizier";
$areanames{fr}->{3335190} = "Charleville\-Mézières";
$areanames{fr}->{3335191} = "Rethel";
$areanames{fr}->{3335192} = "Vouziers";
$areanames{fr}->{3335193} = "Arcis\-sur\-Aube";
$areanames{fr}->{3335194} = "Bar\-sur\-Aube";
$areanames{fr}->{3335195} = "Reims";
$areanames{fr}->{3335196} = "Bar\-sur\-Seine";
$areanames{fr}->{3335197} = "Romilly\-sur\-Seine";
$areanames{fr}->{3335198} = "Troyes";
$areanames{fr}->{3335199} = "Châlons\-en\-Champagne";
$areanames{fr}->{3335200} = "Châlons\-en\-Champagne";
$areanames{fr}->{3335201} = "Vitry\-le\-François";
$areanames{fr}->{3335202} = "Reims";
$areanames{fr}->{3335203} = "Reims";
$areanames{fr}->{3335204} = "Charleville\-Mézières";
$areanames{fr}->{3335205} = "Romilly\-sur\-Seine";
$areanames{fr}->{3335206} = "Bar\-sur\-Seine";
$areanames{fr}->{3335207} = "Saint\-Dizier";
$areanames{fr}->{3335208} = "Rethel";
$areanames{fr}->{3335209} = "Chaumont";
$areanames{fr}->{3335210} = "Rethel";
$areanames{fr}->{3335211} = "Arcis\-sur\-Aube";
$areanames{fr}->{3335212} = "Bar\-sur\-Aube";
$areanames{fr}->{3335213} = "Bar\-sur\-Seine";
$areanames{fr}->{3335214} = "Romilly\-sur\-Seine";
$areanames{fr}->{3335215} = "Reims";
$areanames{fr}->{3335216} = "Sainte\-Menehould";
$areanames{fr}->{3335217} = "Sézanne";
$areanames{fr}->{3335218} = "Chaumont";
$areanames{fr}->{3335219} = "Bar\-sur\-Aube";
$areanames{fr}->{3335220} = "Châlons\-en\-Champagne";
$areanames{fr}->{3335221} = "Arcis\-sur\-Aube";
$areanames{fr}->{3335222} = "Sainte\-Menehould";
$areanames{fr}->{3335223} = "Vitry\-le\-François";
$areanames{fr}->{3335224} = "Vouziers";
$areanames{fr}->{3335225} = "Sézanne";
$areanames{fr}->{3335226} = "Troyes";
$areanames{fr}->{3335227} = "Epernay";
$areanames{fr}->{3335228} = "Charleville\-Mézières";
$areanames{fr}->{3335229} = "Rethel";
$areanames{fr}->{3335230} = "Vouziers";
$areanames{fr}->{3335231} = "Arcis\-sur\-Aube";
$areanames{fr}->{3335232} = "Bar\-sur\-Aube";
$areanames{fr}->{3335233} = "Bar\-sur\-Seine";
$areanames{fr}->{3335234} = "Romilly\-sur\-Seine";
$areanames{fr}->{3335235} = "Troyes";
$areanames{fr}->{3335236} = "Châlons\-en\-Champagne";
$areanames{fr}->{3335237} = "Epernay";
$areanames{fr}->{3335238} = "Reims";
$areanames{fr}->{3335239} = "Sainte\-Menehould";
$areanames{fr}->{3335240} = "Sézanne";
$areanames{fr}->{3335241} = "Vitry\-le\-François";
$areanames{fr}->{3335242} = "Chaumont";
$areanames{fr}->{3335243} = "Saint\-Dizier";
$areanames{fr}->{3335244} = "Reims";
$areanames{fr}->{3335245} = "Reims";
$areanames{fr}->{3335246} = "Arcis\-sur\-Aube";
$areanames{fr}->{3335247} = "Bar\-sur\-Aube";
$areanames{fr}->{3335248} = "Bar\-sur\-Seine";
$areanames{fr}->{3335249} = "Romilly\-sur\-Seine";
$areanames{fr}->{3335250} = "Sézanne";
$areanames{fr}->{3335251} = "Saint\-Dizier";
$areanames{fr}->{3335252} = "Troyes";
$areanames{fr}->{3335253} = "Romilly\-sur\-Seine";
$areanames{fr}->{3335254} = "Troyes";
$areanames{fr}->{3335255} = "Châlons\-en\-Champagne";
$areanames{fr}->{3335256} = "Chaumont";
$areanames{fr}->{3335257} = "Rethel";
$areanames{fr}->{3335258} = "Vouziers";
$areanames{fr}->{3335259} = "Troyes";
$areanames{fr}->{3335260} = "Charleville\-Mézières";
$areanames{fr}->{3335261} = "Rethel";
$areanames{fr}->{3335262} = "Reims";
$areanames{fr}->{3335263} = "Châlons\-en\-Champagne";
$areanames{fr}->{3335264} = "Epernay";
$areanames{fr}->{3335265} = "Reims";
$areanames{fr}->{3335266} = "Sainte\-Menehould";
$areanames{fr}->{3335267} = "Sézanne";
$areanames{fr}->{3335268} = "Vitry\-le\-François";
$areanames{fr}->{3335269} = "Chaumont";
$areanames{fr}->{3335270} = "Saint\-Dizier";
$areanames{fr}->{3335271} = "Chaumont";
$areanames{fr}->{3335272} = "Charleville\-Mézières";
$areanames{fr}->{3335273} = "Troyes";
$areanames{fr}->{3335274} = "Reims";
$areanames{fr}->{3335275} = "Troyes";
$areanames{fr}->{3335276} = "Charleville\-Mézières";
$areanames{fr}->{3335277} = "Châlons\-en\-Champagne";
$areanames{fr}->{3335278} = "Châlons\-en\-Champagne";
$areanames{fr}->{3335279} = "Reims";
$areanames{fr}->{3335280} = "Troyes";
$areanames{fr}->{3335281} = "Troyes";
$areanames{fr}->{3335282} = "Reims";
$areanames{fr}->{3335283} = "Châlons\-en\-Champagne";
$areanames{fr}->{3335284} = "Reims";
$areanames{fr}->{3335285} = "Epernay";
$areanames{fr}->{3335286} = "Saint\-Dizier";
$areanames{fr}->{3335287} = "Rethel";
$areanames{fr}->{3335288} = "Charleville\-Mézières";
$areanames{fr}->{3335289} = "Rethel";
$areanames{fr}->{3335290} = "Charleville\-Mézières";
$areanames{fr}->{3335291} = "Reims";
$areanames{fr}->{3335292} = "Saint\-Dizier";
$areanames{fr}->{3335293} = "Vouziers";
$areanames{fr}->{3335294} = "Arcis\-sur\-Aube";
$areanames{fr}->{3335295} = "Bar\-sur\-Aube";
$areanames{fr}->{3335296} = "Bar\-sur\-Seine";
$areanames{fr}->{3335297} = "Sainte\-Menehould";
$areanames{fr}->{3335298} = "Sézanne";
$areanames{fr}->{3335299} = "Vitry\-le\-François";
$areanames{fr}->{3335300} = "Troyes";
$areanames{fr}->{3335302} = "Vouziers";
$areanames{fr}->{3335303} = "Arcis\-sur\-Aube";
$areanames{fr}->{3335304} = "Bar\-sur\-Aube";
$areanames{fr}->{3335305} = "Bar\-sur\-Seine";
$areanames{fr}->{3335306} = "Romilly\-sur\-Seine";
$areanames{fr}->{3335307} = "Epernay";
$areanames{fr}->{3335308} = "Sainte\-Menehould";
$areanames{fr}->{3335309} = "Sézanne";
$areanames{fr}->{3335310} = "Vitry\-le\-François";
$areanames{fr}->{3335311} = "Chaumont";
$areanames{fr}->{3335312} = "Saint\-Dizier";
$areanames{fr}->{3335313} = "Reims";
$areanames{fr}->{3335314} = "Châlons\-en\-Champagne";
$areanames{fr}->{3335315} = "Troyes";
$areanames{fr}->{3335316} = "Charleville\-Mézières";
$areanames{fr}->{3335317} = "Vouziers";
$areanames{fr}->{3335318} = "Arcis\-sur\-Aube";
$areanames{fr}->{3335319} = "Châlons\-en\-Champagne";
$areanames{fr}->{3335320} = "Epernay";
$areanames{fr}->{3335321} = "Sézanne";
$areanames{fr}->{3335322} = "Saint\-Dizier";
$areanames{fr}->{3335323} = "Chaumont";
$areanames{fr}->{3335324} = "Reims";
$areanames{fr}->{3335325} = "Bar\-sur\-Aube";
$areanames{fr}->{3335326} = "Bar\-sur\-Seine";
$areanames{fr}->{3335327} = "Vitry\-le\-François";
$areanames{fr}->{3335328} = "Reims";
$areanames{fr}->{3335329} = "Romilly\-sur\-Seine";
$areanames{fr}->{3335330} = "Sainte\-Menehould";
$areanames{fr}->{3335331} = "Troyes";
$areanames{fr}->{3335332} = "Reims";
$areanames{fr}->{3335333} = "Charleville\-Mézières";
$areanames{fr}->{3335334} = "Rethel";
$areanames{fr}->{3335335} = "Vouziers";
$areanames{fr}->{3335336} = "Arcis\-sur\-Aube";
$areanames{fr}->{3335337} = "Bar\-sur\-Aube";
$areanames{fr}->{3335338} = "Bar\-sur\-Seine";
$areanames{fr}->{3335339} = "Romilly\-sur\-Seine";
$areanames{fr}->{3335340} = "Châlons\-en\-Champagne";
$areanames{fr}->{3335341} = "Epernay";
$areanames{fr}->{3335342} = "Reims";
$areanames{fr}->{3335343} = "Sainte\-Menehould";
$areanames{fr}->{3335344} = "Sézanne";
$areanames{fr}->{3335345} = "Vitry\-le\-François";
$areanames{fr}->{3335346} = "Chaumont";
$areanames{fr}->{3335347} = "Saint\-Dizier";
$areanames{fr}->{3335348} = "Reims";
$areanames{fr}->{3335349} = "Reims";
$areanames{fr}->{3335350} = "Troyes";
$areanames{fr}->{3335400} = "Nancy";
$areanames{fr}->{3335401} = "Saint\-Avold";
$areanames{fr}->{3335402} = "Bar\-le\-Duc";
$areanames{fr}->{3335403} = "Toul";
$areanames{fr}->{3335404} = "Épinal";
$areanames{fr}->{3335405} = "Sarrebourg";
$areanames{fr}->{3335406} = "Sarreguemines";
$areanames{fr}->{3335407} = "Thionville";
$areanames{fr}->{3335408} = "Épinal";
$areanames{fr}->{3335409} = "Neufchâteau";
$areanames{fr}->{3335412} = "Nancy";
$areanames{fr}->{3335420} = "Verdun";
$areanames{fr}->{3335421} = "Metz";
$areanames{fr}->{3335422} = "Metz";
$areanames{fr}->{3335423} = "Morhange";
$areanames{fr}->{3335424} = "Lunéville";
$areanames{fr}->{3335425} = "Sarrebourg";
$areanames{fr}->{3335426} = "Saint\-Dié\-des\-Vosges";
$areanames{fr}->{3335427} = "Saint\-Avold";
$areanames{fr}->{3335428} = "Sarrebourg";
$areanames{fr}->{3335429} = "Sarreguemines";
$areanames{fr}->{3335430} = "Thionville";
$areanames{fr}->{3335431} = "Épinal";
$areanames{fr}->{3335432} = "Pont\-à\-Mousson";
$areanames{fr}->{3335433} = "Neufchâteau";
$areanames{fr}->{3335434} = "Vittel";
$areanames{fr}->{3335435} = "Remiremont";
$areanames{fr}->{3335436} = "Saint\-Dié\-des\-Vosges";
$areanames{fr}->{3335437} = "Vittel";
$areanames{fr}->{3335438} = "Bar\-le\-Duc";
$areanames{fr}->{3335439} = "Saint\-Dié\-des\-Vosges";
$areanames{fr}->{3335440} = "Nancy";
$areanames{fr}->{3335441} = "Thionville";
$areanames{fr}->{3335442} = "Briey";
$areanames{fr}->{3335443} = "Épinal";
$areanames{fr}->{3335444} = "Metz";
$areanames{fr}->{3335445} = "Lunéville";
$areanames{fr}->{3335446} = "Sarrebourg";
$areanames{fr}->{3335447} = "Lunéville";
$areanames{fr}->{3335448} = "Metz";
$areanames{fr}->{3335449} = "Morhange";
$areanames{fr}->{3335450} = "Nancy";
$areanames{fr}->{3335451} = "Nancy";
$areanames{fr}->{3335452} = "Neufchâteau";
$areanames{fr}->{3335453} = "Morhange";
$areanames{fr}->{3335454} = "Thionville";
$areanames{fr}->{3335455} = "Épinal";
$areanames{fr}->{3335456} = "Briey";
$areanames{fr}->{3335457} = "Lunéville";
$areanames{fr}->{3335458} = "Nancy";
$areanames{fr}->{3335459} = "Nancy";
$areanames{fr}->{3335462} = "Metz";
$areanames{fr}->{3335470} = "Remiremont";
$areanames{fr}->{3335471} = "Thionville";
$areanames{fr}->{3335472} = "Épinal";
$areanames{fr}->{3335473} = "Metz";
$areanames{fr}->{3335474} = "Remiremont";
$areanames{fr}->{3335475} = "Saint\-Dié\-des\-Vosges";
$areanames{fr}->{3335476} = "Nancy";
$areanames{fr}->{3335477} = "Morhange";
$areanames{fr}->{3335478} = "Saint\-Avold";
$areanames{fr}->{3335479} = "Pont\-à\-Mousson";
$areanames{fr}->{3335480} = "Remiremont";
$areanames{fr}->{3335481} = "Saint\-Avold";
$areanames{fr}->{3335482} = "Saint\-Dié\-des\-Vosges";
$areanames{fr}->{3335483} = "Sarrebourg";
$areanames{fr}->{3335484} = "Metz";
$areanames{fr}->{3335485} = "Sarreguemines";
$areanames{fr}->{3335486} = "Thionville";
$areanames{fr}->{3335487} = "Toul";
$areanames{fr}->{3335488} = "Sarreguemines";
$areanames{fr}->{3335489} = "Nancy";
$areanames{fr}->{3335490} = "Briey";
$areanames{fr}->{3335491} = "Lunéville";
$areanames{fr}->{3335492} = "Nancy";
$areanames{fr}->{3335493} = "Pont\-à\-Mousson";
$areanames{fr}->{3335494} = "Toul";
$areanames{fr}->{3335495} = "Nancy";
$areanames{fr}->{3335496} = "Bar\-le\-Duc";
$areanames{fr}->{3335497} = "Verdun";
$areanames{fr}->{3335498} = "Metz";
$areanames{fr}->{3335499} = "Morhange";
$areanames{fr}->{3335500} = "Metz";
$areanames{fr}->{3335501} = "Neufchâteau";
$areanames{fr}->{3335502} = "Nancy";
$areanames{fr}->{3335503} = "Sarreguemines";
$areanames{fr}->{3335504} = "Pont\-à\-Mousson";
$areanames{fr}->{3335505} = "Briey";
$areanames{fr}->{3335506} = "Lunéville";
$areanames{fr}->{3335507} = "Pont\-à\-Mousson";
$areanames{fr}->{3335508} = "Toul";
$areanames{fr}->{3335509} = "Verdun";
$areanames{fr}->{3335510} = "Nancy";
$areanames{fr}->{3335511} = "Metz";
$areanames{fr}->{3335512} = "Bar\-le\-Duc";
$areanames{fr}->{3335513} = "Verdun";
$areanames{fr}->{3335514} = "Morhange";
$areanames{fr}->{3335515} = "Saint\-Avold";
$areanames{fr}->{3335516} = "Sarrebourg";
$areanames{fr}->{3335517} = "Sarreguemines";
$areanames{fr}->{3335518} = "Thionville";
$areanames{fr}->{3335519} = "Épinal";
$areanames{fr}->{3335520} = "Nancy";
$areanames{fr}->{3335521} = "Neufchâteau";
$areanames{fr}->{3335522} = "Remiremont";
$areanames{fr}->{3335523} = "Saint\-Dié\-des\-Vosges";
$areanames{fr}->{3335524} = "Vittel";
$areanames{fr}->{3335525} = "Bar\-le\-Duc";
$areanames{fr}->{3335526} = "Briey";
$areanames{fr}->{3335527} = "Épinal";
$areanames{fr}->{3335528} = "Morhange";
$areanames{fr}->{3335529} = "Pont\-à\-Mousson";
$areanames{fr}->{3335530} = "Nancy";
$areanames{fr}->{3335531} = "Remiremont";
$areanames{fr}->{3335532} = "Toul";
$areanames{fr}->{3335533} = "Nancy";
$areanames{fr}->{3335534} = "Saint\-Avold";
$areanames{fr}->{3335535} = "Metz";
$areanames{fr}->{3335536} = "Sarreguemines";
$areanames{fr}->{3335537} = "Sarrebourg";
$areanames{fr}->{3335538} = "Metz";
$areanames{fr}->{3335539} = "Morhange";
$areanames{fr}->{3335540} = "Nancy";
$areanames{fr}->{3335541} = "Neufchâteau";
$areanames{fr}->{3335542} = "Pont\-à\-Mousson";
$areanames{fr}->{3335543} = "Remiremont";
$areanames{fr}->{3335544} = "Saint\-Avold";
$areanames{fr}->{3335545} = "Sarreguemines";
$areanames{fr}->{3335546} = "Thionville";
$areanames{fr}->{3335547} = "Toul";
$areanames{fr}->{3335548} = "Verdun";
$areanames{fr}->{3335549} = "Vittel";
$areanames{fr}->{3335550} = "Bar\-le\-Duc";
$areanames{fr}->{3335551} = "Briey";
$areanames{fr}->{3335552} = "Épinal";
$areanames{fr}->{3335553} = "Vittel";
$areanames{fr}->{3335554} = "Nancy";
$areanames{fr}->{3335555} = "Metz";
$areanames{fr}->{3335556} = "Remiremont";
$areanames{fr}->{3335557} = "Bar\-le\-Duc";
$areanames{fr}->{3335558} = "Metz";
$areanames{fr}->{3335559} = "Nancy";
$areanames{fr}->{3335560} = "Thionville";
$areanames{fr}->{3335561} = "Saint\-Avold";
$areanames{fr}->{3335562} = "Metz";
$areanames{fr}->{3335563} = "Sarreguemines";
$areanames{fr}->{3335564} = "Thionville";
$areanames{fr}->{3335565} = "Toul";
$areanames{fr}->{3335566} = "Nancy";
$areanames{fr}->{3335567} = "Bar\-le\-Duc";
$areanames{fr}->{3335568} = "Nancy";
$areanames{fr}->{3335569} = "Nancy";
$areanames{fr}->{3335570} = "Briey";
$areanames{fr}->{3335571} = "Sarreguemines";
$areanames{fr}->{3335572} = "Saint\-Avold";
$areanames{fr}->{3335573} = "Metz";
$areanames{fr}->{3335574} = "Metz";
$areanames{fr}->{3335575} = "Morhange";
$areanames{fr}->{3335576} = "Pont\-à\-Mousson";
$areanames{fr}->{3335577} = "Thionville";
$areanames{fr}->{3335578} = "Sarreguemines";
$areanames{fr}->{3335579} = "Saint\-Avold";
$areanames{fr}->{3335580} = "Metz";
$areanames{fr}->{3335590} = "Bar\-le\-Duc";
$areanames{fr}->{3335591} = "Briey";
$areanames{fr}->{3335592} = "Épinal";
$areanames{fr}->{3335593} = "Lunéville";
$areanames{fr}->{3335594} = "Metz";
$areanames{fr}->{3335595} = "Morhange";
$areanames{fr}->{3335596} = "Nancy";
$areanames{fr}->{3335597} = "Neufchâteau";
$areanames{fr}->{3335598} = "Pont\-à\-Mousson";
$areanames{fr}->{3335599} = "Saint\-Avold";
$areanames{fr}->{3335600} = "Bar\-le\-Duc";
$areanames{fr}->{3335601} = "Verdun";
$areanames{fr}->{3335602} = "Morhange";
$areanames{fr}->{3335603} = "Saint\-Avold";
$areanames{fr}->{3335604} = "Sarrebourg";
$areanames{fr}->{3335605} = "Sarreguemines";
$areanames{fr}->{3335606} = "Épinal";
$areanames{fr}->{3335607} = "Neufchâteau";
$areanames{fr}->{3335608} = "Remiremont";
$areanames{fr}->{3335609} = "Saint\-Dié\-des\-Vosges";
$areanames{fr}->{3335610} = "Vittel";
$areanames{fr}->{3335611} = "Épinal";
$areanames{fr}->{3335612} = "Metz";
$areanames{fr}->{3335613} = "Vittel";
$areanames{fr}->{3335614} = "Saint\-Avold";
$areanames{fr}->{3335615} = "Lunéville";
$areanames{fr}->{3335616} = "Lunéville";
$areanames{fr}->{3335617} = "Pont\-à\-Mousson";
$areanames{fr}->{3335618} = "Briey";
$areanames{fr}->{3335619} = "Bar\-le\-Duc";
$areanames{fr}->{3335620} = "Thionville";
$areanames{fr}->{3335621} = "Sarreguemines";
$areanames{fr}->{3335622} = "Metz";
$areanames{fr}->{3335623} = "Saint\-Avold";
$areanames{fr}->{3335624} = "Lunéville";
$areanames{fr}->{3335625} = "Sarrebourg";
$areanames{fr}->{3335626} = "Nancy";
$areanames{fr}->{3335627} = "Morhange";
$areanames{fr}->{3335628} = "Neufchâteau";
$areanames{fr}->{3335629} = "Sarrebourg";
$areanames{fr}->{3335630} = "Toul";
$areanames{fr}->{3335631} = "Vittel";
$areanames{fr}->{3335632} = "Épinal";
$areanames{fr}->{3335633} = "Nancy";
$areanames{fr}->{3335634} = "Remiremont";
$areanames{fr}->{3335635} = "Briey";
$areanames{fr}->{3335636} = "Lunéville";
$areanames{fr}->{3335637} = "Nancy";
$areanames{fr}->{3335638} = "Pont\-à\-Mousson";
$areanames{fr}->{3335639} = "Toul";
$areanames{fr}->{3335640} = "Bar\-le\-Duc";
$areanames{fr}->{3335641} = "Verdun";
$areanames{fr}->{3335642} = "Metz";
$areanames{fr}->{3335643} = "Morhange";
$areanames{fr}->{3335644} = "Saint\-Avold";
$areanames{fr}->{3335645} = "Sarrebourg";
$areanames{fr}->{3335646} = "Sarreguemines";
$areanames{fr}->{3335647} = "Thionville";
$areanames{fr}->{3335648} = "Épinal";
$areanames{fr}->{3335649} = "Neufchâteau";
$areanames{fr}->{3335650} = "Remiremont";
$areanames{fr}->{3335651} = "Saint\-Dié\-des\-Vosges";
$areanames{fr}->{3335652} = "Vittel";
$areanames{fr}->{3335653} = "Briey";
$areanames{fr}->{3335654} = "Metz";
$areanames{fr}->{3335655} = "Saint\-Dié\-des\-Vosges";
$areanames{fr}->{3335656} = "Épinal";
$areanames{fr}->{3335657} = "Nancy";
$areanames{fr}->{3335658} = "Nancy";
$areanames{fr}->{3335660} = "Nancy";
$areanames{fr}->{3335700} = "Remiremont";
$areanames{fr}->{3335701} = "Saint\-Avold";
$areanames{fr}->{3335702} = "Saint\-Dié\-des\-Vosges";
$areanames{fr}->{3335703} = "Sarrebourg";
$areanames{fr}->{3335704} = "Sarreguemines";
$areanames{fr}->{3335705} = "Toul";
$areanames{fr}->{3335706} = "Verdun";
$areanames{fr}->{3335707} = "Vittel";
$areanames{fr}->{3335708} = "Thionville";
$areanames{fr}->{3335709} = "Nancy";
$areanames{fr}->{3335710} = "Briey";
$areanames{fr}->{3335711} = "Verdun";
$areanames{fr}->{3335712} = "Épinal";
$areanames{fr}->{3335713} = "Briey";
$areanames{fr}->{3335714} = "Lunéville";
$areanames{fr}->{3335715} = "Nancy";
$areanames{fr}->{3335716} = "Pont\-à\-Mousson";
$areanames{fr}->{3335717} = "Toul";
$areanames{fr}->{3335718} = "Verdun";
$areanames{fr}->{3335719} = "Morhange";
$areanames{fr}->{3335728} = "Metz";
$areanames{fr}->{3335730} = "Morhange";
$areanames{fr}->{3335731} = "Saint\-Avold";
$areanames{fr}->{3335732} = "Thionville";
$areanames{fr}->{3335733} = "Lunéville";
$areanames{fr}->{3335734} = "Lunéville";
$areanames{fr}->{3335735} = "Nancy";
$areanames{fr}->{3335736} = "Toul";
$areanames{fr}->{3335737} = "Bar\-le\-Duc";
$areanames{fr}->{3335738} = "Épinal";
$areanames{fr}->{3335739} = "Épinal";
$areanames{fr}->{3335740} = "Metz";
$areanames{fr}->{3335741} = "Morhange";
$areanames{fr}->{3335742} = "Saint\-Avold";
$areanames{fr}->{3335743} = "Sarrebourg";
$areanames{fr}->{3335744} = "Sarrebourg";
$areanames{fr}->{3335745} = "Sarreguemines";
$areanames{fr}->{3335746} = "Sarreguemines";
$areanames{fr}->{3335747} = "Thionville";
$areanames{fr}->{3335748} = "Nancy";
$areanames{fr}->{3335749} = "Lunéville";
$areanames{fr}->{3335750} = "Morhange";
$areanames{fr}->{3335751} = "Metz";
$areanames{fr}->{3335752} = "Sarrebourg";
$areanames{fr}->{3335753} = "Saint\-Avold";
$areanames{fr}->{3335754} = "Nancy";
$areanames{fr}->{3335755} = "Metz";
$areanames{fr}->{3335756} = "Metz";
$areanames{fr}->{3335757} = "Metz";
$areanames{fr}->{3335758} = "Verdun";
$areanames{fr}->{3335759} = "Briey";
$areanames{fr}->{3335760} = "Pont\-à\-Mousson";
$areanames{fr}->{3335761} = "Bar\-le\-Duc";
$areanames{fr}->{3335762} = "Verdun";
$areanames{fr}->{3335763} = "Nancy";
$areanames{fr}->{3335764} = "Toul";
$areanames{fr}->{3335765} = "Neufchâteau";
$areanames{fr}->{3335766} = "Épinal";
$areanames{fr}->{3335767} = "Sarreguemines";
$areanames{fr}->{3335768} = "Remiremont";
$areanames{fr}->{3335769} = "Nancy";
$areanames{fr}->{3335770} = "Briey";
$areanames{fr}->{3335771} = "Bar\-le\-Duc";
$areanames{fr}->{3335772} = "Vittel";
$areanames{fr}->{3335773} = "Thionville";
$areanames{fr}->{3335774} = "Saint\-Dié\-des\-Vosges";
$areanames{fr}->{3335775} = "Nancy";
$areanames{fr}->{3335776} = "Épinal";
$areanames{fr}->{3335777} = "Nancy";
$areanames{fr}->{3335778} = "Thionville";
$areanames{fr}->{3335779} = "Briey";
$areanames{fr}->{3335780} = "Nancy";
$areanames{fr}->{3335781} = "Pont\-à\-Mousson";
$areanames{fr}->{3335782} = "Toul";
$areanames{fr}->{3335783} = "Verdun";
$areanames{fr}->{3335784} = "Metz";
$areanames{fr}->{3335785} = "Saint\-Avold";
$areanames{fr}->{3335786} = "Sarrebourg";
$areanames{fr}->{3335787} = "Sarreguemines";
$areanames{fr}->{3335788} = "Thionville";
$areanames{fr}->{3335789} = "Neufchâteau";
$areanames{fr}->{3335790} = "Saint\-Dié\-des\-Vosges";
$areanames{fr}->{3335791} = "Vittel";
$areanames{fr}->{3335792} = "Lunéville";
$areanames{fr}->{3335793} = "Nancy";
$areanames{fr}->{3335794} = "Vittel";
$areanames{fr}->{3335795} = "Pont\-à\-Mousson";
$areanames{fr}->{3335796} = "Toul";
$areanames{fr}->{3335797} = "Bar\-le\-Duc";
$areanames{fr}->{3335798} = "Verdun";
$areanames{fr}->{3335799} = "Épinal";
$areanames{fr}->{3335800} = "Château\-Chinon\(Ville\)";
$areanames{fr}->{3335801} = "Decize";
$areanames{fr}->{3335802} = "Montbard";
$areanames{fr}->{3335803} = "Saulieu";
$areanames{fr}->{3335804} = "Château\-Chinon\(Ville\)";
$areanames{fr}->{3335805} = "Cosne\-Cours\-sur\-Loire";
$areanames{fr}->{3335806} = "Decize";
$areanames{fr}->{3335807} = "Nevers";
$areanames{fr}->{3335808} = "Autun";
$areanames{fr}->{3335809} = "Chalon\-sur\-Saône";
$areanames{fr}->{3335810} = "Montbard";
$areanames{fr}->{3335811} = "Montceau\-les\-Mines";
$areanames{fr}->{3335812} = "Nevers";
$areanames{fr}->{3335813} = "Paray\-le\-Monial";
$areanames{fr}->{3335814} = "Saulieu";
$areanames{fr}->{3335815} = "Sens";
$areanames{fr}->{3335816} = "Tonnerre";
$areanames{fr}->{3335817} = "Toucy";
$areanames{fr}->{3335818} = "Louhans";
$areanames{fr}->{3335819} = "Mâcon";
$areanames{fr}->{3335820} = "Autun";
$areanames{fr}->{3335821} = "Auxerre";
$areanames{fr}->{3335822} = "Beaune";
$areanames{fr}->{3335823} = "Chalon\-sur\-Saône";
$areanames{fr}->{3335824} = "Château\-Chinon\(Ville\)";
$areanames{fr}->{3335825} = "Châtillon\-sur\-Seine";
$areanames{fr}->{3335826} = "Cosne\-Cours\-sur\-Loire";
$areanames{fr}->{3335827} = "Decize";
$areanames{fr}->{3335828} = "Dijon";
$areanames{fr}->{3335829} = "Is\-sur\-Tille";
$areanames{fr}->{3335830} = "Joigny";
$areanames{fr}->{3335831} = "Louhans";
$areanames{fr}->{3335832} = "Mâcon";
$areanames{fr}->{3335833} = "Montbard";
$areanames{fr}->{3335834} = "Montceau\-les\-Mines";
$areanames{fr}->{3335835} = "Nevers";
$areanames{fr}->{3335836} = "Paray\-le\-Monial";
$areanames{fr}->{3335837} = "Saulieu";
$areanames{fr}->{3335838} = "Sens";
$areanames{fr}->{3335839} = "Tonnerre";
$areanames{fr}->{3335840} = "Toucy";
$areanames{fr}->{3335841} = "Montceau\-les\-Mines";
$areanames{fr}->{3335842} = "Paray\-le\-Monial";
$areanames{fr}->{3335843} = "Auxerre";
$areanames{fr}->{3335844} = "Joigny";
$areanames{fr}->{3335845} = "Sens";
$areanames{fr}->{3335846} = "Tonnerre";
$areanames{fr}->{3335847} = "Toucy";
$areanames{fr}->{3335848} = "Auxerre";
$areanames{fr}->{3335849} = "Beaune";
$areanames{fr}->{3335850} = "Chalon\-sur\-Saône";
$areanames{fr}->{3335851} = "Châtillon\-sur\-Seine";
$areanames{fr}->{3335852} = "Cosne\-Cours\-sur\-Loire";
$areanames{fr}->{3335853} = "Is\-sur\-Tille";
$areanames{fr}->{3335854} = "Joigny";
$areanames{fr}->{3335855} = "Montbard";
$areanames{fr}->{3335856} = "Montceau\-les\-Mines";
$areanames{fr}->{3335857} = "Nevers";
$areanames{fr}->{3335858} = "Nevers";
$areanames{fr}->{3335859} = "Paray\-le\-Monial";
$areanames{fr}->{3335860} = "Saulieu";
$areanames{fr}->{3335861} = "Sens";
$areanames{fr}->{3335862} = "Louhans";
$areanames{fr}->{3335863} = "Tonnerre";
$areanames{fr}->{3335864} = "Toucy";
$areanames{fr}->{3335865} = "Auxerre";
$areanames{fr}->{3335866} = "Chalon\-sur\-Saône";
$areanames{fr}->{3335867} = "Cosne\-Cours\-sur\-Loire";
$areanames{fr}->{3335868} = "Dijon";
$areanames{fr}->{3335869} = "Chalon\-sur\-Saône";
$areanames{fr}->{3335870} = "Dijon";
$areanames{fr}->{3335871} = "Mâcon";
$areanames{fr}->{3335872} = "Dijon";
$areanames{fr}->{3335873} = "Louhans";
$areanames{fr}->{3335874} = "Mâcon";
$areanames{fr}->{3335875} = "Montceau\-les\-Mines";
$areanames{fr}->{3335876} = "Nevers";
$areanames{fr}->{3335877} = "Chalon\-sur\-Saône";
$areanames{fr}->{3335878} = "Is\-sur\-Tille";
$areanames{fr}->{3335879} = "Mâcon";
$areanames{fr}->{3335880} = "Nevers";
$areanames{fr}->{3335881} = "Saulieu";
$areanames{fr}->{3335882} = "Nevers";
$areanames{fr}->{3335883} = "Montceau\-les\-Mines";
$areanames{fr}->{3335884} = "Chalon\-sur\-Saône";
$areanames{fr}->{3335885} = "Châtillon\-sur\-Seine";
$areanames{fr}->{3335886} = "Cosne\-Cours\-sur\-Loire";
$areanames{fr}->{3335887} = "Montbard";
$areanames{fr}->{3335888} = "Dijon";
$areanames{fr}->{3335889} = "Montceau\-les\-Mines";
$areanames{fr}->{3335890} = "Mâcon";
$areanames{fr}->{3335891} = "Paray\-le\-Monial";
$areanames{fr}->{3335892} = "Sens";
$areanames{fr}->{3335893} = "Chalon\-sur\-Saône";
$areanames{fr}->{3335894} = "Château\-Chinon\(Ville\)";
$areanames{fr}->{3335895} = "Châtillon\-sur\-Seine";
$areanames{fr}->{3335896} = "Cosne\-Cours\-sur\-Loire";
$areanames{fr}->{3335897} = "Decize";
$areanames{fr}->{3335898} = "Dijon";
$areanames{fr}->{3335899} = "Louhans";
$areanames{fr}->{333590} = "Lille";
$areanames{fr}->{3335902} = "Béthune";
$areanames{fr}->{3335904} = "Cambrai";
$areanames{fr}->{3335906} = "Le\ Cateau\-Cambresis";
$areanames{fr}->{3335907} = "Douai";
$areanames{fr}->{3335910} = "Hazebrouck";
$areanames{fr}->{3335911} = "Hazebrouck";
$areanames{fr}->{3335912} = "Lille";
$areanames{fr}->{3335913} = "Maubeuge";
$areanames{fr}->{3335914} = "Valenciennes";
$areanames{fr}->{3335915} = "Arras";
$areanames{fr}->{3335916} = "Béthune";
$areanames{fr}->{3335917} = "Lens";
$areanames{fr}->{3335918} = "Béthune";
$areanames{fr}->{3335919} = "Calais";
$areanames{fr}->{3335920} = "Lille";
$areanames{fr}->{3335921} = "Maubeuge";
$areanames{fr}->{3335922} = "Lille";
$areanames{fr}->{3335923} = "Valenciennes";
$areanames{fr}->{3335924} = "Dunkerque";
$areanames{fr}->{3335925} = "Arras";
$areanames{fr}->{3335926} = "Cambrai";
$areanames{fr}->{3335927} = "Dunkerque";
$areanames{fr}->{3335928} = "Lille";
$areanames{fr}->{3335929} = "Lens";
$areanames{fr}->{3335930} = "Lille";
$areanames{fr}->{3335931} = "Lille";
$areanames{fr}->{3335932} = "Montreuil";
$areanames{fr}->{3335933} = "Saint\-Omer";
$areanames{fr}->{3335934} = "Saint\-Pol\-sur\-Ternoise";
$areanames{fr}->{3335935} = "Lille";
$areanames{fr}->{3335936} = "Lille";
$areanames{fr}->{3335937} = "Béthune";
$areanames{fr}->{3335938} = "Valenciennes";
$areanames{fr}->{3335939} = "Lille";
$areanames{fr}->{3335940} = "Lille";
$areanames{fr}->{3335941} = "Béthune";
$areanames{fr}->{3335942} = "Lens";
$areanames{fr}->{3335943} = "Douai";
$areanames{fr}->{3335944} = "Calais";
$areanames{fr}->{3335945} = "Cambrai";
$areanames{fr}->{3335946} = "Cambrai";
$areanames{fr}->{3335947} = "Dunkerque";
$areanames{fr}->{3335948} = "Dunkerque";
$areanames{fr}->{3335949} = "Dunkerque";
$areanames{fr}->{333595} = "Lille";
$areanames{fr}->{3335960} = "Maubeuge";
$areanames{fr}->{3335961} = "Lille";
$areanames{fr}->{3335962} = "Calais";
$areanames{fr}->{3335963} = "Lille";
$areanames{fr}->{3335964} = "Douai";
$areanames{fr}->{3335965} = "Cambrai";
$areanames{fr}->{3335966} = "Douai";
$areanames{fr}->{3335967} = "Dunkerque";
$areanames{fr}->{3335968} = "Hazebrouck";
$areanames{fr}->{3335969} = "Lille";
$areanames{fr}->{3335970} = "Calais";
$areanames{fr}->{3335971} = "Lille";
$areanames{fr}->{3335972} = "Calais";
$areanames{fr}->{3335973} = "Lille";
$areanames{fr}->{3335974} = "Maubeuge";
$areanames{fr}->{3335975} = "Lille";
$areanames{fr}->{3335976} = "Valenciennes";
$areanames{fr}->{3335977} = "Cambrai";
$areanames{fr}->{3335978} = "Arras";
$areanames{fr}->{3335979} = "Saint\-Omer";
$areanames{fr}->{3335980} = "Arras";
$areanames{fr}->{3335981} = "Lille";
$areanames{fr}->{3335982} = "Lille";
$areanames{fr}->{3335983} = "Valenciennes";
$areanames{fr}->{3335984} = "Valenciennes";
$areanames{fr}->{3335985} = "Arras";
$areanames{fr}->{3335986} = "Arras";
$areanames{fr}->{3335987} = "Béthune";
$areanames{fr}->{3335988} = "Béthune";
$areanames{fr}->{3335989} = "Lille";
$areanames{fr}->{3335990} = "Le\ Cateau\-Cambresis";
$areanames{fr}->{3335991} = "Calais";
$areanames{fr}->{3335992} = "Calais";
$areanames{fr}->{3335993} = "Lens";
$areanames{fr}->{3335994} = "Lens";
$areanames{fr}->{3335995} = "Valenciennes";
$areanames{fr}->{3335996} = "Lille";
$areanames{fr}->{3335997} = "Lille";
$areanames{fr}->{3335998} = "Cambrai";
$areanames{fr}->{3335999} = "Arras";
$areanames{fr}->{3336000} = "Crépy\-en\-Valois";
$areanames{fr}->{3336001} = "Amiens";
$areanames{fr}->{3336002} = "Creil";
$areanames{fr}->{3336003} = "Amiens";
$areanames{fr}->{3336004} = "Abbeville";
$areanames{fr}->{3336005} = "Beauvais";
$areanames{fr}->{3336006} = "Château\-Thierry";
$areanames{fr}->{3336007} = "Chauny";
$areanames{fr}->{3336008} = "Hirson";
$areanames{fr}->{3336009} = "Laon";
$areanames{fr}->{3336010} = "Amiens";
$areanames{fr}->{3336011} = "Amiens";
$areanames{fr}->{3336012} = "Amiens";
$areanames{fr}->{3336013} = "Amiens";
$areanames{fr}->{3336014} = "Amiens";
$areanames{fr}->{3336015} = "Saint\-Quentin";
$areanames{fr}->{3336016} = "Soissons";
$areanames{fr}->{3336017} = "Beauvais";
$areanames{fr}->{3336018} = "Clermont";
$areanames{fr}->{3336019} = "Compiègne";
$areanames{fr}->{3336020} = "Amiens";
$areanames{fr}->{3336021} = "Crépy\-en\-Valois";
$areanames{fr}->{3336022} = "Abbeville";
$areanames{fr}->{3336023} = "Albert";
$areanames{fr}->{3336024} = "Amiens";
$areanames{fr}->{3336025} = "Péronne";
$areanames{fr}->{3336026} = "Abbeville";
$areanames{fr}->{3336027} = "Albert";
$areanames{fr}->{3336028} = "Amiens";
$areanames{fr}->{3336029} = "Beauvais";
$areanames{fr}->{3336030} = "Beauvais";
$areanames{fr}->{3336031} = "Amiens";
$areanames{fr}->{3336032} = "Abbeville";
$areanames{fr}->{3336033} = "Albert";
$areanames{fr}->{3336034} = "Péronne";
$areanames{fr}->{3336035} = "Creil";
$areanames{fr}->{3336036} = "Beauvais";
$areanames{fr}->{3336037} = "Clermont";
$areanames{fr}->{3336038} = "Château\-Thierry";
$areanames{fr}->{3336039} = "Crépy\-en\-Valois";
$areanames{fr}->{3336040} = "Compiègne";
$areanames{fr}->{3336041} = "Château\-Thierry";
$areanames{fr}->{3336042} = "Chauny";
$areanames{fr}->{3336043} = "Clermont";
$areanames{fr}->{3336044} = "Compiègne";
$areanames{fr}->{3336045} = "Compiègne";
$areanames{fr}->{3336046} = "Creil";
$areanames{fr}->{3336047} = "Crépy\-en\-Valois";
$areanames{fr}->{3336048} = "Hirson";
$areanames{fr}->{3336049} = "Laon";
$areanames{fr}->{3336050} = "Péronne";
$areanames{fr}->{3336051} = "Péronne";
$areanames{fr}->{3336052} = "Saint\-Quentin";
$areanames{fr}->{3336053} = "Soissons";
$areanames{fr}->{3336054} = "Laon";
$areanames{fr}->{3336055} = "Beauvais";
$areanames{fr}->{3336056} = "Beauvais";
$areanames{fr}->{3336057} = "Saint\-Quentin";
$areanames{fr}->{3336058} = "Creil";
$areanames{fr}->{3336059} = "Crépy\-en\-Valois";
$areanames{fr}->{3336060} = "Amiens";
$areanames{fr}->{3336061} = "Abbeville";
$areanames{fr}->{3336062} = "Amiens";
$areanames{fr}->{3336063} = "Péronne";
$areanames{fr}->{3336064} = "Albert";
$areanames{fr}->{3336065} = "Amiens";
$areanames{fr}->{3336066} = "Hirson";
$areanames{fr}->{3336067} = "Creil";
$areanames{fr}->{3336068} = "Saint\-Quentin";
$areanames{fr}->{3336069} = "Soissons";
$areanames{fr}->{3336070} = "Péronne";
$areanames{fr}->{3336071} = "Soissons";
$areanames{fr}->{3336072} = "Chauny";
$areanames{fr}->{3336073} = "Hirson";
$areanames{fr}->{3336074} = "Creil";
$areanames{fr}->{3336075} = "Beauvais";
$areanames{fr}->{3336076} = "Abbeville";
$areanames{fr}->{3336077} = "Amiens";
$areanames{fr}->{3336078} = "Creil";
$areanames{fr}->{3336079} = "Compiègne";
$areanames{fr}->{3336080} = "Creil";
$areanames{fr}->{3336081} = "Laon";
$areanames{fr}->{3336082} = "Beauvais";
$areanames{fr}->{3336083} = "Creil";
$areanames{fr}->{3336084} = "Beauvais";
$areanames{fr}->{3336085} = "Amiens";
$areanames{fr}->{3336086} = "Saint\-Quentin";
$areanames{fr}->{3336087} = "Compiègne";
$areanames{fr}->{3336088} = "Beauvais";
$areanames{fr}->{3336089} = "Creil";
$areanames{fr}->{3336090} = "Château\-Thierry";
$areanames{fr}->{3336091} = "Chauny";
$areanames{fr}->{3336092} = "Hirson";
$areanames{fr}->{3336093} = "Laon";
$areanames{fr}->{3336094} = "Saint\-Quentin";
$areanames{fr}->{3336095} = "Soissons";
$areanames{fr}->{3336096} = "Beauvais";
$areanames{fr}->{3336097} = "Clermont";
$areanames{fr}->{3336098} = "Compiègne";
$areanames{fr}->{3336099} = "Creil";
$areanames{fr}->{3336100} = "Lens";
$areanames{fr}->{3336101} = "Montreuil";
$areanames{fr}->{3336102} = "Saint\-Omer";
$areanames{fr}->{3336103} = "Saint\-Pol\-sur\-Ternoise";
$areanames{fr}->{3336104} = "Cambrai";
$areanames{fr}->{3336105} = "Lille";
$areanames{fr}->{3336106} = "Le\ Cateau\-Cambresis";
$areanames{fr}->{3336107} = "Lille";
$areanames{fr}->{3336108} = "Lille";
$areanames{fr}->{3336109} = "Béthune";
$areanames{fr}->{3336110} = "Valenciennes";
$areanames{fr}->{3336111} = "Arras";
$areanames{fr}->{3336112} = "Béthune";
$areanames{fr}->{3336113} = "Calais";
$areanames{fr}->{3336114} = "Cambrai";
$areanames{fr}->{3336115} = "Le\ Cateau\-Cambresis";
$areanames{fr}->{3336116} = "Douai";
$areanames{fr}->{3336117} = "Dunkerque";
$areanames{fr}->{3336118} = "Hazebrouck";
$areanames{fr}->{3336119} = "Lens";
$areanames{fr}->{3336120} = "Douai";
$areanames{fr}->{3336121} = "Maubeuge";
$areanames{fr}->{3336122} = "Montreuil";
$areanames{fr}->{3336123} = "Saint\-Omer";
$areanames{fr}->{3336124} = "Saint\-Pol\-sur\-Ternoise";
$areanames{fr}->{3336125} = "Valenciennes";
$areanames{fr}->{3336126} = "Lille";
$areanames{fr}->{3336127} = "Valenciennes";
$areanames{fr}->{3336128} = "Calais";
$areanames{fr}->{3336129} = "Douai";
$areanames{fr}->{3336138} = "Dunkerque";
$areanames{fr}->{3336140} = "Béthune";
$areanames{fr}->{3336141} = "Cambrai";
$areanames{fr}->{3336142} = "Le\ Cateau\-Cambresis";
$areanames{fr}->{3336143} = "Douai";
$areanames{fr}->{3336144} = "Dunkerque";
$areanames{fr}->{3336145} = "Hazebrouck";
$areanames{fr}->{3336146} = "Maubeuge";
$areanames{fr}->{3336147} = "Arras";
$areanames{fr}->{3336148} = "Lens";
$areanames{fr}->{3336149} = "Montreuil";
$areanames{fr}->{3336150} = "Lille";
$areanames{fr}->{3336151} = "Saint\-Omer";
$areanames{fr}->{3336152} = "Saint\-Pol\-sur\-Ternoise";
$areanames{fr}->{3336153} = "Arras";
$areanames{fr}->{3336154} = "Cambrai";
$areanames{fr}->{3336155} = "Hazebrouck";
$areanames{fr}->{3336156} = "Le\ Cateau\-Cambresis";
$areanames{fr}->{3336157} = "Lens";
$areanames{fr}->{3336158} = "Lille";
$areanames{fr}->{3336159} = "Maubeuge";
$areanames{fr}->{3336160} = "Dunkerque";
$areanames{fr}->{3336161} = "Lille";
$areanames{fr}->{3336162} = "Lille";
$areanames{fr}->{3336163} = "Dunkerque";
$areanames{fr}->{3336164} = "Saint\-Omer";
$areanames{fr}->{3336165} = "Saint\-Pol\-sur\-Ternoise";
$areanames{fr}->{3336166} = "Arras";
$areanames{fr}->{3336167} = "Valenciennes";
$areanames{fr}->{3336168} = "Lens";
$areanames{fr}->{3336169} = "Calais";
$areanames{fr}->{3336170} = "Béthune";
$areanames{fr}->{3336171} = "Calais";
$areanames{fr}->{3336172} = "Béthune";
$areanames{fr}->{3336173} = "Calais";
$areanames{fr}->{3336174} = "Douai";
$areanames{fr}->{3336175} = "Dunkerque";
$areanames{fr}->{3336176} = "Lille";
$areanames{fr}->{3336177} = "Lens";
$areanames{fr}->{3336178} = "Lille";
$areanames{fr}->{3336179} = "Saint\-Omer";
$areanames{fr}->{3336180} = "Calais";
$areanames{fr}->{3336181} = "Douai";
$areanames{fr}->{3336182} = "Valenciennes";
$areanames{fr}->{3336183} = "Hazebrouck";
$areanames{fr}->{3336184} = "Le\ Cateau\-Cambresis";
$areanames{fr}->{3336185} = "Montreuil";
$areanames{fr}->{3336186} = "Saint\-Omer";
$areanames{fr}->{3336187} = "Calais";
$areanames{fr}->{3336188} = "Béthune";
$areanames{fr}->{3336189} = "Cambrai";
$areanames{fr}->{3336190} = "Lille";
$areanames{fr}->{3336191} = "Béthune";
$areanames{fr}->{3336192} = "Lille";
$areanames{fr}->{3336193} = "Lens";
$areanames{fr}->{3336194} = "Le\ Cateau\-Cambresis";
$areanames{fr}->{3336195} = "Maubeuge";
$areanames{fr}->{3336196} = "Montreuil";
$areanames{fr}->{3336197} = "Lille";
$areanames{fr}->{3336198} = "Saint\-Omer";
$areanames{fr}->{3336199} = "Maubeuge";
$areanames{fr}->{3336200} = "Dunkerque";
$areanames{fr}->{3336201} = "Saint\-Pol\-sur\-Ternoise";
$areanames{fr}->{3336202} = "Lille";
$areanames{fr}->{3336203} = "Arras";
$areanames{fr}->{3336204} = "Béthune";
$areanames{fr}->{3336205} = "Calais";
$areanames{fr}->{3336206} = "Cambrai";
$areanames{fr}->{3336207} = "Douai";
$areanames{fr}->{3336208} = "Dunkerque";
$areanames{fr}->{3336209} = "Hazebrouck";
$areanames{fr}->{3336210} = "Lille";
$areanames{fr}->{3336211} = "Le\ Cateau\-Cambresis";
$areanames{fr}->{3336212} = "Lens";
$areanames{fr}->{3336213} = "Lille";
$areanames{fr}->{3336214} = "Lille";
$areanames{fr}->{3336215} = "Maubeuge";
$areanames{fr}->{3336216} = "Montreuil";
$areanames{fr}->{3336217} = "Saint\-Omer";
$areanames{fr}->{3336218} = "Saint\-Pol\-sur\-Ternoise";
$areanames{fr}->{3336219} = "Valenciennes";
$areanames{fr}->{333622} = "Lille";
$areanames{fr}->{3336220} = "Calais";
$areanames{fr}->{3336222} = "Béthune";
$areanames{fr}->{3336224} = "Dunkerque";
$areanames{fr}->{3336230} = "Lille";
$areanames{fr}->{3336231} = "Lille";
$areanames{fr}->{3336232} = "Lille";
$areanames{fr}->{3336233} = "Lille";
$areanames{fr}->{3336234} = "Lille";
$areanames{fr}->{3336235} = "Le\ Cateau\-Cambresis";
$areanames{fr}->{3336236} = "Douai";
$areanames{fr}->{3336237} = "Dunkerque";
$areanames{fr}->{3336238} = "Hazebrouck";
$areanames{fr}->{3336239} = "Valenciennes";
$areanames{fr}->{3336240} = "Le\ Cateau\-Cambresis";
$areanames{fr}->{3336241} = "Douai";
$areanames{fr}->{3336242} = "Hazebrouck";
$areanames{fr}->{3336243} = "Maubeuge";
$areanames{fr}->{3336244} = "Montreuil";
$areanames{fr}->{3336245} = "Saint\-Omer";
$areanames{fr}->{3336246} = "Saint\-Pol\-sur\-Ternoise";
$areanames{fr}->{3336247} = "Béthune";
$areanames{fr}->{3336248} = "Lens";
$areanames{fr}->{3336249} = "Montreuil";
$areanames{fr}->{3336250} = "Arras";
$areanames{fr}->{3336251} = "Saint\-Omer";
$areanames{fr}->{3336252} = "Lille";
$areanames{fr}->{3336253} = "Lille";
$areanames{fr}->{3336254} = "Saint\-Pol\-sur\-Ternoise";
$areanames{fr}->{3336255} = "Douai";
$areanames{fr}->{3336256} = "Cambrai";
$areanames{fr}->{3336257} = "Lille";
$areanames{fr}->{3336258} = "Cambrai";
$areanames{fr}->{3336259} = "Lille";
$areanames{fr}->{3336265} = "Lille";
$areanames{fr}->{3336270} = "Dunkerque";
$areanames{fr}->{3336271} = "Hazebrouck";
$areanames{fr}->{3336272} = "Lille";
$areanames{fr}->{3336273} = "Dunkerque";
$areanames{fr}->{3336274} = "Cambrai";
$areanames{fr}->{3336275} = "Valenciennes";
$areanames{fr}->{3336276} = "Douai";
$areanames{fr}->{3336277} = "Saint\-Pol\-sur\-Ternoise";
$areanames{fr}->{3336278} = "Calais";
$areanames{fr}->{3336279} = "Béthune";
$areanames{fr}->{3336280} = "Valenciennes";
$areanames{fr}->{3336281} = "Lille";
$areanames{fr}->{3336282} = "Lille";
$areanames{fr}->{3336283} = "Arras";
$areanames{fr}->{3336284} = "Lille";
$areanames{fr}->{3336285} = "Maubeuge";
$areanames{fr}->{3336286} = "Valenciennes";
$areanames{fr}->{3336287} = "Lille";
$areanames{fr}->{3336288} = "Montreuil";
$areanames{fr}->{3336289} = "Béthune";
$areanames{fr}->{3336290} = "Lens";
$areanames{fr}->{3336291} = "Saint\-Pol\-sur\-Ternoise";
$areanames{fr}->{3336292} = "Lille";
$areanames{fr}->{3336293} = "Lens";
$areanames{fr}->{3336294} = "Lille";
$areanames{fr}->{3336295} = "Arras";
$areanames{fr}->{3336296} = "Béthune";
$areanames{fr}->{3336297} = "Calais";
$areanames{fr}->{3336298} = "Calais";
$areanames{fr}->{3336299} = "Saint\-Omer";
$areanames{fr}->{3336300} = "Luxeuil\-les\-Bains";
$areanames{fr}->{3336301} = "Besançon";
$areanames{fr}->{3336302} = "Montbéliard";
$areanames{fr}->{3336303} = "Morteau";
$areanames{fr}->{3336304} = "Pontarlier";
$areanames{fr}->{3336305} = "Arbois";
$areanames{fr}->{3336306} = "Dole";
$areanames{fr}->{3336307} = "Lons\-le\-Saunier";
$areanames{fr}->{3336308} = "Besançon";
$areanames{fr}->{3336309} = "Saint\-Claude";
$areanames{fr}->{3336310} = "Gray";
$areanames{fr}->{3336311} = "Montbéliard";
$areanames{fr}->{3336312} = "Luxeuil\-les\-Bains";
$areanames{fr}->{3336313} = "Vesoul";
$areanames{fr}->{3336314} = "Belfort";
$areanames{fr}->{3336315} = "Montbéliard";
$areanames{fr}->{3336316} = "Besançon";
$areanames{fr}->{3336317} = "Morteau";
$areanames{fr}->{3336318} = "Besançon";
$areanames{fr}->{3336319} = "Belfort";
$areanames{fr}->{3336320} = "Besançon";
$areanames{fr}->{3336321} = "Besançon";
$areanames{fr}->{3336322} = "Montbéliard";
$areanames{fr}->{3336323} = "Morteau";
$areanames{fr}->{3336324} = "Pontarlier";
$areanames{fr}->{3336325} = "Arbois";
$areanames{fr}->{3336326} = "Dole";
$areanames{fr}->{3336327} = "Lons\-le\-Saunier";
$areanames{fr}->{3336328} = "Saint\-Claude";
$areanames{fr}->{3336329} = "Gray";
$areanames{fr}->{3336330} = "Lure";
$areanames{fr}->{3336331} = "Belfort";
$areanames{fr}->{3336332} = "Montbéliard";
$areanames{fr}->{3336333} = "Lons\-le\-Saunier";
$areanames{fr}->{3336334} = "Saint\-Claude";
$areanames{fr}->{3336335} = "Besançon";
$areanames{fr}->{3336336} = "Dole";
$areanames{fr}->{3336337} = "Vesoul";
$areanames{fr}->{3336338} = "Montbéliard";
$areanames{fr}->{3336339} = "Morteau";
$areanames{fr}->{3336340} = "Arbois";
$areanames{fr}->{3336341} = "Belfort";
$areanames{fr}->{3336342} = "Besançon";
$areanames{fr}->{3336343} = "Dole";
$areanames{fr}->{3336344} = "Gray";
$areanames{fr}->{3336345} = "Lons\-le\-Saunier";
$areanames{fr}->{3336346} = "Lure";
$areanames{fr}->{3336347} = "Luxeuil\-les\-Bains";
$areanames{fr}->{3336348} = "Montbéliard";
$areanames{fr}->{3336349} = "Morteau";
$areanames{fr}->{3336350} = "Pontarlier";
$areanames{fr}->{3336351} = "Saint\-Claude";
$areanames{fr}->{3336352} = "Vesoul";
$areanames{fr}->{3336353} = "Belfort";
$areanames{fr}->{3336354} = "Vesoul";
$areanames{fr}->{3336355} = "Lons\-le\-Saunier";
$areanames{fr}->{3336356} = "Pontarlier";
$areanames{fr}->{3336357} = "Arbois";
$areanames{fr}->{3336358} = "Besançon";
$areanames{fr}->{3336359} = "Montbéliard";
$areanames{fr}->{3336360} = "Pontarlier";
$areanames{fr}->{3336361} = "Arbois";
$areanames{fr}->{3336362} = "Vesoul";
$areanames{fr}->{3336363} = "Belfort";
$areanames{fr}->{3336364} = "Besançon";
$areanames{fr}->{3336365} = "Gray";
$areanames{fr}->{3336366} = "Dole";
$areanames{fr}->{3336367} = "Lons\-le\-Saunier";
$areanames{fr}->{3336368} = "Saint\-Claude";
$areanames{fr}->{3336369} = "Belfort";
$areanames{fr}->{3336370} = "Montbéliard";
$areanames{fr}->{3336371} = "Belfort";
$areanames{fr}->{3336372} = "Luxeuil\-les\-Bains";
$areanames{fr}->{3336373} = "Vesoul";
$areanames{fr}->{3336374} = "Gray";
$areanames{fr}->{3336375} = "Lure";
$areanames{fr}->{3336376} = "Luxeuil\-les\-Bains";
$areanames{fr}->{3336377} = "Vesoul";
$areanames{fr}->{3336378} = "Belfort";
$areanames{fr}->{3336379} = "Belfort";
$areanames{fr}->{3336380} = "Pontarlier";
$areanames{fr}->{3336381} = "Montbéliard";
$areanames{fr}->{3336382} = "Belfort";
$areanames{fr}->{3336383} = "Dole";
$areanames{fr}->{3336384} = "Lons\-le\-Saunier";
$areanames{fr}->{3336385} = "Luxeuil\-les\-Bains";
$areanames{fr}->{3336386} = "Arbois";
$areanames{fr}->{3336387} = "Gray";
$areanames{fr}->{3336388} = "Lure";
$areanames{fr}->{3336389} = "Luxeuil\-les\-Bains";
$areanames{fr}->{3336390} = "Besançon";
$areanames{fr}->{3336391} = "Montbéliard";
$areanames{fr}->{3336392} = "Morteau";
$areanames{fr}->{3336393} = "Pontarlier";
$areanames{fr}->{3336394} = "Arbois";
$areanames{fr}->{3336395} = "Dole";
$areanames{fr}->{3336396} = "Lons\-le\-Saunier";
$areanames{fr}->{3336397} = "Saint\-Claude";
$areanames{fr}->{3336398} = "Gray";
$areanames{fr}->{3336399} = "Lure";
$areanames{fr}->{3336400} = "Abbeville";
$areanames{fr}->{3336401} = "Amiens";
$areanames{fr}->{3336402} = "Albert";
$areanames{fr}->{3336403} = "Château\-Thierry";
$areanames{fr}->{3336404} = "Chauny";
$areanames{fr}->{3336405} = "Clermont";
$areanames{fr}->{3336406} = "Crépy\-en\-Valois";
$areanames{fr}->{3336407} = "Hirson";
$areanames{fr}->{3336408} = "Laon";
$areanames{fr}->{3336409} = "Péronne";
$areanames{fr}->{3336410} = "Saint\-Quentin";
$areanames{fr}->{3336411} = "Soissons";
$areanames{fr}->{3336412} = "Compiègne";
$areanames{fr}->{3336413} = "Château\-Thierry";
$areanames{fr}->{3336414} = "Chauny";
$areanames{fr}->{3336415} = "Hirson";
$areanames{fr}->{3336416} = "Laon";
$areanames{fr}->{3336417} = "Saint\-Quentin";
$areanames{fr}->{3336418} = "Soissons";
$areanames{fr}->{3336419} = "Beauvais";
$areanames{fr}->{3336420} = "Clermont";
$areanames{fr}->{3336421} = "Compiègne";
$areanames{fr}->{3336422} = "Creil";
$areanames{fr}->{3336423} = "Crépy\-en\-Valois";
$areanames{fr}->{3336424} = "Abbeville";
$areanames{fr}->{3336425} = "Albert";
$areanames{fr}->{3336426} = "Amiens";
$areanames{fr}->{3336427} = "Péronne";
$areanames{fr}->{3336428} = "Abbeville";
$areanames{fr}->{3336429} = "Beauvais";
$areanames{fr}->{3336430} = "Château\-Thierry";
$areanames{fr}->{3336431} = "Clermont";
$areanames{fr}->{3336432} = "Compiègne";
$areanames{fr}->{3336433} = "Crépy\-en\-Valois";
$areanames{fr}->{3336434} = "Hirson";
$areanames{fr}->{3336435} = "Péronne";
$areanames{fr}->{3336436} = "Saint\-Quentin";
$areanames{fr}->{3336437} = "Abbeville";
$areanames{fr}->{3336438} = "Amiens";
$areanames{fr}->{3336439} = "Beauvais";
$areanames{fr}->{3336440} = "Amiens";
$areanames{fr}->{3336441} = "Beauvais";
$areanames{fr}->{3336442} = "Château\-Thierry";
$areanames{fr}->{3336443} = "Compiègne";
$areanames{fr}->{3336444} = "Creil";
$areanames{fr}->{3336445} = "Péronne";
$areanames{fr}->{3336446} = "Amiens";
$areanames{fr}->{3336447} = "Compiègne";
$areanames{fr}->{3336448} = "Château\-Thierry";
$areanames{fr}->{3336449} = "Crépy\-en\-Valois";
$areanames{fr}->{3336450} = "Abbeville";
$areanames{fr}->{3336451} = "Amiens";
$areanames{fr}->{3336452} = "Château\-Thierry";
$areanames{fr}->{3336453} = "Clermont";
$areanames{fr}->{3336454} = "Laon";
$areanames{fr}->{3336455} = "Abbeville";
$areanames{fr}->{3336456} = "Albert";
$areanames{fr}->{3336457} = "Amiens";
$areanames{fr}->{3336458} = "Beauvais";
$areanames{fr}->{3336459} = "Château\-Thierry";
$areanames{fr}->{3336460} = "Compiègne";
$areanames{fr}->{3336461} = "Clermont";
$areanames{fr}->{3336462} = "Creil";
$areanames{fr}->{3336463} = "Péronne";
$areanames{fr}->{3336464} = "Abbeville";
$areanames{fr}->{3336465} = "Amiens";
$areanames{fr}->{3336466} = "Creil";
$areanames{fr}->{3336467} = "Beauvais";
$areanames{fr}->{3336468} = "Chauny";
$areanames{fr}->{3336469} = "Clermont";
$areanames{fr}->{3336470} = "Château\-Thierry";
$areanames{fr}->{3336471} = "Compiègne";
$areanames{fr}->{3336472} = "Creil";
$areanames{fr}->{3336473} = "Crépy\-en\-Valois";
$areanames{fr}->{3336474} = "Hirson";
$areanames{fr}->{3336475} = "Laon";
$areanames{fr}->{3336476} = "Péronne";
$areanames{fr}->{3336477} = "Saint\-Quentin";
$areanames{fr}->{3336478} = "Soissons";
$areanames{fr}->{3336479} = "Chauny";
$areanames{fr}->{3336480} = "Péronne";
$areanames{fr}->{3336481} = "Chauny";
$areanames{fr}->{3336482} = "Saint\-Quentin";
$areanames{fr}->{3336483} = "Laon";
$areanames{fr}->{3336484} = "Soissons";
$areanames{fr}->{3336485} = "Amiens";
$areanames{fr}->{3336486} = "Saint\-Quentin";
$areanames{fr}->{3336487} = "Albert";
$areanames{fr}->{3336488} = "Compiègne";
$areanames{fr}->{3336489} = "Beauvais";
$areanames{fr}->{3336490} = "Saint\-Quentin";
$areanames{fr}->{3336491} = "Soissons";
$areanames{fr}->{3336492} = "Soissons";
$areanames{fr}->{3336493} = "Chauny";
$areanames{fr}->{3336494} = "Amiens";
$areanames{fr}->{3336495} = "Hirson";
$areanames{fr}->{3336496} = "Laon";
$areanames{fr}->{3336497} = "Saint\-Quentin";
$areanames{fr}->{3336498} = "Soissons";
$areanames{fr}->{3336499} = "Beauvais";
$areanames{fr}->{3336500} = "Clermont";
$areanames{fr}->{3336501} = "Compiègne";
$areanames{fr}->{3336502} = "Creil";
$areanames{fr}->{3336503} = "Crépy\-en\-Valois";
$areanames{fr}->{3336504} = "Abbeville";
$areanames{fr}->{3336505} = "Albert";
$areanames{fr}->{3336506} = "Amiens";
$areanames{fr}->{3336507} = "Péronne";
$areanames{fr}->{3336508} = "Château\-Thierry";
$areanames{fr}->{3336509} = "Creil";
$areanames{fr}->{3336510} = "Beauvais";
$areanames{fr}->{3336511} = "Compiègne";
$areanames{fr}->{3336512} = "Creil";
$areanames{fr}->{3336513} = "Abbeville";
$areanames{fr}->{3336514} = "Amiens";
$areanames{fr}->{3336515} = "Péronne";
$areanames{fr}->{3336516} = "Laon";
$areanames{fr}->{3336517} = "Abbeville";
$areanames{fr}->{3336518} = "Abbeville";
$areanames{fr}->{3336519} = "Albert";
$areanames{fr}->{3336520} = "Abbeville";
$areanames{fr}->{3336521} = "Saint\-Quentin";
$areanames{fr}->{3336522} = "Crépy\-en\-Valois";
$areanames{fr}->{3336523} = "Clermont";
$areanames{fr}->{3336524} = "Beauvais";
$areanames{fr}->{3336525} = "Château\-Thierry";
$areanames{fr}->{3336526} = "Albert";
$areanames{fr}->{3336527} = "Chauny";
$areanames{fr}->{3336528} = "Compiègne";
$areanames{fr}->{3336529} = "Soissons";
$areanames{fr}->{3336530} = "Château\-Thierry";
$areanames{fr}->{3336531} = "Chauny";
$areanames{fr}->{3336532} = "Laon";
$areanames{fr}->{3336533} = "Beauvais";
$areanames{fr}->{3336534} = "Clermont";
$areanames{fr}->{3336535} = "Compiègne";
$areanames{fr}->{3336536} = "Creil";
$areanames{fr}->{3336537} = "Crépy\-en\-Valois";
$areanames{fr}->{3336538} = "Laon";
$areanames{fr}->{3336539} = "Amiens";
$areanames{fr}->{3336540} = "Péronne";
$areanames{fr}->{3336541} = "Hirson";
$areanames{fr}->{3336542} = "Creil";
$areanames{fr}->{3336543} = "Beauvais";
$areanames{fr}->{3336544} = "Château\-Thierry";
$areanames{fr}->{3336545} = "Chauny";
$areanames{fr}->{3336546} = "Hirson";
$areanames{fr}->{3336547} = "Laon";
$areanames{fr}->{3336548} = "Saint\-Quentin";
$areanames{fr}->{3336549} = "Soissons";
$areanames{fr}->{3336550} = "Beauvais";
$areanames{fr}->{3336551} = "Clermont";
$areanames{fr}->{3336552} = "Compiègne";
$areanames{fr}->{3336553} = "Creil";
$areanames{fr}->{3336554} = "Crépy\-en\-Valois";
$areanames{fr}->{3336555} = "Abbeville";
$areanames{fr}->{3336556} = "Albert";
$areanames{fr}->{3336557} = "Amiens";
$areanames{fr}->{3336558} = "Péronne";
$areanames{fr}->{3336559} = "Amiens";
$areanames{fr}->{3336560} = "Laon";
$areanames{fr}->{3336561} = "Amiens";
$areanames{fr}->{3336562} = "Chauny";
$areanames{fr}->{3336563} = "Soissons";
$areanames{fr}->{3336564} = "Albert";
$areanames{fr}->{3336565} = "Creil";
$areanames{fr}->{3336566} = "Amiens";
$areanames{fr}->{3336567} = "Laon";
$areanames{fr}->{3336568} = "Beauvais";
$areanames{fr}->{3336569} = "Creil";
$areanames{fr}->{3336570} = "Abbeville";
$areanames{fr}->{3336571} = "Amiens";
$areanames{fr}->{3336572} = "Laon";
$areanames{fr}->{3336573} = "Saint\-Quentin";
$areanames{fr}->{3336574} = "Beauvais";
$areanames{fr}->{3336575} = "Compiègne";
$areanames{fr}->{3336576} = "Creil";
$areanames{fr}->{3336577} = "Crépy\-en\-Valois";
$areanames{fr}->{3336578} = "Clermont";
$areanames{fr}->{3336579} = "Amiens";
$areanames{fr}->{3336580} = "Amiens";
$areanames{fr}->{3336581} = "Château\-Thierry";
$areanames{fr}->{3336582} = "Chauny";
$areanames{fr}->{3336583} = "Hirson";
$areanames{fr}->{3336584} = "Laon";
$areanames{fr}->{3336585} = "Péronne";
$areanames{fr}->{3336586} = "Saint\-Quentin";
$areanames{fr}->{3336587} = "Soissons";
$areanames{fr}->{3336588} = "Amiens";
$areanames{fr}->{3336589} = "Amiens";
$areanames{fr}->{3336590} = "Laon";
$areanames{fr}->{3336591} = "Amiens";
$areanames{fr}->{3336592} = "Saint\-Quentin";
$areanames{fr}->{3336593} = "Compiègne";
$areanames{fr}->{3336594} = "Beauvais";
$areanames{fr}->{3336595} = "Laon";
$areanames{fr}->{3336596} = "Creil";
$areanames{fr}->{3336597} = "Beauvais";
$areanames{fr}->{3336598} = "Compiègne";
$areanames{fr}->{3336599} = "Saint\-Quentin";
$areanames{fr}->{3336600} = "Douai";
$areanames{fr}->{3336601} = "Dunkerque";
$areanames{fr}->{3336602} = "Hazebrouck";
$areanames{fr}->{3336603} = "Valenciennes";
$areanames{fr}->{3336604} = "Lens";
$areanames{fr}->{3336605} = "Saint\-Omer";
$areanames{fr}->{3336606} = "Lille";
$areanames{fr}->{3336607} = "Lens";
$areanames{fr}->{3336608} = "Lille";
$areanames{fr}->{3336609} = "Béthune";
$areanames{fr}->{3336610} = "Saint\-Omer";
$areanames{fr}->{3336611} = "Saint\-Pol\-sur\-Ternoise";
$areanames{fr}->{3336612} = "Arras";
$areanames{fr}->{3336613} = "Béthune";
$areanames{fr}->{3336614} = "Lens";
$areanames{fr}->{3336615} = "Montreuil";
$areanames{fr}->{3336616} = "Le\ Cateau\-Cambresis";
$areanames{fr}->{3336617} = "Dunkerque";
$areanames{fr}->{3336618} = "Hazebrouck";
$areanames{fr}->{3336619} = "Lille";
$areanames{fr}->{3336620} = "Valenciennes";
$areanames{fr}->{3336621} = "Lille";
$areanames{fr}->{3336622} = "Valenciennes";
$areanames{fr}->{3336623} = "Lens";
$areanames{fr}->{3336624} = "Maubeuge";
$areanames{fr}->{3336625} = "Calais";
$areanames{fr}->{3336626} = "Maubeuge";
$areanames{fr}->{3336627} = "Le\ Cateau\-Cambresis";
$areanames{fr}->{3336628} = "Cambrai";
$areanames{fr}->{3336629} = "Saint\-Pol\-sur\-Ternoise";
$areanames{fr}->{3336630} = "Lens";
$areanames{fr}->{3336631} = "Arras";
$areanames{fr}->{3336632} = "Lille";
$areanames{fr}->{3336633} = "Lille";
$areanames{fr}->{3336634} = "Béthune";
$areanames{fr}->{3336635} = "Hazebrouck";
$areanames{fr}->{3336636} = "Douai";
$areanames{fr}->{3336637} = "Montreuil";
$areanames{fr}->{3336638} = "Saint\-Omer";
$areanames{fr}->{3336639} = "Lille";
$areanames{fr}->{3336640} = "Valenciennes";
$areanames{fr}->{3336641} = "Dunkerque";
$areanames{fr}->{3336642} = "Valenciennes";
$areanames{fr}->{3336643} = "Cambrai";
$areanames{fr}->{3336644} = "Le\ Cateau\-Cambresis";
$areanames{fr}->{3336645} = "Douai";
$areanames{fr}->{3336646} = "Dunkerque";
$areanames{fr}->{3336647} = "Hazebrouck";
$areanames{fr}->{3336648} = "Lille";
$areanames{fr}->{3336649} = "Maubeuge";
$areanames{fr}->{3336650} = "Valenciennes";
$areanames{fr}->{3336651} = "Arras";
$areanames{fr}->{3336652} = "Béthune";
$areanames{fr}->{3336653} = "Calais";
$areanames{fr}->{3336654} = "Lens";
$areanames{fr}->{3336655} = "Montreuil";
$areanames{fr}->{3336656} = "Saint\-Omer";
$areanames{fr}->{3336657} = "Saint\-Pol\-sur\-Ternoise";
$areanames{fr}->{3336658} = "Arras";
$areanames{fr}->{3336659} = "Valenciennes";
$areanames{fr}->{3336664} = "Lille";
$areanames{fr}->{3336672} = "Lille";
$areanames{fr}->{3336673} = "Lille";
$areanames{fr}->{3336680} = "Lille";
$areanames{fr}->{3336681} = "Calais";
$areanames{fr}->{3336682} = "Lens";
$areanames{fr}->{3336683} = "Montreuil";
$areanames{fr}->{3336684} = "Saint\-Omer";
$areanames{fr}->{3336685} = "Saint\-Pol\-sur\-Ternoise";
$areanames{fr}->{3336686} = "Arras";
$areanames{fr}->{3336687} = "Douai";
$areanames{fr}->{3336688} = "Lille";
$areanames{fr}->{3336689} = "Dunkerque";
$areanames{fr}->{3336690} = "Cambrai";
$areanames{fr}->{3336691} = "Douai";
$areanames{fr}->{3336692} = "Dunkerque";
$areanames{fr}->{3336693} = "Hazebrouck";
$areanames{fr}->{3336694} = "Maubeuge";
$areanames{fr}->{3336695} = "Valenciennes";
$areanames{fr}->{3336696} = "Lille";
$areanames{fr}->{3336697} = "Lille";
$areanames{fr}->{3336698} = "Lens";
$areanames{fr}->{3336699} = "Arras";
$areanames{fr}->{3336707} = "Strasbourg";
$areanames{fr}->{3336708} = "Strasbourg";
$areanames{fr}->{3336710} = "Strasbourg";
$areanames{fr}->{3336711} = "Mulhouse";
$areanames{fr}->{3336720} = "Sélestat";
$areanames{fr}->{3336721} = "Strasbourg";
$areanames{fr}->{3336722} = "Strasbourg";
$areanames{fr}->{3336723} = "Mulhouse";
$areanames{fr}->{3336724} = "Caen";
$areanames{fr}->{3336725} = "Strasbourg";
$areanames{fr}->{3336726} = "Mulhouse";
$areanames{fr}->{3336727} = "Mulhouse";
$areanames{fr}->{3336728} = "Colmar";
$areanames{fr}->{3336729} = "Strasbourg";
$areanames{fr}->{3336730} = "Colmar";
$areanames{fr}->{3336731} = "Haguenau";
$areanames{fr}->{3336732} = "Strasbourg";
$areanames{fr}->{3336733} = "Strasbourg";
$areanames{fr}->{3336734} = "Strasbourg";
$areanames{fr}->{3336735} = "Mulhouse";
$areanames{fr}->{3336736} = "Altkirch";
$areanames{fr}->{3336737} = "Sélestat";
$areanames{fr}->{3336738} = "Saverne";
$areanames{fr}->{3336739} = "Strasbourg";
$areanames{fr}->{3336740} = "Haguenau";
$areanames{fr}->{3336741} = "Saverne";
$areanames{fr}->{3336742} = "Sélestat";
$areanames{fr}->{3336743} = "Strasbourg";
$areanames{fr}->{3336744} = "Altkirch";
$areanames{fr}->{3336745} = "Colmar";
$areanames{fr}->{3336746} = "Mulhouse";
$areanames{fr}->{3336747} = "Strasbourg";
$areanames{fr}->{3336748} = "Strasbourg";
$areanames{fr}->{3336749} = "Strasbourg";
$areanames{fr}->{3336750} = "Sélestat";
$areanames{fr}->{3336751} = "Altkirch";
$areanames{fr}->{3336752} = "Altkirch";
$areanames{fr}->{3336760} = "Strasbourg";
$areanames{fr}->{3336761} = "Mulhouse";
$areanames{fr}->{3336762} = "Haguenau";
$areanames{fr}->{3336763} = "Saverne";
$areanames{fr}->{3336764} = "Sélestat";
$areanames{fr}->{3336765} = "Strasbourg";
$areanames{fr}->{3336766} = "Saverne";
$areanames{fr}->{3336767} = "Strasbourg";
$areanames{fr}->{3336768} = "Strasbourg";
$areanames{fr}->{3336769} = "Haguenau";
$areanames{fr}->{333677} = "Strasbourg";
$areanames{fr}->{3336776} = "Mulhouse";
$areanames{fr}->{3336777} = "Mulhouse";
$areanames{fr}->{3336778} = "Mulhouse";
$areanames{fr}->{3336780} = "Strasbourg";
$areanames{fr}->{3336781} = "Saverne";
$areanames{fr}->{3336782} = "Colmar";
$areanames{fr}->{3336783} = "Haguenau";
$areanames{fr}->{3336784} = "Colmar";
$areanames{fr}->{3336785} = "Strasbourg";
$areanames{fr}->{3336786} = "Strasbourg";
$areanames{fr}->{3336787} = "Strasbourg";
$areanames{fr}->{3336788} = "Mulhouse";
$areanames{fr}->{3336789} = "Strasbourg";
$areanames{fr}->{3336790} = "Colmar";
$areanames{fr}->{3336791} = "Mulhouse";
$areanames{fr}->{3336792} = "Sélestat";
$areanames{fr}->{3336793} = "Altkirch";
$areanames{fr}->{3336794} = "Mulhouse";
$areanames{fr}->{3336795} = "Strasbourg";
$areanames{fr}->{3336796} = "Colmar";
$areanames{fr}->{3336797} = "Strasbourg";
$areanames{fr}->{3336798} = "Strasbourg";
$areanames{fr}->{3336799} = "Strasbourg";
$areanames{fr}->{3336807} = "Colmar";
$areanames{fr}->{3336810} = "Mulhouse";
$areanames{fr}->{3336811} = "Colmar";
$areanames{fr}->{3336812} = "Altkirch";
$areanames{fr}->{3336813} = "Sélestat";
$areanames{fr}->{3336814} = "Haguenau";
$areanames{fr}->{3336815} = "Saverne";
$areanames{fr}->{3336816} = "Haguenau";
$areanames{fr}->{3336817} = "Saverne";
$areanames{fr}->{3336818} = "Sélestat";
$areanames{fr}->{3336819} = "Strasbourg";
$areanames{fr}->{3336820} = "Strasbourg";
$areanames{fr}->{3336821} = "Haguenau";
$areanames{fr}->{3336822} = "Altkirch";
$areanames{fr}->{3336823} = "Colmar";
$areanames{fr}->{3336824} = "Haguenau";
$areanames{fr}->{3336825} = "Mulhouse";
$areanames{fr}->{3336826} = "Saverne";
$areanames{fr}->{3336827} = "Sélestat";
$areanames{fr}->{3336828} = "Strasbourg";
$areanames{fr}->{3336829} = "Haguenau";
$areanames{fr}->{3336830} = "Altkirch";
$areanames{fr}->{3336831} = "Colmar";
$areanames{fr}->{3336832} = "Mulhouse";
$areanames{fr}->{3336833} = "Strasbourg";
$areanames{fr}->{3336834} = "Colmar";
$areanames{fr}->{3336835} = "Mulhouse";
$areanames{fr}->{3336836} = "Mulhouse";
$areanames{fr}->{3336837} = "Saverne";
$areanames{fr}->{3336838} = "Strasbourg";
$areanames{fr}->{3336839} = "Sélestat";
$areanames{fr}->{3336847} = "Mulhouse";
$areanames{fr}->{3336850} = "Haguenau";
$areanames{fr}->{3336851} = "Altkirch";
$areanames{fr}->{3336852} = "Colmar";
$areanames{fr}->{3336853} = "Mulhouse";
$areanames{fr}->{3336854} = "Haguenau";
$areanames{fr}->{3336855} = "Haguenau";
$areanames{fr}->{3336856} = "Saverne";
$areanames{fr}->{3336857} = "Sélestat";
$areanames{fr}->{3336858} = "Strasbourg";
$areanames{fr}->{3336859} = "Strasbourg";
$areanames{fr}->{3336860} = "Colmar";
$areanames{fr}->{3336861} = "Colmar";
$areanames{fr}->{3336862} = "Strasbourg";
$areanames{fr}->{3336863} = "Colmar";
$areanames{fr}->{3336864} = "Altkirch";
$areanames{fr}->{3336865} = "Mulhouse";
$areanames{fr}->{3336866} = "Haguenau";
$areanames{fr}->{3336867} = "Strasbourg";
$areanames{fr}->{3336868} = "Strasbourg";
$areanames{fr}->{3336869} = "Strasbourg";
$areanames{fr}->{3336870} = "Mulhouse";
$areanames{fr}->{3336871} = "Strasbourg";
$areanames{fr}->{3336872} = "Haguenau";
$areanames{fr}->{3336873} = "Saverne";
$areanames{fr}->{3336874} = "Sélestat";
$areanames{fr}->{3336875} = "Mulhouse";
$areanames{fr}->{3336876} = "Strasbourg";
$areanames{fr}->{3336877} = "Saverne";
$areanames{fr}->{3336878} = "Strasbourg";
$areanames{fr}->{3336879} = "Sélestat";
$areanames{fr}->{3336880} = "Altkirch";
$areanames{fr}->{3336881} = "Haguenau";
$areanames{fr}->{3336882} = "Saverne";
$areanames{fr}->{3336883} = "Sélestat";
$areanames{fr}->{3336884} = "Strasbourg";
$areanames{fr}->{3336885} = "Altkirch";
$areanames{fr}->{3336886} = "Colmar";
$areanames{fr}->{3336887} = "Mulhouse";
$areanames{fr}->{3336888} = "Saverne";
$areanames{fr}->{3336889} = "Strasbourg";
$areanames{fr}->{3336890} = "Sélestat";
$areanames{fr}->{3336891} = "Strasbourg";
$areanames{fr}->{3336892} = "Haguenau";
$areanames{fr}->{3336893} = "Strasbourg";
$areanames{fr}->{3336894} = "Altkirch";
$areanames{fr}->{3336895} = "Haguenau";
$areanames{fr}->{3336896} = "Saverne";
$areanames{fr}->{3336897} = "Sélestat";
$areanames{fr}->{3336898} = "Strasbourg";
$areanames{fr}->{3336899} = "Colmar";
$areanames{fr}->{3336907} = "Mulhouse";
$areanames{fr}->{3336914} = "Strasbourg";
$areanames{fr}->{3336919} = "Mulhouse";
$areanames{fr}->{333692} = "Strasbourg";
$areanames{fr}->{3336921} = "Mulhouse";
$areanames{fr}->{3336927} = "Sélestat";
$areanames{fr}->{3336928} = "Colmar";
$areanames{fr}->{3336929} = "Mulhouse";
$areanames{fr}->{3336930} = "Sélestat";
$areanames{fr}->{3336931} = "Strasbourg";
$areanames{fr}->{3336932} = "Strasbourg";
$areanames{fr}->{3336933} = "Sélestat";
$areanames{fr}->{3336934} = "Colmar";
$areanames{fr}->{3336935} = "Saverne";
$areanames{fr}->{3336936} = "Strasbourg";
$areanames{fr}->{3336937} = "Saverne";
$areanames{fr}->{3336938} = "Mulhouse";
$areanames{fr}->{3336939} = "Strasbourg";
$areanames{fr}->{3336940} = "Haguenau";
$areanames{fr}->{3336941} = "Strasbourg";
$areanames{fr}->{3336942} = "Saverne";
$areanames{fr}->{3336943} = "Strasbourg";
$areanames{fr}->{3336944} = "Altkirch";
$areanames{fr}->{3336945} = "Colmar";
$areanames{fr}->{3336946} = "Strasbourg";
$areanames{fr}->{3336947} = "Sélestat";
$areanames{fr}->{3336948} = "Strasbourg";
$areanames{fr}->{3336949} = "Colmar";
$areanames{fr}->{3336958} = "Mulhouse";
$areanames{fr}->{3336960} = "Mulhouse";
$areanames{fr}->{3336961} = "Strasbourg";
$areanames{fr}->{3336962} = "Saverne";
$areanames{fr}->{3336963} = "Altkirch";
$areanames{fr}->{3336964} = "Sélestat";
$areanames{fr}->{3336965} = "Mulhouse";
$areanames{fr}->{3336966} = "Altkirch";
$areanames{fr}->{3336967} = "Strasbourg";
$areanames{fr}->{3336968} = "Strasbourg";
$areanames{fr}->{3336969} = "Strasbourg";
$areanames{fr}->{3336977} = "Mulhouse";
$areanames{fr}->{3336978} = "Strasbourg";
$areanames{fr}->{3336981} = "Strasbourg";
$areanames{fr}->{3336990} = "Strasbourg";
$areanames{fr}->{3336991} = "Haguenau";
$areanames{fr}->{3336992} = "Saverne";
$areanames{fr}->{3336993} = "Strasbourg";
$areanames{fr}->{3336994} = "Strasbourg";
$areanames{fr}->{3336995} = "Strasbourg";
$areanames{fr}->{3336996} = "Strasbourg";
$areanames{fr}->{3336997} = "Sélestat";
$areanames{fr}->{3336998} = "Altkirch";
$areanames{fr}->{3336999} = "Colmar";
$areanames{fr}->{3337000} = "Besançon";
$areanames{fr}->{3337001} = "Belfort";
$areanames{fr}->{3337002} = "Besançon";
$areanames{fr}->{3337003} = "Montbéliard";
$areanames{fr}->{3337004} = "Belfort";
$areanames{fr}->{3337005} = "Dole";
$areanames{fr}->{3337006} = "Lons\-le\-Saunier";
$areanames{fr}->{3337007} = "Montbéliard";
$areanames{fr}->{3337008} = "Vesoul";
$areanames{fr}->{3337009} = "Arbois";
$areanames{fr}->{3337010} = "Belfort";
$areanames{fr}->{3337011} = "Besançon";
$areanames{fr}->{3337012} = "Dole";
$areanames{fr}->{3337013} = "Gray";
$areanames{fr}->{3337014} = "Lons\-le\-Saunier";
$areanames{fr}->{3337015} = "Lure";
$areanames{fr}->{3337016} = "Luxeuil\-les\-Bains";
$areanames{fr}->{3337017} = "Montbéliard";
$areanames{fr}->{3337018} = "Morteau";
$areanames{fr}->{3337019} = "Pontarlier";
$areanames{fr}->{3337020} = "Besançon";
$areanames{fr}->{3337021} = "Besançon";
$areanames{fr}->{3337022} = "Saint\-Claude";
$areanames{fr}->{3337023} = "Vesoul";
$areanames{fr}->{3337024} = "Morteau";
$areanames{fr}->{3337025} = "Lure";
$areanames{fr}->{3337026} = "Luxeuil\-les\-Bains";
$areanames{fr}->{3337027} = "Besançon";
$areanames{fr}->{3337028} = "Pontarlier";
$areanames{fr}->{3337029} = "Besançon";
$areanames{fr}->{3337030} = "Montbéliard";
$areanames{fr}->{3337031} = "Morteau";
$areanames{fr}->{3337032} = "Pontarlier";
$areanames{fr}->{3337033} = "Arbois";
$areanames{fr}->{3337034} = "Dole";
$areanames{fr}->{3337035} = "Lons\-le\-Saunier";
$areanames{fr}->{3337036} = "Saint\-Claude";
$areanames{fr}->{3337037} = "Gray";
$areanames{fr}->{3337038} = "Lure";
$areanames{fr}->{3337039} = "Luxeuil\-les\-Bains";
$areanames{fr}->{3337040} = "Vesoul";
$areanames{fr}->{3337041} = "Belfort";
$areanames{fr}->{3337042} = "Belfort";
$areanames{fr}->{3337043} = "Lons\-le\-Saunier";
$areanames{fr}->{3337044} = "Morteau";
$areanames{fr}->{3337045} = "Gray";
$areanames{fr}->{3337046} = "Montbéliard";
$areanames{fr}->{3337047} = "Lure";
$areanames{fr}->{3337048} = "Arbois";
$areanames{fr}->{3337049} = "Pontarlier";
$areanames{fr}->{3337050} = "Besançon";
$areanames{fr}->{3337051} = "Morteau";
$areanames{fr}->{3337052} = "Dole";
$areanames{fr}->{3337053} = "Lons\-le\-Saunier";
$areanames{fr}->{3337054} = "Saint\-Claude";
$areanames{fr}->{3337055} = "Lure";
$areanames{fr}->{3337056} = "Luxeuil\-les\-Bains";
$areanames{fr}->{3337057} = "Vesoul";
$areanames{fr}->{3337058} = "Dole";
$areanames{fr}->{3337059} = "Vesoul";
$areanames{fr}->{3337060} = "Saint\-Claude";
$areanames{fr}->{3337061} = "Belfort";
$areanames{fr}->{3337062} = "Luxeuil\-les\-Bains";
$areanames{fr}->{3337063} = "Besançon";
$areanames{fr}->{3337064} = "Besançon";
$areanames{fr}->{3337065} = "Montbéliard";
$areanames{fr}->{3337066} = "Morteau";
$areanames{fr}->{3337067} = "Pontarlier";
$areanames{fr}->{3337068} = "Gray";
$areanames{fr}->{3337069} = "Lure";
$areanames{fr}->{3337070} = "Besançon";
$areanames{fr}->{3337071} = "Montbéliard";
$areanames{fr}->{3337072} = "Besançon";
$areanames{fr}->{3337073} = "Lons\-le\-Saunier";
$areanames{fr}->{3337074} = "Lons\-le\-Saunier";
$areanames{fr}->{3337075} = "Belfort";
$areanames{fr}->{3337076} = "Vesoul";
$areanames{fr}->{3337077} = "Besançon";
$areanames{fr}->{3337078} = "Montbéliard";
$areanames{fr}->{3337079} = "Arbois";
$areanames{fr}->{3337080} = "Belfort";
$areanames{fr}->{3337081} = "Dole";
$areanames{fr}->{3337082} = "Lons\-le\-Saunier";
$areanames{fr}->{3337083} = "Saint\-Claude";
$areanames{fr}->{3337084} = "Luxeuil\-les\-Bains";
$areanames{fr}->{3337085} = "Vesoul";
$areanames{fr}->{3337086} = "Belfort";
$areanames{fr}->{3337087} = "Besançon";
$areanames{fr}->{3337088} = "Besançon";
$areanames{fr}->{3337089} = "Montbéliard";
$areanames{fr}->{3337090} = "Belfort";
$areanames{fr}->{3337091} = "Morteau";
$areanames{fr}->{3337092} = "Belfort";
$areanames{fr}->{3337093} = "Besançon";
$areanames{fr}->{3337094} = "Montbéliard";
$areanames{fr}->{3337095} = "Pontarlier";
$areanames{fr}->{3337096} = "Arbois";
$areanames{fr}->{3337097} = "Saint\-Claude";
$areanames{fr}->{3337098} = "Gray";
$areanames{fr}->{3337099} = "Belfort";
$areanames{fr}->{3337100} = "Is\-sur\-Tille";
$areanames{fr}->{3337101} = "Joigny";
$areanames{fr}->{3337102} = "Louhans";
$areanames{fr}->{3337103} = "Mâcon";
$areanames{fr}->{3337104} = "Montbard";
$areanames{fr}->{3337105} = "Montceau\-les\-Mines";
$areanames{fr}->{3337106} = "Nevers";
$areanames{fr}->{3337107} = "Paray\-le\-Monial";
$areanames{fr}->{3337108} = "Saulieu";
$areanames{fr}->{3337109} = "Sens";
$areanames{fr}->{3337110} = "Tonnerre";
$areanames{fr}->{3337111} = "Toucy";
$areanames{fr}->{3337112} = "Autun";
$areanames{fr}->{3337113} = "Auxerre";
$areanames{fr}->{3337114} = "Beaune";
$areanames{fr}->{3337115} = "Dijon";
$areanames{fr}->{3337116} = "Autun";
$areanames{fr}->{3337117} = "Joigny";
$areanames{fr}->{3337118} = "Tonnerre";
$areanames{fr}->{3337119} = "Dijon";
$areanames{fr}->{3337120} = "Châtillon\-sur\-Seine";
$areanames{fr}->{3337121} = "Is\-sur\-Tille";
$areanames{fr}->{3337122} = "Montbard";
$areanames{fr}->{3337123} = "Saulieu";
$areanames{fr}->{3337124} = "Château\-Chinon\(Ville\)";
$areanames{fr}->{3337125} = "Cosne\-Cours\-sur\-Loire";
$areanames{fr}->{3337126} = "Decize";
$areanames{fr}->{3337127} = "Nevers";
$areanames{fr}->{3337128} = "Autun";
$areanames{fr}->{3337129} = "Chalon\-sur\-Saône";
$areanames{fr}->{3337130} = "Louhans";
$areanames{fr}->{3337131} = "Mâcon";
$areanames{fr}->{3337132} = "Montceau\-les\-Mines";
$areanames{fr}->{3337133} = "Paray\-le\-Monial";
$areanames{fr}->{3337134} = "Auxerre";
$areanames{fr}->{3337135} = "Joigny";
$areanames{fr}->{3337136} = "Sens";
$areanames{fr}->{3337137} = "Tonnerre";
$areanames{fr}->{3337138} = "Toucy";
$areanames{fr}->{3337139} = "Beaune";
$areanames{fr}->{3337140} = "Chalon\-sur\-Saône";
$areanames{fr}->{3337141} = "Mâcon";
$areanames{fr}->{3337142} = "Nevers";
$areanames{fr}->{3337143} = "Auxerre";
$areanames{fr}->{3337144} = "Sens";
$areanames{fr}->{3337145} = "Nevers";
$areanames{fr}->{3337146} = "Decize";
$areanames{fr}->{3337147} = "Autun";
$areanames{fr}->{3337148} = "Louhans";
$areanames{fr}->{3337149} = "Mâcon";
$areanames{fr}->{3337150} = "Tonnerre";
$areanames{fr}->{3337151} = "Toucy";
$areanames{fr}->{3337152} = "Montbard";
$areanames{fr}->{3337153} = "Saulieu";
$areanames{fr}->{3337154} = "Château\-Chinon\(Ville\)";
$areanames{fr}->{3337155} = "Cosne\-Cours\-sur\-Loire";
$areanames{fr}->{3337156} = "Decize";
$areanames{fr}->{3337157} = "Is\-sur\-Tille";
$areanames{fr}->{3337158} = "Beaune";
$areanames{fr}->{3337159} = "Château\-Chinon\(Ville\)";
$areanames{fr}->{3337160} = "Châtillon\-sur\-Seine";
$areanames{fr}->{3337161} = "Is\-sur\-Tille";
$areanames{fr}->{3337162} = "Toucy";
$areanames{fr}->{3337163} = "Mâcon";
$areanames{fr}->{3337164} = "Nevers";
$areanames{fr}->{3337165} = "Louhans";
$areanames{fr}->{3337166} = "Autun";
$areanames{fr}->{3337167} = "Auxerre";
$areanames{fr}->{3337168} = "Montbard";
$areanames{fr}->{3337169} = "Tonnerre";
$areanames{fr}->{3337170} = "Dijon";
$areanames{fr}->{3337171} = "Nevers";
$areanames{fr}->{3337172} = "Paray\-le\-Monial";
$areanames{fr}->{3337173} = "Châtillon\-sur\-Seine";
$areanames{fr}->{3337174} = "Joigny";
$areanames{fr}->{3337175} = "Sens";
$areanames{fr}->{3337176} = "Chalon\-sur\-Saône";
$areanames{fr}->{3337177} = "Mâcon";
$areanames{fr}->{3337178} = "Auxerre";
$areanames{fr}->{3337179} = "Montceau\-les\-Mines";
$areanames{fr}->{3337180} = "Montceau\-les\-Mines";
$areanames{fr}->{3337181} = "Dijon";
$areanames{fr}->{3337182} = "Autun";
$areanames{fr}->{3337183} = "Chalon\-sur\-Saône";
$areanames{fr}->{3337184} = "Mâcon";
$areanames{fr}->{3337185} = "Montceau\-les\-Mines";
$areanames{fr}->{3337186} = "Dijon";
$areanames{fr}->{3337187} = "Chalon\-sur\-Saône";
$areanames{fr}->{3337188} = "Cosne\-Cours\-sur\-Loire";
$areanames{fr}->{3337189} = "Saulieu";
$areanames{fr}->{3337190} = "Dijon";
$areanames{fr}->{3337191} = "Beaune";
$areanames{fr}->{3337192} = "Châtillon\-sur\-Seine";
$areanames{fr}->{3337193} = "Dijon";
$areanames{fr}->{3337194} = "Is\-sur\-Tille";
$areanames{fr}->{3337195} = "Montbard";
$areanames{fr}->{3337196} = "Saulieu";
$areanames{fr}->{3337197} = "Château\-Chinon\(Ville\)";
$areanames{fr}->{3337198} = "Cosne\-Cours\-sur\-Loire";
$areanames{fr}->{3337199} = "Decize";
$areanames{fr}->{3337200} = "Metz";
$areanames{fr}->{3337201} = "Morhange";
$areanames{fr}->{3337202} = "Saint\-Avold";
$areanames{fr}->{3337203} = "Sarrebourg";
$areanames{fr}->{3337204} = "Sarreguemines";
$areanames{fr}->{3337205} = "Thionville";
$areanames{fr}->{3337206} = "Épinal";
$areanames{fr}->{3337207} = "Neufchâteau";
$areanames{fr}->{3337208} = "Remiremont";
$areanames{fr}->{3337209} = "Saint\-Dié\-des\-Vosges";
$areanames{fr}->{3337210} = "Vittel";
$areanames{fr}->{3337211} = "Saint\-Dié\-des\-Vosges";
$areanames{fr}->{3337212} = "Toul";
$areanames{fr}->{3337213} = "Metz";
$areanames{fr}->{3337214} = "Nancy";
$areanames{fr}->{3337215} = "Pont\-à\-Mousson";
$areanames{fr}->{3337216} = "Lunéville";
$areanames{fr}->{3337217} = "Verdun";
$areanames{fr}->{3337218} = "Saint\-Avold";
$areanames{fr}->{3337219} = "Sarrebourg";
$areanames{fr}->{3337220} = "Sarreguemines";
$areanames{fr}->{3337221} = "Neufchâteau";
$areanames{fr}->{3337222} = "Épinal";
$areanames{fr}->{3337223} = "Nancy";
$areanames{fr}->{3337224} = "Bar\-le\-Duc";
$areanames{fr}->{3337225} = "Bar\-le\-Duc";
$areanames{fr}->{3337226} = "Briey";
$areanames{fr}->{3337227} = "Metz";
$areanames{fr}->{3337228} = "Sarrebourg";
$areanames{fr}->{3337229} = "Sarreguemines";
$areanames{fr}->{3337230} = "Lunéville";
$areanames{fr}->{3337231} = "Nancy";
$areanames{fr}->{3337232} = "Pont\-à\-Mousson";
$areanames{fr}->{3337233} = "Toul";
$areanames{fr}->{3337234} = "Épinal";
$areanames{fr}->{3337235} = "Morhange";
$areanames{fr}->{3337236} = "Saint\-Avold";
$areanames{fr}->{3337237} = "Thionville";
$areanames{fr}->{3337238} = "Bar\-le\-Duc";
$areanames{fr}->{3337239} = "Metz";
$areanames{fr}->{3337240} = "Metz";
$areanames{fr}->{3337241} = "Neufchâteau";
$areanames{fr}->{3337242} = "Nancy";
$areanames{fr}->{3337243} = "Metz";
$areanames{fr}->{3337244} = "Épinal";
$areanames{fr}->{3337245} = "Nancy";
$areanames{fr}->{3337246} = "Verdun";
$areanames{fr}->{3337247} = "Nancy";
$areanames{fr}->{3337248} = "Metz";
$areanames{fr}->{3337249} = "Thionville";
$areanames{fr}->{3337250} = "Épinal";
$areanames{fr}->{3337251} = "Metz";
$areanames{fr}->{3337252} = "Thionville";
$areanames{fr}->{3337253} = "Saint\-Avold";
$areanames{fr}->{3337254} = "Épinal";
$areanames{fr}->{3337255} = "Bar\-le\-Duc";
$areanames{fr}->{3337256} = "Briey";
$areanames{fr}->{3337257} = "Metz";
$areanames{fr}->{3337258} = "Saint\-Dié\-des\-Vosges";
$areanames{fr}->{3337259} = "Lunéville";
$areanames{fr}->{3337260} = "Metz";
$areanames{fr}->{3337261} = "Nancy";
$areanames{fr}->{3337262} = "Bar\-le\-Duc";
$areanames{fr}->{3337263} = "Nancy";
$areanames{fr}->{3337264} = "Sarreguemines";
$areanames{fr}->{3337265} = "Verdun";
$areanames{fr}->{3337266} = "Sarrebourg";
$areanames{fr}->{3337267} = "Remiremont";
$areanames{fr}->{3337268} = "Briey";
$areanames{fr}->{3337269} = "Morhange";
$areanames{fr}->{3337270} = "Metz";
$areanames{fr}->{3337271} = "Nancy";
$areanames{fr}->{3337272} = "Metz";
$areanames{fr}->{3337273} = "Épinal";
$areanames{fr}->{3337274} = "Nancy";
$areanames{fr}->{3337275} = "Pont\-à\-Mousson";
$areanames{fr}->{3337276} = "Toul";
$areanames{fr}->{3337277} = "Morhange";
$areanames{fr}->{3337278} = "Neufchâteau";
$areanames{fr}->{3337279} = "Vittel";
$areanames{fr}->{3337280} = "Thionville";
$areanames{fr}->{3337281} = "Nancy";
$areanames{fr}->{3337282} = "Saint\-Avold";
$areanames{fr}->{3337283} = "Metz";
$areanames{fr}->{3337284} = "Nancy";
$areanames{fr}->{3337285} = "Verdun";
$areanames{fr}->{3337286} = "Épinal";
$areanames{fr}->{3337287} = "Metz";
$areanames{fr}->{3337288} = "Metz";
$areanames{fr}->{3337289} = "Remiremont";
$areanames{fr}->{3337290} = "Metz";
$areanames{fr}->{3337291} = "Nancy";
$areanames{fr}->{3337292} = "Verdun";
$areanames{fr}->{3337293} = "Briey";
$areanames{fr}->{3337294} = "Sarreguemines";
$areanames{fr}->{3337295} = "Briey";
$areanames{fr}->{3337296} = "Lunéville";
$areanames{fr}->{3337297} = "Pont\-à\-Mousson";
$areanames{fr}->{3337298} = "Toul";
$areanames{fr}->{3337299} = "Neufchâteau";
$areanames{fr}->{3337300} = "Nevers";
$areanames{fr}->{3337301} = "Autun";
$areanames{fr}->{3337302} = "Chalon\-sur\-Saône";
$areanames{fr}->{3337303} = "Louhans";
$areanames{fr}->{3337304} = "Mâcon";
$areanames{fr}->{3337305} = "Montceau\-les\-Mines";
$areanames{fr}->{3337306} = "Paray\-le\-Monial";
$areanames{fr}->{3337307} = "Auxerre";
$areanames{fr}->{3337308} = "Joigny";
$areanames{fr}->{3337309} = "Sens";
$areanames{fr}->{3337310} = "Tonnerre";
$areanames{fr}->{3337311} = "Toucy";
$areanames{fr}->{3337312} = "Chalon\-sur\-Saône";
$areanames{fr}->{3337313} = "Dijon";
$areanames{fr}->{3337314} = "Château\-Chinon\(Ville\)";
$areanames{fr}->{3337315} = "Decize";
$areanames{fr}->{3337316} = "Autun";
$areanames{fr}->{3337317} = "Louhans";
$areanames{fr}->{3337318} = "Mâcon";
$areanames{fr}->{3337319} = "Tonnerre";
$areanames{fr}->{3337320} = "Toucy";
$areanames{fr}->{3337321} = "Château\-Chinon\(Ville\)";
$areanames{fr}->{3337322} = "Cosne\-Cours\-sur\-Loire";
$areanames{fr}->{3337323} = "Decize";
$areanames{fr}->{3337324} = "Nevers";
$areanames{fr}->{3337325} = "Dijon";
$areanames{fr}->{3337326} = "Dijon";
$areanames{fr}->{3337327} = "Dijon";
$areanames{fr}->{3337328} = "Beaune";
$areanames{fr}->{3337329} = "Châtillon\-sur\-Seine";
$areanames{fr}->{3337330} = "Dijon";
$areanames{fr}->{3337331} = "Is\-sur\-Tille";
$areanames{fr}->{3337332} = "Montbard";
$areanames{fr}->{3337333} = "Saulieu";
$areanames{fr}->{3337334} = "Autun";
$areanames{fr}->{3337335} = "Chalon\-sur\-Saône";
$areanames{fr}->{3337336} = "Louhans";
$areanames{fr}->{3337337} = "Mâcon";
$areanames{fr}->{3337338} = "Montceau\-les\-Mines";
$areanames{fr}->{3337339} = "Paray\-le\-Monial";
$areanames{fr}->{3337340} = "Auxerre";
$areanames{fr}->{3337341} = "Joigny";
$areanames{fr}->{3337342} = "Sens";
$areanames{fr}->{3337343} = "Tonnerre";
$areanames{fr}->{3337344} = "Toucy";
$areanames{fr}->{3337345} = "Dijon";
$areanames{fr}->{3337346} = "Dijon";
$areanames{fr}->{3337347} = "Auxerre";
$areanames{fr}->{3337348} = "Chalon\-sur\-Saône";
$areanames{fr}->{3337349} = "Nevers";
$areanames{fr}->{3337350} = "Mâcon";
$areanames{fr}->{3337351} = "Sens";
$areanames{fr}->{3337352} = "Chalon\-sur\-Saône";
$areanames{fr}->{3337353} = "Auxerre";
$areanames{fr}->{3337354} = "Auxerre";
$areanames{fr}->{3337355} = "Dijon";
$areanames{fr}->{3337356} = "Sens";
$areanames{fr}->{3337357} = "Montceau\-les\-Mines";
$areanames{fr}->{3337358} = "Cosne\-Cours\-sur\-Loire";
$areanames{fr}->{3337359} = "Joigny";
$areanames{fr}->{3337360} = "Paray\-le\-Monial";
$areanames{fr}->{3337361} = "Sens";
$areanames{fr}->{3337362} = "Dijon";
$areanames{fr}->{3337363} = "Dijon";
$areanames{fr}->{3337364} = "Beaune";
$areanames{fr}->{3337365} = "Châtillon\-sur\-Seine";
$areanames{fr}->{3337366} = "Is\-sur\-Tille";
$areanames{fr}->{3337367} = "Montbard";
$areanames{fr}->{3337368} = "Saulieu";
$areanames{fr}->{3337369} = "Château\-Chinon\(Ville\)";
$areanames{fr}->{3337370} = "Decize";
$areanames{fr}->{3337371} = "Autun";
$areanames{fr}->{3337372} = "Chalon\-sur\-Saône";
$areanames{fr}->{3337373} = "Dijon";
$areanames{fr}->{3337374} = "Auxerre";
$areanames{fr}->{3337375} = "Dijon";
$areanames{fr}->{3337376} = "Beaune";
$areanames{fr}->{3337377} = "Mâcon";
$areanames{fr}->{3337378} = "Châtillon\-sur\-Seine";
$areanames{fr}->{3337379} = "Is\-sur\-Tille";
$areanames{fr}->{3337380} = "Chalon\-sur\-Saône";
$areanames{fr}->{3337381} = "Chalon\-sur\-Saône";
$areanames{fr}->{3337382} = "Paray\-le\-Monial";
$areanames{fr}->{3337383} = "Mâcon";
$areanames{fr}->{3337384} = "Dijon";
$areanames{fr}->{3337385} = "Dijon";
$areanames{fr}->{3337386} = "Montbard";
$areanames{fr}->{3337387} = "Saulieu";
$areanames{fr}->{3337388} = "Dijon";
$areanames{fr}->{3337389} = "Sens";
$areanames{fr}->{3337390} = "Louhans";
$areanames{fr}->{3337391} = "Tonnerre";
$areanames{fr}->{3337392} = "Toucy";
$areanames{fr}->{3337393} = "Nevers";
$areanames{fr}->{3337394} = "Château\-Chinon\(Ville\)";
$areanames{fr}->{3337395} = "Cosne\-Cours\-sur\-Loire";
$areanames{fr}->{3337396} = "Decize";
$areanames{fr}->{3337397} = "Nevers";
$areanames{fr}->{3337398} = "Chalon\-sur\-Saône";
$areanames{fr}->{3337399} = "Chalon\-sur\-Saône";
$areanames{fr}->{3337400} = "Lille";
$areanames{fr}->{3337401} = "Valenciennes";
$areanames{fr}->{3337402} = "Lille";
$areanames{fr}->{3337403} = "Béthune";
$areanames{fr}->{3337404} = "Arras";
$areanames{fr}->{3337405} = "Béthune";
$areanames{fr}->{3337406} = "Dunkerque";
$areanames{fr}->{3337407} = "Lille";
$areanames{fr}->{3337408} = "Lille";
$areanames{fr}->{3337409} = "Lille";
$areanames{fr}->{3337410} = "Calais";
$areanames{fr}->{3337411} = "Lille";
$areanames{fr}->{3337412} = "Calais";
$areanames{fr}->{3337413} = "Dunkerque";
$areanames{fr}->{3337414} = "Lens";
$areanames{fr}->{3337415} = "Valenciennes";
$areanames{fr}->{3337416} = "Douai";
$areanames{fr}->{3337417} = "Arras";
$areanames{fr}->{3337418} = "Saint\-Omer";
$areanames{fr}->{3337419} = "Hazebrouck";
$areanames{fr}->{3337420} = "Montreuil";
$areanames{fr}->{3337421} = "Saint\-Pol\-sur\-Ternoise";
$areanames{fr}->{3337422} = "Douai";
$areanames{fr}->{3337423} = "Lille";
$areanames{fr}->{3337424} = "Lens";
$areanames{fr}->{3337425} = "Calais";
$areanames{fr}->{3337426} = "Lille";
$areanames{fr}->{3337427} = "Lille";
$areanames{fr}->{3337428} = "Lille";
$areanames{fr}->{3337429} = "Lille";
$areanames{fr}->{3337430} = "Dunkerque";
$areanames{fr}->{3337431} = "Dunkerque";
$areanames{fr}->{3337432} = "Lille";
$areanames{fr}->{3337433} = "Hazebrouck";
$areanames{fr}->{3337434} = "Maubeuge";
$areanames{fr}->{3337435} = "Béthune";
$areanames{fr}->{3337436} = "Montreuil";
$areanames{fr}->{3337437} = "Saint\-Omer";
$areanames{fr}->{3337438} = "Saint\-Pol\-sur\-Ternoise";
$areanames{fr}->{3337439} = "Arras";
$areanames{fr}->{333744} = "Lille";
$areanames{fr}->{3337440} = "Valenciennes";
$areanames{fr}->{3337441} = "Arras";
$areanames{fr}->{3337442} = "Maubeuge";
$areanames{fr}->{3337443} = "Arras";
$areanames{fr}->{3337450} = "Lille";
$areanames{fr}->{3337451} = "Cambrai";
$areanames{fr}->{3337452} = "Douai";
$areanames{fr}->{3337453} = "Dunkerque";
$areanames{fr}->{3337454} = "Hazebrouck";
$areanames{fr}->{3337455} = "Le\ Cateau\-Cambresis";
$areanames{fr}->{3337456} = "Lille";
$areanames{fr}->{3337457} = "Maubeuge";
$areanames{fr}->{3337458} = "Valenciennes";
$areanames{fr}->{3337459} = "Arras";
$areanames{fr}->{3337460} = "Béthune";
$areanames{fr}->{3337461} = "Calais";
$areanames{fr}->{3337462} = "Lens";
$areanames{fr}->{3337463} = "Montreuil";
$areanames{fr}->{3337464} = "Saint\-Omer";
$areanames{fr}->{3337465} = "Saint\-Pol\-sur\-Ternoise";
$areanames{fr}->{3337466} = "Lille";
$areanames{fr}->{3337467} = "Lille";
$areanames{fr}->{3337468} = "Lille";
$areanames{fr}->{3337469} = "Lille";
$areanames{fr}->{3337470} = "Douai";
$areanames{fr}->{3337471} = "Lens";
$areanames{fr}->{3337472} = "Lille";
$areanames{fr}->{3337473} = "Calais";
$areanames{fr}->{3337474} = "Lille";
$areanames{fr}->{3337475} = "Valenciennes";
$areanames{fr}->{3337476} = "Lille";
$areanames{fr}->{3337477} = "Le\ Cateau\-Cambresis";
$areanames{fr}->{3337478} = "Cambrai";
$areanames{fr}->{3337479} = "Calais";
$areanames{fr}->{3337480} = "Dunkerque";
$areanames{fr}->{3337481} = "Hazebrouck";
$areanames{fr}->{3337482} = "Lille";
$areanames{fr}->{3337483} = "Lens";
$areanames{fr}->{3337484} = "Lille";
$areanames{fr}->{3337485} = "Lille";
$areanames{fr}->{3337486} = "Cambrai";
$areanames{fr}->{3337487} = "Le\ Cateau\-Cambresis";
$areanames{fr}->{3337488} = "Douai";
$areanames{fr}->{3337489} = "Dunkerque";
$areanames{fr}->{3337490} = "Hazebrouck";
$areanames{fr}->{3337491} = "Lille";
$areanames{fr}->{3337492} = "Maubeuge";
$areanames{fr}->{3337493} = "Valenciennes";
$areanames{fr}->{3337494} = "Saint\-Pol\-sur\-Ternoise";
$areanames{fr}->{3337495} = "Lille";
$areanames{fr}->{3337496} = "Calais";
$areanames{fr}->{3337497} = "Cambrai";
$areanames{fr}->{3337498} = "Le\ Cateau\-Cambresis";
$areanames{fr}->{3337499} = "Lille";
$areanames{fr}->{3337500} = "Amiens";
$areanames{fr}->{3337501} = "Soissons";
$areanames{fr}->{3337502} = "Laon";
$areanames{fr}->{3337503} = "Péronne";
$areanames{fr}->{3337504} = "Chauny";
$areanames{fr}->{3337505} = "Château\-Thierry";
$areanames{fr}->{3337506} = "Abbeville";
$areanames{fr}->{3337507} = "Albert";
$areanames{fr}->{3337508} = "Amiens";
$areanames{fr}->{3337509} = "Péronne";
$areanames{fr}->{3337510} = "Hirson";
$areanames{fr}->{3337511} = "Clermont";
$areanames{fr}->{3337512} = "Crépy\-en\-Valois";
$areanames{fr}->{3337513} = "Albert";
$areanames{fr}->{3337514} = "Amiens";
$areanames{fr}->{3337515} = "Beauvais";
$areanames{fr}->{3337516} = "Abbeville";
$areanames{fr}->{3337517} = "Beauvais";
$areanames{fr}->{3337518} = "Soissons";
$areanames{fr}->{3337519} = "Creil";
$areanames{fr}->{3337520} = "Albert";
$areanames{fr}->{3337521} = "Saint\-Quentin";
$areanames{fr}->{3337522} = "Château\-Thierry";
$areanames{fr}->{3337523} = "Amiens";
$areanames{fr}->{3337524} = "Compiègne";
$areanames{fr}->{3337525} = "Beauvais";
$areanames{fr}->{3337526} = "Saint\-Quentin";
$areanames{fr}->{3337527} = "Crépy\-en\-Valois";
$areanames{fr}->{3337528} = "Creil";
$areanames{fr}->{3337529} = "Creil";
$areanames{fr}->{3337530} = "Chauny";
$areanames{fr}->{3337531} = "Hirson";
$areanames{fr}->{3337532} = "Laon";
$areanames{fr}->{3337533} = "Soissons";
$areanames{fr}->{3337534} = "Clermont";
$areanames{fr}->{3337535} = "Creil";
$areanames{fr}->{3337536} = "Crépy\-en\-Valois";
$areanames{fr}->{3337537} = "Abbeville";
$areanames{fr}->{3337538} = "Albert";
$areanames{fr}->{3337539} = "Péronne";
$areanames{fr}->{3337540} = "Amiens";
$areanames{fr}->{3337541} = "Beauvais";
$areanames{fr}->{3337542} = "Laon";
$areanames{fr}->{3337543} = "Saint\-Quentin";
$areanames{fr}->{3337544} = "Amiens";
$areanames{fr}->{3337545} = "Compiègne";
$areanames{fr}->{3337546} = "Compiègne";
$areanames{fr}->{3337547} = "Amiens";
$areanames{fr}->{3337548} = "Péronne";
$areanames{fr}->{3337549} = "Château\-Thierry";
$areanames{fr}->{3337550} = "Amiens";
$areanames{fr}->{3337551} = "Château\-Thierry";
$areanames{fr}->{3337552} = "Chauny";
$areanames{fr}->{3337553} = "Hirson";
$areanames{fr}->{3337554} = "Laon";
$areanames{fr}->{3337555} = "Saint\-Quentin";
$areanames{fr}->{3337556} = "Soissons";
$areanames{fr}->{3337557} = "Beauvais";
$areanames{fr}->{3337558} = "Clermont";
$areanames{fr}->{3337559} = "Compiègne";
$areanames{fr}->{3337560} = "Creil";
$areanames{fr}->{3337561} = "Crépy\-en\-Valois";
$areanames{fr}->{3337562} = "Abbeville";
$areanames{fr}->{3337563} = "Albert";
$areanames{fr}->{3337564} = "Amiens";
$areanames{fr}->{3337565} = "Péronne";
$areanames{fr}->{3337566} = "Saint\-Quentin";
$areanames{fr}->{3337567} = "Beauvais";
$areanames{fr}->{3337568} = "Abbeville";
$areanames{fr}->{3337569} = "Amiens";
$areanames{fr}->{3337570} = "Château\-Thierry";
$areanames{fr}->{3337571} = "Saint\-Quentin";
$areanames{fr}->{3337600} = "Lille";
$areanames{fr}->{3337601} = "Lille";
$areanames{fr}->{3337602} = "Lens";
$areanames{fr}->{3337603} = "Saint\-Omer";
$areanames{fr}->{3337604} = "Lille";
$areanames{fr}->{3337605} = "Lille";
$areanames{fr}->{3337606} = "Lens";
$areanames{fr}->{3337900} = "Autun";
$areanames{fr}->{3337901} = "Louhans";
$areanames{fr}->{3337902} = "Montceau\-les\-Mines";
$areanames{fr}->{3337903} = "Paray\-le\-Monial";
$areanames{fr}->{3337904} = "Auxerre";
$areanames{fr}->{3337905} = "Joigny";
$areanames{fr}->{3337906} = "Tonnerre";
$areanames{fr}->{3337907} = "Toucy";
$areanames{fr}->{3337908} = "Auxerre";
$areanames{fr}->{3337909} = "Nevers";
$areanames{fr}->{3337910} = "Dijon";
$areanames{fr}->{3337911} = "Beaune";
$areanames{fr}->{3337912} = "Châtillon\-sur\-Seine";
$areanames{fr}->{3337913} = "Dijon";
$areanames{fr}->{3337914} = "Is\-sur\-Tille";
$areanames{fr}->{3337915} = "Montbard";
$areanames{fr}->{3337916} = "Saulieu";
$areanames{fr}->{3337917} = "Château\-Chinon\(Ville\)";
$areanames{fr}->{3337918} = "Cosne\-Cours\-sur\-Loire";
$areanames{fr}->{3337919} = "Decize";
$areanames{fr}->{3337920} = "Nevers";
$areanames{fr}->{3337921} = "Autun";
$areanames{fr}->{3337922} = "Chalon\-sur\-Saône";
$areanames{fr}->{3337923} = "Louhans";
$areanames{fr}->{3337924} = "Mâcon";
$areanames{fr}->{3337925} = "Montceau\-les\-Mines";
$areanames{fr}->{3337926} = "Paray\-le\-Monial";
$areanames{fr}->{3337927} = "Auxerre";
$areanames{fr}->{3337928} = "Joigny";
$areanames{fr}->{3337929} = "Sens";
$areanames{fr}->{3337930} = "Tonnerre";
$areanames{fr}->{3337931} = "Toucy";
$areanames{fr}->{3337932} = "Nevers";
$areanames{fr}->{3337933} = "Dijon";
$areanames{fr}->{3337934} = "Chalon\-sur\-Saône";
$areanames{fr}->{3337935} = "Mâcon";
$areanames{fr}->{3337936} = "Dijon";
$areanames{fr}->{3337937} = "Mâcon";
$areanames{fr}->{3337938} = "Chalon\-sur\-Saône";
$areanames{fr}->{3337939} = "Autun";
$areanames{fr}->{3337940} = "Louhans";
$areanames{fr}->{3337941} = "Mâcon";
$areanames{fr}->{3337942} = "Mâcon";
$areanames{fr}->{3337943} = "Montceau\-les\-Mines";
$areanames{fr}->{3337944} = "Dijon";
$areanames{fr}->{333800} = "Nord\ Est";
$areanames{fr}->{3338009} = "Dijon";
$areanames{fr}->{3338010} = "Dijon";
$areanames{fr}->{3338022} = "Beaune";
$areanames{fr}->{3338024} = "Beaune";
$areanames{fr}->{3338025} = "Beaune";
$areanames{fr}->{3338027} = "Auxonne";
$areanames{fr}->{3338028} = "Dijon";
$areanames{fr}->{3338029} = "Brazey\-en\-Plaine";
$areanames{fr}->{3338030} = "Dijon";
$areanames{fr}->{3338031} = "Auxonne";
$areanames{fr}->{3338032} = "Brazey\-en\-Plaine";
$areanames{fr}->{3338034} = "Gevrey\-Chambertin";
$areanames{fr}->{3338037} = "Auxonne";
$areanames{fr}->{3338038} = "Dijon";
$areanames{fr}->{3338041} = "Dijon";
$areanames{fr}->{3338042} = "Dijon";
$areanames{fr}->{3338043} = "Dijon";
$areanames{fr}->{3338044} = "Dijon";
$areanames{fr}->{3338045} = "Dijon";
$areanames{fr}->{3338046} = "Quetigny";
$areanames{fr}->{3338048} = "Quetigny";
$areanames{fr}->{3338049} = "Dijon";
$areanames{fr}->{333805} = "Dijon";
$areanames{fr}->{3338051} = "Chenôve";
$areanames{fr}->{3338052} = "Chenôve";
$areanames{fr}->{3338056} = "Fontaine\-lès\-Dijon";
$areanames{fr}->{3338057} = "Talant";
$areanames{fr}->{3338060} = "Dijon";
$areanames{fr}->{3338061} = "Nuits\-Saint\-Georges";
$areanames{fr}->{3338062} = "Nuits\-Saint\-Georges";
$areanames{fr}->{3338063} = "Dijon";
$areanames{fr}->{3338064} = "Saulieu";
$areanames{fr}->{3338065} = "Dijon";
$areanames{fr}->{3338066} = "Dijon";
$areanames{fr}->{3338067} = "Dijon";
$areanames{fr}->{3338068} = "Dijon";
$areanames{fr}->{333807} = "Dijon";
$areanames{fr}->{3338075} = "Is\-sur\-Tille";
$areanames{fr}->{3338089} = "Montbard";
$areanames{fr}->{3338090} = "Pouilly\-en\-Auxois";
$areanames{fr}->{3338091} = "Châtillon\-sur\-Seine";
$areanames{fr}->{3338092} = "Montbard";
$areanames{fr}->{3338095} = "Is\-sur\-Tille";
$areanames{fr}->{3338097} = "Semur\-en\-Auxois";
$areanames{fr}->{333810} = "Nord\ Est";
$areanames{fr}->{3338102} = "Montbéliard";
$areanames{fr}->{333811} = "Nord\ Est";
$areanames{fr}->{3338121} = "Besançon";
$areanames{fr}->{3338125} = "Besançon";
$areanames{fr}->{3338130} = "Audincourt";
$areanames{fr}->{3338131} = "Montbéliard";
$areanames{fr}->{3338132} = "Montbéliard";
$areanames{fr}->{3338134} = "Audincourt";
$areanames{fr}->{3338135} = "Audincourt";
$areanames{fr}->{3338136} = "Audincourt";
$areanames{fr}->{3338137} = "Valentigney";
$areanames{fr}->{3338138} = "Pontarlier";
$areanames{fr}->{3338139} = "Pontarlier";
$areanames{fr}->{3338140} = "Besançon";
$areanames{fr}->{3338141} = "Besançon";
$areanames{fr}->{3338146} = "Pontarlier";
$areanames{fr}->{3338147} = "Besançon";
$areanames{fr}->{3338148} = "Besançon";
$areanames{fr}->{3338150} = "Besançon";
$areanames{fr}->{3338151} = "Besançon";
$areanames{fr}->{3338152} = "Besançon";
$areanames{fr}->{3338153} = "Besançon";
$areanames{fr}->{3338156} = "Valdahon";
$areanames{fr}->{3338161} = "Besançon";
$areanames{fr}->{3338162} = "Ornans";
$areanames{fr}->{3338164} = "Maîche";
$areanames{fr}->{3338165} = "Besançon";
$areanames{fr}->{3338167} = "Morteau";
$areanames{fr}->{3338168} = "Villers\-le\-Lac";
$areanames{fr}->{333817} = "Nord\ Est";
$areanames{fr}->{3338170} = "Morteau";
$areanames{fr}->{3338171} = "Montbéliard";
$areanames{fr}->{3338172} = "Montbéliard";
$areanames{fr}->{3338180} = "Besançon";
$areanames{fr}->{3338181} = "Besançon";
$areanames{fr}->{3338182} = "Besançon";
$areanames{fr}->{3338183} = "Besançon";
$areanames{fr}->{3338184} = "Baume\-les\-Dames";
$areanames{fr}->{3338185} = "Besançon";
$areanames{fr}->{3338187} = "Saint\-Vit";
$areanames{fr}->{3338188} = "Besançon";
$areanames{fr}->{3338190} = "Montbéliard";
$areanames{fr}->{3338191} = "Montbéliard";
$areanames{fr}->{3338192} = "Pont\-de\-Roide";
$areanames{fr}->{3338194} = "Montbéliard";
$areanames{fr}->{3338195} = "Montbéliard";
$areanames{fr}->{3338197} = "Montbéliard";
$areanames{fr}->{3338198} = "Montbéliard";
$areanames{fr}->{3338199} = "Montbéliard";
$areanames{fr}->{333820} = "Nord\ Est";
$areanames{fr}->{333821} = "Nord\ Est";
$areanames{fr}->{3338210} = "Thionville";
$areanames{fr}->{3338211} = "Thionville";
$areanames{fr}->{3338212} = "Thionville";
$areanames{fr}->{3338222} = "Jœuf";
$areanames{fr}->{3338223} = "Longwy";
$areanames{fr}->{3338224} = "Longwy";
$areanames{fr}->{3338225} = "Longwy";
$areanames{fr}->{3338226} = "Longuyon";
$areanames{fr}->{3338233} = "Jarny";
$areanames{fr}->{3338234} = "Thionville";
$areanames{fr}->{3338239} = "Longuyon";
$areanames{fr}->{3338246} = "Briey";
$areanames{fr}->{3338251} = "Thionville";
$areanames{fr}->{3338252} = "Audun\-le\-Tiche";
$areanames{fr}->{3338253} = "Thionville";
$areanames{fr}->{3338254} = "Thionville";
$areanames{fr}->{3338255} = "Cattenom";
$areanames{fr}->{3338256} = "Yutz";
$areanames{fr}->{3338257} = "Florange";
$areanames{fr}->{3338258} = "Florange";
$areanames{fr}->{3338259} = "Thionville";
$areanames{fr}->{333826} = "Nord\ Est";
$areanames{fr}->{333827} = "Nord\ Est";
$areanames{fr}->{3338282} = "Thionville";
$areanames{fr}->{3338284} = "Hayange";
$areanames{fr}->{3338285} = "Hayange";
$areanames{fr}->{3338286} = "Uckange";
$areanames{fr}->{3338288} = "Thionville";
$areanames{fr}->{3338289} = "Villerupt";
$areanames{fr}->{3338291} = "Aumetz";
$areanames{fr}->{333830} = "Nord\ Est";
$areanames{fr}->{3338304} = "Nancy";
$areanames{fr}->{3338307} = "Nancy";
$areanames{fr}->{3338315} = "Ludres";
$areanames{fr}->{3338317} = "Nancy";
$areanames{fr}->{3338318} = "Nancy";
$areanames{fr}->{3338319} = "Nancy";
$areanames{fr}->{3338322} = "Bouxières\-aux\-Dames";
$areanames{fr}->{3338323} = "Velaine\-en\-Haye";
$areanames{fr}->{3338324} = "Liverdun";
$areanames{fr}->{3338325} = "Ludres";
$areanames{fr}->{3338327} = "Nancy";
$areanames{fr}->{3338328} = "Nancy";
$areanames{fr}->{3338330} = "Nancy";
$areanames{fr}->{3338332} = "Nancy";
$areanames{fr}->{3338333} = "Nancy";
$areanames{fr}->{3338335} = "Nancy";
$areanames{fr}->{3338336} = "Nancy";
$areanames{fr}->{3338337} = "Nancy";
$areanames{fr}->{3338338} = "Champigneulles";
$areanames{fr}->{3338339} = "Nancy";
$areanames{fr}->{3338340} = "Nancy";
$areanames{fr}->{3338341} = "Nancy";
$areanames{fr}->{3338343} = "Toul";
$areanames{fr}->{3338344} = "Vandœuvre\-lès\-Nancy";
$areanames{fr}->{3338345} = "Dombasle\-sur\-Meurthe";
$areanames{fr}->{3338347} = "Neuves\-Maisons";
$areanames{fr}->{3338348} = "Dombasle\-sur\-Meurthe";
$areanames{fr}->{3338349} = "Pompey";
$areanames{fr}->{333835} = "Vandœuvre\-lès\-Nancy";
$areanames{fr}->{3338363} = "Toul";
$areanames{fr}->{3338364} = "Toul";
$areanames{fr}->{3338367} = "Nancy";
$areanames{fr}->{3338373} = "Lunéville";
$areanames{fr}->{3338374} = "Lunéville";
$areanames{fr}->{3338375} = "Baccarat";
$areanames{fr}->{3338376} = "Lunéville";
$areanames{fr}->{3338380} = "Pont\-à\-Mousson";
$areanames{fr}->{3338381} = "Pont\-à\-Mousson";
$areanames{fr}->{3338382} = "Pont\-à\-Mousson";
$areanames{fr}->{3338383} = "Pont\-à\-Mousson";
$areanames{fr}->{3338384} = "Pont\-à\-Mousson";
$areanames{fr}->{3338385} = "Nancy";
$areanames{fr}->{3338389} = "Lunéville";
$areanames{fr}->{333839} = "Nancy";
$areanames{fr}->{3338399} = "Nord\ Est";
$areanames{fr}->{333840} = "Nord\ Est";
$areanames{fr}->{333841} = "Nord\ Est";
$areanames{fr}->{3338419} = "Belfort";
$areanames{fr}->{3338421} = "Belfort";
$areanames{fr}->{3338422} = "Belfort";
$areanames{fr}->{3338424} = "Lons\-le\-Saunier";
$areanames{fr}->{3338426} = "Belfort";
$areanames{fr}->{3338428} = "Belfort";
$areanames{fr}->{3338430} = "Lure";
$areanames{fr}->{3338433} = "Morez";
$areanames{fr}->{3338436} = "Delle";
$areanames{fr}->{3338437} = "Poligny";
$areanames{fr}->{3338440} = "Luxeuil\-les\-Bains";
$areanames{fr}->{3338442} = "Moirans\-en\-Montagne";
$areanames{fr}->{3338443} = "Lons\-le\-Saunier";
$areanames{fr}->{3338445} = "Saint\-Claude";
$areanames{fr}->{3338446} = "Héricourt";
$areanames{fr}->{3338447} = "Lons\-le\-Saunier";
$areanames{fr}->{3338449} = "Fougerolles";
$areanames{fr}->{3338452} = "Champagnole";
$areanames{fr}->{3338454} = "Belfort";
$areanames{fr}->{3338456} = "Beaucourt";
$areanames{fr}->{3338457} = "Belfort";
$areanames{fr}->{3338458} = "Belfort";
$areanames{fr}->{3338460} = "Les\ Rousses";
$areanames{fr}->{3338462} = "Lure";
$areanames{fr}->{3338464} = "Gray";
$areanames{fr}->{3338465} = "Gray";
$areanames{fr}->{3338466} = "Arbois";
$areanames{fr}->{3338469} = "Dole";
$areanames{fr}->{3338472} = "Dole";
$areanames{fr}->{3338473} = "Salins\-les\-Bains";
$areanames{fr}->{3338474} = "Mollans";
$areanames{fr}->{3338475} = "Vesoul";
$areanames{fr}->{3338476} = "Vesoul";
$areanames{fr}->{3338479} = "Dole";
$areanames{fr}->{3338482} = "Dole";
$areanames{fr}->{3338486} = "Lons\-le\-Saunier";
$areanames{fr}->{3338487} = "Lons\-le\-Saunier";
$areanames{fr}->{3338490} = "Belfort";
$areanames{fr}->{3338493} = "Luxeuil\-les\-Bains";
$areanames{fr}->{3338495} = "Saulx";
$areanames{fr}->{3338496} = "Vesoul";
$areanames{fr}->{3338497} = "Vesoul";
$areanames{fr}->{333850} = "Nord\ Est";
$areanames{fr}->{333851} = "Nord\ Est";
$areanames{fr}->{3338520} = "Mâcon";
$areanames{fr}->{3338521} = "Mâcon";
$areanames{fr}->{3338522} = "Mâcon";
$areanames{fr}->{3338525} = "Marcigny";
$areanames{fr}->{3338526} = "Chauffailles";
$areanames{fr}->{3338528} = "La\ Clayette";
$areanames{fr}->{3338529} = "Mâcon";
$areanames{fr}->{3338531} = "Replonges";
$areanames{fr}->{3338532} = "Tournus";
$areanames{fr}->{3338534} = "Mâcon";
$areanames{fr}->{3338538} = "Mâcon";
$areanames{fr}->{3338539} = "Mâcon";
$areanames{fr}->{333854} = "Chalon\-sur\-Saône";
$areanames{fr}->{3338540} = "Mâcon";
$areanames{fr}->{3338551} = "Tournus";
$areanames{fr}->{3338552} = "Autun";
$areanames{fr}->{3338553} = "Digoin";
$areanames{fr}->{3338555} = "Le\ Creusot";
$areanames{fr}->{3338556} = "Le\ Creusot";
$areanames{fr}->{3338557} = "Montceau\-les\-Mines";
$areanames{fr}->{3338558} = "Montceau\-les\-Mines";
$areanames{fr}->{3338559} = "Cluny";
$areanames{fr}->{3338567} = "Montceau\-les\-Mines";
$areanames{fr}->{3338568} = "Blanzy";
$areanames{fr}->{3338569} = "Montceau\-les\-Mines";
$areanames{fr}->{3338573} = "Le\ Creusot";
$areanames{fr}->{3338575} = "Louhans";
$areanames{fr}->{3338577} = "Le\ Creusot";
$areanames{fr}->{3338578} = "Montchanin";
$areanames{fr}->{3338580} = "Le\ Creusot";
$areanames{fr}->{3338581} = "Paray\-le\-Monial";
$areanames{fr}->{3338585} = "Gueugnon";
$areanames{fr}->{3338586} = "Autun";
$areanames{fr}->{3338587} = "Chagny";
$areanames{fr}->{3338588} = "Digoin";
$areanames{fr}->{3338589} = "Bourbon\-Lancy";
$areanames{fr}->{3338590} = "Chalon\-sur\-Saône";
$areanames{fr}->{3338592} = "Buxy";
$areanames{fr}->{3338593} = "Chalon\-sur\-Saône";
$areanames{fr}->{3338594} = "Chalon\-sur\-Saône";
$areanames{fr}->{3338597} = "Chalon\-sur\-Saône";
$areanames{fr}->{3338598} = "Châtenoy\-le\-Royal";
$areanames{fr}->{333860} = "Nord\ Est";
$areanames{fr}->{3338618} = "Auxerre";
$areanames{fr}->{3338620} = "Corbigny";
$areanames{fr}->{3338621} = "Nevers";
$areanames{fr}->{3338622} = "Lormes";
$areanames{fr}->{3338623} = "Nevers";
$areanames{fr}->{3338624} = "Clamecy";
$areanames{fr}->{3338625} = "Decize";
$areanames{fr}->{3338626} = "Cosne\-Cours\-sur\-Loire";
$areanames{fr}->{3338627} = "Clamecy";
$areanames{fr}->{3338628} = "Cosne\-Cours\-sur\-Loire";
$areanames{fr}->{3338630} = "Luzy";
$areanames{fr}->{3338631} = "Avallon";
$areanames{fr}->{3338634} = "Avallon";
$areanames{fr}->{3338635} = "Saint\-Florentin";
$areanames{fr}->{3338636} = "Nevers";
$areanames{fr}->{3338639} = "Pouilly\-sur\-Loire";
$areanames{fr}->{3338640} = "Monéteau";
$areanames{fr}->{3338642} = "Chablis";
$areanames{fr}->{3338643} = "Saint\-Florentin";
$areanames{fr}->{3338644} = "Toucy";
$areanames{fr}->{3338646} = "Auxerre";
$areanames{fr}->{3338648} = "Auxerre";
$areanames{fr}->{3338649} = "Auxerre";
$areanames{fr}->{3338651} = "Auxerre";
$areanames{fr}->{3338652} = "Auxerre";
$areanames{fr}->{3338653} = "Appoigny";
$areanames{fr}->{3338654} = "Tonnerre";
$areanames{fr}->{3338655} = "Tonnerre";
$areanames{fr}->{3338656} = "Brienon\-sur\-Armançon";
$areanames{fr}->{3338657} = "Nevers";
$areanames{fr}->{3338659} = "Nevers";
$areanames{fr}->{3338661} = "Nevers";
$areanames{fr}->{3338662} = "Joigny";
$areanames{fr}->{3338664} = "Sens";
$areanames{fr}->{3338665} = "Sens";
$areanames{fr}->{3338666} = "Villeneuve\-la\-Guyard";
$areanames{fr}->{3338667} = "Pont\-sur\-Yonne";
$areanames{fr}->{3338668} = "Prémery";
$areanames{fr}->{3338670} = "La\ Charité\ sur\ Loire";
$areanames{fr}->{3338671} = "Nevers";
$areanames{fr}->{3338672} = "Auxerre";
$areanames{fr}->{3338676} = "Moux\-en\-Morvan";
$areanames{fr}->{3338677} = "Decize";
$areanames{fr}->{3338680} = "Migennes";
$areanames{fr}->{3338681} = "Vermenton";
$areanames{fr}->{3338682} = "Noyers\ sur\ Serein";
$areanames{fr}->{3338683} = "Sens";
$areanames{fr}->{3338685} = "Château\-Chinon\(Ville\)";
$areanames{fr}->{3338687} = "Villeneuve\-sur\-Yonne";
$areanames{fr}->{3338692} = "Migennes";
$areanames{fr}->{3338693} = "Nevers";
$areanames{fr}->{3338694} = "Auxerre";
$areanames{fr}->{3338695} = "Sens";
$areanames{fr}->{3338703} = "Sarrebourg";
$areanames{fr}->{3338704} = "Freyming\-Merlebach";
$areanames{fr}->{3338705} = "Château\-Salins";
$areanames{fr}->{3338706} = "Bitche";
$areanames{fr}->{3338713} = "Forbach";
$areanames{fr}->{3338715} = "Metz";
$areanames{fr}->{3338716} = "Metz";
$areanames{fr}->{3338717} = "Metz";
$areanames{fr}->{3338718} = "Metz";
$areanames{fr}->{3338720} = "Metz";
$areanames{fr}->{3338721} = "Metz";
$areanames{fr}->{3338723} = "Sarrebourg";
$areanames{fr}->{3338724} = "Phalsbourg";
$areanames{fr}->{3338727} = "Sarreguemines";
$areanames{fr}->{3338728} = "Sarreguemines";
$areanames{fr}->{3338729} = "Saint\-Avold";
$areanames{fr}->{333873} = "Metz";
$areanames{fr}->{3338738} = "Augny";
$areanames{fr}->{333874} = "Nord\ Est";
$areanames{fr}->{3338740} = "Metz";
$areanames{fr}->{3338741} = "Morhange";
$areanames{fr}->{3338743} = "Saint\-Avold";
$areanames{fr}->{3338749} = "Metz";
$areanames{fr}->{3338750} = "Metz";
$areanames{fr}->{3338751} = "Maizières\-lès\-Metz";
$areanames{fr}->{3338753} = "Amanvillers";
$areanames{fr}->{3338755} = "Metz";
$areanames{fr}->{3338756} = "Metz";
$areanames{fr}->{3338758} = "Moyeuvre\-Grande";
$areanames{fr}->{3338760} = "Ars\-sur\-Moselle";
$areanames{fr}->{3338761} = "Sainte\-Marie\-aux\-Chênes";
$areanames{fr}->{3338762} = "Metz";
$areanames{fr}->{3338763} = "Metz";
$areanames{fr}->{3338765} = "Metz";
$areanames{fr}->{3338766} = "Metz";
$areanames{fr}->{3338767} = "Rombas";
$areanames{fr}->{3338768} = "Metz";
$areanames{fr}->{3338769} = "Metz";
$areanames{fr}->{3338770} = "Hagondange";
$areanames{fr}->{3338771} = "Hagondange";
$areanames{fr}->{3338772} = "Hagondange";
$areanames{fr}->{3338773} = "Ennery";
$areanames{fr}->{3338774} = "Metz";
$areanames{fr}->{3338775} = "Metz";
$areanames{fr}->{3338776} = "Metz";
$areanames{fr}->{3338777} = "Vigy";
$areanames{fr}->{3338778} = "Bouzonville";
$areanames{fr}->{3338779} = "Boulay\-Moselle";
$areanames{fr}->{3338780} = "Maizières\-lès\-Metz";
$areanames{fr}->{3338781} = "Freyming\-Merlebach";
$areanames{fr}->{3338782} = "Creutzwald";
$areanames{fr}->{3338784} = "Forbach";
$areanames{fr}->{3338785} = "Forbach";
$areanames{fr}->{3338787} = "Forbach";
$areanames{fr}->{3338788} = "Forbach";
$areanames{fr}->{3338789} = "Farébersviller";
$areanames{fr}->{3338791} = "Saint\-Avold";
$areanames{fr}->{3338792} = "Saint\-Avold";
$areanames{fr}->{3338793} = "Creutzwald";
$areanames{fr}->{3338794} = "Faulquemont";
$areanames{fr}->{3338795} = "Sarreguemines";
$areanames{fr}->{3338796} = "Bitche";
$areanames{fr}->{3338797} = "Sarralbe";
$areanames{fr}->{3338798} = "Sarreguemines";
$areanames{fr}->{3338802} = "Saverne";
$areanames{fr}->{3338803} = "Saverne";
$areanames{fr}->{3338805} = "Haguenau";
$areanames{fr}->{3338806} = "Haguenau";
$areanames{fr}->{3338808} = "Barr";
$areanames{fr}->{3338809} = "Niederbronn\-les\-Bains";
$areanames{fr}->{3338810} = "Strasbourg";
$areanames{fr}->{3338812} = "Strasbourg";
$areanames{fr}->{3338813} = "Strasbourg";
$areanames{fr}->{3338814} = "Strasbourg";
$areanames{fr}->{3338815} = "Strasbourg";
$areanames{fr}->{3338816} = "Strasbourg";
$areanames{fr}->{3338818} = "Schiltigheim";
$areanames{fr}->{3338819} = "Schiltigheim";
$areanames{fr}->{333882} = "Strasbourg";
$areanames{fr}->{3338820} = "Souffelweyersheim";
$areanames{fr}->{333883} = "Strasbourg";
$areanames{fr}->{3338833} = "Schiltigheim";
$areanames{fr}->{3338838} = "Molsheim";
$areanames{fr}->{333884} = "Strasbourg";
$areanames{fr}->{3338846} = "Nord\ Est";
$areanames{fr}->{3338851} = "Brumath";
$areanames{fr}->{3338852} = "Strasbourg";
$areanames{fr}->{3338853} = "Drusenheim";
$areanames{fr}->{3338854} = "Betschdorf";
$areanames{fr}->{3338855} = "Geispolsheim";
$areanames{fr}->{3338856} = "Oberhausbergen";
$areanames{fr}->{3338858} = "Sélestat";
$areanames{fr}->{3338860} = "Strasbourg";
$areanames{fr}->{3338861} = "Strasbourg";
$areanames{fr}->{3338862} = "Schiltigheim";
$areanames{fr}->{3338863} = "Bischwiller";
$areanames{fr}->{3338864} = "Fegersheim";
$areanames{fr}->{3338865} = "Strasbourg";
$areanames{fr}->{3338866} = "Illkirch\-Graffenstaden";
$areanames{fr}->{3338867} = "Illkirch\-Graffenstaden";
$areanames{fr}->{3338871} = "Saverne";
$areanames{fr}->{3338872} = "Schweighouse\-sur\-Moder";
$areanames{fr}->{3338873} = "Haguenau";
$areanames{fr}->{3338874} = "Benfeld";
$areanames{fr}->{3338875} = "Strasbourg";
$areanames{fr}->{3338876} = "Lingolsheim";
$areanames{fr}->{3338877} = "Lingolsheim";
$areanames{fr}->{3338878} = "Lingolsheim";
$areanames{fr}->{3338879} = "Strasbourg";
$areanames{fr}->{3338881} = "Schiltigheim";
$areanames{fr}->{3338882} = "Sélestat";
$areanames{fr}->{3338883} = "Schiltigheim";
$areanames{fr}->{3338884} = "Strasbourg";
$areanames{fr}->{3338887} = "Wasselonne";
$areanames{fr}->{3338889} = "Ingwiller";
$areanames{fr}->{3338891} = "Saverne";
$areanames{fr}->{3338892} = "Sélestat";
$areanames{fr}->{3338893} = "Haguenau";
$areanames{fr}->{3338894} = "Wissembourg";
$areanames{fr}->{3338895} = "Obernai";
$areanames{fr}->{3338898} = "Erstein";
$areanames{fr}->{3338906} = "Brunstatt";
$areanames{fr}->{3338908} = "Altkirch";
$areanames{fr}->{333891} = "Nord\ Est";
$areanames{fr}->{3338912} = "Colmar";
$areanames{fr}->{3338920} = "Colmar";
$areanames{fr}->{3338921} = "Colmar";
$areanames{fr}->{3338922} = "Sainte\-Croix\-en\-Plaine";
$areanames{fr}->{3338923} = "Colmar";
$areanames{fr}->{3338924} = "Colmar";
$areanames{fr}->{3338927} = "Wintzenheim";
$areanames{fr}->{3338929} = "Colmar";
$areanames{fr}->{3338930} = "Colmar";
$areanames{fr}->{3338931} = "Sausheim";
$areanames{fr}->{3338932} = "Mulhouse";
$areanames{fr}->{3338933} = "Mulhouse";
$areanames{fr}->{3338935} = "Mulhouse";
$areanames{fr}->{3338936} = "Mulhouse";
$areanames{fr}->{3338937} = "Thann";
$areanames{fr}->{3338939} = "Cernay";
$areanames{fr}->{3338940} = "Altkirch";
$areanames{fr}->{3338941} = "Colmar";
$areanames{fr}->{3338942} = "Mulhouse";
$areanames{fr}->{3338943} = "Mulhouse";
$areanames{fr}->{3338944} = "Mulhouse";
$areanames{fr}->{3338945} = "Mulhouse";
$areanames{fr}->{3338946} = "Mulhouse";
$areanames{fr}->{3338951} = "Wittenheim";
$areanames{fr}->{3338952} = "Wittenheim";
$areanames{fr}->{3338953} = "Wittenheim";
$areanames{fr}->{3338954} = "Mulhouse";
$areanames{fr}->{3338955} = "Wittelsheim";
$areanames{fr}->{3338956} = "Mulhouse";
$areanames{fr}->{3338958} = "Sainte\-Marie\-aux\-Mines";
$areanames{fr}->{3338959} = "Mulhouse";
$areanames{fr}->{3338960} = "Mulhouse";
$areanames{fr}->{3338961} = "Illzach";
$areanames{fr}->{3338964} = "Mulhouse";
$areanames{fr}->{3338965} = "Rixheim";
$areanames{fr}->{3338966} = "Mulhouse";
$areanames{fr}->{3338967} = "Saint\-Louis";
$areanames{fr}->{3338969} = "Saint\-Louis";
$areanames{fr}->{3338970} = "Saint\-Louis";
$areanames{fr}->{3338971} = "Orbey";
$areanames{fr}->{3338973} = "Ribeauville";
$areanames{fr}->{3338974} = "Guebwiller";
$areanames{fr}->{3338975} = "Cernay";
$areanames{fr}->{3338976} = "Guebwiller";
$areanames{fr}->{3338977} = "Munster";
$areanames{fr}->{3338978} = "Kaysersberg";
$areanames{fr}->{3338979} = "Colmar";
$areanames{fr}->{3338980} = "Colmar";
$areanames{fr}->{3338989} = "Saint\-Louis";
$areanames{fr}->{333899} = "Nord\ Est";
$areanames{fr}->{3338990} = "Altkirch";
$areanames{fr}->{3338991} = "Altkirch";
$areanames{fr}->{3338996} = "Strasbourg";
$areanames{fr}->{333900} = "Nord\ Est";
$areanames{fr}->{3339000} = "Strasbourg";
$areanames{fr}->{3339006} = "Strasbourg";
$areanames{fr}->{3339007} = "Strasbourg";
$areanames{fr}->{333901} = "Nord\ Est";
$areanames{fr}->{3339014} = "Strasbourg";
$areanames{fr}->{3339020} = "Strasbourg";
$areanames{fr}->{3339022} = "Strasbourg";
$areanames{fr}->{3339023} = "Strasbourg";
$areanames{fr}->{333903} = "Nord\ Est";
$areanames{fr}->{3339031} = "Strasbourg";
$areanames{fr}->{3339040} = "Strasbourg";
$areanames{fr}->{3339041} = "Strasbourg";
$areanames{fr}->{3339057} = "Sélestat";
$areanames{fr}->{333906} = "Nord\ Est";
$areanames{fr}->{3339060} = "Sélestat";
$areanames{fr}->{3339064} = "Strasbourg";
$areanames{fr}->{3339067} = "Strasbourg";
$areanames{fr}->{333907} = "Nord\ Est";
$areanames{fr}->{333908} = "Nord\ Est";
$areanames{fr}->{333909} = "Nord\ Est";
$areanames{fr}->{333910} = "Nord\ Est";
$areanames{fr}->{333911} = "Nord\ Est";
$areanames{fr}->{3339116} = "Montreuil";
$areanames{fr}->{3339117} = "Montreuil";
$areanames{fr}->{3339118} = "Calais";
$areanames{fr}->{3339119} = "Arras";
$areanames{fr}->{333912} = "Nord\ Est";
$areanames{fr}->{3339120} = "Arras";
$areanames{fr}->{3339121} = "Calais";
$areanames{fr}->{3339122} = "Calais";
$areanames{fr}->{333913} = "Nord\ Est";
$areanames{fr}->{333914} = "Nord\ Est";
$areanames{fr}->{333915} = "Nord\ Est";
$areanames{fr}->{333916} = "Nord\ Est";
$areanames{fr}->{333917} = "Nord\ Est";
$areanames{fr}->{3339178} = "Calais";
$areanames{fr}->{3339179} = "Béthune";
$areanames{fr}->{3339180} = "Bruay\-la\-Buissière";
$areanames{fr}->{3339183} = "Carvin";
$areanames{fr}->{3339190} = "Boulogne\-sur\-Mer";
$areanames{fr}->{3341100} = "Limoux";
$areanames{fr}->{3341101} = "Narbonne";
$areanames{fr}->{3341102} = "Ales";
$areanames{fr}->{3341103} = "Bagnols\-sur\-Ceze";
$areanames{fr}->{3341104} = "Nîmes";
$areanames{fr}->{3341105} = "Bedarieux";
$areanames{fr}->{3341106} = "Beziers";
$areanames{fr}->{3341107} = "Langogne";
$areanames{fr}->{3341108} = "Mende";
$areanames{fr}->{3341109} = "Perpignan";
$areanames{fr}->{3341110} = "Prades";
$areanames{fr}->{3341111} = "Montpellier";
$areanames{fr}->{3341112} = "Nîmes";
$areanames{fr}->{3341113} = "Perpignan";
$areanames{fr}->{3341114} = "Carcassonne";
$areanames{fr}->{3341115} = "Narbonne";
$areanames{fr}->{3341116} = "Beziers";
$areanames{fr}->{3341117} = "Bagnols\-sur\-Ceze";
$areanames{fr}->{3341118} = "Nîmes";
$areanames{fr}->{3341119} = "Montpellier";
$areanames{fr}->{3341120} = "Carcassonne";
$areanames{fr}->{3341121} = "Castelnaudary";
$areanames{fr}->{3341122} = "Limoux";
$areanames{fr}->{3341123} = "Narbonne";
$areanames{fr}->{3341124} = "Ales";
$areanames{fr}->{3341125} = "Nîmes";
$areanames{fr}->{3341126} = "Bedarieux";
$areanames{fr}->{3341127} = "Beziers";
$areanames{fr}->{3341128} = "Montpellier";
$areanames{fr}->{3341129} = "Mende";
$areanames{fr}->{3341130} = "Perpignan";
$areanames{fr}->{3341131} = "Prades";
$areanames{fr}->{3341132} = "Montpellier";
$areanames{fr}->{3341133} = "Langogne";
$areanames{fr}->{3341134} = "Bedarieux";
$areanames{fr}->{3341135} = "Perpignan";
$areanames{fr}->{3341136} = "Ales";
$areanames{fr}->{3341137} = "Bedarieux";
$areanames{fr}->{3341138} = "Montpellier";
$areanames{fr}->{3341139} = "Beziers";
$areanames{fr}->{3341140} = "Nîmes";
$areanames{fr}->{3341141} = "Narbonne";
$areanames{fr}->{3341142} = "Castelnaudary";
$areanames{fr}->{3341143} = "Mende";
$areanames{fr}->{3341144} = "Bagnols\-sur\-Ceze";
$areanames{fr}->{3341145} = "Prades";
$areanames{fr}->{3341146} = "Limoux";
$areanames{fr}->{3341147} = "Carcassonne";
$areanames{fr}->{3341148} = "Carcassonne";
$areanames{fr}->{3341149} = "Castelnaudary";
$areanames{fr}->{3341150} = "Limoux";
$areanames{fr}->{3341151} = "Narbonne";
$areanames{fr}->{3341152} = "Ales";
$areanames{fr}->{3341153} = "Bagnols\-sur\-Ceze";
$areanames{fr}->{3341154} = "Nîmes";
$areanames{fr}->{3341155} = "Bedarieux";
$areanames{fr}->{3341156} = "Beziers";
$areanames{fr}->{3341157} = "Montpellier";
$areanames{fr}->{3341158} = "Langogne";
$areanames{fr}->{3341159} = "Mende";
$areanames{fr}->{3341164} = "Perpignan";
$areanames{fr}->{3341175} = "Montpellier";
$areanames{fr}->{3341180} = "Montpellier";
$areanames{fr}->{3341181} = "Perpignan";
$areanames{fr}->{3341182} = "Narbonne";
$areanames{fr}->{3341183} = "Nîmes";
$areanames{fr}->{3341184} = "Ales";
$areanames{fr}->{3341185} = "Nîmes";
$areanames{fr}->{3341186} = "Mende";
$areanames{fr}->{3341187} = "Nîmes";
$areanames{fr}->{3341188} = "Nîmes";
$areanames{fr}->{3341189} = "Montpellier";
$areanames{fr}->{3341190} = "Beziers";
$areanames{fr}->{3341191} = "Beziers";
$areanames{fr}->{3341192} = "Montpellier";
$areanames{fr}->{3341193} = "Montpellier";
$areanames{fr}->{3341194} = "Nîmes";
$areanames{fr}->{3341195} = "Montpellier";
$areanames{fr}->{3341196} = "Perpignan";
$areanames{fr}->{3341197} = "Beziers";
$areanames{fr}->{3341198} = "Perpignan";
$areanames{fr}->{3341199} = "Perpignan";
$areanames{fr}->{3341307} = "Carpentras";
$areanames{fr}->{3341310} = "Aix\-en\-Provence";
$areanames{fr}->{3341311} = "Arles";
$areanames{fr}->{3341312} = "Aubagne";
$areanames{fr}->{3341313} = "Marseille";
$areanames{fr}->{3341314} = "Aix\-en\-Provence";
$areanames{fr}->{3341315} = "Avignon";
$areanames{fr}->{3341316} = "Avignon";
$areanames{fr}->{3341317} = "Cavaillon";
$areanames{fr}->{3341318} = "Digne\-les\-Bains";
$areanames{fr}->{3341319} = "Gap";
$areanames{fr}->{3341320} = "Marseille";
$areanames{fr}->{3341339} = "Avignon";
$areanames{fr}->{3341340} = "Marignane";
$areanames{fr}->{3341341} = "Aix\-en\-Provence";
$areanames{fr}->{3341342} = "Marseille";
$areanames{fr}->{3341343} = "Marignane";
$areanames{fr}->{3341344} = "Aix\-en\-Provence";
$areanames{fr}->{3341345} = "Arles";
$areanames{fr}->{3341346} = "Cavaillon";
$areanames{fr}->{3341347} = "Orange";
$areanames{fr}->{3341348} = "Pertuis";
$areanames{fr}->{3341349} = "Manosque";
$areanames{fr}->{3341359} = "Marseille";
$areanames{fr}->{3341363} = "Marseille";
$areanames{fr}->{3341370} = "Arles";
$areanames{fr}->{3341371} = "Cavaillon";
$areanames{fr}->{3341372} = "Manosque";
$areanames{fr}->{3341373} = "Marseille";
$areanames{fr}->{3341374} = "Pertuis";
$areanames{fr}->{3341375} = "Aix\-en\-Provence";
$areanames{fr}->{3341376} = "Orange";
$areanames{fr}->{3341377} = "Avignon";
$areanames{fr}->{3341378} = "Saint\-André\-les\-Alpes";
$areanames{fr}->{3341379} = "Digne\-les\-Bains";
$areanames{fr}->{3341380} = "Digne\-les\-Bains";
$areanames{fr}->{3341381} = "Manosque";
$areanames{fr}->{3341382} = "Aix\-en\-Provence";
$areanames{fr}->{3341383} = "Arles";
$areanames{fr}->{3341384} = "Aubagne";
$areanames{fr}->{3341385} = "Marignane";
$areanames{fr}->{3341386} = "Marseille";
$areanames{fr}->{3341387} = "Avignon";
$areanames{fr}->{3341388} = "Cavaillon";
$areanames{fr}->{3341389} = "Aubagne";
$areanames{fr}->{3341390} = "Saint\-André\-les\-Alpes";
$areanames{fr}->{3341391} = "Aix\-en\-Provence";
$areanames{fr}->{3341392} = "Aubagne";
$areanames{fr}->{3341393} = "Marignane";
$areanames{fr}->{3341394} = "Marseille";
$areanames{fr}->{3341395} = "Avignon";
$areanames{fr}->{3341396} = "Marseille";
$areanames{fr}->{3341397} = "Orange";
$areanames{fr}->{3341398} = "Pertuis";
$areanames{fr}->{3341399} = "Cavaillon";
$areanames{fr}->{3341500} = "Issoire";
$areanames{fr}->{3341501} = "Riom";
$areanames{fr}->{3341502} = "La\ Bourboule";
$areanames{fr}->{3341503} = "Montlucon";
$areanames{fr}->{3341504} = "Le\ Puy\-en\-Velay";
$areanames{fr}->{3341505} = "Aurillac";
$areanames{fr}->{3341506} = "Saint\-Flour";
$areanames{fr}->{3341507} = "Mauriac";
$areanames{fr}->{3341508} = "Vichy";
$areanames{fr}->{3341509} = "Ambert";
$areanames{fr}->{3341510} = "Bourbon\-lArchambault";
$areanames{fr}->{3341511} = "Clermont\-Ferrand";
$areanames{fr}->{3341512} = "Yssingeaux";
$areanames{fr}->{3341513} = "Thiers";
$areanames{fr}->{3341514} = "Moulins";
$areanames{fr}->{3341515} = "Brioude";
$areanames{fr}->{3341516} = "Bourbon\-lArchambault";
$areanames{fr}->{3341517} = "Montlucon";
$areanames{fr}->{3341518} = "Moulins";
$areanames{fr}->{3341519} = "Vichy";
$areanames{fr}->{3341520} = "Aurillac";
$areanames{fr}->{3341521} = "Mauriac";
$areanames{fr}->{3341522} = "Saint\-Flour";
$areanames{fr}->{3341523} = "Brioude";
$areanames{fr}->{3341524} = "Le\ Puy\-en\-Velay";
$areanames{fr}->{3341525} = "Yssingeaux";
$areanames{fr}->{3341526} = "Ambert";
$areanames{fr}->{3341527} = "La\ Bourboule";
$areanames{fr}->{3341528} = "Clermont\-Ferrand";
$areanames{fr}->{3341529} = "Issoire";
$areanames{fr}->{3341530} = "Riom";
$areanames{fr}->{3341531} = "Thiers";
$areanames{fr}->{3341532} = "Clermont\-Ferrand";
$areanames{fr}->{3341533} = "Bourbon\-lArchambault";
$areanames{fr}->{3341534} = "Montlucon";
$areanames{fr}->{3341535} = "Moulins";
$areanames{fr}->{3341536} = "Saint\-Flour";
$areanames{fr}->{3341537} = "Brioude";
$areanames{fr}->{3341538} = "Yssingeaux";
$areanames{fr}->{3341539} = "Clermont\-Ferrand";
$areanames{fr}->{3341540} = "Clermont\-Ferrand";
$areanames{fr}->{3341541} = "Moulins";
$areanames{fr}->{3341542} = "Aurillac";
$areanames{fr}->{3341543} = "Moulins";
$areanames{fr}->{3341544} = "Clermont\-Ferrand";
$areanames{fr}->{3341545} = "Moulins";
$areanames{fr}->{3341546} = "Le\ Puy\-en\-Velay";
$areanames{fr}->{3341547} = "Riom";
$areanames{fr}->{3341548} = "Aurillac";
$areanames{fr}->{3341549} = "Yssingeaux";
$areanames{fr}->{3341550} = "Le\ Puy\-en\-Velay";
$areanames{fr}->{3341551} = "Clermont\-Ferrand";
$areanames{fr}->{3341552} = "Le\ Puy\-en\-Velay";
$areanames{fr}->{3341553} = "Moulins";
$areanames{fr}->{3341554} = "Clermont\-Ferrand";
$areanames{fr}->{3341555} = "Aurillac";
$areanames{fr}->{3341556} = "Bourbon\-lArchambault";
$areanames{fr}->{3341557} = "Mauriac";
$areanames{fr}->{3341558} = "Saint\-Flour";
$areanames{fr}->{3341559} = "Brioude";
$areanames{fr}->{3341560} = "Ambert";
$areanames{fr}->{3341561} = "La\ Bourboule";
$areanames{fr}->{3341562} = "Issoire";
$areanames{fr}->{3341563} = "Thiers";
$areanames{fr}->{3341564} = "Bourbon\-lArchambault";
$areanames{fr}->{3341565} = "Montlucon";
$areanames{fr}->{3341566} = "Clermont\-Ferrand";
$areanames{fr}->{3341567} = "Montlucon";
$areanames{fr}->{3341568} = "Moulins";
$areanames{fr}->{3341569} = "Vichy";
$areanames{fr}->{3341570} = "Aurillac";
$areanames{fr}->{3341571} = "Mauriac";
$areanames{fr}->{3341572} = "Saint\-Flour";
$areanames{fr}->{3341573} = "Brioude";
$areanames{fr}->{3341574} = "Le\ Puy\-en\-Velay";
$areanames{fr}->{3341575} = "Yssingeaux";
$areanames{fr}->{3341576} = "Ambert";
$areanames{fr}->{3341577} = "La\ Bourboule";
$areanames{fr}->{3341578} = "Issoire";
$areanames{fr}->{3341579} = "Riom";
$areanames{fr}->{3341580} = "Thiers";
$areanames{fr}->{3341581} = "Clermont\-Ferrand";
$areanames{fr}->{3341582} = "Vichy";
$areanames{fr}->{3341583} = "Issoire";
$areanames{fr}->{3341584} = "Aurillac";
$areanames{fr}->{3341585} = "Clermont\-Ferrand";
$areanames{fr}->{3341586} = "Aurillac";
$areanames{fr}->{3341587} = "Mauriac";
$areanames{fr}->{3341588} = "Saint\-Flour";
$areanames{fr}->{3341589} = "Saint\-Flour";
$areanames{fr}->{3341590} = "Vichy";
$areanames{fr}->{3341591} = "Vichy";
$areanames{fr}->{3341592} = "Riom";
$areanames{fr}->{3341593} = "Le\ Puy\-en\-Velay";
$areanames{fr}->{3341594} = "Brioude";
$areanames{fr}->{3342004} = "Ajaccio";
$areanames{fr}->{334201} = "Corse";
$areanames{fr}->{3342020} = "Corse";
$areanames{fr}->{3342030} = "Corse";
$areanames{fr}->{3342040} = "Corse";
$areanames{fr}->{3342055} = "Corse";
$areanames{fr}->{3342057} = "Corse";
$areanames{fr}->{3342058} = "Corse";
$areanames{fr}->{3342059} = "Corse";
$areanames{fr}->{3342060} = "Corse";
$areanames{fr}->{3342061} = "Corse";
$areanames{fr}->{3342088} = "Corse";
$areanames{fr}->{3342094} = "Corse";
$areanames{fr}->{3342095} = "Corse";
$areanames{fr}->{3342200} = "Cannes";
$areanames{fr}->{3342201} = "Grasse";
$areanames{fr}->{3342202} = "Nice";
$areanames{fr}->{3342203} = "Puget\-Theniers";
$areanames{fr}->{3342204} = "Brignoles";
$areanames{fr}->{3342205} = "Draguignan";
$areanames{fr}->{3342206} = "Saint\-Raphael";
$areanames{fr}->{3342207} = "Toulon";
$areanames{fr}->{3342208} = "Cannes";
$areanames{fr}->{3342209} = "Nice";
$areanames{fr}->{3342220} = "Nice";
$areanames{fr}->{3342221} = "Cannes";
$areanames{fr}->{3342222} = "Nice";
$areanames{fr}->{3342223} = "Grasse";
$areanames{fr}->{3342224} = "Cannes";
$areanames{fr}->{3342225} = "Grasse";
$areanames{fr}->{3342226} = "Nice";
$areanames{fr}->{3342227} = "Puget\-Theniers";
$areanames{fr}->{3342228} = "Brignoles";
$areanames{fr}->{3342229} = "Draguignan";
$areanames{fr}->{3342230} = "Saint\-Raphael";
$areanames{fr}->{3342231} = "Toulon";
$areanames{fr}->{3342232} = "Cannes";
$areanames{fr}->{3342233} = "Brignoles";
$areanames{fr}->{3342234} = "Cannes";
$areanames{fr}->{3342235} = "Draguignan";
$areanames{fr}->{3342236} = "Cannes";
$areanames{fr}->{3342237} = "Toulon";
$areanames{fr}->{3342238} = "Toulon";
$areanames{fr}->{3342239} = "Cannes";
$areanames{fr}->{3342250} = "Brignoles";
$areanames{fr}->{3342251} = "Saint\-Raphael";
$areanames{fr}->{3342252} = "Cannes";
$areanames{fr}->{3342253} = "Nice";
$areanames{fr}->{3342254} = "Toulon";
$areanames{fr}->{3342255} = "Saint\-Raphael";
$areanames{fr}->{3342256} = "Draguignan";
$areanames{fr}->{3342257} = "Brignoles";
$areanames{fr}->{3342258} = "Cannes";
$areanames{fr}->{3342259} = "Toulon";
$areanames{fr}->{3342260} = "Brignoles";
$areanames{fr}->{3342261} = "Nice";
$areanames{fr}->{3342262} = "Toulon";
$areanames{fr}->{3342263} = "Draguignan";
$areanames{fr}->{3342264} = "Puget\-Theniers";
$areanames{fr}->{3342265} = "Toulon";
$areanames{fr}->{3342266} = "Draguignan";
$areanames{fr}->{3342267} = "Nice";
$areanames{fr}->{3342268} = "Nice";
$areanames{fr}->{3342269} = "Nice";
$areanames{fr}->{3342270} = "Nice";
$areanames{fr}->{3342271} = "Cannes";
$areanames{fr}->{3342272} = "Cannes";
$areanames{fr}->{3342273} = "Saint\-Raphael";
$areanames{fr}->{3342274} = "Nice";
$areanames{fr}->{3342275} = "Nice";
$areanames{fr}->{3342276} = "Brignoles";
$areanames{fr}->{3342277} = "Draguignan";
$areanames{fr}->{3342278} = "Cannes";
$areanames{fr}->{3342279} = "Toulon";
$areanames{fr}->{3342280} = "Toulon";
$areanames{fr}->{3342281} = "Saint\-Raphael";
$areanames{fr}->{3342282} = "Saint\-Raphael";
$areanames{fr}->{3342283} = "Toulon";
$areanames{fr}->{3342284} = "Cannes";
$areanames{fr}->{3342285} = "Nice";
$areanames{fr}->{3342286} = "Toulon";
$areanames{fr}->{3342287} = "Toulon";
$areanames{fr}->{3342288} = "Grasse";
$areanames{fr}->{3342289} = "Saint\-Raphael";
$areanames{fr}->{3342290} = "Cannes";
$areanames{fr}->{3342291} = "Grasse";
$areanames{fr}->{3342292} = "Puget\-Theniers";
$areanames{fr}->{3342293} = "Cannes";
$areanames{fr}->{3342294} = "Nice";
$areanames{fr}->{3342295} = "Toulon";
$areanames{fr}->{3342296} = "Nice";
$areanames{fr}->{3342297} = "Brignoles";
$areanames{fr}->{3342298} = "Draguignan";
$areanames{fr}->{3342299} = "Saint\-Raphael";
$areanames{fr}->{3342300} = "Nice";
$areanames{fr}->{3342301} = "Cannes";
$areanames{fr}->{3342302} = "Grasse";
$areanames{fr}->{3342303} = "Nice";
$areanames{fr}->{3342304} = "Puget\-Theniers";
$areanames{fr}->{3342305} = "Brignoles";
$areanames{fr}->{3342306} = "Draguignan";
$areanames{fr}->{3342307} = "Saint\-Raphael";
$areanames{fr}->{3342308} = "Toulon";
$areanames{fr}->{3342309} = "Nice";
$areanames{fr}->{3342310} = "Toulon";
$areanames{fr}->{3342311} = "Nice";
$areanames{fr}->{3342312} = "Toulon";
$areanames{fr}->{3342313} = "Nice";
$areanames{fr}->{3342314} = "Toulon";
$areanames{fr}->{3342315} = "Toulon";
$areanames{fr}->{3342316} = "Nice";
$areanames{fr}->{3342317} = "Nice";
$areanames{fr}->{3342318} = "Saint\-Raphael";
$areanames{fr}->{3342319} = "Cannes";
$areanames{fr}->{3342320} = "Nice";
$areanames{fr}->{3342323} = "Nice";
$areanames{fr}->{3342610} = "Lyon";
$areanames{fr}->{3342611} = "Bourg\-en\-Bresse";
$areanames{fr}->{3342612} = "Nantua";
$areanames{fr}->{3342613} = "Annonay";
$areanames{fr}->{3342614} = "Aubenas";
$areanames{fr}->{3342615} = "Privas";
$areanames{fr}->{3342616} = "Bourg\-en\-Bresse";
$areanames{fr}->{3342617} = "Lyon";
$areanames{fr}->{3342618} = "Lyon";
$areanames{fr}->{3342619} = "Lyon";
$areanames{fr}->{334262} = "Lyon";
$areanames{fr}->{3342624} = "Roanne";
$areanames{fr}->{3342625} = "Privas";
$areanames{fr}->{3342630} = "Annonay";
$areanames{fr}->{3342631} = "Lyon";
$areanames{fr}->{3342632} = "Tournon\-sur\-Rhone";
$areanames{fr}->{3342633} = "Die";
$areanames{fr}->{3342634} = "Montelimar";
$areanames{fr}->{3342635} = "Nyons";
$areanames{fr}->{3342636} = "Saint\-Etienne";
$areanames{fr}->{3342637} = "Bourg\-en\-Bresse";
$areanames{fr}->{3342638} = "Bourgoin\-Jallieu";
$areanames{fr}->{3342639} = "Feurs";
$areanames{fr}->{3342640} = "Saint\-Vallier";
$areanames{fr}->{3342641} = "Amberieu\-en\-Bugey";
$areanames{fr}->{3342642} = "Valence";
$areanames{fr}->{3342643} = "Romans\-sur\-Isere";
$areanames{fr}->{3342644} = "Valence";
$areanames{fr}->{3342645} = "Tarare";
$areanames{fr}->{3342646} = "Lyon";
$areanames{fr}->{3342647} = "Villefranche\-sur\-Saone";
$areanames{fr}->{3342648} = "Saint\-Etienne";
$areanames{fr}->{3342649} = "Lyon";
$areanames{fr}->{3342650} = "Valence";
$areanames{fr}->{3342651} = "Montelimar";
$areanames{fr}->{3342652} = "Valence";
$areanames{fr}->{3342653} = "Privas";
$areanames{fr}->{3342654} = "Roanne";
$areanames{fr}->{3342655} = "Lyon";
$areanames{fr}->{3342656} = "Saint\-Etienne";
$areanames{fr}->{3342657} = "Vienne";
$areanames{fr}->{3342658} = "Die";
$areanames{fr}->{3342659} = "Lyon";
$areanames{fr}->{334267} = "Lyon";
$areanames{fr}->{3342674} = "Villefranche\-sur\-Saone";
$areanames{fr}->{3342675} = "Vienne";
$areanames{fr}->{3342677} = "Villefranche\-sur\-Saone";
$areanames{fr}->{3342679} = "Montelimar";
$areanames{fr}->{3342680} = "Amberieu\-en\-Bugey";
$areanames{fr}->{3342681} = "Tarare";
$areanames{fr}->{3342682} = "Bourg\-en\-Bresse";
$areanames{fr}->{3342683} = "Lyon";
$areanames{fr}->{3342684} = "Lyon";
$areanames{fr}->{3342685} = "Privas";
$areanames{fr}->{3342686} = "Nantua";
$areanames{fr}->{3342687} = "Privas";
$areanames{fr}->{3342688} = "Bourg\-en\-Bresse";
$areanames{fr}->{3342689} = "Bourg\-en\-Bresse";
$areanames{fr}->{3342690} = "Lyon";
$areanames{fr}->{3342691} = "Bourg\-en\-Bresse";
$areanames{fr}->{3342692} = "Montelimar";
$areanames{fr}->{3342693} = "Montelimar";
$areanames{fr}->{3342694} = "Romans\-sur\-Isere";
$areanames{fr}->{3342695} = "Romans\-sur\-Isere";
$areanames{fr}->{3342696} = "Tarare";
$areanames{fr}->{3342697} = "Saint\-Etienne";
$areanames{fr}->{3342698} = "Saint\-Etienne";
$areanames{fr}->{3342699} = "Lyon";
$areanames{fr}->{3342700} = "Romans\-sur\-Isere";
$areanames{fr}->{3342701} = "Lyon";
$areanames{fr}->{3342702} = "Lyon";
$areanames{fr}->{3342703} = "Saint\-Vallier";
$areanames{fr}->{3342704} = "Lyon";
$areanames{fr}->{3342705} = "Amberieu\-en\-Bugey";
$areanames{fr}->{3342706} = "Amberieu\-en\-Bugey";
$areanames{fr}->{3342707} = "Bourgoin\-Jallieu";
$areanames{fr}->{3342708} = "Bourgoin\-Jallieu";
$areanames{fr}->{3342709} = "Vienne";
$areanames{fr}->{334271} = "Lyon";
$areanames{fr}->{3342710} = "Saint\-Etienne";
$areanames{fr}->{3342715} = "Privas";
$areanames{fr}->{3342716} = "Valence";
$areanames{fr}->{3342717} = "Valence";
$areanames{fr}->{3342720} = "Feurs";
$areanames{fr}->{3342721} = "Lyon";
$areanames{fr}->{3342722} = "Lyon";
$areanames{fr}->{3342723} = "Roanne";
$areanames{fr}->{3342724} = "Valence";
$areanames{fr}->{3342725} = "Saint\-Etienne";
$areanames{fr}->{3342726} = "Roanne";
$areanames{fr}->{3342727} = "Saint\-Etienne";
$areanames{fr}->{3342728} = "Lyon";
$areanames{fr}->{3342729} = "Tarare";
$areanames{fr}->{3342730} = "Villefranche\-sur\-Saone";
$areanames{fr}->{3342731} = "Amberieu\-en\-Bugey";
$areanames{fr}->{3342732} = "Bourg\-en\-Bresse";
$areanames{fr}->{3342733} = "Nantua";
$areanames{fr}->{3342734} = "Annonay";
$areanames{fr}->{3342735} = "Feurs";
$areanames{fr}->{3342736} = "Bourg\-en\-Bresse";
$areanames{fr}->{3342737} = "Tarare";
$areanames{fr}->{3342738} = "Valence";
$areanames{fr}->{3342739} = "Vienne";
$areanames{fr}->{3342740} = "Saint\-Etienne";
$areanames{fr}->{3342741} = "Amberieu\-en\-Bugey";
$areanames{fr}->{3342742} = "Tournon\-sur\-Rhone";
$areanames{fr}->{3342743} = "Romans\-sur\-Isere";
$areanames{fr}->{3342744} = "Lyon";
$areanames{fr}->{3342745} = "Saint\-Vallier";
$areanames{fr}->{3342746} = "Lyon";
$areanames{fr}->{3342747} = "Villefranche\-sur\-Saone";
$areanames{fr}->{3342748} = "Tarare";
$areanames{fr}->{3342749} = "Villefranche\-sur\-Saone";
$areanames{fr}->{3342750} = "Amberieu\-en\-Bugey";
$areanames{fr}->{3342751} = "Annonay";
$areanames{fr}->{3342752} = "Aubenas";
$areanames{fr}->{3342753} = "Bourg\-en\-Bresse";
$areanames{fr}->{3342754} = "Bourgoin\-Jallieu";
$areanames{fr}->{3342755} = "Die";
$areanames{fr}->{3342756} = "Feurs";
$areanames{fr}->{3342757} = "Bourgoin\-Jallieu";
$areanames{fr}->{3342758} = "Montelimar";
$areanames{fr}->{3342759} = "Nantua";
$areanames{fr}->{3342790} = "Amberieu\-en\-Bugey";
$areanames{fr}->{3342791} = "Bourg\-en\-Bresse";
$areanames{fr}->{3342792} = "Nantua";
$areanames{fr}->{3342793} = "Annonay";
$areanames{fr}->{3342794} = "Aubenas";
$areanames{fr}->{3342795} = "Privas";
$areanames{fr}->{3342796} = "Tournon\-sur\-Rhone";
$areanames{fr}->{3342797} = "Die";
$areanames{fr}->{3342798} = "Montelimar";
$areanames{fr}->{3342799} = "Nyons";
$areanames{fr}->{3342800} = "Lyon";
$areanames{fr}->{3342801} = "Lyon";
$areanames{fr}->{3342802} = "Bourg\-en\-Bresse";
$areanames{fr}->{3342803} = "Nantua";
$areanames{fr}->{3342804} = "Saint\-Etienne";
$areanames{fr}->{3342805} = "Feurs";
$areanames{fr}->{3342806} = "Roanne";
$areanames{fr}->{3342807} = "Saint\-Etienne";
$areanames{fr}->{3342808} = "Valence";
$areanames{fr}->{3342809} = "Saint\-Etienne";
$areanames{fr}->{3342810} = "Lyon";
$areanames{fr}->{3342811} = "Valence";
$areanames{fr}->{3342812} = "Nantua";
$areanames{fr}->{3342813} = "Saint\-Vallier";
$areanames{fr}->{3342814} = "Tournon\-sur\-Rhone";
$areanames{fr}->{3342815} = "Valence";
$areanames{fr}->{3342816} = "Die";
$areanames{fr}->{3342817} = "Nyons";
$areanames{fr}->{3342818} = "Romans\-sur\-Isere";
$areanames{fr}->{3342819} = "Bourgoin\-Jallieu";
$areanames{fr}->{3342820} = "Vienne";
$areanames{fr}->{3342821} = "Feurs";
$areanames{fr}->{3342822} = "Roanne";
$areanames{fr}->{3342823} = "Saint\-Etienne";
$areanames{fr}->{3342824} = "Bourg\-en\-Bresse";
$areanames{fr}->{3342825} = "Bourgoin\-Jallieu";
$areanames{fr}->{3342826} = "Roanne";
$areanames{fr}->{3342827} = "Lyon";
$areanames{fr}->{3342828} = "Lyon";
$areanames{fr}->{3342829} = "Lyon";
$areanames{fr}->{3342830} = "Nantua";
$areanames{fr}->{3342831} = "Lyon";
$areanames{fr}->{3342832} = "Saint\-Etienne";
$areanames{fr}->{3342833} = "Villefranche\-sur\-Saone";
$areanames{fr}->{3342834} = "Bourgoin\-Jallieu";
$areanames{fr}->{3342835} = "Bourgoin\-Jallieu";
$areanames{fr}->{3342836} = "Bourg\-en\-Bresse";
$areanames{fr}->{3342837} = "Montelimar";
$areanames{fr}->{3342838} = "Lyon";
$areanames{fr}->{3342839} = "Villefranche\-sur\-Saone";
$areanames{fr}->{3342840} = "Aubenas";
$areanames{fr}->{3342841} = "Amberieu\-en\-Bugey";
$areanames{fr}->{3342842} = "Romans\-sur\-Isere";
$areanames{fr}->{3342843} = "Tournon\-sur\-Rhone";
$areanames{fr}->{3342844} = "Bourg\-en\-Bresse";
$areanames{fr}->{3342845} = "Bourg\-en\-Bresse";
$areanames{fr}->{3342846} = "Lyon";
$areanames{fr}->{3342847} = "Saint\-Etienne";
$areanames{fr}->{3342848} = "Annonay";
$areanames{fr}->{3342849} = "Privas";
$areanames{fr}->{3342850} = "Tournon\-sur\-Rhone";
$areanames{fr}->{3342851} = "Die";
$areanames{fr}->{3342852} = "Nyons";
$areanames{fr}->{3342853} = "Feurs";
$areanames{fr}->{3342854} = "Tarare";
$areanames{fr}->{3342855} = "Saint\-Vallier";
$areanames{fr}->{3342856} = "Bourgoin\-Jallieu";
$areanames{fr}->{3342857} = "Vienne";
$areanames{fr}->{3342858} = "Tarare";
$areanames{fr}->{3342859} = "Villefranche\-sur\-Saone";
$areanames{fr}->{334286} = "Lyon";
$areanames{fr}->{3342861} = "Valence";
$areanames{fr}->{3342864} = "Amberieu\-en\-Bugey";
$areanames{fr}->{3342868} = "Romans\-sur\-Isere";
$areanames{fr}->{3342870} = "Lyon";
$areanames{fr}->{3342871} = "Bourgoin\-Jallieu";
$areanames{fr}->{3342872} = "Roanne";
$areanames{fr}->{3342873} = "Vienne";
$areanames{fr}->{3342874} = "Valence";
$areanames{fr}->{3342875} = "Bourgoin\-Jallieu";
$areanames{fr}->{3342876} = "Saint\-Vallier";
$areanames{fr}->{3342877} = "Lyon";
$areanames{fr}->{3342878} = "Saint\-Etienne";
$areanames{fr}->{3342879} = "Saint\-Vallier";
$areanames{fr}->{3342880} = "Lyon";
$areanames{fr}->{3342881} = "Lyon";
$areanames{fr}->{3342882} = "Privas";
$areanames{fr}->{3342883} = "Amberieu\-en\-Bugey";
$areanames{fr}->{3342884} = "Nantua";
$areanames{fr}->{3342885} = "Bourgoin\-Jallieu";
$areanames{fr}->{3342886} = "Vienne";
$areanames{fr}->{3342887} = "Lyon";
$areanames{fr}->{3342888} = "Bourg\-en\-Bresse";
$areanames{fr}->{3342889} = "Lyon";
$areanames{fr}->{3342890} = "Annonay";
$areanames{fr}->{3342891} = "Aubenas";
$areanames{fr}->{3342892} = "Privas";
$areanames{fr}->{3342893} = "Tournon\-sur\-Rhone";
$areanames{fr}->{3342894} = "Die";
$areanames{fr}->{3342895} = "Montelimar";
$areanames{fr}->{3342896} = "Nyons";
$areanames{fr}->{3342897} = "Romans\-sur\-Isere";
$areanames{fr}->{3342898} = "Saint\-Vallier";
$areanames{fr}->{3342899} = "Valence";
$areanames{fr}->{3343000} = "Montpellier";
$areanames{fr}->{3343001} = "Nîmes";
$areanames{fr}->{3343002} = "Montpellier";
$areanames{fr}->{3343003} = "Nîmes";
$areanames{fr}->{3343004} = "Perpignan";
$areanames{fr}->{3343005} = "Montpellier";
$areanames{fr}->{3343006} = "Nîmes";
$areanames{fr}->{3343007} = "Limoux";
$areanames{fr}->{3343008} = "Nîmes";
$areanames{fr}->{3343009} = "Langogne";
$areanames{fr}->{3343020} = "Ales";
$areanames{fr}->{3343021} = "Bagnols\-sur\-Ceze";
$areanames{fr}->{3343022} = "Bedarieux";
$areanames{fr}->{3343023} = "Beziers";
$areanames{fr}->{3343024} = "Carcassonne";
$areanames{fr}->{3343025} = "Castelnaudary";
$areanames{fr}->{3343026} = "Langogne";
$areanames{fr}->{3343027} = "Limoux";
$areanames{fr}->{3343028} = "Mende";
$areanames{fr}->{3343029} = "Montpellier";
$areanames{fr}->{3343050} = "Nîmes";
$areanames{fr}->{3343051} = "Carcassonne";
$areanames{fr}->{3343052} = "Narbonne";
$areanames{fr}->{3343053} = "Perpignan";
$areanames{fr}->{3343054} = "Beziers";
$areanames{fr}->{3343055} = "Beziers";
$areanames{fr}->{3343056} = "Carcassonne";
$areanames{fr}->{3343057} = "Montpellier";
$areanames{fr}->{3343058} = "Narbonne";
$areanames{fr}->{3343059} = "Nîmes";
$areanames{fr}->{3343070} = "Montpellier";
$areanames{fr}->{3343071} = "Bedarieux";
$areanames{fr}->{3343072} = "Beziers";
$areanames{fr}->{3343073} = "Carcassonne";
$areanames{fr}->{3343074} = "Castelnaudary";
$areanames{fr}->{3343075} = "Langogne";
$areanames{fr}->{3343076} = "Limoux";
$areanames{fr}->{3343077} = "Mende";
$areanames{fr}->{3343078} = "Montpellier";
$areanames{fr}->{3343079} = "Narbonne";
$areanames{fr}->{3343080} = "Beziers";
$areanames{fr}->{3343081} = "Nîmes";
$areanames{fr}->{3343082} = "Perpignan";
$areanames{fr}->{3343083} = "Prades";
$areanames{fr}->{3343084} = "Beziers";
$areanames{fr}->{3343085} = "Castelnaudary";
$areanames{fr}->{3343086} = "Limoux";
$areanames{fr}->{3343087} = "Mende";
$areanames{fr}->{3343088} = "Carcassonne";
$areanames{fr}->{3343089} = "Prades";
$areanames{fr}->{3343090} = "Nîmes";
$areanames{fr}->{3343091} = "Carcassonne";
$areanames{fr}->{3343092} = "Nîmes";
$areanames{fr}->{3343093} = "Ales";
$areanames{fr}->{3343094} = "Mende";
$areanames{fr}->{3343095} = "Perpignan";
$areanames{fr}->{3343096} = "Montpellier";
$areanames{fr}->{3343097} = "Carcassonne";
$areanames{fr}->{3343098} = "Castelnaudary";
$areanames{fr}->{3343099} = "Narbonne";
$areanames{fr}->{334320} = "Sud\ Est";
$areanames{fr}->{334321} = "Sud\ Est";
$areanames{fr}->{334322} = "Sud\ Est";
$areanames{fr}->{334323} = "Sud\ Est";
$areanames{fr}->{334324} = "Sud\ Est";
$areanames{fr}->{3343240} = "Avignon";
$areanames{fr}->{3343244} = "Avignon";
$areanames{fr}->{334329} = "Sud\ Est";
$areanames{fr}->{3343450} = "Montpellier";
$areanames{fr}->{3343451} = "Prades";
$areanames{fr}->{3343452} = "Prades";
$areanames{fr}->{3343453} = "Beziers";
$areanames{fr}->{3343454} = "Perpignan";
$areanames{fr}->{3343455} = "Perpignan";
$areanames{fr}->{3343456} = "Prades";
$areanames{fr}->{3343457} = "Carcassonne";
$areanames{fr}->{3343458} = "Carcassonne";
$areanames{fr}->{3343459} = "Perpignan";
$areanames{fr}->{3343460} = "Narbonne";
$areanames{fr}->{3343461} = "Ales";
$areanames{fr}->{3343462} = "Bagnols\-sur\-Ceze";
$areanames{fr}->{3343463} = "Nîmes";
$areanames{fr}->{3343464} = "Prades";
$areanames{fr}->{3343465} = "Beziers";
$areanames{fr}->{3343466} = "Montpellier";
$areanames{fr}->{3343467} = "Montpellier";
$areanames{fr}->{3343468} = "Perpignan";
$areanames{fr}->{3343469} = "Nîmes";
$areanames{fr}->{3343470} = "Langogne";
$areanames{fr}->{3343471} = "Ales";
$areanames{fr}->{3343472} = "Bagnols\-sur\-Ceze";
$areanames{fr}->{3343473} = "Castelnaudary";
$areanames{fr}->{3343474} = "Beziers";
$areanames{fr}->{3343475} = "Limoux";
$areanames{fr}->{3343476} = "Montpellier";
$areanames{fr}->{3343477} = "Bagnols\-sur\-Ceze";
$areanames{fr}->{3343478} = "Bagnols\-sur\-Ceze";
$areanames{fr}->{3343479} = "Bedarieux";
$areanames{fr}->{3343480} = "Beziers";
$areanames{fr}->{3343481} = "Montpellier";
$areanames{fr}->{3343482} = "Mende";
$areanames{fr}->{3343483} = "Prades";
$areanames{fr}->{3343484} = "Narbonne";
$areanames{fr}->{3343485} = "Beziers";
$areanames{fr}->{3343486} = "Bedarieux";
$areanames{fr}->{3343487} = "Carcassonne";
$areanames{fr}->{3343488} = "Montpellier";
$areanames{fr}->{3343489} = "Carcassonne";
$areanames{fr}->{3343490} = "Montpellier";
$areanames{fr}->{3343491} = "Carcassonne";
$areanames{fr}->{3343492} = "Castelnaudary";
$areanames{fr}->{3343493} = "Limoux";
$areanames{fr}->{3343494} = "Narbonne";
$areanames{fr}->{3343495} = "Ales";
$areanames{fr}->{3343496} = "Bagnols\-sur\-Ceze";
$areanames{fr}->{3343497} = "Nîmes";
$areanames{fr}->{3343498} = "Bedarieux";
$areanames{fr}->{3343499} = "Beziers";
$areanames{fr}->{334371} = "Sud\ Est";
$areanames{fr}->{334382} = "Sud\ Est";
$areanames{fr}->{3343821} = "Grenoble";
$areanames{fr}->{3343824} = "Grenoble";
$areanames{fr}->{3343826} = "Grenoble";
$areanames{fr}->{334385} = "Sud\ Est";
$areanames{fr}->{3343850} = "Grenoble";
$areanames{fr}->{334386} = "Sud\ Est";
$areanames{fr}->{3343860} = "Grenoble";
$areanames{fr}->{334388} = "Sud\ Est";
$areanames{fr}->{3343880} = "Annecy";
$areanames{fr}->{3343886} = "Grenoble";
$areanames{fr}->{3343888} = "Grenoble";
$areanames{fr}->{3344300} = "Bourbon\-lArchambault";
$areanames{fr}->{3344301} = "Montlucon";
$areanames{fr}->{3344302} = "Moulins";
$areanames{fr}->{3344303} = "Vichy";
$areanames{fr}->{3344304} = "Aurillac";
$areanames{fr}->{3344305} = "Mauriac";
$areanames{fr}->{3344306} = "Brioude";
$areanames{fr}->{3344307} = "Le\ Puy\-en\-Velay";
$areanames{fr}->{3344308} = "Yssingeaux";
$areanames{fr}->{3344309} = "Ambert";
$areanames{fr}->{3344310} = "La\ Bourboule";
$areanames{fr}->{3344311} = "Clermont\-Ferrand";
$areanames{fr}->{3344312} = "Issoire";
$areanames{fr}->{3344313} = "Riom";
$areanames{fr}->{3344314} = "Thiers";
$areanames{fr}->{3344315} = "Ambert";
$areanames{fr}->{3344316} = "Issoire";
$areanames{fr}->{3344317} = "La\ Bourboule";
$areanames{fr}->{3344318} = "Le\ Puy\-en\-Velay";
$areanames{fr}->{3344319} = "Riom";
$areanames{fr}->{3344320} = "Thiers";
$areanames{fr}->{3344321} = "Vichy";
$areanames{fr}->{3344322} = "Clermont\-Ferrand";
$areanames{fr}->{3344323} = "Vichy";
$areanames{fr}->{3344324} = "Le\ Puy\-en\-Velay";
$areanames{fr}->{3344325} = "Ambert";
$areanames{fr}->{3344326} = "La\ Bourboule";
$areanames{fr}->{3344327} = "Issoire";
$areanames{fr}->{3344328} = "Riom";
$areanames{fr}->{3344329} = "Thiers";
$areanames{fr}->{3344330} = "Clermont\-Ferrand";
$areanames{fr}->{3344331} = "Montlucon";
$areanames{fr}->{3344332} = "Ambert";
$areanames{fr}->{3344333} = "Aurillac";
$areanames{fr}->{3344334} = "Bourbon\-lArchambault";
$areanames{fr}->{3344335} = "Brioude";
$areanames{fr}->{3344336} = "Clermont\-Ferrand";
$areanames{fr}->{3344337} = "Issoire";
$areanames{fr}->{3344338} = "La\ Bourboule";
$areanames{fr}->{3344339} = "Le\ Puy\-en\-Velay";
$areanames{fr}->{3344340} = "Mauriac";
$areanames{fr}->{3344341} = "Montlucon";
$areanames{fr}->{3344342} = "Moulins";
$areanames{fr}->{3344343} = "Clermont\-Ferrand";
$areanames{fr}->{3344344} = "Riom";
$areanames{fr}->{3344345} = "Saint\-Flour";
$areanames{fr}->{3344346} = "Thiers";
$areanames{fr}->{3344347} = "Vichy";
$areanames{fr}->{3344348} = "Yssingeaux";
$areanames{fr}->{3344349} = "Moulins";
$areanames{fr}->{3344350} = "Vichy";
$areanames{fr}->{3344351} = "Moulins";
$areanames{fr}->{3344352} = "Aurillac";
$areanames{fr}->{3344353} = "Mauriac";
$areanames{fr}->{3344354} = "Saint\-Flour";
$areanames{fr}->{3344355} = "Clermont\-Ferrand";
$areanames{fr}->{3344356} = "Montlucon";
$areanames{fr}->{3344357} = "Clermont\-Ferrand";
$areanames{fr}->{3344358} = "Clermont\-Ferrand";
$areanames{fr}->{3344359} = "Montlucon";
$areanames{fr}->{3344360} = "Moulins";
$areanames{fr}->{3344361} = "Vichy";
$areanames{fr}->{3344362} = "Aurillac";
$areanames{fr}->{3344363} = "Mauriac";
$areanames{fr}->{3344364} = "Saint\-Flour";
$areanames{fr}->{3344365} = "Brioude";
$areanames{fr}->{3344366} = "Le\ Puy\-en\-Velay";
$areanames{fr}->{3344367} = "Yssingeaux";
$areanames{fr}->{3344368} = "Ambert";
$areanames{fr}->{3344369} = "La\ Bourboule";
$areanames{fr}->{3344370} = "Vichy";
$areanames{fr}->{3344371} = "Issoire";
$areanames{fr}->{3344372} = "Riom";
$areanames{fr}->{3344373} = "Moulins";
$areanames{fr}->{3344374} = "Thiers";
$areanames{fr}->{3344375} = "Bourbon\-lArchambault";
$areanames{fr}->{3344376} = "Clermont\-Ferrand";
$areanames{fr}->{3344377} = "Montlucon";
$areanames{fr}->{3344378} = "Moulins";
$areanames{fr}->{3344379} = "Aurillac";
$areanames{fr}->{3344380} = "Clermont\-Ferrand";
$areanames{fr}->{3344381} = "Riom";
$areanames{fr}->{3344382} = "Le\ Puy\-en\-Velay";
$areanames{fr}->{3344383} = "Clermont\-Ferrand";
$areanames{fr}->{3344384} = "Clermont\-Ferrand";
$areanames{fr}->{3344385} = "Aurillac";
$areanames{fr}->{3344386} = "Clermont\-Ferrand";
$areanames{fr}->{3344387} = "Mauriac";
$areanames{fr}->{3344388} = "Bourbon\-lArchambault";
$areanames{fr}->{3344389} = "Montlucon";
$areanames{fr}->{3344390} = "Vichy";
$areanames{fr}->{3344391} = "Aurillac";
$areanames{fr}->{3344392} = "Mauriac";
$areanames{fr}->{3344393} = "Saint\-Flour";
$areanames{fr}->{3344394} = "Le\ Puy\-en\-Velay";
$areanames{fr}->{3344395} = "Ambert";
$areanames{fr}->{3344396} = "La\ Bourboule";
$areanames{fr}->{3344397} = "Clermont\-Ferrand";
$areanames{fr}->{3344398} = "Riom";
$areanames{fr}->{3344399} = "Thiers";
$areanames{fr}->{3344400} = "Brioude";
$areanames{fr}->{3344401} = "Le\ Puy\-en\-Velay";
$areanames{fr}->{3344402} = "Yssingeaux";
$areanames{fr}->{3344403} = "Aurillac";
$areanames{fr}->{3344404} = "Le\ Puy\-en\-Velay";
$areanames{fr}->{3344405} = "Clermont\-Ferrand";
$areanames{fr}->{3344406} = "Clermont\-Ferrand";
$areanames{fr}->{3344437} = "Ambert";
$areanames{fr}->{3344438} = "Clermont\-Ferrand";
$areanames{fr}->{3344439} = "Issoire";
$areanames{fr}->{3344440} = "La\ Bourboule";
$areanames{fr}->{3344441} = "Riom";
$areanames{fr}->{3344442} = "Thiers";
$areanames{fr}->{3344443} = "Le\ Puy\-en\-Velay";
$areanames{fr}->{3344444} = "Clermont\-Ferrand";
$areanames{fr}->{3344445} = "Yssingeaux";
$areanames{fr}->{3344446} = "Brioude";
$areanames{fr}->{3344447} = "Thiers";
$areanames{fr}->{3344448} = "Bourbon\-lArchambault";
$areanames{fr}->{3344449} = "Montlucon";
$areanames{fr}->{3344450} = "Moulins";
$areanames{fr}->{3344451} = "Vichy";
$areanames{fr}->{3344452} = "Brioude";
$areanames{fr}->{3344453} = "Le\ Puy\-en\-Velay";
$areanames{fr}->{3344454} = "Clermont\-Ferrand";
$areanames{fr}->{3344455} = "Yssingeaux";
$areanames{fr}->{3344488} = "Clermont\-Ferrand";
$areanames{fr}->{3344489} = "Clermont\-Ferrand";
$areanames{fr}->{3344800} = "Nîmes";
$areanames{fr}->{3344801} = "Langogne";
$areanames{fr}->{3344802} = "Carcassonne";
$areanames{fr}->{3344803} = "Mende";
$areanames{fr}->{3344804} = "Perpignan";
$areanames{fr}->{3344805} = "Perpignan";
$areanames{fr}->{3344806} = "Nîmes";
$areanames{fr}->{3344807} = "Perpignan";
$areanames{fr}->{3344808} = "Beziers";
$areanames{fr}->{3344809} = "Carcassonne";
$areanames{fr}->{3344810} = "Perpignan";
$areanames{fr}->{3344811} = "Beziers";
$areanames{fr}->{3344812} = "Bagnols\-sur\-Ceze";
$areanames{fr}->{3344813} = "Narbonne";
$areanames{fr}->{3344814} = "Beziers";
$areanames{fr}->{3344815} = "Ales";
$areanames{fr}->{3344816} = "Narbonne";
$areanames{fr}->{3344817} = "Beziers";
$areanames{fr}->{3344818} = "Montpellier";
$areanames{fr}->{3344819} = "Montpellier";
$areanames{fr}->{3344820} = "Montpellier";
$areanames{fr}->{3344821} = "Nîmes";
$areanames{fr}->{3344822} = "Perpignan";
$areanames{fr}->{3344823} = "Carcassonne";
$areanames{fr}->{3344824} = "Bagnols\-sur\-Ceze";
$areanames{fr}->{3344825} = "Mende";
$areanames{fr}->{3344826} = "Bedarieux";
$areanames{fr}->{3344827} = "Nîmes";
$areanames{fr}->{3344828} = "Ales";
$areanames{fr}->{3344829} = "Montpellier";
$areanames{fr}->{3344830} = "Castelnaudary";
$areanames{fr}->{3344831} = "Limoux";
$areanames{fr}->{3344832} = "Langogne";
$areanames{fr}->{3344833} = "Prades";
$areanames{fr}->{3344834} = "Montpellier";
$areanames{fr}->{3344835} = "Nîmes";
$areanames{fr}->{3344836} = "Carcassonne";
$areanames{fr}->{3344837} = "Castelnaudary";
$areanames{fr}->{3344838} = "Limoux";
$areanames{fr}->{3344839} = "Narbonne";
$areanames{fr}->{3344840} = "Ales";
$areanames{fr}->{3344841} = "Bagnols\-sur\-Ceze";
$areanames{fr}->{3344842} = "Nîmes";
$areanames{fr}->{3344843} = "Bedarieux";
$areanames{fr}->{3344844} = "Beziers";
$areanames{fr}->{3344845} = "Montpellier";
$areanames{fr}->{3344846} = "Perpignan";
$areanames{fr}->{3344847} = "Prades";
$areanames{fr}->{3344848} = "Montpellier";
$areanames{fr}->{3344849} = "Carcassonne";
$areanames{fr}->{3344850} = "Perpignan";
$areanames{fr}->{3344851} = "Narbonne";
$areanames{fr}->{3344852} = "Beziers";
$areanames{fr}->{3344853} = "Ales";
$areanames{fr}->{3344854} = "Bedarieux";
$areanames{fr}->{3344855} = "Prades";
$areanames{fr}->{3344856} = "Beziers";
$areanames{fr}->{3344857} = "Perpignan";
$areanames{fr}->{3344858} = "Nîmes";
$areanames{fr}->{3344859} = "Castelnaudary";
$areanames{fr}->{3344860} = "Limoux";
$areanames{fr}->{3344861} = "Ales";
$areanames{fr}->{3344862} = "Bedarieux";
$areanames{fr}->{3344863} = "Langogne";
$areanames{fr}->{3344864} = "Mende";
$areanames{fr}->{3344865} = "Prades";
$areanames{fr}->{3344866} = "Carcassonne";
$areanames{fr}->{3344867} = "Montpellier";
$areanames{fr}->{3344868} = "Nîmes";
$areanames{fr}->{3344869} = "Ales";
$areanames{fr}->{3344870} = "Bagnols\-sur\-Ceze";
$areanames{fr}->{3344871} = "Nîmes";
$areanames{fr}->{3344872} = "Bedarieux";
$areanames{fr}->{3344873} = "Beziers";
$areanames{fr}->{3344874} = "Montpellier";
$areanames{fr}->{3344875} = "Montpellier";
$areanames{fr}->{3344876} = "Nîmes";
$areanames{fr}->{3344877} = "Montpellier";
$areanames{fr}->{3344878} = "Montpellier";
$areanames{fr}->{3344879} = "Montpellier";
$areanames{fr}->{3344880} = "Montpellier";
$areanames{fr}->{3344881} = "Carcassonne";
$areanames{fr}->{3344882} = "Castelnaudary";
$areanames{fr}->{3344883} = "Limoux";
$areanames{fr}->{3344884} = "Narbonne";
$areanames{fr}->{3344885} = "Ales";
$areanames{fr}->{3344886} = "Bagnols\-sur\-Ceze";
$areanames{fr}->{3344887} = "Nîmes";
$areanames{fr}->{3344888} = "Mende";
$areanames{fr}->{3344889} = "Perpignan";
$areanames{fr}->{3344890} = "Beziers";
$areanames{fr}->{3344891} = "Nîmes";
$areanames{fr}->{3344892} = "Nîmes";
$areanames{fr}->{3344893} = "Bedarieux";
$areanames{fr}->{3344894} = "Beziers";
$areanames{fr}->{3344895} = "Montpellier";
$areanames{fr}->{3344896} = "Langogne";
$areanames{fr}->{3344897} = "Mende";
$areanames{fr}->{3344898} = "Perpignan";
$areanames{fr}->{3344899} = "Prades";
$areanames{fr}->{3344900} = "Ales";
$areanames{fr}->{3344901} = "Perpignan";
$areanames{fr}->{3344902} = "Montpellier";
$areanames{fr}->{3344903} = "Carcassonne";
$areanames{fr}->{3344904} = "Perpignan";
$areanames{fr}->{3344905} = "Nîmes";
$areanames{fr}->{3344906} = "Beziers";
$areanames{fr}->{3344907} = "Montpellier";
$areanames{fr}->{3344908} = "Perpignan";
$areanames{fr}->{3344909} = "Bagnols\-sur\-Ceze";
$areanames{fr}->{3345600} = "Grenoble";
$areanames{fr}->{3345601} = "Le\ Bourg\-dOisans";
$areanames{fr}->{3345602} = "Bellegarde\-sur\-Valserine";
$areanames{fr}->{3345603} = "Le\ Bourg\-dOisans";
$areanames{fr}->{3345604} = "Monestier\-de\-Clermont";
$areanames{fr}->{3345605} = "Grenoble";
$areanames{fr}->{3345606} = "Aix\-les\-Bains";
$areanames{fr}->{3345607} = "Albertville";
$areanames{fr}->{3345608} = "Chambery";
$areanames{fr}->{3345609} = "Grenoble";
$areanames{fr}->{3345620} = "Annecy";
$areanames{fr}->{3345621} = "Saint\-Marcellin";
$areanames{fr}->{3345622} = "Voiron";
$areanames{fr}->{3345623} = "Belley";
$areanames{fr}->{3345624} = "Grenoble";
$areanames{fr}->{3345625} = "Voiron";
$areanames{fr}->{3345626} = "Voiron";
$areanames{fr}->{3345627} = "Aix\-les\-Bains";
$areanames{fr}->{3345628} = "Albertville";
$areanames{fr}->{3345629} = "Chambery";
$areanames{fr}->{3345630} = "Annemasse";
$areanames{fr}->{3345631} = "Moutiers";
$areanames{fr}->{3345632} = "Saint\-Jean\-de\-Maurienne";
$areanames{fr}->{3345633} = "Saint\-Marcellin";
$areanames{fr}->{3345634} = "Annecy";
$areanames{fr}->{3345635} = "Annemasse";
$areanames{fr}->{3345636} = "Annemasse";
$areanames{fr}->{3345637} = "Sallanches";
$areanames{fr}->{3345638} = "Grenoble";
$areanames{fr}->{3345639} = "Aix\-les\-Bains";
$areanames{fr}->{3345640} = "Grenoble";
$areanames{fr}->{3345641} = "Annecy";
$areanames{fr}->{3345642} = "Chambery";
$areanames{fr}->{3345643} = "Albertville";
$areanames{fr}->{3345644} = "Annemasse";
$areanames{fr}->{3345645} = "Grenoble";
$areanames{fr}->{3345646} = "Sallanches";
$areanames{fr}->{3345647} = "Voiron";
$areanames{fr}->{3345648} = "Aix\-les\-Bains";
$areanames{fr}->{3345649} = "Annecy";
$areanames{fr}->{3345650} = "Chambery";
$areanames{fr}->{3345651} = "Moutiers";
$areanames{fr}->{3345652} = "Grenoble";
$areanames{fr}->{3345653} = "Saint\-Jean\-de\-Maurienne";
$areanames{fr}->{3345654} = "Belley";
$areanames{fr}->{3345655} = "Monestier\-de\-Clermont";
$areanames{fr}->{3345656} = "La\ Mure";
$areanames{fr}->{3345657} = "Aix\-les\-Bains";
$areanames{fr}->{3345658} = "Grenoble";
$areanames{fr}->{3345659} = "Grenoble";
$areanames{fr}->{3345660} = "Grenoble";
$areanames{fr}->{3345661} = "Grenoble";
$areanames{fr}->{3345662} = "Voiron";
$areanames{fr}->{3345663} = "Voiron";
$areanames{fr}->{3345664} = "Chambery";
$areanames{fr}->{3345665} = "Chambery";
$areanames{fr}->{3345666} = "Annemasse";
$areanames{fr}->{3345667} = "Annecy";
$areanames{fr}->{3345668} = "Annecy";
$areanames{fr}->{3345669} = "Sallanches";
$areanames{fr}->{3345670} = "Annecy";
$areanames{fr}->{3345671} = "Annecy";
$areanames{fr}->{3345672} = "Annecy";
$areanames{fr}->{3345673} = "Annecy";
$areanames{fr}->{3345674} = "Annecy";
$areanames{fr}->{3345675} = "Chambery";
$areanames{fr}->{3345676} = "Chambery";
$areanames{fr}->{3345677} = "Chambery";
$areanames{fr}->{3345678} = "Chambery";
$areanames{fr}->{3345679} = "Chambery";
$areanames{fr}->{3345690} = "Grenoble";
$areanames{fr}->{3345691} = "Bellegarde\-sur\-Valserine";
$areanames{fr}->{3345692} = "Bellegarde\-sur\-Valserine";
$areanames{fr}->{3345693} = "Belley";
$areanames{fr}->{3345694} = "Le\ Bourg\-dOisans";
$areanames{fr}->{3345695} = "Monestier\-de\-Clermont";
$areanames{fr}->{3345696} = "Saint\-Jean\-de\-Maurienne";
$areanames{fr}->{3345697} = "La\ Mure";
$areanames{fr}->{3345698} = "Saint\-Marcellin";
$areanames{fr}->{3345699} = "Voiron";
$areanames{fr}->{3345700} = "Grenoble";
$areanames{fr}->{3345701} = "Voiron";
$areanames{fr}->{3345702} = "Grenoble";
$areanames{fr}->{3345703} = "Belley";
$areanames{fr}->{3345704} = "Grenoble";
$areanames{fr}->{3345705} = "Bellegarde\-sur\-Valserine";
$areanames{fr}->{3345706} = "Annecy";
$areanames{fr}->{3345707} = "Grenoble";
$areanames{fr}->{3345708} = "Chambery";
$areanames{fr}->{3345709} = "Annecy";
$areanames{fr}->{3345720} = "Voiron";
$areanames{fr}->{3345721} = "Grenoble";
$areanames{fr}->{3345722} = "Annemasse";
$areanames{fr}->{3345723} = "Voiron";
$areanames{fr}->{3345724} = "Aix\-les\-Bains";
$areanames{fr}->{3345725} = "Albertville";
$areanames{fr}->{3345726} = "Annemasse";
$areanames{fr}->{3345727} = "Sallanches";
$areanames{fr}->{3345728} = "Bellegarde\-sur\-Valserine";
$areanames{fr}->{3345729} = "Belley";
$areanames{fr}->{3345750} = "Monestier\-de\-Clermont";
$areanames{fr}->{3345751} = "Moutiers";
$areanames{fr}->{3345752} = "Saint\-Jean\-de\-Maurienne";
$areanames{fr}->{3345753} = "Saint\-Marcellin";
$areanames{fr}->{3345754} = "Sallanches";
$areanames{fr}->{3345755} = "Moutiers";
$areanames{fr}->{3345756} = "Voiron";
$areanames{fr}->{3345757} = "Annecy";
$areanames{fr}->{3345758} = "Grenoble";
$areanames{fr}->{3345759} = "La\ Mure";
$areanames{fr}->{3345760} = "Aix\-les\-Bains";
$areanames{fr}->{3345761} = "Albertville";
$areanames{fr}->{3345762} = "Annemasse";
$areanames{fr}->{3345763} = "Moutiers";
$areanames{fr}->{3345764} = "Saint\-Jean\-de\-Maurienne";
$areanames{fr}->{3345765} = "Sallanches";
$areanames{fr}->{3345766} = "Le\ Bourg\-dOisans";
$areanames{fr}->{3345767} = "Bellegarde\-sur\-Valserine";
$areanames{fr}->{3345768} = "Monestier\-de\-Clermont";
$areanames{fr}->{3345769} = "La\ Mure";
$areanames{fr}->{3345770} = "Saint\-Marcellin";
$areanames{fr}->{3345771} = "Belley";
$areanames{fr}->{3345772} = "Aix\-les\-Bains";
$areanames{fr}->{3345773} = "Chambery";
$areanames{fr}->{3345774} = "Annecy";
$areanames{fr}->{3345775} = "Annemasse";
$areanames{fr}->{3345776} = "Annecy";
$areanames{fr}->{3345777} = "Annemasse";
$areanames{fr}->{3345778} = "Chambery";
$areanames{fr}->{3345779} = "Grenoble";
$areanames{fr}->{3345780} = "Sallanches";
$areanames{fr}->{3345781} = "Voiron";
$areanames{fr}->{3345782} = "Saint\-Marcellin";
$areanames{fr}->{3345783} = "Saint\-Jean\-de\-Maurienne";
$areanames{fr}->{3345784} = "Annemasse";
$areanames{fr}->{3345785} = "Chambery";
$areanames{fr}->{3345786} = "Sallanches";
$areanames{fr}->{3345787} = "Voiron";
$areanames{fr}->{3345788} = "Annemasse";
$areanames{fr}->{3345789} = "Annecy";
$areanames{fr}->{3345790} = "Grenoble";
$areanames{fr}->{3345791} = "Sallanches";
$areanames{fr}->{3345792} = "Voiron";
$areanames{fr}->{3345793} = "Grenoble";
$areanames{fr}->{3345794} = "Bellegarde\-sur\-Valserine";
$areanames{fr}->{3345795} = "Aix\-les\-Bains";
$areanames{fr}->{3345796} = "Albertville";
$areanames{fr}->{3345797} = "Aix\-les\-Bains";
$areanames{fr}->{3345798} = "Annecy";
$areanames{fr}->{3345799} = "Chambery";
$areanames{fr}->{3345800} = "Grenoble";
$areanames{fr}->{3345801} = "Chambery";
$areanames{fr}->{3345802} = "Annecy";
$areanames{fr}->{3345803} = "Le\ Bourg\-dOisans";
$areanames{fr}->{3345804} = "Chambery";
$areanames{fr}->{3345805} = "Grenoble";
$areanames{fr}->{3345806} = "Monestier\-de\-Clermont";
$areanames{fr}->{3345807} = "La\ Mure";
$areanames{fr}->{3345808} = "Saint\-Marcellin";
$areanames{fr}->{3345809} = "Voiron";
$areanames{fr}->{3345810} = "Annecy";
$areanames{fr}->{3345811} = "Belley";
$areanames{fr}->{3345812} = "Chambery";
$areanames{fr}->{3345813} = "Annecy";
$areanames{fr}->{3345814} = "Chambery";
$areanames{fr}->{3345815} = "Voiron";
$areanames{fr}->{3345816} = "Aix\-les\-Bains";
$areanames{fr}->{3345817} = "Grenoble";
$areanames{fr}->{3345818} = "Grenoble";
$areanames{fr}->{3345819} = "Le\ Bourg\-dOisans";
$areanames{fr}->{3345820} = "Monestier\-de\-Clermont";
$areanames{fr}->{3345821} = "La\ Mure";
$areanames{fr}->{3345822} = "Saint\-Marcellin";
$areanames{fr}->{3345823} = "Albertville";
$areanames{fr}->{3345824} = "Moutiers";
$areanames{fr}->{3345825} = "Saint\-Jean\-de\-Maurienne";
$areanames{fr}->{3345826} = "Le\ Bourg\-dOisans";
$areanames{fr}->{3345827} = "Grenoble";
$areanames{fr}->{3345828} = "Monestier\-de\-Clermont";
$areanames{fr}->{3345829} = "La\ Mure";
$areanames{fr}->{3345830} = "Saint\-Marcellin";
$areanames{fr}->{3345831} = "Voiron";
$areanames{fr}->{3345832} = "Aix\-les\-Bains";
$areanames{fr}->{3345833} = "Albertville";
$areanames{fr}->{3345834} = "Chambery";
$areanames{fr}->{3345835} = "Moutiers";
$areanames{fr}->{3345836} = "Saint\-Jean\-de\-Maurienne";
$areanames{fr}->{3345837} = "Annemasse";
$areanames{fr}->{3345838} = "Sallanches";
$areanames{fr}->{3345839} = "Aix\-les\-Bains";
$areanames{fr}->{3345840} = "Albertville";
$areanames{fr}->{3345841} = "Bellegarde\-sur\-Valserine";
$areanames{fr}->{3345842} = "La\ Mure";
$areanames{fr}->{3345843} = "Grenoble";
$areanames{fr}->{3345844} = "Chambery";
$areanames{fr}->{3345845} = "Belley";
$areanames{fr}->{3345846} = "Grenoble";
$areanames{fr}->{3345847} = "Grenoble";
$areanames{fr}->{3345848} = "Chambery";
$areanames{fr}->{3345849} = "Belley";
$areanames{fr}->{3345850} = "Annemasse";
$areanames{fr}->{3345851} = "Voiron";
$areanames{fr}->{3345852} = "Annecy";
$areanames{fr}->{3345853} = "Aix\-les\-Bains";
$areanames{fr}->{3345854} = "Annecy";
$areanames{fr}->{3345855} = "Grenoble";
$areanames{fr}->{3345856} = "Sallanches";
$areanames{fr}->{3345857} = "Annemasse";
$areanames{fr}->{3345858} = "Annecy";
$areanames{fr}->{3345859} = "Le\ Bourg\-dOisans";
$areanames{fr}->{3345860} = "Grenoble";
$areanames{fr}->{3345861} = "Chambery";
$areanames{fr}->{3345862} = "Aix\-les\-Bains";
$areanames{fr}->{3345863} = "Annecy";
$areanames{fr}->{3345864} = "Annemasse";
$areanames{fr}->{3345865} = "Sallanches";
$areanames{fr}->{3345866} = "Annemasse";
$areanames{fr}->{3345867} = "Grenoble";
$areanames{fr}->{3345868} = "Monestier\-de\-Clermont";
$areanames{fr}->{3345869} = "La\ Mure";
$areanames{fr}->{3345870} = "Saint\-Marcellin";
$areanames{fr}->{3345871} = "Voiron";
$areanames{fr}->{3345872} = "Aix\-les\-Bains";
$areanames{fr}->{3345873} = "Albertville";
$areanames{fr}->{3345874} = "Moutiers";
$areanames{fr}->{3345875} = "Saint\-Jean\-de\-Maurienne";
$areanames{fr}->{3345876} = "Annemasse";
$areanames{fr}->{3345877} = "Sallanches";
$areanames{fr}->{3345878} = "Annemasse";
$areanames{fr}->{3345879} = "Sallanches";
$areanames{fr}->{3345880} = "Grenoble";
$areanames{fr}->{3345881} = "Saint\-Jean\-de\-Maurienne";
$areanames{fr}->{3345882} = "Chambery";
$areanames{fr}->{3345883} = "Moutiers";
$areanames{fr}->{3345884} = "Grenoble";
$areanames{fr}->{3345885} = "Albertville";
$areanames{fr}->{3345886} = "Le\ Bourg\-dOisans";
$areanames{fr}->{3345887} = "Voiron";
$areanames{fr}->{3345888} = "Saint\-Marcellin";
$areanames{fr}->{3345889} = "Voiron";
$areanames{fr}->{3345890} = "Chambery";
$areanames{fr}->{3345891} = "Albertville";
$areanames{fr}->{3345892} = "Annemasse";
$areanames{fr}->{3345893} = "Bellegarde\-sur\-Valserine";
$areanames{fr}->{3345894} = "Belley";
$areanames{fr}->{3345895} = "Moutiers";
$areanames{fr}->{3345896} = "Saint\-Jean\-de\-Maurienne";
$areanames{fr}->{3345897} = "Sallanches";
$areanames{fr}->{3345898} = "Annecy";
$areanames{fr}->{3345899} = "Annemasse";
$areanames{fr}->{3346300} = "Ambert";
$areanames{fr}->{3346301} = "Clermont\-Ferrand";
$areanames{fr}->{3346302} = "Montlucon";
$areanames{fr}->{3346303} = "Saint\-Flour";
$areanames{fr}->{3346304} = "Clermont\-Ferrand";
$areanames{fr}->{3346305} = "Clermont\-Ferrand";
$areanames{fr}->{3346306} = "Bourbon\-lArchambault";
$areanames{fr}->{3346307} = "Moulins";
$areanames{fr}->{3346308} = "Clermont\-Ferrand";
$areanames{fr}->{3346309} = "Bourbon\-lArchambault";
$areanames{fr}->{3346310} = "Montlucon";
$areanames{fr}->{3346311} = "Moulins";
$areanames{fr}->{3346312} = "Vichy";
$areanames{fr}->{3346313} = "Aurillac";
$areanames{fr}->{3346314} = "Mauriac";
$areanames{fr}->{3346315} = "Saint\-Flour";
$areanames{fr}->{3346316} = "Brioude";
$areanames{fr}->{3346317} = "Le\ Puy\-en\-Velay";
$areanames{fr}->{3346318} = "Yssingeaux";
$areanames{fr}->{3346319} = "Ambert";
$areanames{fr}->{3346330} = "Clermont\-Ferrand";
$areanames{fr}->{3346331} = "Brioude";
$areanames{fr}->{3346332} = "Clermont\-Ferrand";
$areanames{fr}->{3346333} = "Ambert";
$areanames{fr}->{3346334} = "Ambert";
$areanames{fr}->{3346335} = "Vichy";
$areanames{fr}->{3346336} = "Aurillac";
$areanames{fr}->{3346337} = "Le\ Puy\-en\-Velay";
$areanames{fr}->{3346338} = "Aurillac";
$areanames{fr}->{3346339} = "Bourbon\-lArchambault";
$areanames{fr}->{3346340} = "Ambert";
$areanames{fr}->{3346341} = "Aurillac";
$areanames{fr}->{3346342} = "La\ Bourboule";
$areanames{fr}->{3346343} = "Clermont\-Ferrand";
$areanames{fr}->{3346344} = "Issoire";
$areanames{fr}->{3346345} = "Brioude";
$areanames{fr}->{3346346} = "Clermont\-Ferrand";
$areanames{fr}->{3346347} = "Issoire";
$areanames{fr}->{3346348} = "Mauriac";
$areanames{fr}->{3346349} = "Montlucon";
$areanames{fr}->{3346350} = "Moulins";
$areanames{fr}->{3346351} = "Roanne";
$areanames{fr}->{3346352} = "Le\ Puy\-en\-Velay";
$areanames{fr}->{3346353} = "Issoire";
$areanames{fr}->{3346354} = "Riom";
$areanames{fr}->{3346355} = "La\ Bourboule";
$areanames{fr}->{3346356} = "Saint\-Flour";
$areanames{fr}->{3346357} = "Thiers";
$areanames{fr}->{3346358} = "Vichy";
$areanames{fr}->{3346359} = "Brioude";
$areanames{fr}->{3346360} = "Clermont\-Ferrand";
$areanames{fr}->{3346361} = "Riom";
$areanames{fr}->{3346362} = "Thiers";
$areanames{fr}->{3346363} = "Riom";
$areanames{fr}->{3346364} = "Vichy";
$areanames{fr}->{3346365} = "Roanne";
$areanames{fr}->{3346366} = "Clermont\-Ferrand";
$areanames{fr}->{3346367} = "Clermont\-Ferrand";
$areanames{fr}->{3346368} = "Issoire";
$areanames{fr}->{3346369} = "Riom";
$areanames{fr}->{3346370} = "Thiers";
$areanames{fr}->{3346371} = "Yssingeaux";
$areanames{fr}->{3346372} = "Montlucon";
$areanames{fr}->{3346373} = "Moulins";
$areanames{fr}->{3346374} = "Yssingeaux";
$areanames{fr}->{3346375} = "Yssingeaux";
$areanames{fr}->{3346376} = "Bourbon\-lArchambault";
$areanames{fr}->{3346377} = "La\ Bourboule";
$areanames{fr}->{3346378} = "Brioude";
$areanames{fr}->{3346379} = "Clermont\-Ferrand";
$areanames{fr}->{3346380} = "Issoire";
$areanames{fr}->{3346381} = "Mauriac";
$areanames{fr}->{3346382} = "Montlucon";
$areanames{fr}->{3346383} = "Moulins";
$areanames{fr}->{3346384} = "Le\ Puy\-en\-Velay";
$areanames{fr}->{3346385} = "Riom";
$areanames{fr}->{3346386} = "Saint\-Flour";
$areanames{fr}->{3346387} = "Thiers";
$areanames{fr}->{3346388} = "Vichy";
$areanames{fr}->{3346389} = "Yssingeaux";
$areanames{fr}->{3346390} = "Bourbon\-lArchambault";
$areanames{fr}->{3346391} = "Montlucon";
$areanames{fr}->{3346392} = "Moulins";
$areanames{fr}->{3346393} = "Vichy";
$areanames{fr}->{3346394} = "Aurillac";
$areanames{fr}->{3346395} = "Mauriac";
$areanames{fr}->{3346396} = "Saint\-Flour";
$areanames{fr}->{3346397} = "Brioude";
$areanames{fr}->{3346398} = "Le\ Puy\-en\-Velay";
$areanames{fr}->{3346399} = "Yssingeaux";
$areanames{fr}->{3346500} = "Avignon";
$areanames{fr}->{3346501} = "Marignane";
$areanames{fr}->{3346502} = "Orange";
$areanames{fr}->{3346503} = "Gap";
$areanames{fr}->{3346504} = "Aix\-en\-Provence";
$areanames{fr}->{3346505} = "Marignane";
$areanames{fr}->{3346506} = "Marseille";
$areanames{fr}->{3346507} = "Aix\-en\-Provence";
$areanames{fr}->{3346508} = "Arles";
$areanames{fr}->{3346509} = "Cavaillon";
$areanames{fr}->{3346510} = "Manosque";
$areanames{fr}->{3346511} = "Marseille";
$areanames{fr}->{3346512} = "Marseille";
$areanames{fr}->{3346513} = "Digne\-les\-Bains";
$areanames{fr}->{3346514} = "Gap";
$areanames{fr}->{3346515} = "Aix\-en\-Provence";
$areanames{fr}->{3346516} = "Arles";
$areanames{fr}->{3346517} = "Aubagne";
$areanames{fr}->{3346518} = "Marignane";
$areanames{fr}->{3346519} = "Aix\-en\-Provence";
$areanames{fr}->{3346520} = "Avignon";
$areanames{fr}->{3346521} = "Marseille";
$areanames{fr}->{3346522} = "Saint\-André\-les\-Alpes";
$areanames{fr}->{3346523} = "Pertuis";
$areanames{fr}->{3346524} = "Avignon";
$areanames{fr}->{3346525} = "Orange";
$areanames{fr}->{3346526} = "Aix\-en\-Provence";
$areanames{fr}->{3346527} = "Marseille";
$areanames{fr}->{3346528} = "Aubagne";
$areanames{fr}->{3346529} = "Marignane";
$areanames{fr}->{3346530} = "Cavaillon";
$areanames{fr}->{3346531} = "Marseille";
$areanames{fr}->{3346532} = "Digne\-les\-Bains";
$areanames{fr}->{3346533} = "Marseille";
$areanames{fr}->{3346534} = "Manosque";
$areanames{fr}->{3346535} = "Digne\-les\-Bains";
$areanames{fr}->{3346536} = "Aix\-en\-Provence";
$areanames{fr}->{3346537} = "Marseille";
$areanames{fr}->{3346538} = "Marseille";
$areanames{fr}->{3346539} = "Marseille";
$areanames{fr}->{3346540} = "Marseille";
$areanames{fr}->{3346541} = "Marseille";
$areanames{fr}->{3346542} = "Marseille";
$areanames{fr}->{3346543} = "Marseille";
$areanames{fr}->{3346544} = "Digne\-les\-Bains";
$areanames{fr}->{3346545} = "Manosque";
$areanames{fr}->{3346546} = "Saint\-André\-les\-Alpes";
$areanames{fr}->{3346547} = "Gap";
$areanames{fr}->{3346548} = "Aix\-en\-Provence";
$areanames{fr}->{3346549} = "Arles";
$areanames{fr}->{3346550} = "Aubagne";
$areanames{fr}->{3346551} = "Marignane";
$areanames{fr}->{3346552} = "Marseille";
$areanames{fr}->{3346553} = "Avignon";
$areanames{fr}->{3346554} = "Cavaillon";
$areanames{fr}->{3346555} = "Orange";
$areanames{fr}->{3346556} = "Pertuis";
$areanames{fr}->{3346557} = "Marseille";
$areanames{fr}->{3346558} = "Marseille";
$areanames{fr}->{3346559} = "Marseille";
$areanames{fr}->{3346560} = "Gap";
$areanames{fr}->{3346561} = "Digne\-les\-Bains";
$areanames{fr}->{3346562} = "Avignon";
$areanames{fr}->{3346563} = "Marseille";
$areanames{fr}->{3346564} = "Aubagne";
$areanames{fr}->{3346565} = "Marseille";
$areanames{fr}->{3346566} = "Marseille";
$areanames{fr}->{3346567} = "Avignon";
$areanames{fr}->{3346568} = "Avignon";
$areanames{fr}->{3346569} = "Manosque";
$areanames{fr}->{3346570} = "Arles";
$areanames{fr}->{3346572} = "Marseille";
$areanames{fr}->{3346573} = "Manosque";
$areanames{fr}->{3346574} = "Saint\-André\-les\-Alpes";
$areanames{fr}->{3346575} = "Cavaillon";
$areanames{fr}->{3346576} = "Orange";
$areanames{fr}->{3346577} = "Pertuis";
$areanames{fr}->{3346578} = "Arles";
$areanames{fr}->{3346579} = "Orange";
$areanames{fr}->{3346580} = "Pertuis";
$areanames{fr}->{3346581} = "Avignon";
$areanames{fr}->{3346582} = "Marseille";
$areanames{fr}->{3346583} = "Orange";
$areanames{fr}->{3346584} = "Marseille";
$areanames{fr}->{3346585} = "Marseille";
$areanames{fr}->{3346586} = "Aix\-en\-Provence";
$areanames{fr}->{3346587} = "Avignon";
$areanames{fr}->{3346588} = "Arles";
$areanames{fr}->{3346589} = "Orange";
$areanames{fr}->{3346590} = "Gap";
$areanames{fr}->{3346591} = "Marseille";
$areanames{fr}->{3346592} = "Aix\-en\-Provence";
$areanames{fr}->{3346593} = "Marseille";
$areanames{fr}->{3346594} = "Marignane";
$areanames{fr}->{3346595} = "Marseille";
$areanames{fr}->{3346596} = "Marseille";
$areanames{fr}->{3346597} = "Marseille";
$areanames{fr}->{3346598} = "Marseille";
$areanames{fr}->{334661} = "Sud\ Est";
$areanames{fr}->{3346617} = "Mende";
$areanames{fr}->{3346618} = "Nîmes";
$areanames{fr}->{3346619} = "Nîmes";
$areanames{fr}->{3346690} = "Bagnols\-sur\-Ceze";
$areanames{fr}->{3346691} = "Ales";
$areanames{fr}->{3346692} = "Ales";
$areanames{fr}->{3346693} = "Nîmes";
$areanames{fr}->{3346694} = "Mende";
$areanames{fr}->{3346695} = "Nîmes";
$areanames{fr}->{3346696} = "Bagnols\-sur\-Ceze";
$areanames{fr}->{3346697} = "Sud\ Est";
$areanames{fr}->{3346698} = "Bagnols\-sur\-Ceze";
$areanames{fr}->{3346699} = "Sud\ Est";
$areanames{fr}->{3346900} = "Bourgoin\-Jallieu";
$areanames{fr}->{3346901} = "Vienne";
$areanames{fr}->{3346902} = "Annonay";
$areanames{fr}->{3346903} = "Aubenas";
$areanames{fr}->{3346904} = "Die";
$areanames{fr}->{3346905} = "Feurs";
$areanames{fr}->{3346906} = "Nyons";
$areanames{fr}->{3346907} = "Roanne";
$areanames{fr}->{3346908} = "Saint\-Vallier";
$areanames{fr}->{3346909} = "Tarare";
$areanames{fr}->{3346910} = "Tournon\-sur\-Rhone";
$areanames{fr}->{3346911} = "Valence";
$areanames{fr}->{3346912} = "Villefranche\-sur\-Saone";
$areanames{fr}->{3346913} = "Amberieu\-en\-Bugey";
$areanames{fr}->{3346914} = "Montelimar";
$areanames{fr}->{3346915} = "Bourgoin\-Jallieu";
$areanames{fr}->{3346916} = "Lyon";
$areanames{fr}->{3346917} = "Villefranche\-sur\-Saone";
$areanames{fr}->{3346918} = "Amberieu\-en\-Bugey";
$areanames{fr}->{3346919} = "Bourg\-en\-Bresse";
$areanames{fr}->{3346920} = "Nantua";
$areanames{fr}->{3346921} = "Annonay";
$areanames{fr}->{3346922} = "Aubenas";
$areanames{fr}->{3346923} = "Privas";
$areanames{fr}->{3346924} = "Tournon\-sur\-Rhone";
$areanames{fr}->{3346925} = "Die";
$areanames{fr}->{3346926} = "Montelimar";
$areanames{fr}->{3346927} = "Nyons";
$areanames{fr}->{3346928} = "Romans\-sur\-Isere";
$areanames{fr}->{3346929} = "Saint\-Vallier";
$areanames{fr}->{3346940} = "Annonay";
$areanames{fr}->{3346941} = "Bourg\-en\-Bresse";
$areanames{fr}->{3346942} = "Bourgoin\-Jallieu";
$areanames{fr}->{3346943} = "Montelimar";
$areanames{fr}->{3346944} = "Nantua";
$areanames{fr}->{3346945} = "Roanne";
$areanames{fr}->{3346946} = "Vienne";
$areanames{fr}->{3346947} = "Villefranche\-sur\-Saone";
$areanames{fr}->{3346948} = "Nantua";
$areanames{fr}->{3346949} = "Bourg\-en\-Bresse";
$areanames{fr}->{3346950} = "Bourgoin\-Jallieu";
$areanames{fr}->{3346951} = "Saint\-Etienne";
$areanames{fr}->{3346952} = "Valence";
$areanames{fr}->{3346953} = "Vienne";
$areanames{fr}->{3346954} = "Bourg\-en\-Bresse";
$areanames{fr}->{3346955} = "Lyon";
$areanames{fr}->{3346956} = "Montelimar";
$areanames{fr}->{3346957} = "Romans\-sur\-Isere";
$areanames{fr}->{3346958} = "Saint\-Etienne";
$areanames{fr}->{3346959} = "Tarare";
$areanames{fr}->{3346980} = "Romans\-sur\-Isere";
$areanames{fr}->{3346981} = "Bourg\-en\-Bresse";
$areanames{fr}->{3346982} = "Bourgoin\-Jallieu";
$areanames{fr}->{3346983} = "Feurs";
$areanames{fr}->{3346984} = "Lyon";
$areanames{fr}->{3346985} = "Lyon";
$areanames{fr}->{3346986} = "Montelimar";
$areanames{fr}->{3346987} = "Nantua";
$areanames{fr}->{3346988} = "Bourg\-en\-Bresse";
$areanames{fr}->{3346989} = "Villefranche\-sur\-Saone";
$areanames{fr}->{3346990} = "Montelimar";
$areanames{fr}->{3346991} = "Nyons";
$areanames{fr}->{3346992} = "Privas";
$areanames{fr}->{3346993} = "Roanne";
$areanames{fr}->{3346994} = "Romans\-sur\-Isere";
$areanames{fr}->{3346995} = "Saint\-Etienne";
$areanames{fr}->{3346996} = "Lyon";
$areanames{fr}->{3346997} = "Annemasse";
$areanames{fr}->{3346998} = "Lyon";
$areanames{fr}->{3346999} = "Tarare";
$areanames{fr}->{334700} = "Montlucon";
$areanames{fr}->{3347000} = "Sud\ Est";
$areanames{fr}->{3347001} = "Sud\ Est";
$areanames{fr}->{334701} = "Sud\ Est";
$areanames{fr}->{3347050} = "Vichy";
$areanames{fr}->{3347051} = "Montlucon";
$areanames{fr}->{3347052} = "Moulins";
$areanames{fr}->{3347053} = "Sud\ Est";
$areanames{fr}->{3347054} = "Sud\ Est";
$areanames{fr}->{3347055} = "Vichy";
$areanames{fr}->{3347056} = "Vichy";
$areanames{fr}->{3347057} = "Moulins";
$areanames{fr}->{3347058} = "Vichy";
$areanames{fr}->{3347059} = "Vichy";
$areanames{fr}->{334707} = "Sud\ Est";
$areanames{fr}->{334708} = "Sud\ Est";
$areanames{fr}->{334711} = "Sud\ Est";
$areanames{fr}->{334713} = "Sud\ Est";
$areanames{fr}->{334718} = "Sud\ Est";
$areanames{fr}->{334719} = "Sud\ Est";
$areanames{fr}->{334730} = "Sud\ Est";
$areanames{fr}->{334731} = "Clermont\-Ferrand";
$areanames{fr}->{3347311} = "Sud\ Est";
$areanames{fr}->{3347312} = "Sud\ Est";
$areanames{fr}->{3347313} = "Moulins";
$areanames{fr}->{3347318} = "Sud\ Est";
$areanames{fr}->{334732} = "Clermont\-Ferrand";
$areanames{fr}->{3347321} = "La\ Bourboule";
$areanames{fr}->{3347322} = "La\ Bourboule";
$areanames{fr}->{334751} = "Sud\ Est";
$areanames{fr}->{3348000} = "Annemasse";
$areanames{fr}->{3348001} = "Bellegarde\-sur\-Valserine";
$areanames{fr}->{3348002} = "Belley";
$areanames{fr}->{3348003} = "Chambery";
$areanames{fr}->{3348004} = "Grenoble";
$areanames{fr}->{3348005} = "La\ Mure";
$areanames{fr}->{3348006} = "Le\ Bourg\-dOisans";
$areanames{fr}->{3348007} = "Monestier\-de\-Clermont";
$areanames{fr}->{3348008} = "Moutiers";
$areanames{fr}->{3348009} = "Saint\-Jean\-de\-Maurienne";
$areanames{fr}->{3348010} = "Saint\-Marcellin";
$areanames{fr}->{3348011} = "Sallanches";
$areanames{fr}->{3348012} = "Voiron";
$areanames{fr}->{3348013} = "Annemasse";
$areanames{fr}->{3348014} = "Chambery";
$areanames{fr}->{3348015} = "Grenoble";
$areanames{fr}->{3348016} = "Annemasse";
$areanames{fr}->{3348017} = "Bellegarde\-sur\-Valserine";
$areanames{fr}->{3348018} = "Le\ Bourg\-dOisans";
$areanames{fr}->{3348019} = "Monestier\-de\-Clermont";
$areanames{fr}->{3348020} = "La\ Mure";
$areanames{fr}->{3348021} = "Saint\-Marcellin";
$areanames{fr}->{3348022} = "Voiron";
$areanames{fr}->{3348023} = "Aix\-les\-Bains";
$areanames{fr}->{3348024} = "Albertville";
$areanames{fr}->{3348025} = "Chambery";
$areanames{fr}->{3348026} = "Moutiers";
$areanames{fr}->{3348027} = "Saint\-Jean\-de\-Maurienne";
$areanames{fr}->{3348028} = "Annecy";
$areanames{fr}->{3348029} = "Annemasse";
$areanames{fr}->{3348040} = "Belley";
$areanames{fr}->{3348041} = "Le\ Bourg\-dOisans";
$areanames{fr}->{3348042} = "Grenoble";
$areanames{fr}->{3348043} = "Monestier\-de\-Clermont";
$areanames{fr}->{3348044} = "La\ Mure";
$areanames{fr}->{3348045} = "Saint\-Marcellin";
$areanames{fr}->{3348046} = "Albertville";
$areanames{fr}->{3348047} = "Chambery";
$areanames{fr}->{3348048} = "Annecy";
$areanames{fr}->{3348049} = "Annecy";
$areanames{fr}->{3348050} = "Saint\-Jean\-de\-Maurienne";
$areanames{fr}->{3348051} = "Albertville";
$areanames{fr}->{3348052} = "Chambery";
$areanames{fr}->{3348053} = "Grenoble";
$areanames{fr}->{3348054} = "Saint\-Marcellin";
$areanames{fr}->{3348055} = "Aix\-les\-Bains";
$areanames{fr}->{3348056} = "Voiron";
$areanames{fr}->{3348057} = "Annemasse";
$areanames{fr}->{3348058} = "Sallanches";
$areanames{fr}->{3348059} = "Belley";
$areanames{fr}->{3348060} = "Le\ Bourg\-dOisans";
$areanames{fr}->{3348061} = "Grenoble";
$areanames{fr}->{3348062} = "Monestier\-de\-Clermont";
$areanames{fr}->{3348063} = "La\ Mure";
$areanames{fr}->{3348064} = "Saint\-Marcellin";
$areanames{fr}->{3348065} = "Voiron";
$areanames{fr}->{3348066} = "Aix\-les\-Bains";
$areanames{fr}->{3348067} = "Albertville";
$areanames{fr}->{3348068} = "Chambery";
$areanames{fr}->{3348069} = "Moutiers";
$areanames{fr}->{3348070} = "Grenoble";
$areanames{fr}->{3348071} = "Voiron";
$areanames{fr}->{3348072} = "Saint\-Jean\-de\-Maurienne";
$areanames{fr}->{3348073} = "Annecy";
$areanames{fr}->{3348074} = "Annemasse";
$areanames{fr}->{3348075} = "Sallanches";
$areanames{fr}->{3348076} = "Chambery";
$areanames{fr}->{3348077} = "Annemasse";
$areanames{fr}->{3348078} = "Annecy";
$areanames{fr}->{3348079} = "Voiron";
$areanames{fr}->{3348080} = "Grenoble";
$areanames{fr}->{3348081} = "Chambery";
$areanames{fr}->{3348082} = "Grenoble";
$areanames{fr}->{3348083} = "Grenoble";
$areanames{fr}->{3348084} = "Albertville";
$areanames{fr}->{3348085} = "Aix\-les\-Bains";
$areanames{fr}->{3348086} = "Albertville";
$areanames{fr}->{3348087} = "Chambery";
$areanames{fr}->{3348088} = "Annecy";
$areanames{fr}->{3348089} = "Annemasse";
$areanames{fr}->{3348090} = "Sallanches";
$areanames{fr}->{3348091} = "Bellegarde\-sur\-Valserine";
$areanames{fr}->{3348092} = "Annecy";
$areanames{fr}->{3348093} = "Grenoble";
$areanames{fr}->{3348094} = "Annecy";
$areanames{fr}->{3348095} = "Annemasse";
$areanames{fr}->{3348096} = "Sallanches";
$areanames{fr}->{3348097} = "Annecy";
$areanames{fr}->{3348098} = "Moutiers";
$areanames{fr}->{3348099} = "Annemasse";
$areanames{fr}->{3348100} = "Tarare";
$areanames{fr}->{3348101} = "Tournon\-sur\-Rhone";
$areanames{fr}->{3348102} = "Valence";
$areanames{fr}->{3348103} = "Vienne";
$areanames{fr}->{3348104} = "Villefranche\-sur\-Saone";
$areanames{fr}->{3348105} = "Die";
$areanames{fr}->{3348106} = "Lyon";
$areanames{fr}->{3348107} = "Lyon";
$areanames{fr}->{3348108} = "Saint\-Etienne";
$areanames{fr}->{3348109} = "Lyon";
$areanames{fr}->{3348110} = "Lyon";
$areanames{fr}->{3348111} = "Lyon";
$areanames{fr}->{3348112} = "Saint\-Etienne";
$areanames{fr}->{3348113} = "Lyon";
$areanames{fr}->{3348114} = "Tarare";
$areanames{fr}->{3348115} = "Villefranche\-sur\-Saone";
$areanames{fr}->{3348116} = "Valence";
$areanames{fr}->{3348117} = "Roanne";
$areanames{fr}->{3348118} = "Lyon";
$areanames{fr}->{3348119} = "Amberieu\-en\-Bugey";
$areanames{fr}->{3348120} = "Bourg\-en\-Bresse";
$areanames{fr}->{3348121} = "Nantua";
$areanames{fr}->{3348122} = "Annonay";
$areanames{fr}->{3348123} = "Aubenas";
$areanames{fr}->{3348124} = "Tournon\-sur\-Rhone";
$areanames{fr}->{3348125} = "Die";
$areanames{fr}->{3348126} = "Montelimar";
$areanames{fr}->{3348127} = "Nyons";
$areanames{fr}->{3348128} = "Romans\-sur\-Isere";
$areanames{fr}->{3348129} = "Saint\-Vallier";
$areanames{fr}->{3348130} = "Bourg\-en\-Bresse";
$areanames{fr}->{3348131} = "Aubenas";
$areanames{fr}->{3348132} = "Valence";
$areanames{fr}->{3348133} = "Saint\-Etienne";
$areanames{fr}->{3348134} = "Vienne";
$areanames{fr}->{3348135} = "Vienne";
$areanames{fr}->{3348136} = "Roanne";
$areanames{fr}->{3348137} = "Feurs";
$areanames{fr}->{3348138} = "Roanne";
$areanames{fr}->{3348139} = "Valence";
$areanames{fr}->{3348140} = "Saint\-Etienne";
$areanames{fr}->{3348141} = "Tarare";
$areanames{fr}->{3348142} = "Villefranche\-sur\-Saone";
$areanames{fr}->{3348143} = "Vienne";
$areanames{fr}->{3348144} = "Lyon";
$areanames{fr}->{3348145} = "Tarare";
$areanames{fr}->{3348146} = "Villefranche\-sur\-Saone";
$areanames{fr}->{3348147} = "Lyon";
$areanames{fr}->{3348148} = "Villefranche\-sur\-Saone";
$areanames{fr}->{3348149} = "Lyon";
$areanames{fr}->{3348150} = "Amberieu\-en\-Bugey";
$areanames{fr}->{3348151} = "Bourg\-en\-Bresse";
$areanames{fr}->{3348152} = "Annonay";
$areanames{fr}->{3348153} = "Aubenas";
$areanames{fr}->{3348154} = "Privas";
$areanames{fr}->{3348155} = "Bourgoin\-Jallieu";
$areanames{fr}->{3348156} = "Tournon\-sur\-Rhone";
$areanames{fr}->{3348157} = "Die";
$areanames{fr}->{3348158} = "Nyons";
$areanames{fr}->{3348159} = "Romans\-sur\-Isere";
$areanames{fr}->{3348160} = "Saint\-Vallier";
$areanames{fr}->{3348161} = "Bourgoin\-Jallieu";
$areanames{fr}->{3348162} = "Vienne";
$areanames{fr}->{3348163} = "Feurs";
$areanames{fr}->{3348164} = "Saint\-Etienne";
$areanames{fr}->{3348165} = "Lyon";
$areanames{fr}->{3348166} = "Valence";
$areanames{fr}->{3348167} = "Nantua";
$areanames{fr}->{3348168} = "Lyon";
$areanames{fr}->{3348169} = "Lyon";
$areanames{fr}->{3348170} = "Villefranche\-sur\-Saone";
$areanames{fr}->{3348171} = "Lyon";
$areanames{fr}->{3348172} = "Tarare";
$areanames{fr}->{3348173} = "Romans\-sur\-Isere";
$areanames{fr}->{3348174} = "Valence";
$areanames{fr}->{3348175} = "Die";
$areanames{fr}->{3348176} = "Lyon";
$areanames{fr}->{3348177} = "Feurs";
$areanames{fr}->{3348178} = "Roanne";
$areanames{fr}->{3348179} = "Villefranche\-sur\-Saone";
$areanames{fr}->{3348180} = "Tarare";
$areanames{fr}->{3348181} = "Villefranche\-sur\-Saone";
$areanames{fr}->{3348182} = "Montelimar";
$areanames{fr}->{3348183} = "Romans\-sur\-Isere";
$areanames{fr}->{3348184} = "Valence";
$areanames{fr}->{3348185} = "Saint\-Etienne";
$areanames{fr}->{3348186} = "Privas";
$areanames{fr}->{3348187} = "Romans\-sur\-Isere";
$areanames{fr}->{3348188} = "Lyon";
$areanames{fr}->{3348189} = "Annonay";
$areanames{fr}->{3348190} = "Romans\-sur\-Isere";
$areanames{fr}->{3348191} = "Lyon";
$areanames{fr}->{3348192} = "Lyon";
$areanames{fr}->{3348193} = "Lyon";
$areanames{fr}->{3348194} = "Bourg\-en\-Bresse";
$areanames{fr}->{3348195} = "Roanne";
$areanames{fr}->{3348196} = "Saint\-Etienne";
$areanames{fr}->{3348197} = "Bourgoin\-Jallieu";
$areanames{fr}->{3348198} = "Vienne";
$areanames{fr}->{3348199} = "Valence";
$areanames{fr}->{3348200} = "Bourg\-en\-Bresse";
$areanames{fr}->{3348201} = "Tournon\-sur\-Rhone";
$areanames{fr}->{3348202} = "Nantua";
$areanames{fr}->{3348203} = "Aubenas";
$areanames{fr}->{3348204} = "Saint\-Vallier";
$areanames{fr}->{3348205} = "Bourgoin\-Jallieu";
$areanames{fr}->{3348206} = "Vienne";
$areanames{fr}->{3348207} = "Amberieu\-en\-Bugey";
$areanames{fr}->{3348208} = "Nantua";
$areanames{fr}->{3348209} = "Bourg\-en\-Bresse";
$areanames{fr}->{3348210} = "Annonay";
$areanames{fr}->{3348211} = "Aubenas";
$areanames{fr}->{3348212} = "Privas";
$areanames{fr}->{3348213} = "Tournon\-sur\-Rhone";
$areanames{fr}->{3348214} = "Die";
$areanames{fr}->{3348215} = "Montelimar";
$areanames{fr}->{3348216} = "Nyons";
$areanames{fr}->{3348217} = "Romans\-sur\-Isere";
$areanames{fr}->{3348218} = "Saint\-Vallier";
$areanames{fr}->{3348219} = "Valence";
$areanames{fr}->{3348220} = "Bourgoin\-Jallieu";
$areanames{fr}->{3348221} = "Vienne";
$areanames{fr}->{3348222} = "Feurs";
$areanames{fr}->{3348223} = "Roanne";
$areanames{fr}->{3348224} = "Saint\-Etienne";
$areanames{fr}->{3348225} = "Lyon";
$areanames{fr}->{3348226} = "Tarare";
$areanames{fr}->{3348227} = "Villefranche\-sur\-Saone";
$areanames{fr}->{3348228} = "Saint\-Etienne";
$areanames{fr}->{3348229} = "Lyon";
$areanames{fr}->{3348230} = "Romans\-sur\-Isere";
$areanames{fr}->{3348231} = "Lyon";
$areanames{fr}->{3348232} = "Valence";
$areanames{fr}->{3348233} = "Lyon";
$areanames{fr}->{3348234} = "Montelimar";
$areanames{fr}->{3348235} = "Roanne";
$areanames{fr}->{3348236} = "Romans\-sur\-Isere";
$areanames{fr}->{3348237} = "Saint\-Etienne";
$areanames{fr}->{3348238} = "Tarare";
$areanames{fr}->{3348239} = "Valence";
$areanames{fr}->{3348240} = "Vienne";
$areanames{fr}->{3348241} = "Villefranche\-sur\-Saone";
$areanames{fr}->{3348242} = "Amberieu\-en\-Bugey";
$areanames{fr}->{3348243} = "Aubenas";
$areanames{fr}->{3348244} = "Privas";
$areanames{fr}->{3348245} = "Tournon\-sur\-Rhone";
$areanames{fr}->{3348246} = "Die";
$areanames{fr}->{3348247} = "Nyons";
$areanames{fr}->{3348248} = "Romans\-sur\-Isere";
$areanames{fr}->{3348249} = "Saint\-Vallier";
$areanames{fr}->{3348250} = "Feurs";
$areanames{fr}->{3348251} = "Tarare";
$areanames{fr}->{3348252} = "Lyon";
$areanames{fr}->{3348253} = "Lyon";
$areanames{fr}->{3348254} = "Lyon";
$areanames{fr}->{3348255} = "Annonay";
$areanames{fr}->{3348256} = "Aubenas";
$areanames{fr}->{3348257} = "Privas";
$areanames{fr}->{3348258} = "Tournon\-sur\-Rhone";
$areanames{fr}->{3348259} = "Die";
$areanames{fr}->{3348260} = "Montelimar";
$areanames{fr}->{3348261} = "Nyons";
$areanames{fr}->{3348262} = "Vienne";
$areanames{fr}->{3348263} = "Romans\-sur\-Isere";
$areanames{fr}->{3348264} = "Saint\-Vallier";
$areanames{fr}->{3348265} = "Valence";
$areanames{fr}->{3348266} = "Bourgoin\-Jallieu";
$areanames{fr}->{3348267} = "Vienne";
$areanames{fr}->{3348268} = "Feurs";
$areanames{fr}->{3348269} = "Roanne";
$areanames{fr}->{3348270} = "Saint\-Etienne";
$areanames{fr}->{3348271} = "Lyon";
$areanames{fr}->{3348272} = "Tarare";
$areanames{fr}->{3348273} = "Villefranche\-sur\-Saone";
$areanames{fr}->{3348274} = "Lyon";
$areanames{fr}->{3348275} = "Lyon";
$areanames{fr}->{3348276} = "Tournon\-sur\-Rhone";
$areanames{fr}->{3348277} = "Saint\-Etienne";
$areanames{fr}->{3348278} = "Lyon";
$areanames{fr}->{3348279} = "Lyon";
$areanames{fr}->{3348280} = "Lyon";
$areanames{fr}->{3348281} = "Saint\-Etienne";
$areanames{fr}->{3348282} = "Saint\-Etienne";
$areanames{fr}->{3348283} = "Villefranche\-sur\-Saone";
$areanames{fr}->{3348284} = "Bourg\-en\-Bresse";
$areanames{fr}->{3348285} = "Valence";
$areanames{fr}->{3348286} = "Vienne";
$areanames{fr}->{3348287} = "Roanne";
$areanames{fr}->{3348288} = "Nyons";
$areanames{fr}->{3348289} = "Saint\-Etienne";
$areanames{fr}->{3348290} = "Lyon";
$areanames{fr}->{3348291} = "Lyon";
$areanames{fr}->{3348292} = "Bourgoin\-Jallieu";
$areanames{fr}->{3348293} = "Amberieu\-en\-Bugey";
$areanames{fr}->{3348294} = "Annonay";
$areanames{fr}->{3348295} = "Aubenas";
$areanames{fr}->{3348296} = "Montelimar";
$areanames{fr}->{3348297} = "Privas";
$areanames{fr}->{3348298} = "Lyon";
$areanames{fr}->{3348299} = "Amberieu\-en\-Bugey";
$areanames{fr}->{3348300} = "Brignoles";
$areanames{fr}->{3348301} = "Nice";
$areanames{fr}->{3348302} = "Toulon";
$areanames{fr}->{3348303} = "Cannes";
$areanames{fr}->{3348304} = "Nice";
$areanames{fr}->{3348305} = "Grasse";
$areanames{fr}->{3348306} = "Nice";
$areanames{fr}->{3348307} = "Brignoles";
$areanames{fr}->{3348308} = "Draguignan";
$areanames{fr}->{3348309} = "Saint\-Raphael";
$areanames{fr}->{3348320} = "Saint\-Raphael";
$areanames{fr}->{3348321} = "Toulon";
$areanames{fr}->{3348322} = "Puget\-Theniers";
$areanames{fr}->{3348323} = "Toulon";
$areanames{fr}->{3348324} = "Toulon";
$areanames{fr}->{3348325} = "Toulon";
$areanames{fr}->{3348326} = "Grasse";
$areanames{fr}->{3348327} = "Brignoles";
$areanames{fr}->{3348328} = "Cannes";
$areanames{fr}->{3348329} = "Draguignan";
$areanames{fr}->{3348330} = "Cannes";
$areanames{fr}->{3348331} = "Grasse";
$areanames{fr}->{3348332} = "Nice";
$areanames{fr}->{3348333} = "Nice";
$areanames{fr}->{3348334} = "Puget\-Theniers";
$areanames{fr}->{3348335} = "Saint\-Raphael";
$areanames{fr}->{3348336} = "Toulon";
$areanames{fr}->{3348337} = "Grasse";
$areanames{fr}->{3348338} = "Toulon";
$areanames{fr}->{3348339} = "Nice";
$areanames{fr}->{3348360} = "Puget\-Theniers";
$areanames{fr}->{3348361} = "Cannes";
$areanames{fr}->{3348362} = "Saint\-Raphael";
$areanames{fr}->{3348363} = "Nice";
$areanames{fr}->{3348364} = "Toulon";
$areanames{fr}->{3348365} = "Cannes";
$areanames{fr}->{3348366} = "Nice";
$areanames{fr}->{3348367} = "Brignoles";
$areanames{fr}->{3348368} = "Saint\-Raphael";
$areanames{fr}->{3348369} = "Toulon";
$areanames{fr}->{3348370} = "Nice";
$areanames{fr}->{3348371} = "Draguignan";
$areanames{fr}->{3348372} = "Brignoles";
$areanames{fr}->{3348373} = "Toulon";
$areanames{fr}->{3348374} = "Puget\-Theniers";
$areanames{fr}->{3348375} = "Toulon";
$areanames{fr}->{3348376} = "Nice";
$areanames{fr}->{3348377} = "Toulon";
$areanames{fr}->{3348378} = "Draguignan";
$areanames{fr}->{3348379} = "Puget\-Theniers";
$areanames{fr}->{3348380} = "Nice";
$areanames{fr}->{3348381} = "Nice";
$areanames{fr}->{3348382} = "Brignoles";
$areanames{fr}->{3348383} = "Cannes";
$areanames{fr}->{3348384} = "Nice";
$areanames{fr}->{3348385} = "Nice";
$areanames{fr}->{3348386} = "Cannes";
$areanames{fr}->{3348387} = "Toulon";
$areanames{fr}->{3348388} = "Cannes";
$areanames{fr}->{3348389} = "Toulon";
$areanames{fr}->{3348390} = "Grasse";
$areanames{fr}->{3348391} = "Cannes";
$areanames{fr}->{3348392} = "Grasse";
$areanames{fr}->{3348393} = "Nice";
$areanames{fr}->{3348394} = "Nice";
$areanames{fr}->{3348395} = "Toulon";
$areanames{fr}->{3348396} = "Nice";
$areanames{fr}->{3348397} = "Toulon";
$areanames{fr}->{3348398} = "Nice";
$areanames{fr}->{3348399} = "Toulon";
$areanames{fr}->{3348400} = "Digne\-les\-Bains";
$areanames{fr}->{3348401} = "Manosque";
$areanames{fr}->{3348402} = "Saint\-André\-les\-Alpes";
$areanames{fr}->{3348403} = "Gap";
$areanames{fr}->{3348404} = "Aix\-en\-Provence";
$areanames{fr}->{3348405} = "Arles";
$areanames{fr}->{3348406} = "Aubagne";
$areanames{fr}->{3348407} = "Marignane";
$areanames{fr}->{3348408} = "Marseille";
$areanames{fr}->{3348409} = "Avignon";
$areanames{fr}->{3348430} = "Aix\-en\-Provence";
$areanames{fr}->{3348431} = "Marseille";
$areanames{fr}->{3348432} = "Marseille";
$areanames{fr}->{3348433} = "Marseille";
$areanames{fr}->{3348434} = "Aix\-en\-Provence";
$areanames{fr}->{3348435} = "Marseille";
$areanames{fr}->{3348436} = "Avignon";
$areanames{fr}->{3348437} = "Digne\-les\-Bains";
$areanames{fr}->{3348438} = "Gap";
$areanames{fr}->{3348439} = "Aix\-en\-Provence";
$areanames{fr}->{3348440} = "Marseille";
$areanames{fr}->{3348441} = "Arles";
$areanames{fr}->{3348442} = "Aubagne";
$areanames{fr}->{3348443} = "Avignon";
$areanames{fr}->{3348444} = "Marignane";
$areanames{fr}->{3348445} = "Marseille";
$areanames{fr}->{3348446} = "Aix\-en\-Provence";
$areanames{fr}->{3348447} = "Aix\-en\-Provence";
$areanames{fr}->{3348448} = "Aubagne";
$areanames{fr}->{3348449} = "Aix\-en\-Provence";
$areanames{fr}->{3348450} = "Marseille";
$areanames{fr}->{3348451} = "Avignon";
$areanames{fr}->{3348452} = "Marseille";
$areanames{fr}->{3348453} = "Digne\-les\-Bains";
$areanames{fr}->{3348454} = "Digne\-les\-Bains";
$areanames{fr}->{3348455} = "Manosque";
$areanames{fr}->{3348456} = "Saint\-André\-les\-Alpes";
$areanames{fr}->{3348457} = "Gap";
$areanames{fr}->{3348458} = "Aix\-en\-Provence";
$areanames{fr}->{3348459} = "Arles";
$areanames{fr}->{3348460} = "Aix\-en\-Provence";
$areanames{fr}->{3348461} = "Arles";
$areanames{fr}->{3348462} = "Aubagne";
$areanames{fr}->{3348463} = "Avignon";
$areanames{fr}->{3348464} = "Cavaillon";
$areanames{fr}->{3348465} = "Gap";
$areanames{fr}->{3348466} = "Marignane";
$areanames{fr}->{3348467} = "Marseille";
$areanames{fr}->{3348468} = "Orange";
$areanames{fr}->{3348469} = "Pertuis";
$areanames{fr}->{3348470} = "Aubagne";
$areanames{fr}->{3348471} = "Marignane";
$areanames{fr}->{3348472} = "Marseille";
$areanames{fr}->{3348473} = "Avignon";
$areanames{fr}->{3348474} = "Gap";
$areanames{fr}->{3348475} = "Cavaillon";
$areanames{fr}->{3348476} = "Arles";
$areanames{fr}->{3348477} = "Orange";
$areanames{fr}->{3348478} = "Pertuis";
$areanames{fr}->{3348479} = "Marseille";
$areanames{fr}->{3348480} = "Aix\-en\-Provence";
$areanames{fr}->{3348481} = "Marseille";
$areanames{fr}->{3348482} = "Marseille";
$areanames{fr}->{3348483} = "Aubagne";
$areanames{fr}->{3348484} = "Arles";
$areanames{fr}->{3348485} = "Orange";
$areanames{fr}->{3348486} = "Marseille";
$areanames{fr}->{3348487} = "Digne\-les\-Bains";
$areanames{fr}->{3348488} = "Marseille";
$areanames{fr}->{3348489} = "Marseille";
$areanames{fr}->{3348490} = "Marseille";
$areanames{fr}->{3348491} = "Marseille";
$areanames{fr}->{3348492} = "Marignane";
$areanames{fr}->{3348493} = "Aix\-en\-Provence";
$areanames{fr}->{3348494} = "Avignon";
$areanames{fr}->{3348495} = "Aubagne";
$areanames{fr}->{3348496} = "Gap";
$areanames{fr}->{3348497} = "Arles";
$areanames{fr}->{3348498} = "Arles";
$areanames{fr}->{3348499} = "Marseille";
$areanames{fr}->{3348500} = "Annecy";
$areanames{fr}->{3348501} = "Chambery";
$areanames{fr}->{3348502} = "Grenoble";
$areanames{fr}->{3348503} = "Bellegarde\-sur\-Valserine";
$areanames{fr}->{3348504} = "Belley";
$areanames{fr}->{3348505} = "Aix\-les\-Bains";
$areanames{fr}->{3348506} = "Monestier\-de\-Clermont";
$areanames{fr}->{3348507} = "Saint\-Marcellin";
$areanames{fr}->{3348508} = "Voiron";
$areanames{fr}->{3348509} = "Le\ Bourg\-dOisans";
$areanames{fr}->{3348510} = "La\ Mure";
$areanames{fr}->{3348511} = "Aix\-les\-Bains";
$areanames{fr}->{3348512} = "Albertville";
$areanames{fr}->{3348513} = "Chambery";
$areanames{fr}->{3348514} = "Moutiers";
$areanames{fr}->{3348515} = "Saint\-Jean\-de\-Maurienne";
$areanames{fr}->{3348516} = "Annecy";
$areanames{fr}->{3348517} = "Annemasse";
$areanames{fr}->{3348518} = "Sallanches";
$areanames{fr}->{3348519} = "Grenoble";
$areanames{fr}->{3348520} = "Bellegarde\-sur\-Valserine";
$areanames{fr}->{3348521} = "Annecy";
$areanames{fr}->{3348522} = "Annemasse";
$areanames{fr}->{3348523} = "Sallanches";
$areanames{fr}->{3348524} = "Belley";
$areanames{fr}->{3348525} = "Aix\-les\-Bains";
$areanames{fr}->{3348526} = "Albertville";
$areanames{fr}->{3348527} = "Moutiers";
$areanames{fr}->{3348528} = "Saint\-Jean\-de\-Maurienne";
$areanames{fr}->{3348529} = "Bellegarde\-sur\-Valserine";
$areanames{fr}->{3348530} = "Sallanches";
$areanames{fr}->{3348531} = "Grenoble";
$areanames{fr}->{3348532} = "La\ Mure";
$areanames{fr}->{3348533} = "Le\ Bourg\-dOisans";
$areanames{fr}->{3348534} = "Monestier\-de\-Clermont";
$areanames{fr}->{3348535} = "Saint\-Marcellin";
$areanames{fr}->{3348536} = "Voiron";
$areanames{fr}->{3348537} = "Belley";
$areanames{fr}->{3348538} = "Grenoble";
$areanames{fr}->{3348539} = "Bellegarde\-sur\-Valserine";
$areanames{fr}->{3348540} = "Voiron";
$areanames{fr}->{3348541} = "Grenoble";
$areanames{fr}->{3348542} = "Sallanches";
$areanames{fr}->{3348543} = "Grenoble";
$areanames{fr}->{3348544} = "Chambery";
$areanames{fr}->{3348545} = "Aix\-les\-Bains";
$areanames{fr}->{3348546} = "Annecy";
$areanames{fr}->{3348547} = "Annemasse";
$areanames{fr}->{3348571} = "Saint\-Jean\-de\-Maurienne";
$areanames{fr}->{3348572} = "Annecy";
$areanames{fr}->{3348573} = "Annemasse";
$areanames{fr}->{3348574} = "Sallanches";
$areanames{fr}->{3348575} = "Bellegarde\-sur\-Valserine";
$areanames{fr}->{3348576} = "Aix\-les\-Bains";
$areanames{fr}->{3348577} = "Albertville";
$areanames{fr}->{3348578} = "Chambery";
$areanames{fr}->{3348579} = "Moutiers";
$areanames{fr}->{3348580} = "Annecy";
$areanames{fr}->{3348581} = "La\ Mure";
$areanames{fr}->{3348582} = "Monestier\-de\-Clermont";
$areanames{fr}->{3348583} = "Saint\-Marcellin";
$areanames{fr}->{3348584} = "Voiron";
$areanames{fr}->{3348585} = "Grenoble";
$areanames{fr}->{3348586} = "Chambery";
$areanames{fr}->{3348587} = "Grenoble";
$areanames{fr}->{3348588} = "Grenoble";
$areanames{fr}->{3348589} = "Saint\-Jean\-de\-Maurienne";
$areanames{fr}->{3348590} = "Annecy";
$areanames{fr}->{3348591} = "Grenoble";
$areanames{fr}->{3348592} = "Chambery";
$areanames{fr}->{3348593} = "Bellegarde\-sur\-Valserine";
$areanames{fr}->{3348594} = "Aix\-les\-Bains";
$areanames{fr}->{3348595} = "Albertville";
$areanames{fr}->{3348596} = "Chambery";
$areanames{fr}->{3348597} = "Moutiers";
$areanames{fr}->{3348598} = "Saint\-Jean\-de\-Maurienne";
$areanames{fr}->{3348600} = "Digne\-les\-Bains";
$areanames{fr}->{3348601} = "Marseille";
$areanames{fr}->{3348602} = "Manosque";
$areanames{fr}->{3348603} = "Cavaillon";
$areanames{fr}->{3348604} = "Orange";
$areanames{fr}->{3348605} = "Pertuis";
$areanames{fr}->{3348606} = "Marseille";
$areanames{fr}->{3348607} = "Marseille";
$areanames{fr}->{3348608} = "Marignane";
$areanames{fr}->{3348609} = "Marseille";
$areanames{fr}->{3348620} = "Aubagne";
$areanames{fr}->{3348621} = "Marignane";
$areanames{fr}->{3348622} = "Aix\-en\-Provence";
$areanames{fr}->{3348623} = "Aix\-en\-Provence";
$areanames{fr}->{3348624} = "Avignon";
$areanames{fr}->{3348625} = "Aubagne";
$areanames{fr}->{3348626} = "Marseille";
$areanames{fr}->{3348627} = "Manosque";
$areanames{fr}->{3348628} = "Pertuis";
$areanames{fr}->{3348629} = "Saint\-André\-les\-Alpes";
$areanames{fr}->{3348640} = "Avignon";
$areanames{fr}->{3348641} = "Marseille";
$areanames{fr}->{3348642} = "Aix\-en\-Provence";
$areanames{fr}->{3348643} = "Marignane";
$areanames{fr}->{3348644} = "Aubagne";
$areanames{fr}->{3348645} = "Cavaillon";
$areanames{fr}->{3348646} = "Marseille";
$areanames{fr}->{3348647} = "Orange";
$areanames{fr}->{3348648} = "Marignane";
$areanames{fr}->{3348649} = "Digne\-les\-Bains";
$areanames{fr}->{3348650} = "Cavaillon";
$areanames{fr}->{3348651} = "Marignane";
$areanames{fr}->{3348652} = "Arles";
$areanames{fr}->{3348653} = "Orange";
$areanames{fr}->{3348654} = "Pertuis";
$areanames{fr}->{3348655} = "Cavaillon";
$areanames{fr}->{3348656} = "Manosque";
$areanames{fr}->{3348657} = "Marseille";
$areanames{fr}->{3348658} = "Manosque";
$areanames{fr}->{3348659} = "Saint\-André\-les\-Alpes";
$areanames{fr}->{3348700} = "Saint\-Etienne";
$areanames{fr}->{3348701} = "Villefranche\-sur\-Saone";
$areanames{fr}->{3348702} = "Saint\-Etienne";
$areanames{fr}->{3348703} = "Feurs";
$areanames{fr}->{3348704} = "Roanne";
$areanames{fr}->{3348705} = "Nantua";
$areanames{fr}->{3348706} = "Annonay";
$areanames{fr}->{3348707} = "Aubenas";
$areanames{fr}->{3348708} = "Privas";
$areanames{fr}->{3348709} = "Tournon\-sur\-Rhone";
$areanames{fr}->{3348710} = "Die";
$areanames{fr}->{3348711} = "Montelimar";
$areanames{fr}->{3348712} = "Nyons";
$areanames{fr}->{3348713} = "Romans\-sur\-Isere";
$areanames{fr}->{3348714} = "Saint\-Vallier";
$areanames{fr}->{3348715} = "Valence";
$areanames{fr}->{3348716} = "Vienne";
$areanames{fr}->{3348717} = "Feurs";
$areanames{fr}->{3348718} = "Roanne";
$areanames{fr}->{3348719} = "Tarare";
$areanames{fr}->{3348720} = "Romans\-sur\-Isere";
$areanames{fr}->{3348721} = "Nantua";
$areanames{fr}->{3348722} = "Aubenas";
$areanames{fr}->{3348723} = "Roanne";
$areanames{fr}->{3348724} = "Lyon";
$areanames{fr}->{3348725} = "Lyon";
$areanames{fr}->{3348726} = "Montelimar";
$areanames{fr}->{3348727} = "Saint\-Etienne";
$areanames{fr}->{3348728} = "Feurs";
$areanames{fr}->{3348729} = "Lyon";
$areanames{fr}->{3348730} = "Villefranche\-sur\-Saone";
$areanames{fr}->{3348731} = "Romans\-sur\-Isere";
$areanames{fr}->{3348732} = "Montelimar";
$areanames{fr}->{3348733} = "Lyon";
$areanames{fr}->{3348734} = "Lyon";
$areanames{fr}->{3348735} = "Lyon";
$areanames{fr}->{3348736} = "Amberieu\-en\-Bugey";
$areanames{fr}->{3348737} = "Lyon";
$areanames{fr}->{3348738} = "Lyon";
$areanames{fr}->{3348739} = "Amberieu\-en\-Bugey";
$areanames{fr}->{3348740} = "Bourg\-en\-Bresse";
$areanames{fr}->{3348741} = "Nantua";
$areanames{fr}->{3348742} = "Annonay";
$areanames{fr}->{3348743} = "Aubenas";
$areanames{fr}->{3348744} = "Privas";
$areanames{fr}->{3348745} = "Tournon\-sur\-Rhone";
$areanames{fr}->{3348746} = "Die";
$areanames{fr}->{3348747} = "Montelimar";
$areanames{fr}->{3348748} = "Nyons";
$areanames{fr}->{3348749} = "Romans\-sur\-Isere";
$areanames{fr}->{3348750} = "Saint\-Vallier";
$areanames{fr}->{3348751} = "Valence";
$areanames{fr}->{3348752} = "Feurs";
$areanames{fr}->{3348753} = "Roanne";
$areanames{fr}->{3348754} = "Saint\-Etienne";
$areanames{fr}->{3348755} = "Lyon";
$areanames{fr}->{3348756} = "Tarare";
$areanames{fr}->{3348757} = "Villefranche\-sur\-Saone";
$areanames{fr}->{3348758} = "Bourgoin\-Jallieu";
$areanames{fr}->{3348759} = "Vienne";
$areanames{fr}->{3348760} = "Aubenas";
$areanames{fr}->{3348761} = "Lyon";
$areanames{fr}->{3348762} = "Lyon";
$areanames{fr}->{3348763} = "Lyon";
$areanames{fr}->{3348764} = "Lyon";
$areanames{fr}->{3348765} = "Lyon";
$areanames{fr}->{3348766} = "Saint\-Etienne";
$areanames{fr}->{3348767} = "Bourg\-en\-Bresse";
$areanames{fr}->{3348768} = "Amberieu\-en\-Bugey";
$areanames{fr}->{3348769} = "Feurs";
$areanames{fr}->{3348770} = "Tarare";
$areanames{fr}->{3348771} = "Lyon";
$areanames{fr}->{3348772} = "Annonay";
$areanames{fr}->{3348773} = "Montelimar";
$areanames{fr}->{3348775} = "Valence";
$areanames{fr}->{3348776} = "Lyon";
$areanames{fr}->{3348777} = "Lyon";
$areanames{fr}->{3348778} = "Lyon";
$areanames{fr}->{3348779} = "Amberieu\-en\-Bugey";
$areanames{fr}->{3348780} = "Lyon";
$areanames{fr}->{3348788} = "Amberieu\-en\-Bugey";
$areanames{fr}->{3348789} = "Lyon";
$areanames{fr}->{3348790} = "Valence";
$areanames{fr}->{3348791} = "Lyon";
$areanames{fr}->{3348792} = "Tarare";
$areanames{fr}->{3348793} = "Lyon";
$areanames{fr}->{3348794} = "Lyon";
$areanames{fr}->{3348795} = "Lyon";
$areanames{fr}->{3348796} = "Valence";
$areanames{fr}->{3348797} = "Amberieu\-en\-Bugey";
$areanames{fr}->{3348798} = "Bourg\-en\-Bresse";
$areanames{fr}->{3348799} = "Lyon";
$areanames{fr}->{3348810} = "Marseille";
$areanames{fr}->{3348811} = "Gap";
$areanames{fr}->{3348812} = "Aix\-en\-Provence";
$areanames{fr}->{3348813} = "Marseille";
$areanames{fr}->{3348814} = "Aix\-en\-Provence";
$areanames{fr}->{3348815} = "Marseille";
$areanames{fr}->{3348816} = "Digne\-les\-Bains";
$areanames{fr}->{3348817} = "Avignon";
$areanames{fr}->{3348818} = "Arles";
$areanames{fr}->{3348819} = "Aix\-en\-Provence";
$areanames{fr}->{3348820} = "Aubagne";
$areanames{fr}->{3348821} = "Marignane";
$areanames{fr}->{3348822} = "Marseille";
$areanames{fr}->{3348823} = "Cavaillon";
$areanames{fr}->{3348824} = "Digne\-les\-Bains";
$areanames{fr}->{3348825} = "Manosque";
$areanames{fr}->{3348826} = "Gap";
$areanames{fr}->{3348827} = "Gap";
$areanames{fr}->{3348828} = "Avignon";
$areanames{fr}->{3348829} = "Aix\-en\-Provence";
$areanames{fr}->{3348830} = "Marseille";
$areanames{fr}->{3348831} = "Marseille";
$areanames{fr}->{3348832} = "Marseille";
$areanames{fr}->{3348833} = "Marseille";
$areanames{fr}->{3348834} = "Aix\-en\-Provence";
$areanames{fr}->{3348835} = "Aix\-en\-Provence";
$areanames{fr}->{3348836} = "Marseille";
$areanames{fr}->{3348837} = "Arles";
$areanames{fr}->{3348838} = "Cavaillon";
$areanames{fr}->{3348839} = "Aubagne";
$areanames{fr}->{3348840} = "Marignane";
$areanames{fr}->{3348841} = "Aix\-en\-Provence";
$areanames{fr}->{3348842} = "Aubagne";
$areanames{fr}->{3348843} = "Marignane";
$areanames{fr}->{3348844} = "Marseille";
$areanames{fr}->{3348845} = "Arles";
$areanames{fr}->{3348846} = "Aubagne";
$areanames{fr}->{3348847} = "Marignane";
$areanames{fr}->{3348848} = "Orange";
$areanames{fr}->{3348849} = "Marseille";
$areanames{fr}->{3348850} = "Orange";
$areanames{fr}->{3348851} = "Avignon";
$areanames{fr}->{3348852} = "Cavaillon";
$areanames{fr}->{3348853} = "Orange";
$areanames{fr}->{3348854} = "Avignon";
$areanames{fr}->{3348855} = "Pertuis";
$areanames{fr}->{3348856} = "Marseille";
$areanames{fr}->{3348857} = "Marseille";
$areanames{fr}->{3348858} = "Pertuis";
$areanames{fr}->{3348859} = "Aix\-en\-Provence";
$areanames{fr}->{334886} = "Marseille";
$areanames{fr}->{3348861} = "Avignon";
$areanames{fr}->{3348863} = "Marignane";
$areanames{fr}->{3348865} = "Arles";
$areanames{fr}->{3348868} = "Aubagne";
$areanames{fr}->{3348870} = "Avignon";
$areanames{fr}->{3348871} = "Aix\-en\-Provence";
$areanames{fr}->{3348872} = "Aubagne";
$areanames{fr}->{3348873} = "Marseille";
$areanames{fr}->{3348874} = "Digne\-les\-Bains";
$areanames{fr}->{3348875} = "Digne\-les\-Bains";
$areanames{fr}->{3348876} = "Gap";
$areanames{fr}->{3348877} = "Marseille";
$areanames{fr}->{3348878} = "Aix\-en\-Provence";
$areanames{fr}->{3348879} = "Gap";
$areanames{fr}->{3348880} = "Aix\-en\-Provence";
$areanames{fr}->{3348881} = "Aix\-en\-Provence";
$areanames{fr}->{3348882} = "Arles";
$areanames{fr}->{3348883} = "Arles";
$areanames{fr}->{3348884} = "Orange";
$areanames{fr}->{3348885} = "Cavaillon";
$areanames{fr}->{3348886} = "Marseille";
$areanames{fr}->{3348887} = "Digne\-les\-Bains";
$areanames{fr}->{3348888} = "Marignane";
$areanames{fr}->{3348889} = "Aubagne";
$areanames{fr}->{3348890} = "Marseille";
$areanames{fr}->{3348891} = "Marseille";
$areanames{fr}->{3348892} = "Marseille";
$areanames{fr}->{3348893} = "Marignane";
$areanames{fr}->{3348894} = "Marignane";
$areanames{fr}->{3348895} = "Avignon";
$areanames{fr}->{3348896} = "Avignon";
$areanames{fr}->{3348897} = "Orange";
$areanames{fr}->{3348898} = "Orange";
$areanames{fr}->{3348899} = "Avignon";
$areanames{fr}->{3348930} = "Toulon";
$areanames{fr}->{3348931} = "Puget\-Theniers";
$areanames{fr}->{3348932} = "Nice";
$areanames{fr}->{3348933} = "Toulon";
$areanames{fr}->{3348934} = "Puget\-Theniers";
$areanames{fr}->{3348935} = "Grasse";
$areanames{fr}->{3348936} = "Brignoles";
$areanames{fr}->{3348937} = "Cannes";
$areanames{fr}->{3348938} = "Cannes";
$areanames{fr}->{3348939} = "Grasse";
$areanames{fr}->{3348940} = "Grasse";
$areanames{fr}->{3348941} = "Nice";
$areanames{fr}->{3348942} = "Nice";
$areanames{fr}->{3348943} = "Puget\-Theniers";
$areanames{fr}->{3348944} = "Puget\-Theniers";
$areanames{fr}->{3348945} = "Brignoles";
$areanames{fr}->{3348946} = "Brignoles";
$areanames{fr}->{3348947} = "Draguignan";
$areanames{fr}->{3348948} = "Draguignan";
$areanames{fr}->{3348949} = "Saint\-Raphael";
$areanames{fr}->{3348950} = "Saint\-Raphael";
$areanames{fr}->{3348951} = "Toulon";
$areanames{fr}->{3348952} = "Toulon";
$areanames{fr}->{3348953} = "Draguignan";
$areanames{fr}->{3348954} = "Toulon";
$areanames{fr}->{3348955} = "Saint\-Raphael";
$areanames{fr}->{3348956} = "Nice";
$areanames{fr}->{3348957} = "Nice";
$areanames{fr}->{3348958} = "Nice";
$areanames{fr}->{3348959} = "Puget\-Theniers";
$areanames{fr}->{334911} = "Marseille";
$areanames{fr}->{334912} = "Marseille";
$areanames{fr}->{334913} = "Marseille";
$areanames{fr}->{334914} = "Marseille";
$areanames{fr}->{334915} = "Marseille";
$areanames{fr}->{334917} = "Marseille";
$areanames{fr}->{334918} = "Marseille";
$areanames{fr}->{334919} = "Marseille";
$areanames{fr}->{334938} = "Nice";
$areanames{fr}->{334958} = "Sud\ Est";
$areanames{fr}->{334959} = "Sud\ Est";
$areanames{fr}->{3349597} = "Corse";
$areanames{fr}->{334960} = "Sud\ Est";
$areanames{fr}->{334961} = "Marseille";
$areanames{fr}->{334963} = "Sud\ Est";
$areanames{fr}->{3349630} = "Aubagne";
$areanames{fr}->{334964} = "Sud\ Est";
$areanames{fr}->{3349641} = "Marseille";
$areanames{fr}->{334965} = "Sud\ Est";
$areanames{fr}->{334966} = "Sud\ Est";
$areanames{fr}->{334967} = "Sud\ Est";
$areanames{fr}->{334968} = "Sud\ Est";
$areanames{fr}->{334969} = "Sud\ Est";
$areanames{fr}->{334971} = "Nice";
$areanames{fr}->{3349715} = "Cannes";
$areanames{fr}->{3349716} = "Cannes";
$areanames{fr}->{334973} = "Sud\ Est";
$areanames{fr}->{3349733} = "Nice";
$areanames{fr}->{334974} = "Sud\ Est";
$areanames{fr}->{3349746} = "Nice";
$areanames{fr}->{334975} = "Sud\ Est";
$areanames{fr}->{334976} = "Sud\ Est";
$areanames{fr}->{334977} = "Sud\ Est";
$areanames{fr}->{334978} = "Sud\ Est";
$areanames{fr}->{3349780} = "Nice";
$areanames{fr}->{334979} = "Sud\ Est";
$areanames{fr}->{3349797} = "Cannes";
$areanames{fr}->{334982} = "Sud\ Est";
$areanames{fr}->{334983} = "Sud\ Est";
$areanames{fr}->{334984} = "Sud\ Est";
$areanames{fr}->{334985} = "Sud\ Est";
$areanames{fr}->{3349851} = "Toulon";
$areanames{fr}->{334986} = "Sud\ Est";
$areanames{fr}->{334987} = "Sud\ Est";
$areanames{fr}->{334988} = "Sud\ Est";
$areanames{fr}->{334989} = "Sud\ Est";
$areanames{fr}->{334993} = "Sud\ Est";
$areanames{fr}->{334998} = "Sud\ Est";
$areanames{fr}->{3351610} = "Saintes";
$areanames{fr}->{3351611} = "Montmorillon";
$areanames{fr}->{3351612} = "Melle";
$areanames{fr}->{3351613} = "Niort";
$areanames{fr}->{3351614} = "Parthenay";
$areanames{fr}->{3351615} = "Thouars";
$areanames{fr}->{3351616} = "Angoulême";
$areanames{fr}->{3351617} = "Chatellerault";
$areanames{fr}->{3351618} = "Niort";
$areanames{fr}->{3351619} = "La\ Rochelle";
$areanames{fr}->{3351620} = "Saintes";
$areanames{fr}->{3351621} = "Saint\-Jean\-dAngely";
$areanames{fr}->{3351622} = "Saintes";
$areanames{fr}->{3351623} = "Bressuire";
$areanames{fr}->{3351624} = "Melle";
$areanames{fr}->{3351625} = "Niort";
$areanames{fr}->{3351626} = "Parthenay";
$areanames{fr}->{3351627} = "Thouars";
$areanames{fr}->{3351628} = "Chatellerault";
$areanames{fr}->{3351629} = "Angoulême";
$areanames{fr}->{3351630} = "Chatellerault";
$areanames{fr}->{3351631} = "Loudun";
$areanames{fr}->{3351632} = "Montmorillon";
$areanames{fr}->{3351633} = "Civray";
$areanames{fr}->{3351634} = "Poitiers";
$areanames{fr}->{3351635} = "Rochefort";
$areanames{fr}->{3351636} = "Niort";
$areanames{fr}->{3351637} = "Poitiers";
$areanames{fr}->{3351638} = "Barbezieux\-Saint\-Hilaire";
$areanames{fr}->{3351639} = "Poitiers";
$areanames{fr}->{3351650} = "Angoulême";
$areanames{fr}->{3351651} = "Saint\-Jean\-dAngely";
$areanames{fr}->{3351652} = "Poitiers";
$areanames{fr}->{3351653} = "Angoulême";
$areanames{fr}->{3351654} = "Barbezieux\-Saint\-Hilaire";
$areanames{fr}->{3351655} = "Loudun";
$areanames{fr}->{3351656} = "Confolens";
$areanames{fr}->{3351657} = "Cognac";
$areanames{fr}->{3351658} = "Rochefort";
$areanames{fr}->{3351659} = "La\ Rochelle";
$areanames{fr}->{3351660} = "Poitiers";
$areanames{fr}->{3351661} = "Saintes";
$areanames{fr}->{3351662} = "La\ Rochelle";
$areanames{fr}->{3351663} = "Confolens";
$areanames{fr}->{3351664} = "Niort";
$areanames{fr}->{3351665} = "Rochefort";
$areanames{fr}->{3351666} = "Montmorillon";
$areanames{fr}->{3351667} = "Chatellerault";
$areanames{fr}->{3351668} = "Poitiers";
$areanames{fr}->{3351669} = "Poitiers";
$areanames{fr}->{3351670} = "Angoulême";
$areanames{fr}->{3351671} = "Barbezieux\-Saint\-Hilaire";
$areanames{fr}->{3351672} = "Bressuire";
$areanames{fr}->{3351673} = "Chatellerault";
$areanames{fr}->{3351674} = "Civray";
$areanames{fr}->{3351675} = "Cognac";
$areanames{fr}->{3351676} = "Confolens";
$areanames{fr}->{3351677} = "Jonzac";
$areanames{fr}->{3351678} = "Loudun";
$areanames{fr}->{3351679} = "Melle";
$areanames{fr}->{3351690} = "Angoulême";
$areanames{fr}->{3351691} = "Barbezieux\-Saint\-Hilaire";
$areanames{fr}->{3351692} = "Cognac";
$areanames{fr}->{3351693} = "Confolens";
$areanames{fr}->{3351694} = "Jonzac";
$areanames{fr}->{3351695} = "Poitiers";
$areanames{fr}->{3351696} = "Rochefort";
$areanames{fr}->{3351697} = "La\ Rochelle";
$areanames{fr}->{3351698} = "Saintes";
$areanames{fr}->{3351699} = "Saint\-Jean\-dAngely";
$areanames{fr}->{3351700} = "Angoulême";
$areanames{fr}->{3351701} = "Barbezieux\-Saint\-Hilaire";
$areanames{fr}->{3351702} = "Bressuire";
$areanames{fr}->{3351703} = "Chatellerault";
$areanames{fr}->{3351704} = "Civray";
$areanames{fr}->{3351705} = "Jonzac";
$areanames{fr}->{3351706} = "La\ Rochelle";
$areanames{fr}->{3351707} = "Loudun";
$areanames{fr}->{3351708} = "Melle";
$areanames{fr}->{3351709} = "Montmorillon";
$areanames{fr}->{3351710} = "Niort";
$areanames{fr}->{3351711} = "Parthenay";
$areanames{fr}->{3351712} = "Poitiers";
$areanames{fr}->{3351713} = "Rochefort";
$areanames{fr}->{3351714} = "Saint\-Jean\-dAngely";
$areanames{fr}->{3351715} = "Saintes";
$areanames{fr}->{3351716} = "Thouars";
$areanames{fr}->{3351717} = "Angoulême";
$areanames{fr}->{3351718} = "Niort";
$areanames{fr}->{3351719} = "Chatellerault";
$areanames{fr}->{3351720} = "Angoulême";
$areanames{fr}->{3351721} = "Barbezieux\-Saint\-Hilaire";
$areanames{fr}->{3351722} = "Cognac";
$areanames{fr}->{3351723} = "Confolens";
$areanames{fr}->{3351724} = "Jonzac";
$areanames{fr}->{3351725} = "Rochefort";
$areanames{fr}->{3351726} = "La\ Rochelle";
$areanames{fr}->{3351727} = "Saint\-Jean\-dAngely";
$areanames{fr}->{3351728} = "Saintes";
$areanames{fr}->{3351729} = "Bressuire";
$areanames{fr}->{3351730} = "Melle";
$areanames{fr}->{3351731} = "Parthenay";
$areanames{fr}->{3351732} = "Thouars";
$areanames{fr}->{3351733} = "Chatellerault";
$areanames{fr}->{3351734} = "Civray";
$areanames{fr}->{3351735} = "Loudun";
$areanames{fr}->{3351736} = "Montmorillon";
$areanames{fr}->{3351737} = "Chatellerault";
$areanames{fr}->{3351738} = "Niort";
$areanames{fr}->{3351739} = "Saintes";
$areanames{fr}->{3351740} = "Niort";
$areanames{fr}->{3351741} = "Bressuire";
$areanames{fr}->{3351742} = "Melle";
$areanames{fr}->{3351743} = "Parthenay";
$areanames{fr}->{3351744} = "Thouars";
$areanames{fr}->{3351745} = "Civray";
$areanames{fr}->{3351746} = "Loudun";
$areanames{fr}->{3351747} = "Montmorillon";
$areanames{fr}->{3351748} = "Angoulême";
$areanames{fr}->{3351749} = "Angoulême";
$areanames{fr}->{3351750} = "Angoulême";
$areanames{fr}->{3351751} = "Chatellerault";
$areanames{fr}->{3351752} = "La\ Rochelle";
$areanames{fr}->{3351753} = "Niort";
$areanames{fr}->{3351754} = "Poitiers";
$areanames{fr}->{3351755} = "Rochefort";
$areanames{fr}->{3351756} = "Angoulême";
$areanames{fr}->{3351757} = "Angoulême";
$areanames{fr}->{3351758} = "Barbezieux\-Saint\-Hilaire";
$areanames{fr}->{3351759} = "Bressuire";
$areanames{fr}->{3351760} = "Chatellerault";
$areanames{fr}->{3351761} = "Chatellerault";
$areanames{fr}->{3351762} = "Civray";
$areanames{fr}->{3351763} = "Cognac";
$areanames{fr}->{3351764} = "Confolens";
$areanames{fr}->{3351765} = "Jonzac";
$areanames{fr}->{3351766} = "Niort";
$areanames{fr}->{3351767} = "La\ Rochelle";
$areanames{fr}->{3351768} = "Loudun";
$areanames{fr}->{3351769} = "Melle";
$areanames{fr}->{3351770} = "Poitiers";
$areanames{fr}->{3351771} = "Montmorillon";
$areanames{fr}->{3351772} = "Niort";
$areanames{fr}->{3351773} = "Parthenay";
$areanames{fr}->{3351774} = "Poitiers";
$areanames{fr}->{3351775} = "Rochefort";
$areanames{fr}->{3351776} = "Saintes";
$areanames{fr}->{3351777} = "Saint\-Jean\-dAngely";
$areanames{fr}->{3351778} = "Thouars";
$areanames{fr}->{3351779} = "Angoulême";
$areanames{fr}->{3351780} = "La\ Rochelle";
$areanames{fr}->{3351781} = "La\ Rochelle";
$areanames{fr}->{3351782} = "Rochefort";
$areanames{fr}->{3351783} = "La\ Rochelle";
$areanames{fr}->{3351784} = "Poitiers";
$areanames{fr}->{3351785} = "Angoulême";
$areanames{fr}->{3351786} = "Poitiers";
$areanames{fr}->{3351787} = "Niort";
$areanames{fr}->{3351788} = "Barbezieux\-Saint\-Hilaire";
$areanames{fr}->{3351789} = "Cognac";
$areanames{fr}->{3351790} = "Angoulême";
$areanames{fr}->{3351791} = "La\ Rochelle";
$areanames{fr}->{3351792} = "Rochefort";
$areanames{fr}->{3351793} = "Poitiers";
$areanames{fr}->{3351794} = "Jonzac";
$areanames{fr}->{3351795} = "Rochefort";
$areanames{fr}->{3351796} = "La\ Rochelle";
$areanames{fr}->{3351797} = "Saint\-Jean\-dAngely";
$areanames{fr}->{3351798} = "Saintes";
$areanames{fr}->{3351799} = "Bressuire";
$areanames{fr}->{3351800} = "Bourganeuf";
$areanames{fr}->{3351801} = "Boussac";
$areanames{fr}->{3351802} = "Gueret";
$areanames{fr}->{3351803} = "La\ Souterraine";
$areanames{fr}->{3351804} = "Bellac";
$areanames{fr}->{3351805} = "Limoges";
$areanames{fr}->{3351806} = "Limoges";
$areanames{fr}->{3351807} = "Limoges";
$areanames{fr}->{3351900} = "Boussac";
$areanames{fr}->{3351901} = "Gueret";
$areanames{fr}->{3351902} = "La\ Souterraine";
$areanames{fr}->{3351903} = "Limoges";
$areanames{fr}->{3351904} = "Tulle";
$areanames{fr}->{3351905} = "Ussel";
$areanames{fr}->{3351906} = "Uzerche";
$areanames{fr}->{3351907} = "Tulle";
$areanames{fr}->{3351908} = "Limoges";
$areanames{fr}->{3351909} = "Limoges";
$areanames{fr}->{3351910} = "Argentat";
$areanames{fr}->{3351911} = "Tulle";
$areanames{fr}->{3351912} = "Ussel";
$areanames{fr}->{3351913} = "Uzerche";
$areanames{fr}->{3351914} = "Aubusson";
$areanames{fr}->{3351915} = "Bourganeuf";
$areanames{fr}->{3351916} = "Boussac";
$areanames{fr}->{3351917} = "Gueret";
$areanames{fr}->{3351918} = "La\ Souterraine";
$areanames{fr}->{3351919} = "Gueret";
$areanames{fr}->{3351920} = "Bellac";
$areanames{fr}->{3351921} = "Limoges";
$areanames{fr}->{3351922} = "Limoges";
$areanames{fr}->{3351923} = "Bellac";
$areanames{fr}->{3351924} = "Bourganeuf";
$areanames{fr}->{3351925} = "La\ Souterraine";
$areanames{fr}->{3351926} = "Ussel";
$areanames{fr}->{3351927} = "Aubusson";
$areanames{fr}->{3351928} = "Gueret";
$areanames{fr}->{3351929} = "Limoges";
$areanames{fr}->{3351930} = "Argentat";
$areanames{fr}->{3351931} = "Tulle";
$areanames{fr}->{3351932} = "Ussel";
$areanames{fr}->{3351933} = "Uzerche";
$areanames{fr}->{3351934} = "Aubusson";
$areanames{fr}->{3351935} = "Bourganeuf";
$areanames{fr}->{3351936} = "Boussac";
$areanames{fr}->{3351937} = "Gueret";
$areanames{fr}->{3351938} = "Bellac";
$areanames{fr}->{3351939} = "Limoges";
$areanames{fr}->{3351940} = "Argentat";
$areanames{fr}->{3351941} = "Limoges";
$areanames{fr}->{3351942} = "Boussac";
$areanames{fr}->{3351943} = "Tulle";
$areanames{fr}->{3351944} = "Uzerche";
$areanames{fr}->{3351945} = "Argentat";
$areanames{fr}->{3351946} = "Tulle";
$areanames{fr}->{3351947} = "Ussel";
$areanames{fr}->{3351948} = "Uzerche";
$areanames{fr}->{3351949} = "Aubusson";
$areanames{fr}->{3351950} = "Bourganeuf";
$areanames{fr}->{3351951} = "Boussac";
$areanames{fr}->{3351952} = "Gueret";
$areanames{fr}->{3351953} = "La\ Souterraine";
$areanames{fr}->{3351954} = "Bellac";
$areanames{fr}->{3351955} = "Limoges";
$areanames{fr}->{3351956} = "Limoges";
$areanames{fr}->{3351957} = "Limoges";
$areanames{fr}->{3351958} = "Argentat";
$areanames{fr}->{3351959} = "Tulle";
$areanames{fr}->{3351960} = "Ussel";
$areanames{fr}->{3351961} = "Aubusson";
$areanames{fr}->{3351962} = "Boussac";
$areanames{fr}->{3351963} = "Tulle";
$areanames{fr}->{3351964} = "Argentat";
$areanames{fr}->{3351965} = "Tulle";
$areanames{fr}->{3351966} = "Ussel";
$areanames{fr}->{3351967} = "Uzerche";
$areanames{fr}->{3351968} = "Aubusson";
$areanames{fr}->{3351969} = "Bourganeuf";
$areanames{fr}->{3351970} = "Boussac";
$areanames{fr}->{3351971} = "Gueret";
$areanames{fr}->{3351972} = "La\ Souterraine";
$areanames{fr}->{3351973} = "Bellac";
$areanames{fr}->{3351974} = "Limoges";
$areanames{fr}->{3351975} = "Tulle";
$areanames{fr}->{3351976} = "Limoges";
$areanames{fr}->{3351977} = "Gueret";
$areanames{fr}->{3351978} = "Limoges";
$areanames{fr}->{3351979} = "Tulle";
$areanames{fr}->{3351980} = "Tulle";
$areanames{fr}->{3351981} = "Tulle";
$areanames{fr}->{3351982} = "Argentat";
$areanames{fr}->{3351983} = "Ussel";
$areanames{fr}->{3351984} = "Uzerche";
$areanames{fr}->{3351985} = "Aubusson";
$areanames{fr}->{3351986} = "Limoges";
$areanames{fr}->{3351987} = "Limoges";
$areanames{fr}->{3351988} = "Limoges";
$areanames{fr}->{3351989} = "Gueret";
$areanames{fr}->{3351990} = "Argentat";
$areanames{fr}->{3351991} = "Ussel";
$areanames{fr}->{3351992} = "Uzerche";
$areanames{fr}->{3351993} = "Aubusson";
$areanames{fr}->{3351994} = "Bourganeuf";
$areanames{fr}->{3351995} = "Boussac";
$areanames{fr}->{3351996} = "La\ Souterraine";
$areanames{fr}->{3351997} = "Bellac";
$areanames{fr}->{3351998} = "Tulle";
$areanames{fr}->{3351999} = "Limoges";
$areanames{fr}->{3352410} = "Bergerac";
$areanames{fr}->{3352411} = "Mussidan";
$areanames{fr}->{3352412} = "Nontron";
$areanames{fr}->{3352413} = "Perigueux";
$areanames{fr}->{3352414} = "Riberac";
$areanames{fr}->{3352415} = "Sarlat\-la\-Caneda";
$areanames{fr}->{3352416} = "Terrasson\-Lavilledieu";
$areanames{fr}->{3352417} = "Thiviers";
$areanames{fr}->{3352418} = "Andernos\-les\-Bains";
$areanames{fr}->{3352419} = "Arcachon";
$areanames{fr}->{3352420} = "Bazas";
$areanames{fr}->{3352421} = "Blaye";
$areanames{fr}->{3352422} = "Langon";
$areanames{fr}->{3352423} = "Lesparre\-Medoc";
$areanames{fr}->{3352424} = "Libourne";
$areanames{fr}->{3352425} = "La\ Reole";
$areanames{fr}->{3352426} = "Dax";
$areanames{fr}->{3352427} = "Labouheyre";
$areanames{fr}->{3352428} = "Mont\-de\-Marsan";
$areanames{fr}->{3352429} = "Agen";
$areanames{fr}->{3352440} = "Arcachon";
$areanames{fr}->{3352441} = "Bazas";
$areanames{fr}->{3352442} = "Blaye";
$areanames{fr}->{3352443} = "Agen";
$areanames{fr}->{3352444} = "Bordeaux";
$areanames{fr}->{3352445} = "Dax";
$areanames{fr}->{3352446} = "La\ Reole";
$areanames{fr}->{3352447} = "Labouheyre";
$areanames{fr}->{3352448} = "Langon";
$areanames{fr}->{3352449} = "Lesparre\-Medoc";
$areanames{fr}->{3352450} = "Libourne";
$areanames{fr}->{3352451} = "Marmande";
$areanames{fr}->{3352452} = "Perigueux";
$areanames{fr}->{3352453} = "Bayonne";
$areanames{fr}->{3352454} = "Bordeaux";
$areanames{fr}->{3352455} = "Libourne";
$areanames{fr}->{3352456} = "Pau";
$areanames{fr}->{3352457} = "Bordeaux";
$areanames{fr}->{3352458} = "Bordeaux";
$areanames{fr}->{3352459} = "Andernos\-les\-Bains";
$areanames{fr}->{3352470} = "Bordeaux";
$areanames{fr}->{3352471} = "Blaye";
$areanames{fr}->{3352472} = "Bordeaux";
$areanames{fr}->{3352473} = "Bordeaux";
$areanames{fr}->{3352474} = "Dax";
$areanames{fr}->{3352475} = "La\ Reole";
$areanames{fr}->{3352476} = "Labouheyre";
$areanames{fr}->{3352477} = "Langon";
$areanames{fr}->{3352478} = "Lesparre\-Medoc";
$areanames{fr}->{3352479} = "Libourne";
$areanames{fr}->{3352480} = "Bayonne";
$areanames{fr}->{3352481} = "Marmande";
$areanames{fr}->{3352482} = "Mauleon\-Licharre";
$areanames{fr}->{3352483} = "Mont\-de\-Marsan";
$areanames{fr}->{3352484} = "Bordeaux";
$areanames{fr}->{3352485} = "Mussidan";
$areanames{fr}->{3352486} = "Nerac";
$areanames{fr}->{3352487} = "Nontron";
$areanames{fr}->{3352488} = "Oloron\-Sainte\-Marie";
$areanames{fr}->{3352489} = "Pau";
$areanames{fr}->{3353100} = "Auch";
$areanames{fr}->{3353101} = "Castres";
$areanames{fr}->{3353102} = "Cazeres";
$areanames{fr}->{3353103} = "Foix";
$areanames{fr}->{3353104} = "Lannemezan";
$areanames{fr}->{3353105} = "Montauban";
$areanames{fr}->{3353106} = "Pamiers";
$areanames{fr}->{3353107} = "Saint\-Gaudens";
$areanames{fr}->{3353108} = "Toulouse";
$areanames{fr}->{3353109} = "Toulouse";
$areanames{fr}->{3353110} = "Condom";
$areanames{fr}->{3353111} = "Toulouse";
$areanames{fr}->{3353112} = "Albi";
$areanames{fr}->{3353113} = "Castres";
$areanames{fr}->{3353114} = "Montauban";
$areanames{fr}->{3353115} = "Toulouse";
$areanames{fr}->{3353116} = "Auch";
$areanames{fr}->{3353117} = "Tarbes";
$areanames{fr}->{3353118} = "Albi";
$areanames{fr}->{3353119} = "Montauban";
$areanames{fr}->{3353120} = "Toulouse";
$areanames{fr}->{3353121} = "Toulouse";
$areanames{fr}->{3353122} = "Toulouse";
$areanames{fr}->{3353123} = "Albi";
$areanames{fr}->{3353124} = "Auch";
$areanames{fr}->{3353125} = "Cahors";
$areanames{fr}->{3353126} = "Castres";
$areanames{fr}->{3353127} = "Cazeres";
$areanames{fr}->{3353128} = "Condom";
$areanames{fr}->{3353129} = "Decazeville";
$areanames{fr}->{3353130} = "Montauban";
$areanames{fr}->{3353131} = "Toulouse";
$areanames{fr}->{3353132} = "Albi";
$areanames{fr}->{3353133} = "Castres";
$areanames{fr}->{3353134} = "Espalion";
$areanames{fr}->{3353135} = "Figeac";
$areanames{fr}->{3353136} = "Foix";
$areanames{fr}->{3353137} = "Lannemezan";
$areanames{fr}->{3353138} = "Moissac";
$areanames{fr}->{3353139} = "Montauban";
$areanames{fr}->{3353140} = "Nogaro";
$areanames{fr}->{3353141} = "Pamiers";
$areanames{fr}->{3353142} = "Rodez";
$areanames{fr}->{3353143} = "Saint\-Affrique";
$areanames{fr}->{3353144} = "Saint\-Gaudens";
$areanames{fr}->{3353145} = "Souillac";
$areanames{fr}->{3353146} = "Tarbes";
$areanames{fr}->{3353147} = "Toulouse";
$areanames{fr}->{3353148} = "Toulouse";
$areanames{fr}->{3353149} = "Villefranche\-de\-Rouergue";
$areanames{fr}->{3353160} = "Toulouse";
$areanames{fr}->{3353161} = "Toulouse";
$areanames{fr}->{3353162} = "Decazeville";
$areanames{fr}->{3353163} = "Espalion";
$areanames{fr}->{3353164} = "Rodez";
$areanames{fr}->{3353165} = "Saint\-Affrique";
$areanames{fr}->{3353166} = "Villefranche\-de\-Rouergue";
$areanames{fr}->{3353167} = "Cazeres";
$areanames{fr}->{3353168} = "Saint\-Gaudens";
$areanames{fr}->{3353169} = "Auch";
$areanames{fr}->{3353170} = "Foix";
$areanames{fr}->{3353171} = "Rodez";
$areanames{fr}->{3353172} = "Auch";
$areanames{fr}->{3353173} = "Cahors";
$areanames{fr}->{3353174} = "Tarbes";
$areanames{fr}->{3353175} = "Condom";
$areanames{fr}->{3353176} = "Albi";
$areanames{fr}->{3353177} = "Castres";
$areanames{fr}->{3353178} = "Montauban";
$areanames{fr}->{3353179} = "Nogaro";
$areanames{fr}->{3353180} = "Castres";
$areanames{fr}->{3353181} = "Albi";
$areanames{fr}->{3353182} = "Montauban";
$areanames{fr}->{3353183} = "Auch";
$areanames{fr}->{3353184} = "Toulouse";
$areanames{fr}->{3353185} = "Moissac";
$areanames{fr}->{3353186} = "Cahors";
$areanames{fr}->{3353187} = "Moissac";
$areanames{fr}->{3353188} = "Montauban";
$areanames{fr}->{3353189} = "Cahors";
$areanames{fr}->{3353200} = "Cahors";
$areanames{fr}->{3353201} = "Cazeres";
$areanames{fr}->{3353202} = "Toulouse";
$areanames{fr}->{3353203} = "Auch";
$areanames{fr}->{3353204} = "Condom";
$areanames{fr}->{3353205} = "Albi";
$areanames{fr}->{3353206} = "Souillac";
$areanames{fr}->{3353207} = "Moissac";
$areanames{fr}->{3353208} = "Montauban";
$areanames{fr}->{3353209} = "Toulouse";
$areanames{fr}->{3353210} = "Toulouse";
$areanames{fr}->{3353211} = "Toulouse";
$areanames{fr}->{3353212} = "Decazeville";
$areanames{fr}->{3353213} = "Espalion";
$areanames{fr}->{3353214} = "Rodez";
$areanames{fr}->{3353215} = "Saint\-Affrique";
$areanames{fr}->{3353216} = "Villefranche\-de\-Rouergue";
$areanames{fr}->{3353217} = "Saint\-Gaudens";
$areanames{fr}->{3353218} = "Toulouse";
$areanames{fr}->{3353219} = "Tarbes";
$areanames{fr}->{3353220} = "Lannemezan";
$areanames{fr}->{3353221} = "Auch";
$areanames{fr}->{3353222} = "Cahors";
$areanames{fr}->{3353223} = "Foix";
$areanames{fr}->{3353224} = "Rodez";
$areanames{fr}->{3353225} = "Tarbes";
$areanames{fr}->{3353226} = "Toulouse";
$areanames{fr}->{3353227} = "Nogaro";
$areanames{fr}->{3353228} = "Toulouse";
$areanames{fr}->{3353229} = "Toulouse";
$areanames{fr}->{3353230} = "Toulouse";
$areanames{fr}->{3353231} = "Toulouse";
$areanames{fr}->{3353232} = "Toulouse";
$areanames{fr}->{3353233} = "Albi";
$areanames{fr}->{3353234} = "Figeac";
$areanames{fr}->{3353235} = "Souillac";
$areanames{fr}->{3353236} = "Lannemezan";
$areanames{fr}->{3353237} = "Castres";
$areanames{fr}->{3353238} = "Moissac";
$areanames{fr}->{3353239} = "Pamiers";
$areanames{fr}->{3353240} = "Souillac";
$areanames{fr}->{3353241} = "Rodez";
$areanames{fr}->{3353242} = "Foix";
$areanames{fr}->{3353243} = "Villefranche\-de\-Rouergue";
$areanames{fr}->{3353244} = "Cazeres";
$areanames{fr}->{3353245} = "Saint\-Gaudens";
$areanames{fr}->{3353246} = "Auch";
$areanames{fr}->{3353247} = "Condom";
$areanames{fr}->{3353248} = "Nogaro";
$areanames{fr}->{3353249} = "Cahors";
$areanames{fr}->{3353250} = "Toulouse";
$areanames{fr}->{3353251} = "Toulouse";
$areanames{fr}->{3353252} = "Rodez";
$areanames{fr}->{3353253} = "Toulouse";
$areanames{fr}->{3353254} = "Rodez";
$areanames{fr}->{3353255} = "Montauban";
$areanames{fr}->{3353256} = "Castres";
$areanames{fr}->{3353257} = "Foix";
$areanames{fr}->{3353258} = "Toulouse";
$areanames{fr}->{3353259} = "Toulouse";
$areanames{fr}->{3353260} = "Toulouse";
$areanames{fr}->{3353261} = "Foix";
$areanames{fr}->{3353262} = "Albi";
$areanames{fr}->{3353263} = "Toulouse";
$areanames{fr}->{3353264} = "Montauban";
$areanames{fr}->{3353280} = "Moissac";
$areanames{fr}->{3353281} = "Toulouse";
$areanames{fr}->{3353282} = "Foix";
$areanames{fr}->{3353283} = "Pamiers";
$areanames{fr}->{3353284} = "Decazeville";
$areanames{fr}->{3353285} = "Espalion";
$areanames{fr}->{3353286} = "Rodez";
$areanames{fr}->{3353287} = "Saint\-Affrique";
$areanames{fr}->{3353288} = "Montauban";
$areanames{fr}->{3353289} = "Albi";
$areanames{fr}->{3353290} = "Auch";
$areanames{fr}->{3353291} = "Foix";
$areanames{fr}->{3353292} = "Toulouse";
$areanames{fr}->{3353293} = "Toulouse";
$areanames{fr}->{3353294} = "Toulouse";
$areanames{fr}->{3353295} = "Tarbes";
$areanames{fr}->{3353296} = "Albi";
$areanames{fr}->{3353297} = "Toulouse";
$areanames{fr}->{3353298} = "Toulouse";
$areanames{fr}->{3353299} = "Foix";
$areanames{fr}->{3353310} = "Bordeaux";
$areanames{fr}->{3353311} = "Pau";
$areanames{fr}->{3353312} = "Perigueux";
$areanames{fr}->{3353313} = "Mont\-de\-Marsan";
$areanames{fr}->{3353314} = "Marmande";
$areanames{fr}->{3353315} = "Pau";
$areanames{fr}->{3353316} = "Mussidan";
$areanames{fr}->{3353317} = "Nontron";
$areanames{fr}->{3353318} = "Perigueux";
$areanames{fr}->{3353319} = "Riberac";
$areanames{fr}->{3353320} = "Bordeaux";
$areanames{fr}->{3353321} = "Sarlat\-la\-Caneda";
$areanames{fr}->{3353322} = "Terrasson\-Lavilledieu";
$areanames{fr}->{3353323} = "Thiviers";
$areanames{fr}->{3353324} = "Perigueux";
$areanames{fr}->{3353325} = "Arcachon";
$areanames{fr}->{3353326} = "Bazas";
$areanames{fr}->{3353327} = "Blaye";
$areanames{fr}->{3353328} = "Langon";
$areanames{fr}->{3353329} = "Lesparre\-Medoc";
$areanames{fr}->{3353330} = "Bayonne";
$areanames{fr}->{3353331} = "La\ Reole";
$areanames{fr}->{3353332} = "Dax";
$areanames{fr}->{3353333} = "Dax";
$areanames{fr}->{3353334} = "Labouheyre";
$areanames{fr}->{3353335} = "Mont\-de\-Marsan";
$areanames{fr}->{3353336} = "Agen";
$areanames{fr}->{3353337} = "Marmande";
$areanames{fr}->{3353338} = "Nerac";
$areanames{fr}->{3353339} = "Villeneuve\-sur\-Lot";
$areanames{fr}->{3353360} = "Salies\-de\-Bearn";
$areanames{fr}->{3353361} = "Libourne";
$areanames{fr}->{3353362} = "Oloron\-Sainte\-Marie";
$areanames{fr}->{3353363} = "Bordeaux";
$areanames{fr}->{3353364} = "Pau";
$areanames{fr}->{3353365} = "Bordeaux";
$areanames{fr}->{3353366} = "Pau";
$areanames{fr}->{3353367} = "Mauleon\-Licharre";
$areanames{fr}->{3353368} = "Agen";
$areanames{fr}->{3353369} = "Riberac";
$areanames{fr}->{3353370} = "Bordeaux";
$areanames{fr}->{3353371} = "Bayonne";
$areanames{fr}->{3353372} = "Bayonne";
$areanames{fr}->{3353373} = "Pau";
$areanames{fr}->{3353374} = "Pau";
$areanames{fr}->{3353375} = "Salies\-de\-Bearn";
$areanames{fr}->{3353376} = "Bergerac";
$areanames{fr}->{3353377} = "Libourne";
$areanames{fr}->{3353378} = "Bayonne";
$areanames{fr}->{3353379} = "Bordeaux";
$areanames{fr}->{3353380} = "Mussidan";
$areanames{fr}->{3353381} = "Nontron";
$areanames{fr}->{3353382} = "Perigueux";
$areanames{fr}->{3353383} = "Riberac";
$areanames{fr}->{3353384} = "Sarlat\-la\-Caneda";
$areanames{fr}->{3353385} = "Terrasson\-Lavilledieu";
$areanames{fr}->{3353386} = "Thiviers";
$areanames{fr}->{3353387} = "Bazas";
$areanames{fr}->{3353388} = "Blaye";
$areanames{fr}->{3353389} = "Bordeaux";
$areanames{fr}->{3353390} = "Langon";
$areanames{fr}->{3353391} = "Lesparre\-Medoc";
$areanames{fr}->{3353392} = "La\ Reole";
$areanames{fr}->{3353393} = "Labouheyre";
$areanames{fr}->{3353394} = "Mont\-de\-Marsan";
$areanames{fr}->{3353395} = "Agen";
$areanames{fr}->{3353396} = "Nerac";
$areanames{fr}->{3353397} = "Villeneuve\-sur\-Lot";
$areanames{fr}->{3353398} = "Mauleon\-Licharre";
$areanames{fr}->{3353399} = "Oloron\-Sainte\-Marie";
$areanames{fr}->{335345} = "Toulouse";
$areanames{fr}->{335346} = "Toulouse";
$areanames{fr}->{3353468} = "Sud\ Ouest";
$areanames{fr}->{3353469} = "Sud\ Ouest";
$areanames{fr}->{335347} = "Sud\ Ouest";
$areanames{fr}->{335349} = "Sud\ Ouest";
$areanames{fr}->{3353500} = "Bordeaux";
$areanames{fr}->{3353501} = "La\ Reole";
$areanames{fr}->{3353502} = "Bergerac";
$areanames{fr}->{3353503} = "Mussidan";
$areanames{fr}->{3353504} = "Nontron";
$areanames{fr}->{3353505} = "Perigueux";
$areanames{fr}->{3353506} = "Riberac";
$areanames{fr}->{3353507} = "Andernos\-les\-Bains";
$areanames{fr}->{3353508} = "Arcachon";
$areanames{fr}->{3353509} = "Sarlat\-la\-Caneda";
$areanames{fr}->{3353510} = "Terrasson\-Lavilledieu";
$areanames{fr}->{3353511} = "Thiviers";
$areanames{fr}->{3353512} = "Bazas";
$areanames{fr}->{3353513} = "Blaye";
$areanames{fr}->{3353514} = "Bordeaux";
$areanames{fr}->{3353515} = "Langon";
$areanames{fr}->{3353516} = "Lesparre\-Medoc";
$areanames{fr}->{3353517} = "Libourne";
$areanames{fr}->{3353518} = "La\ Reole";
$areanames{fr}->{3353519} = "Dax";
$areanames{fr}->{3353520} = "Labouheyre";
$areanames{fr}->{3353521} = "Mont\-de\-Marsan";
$areanames{fr}->{3353522} = "Agen";
$areanames{fr}->{3353523} = "Marmande";
$areanames{fr}->{3353524} = "Nerac";
$areanames{fr}->{3353525} = "Villeneuve\-sur\-Lot";
$areanames{fr}->{3353526} = "Bayonne";
$areanames{fr}->{3353527} = "Mauleon\-Licharre";
$areanames{fr}->{3353528} = "Oloron\-Sainte\-Marie";
$areanames{fr}->{3353529} = "Pau";
$areanames{fr}->{3353550} = "Mauleon\-Licharre";
$areanames{fr}->{3353551} = "Oloron\-Sainte\-Marie";
$areanames{fr}->{3353552} = "Salies\-de\-Bearn";
$areanames{fr}->{3353553} = "Pau";
$areanames{fr}->{3353554} = "Bordeaux";
$areanames{fr}->{3353555} = "Agen";
$areanames{fr}->{3353556} = "Bordeaux";
$areanames{fr}->{3353557} = "Bergerac";
$areanames{fr}->{3353558} = "Mussidan";
$areanames{fr}->{3353559} = "Nontron";
$areanames{fr}->{3353560} = "Perigueux";
$areanames{fr}->{3353561} = "Riberac";
$areanames{fr}->{3353562} = "Sarlat\-la\-Caneda";
$areanames{fr}->{3353563} = "Terrasson\-Lavilledieu";
$areanames{fr}->{3353564} = "Thiviers";
$areanames{fr}->{3353565} = "Dax";
$areanames{fr}->{3353566} = "Andernos\-les\-Bains";
$areanames{fr}->{3353567} = "Arcachon";
$areanames{fr}->{3353568} = "Bazas";
$areanames{fr}->{3353569} = "Blaye";
$areanames{fr}->{3353570} = "Bordeaux";
$areanames{fr}->{3353571} = "Salies\-de\-Bearn";
$areanames{fr}->{3353572} = "Langon";
$areanames{fr}->{3353573} = "Lesparre\-Medoc";
$areanames{fr}->{3353574} = "Libourne";
$areanames{fr}->{3353575} = "Lesparre\-Medoc";
$areanames{fr}->{3353576} = "Villeneuve\-sur\-Lot";
$areanames{fr}->{3353577} = "Nerac";
$areanames{fr}->{3353578} = "Marmande";
$areanames{fr}->{3353579} = "La\ Reole";
$areanames{fr}->{3353580} = "Mont\-de\-Marsan";
$areanames{fr}->{3353581} = "Labouheyre";
$areanames{fr}->{3353582} = "Dax";
$areanames{fr}->{3353583} = "Dax";
$areanames{fr}->{3353584} = "Labouheyre";
$areanames{fr}->{3353585} = "Lesparre\-Medoc";
$areanames{fr}->{3353586} = "Langon";
$areanames{fr}->{3353587} = "Mont\-de\-Marsan";
$areanames{fr}->{3353588} = "Blaye";
$areanames{fr}->{3353589} = "Bazas";
$areanames{fr}->{3353590} = "Arcachon";
$areanames{fr}->{3353591} = "Andernos\-les\-Bains";
$areanames{fr}->{3353592} = "Thiviers";
$areanames{fr}->{3353593} = "Terrasson\-Lavilledieu";
$areanames{fr}->{3353594} = "Sarlat\-la\-Caneda";
$areanames{fr}->{3353595} = "Pau";
$areanames{fr}->{3353596} = "Agen";
$areanames{fr}->{3353597} = "Nontron";
$areanames{fr}->{3353598} = "Mussidan";
$areanames{fr}->{3353599} = "Bergerac";
$areanames{fr}->{3353600} = "Montauban";
$areanames{fr}->{3353601} = "Albi";
$areanames{fr}->{3353602} = "Tarbes";
$areanames{fr}->{3353603} = "Auch";
$areanames{fr}->{3353604} = "Cahors";
$areanames{fr}->{3353605} = "Foix";
$areanames{fr}->{3353606} = "Moissac";
$areanames{fr}->{3353607} = "Saint\-Gaudens";
$areanames{fr}->{3353608} = "Figeac";
$areanames{fr}->{3353609} = "Toulouse";
$areanames{fr}->{3353611} = "Toulouse";
$areanames{fr}->{3353612} = "Pamiers";
$areanames{fr}->{3353613} = "Decazeville";
$areanames{fr}->{3353614} = "Espalion";
$areanames{fr}->{3353615} = "Saint\-Affrique";
$areanames{fr}->{3353616} = "Villefranche\-de\-Rouergue";
$areanames{fr}->{3353617} = "Cazeres";
$areanames{fr}->{3353618} = "Condom";
$areanames{fr}->{3353619} = "Nogaro";
$areanames{fr}->{3353620} = "Souillac";
$areanames{fr}->{3353621} = "Lannemezan";
$areanames{fr}->{3353622} = "Cazeres";
$areanames{fr}->{3353623} = "Saint\-Gaudens";
$areanames{fr}->{3353624} = "Toulouse";
$areanames{fr}->{3353625} = "Toulouse";
$areanames{fr}->{3353627} = "Toulouse";
$areanames{fr}->{3353628} = "Toulouse";
$areanames{fr}->{3353629} = "Castres";
$areanames{fr}->{3353630} = "Tarbes";
$areanames{fr}->{3353631} = "Toulouse";
$areanames{fr}->{3353632} = "Tarbes";
$areanames{fr}->{3353633} = "Foix";
$areanames{fr}->{3353634} = "Saint\-Gaudens";
$areanames{fr}->{3353635} = "Albi";
$areanames{fr}->{3353636} = "Toulouse";
$areanames{fr}->{3353637} = "Toulouse";
$areanames{fr}->{3353638} = "Condom";
$areanames{fr}->{3353640} = "Toulouse";
$areanames{fr}->{3353641} = "Montauban";
$areanames{fr}->{3353642} = "Toulouse";
$areanames{fr}->{3353643} = "Toulouse";
$areanames{fr}->{3353644} = "Toulouse";
$areanames{fr}->{3353645} = "Cazeres";
$areanames{fr}->{3353646} = "Albi";
$areanames{fr}->{3353647} = "Toulouse";
$areanames{fr}->{3353648} = "Montauban";
$areanames{fr}->{3353653} = "Toulouse";
$areanames{fr}->{3354010} = "Blaye";
$areanames{fr}->{3354011} = "Langon";
$areanames{fr}->{3354012} = "Bordeaux";
$areanames{fr}->{3354013} = "Bordeaux";
$areanames{fr}->{3354014} = "Libourne";
$areanames{fr}->{3354015} = "La\ Reole";
$areanames{fr}->{3354016} = "Bordeaux";
$areanames{fr}->{3354017} = "Pau";
$areanames{fr}->{3354018} = "Bordeaux";
$areanames{fr}->{3354019} = "Lesparre\-Medoc";
$areanames{fr}->{3354020} = "Libourne";
$areanames{fr}->{3354021} = "Bordeaux";
$areanames{fr}->{3354022} = "Andernos\-les\-Bains";
$areanames{fr}->{3354023} = "Arcachon";
$areanames{fr}->{3354024} = "Bordeaux";
$areanames{fr}->{3354025} = "Bordeaux";
$areanames{fr}->{3354026} = "Andernos\-les\-Bains";
$areanames{fr}->{3354027} = "Arcachon";
$areanames{fr}->{3354028} = "Bazas";
$areanames{fr}->{3354029} = "Blaye";
$areanames{fr}->{3354040} = "Agen";
$areanames{fr}->{3354041} = "Langon";
$areanames{fr}->{3354042} = "Dax";
$areanames{fr}->{3354043} = "Andernos\-les\-Bains";
$areanames{fr}->{3354044} = "Labouheyre";
$areanames{fr}->{3354045} = "Bordeaux";
$areanames{fr}->{3354046} = "Perigueux";
$areanames{fr}->{3354047} = "Mont\-de\-Marsan";
$areanames{fr}->{3354048} = "Bayonne";
$areanames{fr}->{3354049} = "Agen";
$areanames{fr}->{3354050} = "Bazas";
$areanames{fr}->{3354051} = "Arcachon";
$areanames{fr}->{3354052} = "Marmande";
$areanames{fr}->{3354053} = "Blaye";
$areanames{fr}->{3354054} = "Bordeaux";
$areanames{fr}->{3354055} = "Nerac";
$areanames{fr}->{3354056} = "Langon";
$areanames{fr}->{3354057} = "Villeneuve\-sur\-Lot";
$areanames{fr}->{3354058} = "Libourne";
$areanames{fr}->{3354059} = "Bayonne";
$areanames{fr}->{3354060} = "Labouheyre";
$areanames{fr}->{3354061} = "Dax";
$areanames{fr}->{3354062} = "Mauleon\-Licharre";
$areanames{fr}->{3354063} = "Mont\-de\-Marsan";
$areanames{fr}->{3354064} = "Oloron\-Sainte\-Marie";
$areanames{fr}->{3354065} = "Marmande";
$areanames{fr}->{3354066} = "Pau";
$areanames{fr}->{3354067} = "Salies\-de\-Bearn";
$areanames{fr}->{3354068} = "Blaye";
$areanames{fr}->{3354069} = "Bayonne";
$areanames{fr}->{3354080} = "Andernos\-les\-Bains";
$areanames{fr}->{3354081} = "Bordeaux";
$areanames{fr}->{3354082} = "Bordeaux";
$areanames{fr}->{3354083} = "Bordeaux";
$areanames{fr}->{3354084} = "Bordeaux";
$areanames{fr}->{3354085} = "Pau";
$areanames{fr}->{3354086} = "Mont\-de\-Marsan";
$areanames{fr}->{3354087} = "Agen";
$areanames{fr}->{3354088} = "Marmande";
$areanames{fr}->{3354089} = "Marmande";
$areanames{fr}->{3354090} = "Lesparre\-Medoc";
$areanames{fr}->{3354091} = "Bordeaux";
$areanames{fr}->{3354092} = "Bergerac";
$areanames{fr}->{3354093} = "Mussidan";
$areanames{fr}->{3354094} = "Nontron";
$areanames{fr}->{3354095} = "Perigueux";
$areanames{fr}->{3354096} = "Riberac";
$areanames{fr}->{3354097} = "Sarlat\-la\-Caneda";
$areanames{fr}->{3354098} = "Terrasson\-Lavilledieu";
$areanames{fr}->{3354099} = "Thiviers";
$areanames{fr}->{33542} = "Sud\ Ouest";
$areanames{fr}->{3354254} = "Auch";
$areanames{fr}->{33544} = "Sud\ Ouest";
$areanames{fr}->{3354400} = "Limoges";
$areanames{fr}->{3354419} = "Limoges";
$areanames{fr}->{335442} = "Limoges";
$areanames{fr}->{3354425} = "Bellac";
$areanames{fr}->{3354430} = "Gueret";
$areanames{fr}->{3354431} = "Tulle";
$areanames{fr}->{3354440} = "Tulle";
$areanames{fr}->{3354441} = "Tulle";
$areanames{fr}->{3354460} = "Tulle";
$areanames{fr}->{335450} = "Sud\ Ouest";
$areanames{fr}->{335451} = "Sud\ Ouest";
$areanames{fr}->{335454} = "Sud\ Ouest";
$areanames{fr}->{335455} = "Sud\ Ouest";
$areanames{fr}->{335461} = "Sud\ Ouest";
$areanames{fr}->{3354700} = "Nerac";
$areanames{fr}->{3354701} = "Villeneuve\-sur\-Lot";
$areanames{fr}->{3354702} = "Bayonne";
$areanames{fr}->{3354703} = "Mauleon\-Licharre";
$areanames{fr}->{3354704} = "Oloron\-Sainte\-Marie";
$areanames{fr}->{3354705} = "Pau";
$areanames{fr}->{3354706} = "Salies\-de\-Bearn";
$areanames{fr}->{3354707} = "Bazas";
$areanames{fr}->{3354708} = "Riberac";
$areanames{fr}->{3354709} = "Langon";
$areanames{fr}->{3354710} = "Lesparre\-Medoc";
$areanames{fr}->{3354711} = "Libourne";
$areanames{fr}->{3354712} = "Bergerac";
$areanames{fr}->{3354713} = "Nontron";
$areanames{fr}->{3354714} = "Perigueux";
$areanames{fr}->{3354715} = "Bayonne";
$areanames{fr}->{3354716} = "Bordeaux";
$areanames{fr}->{3354717} = "Bordeaux";
$areanames{fr}->{3354718} = "Pau";
$areanames{fr}->{3354719} = "Mussidan";
$areanames{fr}->{3354750} = "Bordeaux";
$areanames{fr}->{3354751} = "Bayonne";
$areanames{fr}->{3354752} = "Bergerac";
$areanames{fr}->{3354753} = "Dax";
$areanames{fr}->{3354754} = "Bordeaux";
$areanames{fr}->{3354755} = "Dax";
$areanames{fr}->{3354756} = "Bergerac";
$areanames{fr}->{3354757} = "Marmande";
$areanames{fr}->{3354758} = "Mauleon\-Licharre";
$areanames{fr}->{3354759} = "Mont\-de\-Marsan";
$areanames{fr}->{3354780} = "Dax";
$areanames{fr}->{3354781} = "Labouheyre";
$areanames{fr}->{3354782} = "Langon";
$areanames{fr}->{3354783} = "Lesparre\-Medoc";
$areanames{fr}->{3354784} = "Libourne";
$areanames{fr}->{3354785} = "Marmande";
$areanames{fr}->{3354786} = "Mauleon\-Licharre";
$areanames{fr}->{3354787} = "Mont\-de\-Marsan";
$areanames{fr}->{3354788} = "Mussidan";
$areanames{fr}->{3354789} = "Nerac";
$areanames{fr}->{335495} = "Poitiers";
$areanames{fr}->{3355400} = "Dax";
$areanames{fr}->{3355401} = "Marmande";
$areanames{fr}->{3355402} = "Bordeaux";
$areanames{fr}->{3355403} = "Bayonne";
$areanames{fr}->{3355404} = "Langon";
$areanames{fr}->{3355405} = "La\ Reole";
$areanames{fr}->{3355406} = "Bordeaux";
$areanames{fr}->{3355407} = "Bordeaux";
$areanames{fr}->{3355408} = "Labouheyre";
$areanames{fr}->{3355409} = "Pau";
$areanames{fr}->{3355410} = "Bordeaux";
$areanames{fr}->{3355411} = "Bordeaux";
$areanames{fr}->{3355412} = "Pau";
$areanames{fr}->{3355413} = "Bordeaux";
$areanames{fr}->{3355414} = "Bordeaux";
$areanames{fr}->{3355415} = "Libourne";
$areanames{fr}->{3355416} = "Bordeaux";
$areanames{fr}->{3355417} = "Pau";
$areanames{fr}->{3355418} = "Arcachon";
$areanames{fr}->{3355419} = "Libourne";
$areanames{fr}->{3355420} = "Bordeaux";
$areanames{fr}->{3355421} = "Bordeaux";
$areanames{fr}->{3355422} = "Bergerac";
$areanames{fr}->{3355423} = "Mussidan";
$areanames{fr}->{3355424} = "Nontron";
$areanames{fr}->{3355425} = "Perigueux";
$areanames{fr}->{3355426} = "Riberac";
$areanames{fr}->{3355427} = "Sarlat\-la\-Caneda";
$areanames{fr}->{3355428} = "Terrasson\-Lavilledieu";
$areanames{fr}->{3355429} = "Thiviers";
$areanames{fr}->{3355430} = "Andernos\-les\-Bains";
$areanames{fr}->{3355431} = "Arcachon";
$areanames{fr}->{3355432} = "Bazas";
$areanames{fr}->{3355433} = "Blaye";
$areanames{fr}->{3355434} = "Langon";
$areanames{fr}->{3355435} = "Lesparre\-Medoc";
$areanames{fr}->{3355436} = "Libourne";
$areanames{fr}->{3355437} = "La\ Reole";
$areanames{fr}->{3355438} = "Dax";
$areanames{fr}->{3355439} = "Labouheyre";
$areanames{fr}->{3355440} = "Mont\-de\-Marsan";
$areanames{fr}->{3355441} = "Agen";
$areanames{fr}->{3355442} = "Marmande";
$areanames{fr}->{3355443} = "Nerac";
$areanames{fr}->{3355444} = "Villeneuve\-sur\-Lot";
$areanames{fr}->{3355445} = "Mauleon\-Licharre";
$areanames{fr}->{3355446} = "Oloron\-Sainte\-Marie";
$areanames{fr}->{3355447} = "Salies\-de\-Bearn";
$areanames{fr}->{3355448} = "Bordeaux";
$areanames{fr}->{3355449} = "Bordeaux";
$areanames{fr}->{335545} = "Bordeaux";
$areanames{fr}->{3355450} = "Perigueux";
$areanames{fr}->{3355456} = "Lesparre\-Medoc";
$areanames{fr}->{3355459} = "Langon";
$areanames{fr}->{3355460} = "Oloron\-Sainte\-Marie";
$areanames{fr}->{3355461} = "Bayonne";
$areanames{fr}->{3355462} = "Bergerac";
$areanames{fr}->{3355463} = "Andernos\-les\-Bains";
$areanames{fr}->{3355464} = "Bayonne";
$areanames{fr}->{3355465} = "Bordeaux";
$areanames{fr}->{3355466} = "Bayonne";
$areanames{fr}->{3355467} = "Bordeaux";
$areanames{fr}->{3355468} = "Bordeaux";
$areanames{fr}->{3355469} = "Bordeaux";
$areanames{fr}->{3355470} = "Agen";
$areanames{fr}->{3355471} = "Bordeaux";
$areanames{fr}->{3355472} = "Bordeaux";
$areanames{fr}->{3355473} = "Mont\-de\-Marsan";
$areanames{fr}->{3355474} = "Labouheyre";
$areanames{fr}->{3355475} = "Labouheyre";
$areanames{fr}->{3355476} = "Andernos\-les\-Bains";
$areanames{fr}->{3355477} = "Libourne";
$areanames{fr}->{3355478} = "Bordeaux";
$areanames{fr}->{3355479} = "Bordeaux";
$areanames{fr}->{3355480} = "Sarlat\-la\-Caneda";
$areanames{fr}->{3355481} = "Bayonne";
$areanames{fr}->{3355482} = "Sarlat\-la\-Caneda";
$areanames{fr}->{3355483} = "Bordeaux";
$areanames{fr}->{3355484} = "Dax";
$areanames{fr}->{3355760} = "Bordeaux";
$areanames{fr}->{3355761} = "Bordeaux";
$areanames{fr}->{3355762} = "Bordeaux";
$areanames{fr}->{3355763} = "Arcachon";
$areanames{fr}->{3355764} = "Blaye";
$areanames{fr}->{3355765} = "Bordeaux";
$areanames{fr}->{3355766} = "Sud\ Ouest";
$areanames{fr}->{3355767} = "Bordeaux";
$areanames{fr}->{3355768} = "Blaye";
$areanames{fr}->{3355769} = "Libourne";
$areanames{fr}->{335581} = "Sud\ Ouest";
$areanames{fr}->{335582} = "Sud\ Ouest";
$areanames{fr}->{335586} = "Sud\ Ouest";
$areanames{fr}->{335614} = "Toulouse";
$areanames{fr}->{335631} = "Sud\ Ouest";
$areanames{fr}->{3356400} = "Nerac";
$areanames{fr}->{3356401} = "Villeneuve\-sur\-Lot";
$areanames{fr}->{3356402} = "Bayonne";
$areanames{fr}->{3356403} = "Mauleon\-Licharre";
$areanames{fr}->{3356404} = "Oloron\-Sainte\-Marie";
$areanames{fr}->{3356405} = "Pau";
$areanames{fr}->{3356406} = "Salies\-de\-Bearn";
$areanames{fr}->{3356407} = "Bayonne";
$areanames{fr}->{3356408} = "Bordeaux";
$areanames{fr}->{3356409} = "Bordeaux";
$areanames{fr}->{3356410} = "Bordeaux";
$areanames{fr}->{3356411} = "Bayonne";
$areanames{fr}->{3356412} = "Bordeaux";
$areanames{fr}->{3356413} = "Bordeaux";
$areanames{fr}->{3356414} = "Bayonne";
$areanames{fr}->{3356415} = "Mauleon\-Licharre";
$areanames{fr}->{3356416} = "Oloron\-Sainte\-Marie";
$areanames{fr}->{3356417} = "Pau";
$areanames{fr}->{3356418} = "Salies\-de\-Bearn";
$areanames{fr}->{3356419} = "Pau";
$areanames{fr}->{3356420} = "Perigueux";
$areanames{fr}->{3356421} = "Bordeaux";
$areanames{fr}->{3356422} = "Mont\-de\-Marsan";
$areanames{fr}->{3356423} = "Agen";
$areanames{fr}->{3356424} = "Perigueux";
$areanames{fr}->{3356425} = "Agen";
$areanames{fr}->{3356426} = "Bordeaux";
$areanames{fr}->{3356427} = "Pau";
$areanames{fr}->{3356428} = "Bordeaux";
$areanames{fr}->{3356429} = "Pau";
$areanames{fr}->{3356430} = "Bayonne";
$areanames{fr}->{3356431} = "Bordeaux";
$areanames{fr}->{3356432} = "Thiviers";
$areanames{fr}->{3356433} = "Bordeaux";
$areanames{fr}->{3356434} = "Bergerac";
$areanames{fr}->{3356435} = "Villeneuve\-sur\-Lot";
$areanames{fr}->{3356436} = "Blaye";
$areanames{fr}->{3356437} = "Bordeaux";
$areanames{fr}->{3356438} = "Bordeaux";
$areanames{fr}->{3356439} = "Pau";
$areanames{fr}->{3356440} = "Labouheyre";
$areanames{fr}->{3356441} = "Dax";
$areanames{fr}->{3356442} = "Thiviers";
$areanames{fr}->{3356443} = "Villeneuve\-sur\-Lot";
$areanames{fr}->{3356444} = "Langon";
$areanames{fr}->{3356445} = "Mussidan";
$areanames{fr}->{3356446} = "Nontron";
$areanames{fr}->{3356447} = "Riberac";
$areanames{fr}->{3356448} = "Sarlat\-la\-Caneda";
$areanames{fr}->{3356449} = "Terrasson\-Lavilledieu";
$areanames{fr}->{3356450} = "Thiviers";
$areanames{fr}->{3356451} = "Andernos\-les\-Bains";
$areanames{fr}->{3356452} = "Arcachon";
$areanames{fr}->{3356453} = "Bazas";
$areanames{fr}->{3356454} = "Langon";
$areanames{fr}->{3356455} = "Lesparre\-Medoc";
$areanames{fr}->{3356456} = "La\ Reole";
$areanames{fr}->{3356457} = "Labouheyre";
$areanames{fr}->{3356458} = "Nerac";
$areanames{fr}->{3356459} = "Mauleon\-Licharre";
$areanames{fr}->{3356460} = "Bordeaux";
$areanames{fr}->{3356461} = "Oloron\-Sainte\-Marie";
$areanames{fr}->{3356462} = "Salies\-de\-Bearn";
$areanames{fr}->{3356463} = "Marmande";
$areanames{fr}->{3356464} = "Pau";
$areanames{fr}->{3356465} = "Andernos\-les\-Bains";
$areanames{fr}->{3356466} = "Arcachon";
$areanames{fr}->{3356467} = "Bazas";
$areanames{fr}->{3356468} = "Blaye";
$areanames{fr}->{3356469} = "Bordeaux";
$areanames{fr}->{3356470} = "Langon";
$areanames{fr}->{3356471} = "Lesparre\-Medoc";
$areanames{fr}->{3356472} = "Libourne";
$areanames{fr}->{3356473} = "La\ Reole";
$areanames{fr}->{3356474} = "Perigueux";
$areanames{fr}->{3356475} = "Blaye";
$areanames{fr}->{3356476} = "Labouheyre";
$areanames{fr}->{3356477} = "Mauleon\-Licharre";
$areanames{fr}->{3356478} = "Mussidan";
$areanames{fr}->{3356479} = "Nerac";
$areanames{fr}->{3356480} = "Nontron";
$areanames{fr}->{3356481} = "Oloron\-Sainte\-Marie";
$areanames{fr}->{3356482} = "Pau";
$areanames{fr}->{3356483} = "Perigueux";
$areanames{fr}->{3356484} = "Riberac";
$areanames{fr}->{3356485} = "Salies\-de\-Bearn";
$areanames{fr}->{3356486} = "Sarlat\-la\-Caneda";
$areanames{fr}->{3356487} = "Terrasson\-Lavilledieu";
$areanames{fr}->{3356488} = "Pau";
$areanames{fr}->{3356489} = "Agen";
$areanames{fr}->{3356490} = "Andernos\-les\-Bains";
$areanames{fr}->{3356491} = "Arcachon";
$areanames{fr}->{3356492} = "Bayonne";
$areanames{fr}->{3356493} = "Bazas";
$areanames{fr}->{3356494} = "Blaye";
$areanames{fr}->{3356495} = "Dax";
$areanames{fr}->{3356496} = "La\ Reole";
$areanames{fr}->{3356497} = "Labouheyre";
$areanames{fr}->{3356498} = "Lesparre\-Medoc";
$areanames{fr}->{3356499} = "Marmande";
$areanames{fr}->{335650} = "Sud\ Ouest";
$areanames{fr}->{3356740} = "Lannemezan";
$areanames{fr}->{3356741} = "Tarbes";
$areanames{fr}->{3356742} = "Albi";
$areanames{fr}->{3356743} = "Castres";
$areanames{fr}->{3356744} = "Pamiers";
$areanames{fr}->{3356745} = "Tarbes";
$areanames{fr}->{3356746} = "Castres";
$areanames{fr}->{3356747} = "Lannemezan";
$areanames{fr}->{3356748} = "Saint\-Gaudens";
$areanames{fr}->{3356749} = "Villefranche\-de\-Rouergue";
$areanames{fr}->{3356750} = "Cazeres";
$areanames{fr}->{3356751} = "Saint\-Gaudens";
$areanames{fr}->{3356752} = "Toulouse";
$areanames{fr}->{3356753} = "Castres";
$areanames{fr}->{3356754} = "Auch";
$areanames{fr}->{3356755} = "Cazeres";
$areanames{fr}->{3356756} = "Condom";
$areanames{fr}->{3356757} = "Castres";
$areanames{fr}->{3356758} = "Nogaro";
$areanames{fr}->{3356759} = "Cahors";
$areanames{fr}->{3356770} = "Toulouse";
$areanames{fr}->{3356771} = "Tarbes";
$areanames{fr}->{3356772} = "Albi";
$areanames{fr}->{3356773} = "Toulouse";
$areanames{fr}->{3356774} = "Toulouse";
$areanames{fr}->{3356775} = "Montauban";
$areanames{fr}->{3356776} = "Toulouse";
$areanames{fr}->{3356777} = "Toulouse";
$areanames{fr}->{3356778} = "Rodez";
$areanames{fr}->{3356779} = "Rodez";
$areanames{fr}->{3356780} = "Toulouse";
$areanames{fr}->{3356781} = "Toulouse";
$areanames{fr}->{3356782} = "Auch";
$areanames{fr}->{3356783} = "Auch";
$areanames{fr}->{3356784} = "Cahors";
$areanames{fr}->{3356785} = "Cahors";
$areanames{fr}->{3356786} = "Tarbes";
$areanames{fr}->{3356787} = "Albi";
$areanames{fr}->{3356788} = "Tarbes";
$areanames{fr}->{3356789} = "Albi";
$areanames{fr}->{3356790} = "Albi";
$areanames{fr}->{3356791} = "Albi";
$areanames{fr}->{3356792} = "Toulouse";
$areanames{fr}->{3356793} = "Pamiers";
$areanames{fr}->{3356794} = "Decazeville";
$areanames{fr}->{3356795} = "Toulouse";
$areanames{fr}->{3356796} = "Moissac";
$areanames{fr}->{3356797} = "Moissac";
$areanames{fr}->{3356798} = "Montauban";
$areanames{fr}->{3356799} = "Montauban";
$areanames{fr}->{3357900} = "Melle";
$areanames{fr}->{3357901} = "Niort";
$areanames{fr}->{3357902} = "Parthenay";
$areanames{fr}->{3357903} = "Thouars";
$areanames{fr}->{3357904} = "Chatellerault";
$areanames{fr}->{3357905} = "Civray";
$areanames{fr}->{3357906} = "Loudun";
$areanames{fr}->{3357907} = "Montmorillon";
$areanames{fr}->{3357908} = "Niort";
$areanames{fr}->{3357909} = "Angoulême";
$areanames{fr}->{3357910} = "Chatellerault";
$areanames{fr}->{3357911} = "Confolens";
$areanames{fr}->{3357912} = "Poitiers";
$areanames{fr}->{3357913} = "La\ Rochelle";
$areanames{fr}->{3357914} = "Saintes";
$areanames{fr}->{3357915} = "Montmorillon";
$areanames{fr}->{3357916} = "Poitiers";
$areanames{fr}->{3357917} = "Jonzac";
$areanames{fr}->{3357918} = "Niort";
$areanames{fr}->{3357919} = "Chatellerault";
$areanames{fr}->{3357920} = "Cognac";
$areanames{fr}->{3357921} = "Jonzac";
$areanames{fr}->{3357922} = "Rochefort";
$areanames{fr}->{3357923} = "Saint\-Jean\-dAngely";
$areanames{fr}->{3357924} = "Bressuire";
$areanames{fr}->{3357925} = "Melle";
$areanames{fr}->{3357926} = "Parthenay";
$areanames{fr}->{3357927} = "Thouars";
$areanames{fr}->{3357928} = "Chatellerault";
$areanames{fr}->{3357929} = "Civray";
$areanames{fr}->{3357930} = "Loudun";
$areanames{fr}->{3357931} = "Montmorillon";
$areanames{fr}->{3357932} = "Chatellerault";
$areanames{fr}->{3357933} = "Bressuire";
$areanames{fr}->{3357934} = "Saint\-Jean\-dAngely";
$areanames{fr}->{3357935} = "Angoulême";
$areanames{fr}->{3357936} = "Thouars";
$areanames{fr}->{3357937} = "Saintes";
$areanames{fr}->{3357938} = "Cognac";
$areanames{fr}->{3357939} = "Confolens";
$areanames{fr}->{3357940} = "Parthenay";
$areanames{fr}->{3357941} = "Civray";
$areanames{fr}->{3357942} = "Barbezieux\-Saint\-Hilaire";
$areanames{fr}->{3357943} = "Loudun";
$areanames{fr}->{3357944} = "La\ Rochelle";
$areanames{fr}->{3357945} = "Rochefort";
$areanames{fr}->{3357946} = "Melle";
$areanames{fr}->{3357947} = "Angoulême";
$areanames{fr}->{3357948} = "Barbezieux\-Saint\-Hilaire";
$areanames{fr}->{3357949} = "Cognac";
$areanames{fr}->{3357950} = "Confolens";
$areanames{fr}->{3357951} = "Jonzac";
$areanames{fr}->{3357952} = "Rochefort";
$areanames{fr}->{3357953} = "La\ Rochelle";
$areanames{fr}->{3357954} = "Saint\-Jean\-dAngely";
$areanames{fr}->{3357955} = "Saintes";
$areanames{fr}->{3357956} = "Bressuire";
$areanames{fr}->{3357957} = "Melle";
$areanames{fr}->{3357958} = "Niort";
$areanames{fr}->{3357959} = "Parthenay";
$areanames{fr}->{3357960} = "Thouars";
$areanames{fr}->{3357961} = "Chatellerault";
$areanames{fr}->{3357962} = "Civray";
$areanames{fr}->{3357963} = "Loudun";
$areanames{fr}->{3357964} = "Montmorillon";
$areanames{fr}->{3357965} = "Poitiers";
$areanames{fr}->{3357966} = "La\ Rochelle";
$areanames{fr}->{3357967} = "Rochefort";
$areanames{fr}->{3357968} = "Niort";
$areanames{fr}->{3357969} = "Angoulême";
$areanames{fr}->{3357970} = "Niort";
$areanames{fr}->{3357971} = "Barbezieux\-Saint\-Hilaire";
$areanames{fr}->{3357972} = "Cognac";
$areanames{fr}->{3357973} = "Confolens";
$areanames{fr}->{3357974} = "Jonzac";
$areanames{fr}->{3357975} = "Saint\-Jean\-dAngely";
$areanames{fr}->{3357976} = "Bressuire";
$areanames{fr}->{3357977} = "Melle";
$areanames{fr}->{3357978} = "Parthenay";
$areanames{fr}->{3357979} = "Poitiers";
$areanames{fr}->{3357980} = "Saintes";
$areanames{fr}->{3357981} = "Thouars";
$areanames{fr}->{3357982} = "Civray";
$areanames{fr}->{3357983} = "Loudun";
$areanames{fr}->{3357984} = "Montmorillon";
$areanames{fr}->{3357985} = "Jonzac";
$areanames{fr}->{3357986} = "Rochefort";
$areanames{fr}->{3357987} = "La\ Rochelle";
$areanames{fr}->{3357988} = "Saintes";
$areanames{fr}->{3357989} = "Angoulême";
$areanames{fr}->{3357990} = "Saint\-Jean\-dAngely";
$areanames{fr}->{3357991} = "Parthenay";
$areanames{fr}->{3357992} = "Civray";
$areanames{fr}->{3357993} = "Loudun";
$areanames{fr}->{3357994} = "Montmorillon";
$areanames{fr}->{3357995} = "La\ Rochelle";
$areanames{fr}->{3357996} = "Poitiers";
$areanames{fr}->{3357997} = "Rochefort";
$areanames{fr}->{3357998} = "Poitiers";
$areanames{fr}->{3357999} = "Niort";
$areanames{fr}->{3358100} = "Lannemezan";
$areanames{fr}->{3358101} = "Tarbes";
$areanames{fr}->{3358102} = "Albi";
$areanames{fr}->{3358103} = "Moissac";
$areanames{fr}->{3358104} = "Montauban";
$areanames{fr}->{3358105} = "Foix";
$areanames{fr}->{3358106} = "Pamiers";
$areanames{fr}->{3358107} = "Decazeville";
$areanames{fr}->{3358108} = "Toulouse";
$areanames{fr}->{3358109} = "Foix";
$areanames{fr}->{3358110} = "Toulouse";
$areanames{fr}->{3358111} = "Moissac";
$areanames{fr}->{3358112} = "Rodez";
$areanames{fr}->{3358113} = "Toulouse";
$areanames{fr}->{3358114} = "Toulouse";
$areanames{fr}->{3358115} = "Foix";
$areanames{fr}->{3358116} = "Decazeville";
$areanames{fr}->{3358117} = "Espalion";
$areanames{fr}->{3358118} = "Toulouse";
$areanames{fr}->{3358119} = "Rodez";
$areanames{fr}->{3358120} = "Saint\-Affrique";
$areanames{fr}->{3358121} = "Villefranche\-de\-Rouergue";
$areanames{fr}->{3358122} = "Cahors";
$areanames{fr}->{3358123} = "Nogaro";
$areanames{fr}->{3358124} = "Figeac";
$areanames{fr}->{3358125} = "Souillac";
$areanames{fr}->{3358126} = "Toulouse";
$areanames{fr}->{3358127} = "Albi";
$areanames{fr}->{3358128} = "Montauban";
$areanames{fr}->{3358129} = "Foix";
$areanames{fr}->{3358140} = "Albi";
$areanames{fr}->{3358141} = "Auch";
$areanames{fr}->{3358142} = "Cahors";
$areanames{fr}->{3358143} = "Castres";
$areanames{fr}->{3358144} = "Cazeres";
$areanames{fr}->{3358145} = "Condom";
$areanames{fr}->{3358146} = "Decazeville";
$areanames{fr}->{3358147} = "Espalion";
$areanames{fr}->{3358148} = "Figeac";
$areanames{fr}->{3358149} = "Foix";
$areanames{fr}->{3358150} = "Lannemezan";
$areanames{fr}->{3358151} = "Moissac";
$areanames{fr}->{3358152} = "Montauban";
$areanames{fr}->{3358153} = "Nogaro";
$areanames{fr}->{3358154} = "Pamiers";
$areanames{fr}->{3358155} = "Rodez";
$areanames{fr}->{3358156} = "Saint\-Affrique";
$areanames{fr}->{3358157} = "Saint\-Gaudens";
$areanames{fr}->{3358158} = "Souillac";
$areanames{fr}->{3358159} = "Tarbes";
$areanames{fr}->{3358170} = "Cahors";
$areanames{fr}->{3358171} = "Figeac";
$areanames{fr}->{3358172} = "Tarbes";
$areanames{fr}->{3358173} = "Souillac";
$areanames{fr}->{3358174} = "Lannemezan";
$areanames{fr}->{3358175} = "Tarbes";
$areanames{fr}->{3358176} = "Toulouse";
$areanames{fr}->{3358177} = "Toulouse";
$areanames{fr}->{3358178} = "Moissac";
$areanames{fr}->{3358179} = "Castres";
$areanames{fr}->{3358180} = "Toulouse";
$areanames{fr}->{3358181} = "Toulouse";
$areanames{fr}->{3358182} = "Montauban";
$areanames{fr}->{3358183} = "Toulouse";
$areanames{fr}->{3358184} = "Cazeres";
$areanames{fr}->{3358185} = "Condom";
$areanames{fr}->{3358186} = "Decazeville";
$areanames{fr}->{3358187} = "Espalion";
$areanames{fr}->{3358188} = "Figeac";
$areanames{fr}->{3358189} = "Lannemezan";
$areanames{fr}->{3358200} = "Saint\-Gaudens";
$areanames{fr}->{3358201} = "Toulouse";
$areanames{fr}->{3358202} = "Castres";
$areanames{fr}->{3358203} = "Montauban";
$areanames{fr}->{3358204} = "Tarbes";
$areanames{fr}->{3358205} = "Toulouse";
$areanames{fr}->{3358206} = "Toulouse";
$areanames{fr}->{3358207} = "Saint\-Gaudens";
$areanames{fr}->{3358208} = "Toulouse";
$areanames{fr}->{3358209} = "Condom";
$areanames{fr}->{3358210} = "Albi";
$areanames{fr}->{3358211} = "Cahors";
$areanames{fr}->{3358212} = "Figeac";
$areanames{fr}->{3358213} = "Souillac";
$areanames{fr}->{3358214} = "Lannemezan";
$areanames{fr}->{3358215} = "Tarbes";
$areanames{fr}->{3358216} = "Moissac";
$areanames{fr}->{3358217} = "Montauban";
$areanames{fr}->{3358218} = "Rodez";
$areanames{fr}->{3358219} = "Nogaro";
$areanames{fr}->{3358220} = "Foix";
$areanames{fr}->{3358221} = "Pamiers";
$areanames{fr}->{3358222} = "Decazeville";
$areanames{fr}->{3358223} = "Espalion";
$areanames{fr}->{3358224} = "Rodez";
$areanames{fr}->{3358225} = "Saint\-Affrique";
$areanames{fr}->{3358226} = "Villefranche\-de\-Rouergue";
$areanames{fr}->{3358227} = "Nogaro";
$areanames{fr}->{3358228} = "Toulouse";
$areanames{fr}->{3358229} = "Condom";
$areanames{fr}->{3358230} = "Foix";
$areanames{fr}->{3358231} = "Pamiers";
$areanames{fr}->{3358232} = "Nogaro";
$areanames{fr}->{3358233} = "Souillac";
$areanames{fr}->{3358234} = "Pamiers";
$areanames{fr}->{3358235} = "Albi";
$areanames{fr}->{3358236} = "Auch";
$areanames{fr}->{3358237} = "Moissac";
$areanames{fr}->{3358238} = "Saint\-Affrique";
$areanames{fr}->{3358239} = "Figeac";
$areanames{fr}->{3358240} = "Figeac";
$areanames{fr}->{3358241} = "Saint\-Gaudens";
$areanames{fr}->{3358242} = "Tarbes";
$areanames{fr}->{3358243} = "Cazeres";
$areanames{fr}->{3358244} = "Montauban";
$areanames{fr}->{3358245} = "Castres";
$areanames{fr}->{3358246} = "Foix";
$areanames{fr}->{3358247} = "Cahors";
$areanames{fr}->{3358248} = "Decazeville";
$areanames{fr}->{3358249} = "Espalion";
$areanames{fr}->{3358250} = "Villefranche\-de\-Rouergue";
$areanames{fr}->{3358251} = "Lannemezan";
$areanames{fr}->{3358252} = "Toulouse";
$areanames{fr}->{3358253} = "Decazeville";
$areanames{fr}->{3358254} = "Espalion";
$areanames{fr}->{3358255} = "Rodez";
$areanames{fr}->{3358256} = "Saint\-Affrique";
$areanames{fr}->{3358257} = "Villefranche\-de\-Rouergue";
$areanames{fr}->{3358258} = "Cazeres";
$areanames{fr}->{3358259} = "Saint\-Gaudens";
$areanames{fr}->{3358260} = "Toulouse";
$areanames{fr}->{3358261} = "Auch";
$areanames{fr}->{3358262} = "Condom";
$areanames{fr}->{3358263} = "Nogaro";
$areanames{fr}->{3358264} = "Cahors";
$areanames{fr}->{3358265} = "Figeac";
$areanames{fr}->{3358266} = "Souillac";
$areanames{fr}->{3358267} = "Lannemezan";
$areanames{fr}->{3358268} = "Tarbes";
$areanames{fr}->{3358269} = "Albi";
$areanames{fr}->{3358280} = "Tarbes";
$areanames{fr}->{3358281} = "Montauban";
$areanames{fr}->{3358283} = "Auch";
$areanames{fr}->{3358284} = "Toulouse";
$areanames{fr}->{3358285} = "Villefranche\-de\-Rouergue";
$areanames{fr}->{3358286} = "Condom";
$areanames{fr}->{3358287} = "Nogaro";
$areanames{fr}->{3358288} = "Toulouse";
$areanames{fr}->{3358289} = "Cahors";
$areanames{fr}->{3358600} = "Angoulême";
$areanames{fr}->{3358601} = "Bressuire";
$areanames{fr}->{3358602} = "Melle";
$areanames{fr}->{3358603} = "Niort";
$areanames{fr}->{3358604} = "Parthenay";
$areanames{fr}->{3358605} = "Thouars";
$areanames{fr}->{3358606} = "Civray";
$areanames{fr}->{3358607} = "Angoulême";
$areanames{fr}->{3358608} = "La\ Rochelle";
$areanames{fr}->{3358609} = "Poitiers";
$areanames{fr}->{3358610} = "La\ Rochelle";
$areanames{fr}->{3358611} = "La\ Rochelle";
$areanames{fr}->{3358612} = "Angoulême";
$areanames{fr}->{3358613} = "Barbezieux\-Saint\-Hilaire";
$areanames{fr}->{3358614} = "Cognac";
$areanames{fr}->{3358615} = "Confolens";
$areanames{fr}->{3358616} = "Poitiers";
$areanames{fr}->{3358617} = "Poitiers";
$areanames{fr}->{3358618} = "La\ Rochelle";
$areanames{fr}->{3358619} = "Cognac";
$areanames{fr}->{3358620} = "Niort";
$areanames{fr}->{3358621} = "Saint\-Jean\-dAngely";
$areanames{fr}->{3358622} = "Rochefort";
$areanames{fr}->{3358623} = "Saintes";
$areanames{fr}->{3358624} = "Chatellerault";
$areanames{fr}->{3358625} = "Bressuire";
$areanames{fr}->{3358626} = "Parthenay";
$areanames{fr}->{3358627} = "Cognac";
$areanames{fr}->{3358628} = "Poitiers";
$areanames{fr}->{3358629} = "Cognac";
$areanames{fr}->{3358630} = "Poitiers";
$areanames{fr}->{3358631} = "Poitiers";
$areanames{fr}->{3358632} = "Barbezieux\-Saint\-Hilaire";
$areanames{fr}->{3358633} = "Confolens";
$areanames{fr}->{3358634} = "Jonzac";
$areanames{fr}->{3358635} = "Rochefort";
$areanames{fr}->{3358636} = "Saintes";
$areanames{fr}->{3358637} = "Bressuire";
$areanames{fr}->{3358638} = "Melle";
$areanames{fr}->{3358639} = "Parthenay";
$areanames{fr}->{3358640} = "Thouars";
$areanames{fr}->{3358641} = "Chatellerault";
$areanames{fr}->{3358642} = "Civray";
$areanames{fr}->{3358643} = "Loudun";
$areanames{fr}->{3358644} = "Montmorillon";
$areanames{fr}->{3358645} = "Chatellerault";
$areanames{fr}->{3358646} = "Poitiers";
$areanames{fr}->{3358647} = "Saintes";
$areanames{fr}->{3358648} = "Poitiers";
$areanames{fr}->{3358649} = "Bressuire";
$areanames{fr}->{3358650} = "Angoulême";
$areanames{fr}->{3358651} = "Parthenay";
$areanames{fr}->{3358652} = "La\ Rochelle";
$areanames{fr}->{3358653} = "Rochefort";
$areanames{fr}->{3358654} = "Poitiers";
$areanames{fr}->{3358655} = "Angoulême";
$areanames{fr}->{3358656} = "La\ Rochelle";
$areanames{fr}->{3358657} = "Rochefort";
$areanames{fr}->{3358658} = "La\ Rochelle";
$areanames{fr}->{3358665} = "Cognac";
$areanames{fr}->{3358666} = "Angoulême";
$areanames{fr}->{3358667} = "Barbezieux\-Saint\-Hilaire";
$areanames{fr}->{3358668} = "Confolens";
$areanames{fr}->{3358669} = "Jonzac";
$areanames{fr}->{3358670} = "Loudun";
$areanames{fr}->{3358671} = "Montmorillon";
$areanames{fr}->{3358672} = "Melle";
$areanames{fr}->{3358673} = "Saint\-Jean\-dAngely";
$areanames{fr}->{3358674} = "Poitiers";
$areanames{fr}->{3358675} = "Angoulême";
$areanames{fr}->{3358676} = "Rochefort";
$areanames{fr}->{3358677} = "La\ Rochelle";
$areanames{fr}->{3358678} = "Niort";
$areanames{fr}->{3358679} = "Niort";
$areanames{fr}->{3358680} = "Rochefort";
$areanames{fr}->{3358681} = "Confolens";
$areanames{fr}->{3358682} = "Melle";
$areanames{fr}->{3358683} = "Thouars";
$areanames{fr}->{3358684} = "Angoulême";
$areanames{fr}->{3358685} = "La\ Rochelle";
$areanames{fr}->{3358686} = "Angoulême";
$areanames{fr}->{3358687} = "Rochefort";
$areanames{fr}->{3358688} = "La\ Rochelle";
$areanames{fr}->{3358689} = "Barbezieux\-Saint\-Hilaire";
$areanames{fr}->{3358690} = "Confolens";
$areanames{fr}->{3358691} = "Jonzac";
$areanames{fr}->{3358692} = "Saint\-Jean\-dAngely";
$areanames{fr}->{3358693} = "Melle";
$areanames{fr}->{3358694} = "Thouars";
$areanames{fr}->{3358695} = "Civray";
$areanames{fr}->{3358696} = "Loudun";
$areanames{fr}->{3358697} = "Montmorillon";
$areanames{fr}->{3358698} = "Poitiers";
$areanames{fr}->{3358699} = "Niort";
$areanames{fr}->{3358700} = "Limoges";
$areanames{fr}->{3358701} = "Tulle";
$areanames{fr}->{3358702} = "Limoges";
$areanames{fr}->{3358703} = "Limoges";
$areanames{fr}->{3358704} = "Aubusson";
$areanames{fr}->{3358705} = "Uzerche";
$areanames{fr}->{3358706} = "Argentat";
$areanames{fr}->{3358707} = "Limoges";
$areanames{fr}->{3358708} = "Limoges";
$areanames{fr}->{3358709} = "Tulle";
$areanames{fr}->{3358710} = "Tulle";
$areanames{fr}->{3358711} = "Ussel";
$areanames{fr}->{3358712} = "Uzerche";
$areanames{fr}->{3358713} = "Aubusson";
$areanames{fr}->{3358714} = "Limoges";
$areanames{fr}->{3358715} = "Gueret";
$areanames{fr}->{3358716} = "Gueret";
$areanames{fr}->{3358717} = "La\ Souterraine";
$areanames{fr}->{3358718} = "Bellac";
$areanames{fr}->{3358719} = "Limoges";
$areanames{fr}->{3358720} = "Limoges";
$areanames{fr}->{3358721} = "Limoges";
$areanames{fr}->{3358722} = "Tulle";
$areanames{fr}->{3358723} = "Gueret";
$areanames{fr}->{3358724} = "Boussac";
$areanames{fr}->{3358725} = "Argentat";
$areanames{fr}->{3358726} = "Aubusson";
$areanames{fr}->{3358727} = "Bellac";
$areanames{fr}->{3358728} = "Bourganeuf";
$areanames{fr}->{3358729} = "Boussac";
$areanames{fr}->{3358730} = "Gueret";
$areanames{fr}->{3358731} = "Limoges";
$areanames{fr}->{3358732} = "La\ Souterraine";
$areanames{fr}->{3358733} = "Limoges";
$areanames{fr}->{3358734} = "Argentat";
$areanames{fr}->{3358735} = "Argentat";
$areanames{fr}->{3358736} = "Aubusson";
$areanames{fr}->{3358737} = "Bellac";
$areanames{fr}->{3358738} = "Bourganeuf";
$areanames{fr}->{3358739} = "Boussac";
$areanames{fr}->{3358740} = "Gueret";
$areanames{fr}->{3358741} = "Limoges";
$areanames{fr}->{3358742} = "La\ Souterraine";
$areanames{fr}->{3358743} = "Tulle";
$areanames{fr}->{3358744} = "Ussel";
$areanames{fr}->{3358745} = "Uzerche";
$areanames{fr}->{3358746} = "Tulle";
$areanames{fr}->{3358747} = "Ussel";
$areanames{fr}->{3358748} = "Uzerche";
$areanames{fr}->{3358749} = "Tulle";
$areanames{fr}->{3358750} = "Limoges";
$areanames{fr}->{3358751} = "Ussel";
$areanames{fr}->{3358752} = "Uzerche";
$areanames{fr}->{3358753} = "Aubusson";
$areanames{fr}->{3358754} = "Bourganeuf";
$areanames{fr}->{3358755} = "Boussac";
$areanames{fr}->{3358756} = "Gueret";
$areanames{fr}->{3358757} = "La\ Souterraine";
$areanames{fr}->{3358758} = "Tulle";
$areanames{fr}->{3358759} = "Bellac";
$areanames{fr}->{3358760} = "Bellac";
$areanames{fr}->{3358761} = "Bourganeuf";
$areanames{fr}->{3358762} = "La\ Souterraine";
$areanames{fr}->{3358763} = "Gueret";
$areanames{fr}->{3358764} = "Limoges";
$areanames{fr}->{3358765} = "La\ Souterraine";
$areanames{fr}->{3358766} = "La\ Souterraine";
$areanames{fr}->{3358767} = "Uzerche";
$areanames{fr}->{3358768} = "Limoges";
$areanames{fr}->{3358769} = "Limoges";
$areanames{fr}->{3358770} = "Limoges";
$areanames{fr}->{3358771} = "Gueret";
$areanames{fr}->{3358772} = "Bourganeuf";
$areanames{fr}->{3358773} = "Limoges";
$areanames{fr}->{3358774} = "La\ Souterraine";
$areanames{fr}->{3358775} = "Limoges";
$areanames{fr}->{3358776} = "Limoges";
$areanames{fr}->{3358777} = "Bellac";
$areanames{fr}->{3358778} = "Ussel";
$areanames{fr}->{3358779} = "Limoges";
$areanames{fr}->{3358780} = "Gueret";
$areanames{fr}->{3358781} = "Argentat";
$areanames{fr}->{3358782} = "Aubusson";
$areanames{fr}->{3358783} = "Limoges";
$areanames{fr}->{3358784} = "Limoges";
$areanames{fr}->{3358785} = "Limoges";
$areanames{fr}->{3358786} = "Gueret";
$areanames{fr}->{3358787} = "Bellac";
$areanames{fr}->{3358788} = "Bourganeuf";
$areanames{fr}->{3358789} = "Bourganeuf";
$areanames{fr}->{3358790} = "Argentat";
$areanames{fr}->{3358791} = "Tulle";
$areanames{fr}->{3358792} = "Ussel";
$areanames{fr}->{3358793} = "Uzerche";
$areanames{fr}->{3358794} = "Aubusson";
$areanames{fr}->{3358795} = "Bourganeuf";
$areanames{fr}->{3358796} = "Boussac";
$areanames{fr}->{3358797} = "Gueret";
$areanames{fr}->{3358798} = "La\ Souterraine";
$areanames{fr}->{3358799} = "Bellac";
$areanames{fr}->{3359020} = "Les\ Abymes";
$areanames{fr}->{3359021} = "Pointe\-à\-Pitre";
$areanames{fr}->{3359022} = "Petit\-Canal";
$areanames{fr}->{3359023} = "Le\ Moule";
$areanames{fr}->{3359024} = "Morne\-À\-l\'Eau";
$areanames{fr}->{3359025} = "Baie\ Mahault";
$areanames{fr}->{3359026} = "Baie\ Mahault";
$areanames{fr}->{3359027} = "Saint\ Barthélémy";
$areanames{fr}->{3359028} = "Sainte\ Rose";
$areanames{fr}->{3359029} = "Saint\ Barthélémy";
$areanames{fr}->{3359032} = "Baie\ Mahault";
$areanames{fr}->{3359038} = "Baie\ Mahault";
$areanames{fr}->{3359041} = "Baie\ Mahault";
$areanames{fr}->{3359048} = "Les\ Abymes";
$areanames{fr}->{3359052} = "Saint\ Barthélémy";
$areanames{fr}->{3359060} = "Baie\ Mahault";
$areanames{fr}->{3359068} = "Les\ Abymes";
$areanames{fr}->{3359080} = "Saint\-Claude";
$areanames{fr}->{3359081} = "Basse\ Terre";
$areanames{fr}->{3359082} = "Pointe\-à\-Pitre";
$areanames{fr}->{3359083} = "Pointe\-à\-Pitre";
$areanames{fr}->{3359084} = "Le\ Gosier";
$areanames{fr}->{3359085} = "Sainte\-Anne";
$areanames{fr}->{3359086} = "Capesterre\ Belle\ Eau";
$areanames{fr}->{3359087} = "Saint\ Barthélémy";
$areanames{fr}->{3359088} = "Sainte\-Anne";
$areanames{fr}->{3359089} = "Les\ Abymes";
$areanames{fr}->{3359090} = "Pointe\-à\-Pitre";
$areanames{fr}->{3359091} = "Les\ Abymes";
$areanames{fr}->{3359092} = "Trois\ Rivieres";
$areanames{fr}->{3359093} = "Pointe\-à\-Pitre";
$areanames{fr}->{3359094} = "Petit\ Bourg";
$areanames{fr}->{3359095} = "Petit\ Bourg";
$areanames{fr}->{3359097} = "Grand\-Bourg";
$areanames{fr}->{3359098} = "Vieux\ Habitants";
$areanames{fr}->{3359099} = "Basse\ Terre";
$areanames{fr}->{3359422} = "Kourou";
$areanames{fr}->{3359425} = "Cayenne";
$areanames{fr}->{3359427} = "Saint\-Laurent\-du\-Maroni";
$areanames{fr}->{3359428} = "Cayenne";
$areanames{fr}->{3359429} = "Cayenne";
$areanames{fr}->{3359430} = "Cayenne";
$areanames{fr}->{3359431} = "Cayenne";
$areanames{fr}->{3359432} = "Kourou";
$areanames{fr}->{3359434} = "Saint\-Laurent\-du\-Maroni";
$areanames{fr}->{3359435} = "Matoury";
$areanames{fr}->{3359437} = "Cayenne";
$areanames{fr}->{3359438} = "Cayenne";
$areanames{fr}->{3359439} = "Cayenne";
$areanames{fr}->{3359638} = "Le\ Robert";
$areanames{fr}->{3359639} = "Fort\ de\ France";
$areanames{fr}->{3359642} = "Fort\ de\ France";
$areanames{fr}->{3359648} = "Rivière\-Salée";
$areanames{fr}->{3359650} = "Fort\ de\ France";
$areanames{fr}->{3359651} = "Fort\ de\ France";
$areanames{fr}->{3359652} = "Le\ Morne\ Rouge";
$areanames{fr}->{3359653} = "Le\ Lorrain";
$areanames{fr}->{3359654} = "Le\ François";
$areanames{fr}->{3359655} = "Le\ Morne\ Vert";
$areanames{fr}->{3359656} = "Ducos";
$areanames{fr}->{3359657} = "Saint\ Joseph";
$areanames{fr}->{3359658} = "Fort\ de\ France";
$areanames{fr}->{3359660} = "Fort\ de\ France";
$areanames{fr}->{3359661} = "Schoelcher";
$areanames{fr}->{3359662} = "Rivière\-Pilote";
$areanames{fr}->{3359663} = "Fort\ de\ France";
$areanames{fr}->{3359664} = "Fort\ de\ France";
$areanames{fr}->{3359665} = "Le\ Robert";
$areanames{fr}->{3359667} = "Gros\-Morne";
$areanames{fr}->{3359668} = "Rivière\-Salée";
$areanames{fr}->{3359669} = "Sainte\ Marie";
$areanames{fr}->{335967} = "Fort\ de\ France";
$areanames{fr}->{3359674} = "Le\ Vauclin";
$areanames{fr}->{3359676} = "Sainte\-Anne";
$areanames{fr}->{3359677} = "Ducos";
$areanames{fr}->{3359678} = "Basse\-Pointe";

    sub new {
      my $class = shift;
      my $number = shift;
      $number =~ s/(^\+33|\D)//g;
      my $self = bless({ number => $number, formatters => $formatters, validators => $validators, areanames => \%areanames}, $class);
      return $self if ($self->is_valid());
      $number =~ s/^(?:0)//;
      $self = bless({ number => $number, formatters => $formatters, validators => $validators, areanames => \%areanames}, $class);
      return $self->is_valid() ? $self : undef;
    }
1;